c    ch3o + o , cas+1+2/aug-cc-pvdz, 1A',  with Davidson correction (qc)

      real*8 function ch3o_h_qc(r, rpar, ipar)

c     
c     this is a general subroutine for evaluating the potential 
c     energy for the transitional modes.
c
c the potential should be output in au in vtot
c the cartesian coordinates of the atoms of each fragment are 
c stored in r
c the bond length or some other suitable approximation to a 
c distinguished reaction coordinate should be passed back in rmepi
c
c
c     the most important current utility of this routine is its 
c     evaluation of a particular set of valence bending and 
c     torsional angles for the incipient bond (qq).
c     it also generates the atom-atom interfragment distances and the 
c     center-of-mass to center-of-mass separation. 
c     it is also currently setup to consider
c     (i) valence stretching and bending potentials and/or 
c     lennard-jones and/or hard sphere interactions.
c     (ii) ion-molecule potentials including ion-induced dipole, 
c     ion-dipole, hard sphere, and/or lennard-jones interactions.
c
c the valence stretching and bending potential works in terms  of
c either 
c (i) an exponential extrapolation of an equilibrium set 
c of force constants 
c or
c (ii) an exponential interpolation of force constants along the 
c bond stretching path.
c
c for the ion-dipole component some work needs to be done on 
c defining the axis for the dipole.  once this is done it should 
c also be easy to include the ion-quadrupole interaction.
c     

      implicit double precision (a-h,o-z)

      include 'param2.fi'
      include 'commonpot.fi'

c
c vectors for primary coordinates 
c

      dimension r(nfrag,natommx,ndim)
      dimension cm(nfrag,ndim),rij(natommx,natommx)
      dimension qq(5),rmov(ndim),rmhv(ndim)

c
c vectors from mcpot calling routine
c

      dimension ift(nfrag),natom(nfrag),ineutf(nchmx)
      dimension dmss(nfrag,natommx),dmsst(nfrag)

c
c intermediate use vectors
c

      dimension r1(ndim),r2p(ndim),r2d(ndim),r2q(ndim)
      dimension nr(nfrag)
      dimension rbvec(ndim),rax1v(ndim),rbx1v(ndim),rax2v(ndim),
     $          rbx2v(ndim),rx1x2v(ndim),ray1v(ndim),rby1v(ndim),
     $          ray2v(ndim),rby2v(ndim),ry1y2v(ndim)
      dimension cptmp1(ndim),cptmp2(ndim),cptmp3(ndim)

c
c specific potential parameter vectors
c

      dimension fijrb(5,5),qqerb(5)
      dimension rpathv(nrpotm),vrr(nrpotm)

      include 'data.fi'
      data dmss(1,1), dmss(1,2) /15.99491 , 12./

c
c for generality/ease of modification purposes i have set this up to 
c begin by evaluating the interfragment atom-atom distances
c and a particular set of valence stretching, bending and torsional 
c angles.
c for efficient use one might wish to only evaluate the components 
c that are required for the particular potential being used.  for a 
c variety of reasons this seems to me to be best left for the specific 
c applications.
c      
      pi2 = asin(1.0d0)
      pi = 2.0d0*pi2

c
c now evaluate atom-atom separations
c

      rij(1,1) = dsqrt((r(1,1,1)-r(2,1,1))**2+(r(1,1,2)-r(2,1,2))**2+ 
     $                 (r(1,1,3)-r(2,1,3))**2)
      rbond = rij(1,1)
      rmepi = rbond

c
c now proceed to the valence bending/torsional coordinates.
c

c
c determine distances needed for bending angles
c
      rbond2 = 0.0d0
      rax12 = 0.0d0
      rbx12 = 0.0d0
      rby12 = 0.0d0
      ray12 = 0.0d0
      rmo2 = 0.0d0
      rmh2 = 0.0d0
      dm12t = dmss(1,1)+dmss(1,2)
      do 1500 idim = 1 , ndim
         rbvec(idim) = r(2,1,idim) - r(1,1,idim)
         rbond2 = rbond2 + rbvec(idim)**2
         rax1v(idim) = r(1,2,idim) - r(1,1,idim)
         rax12 = rax12 + rax1v(idim)**2
         rbx1v(idim) = r(2,1,idim) - r(1,2,idim)
         rbx12 = rbx12 + rbx1v(idim)**2
         rmov(idim)=(dmss(1,2)*r(1,2,idim)+dmss(1,1)*r(1,1,idim))/
     $    dm12t - r(1,1,idim)
         rmo2 = rmo2 + rmov(idim)**2
         rmhv(idim)=(dmss(1,2)*r(1,2,idim)+dmss(1,1)*r(1,1,idim))/
     $    dm12t - r(2,1,idim)
         rmh2 = rmh2 + rmhv(idim)**2
 1500 continue
      rbond = sqrt(rbond2)
      rax1 = sqrt(rax12)
      rbx1 = sqrt(rbx12)
      ray1 = sqrt(ray12)
      rby1 = sqrt(rby12)
      rmo = sqrt(rmo2)
      rmh = sqrt(rmh2)
c     write (6,*) 'rmo test',rmov,rmo
c     write (6,*) 'rmh test',rmhv,rmh
c     write (6,*) 'rbvec test',rbvec,rbond
c     write (6,*) 'r11 test',(r(1,1,idim),idim=1,ndim)
c     write (6,*) 'r12 test',(r(1,2,idim),idim=1,ndim)
c     write (6,*) 'r21 test',(r(2,1,idim),idim=1,ndim)
c     write (6,*) 'mss test',dmss(1,1),dmss(1,2),dm12t

c     
c     calculate the bending angles.
c     

      cthep = (rmo2+rmh2-rbond2)/(2.0d0*rmo*rmh)
      if (dabs(cthep).le.1.0d0) go to 1630
      if(dabs(cthep)-1.d0.gt.1.d-10) 
     x   write (6,*) 'error in thep, cthep = ',cthep
      thep = 0.0d0
      if (cthep.lt.1.0d0) thep = 2.0d0*dasin(1.0d0)
      go to 1650
 1630 continue
      thep = dacos(cthep)
 1650 continue

      cthe1 = (rax12 + rbond2 - rbx12)/(2.0d0*rax1*rbond)
      if (dabs(cthe1).le.1.0d0) go to 2030
      if(dabs(cthe1)-1.d0.gt.1.e-6) 
     x   write (6,*) 'error in the1, cthe1 = ',cthe1
      the1 = 0.0d0
      if (cthe1.lt.1.0d0) the1 = 2.0d0*dasin(1.0d0)
      go to 2050
 2030 continue
c      write (6,*) 'cthe1 test',cthe1
      the1 = dacos(cthe1)
 2050 continue
      
c     
c     calculate the torsional angles if ivb.ne.0
c     
c
c
c determine distances needed for torsional angles
c
      rax22 = 0.0d0
      rbx22 = 0.0d0
      rby22 = 0.0d0
      ray22 = 0.0d0
      ry1y22 = 0.0d0
      rx1x22 = 0.0d0
      do idim = 1 , ndim
         rax2v(idim) = r(1,3,idim) - r(1,1,idim)
         rax22 = rax22 + rax2v(idim)**2
         rbx2v(idim) = r(2,1,idim) - r(1,3,idim)
         rbx22 = rbx22 + rbx2v(idim)**2
         rx1x2v(idim) = r(1,3,idim) - r(1,2,idim)
         rx1x22 = rx1x22 + rx1x2v(idim)**2
      enddo
      rax2 = sqrt(rax22)
      rbx2 = sqrt(rbx22)
      ray2 = sqrt(ray22)
      rby2 = sqrt(rby22)
      ry1y2 = sqrt(ry1y22)
      rx1x2 = sqrt(rx1x22)

c
c     now evaluate tau 3 (torsion angle for x2,11,x1,21.
c     tau3b corresponds to torsion angle for perp to x1,21;
c     x2,21,x1,perp
c

c
c     consider the terminal atom case.
c
c     first evaluate internal x2,11,x1 bending angle
c

      ctaint = (rax12 + rx1x22 - rax22)/(2.0d0*rax1*rx1x2)
      if (dabs(ctaint).le.1.0d0) go to 2810
      write (6,*) 'error in taint, ctaint = ',ctaint
      taint = 0.0d0
      if (ctaint.lt.1.0d0) taint = 2.0d0*dasin(1.0d0)
      go to 2820
 2810 continue
c      write (6,*) 'ctaint test',ctaint
      taint = dacos(ctaint)
 2820 continue
 
      sum = 0.0d0
      call cross(rbvec,rax1v,cptmp1)
      call cross(rax1v,rx1x2v,cptmp2)
      do 2830 idim = 1 , ndim
         sum = sum - cptmp1(idim)*cptmp2(idim)
 2830 continue
      ctau3 = sum/(rbond*rax12*rx1x2*sin(the1)*sin(taint))
      if (dabs(ctau3).le.1.0d0) go to 2840
      write (6,*) 'error in tau3, ctau3 = ',ctau3
      tau3 = 0.0d0
      if (ctau3.lt.1.0d0) tau3 = 2.0d0*dasin(1.0d0)
      go to 2850
 2840 continue
c      write (6,*) 'ctau3 test',ctau3
      tau3 = dacos(ctau3)
 2850 continue
         
c     
c     still need to determine whether it is +/-
c     
         
      sum = 0.0d0
      call cross(rbvec,rax1v,cptmp1)
      call cross(rax1v,cptmp2,cptmp3)
      do 2860 idim = 1 , ndim
         sum = sum - cptmp1(idim)*cptmp3(idim)
 2860 continue
      ctau3b = sum/(rbond*rax12*rax1*rx1x2*sin(the1)*
     $ sin(taint))
      if (dabs(ctau3b).le.1.0d0) go to 2870
      write (6,*) 'error in tau3b, ctau3b = ',ctau3b
      tau3b = 0.0d0
      if (ctau3b.lt.1.0d0) tau3b = 2.0d0*dasin(1.0d0)
      go to 2880
 2870 continue
c      write (6,*) 'ctau3b test',ctau3b
      tau3b = dacos(ctau3b)
 2880 continue
            
      if (tau3b.lt.pi2) tau3 = -tau3

      thetap = 180.0d0 - thep*180.0d0/pi
      phi = tau3*180.0d0/pi

      if (rmh.lt.3.2d0) then
c        write (6,*) 'error rmh too small',rmh,theta,phi
         rmh=3.2d0
      endif
      if (rmh.gt.15.0d0) then
c        write (6,*) 'error rmh too large',rmh,theta,phi
         rmh=15.0d0
      endif
c     write (6,*) 'entering hpch3o',rmh,thetap,phi,vtot
      call hpch3o_qc(rmh,thetap,phi,vtot)
      ch3o_h_qc = vtot
c     write (6,*) 'exiting hpch3o',rmh,thetap,phi,vtot

      return
      end

      subroutine hpch3o_qc(rmh,theta,phi,energy)
      implicit real*8 (a-h,o-z)
      data degrad / 57.29577951308232d 00/
c
c     fcs is based on points having cs symmetry.
c     by convention if theta>0, fcs returns the
c     energy for phi=0 (eclipsed), if theta<0, fcs
c     returns the energy for phi=180 (staggered)
c
c
      call fcs_dci_1ap(rmh,-theta,es)
      call fcs_dci_1ap(rmh,theta,ee)

      p = phi/degrad
      sum = 0.5d0*(ee+es)
      diff =0.5d0*(ee-es)
      energy = 115.2783822d0 + sum + diff*cos( 3.0d0*p) 

      return
      end
      subroutine fcs_dci_1ap(xi,yi,fi)
c
c     cas+1+2+qc/aug-cc-pvdz
c     1a' state
c
      implicit real*8 (a-h,o-z)
      dimension fpp(15,42,2),f(15,42),fpppp(15,42)
      dimension delx(14),dely(41),x(15),y(42)
      dimension c(4,4),px(4),py(4)
 
      data f( 1, 1),f( 1, 2) / -1.15385733d+02 , -1.15389956d+02 /
      data f( 1, 3),f( 1, 4) / -1.15385872d+02 , -1.15378369d+02 /
      data f( 1, 5),f( 1, 6) / -1.15378389d+02 , -1.15386024d+02 /
      data f( 1, 7),f( 1, 8) / -1.15390520d+02 , -1.15387172d+02 /
      data f( 1, 9),f( 1,10) / -1.15375363d+02 , -1.15356933d+02 /
      data f( 1,11),f( 1,12) / -1.15334314d+02 , -1.15309530d+02 /
      data f( 1,13),f( 1,14) / -1.15283951d+02 , -1.15258332d+02 /
      data f( 1,15),f( 1,16) / -1.15232677d+02 , -1.15206221d+02 /
      data f( 1,17),f( 1,18) / -1.15187296d+02 , -1.15250304d+02 /
      data f( 1,19),f( 1,20) / -1.15248485d+02 , -1.15223071d+02 /
      data f( 1,21),f( 1,22) / -1.15186456d+02 , -1.15184437d+02 /
      data f( 1,23),f( 1,24) / -1.15186662d+02 , -1.14911405d+02 /
      data f( 1,25),f( 1,26) / -1.12891472d+02 , -1.14537941d+02 /
      data f( 1,27),f( 1,28) / -1.15167305d+02 , -1.15214099d+02 /
      data f( 1,29),f( 1,30) / -1.15226241d+02 , -1.15259950d+02 /
      data f( 1,31),f( 1,32) / -1.15293686d+02 , -1.15324539d+02 /
      data f( 1,33),f( 1,34) / -1.15351271d+02 , -1.15372337d+02 /
      data f( 1,35),f( 1,36) / -1.15385733d+02 , -1.15389956d+02 /
      data f( 1,37),f( 1,38) / -1.15385872d+02 , -1.15378369d+02 /
      data f( 1,39),f( 1,40) / -1.15378389d+02 , -1.15386024d+02 /
      data f( 1,41),f( 1,42) / -1.15390520d+02 , -1.15387172d+02 /
      data f( 2, 1),f( 2, 2) / -1.15363585d+02 , -1.15365912d+02 /
      data f( 2, 3),f( 2, 4) / -1.15360642d+02 , -1.15352516d+02 /
      data f( 2, 5),f( 2, 6) / -1.15352536d+02 , -1.15360802d+02 /
      data f( 2, 7),f( 2, 8) / -1.15366497d+02 , -1.15365030d+02 /
      data f( 2, 9),f( 2,10) / -1.15355897d+02 , -1.15340824d+02 /
      data f( 2,11),f( 2,12) / -1.15322042d+02 , -1.15301438d+02 /
      data f( 2,13),f( 2,14) / -1.15280345d+02 , -1.15259627d+02 /
      data f( 2,15),f( 2,16) / -1.15239669d+02 , -1.15220763d+02 /
      data f( 2,17),f( 2,18) / -1.15208818d+02 , -1.15232769d+02 /
      data f( 2,19),f( 2,20) / -1.15254272d+02 , -1.15242492d+02 /
      data f( 2,21),f( 2,22) / -1.15217978d+02 , -1.15217624d+02 /
      data f( 2,23),f( 2,24) / -1.15222879d+02 , -1.15049754d+02 /
      data f( 2,25),f( 2,26) / -1.14373981d+02 , -1.14855999d+02 /
      data f( 2,27),f( 2,28) / -1.15201597d+02 , -1.15231298d+02 /
      data f( 2,29),f( 2,30) / -1.15234999d+02 , -1.15259047d+02 /
      data f( 2,31),f( 2,32) / -1.15286733d+02 , -1.15312773d+02 /
      data f( 2,33),f( 2,34) / -1.15335369d+02 , -1.15352933d+02 /
      data f( 2,35),f( 2,36) / -1.15363585d+02 , -1.15365912d+02 /
      data f( 2,37),f( 2,38) / -1.15360642d+02 , -1.15352516d+02 /
      data f( 2,39),f( 2,40) / -1.15352536d+02 , -1.15360802d+02 /
      data f( 2,41),f( 2,42) / -1.15366497d+02 , -1.15365030d+02 /
      data f( 3, 1),f( 3, 2) / -1.15343566d+02 , -1.15343337d+02 /
      data f( 3, 3),f( 3, 4) / -1.15335468d+02 , -1.15324540d+02 /
      data f( 3, 5),f( 3, 6) / -1.15324560d+02 , -1.15335636d+02 /
      data f( 3, 7),f( 3, 8) / -1.15343923d+02 , -1.15344961d+02 /
      data f( 3, 9),f( 3,10) / -1.15338692d+02 , -1.15326925d+02 /
      data f( 3,11),f( 3,12) / -1.15311818d+02 , -1.15295173d+02 /
      data f( 3,13),f( 3,14) / -1.15278285d+02 , -1.15262036d+02 /
      data f( 3,15),f( 3,16) / -1.15246939d+02 , -1.15233458d+02 /
      data f( 3,17),f( 3,18) / -1.15224779d+02 , -1.15231881d+02 /
      data f( 3,19),f( 3,20) / -1.15249558d+02 , -1.15246208d+02 /
      data f( 3,21),f( 3,22) / -1.15227190d+02 , -1.15228580d+02 /
      data f( 3,23),f( 3,24) / -1.15242983d+02 , -1.15153311d+02 /
      data f( 3,25),f( 3,26) / -1.14892780d+02 , -1.15062423d+02 /
      data f( 3,27),f( 3,28) / -1.15231788d+02 , -1.15244597d+02 /
      data f( 3,29),f( 3,30) / -1.15243831d+02 , -1.15260402d+02 /
      data f( 3,31),f( 3,32) / -1.15282192d+02 , -1.15303418d+02 /
      data f( 3,33),f( 3,34) / -1.15321895d+02 , -1.15335906d+02 /
      data f( 3,35),f( 3,36) / -1.15343566d+02 , -1.15343337d+02 /
      data f( 3,37),f( 3,38) / -1.15335468d+02 , -1.15324540d+02 /
      data f( 3,39),f( 3,40) / -1.15324560d+02 , -1.15335636d+02 /
      data f( 3,41),f( 3,42) / -1.15343923d+02 , -1.15344961d+02 /
      data f( 4, 1),f( 4, 2) / -1.15326624d+02 , -1.15324001d+02 /
      data f( 4, 3),f( 4, 4) / -1.15313238d+02 , -1.15296973d+02 /
      data f( 4, 5),f( 4, 6) / -1.15296983d+02 , -1.15313401d+02 /
      data f( 4, 7),f( 4, 8) / -1.15324552d+02 , -1.15327905d+02 /
      data f( 4, 9),f( 4,10) / -1.15324197d+02 , -1.15315390d+02 /
      data f( 4,11),f( 4,12) / -1.15303580d+02 , -1.15290483d+02 /
      data f( 4,13),f( 4,14) / -1.15277297d+02 , -1.15264815d+02 /
      data f( 4,15),f( 4,16) / -1.15253524d+02 , -1.15243772d+02 /
      data f( 4,17),f( 4,18) / -1.15237166d+02 , -1.15237952d+02 /
      data f( 4,19),f( 4,20) / -1.15244551d+02 , -1.15240975d+02 /
      data f( 4,21),f( 4,22) / -1.15219526d+02 , -1.15224641d+02 /
      data f( 4,23),f( 4,24) / -1.15251876d+02 , -1.15216908d+02 /
      data f( 4,25),f( 4,26) / -1.15112523d+02 , -1.15177753d+02 /
      data f( 4,27),f( 4,28) / -1.15253729d+02 , -1.15254434d+02 /
      data f( 4,29),f( 4,30) / -1.15251468d+02 , -1.15262816d+02 /
      data f( 4,31),f( 4,32) / -1.15279486d+02 , -1.15296281d+02 /
      data f( 4,33),f( 4,34) / -1.15310940d+02 , -1.15321692d+02 /
      data f( 4,35),f( 4,36) / -1.15326624d+02 , -1.15324001d+02 /
      data f( 4,37),f( 4,38) / -1.15313238d+02 , -1.15296973d+02 /
      data f( 4,39),f( 4,40) / -1.15296983d+02 , -1.15313401d+02 /
      data f( 4,41),f( 4,42) / -1.15324552d+02 , -1.15327905d+02 /
      data f( 5, 1),f( 5, 2) / -1.15313108d+02 , -1.15308864d+02 /
      data f( 5, 3),f( 5, 4) / -1.15296394d+02 , -1.15275333d+02 /
      data f( 5, 5),f( 5, 6) / -1.15275322d+02 , -1.15296528d+02 /
      data f( 5, 7),f( 5, 8) / -1.15309344d+02 , -1.15314221d+02 /
      data f( 5, 9),f( 5,10) / -1.15312490d+02 , -1.15306134d+02 /
      data f( 5,11),f( 5,12) / -1.15297136d+02 , -1.15287068d+02 /
      data f( 5,13),f( 5,14) / -1.15276983d+02 , -1.15267531d+02 /
      data f( 5,15),f( 5,16) / -1.15259109d+02 , -1.15251993d+02 /
      data f( 5,17),f( 5,18) / -1.15246871d+02 , -1.15245267d+02 /
      data f( 5,19),f( 5,20) / -1.15245581d+02 , -1.15238684d+02 /
      data f( 5,21),f( 5,22) / -1.15217591d+02 , -1.15221493d+02 /
      data f( 5,23),f( 5,24) / -1.15254869d+02 , -1.15251492d+02 /
      data f( 5,25),f( 5,26) / -1.15212465d+02 , -1.15238212d+02 /
      data f( 5,27),f( 5,28) / -1.15267649d+02 , -1.15261429d+02 /
      data f( 5,29),f( 5,30) / -1.15257693d+02 , -1.15265521d+02 /
      data f( 5,31),f( 5,32) / -1.15278051d+02 , -1.15291021d+02 /
      data f( 5,33),f( 5,34) / -1.15302349d+02 , -1.15310329d+02 /
      data f( 5,35),f( 5,36) / -1.15313108d+02 , -1.15308864d+02 /
      data f( 5,37),f( 5,38) / -1.15296394d+02 , -1.15275333d+02 /
      data f( 5,39),f( 5,40) / -1.15275322d+02 , -1.15296528d+02 /
      data f( 5,41),f( 5,42) / -1.15309344d+02 , -1.15314221d+02 /
      data f( 6, 1),f( 6, 2) / -1.15302870d+02 , -1.15298010d+02 /
      data f( 6, 3),f( 6, 4) / -1.15285904d+02 , -1.15266868d+02 /
      data f( 6, 5),f( 6, 6) / -1.15266825d+02 , -1.15285987d+02 /
      data f( 6, 7),f( 6, 8) / -1.15298392d+02 , -1.15303788d+02 /
      data f( 6, 9),f( 6,10) / -1.15303372d+02 , -1.15298926d+02 /
      data f( 6,11),f( 6,12) / -1.15292220d+02 , -1.15284633d+02 /
      data f( 6,13),f( 6,14) / -1.15277046d+02 , -1.15269963d+02 /
      data f( 6,15),f( 6,16) / -1.15263683d+02 , -1.15258418d+02 /
      data f( 6,17),f( 6,18) / -1.15254457d+02 , -1.15252150d+02 /
      data f( 6,19),f( 6,20) / -1.15249924d+02 , -1.15242272d+02 /
      data f( 6,21),f( 6,22) / -1.15226211d+02 , -1.15227740d+02 /
      data f( 6,23),f( 6,24) / -1.15256696d+02 , -1.15268530d+02 /
      data f( 6,25),f( 6,26) / -1.15258231d+02 , -1.15268128d+02 /
      data f( 6,27),f( 6,28) / -1.15275419d+02 , -1.15266293d+02 /
      data f( 6,29),f( 6,30) / -1.15262637d+02 , -1.15268112d+02 /
      data f( 6,31),f( 6,32) / -1.15277425d+02 , -1.15287253d+02 /
      data f( 6,33),f( 6,34) / -1.15295816d+02 , -1.15301583d+02 /
      data f( 6,35),f( 6,36) / -1.15302870d+02 , -1.15298010d+02 /
      data f( 6,37),f( 6,38) / -1.15285904d+02 , -1.15266868d+02 /
      data f( 6,39),f( 6,40) / -1.15266825d+02 , -1.15285987d+02 /
      data f( 6,41),f( 6,42) / -1.15298392d+02 , -1.15303788d+02 /
      data f( 7, 1),f( 7, 2) / -1.15292589d+02 , -1.15288213d+02 /
      data f( 7, 3),f( 7, 4) / -1.15279083d+02 , -1.15267423d+02 /
      data f( 7, 5),f( 7, 6) / -1.15267371d+02 , -1.15279106d+02 /
      data f( 7, 7),f( 7, 8) / -1.15288453d+02 , -1.15293225d+02 /
      data f( 7, 9),f( 7,10) / -1.15293755d+02 , -1.15291268d+02 /
      data f( 7,11),f( 7,12) / -1.15287092d+02 , -1.15282269d+02 /
      data f( 7,13),f( 7,14) / -1.15277439d+02 , -1.15272916d+02 /
      data f( 7,15),f( 7,16) / -1.15268881d+02 , -1.15265480d+02 /
      data f( 7,17),f( 7,18) / -1.15262789d+02 , -1.15260608d+02 /
      data f( 7,19),f( 7,20) / -1.15257674d+02 , -1.15251316d+02 /
      data f( 7,21),f( 7,22) / -1.15241282d+02 , -1.15241352d+02 /
      data f( 7,23),f( 7,24) / -1.15260623d+02 , -1.15277821d+02 /
      data f( 7,25),f( 7,26) / -1.15282902d+02 , -1.15284724d+02 /
      data f( 7,27),f( 7,28) / -1.15279967d+02 , -1.15270979d+02 /
      data f( 7,29),f( 7,30) / -1.15268093d+02 , -1.15271404d+02 /
      data f( 7,31),f( 7,32) / -1.15277297d+02 , -1.15283615d+02 /
      data f( 7,33),f( 7,34) / -1.15289068d+02 , -1.15292488d+02 /
      data f( 7,35),f( 7,36) / -1.15292589d+02 , -1.15288213d+02 /
      data f( 7,37),f( 7,38) / -1.15279083d+02 , -1.15267423d+02 /
      data f( 7,39),f( 7,40) / -1.15267371d+02 , -1.15279106d+02 /
      data f( 7,41),f( 7,42) / -1.15288453d+02 , -1.15293225d+02 /
      data f( 8, 1),f( 8, 2) / -1.15284152d+02 , -1.15281648d+02 /
      data f( 8, 3),f( 8, 4) / -1.15277309d+02 , -1.15272779d+02 /
      data f( 8, 5),f( 8, 6) / -1.15272749d+02 , -1.15277303d+02 /
      data f( 8, 7),f( 8, 8) / -1.15281748d+02 , -1.15284457d+02 /
      data f( 8, 9),f( 8,10) / -1.15285140d+02 , -1.15284254d+02 /
      data f( 8,11),f( 8,12) / -1.15282455d+02 , -1.15280300d+02 /
      data f( 8,13),f( 8,14) / -1.15278126d+02 , -1.15276080d+02 /
      data f( 8,15),f( 8,16) / -1.15274212d+02 , -1.15272570d+02 /
      data f( 8,17),f( 8,18) / -1.15271161d+02 , -1.15269779d+02 /
      data f( 8,19),f( 8,20) / -1.15267771d+02 , -1.15264237d+02 /
      data f( 8,21),f( 8,22) / -1.15259606d+02 , -1.15259181d+02 /
      data f( 8,23),f( 8,24) / -1.15267898d+02 , -1.15279200d+02 /
      data f( 8,25),f( 8,26) / -1.15286085d+02 , -1.15285804d+02 /
      data f( 8,27),f( 8,28) / -1.15280351d+02 , -1.15275166d+02 /
      data f( 8,29),f( 8,30) / -1.15273690d+02 , -1.15275114d+02 /
      data f( 8,31),f( 8,32) / -1.15277792d+02 , -1.15280686d+02 /
      data f( 8,33),f( 8,34) / -1.15283131d+02 , -1.15284503d+02 /
      data f( 8,35),f( 8,36) / -1.15284152d+02 , -1.15281648d+02 /
      data f( 8,37),f( 8,38) / -1.15277309d+02 , -1.15272779d+02 /
      data f( 8,39),f( 8,40) / -1.15272749d+02 , -1.15277303d+02 /
      data f( 8,41),f( 8,42) / -1.15281748d+02 , -1.15284457d+02 /
      data f( 9, 1),f( 9, 2) / -1.15280909d+02 , -1.15279732d+02 /
      data f( 9, 3),f( 9, 4) / -1.15277866d+02 , -1.15276065d+02 /
      data f( 9, 5),f( 9, 6) / -1.15276051d+02 , -1.15277863d+02 /
      data f( 9, 7),f( 9, 8) / -1.15279778d+02 , -1.15281051d+02 /
      data f( 9, 9),f( 9,10) / -1.15281452d+02 , -1.15281132d+02 /
      data f( 9,11),f( 9,12) / -1.15280379d+02 , -1.15279454d+02 /
      data f( 9,13),f( 9,14) / -1.15278523d+02 , -1.15277658d+02 /
      data f( 9,15),f( 9,16) / -1.15276866d+02 , -1.15276135d+02 /
      data f( 9,17),f( 9,18) / -1.15275441d+02 , -1.15274683d+02 /
      data f( 9,19),f( 9,20) / -1.15273601d+02 , -1.15271901d+02 /
      data f( 9,21),f( 9,22) / -1.15269837d+02 , -1.15269480d+02 /
      data f( 9,23),f( 9,24) / -1.15273187d+02 , -1.15278507d+02 /
      data f( 9,25),f( 9,26) / -1.15282219d+02 , -1.15282229d+02 /
      data f( 9,27),f( 9,28) / -1.15279651d+02 , -1.15277269d+02 /
      data f( 9,29),f( 9,30) / -1.15276531d+02 , -1.15277096d+02 /
      data f( 9,31),f( 9,32) / -1.15278257d+02 , -1.15279529d+02 /
      data f( 9,33),f( 9,34) / -1.15280595d+02 , -1.15281152d+02 /
      data f( 9,35),f( 9,36) / -1.15280909d+02 , -1.15279732d+02 /
      data f( 9,37),f( 9,38) / -1.15277866d+02 , -1.15276065d+02 /
      data f( 9,39),f( 9,40) / -1.15276051d+02 , -1.15277863d+02 /
      data f( 9,41),f( 9,42) / -1.15279778d+02 , -1.15281051d+02 /
      data f(10, 1),f(10, 2) / -1.15279615d+02 , -1.15279109d+02 /
      data f(10, 3),f(10, 4) / -1.15278332d+02 , -1.15277604d+02 /
      data f(10, 5),f(10, 6) / -1.15277599d+02 , -1.15278334d+02 /
      data f(10, 7),f(10, 8) / -1.15279134d+02 , -1.15279685d+02 /
      data f(10, 9),f(10,10) / -1.15279870d+02 , -1.15279743d+02 /
      data f(10,11),f(10,12) / -1.15279430d+02 , -1.15279047d+02 /
      data f(10,13),f(10,14) / -1.15278670d+02 , -1.15278334d+02 /
      data f(10,15),f(10,16) / -1.15278029d+02 , -1.15277776d+02 /
      data f(10,17),f(10,18) / -1.15277493d+02 , -1.15277138d+02 /
      data f(10,19),f(10,20) / -1.15276631d+02 , -1.15275897d+02 /
      data f(10,21),f(10,22) / -1.15275040d+02 , -1.15274815d+02 /
      data f(10,23),f(10,24) / -1.15276309d+02 , -1.15278549d+02 /
      data f(10,25),f(10,26) / -1.15280229d+02 , -1.15280387d+02 /
      data f(10,27),f(10,28) / -1.15279361d+02 , -1.15278290d+02 /
      data f(10,29),f(10,30) / -1.15277869d+02 , -1.15278040d+02 /
      data f(10,31),f(10,32) / -1.15278502d+02 , -1.15279035d+02 /
      data f(10,33),f(10,34) / -1.15279491d+02 , -1.15279727d+02 /
      data f(10,35),f(10,36) / -1.15279615d+02 , -1.15279109d+02 /
      data f(10,37),f(10,38) / -1.15278332d+02 , -1.15277604d+02 /
      data f(10,39),f(10,40) / -1.15277599d+02 , -1.15278334d+02 /
      data f(10,41),f(10,42) / -1.15279134d+02 , -1.15279685d+02 /
      data f(11, 1),f(11, 2) / -1.15278789d+02 , -1.15278710d+02 /
      data f(11, 3),f(11, 4) / -1.15278583d+02 , -1.15278463d+02 /
      data f(11, 5),f(11, 6) / -1.15278463d+02 , -1.15278586d+02 /
      data f(11, 7),f(11, 8) / -1.15278720d+02 , -1.15278811d+02 /
      data f(11, 9),f(11,10) / -1.15278838d+02 , -1.15278808d+02 /
      data f(11,11),f(11,12) / -1.15278748d+02 , -1.15278683d+02 /
      data f(11,13),f(11,14) / -1.15278633d+02 , -1.15278609d+02 /
      data f(11,15),f(11,16) / -1.15278613d+02 , -1.15278633d+02 /
      data f(11,17),f(11,18) / -1.15278644d+02 , -1.15278624d+02 /
      data f(11,19),f(11,20) / -1.15278574d+02 , -1.15278498d+02 /
      data f(11,21),f(11,22) / -1.15278388d+02 , -1.15278322d+02 /
      data f(11,23),f(11,24) / -1.15278544d+02 , -1.15278907d+02 /
      data f(11,25),f(11,26) / -1.15279216d+02 , -1.15279272d+02 /
      data f(11,27),f(11,28) / -1.15279070d+02 , -1.15278795d+02 /
      data f(11,29),f(11,30) / -1.15278615d+02 , -1.15278559d+02 /
      data f(11,31),f(11,32) / -1.15278589d+02 , -1.15278663d+02 /
      data f(11,33),f(11,34) / -1.15278745d+02 , -1.15278797d+02 /
      data f(11,35),f(11,36) / -1.15278789d+02 , -1.15278710d+02 /
      data f(11,37),f(11,38) / -1.15278583d+02 , -1.15278463d+02 /
      data f(11,39),f(11,40) / -1.15278463d+02 , -1.15278586d+02 /
      data f(11,41),f(11,42) / -1.15278720d+02 , -1.15278811d+02 /
      data f(12, 1),f(12, 2) / -1.15278562d+02 , -1.15278554d+02 /
      data f(12, 3),f(12, 4) / -1.15278537d+02 , -1.15278519d+02 /
      data f(12, 5),f(12, 6) / -1.15278519d+02 , -1.15278537d+02 /
      data f(12, 7),f(12, 8) / -1.15278557d+02 , -1.15278569d+02 /
      data f(12, 9),f(12,10) / -1.15278570d+02 , -1.15278563d+02 /
      data f(12,11),f(12,12) / -1.15278552d+02 , -1.15278543d+02 /
      data f(12,13),f(12,14) / -1.15278541d+02 , -1.15278536d+02 /
      data f(12,15),f(12,16) / -1.15278575d+02 , -1.15278610d+02 /
      data f(12,17),f(12,18) / -1.15278644d+02 , -1.15278671d+02 /
      data f(12,19),f(12,20) / -1.15278690d+02 , -1.15278706d+02 /
      data f(12,21),f(12,22) / -1.15278713d+02 , -1.15278700d+02 /
      data f(12,23),f(12,24) / -1.15278733d+02 , -1.15278802d+02 /
      data f(12,25),f(12,26) / -1.15278861d+02 , -1.15278856d+02 /
      data f(12,27),f(12,28) / -1.15278785d+02 , -1.15278688d+02 /
      data f(12,29),f(12,30) / -1.15278604d+02 , -1.15278533d+02 /
      data f(12,31),f(12,32) / -1.15278524d+02 , -1.15278526d+02 /
      data f(12,33),f(12,34) / -1.15278541d+02 , -1.15278557d+02 /
      data f(12,35),f(12,36) / -1.15278562d+02 , -1.15278554d+02 /
      data f(12,37),f(12,38) / -1.15278537d+02 , -1.15278519d+02 /
      data f(12,39),f(12,40) / -1.15278519d+02 , -1.15278537d+02 /
      data f(12,41),f(12,42) / -1.15278557d+02 , -1.15278569d+02 /
      data f(13, 1),f(13, 2) / -1.15278435d+02 , -1.15278437d+02 /
      data f(13, 3),f(13, 4) / -1.15278423d+02 , -1.15278423d+02 /
      data f(13, 5),f(13, 6) / -1.15278423d+02 , -1.15278423d+02 /
      data f(13, 7),f(13, 8) / -1.15278437d+02 , -1.15278437d+02 /
      data f(13, 9),f(13,10) / -1.15278436d+02 , -1.15278436d+02 /
      data f(13,11),f(13,12) / -1.15278438d+02 , -1.15278427d+02 /
      data f(13,13),f(13,14) / -1.15278432d+02 , -1.15278438d+02 /
      data f(13,15),f(13,16) / -1.15278443d+02 , -1.15278449d+02 /
      data f(13,17),f(13,18) / -1.15278471d+02 , -1.15278480d+02 /
      data f(13,19),f(13,20) / -1.15278488d+02 , -1.15278495d+02 /
      data f(13,21),f(13,22) / -1.15278483d+02 , -1.15278484d+02 /
      data f(13,23),f(13,24) / -1.15278504d+02 , -1.15278510d+02 /
      data f(13,25),f(13,26) / -1.15278510d+02 , -1.15278500d+02 /
      data f(13,27),f(13,28) / -1.15278483d+02 , -1.15278466d+02 /
      data f(13,29),f(13,30) / -1.15278437d+02 , -1.15278426d+02 /
      data f(13,31),f(13,32) / -1.15278420d+02 , -1.15278417d+02 /
      data f(13,33),f(13,34) / -1.15278432d+02 , -1.15278434d+02 /
      data f(13,35),f(13,36) / -1.15278435d+02 , -1.15278437d+02 /
      data f(13,37),f(13,38) / -1.15278423d+02 , -1.15278423d+02 /
      data f(13,39),f(13,40) / -1.15278423d+02 , -1.15278423d+02 /
      data f(13,41),f(13,42) / -1.15278437d+02 , -1.15278437d+02 /
      data f(14, 1),f(14, 2) / -1.15278392d+02 , -1.15278393d+02 /
      data f(14, 3),f(14, 4) / -1.15278394d+02 , -1.15278394d+02 /
      data f(14, 5),f(14, 6) / -1.15278394d+02 , -1.15278394d+02 /
      data f(14, 7),f(14, 8) / -1.15278393d+02 , -1.15278393d+02 /
      data f(14, 9),f(14,10) / -1.15278393d+02 , -1.15278393d+02 /
      data f(14,11),f(14,12) / -1.15278394d+02 , -1.15278395d+02 /
      data f(14,13),f(14,14) / -1.15278396d+02 , -1.15278398d+02 /
      data f(14,15),f(14,16) / -1.15278400d+02 , -1.15278402d+02 /
      data f(14,17),f(14,18) / -1.15278404d+02 , -1.15278407d+02 /
      data f(14,19),f(14,20) / -1.15278411d+02 , -1.15278414d+02 /
      data f(14,21),f(14,22) / -1.15278416d+02 , -1.15278416d+02 /
      data f(14,23),f(14,24) / -1.15278416d+02 , -1.15278415d+02 /
      data f(14,25),f(14,26) / -1.15278414d+02 , -1.15278411d+02 /
      data f(14,27),f(14,28) / -1.15278406d+02 , -1.15278402d+02 /
      data f(14,29),f(14,30) / -1.15278398d+02 , -1.15278395d+02 /
      data f(14,31),f(14,32) / -1.15278393d+02 , -1.15278392d+02 /
      data f(14,33),f(14,34) / -1.15278392d+02 , -1.15278392d+02 /
      data f(14,35),f(14,36) / -1.15278392d+02 , -1.15278393d+02 /
      data f(14,37),f(14,38) / -1.15278394d+02 , -1.15278394d+02 /
      data f(14,39),f(14,40) / -1.15278394d+02 , -1.15278394d+02 /
      data f(14,41),f(14,42) / -1.15278393d+02 , -1.15278393d+02 /
      data f(15, 1),f(15, 2) / -1.15278382d+02 , -1.15278382d+02 /
      data f(15, 3),f(15, 4) / -1.15278382d+02 , -1.15278382d+02 /
      data f(15, 5),f(15, 6) / -1.15278382d+02 , -1.15278382d+02 /
      data f(15, 7),f(15, 8) / -1.15278382d+02 , -1.15278382d+02 /
      data f(15, 9),f(15,10) / -1.15278382d+02 , -1.15278382d+02 /
      data f(15,11),f(15,12) / -1.15278382d+02 , -1.15278382d+02 /
      data f(15,13),f(15,14) / -1.15278383d+02 , -1.15278383d+02 /
      data f(15,15),f(15,16) / -1.15278383d+02 , -1.15278384d+02 /
      data f(15,17),f(15,18) / -1.15278385d+02 , -1.15278385d+02 /
      data f(15,19),f(15,20) / -1.15278386d+02 , -1.15278387d+02 /
      data f(15,21),f(15,22) / -1.15278387d+02 , -1.15278387d+02 /
      data f(15,23),f(15,24) / -1.15278387d+02 , -1.15278387d+02 /
      data f(15,25),f(15,26) / -1.15278387d+02 , -1.15278387d+02 /
      data f(15,27),f(15,28) / -1.15278386d+02 , -1.15278385d+02 /
      data f(15,29),f(15,30) / -1.15278384d+02 , -1.15278383d+02 /
      data f(15,31),f(15,32) / -1.15278382d+02 , -1.15278382d+02 /
      data f(15,33),f(15,34) / -1.15278382d+02 , -1.15278382d+02 /
      data f(15,35),f(15,36) / -1.15278382d+02 , -1.15278382d+02 /
      data f(15,37),f(15,38) / -1.15278382d+02 , -1.15278382d+02 /
      data f(15,39),f(15,40) / -1.15278382d+02 , -1.15278382d+02 /
      data f(15,41),f(15,42) / -1.15278382d+02 , -1.15278382d+02 /
 
      data fpp( 1, 1,1),fpp( 1, 1,2)/-3.01243189d-02, 1.33751831d-04/
      data fpp( 1, 2,1),fpp( 1, 2,2)/ 6.84187024d-03, 7.94103381d-05/
      data fpp( 1, 3,1),fpp( 1, 3,2)/ 7.05957990d-02, 4.69908168d-05/
      data fpp( 1, 4,1),fpp( 1, 4,2)/ 1.18056085d-01,-6.21556051d-05/
      data fpp( 1, 5,1),fpp( 1, 5,2)/ 1.17905437d-01,-6.24380930d-05/
      data fpp( 1, 6,1),fpp( 1, 6,2)/ 7.03050541d-02, 4.14307683d-05/
      data fpp( 1, 7,1),fpp( 1, 7,2)/ 7.01165277d-03, 8.50610198d-05/
      data fpp( 1, 8,1),fpp( 1, 8,2)/-2.88143340d-02, 8.89591525d-05/
      data fpp( 1, 9,1),fpp( 1, 9,2)/-4.55396052d-02, 6.67803700d-05/
      data fpp( 1,10,1),fpp( 1,10,2)/-5.15880684d-02, 4.11433673d-05/
      data fpp( 1,11,1),fpp( 1,11,2)/-5.28309787d-02, 2.00341607d-05/
      data fpp( 1,12,1),fpp( 1,12,2)/-5.19870250d-02, 8.58998972d-06/
      data fpp( 1,13,1),fpp( 1,13,2)/-5.04575834d-02,-6.68811964d-06/
      data fpp( 1,14,1),fpp( 1,14,2)/-4.61124848d-02, 2.05564888d-05/
      data fpp( 1,15,1),fpp( 1,15,2)/-3.04983419d-02,-7.34078357d-05/
      data fpp( 1,16,1),fpp( 1,16,2)/ 3.36149749d-02, 3.21176854d-04/
      data fpp( 1,17,1),fpp( 1,17,2)/ 1.87621280d-01,-1.66315958d-03/
      data fpp( 1,18,1),fpp( 1,18,2)/-6.55306127d-01, 1.41551747d-03/
      data fpp( 1,19,1),fpp( 1,19,2)/ 5.16241347d-01,-1.09386290d-04/
      data fpp( 1,20,1),fpp( 1,20,2)/ 5.68866542d-01, 4.37811693d-04/
      data fpp( 1,21,1),fpp( 1,21,2)/ 7.15171835d-01,-9.69812481d-04/
      data fpp( 1,22,1),fpp( 1,22,2)/ 7.48683769d-01, 1.62235460d-03/
      data fpp( 1,23,1),fpp( 1,23,2)/ 5.25801448d-01,-7.98858461d-03/
      data fpp( 1,24,1),fpp( 1,24,2)/ 7.56938149d-01, 4.69809279d-02/
      data fpp( 1,25,1),fpp( 1,25,2)/ 4.02351046d+01,-7.52545908d-02/
      data fpp( 1,26,1),fpp( 1,26,2)/ 3.32328889d+00, 3.40533695d-02/
      data fpp( 1,27,1),fpp( 1,27,2)/ 2.83445434d-03, 6.73828475d-05/
      data fpp( 1,28,1),fpp( 1,28,2)/ 1.08603467d-01, 6.31275112d-04/
      data fpp( 1,29,1),fpp( 1,29,2)/-3.25906715d-02,-5.13363294d-04/
      data fpp( 1,30,1),fpp( 1,30,2)/-8.61719520d-02, 1.28182064d-04/
      data fpp( 1,31,1),fpp( 1,31,2)/-7.47436440d-02,-9.84962563d-07/
      data fpp( 1,32,1),fpp( 1,32,2)/-6.52818440d-02, 4.87257861d-05/
      data fpp( 1,33,1),fpp( 1,33,2)/-5.85613322d-02, 5.33598181d-05/
      data fpp( 1,34,1),fpp( 1,34,2)/-4.88276221d-02, 7.77769417d-05/
      data fpp( 1,35,1),fpp( 1,35,2)/-3.01243189d-02, 9.57504153d-05/
      data fpp( 1,36,1),fpp( 1,36,2)/ 6.84187024d-03, 8.95893971d-05/
      data fpp( 1,37,1),fpp( 1,37,2)/ 7.05957990d-02, 4.42759965d-05/
      data fpp( 1,38,1),fpp( 1,38,2)/ 1.18056085d-01,-6.14753829d-05/
      data fpp( 1,39,1),fpp( 1,39,2)/ 1.17905437d-01,-6.31213496d-05/
      data fpp( 1,40,1),fpp( 1,40,2)/ 7.03050541d-02, 4.41698634d-05/
      data fpp( 1,41,1),fpp( 1,41,2)/ 7.01165277d-03, 7.47878962d-05/
      data fpp( 1,42,1),fpp( 1,42,2)/-2.88143340d-02, 1.27312552d-04/
      data fpp( 2, 1,1),fpp( 2, 1,2)/-5.22588623d-02, 1.25180274d-04/
      data fpp( 2, 2,1),fpp( 2, 2,2)/-3.54562405d-02, 7.23294529d-05/
      data fpp( 2, 3,1),fpp( 2, 3,2)/-1.00159806d-03, 4.12979150d-05/
      data fpp( 2, 4,1),fpp( 2, 4,2)/ 4.96628292d-02,-6.61011127d-05/
      data fpp( 2, 5,1),fpp( 2, 5,2)/ 4.96816260d-02,-6.64451194d-05/
      data fpp( 2, 6,1),fpp( 2, 6,2)/-9.82608245d-04, 3.55519418d-05/
      data fpp( 2, 7,1),fpp( 2, 7,2)/-3.49558055d-02, 7.84553524d-05/
      data fpp( 2, 8,1),fpp( 2, 8,2)/-5.08463320d-02, 8.03826487d-05/
      data fpp( 2, 9,1),fpp( 2, 9,2)/-5.58482895d-02, 5.99260526d-05/
      data fpp( 2,10,1),fpp( 2,10,2)/-5.48138632d-02, 3.63671407d-05/
      data fpp( 2,11,1),fpp( 2,11,2)/-5.09480427d-02, 1.71153846d-05/
      data fpp( 2,12,1),fpp( 2,12,2)/-4.55609501d-02, 4.52132104d-06/
      data fpp( 2,13,1),fpp( 2,13,2)/-3.87673332d-02,-5.89666874d-06/
      data fpp( 2,14,1),fpp( 2,14,2)/-2.83600304d-02,-3.45264609d-06/
      data fpp( 2,15,1),fpp( 2,15,2)/-8.17581625d-03,-2.58267469d-05/
      data fpp( 2,16,1),fpp( 2,16,2)/ 4.44300503d-02, 4.36096338d-05/
      data fpp( 2,17,1),fpp( 2,17,2)/ 1.41119940d-01,-5.66301788d-04/
      data fpp( 2,18,1),fpp( 2,18,2)/-4.22317746d-01, 6.78735188d-05/
      data fpp( 2,19,1),fpp( 2,19,2)/ 2.65557306d-01, 4.41663713d-04/
      data fpp( 2,20,1),fpp( 2,20,2)/ 3.78041916d-01, 1.62457629d-04/
      data fpp( 2,21,1),fpp( 2,21,2)/ 5.14526329d-01,-3.27418229d-04/
      data fpp( 2,22,1),fpp( 2,22,2)/ 5.36927462d-01, 1.70893371d-04/
      data fpp( 2,23,1),fpp( 2,23,2)/ 4.02019604d-01,-6.96410771d-04/
      data fpp( 2,24,1),fpp( 2,24,2)/ 8.37068702d-01, 1.33175437d-02/
      data fpp( 2,25,1),fpp( 2,25,2)/ 2.50405583d+01,-2.24148781d-02/
      data fpp( 2,26,1),fpp( 2,26,2)/ 2.75304723d+00, 6.87444859d-03/
      data fpp( 2,27,1),fpp( 2,27,2)/ 9.42985913d-02, 3.10236172d-03/
      data fpp( 2,28,1),fpp( 2,28,2)/ 9.71705651d-02,-3.30123468d-04/
      data fpp( 2,29,1),fpp( 2,29,2)/-3.85365704d-03,-2.21849849d-04/
      data fpp( 2,30,1),fpp( 2,30,2)/-5.72210960d-02,-3.29713471d-06/
      data fpp( 2,31,1),fpp( 2,31,2)/-6.02877119d-02, 1.67343883d-05/
      data fpp( 2,32,1),fpp( 2,32,2)/-6.00138121d-02, 3.51435817d-05/
      data fpp( 2,33,1),fpp( 2,33,2)/-6.02273357d-02, 4.92892851d-05/
      data fpp( 2,34,1),fpp( 2,34,2)/-5.87122557d-02, 6.96672781d-05/
      data fpp( 2,35,1),fpp( 2,35,2)/-5.22588623d-02, 8.67916025d-05/
      data fpp( 2,36,1),fpp( 2,36,2)/-3.54562405d-02, 8.26123119d-05/
      data fpp( 2,37,1),fpp( 2,37,2)/-1.00159806d-03, 3.85551500d-05/
      data fpp( 2,38,1),fpp( 2,38,2)/ 4.96628292d-02,-6.54129118d-05/
      data fpp( 2,39,1),fpp( 2,39,2)/ 4.96816260d-02,-6.71383395d-05/
      data fpp( 2,40,1),fpp( 2,40,2)/-9.82608245d-04, 3.83348606d-05/
      data fpp( 2,41,1),fpp( 2,41,2)/-3.49558055d-02, 6.80168970d-05/
      data fpp( 2,42,1),fpp( 2,42,2)/-5.08463320d-02, 1.19353552d-04/
      data fpp( 3, 1,1),fpp( 3, 1,2)/-8.03852321d-02, 1.25007250d-04/
      data fpp( 3, 2,1),fpp( 3, 2,2)/-8.54419084d-02, 7.07805007d-05/
      data fpp( 3, 3,1),fpp( 3, 3,2)/-7.49894068d-02, 5.02407476d-05/
      data fpp( 3, 4,1),fpp( 3, 4,2)/ 1.71259787d-03,-8.82034910d-05/
      data fpp( 3, 5,1),fpp( 3, 5,2)/ 1.98305897d-03,-8.86439009d-05/
      data fpp( 3, 6,1),fpp( 3, 6,2)/-7.46996211d-02, 4.43223875d-05/
      data fpp( 3, 7,1),fpp( 3, 7,2)/-8.44634307d-02, 7.86403511d-05/
      data fpp( 3, 8,1),fpp( 3, 8,2)/-7.87203379d-02, 7.61162082d-05/
      data fpp( 3, 9,1),fpp( 3, 9,2)/-7.00222367d-02, 5.52848163d-05/
      data fpp( 3,10,1),fpp( 3,10,2)/-6.05964787d-02, 3.26485268d-05/
      data fpp( 3,11,1),fpp( 3,11,2)/-5.04868507d-02, 1.44790766d-05/
      data fpp( 3,12,1),fpp( 3,12,2)/-3.97591748d-02, 1.78116666d-06/
      data fpp( 3,13,1),fpp( 3,13,2)/-2.63880838d-02,-7.11974329d-06/
      data fpp( 3,14,1),fpp( 3,14,2)/-7.36739372d-03,-1.15641935d-05/
      data fpp( 3,15,1),fpp( 3,15,2)/ 2.13666069d-02,-1.57854827d-05/
      data fpp( 3,16,1),fpp( 3,16,2)/ 6.55648241d-02,-2.22358756d-05/
      data fpp( 3,17,1),fpp( 3,17,2)/ 8.20039591d-02,-1.83403015d-04/
      data fpp( 3,18,1),fpp( 3,18,2)/-1.52442888d-01,-1.90988064d-04/
      data fpp( 3,19,1),fpp( 3,19,2)/-3.29056960d-03, 3.12873273d-04/
      data fpp( 3,20,1),fpp( 3,20,2)/ 2.74805794d-01, 2.01066973d-04/
      data fpp( 3,21,1),fpp( 3,21,2)/ 5.73192847d-01,-1.77049165d-04/
      data fpp( 3,22,1),fpp( 3,22,2)/ 4.38406383d-01,-1.60766993d-04/
      data fpp( 3,23,1),fpp( 3,23,2)/ 2.83085137d-01, 4.96208285d-04/
      data fpp( 3,24,1),fpp( 3,24,2)/ 1.11352704d+00, 4.42042185d-03/
      data fpp( 3,25,1),fpp( 3,25,2)/ 4.15896703d+00,-7.92634370d-03/
      data fpp( 3,26,1),fpp( 3,26,2)/ 2.40971221d+00, 1.47450695d-03/
      data fpp( 3,27,1),fpp( 3,27,2)/ 2.35016180d-01, 2.04498988d-03/
      data fpp( 3,28,1),fpp( 3,28,2)/ 8.76992722d-02,-2.61064485d-04/
      data fpp( 3,29,1),fpp( 3,29,2)/ 3.68452997d-02,-1.86249944d-04/
      data fpp( 3,30,1),fpp( 3,30,2)/-2.38536641d-02,-3.42217382d-05/
      data fpp( 3,31,1),fpp( 3,31,2)/-4.59355082d-02, 1.00808970d-05/
      data fpp( 3,32,1),fpp( 3,32,2)/-5.64179077d-02, 2.76961500d-05/
      data fpp( 3,33,1),fpp( 3,33,2)/-6.45493251d-02, 4.41165028d-05/
      data fpp( 3,34,1),fpp( 3,34,2)/-7.27683551d-02, 6.37678389d-05/
      data fpp( 3,35,1),fpp( 3,35,2)/-8.03852321d-02, 8.18241418d-05/
      data fpp( 3,36,1),fpp( 3,36,2)/-8.54419084d-02, 8.23475940d-05/
      data fpp( 3,37,1),fpp( 3,37,2)/-7.49894068d-02, 4.71554821d-05/
      data fpp( 3,38,1),fpp( 3,38,2)/ 1.71259787d-03,-8.74295226d-05/
      data fpp( 3,39,1),fpp( 3,39,2)/ 1.98305897d-03,-8.94231733d-05/
      data fpp( 3,40,1),fpp( 3,40,2)/-7.46996211d-02, 4.74500851d-05/
      data fpp( 3,41,1),fpp( 3,41,2)/-8.44634307d-02, 6.69088328d-05/
      data fpp( 3,42,1),fpp( 3,42,2)/-7.87203379d-02, 1.19914584d-04/
      data fpp( 4, 1,1),fpp( 4, 1,2)/-8.75402094d-02, 1.14034899d-04/
      data fpp( 4, 2,1),fpp( 4, 2,2)/-1.08521126d-01, 6.88742024d-05/
      data fpp( 4, 3,1),fpp( 4, 3,2)/-1.40610775d-01, 9.88442917d-05/
      data fpp( 4, 4,1),fpp( 4, 4,2)/-1.17788221d-01,-1.34143369d-04/
      data fpp( 4, 5,1),fpp( 4, 5,2)/-1.17553862d-01,-1.35086038d-04/
      data fpp( 4, 6,1),fpp( 4, 6,2)/-1.39913907d-01, 9.40589672d-05/
      data fpp( 4, 7,1),fpp( 4, 7,2)/-1.07580472d-01, 7.48281694d-05/
      data fpp( 4, 8,1),fpp( 4, 8,2)/-8.61473162d-02, 7.45563551d-05/
      data fpp( 4, 9,1),fpp( 4, 9,2)/-7.06677636d-02, 5.05164102d-05/
      data fpp( 4,10,1),fpp( 4,10,2)/-5.74302218d-02, 2.94140043d-05/
      data fpp( 4,11,1),fpp( 4,11,2)/-4.50495545d-02, 1.19175727d-05/
      data fpp( 4,12,1),fpp( 4,12,2)/-3.17723508d-02, 2.13704754d-07/
      data fpp( 4,13,1),fpp( 4,13,2)/-1.64203317d-02,-7.48639176d-06/
      data fpp( 4,14,1),fpp( 4,14,2)/ 2.28460524d-03,-1.24481377d-05/
      data fpp( 4,15,1),fpp( 4,15,2)/ 2.56393887d-02,-1.41990574d-05/
      data fpp( 4,16,1),fpp( 4,16,2)/ 5.05806533d-02,-2.31436328d-05/
      data fpp( 4,17,1),fpp( 4,17,2)/ 6.70392234d-02,-8.19744114d-05/
      data fpp( 4,18,1),fpp( 4,18,2)/-1.16707002d-02,-9.24427217d-05/
      data fpp( 4,19,1),fpp( 4,19,2)/-2.08565027d-01, 1.02935298d-04/
      data fpp( 4,20,1),fpp( 4,20,2)/-1.34990094d-01, 2.91201529d-04/
      data fpp( 4,21,1),fpp( 4,21,2)/-2.75732717d-01,-1.95295414d-04/
      data fpp( 4,22,1),fpp( 4,22,2)/-5.64379956d-02,-2.79947024d-04/
      data fpp( 4,23,1),fpp( 4,23,2)/ 1.47184848d-01, 5.89637969d-04/
      data fpp( 4,24,1),fpp( 4,24,2)/ 7.02838124d-01, 1.65359315d-03/
      data fpp( 4,25,1),fpp( 4,25,2)/ 3.18203354d+00,-3.03900256d-03/
      data fpp( 4,26,1),fpp( 4,26,2)/ 1.27220395d+00, 3.25523092d-04/
      data fpp( 4,27,1),fpp( 4,27,2)/ 2.03346687d-01, 1.09216819d-03/
      data fpp( 4,28,1),fpp( 4,28,2)/ 7.13623463d-02,-1.77959861d-04/
      data fpp( 4,29,1),fpp( 4,29,2)/ 3.56774584d-02,-1.60080748d-04/
      data fpp( 4,30,1),fpp( 4,30,2)/-5.94424764d-03,-4.05331465d-05/
      data fpp( 4,31,1),fpp( 4,31,2)/-3.12202553d-02, 2.85133393d-06/
      data fpp( 4,32,1),fpp( 4,32,2)/-4.69695569d-02, 2.16458107d-05/
      data fpp( 4,33,1),fpp( 4,33,2)/-5.95753639d-02, 3.87554232d-05/
      data fpp( 4,34,1),fpp( 4,34,2)/-7.22243240d-02, 5.77584967d-05/
      data fpp( 4,35,1),fpp( 4,35,2)/-8.75402094d-02, 7.93565902d-05/
      data fpp( 4,36,1),fpp( 4,36,2)/-1.08521126d-01, 7.81631426d-05/
      data fpp( 4,37,1),fpp( 4,37,2)/-1.40610775d-01, 9.63668394d-05/
      data fpp( 4,38,1),fpp( 4,38,2)/-1.17788221d-01,-1.33522500d-04/
      data fpp( 4,39,1),fpp( 4,39,2)/-1.17553862d-01,-1.35709919d-04/
      data fpp( 4,40,1),fpp( 4,40,2)/-1.39913907d-01, 9.65605168d-05/
      data fpp( 4,41,1),fpp( 4,41,2)/-1.07580472d-01, 6.54458524d-05/
      data fpp( 4,42,1),fpp( 4,42,2)/-8.61473162d-02, 1.09584074d-04/
      data fpp( 5, 1,1),fpp( 5, 1,2)/-8.33389302d-02, 8.88790312d-05/
      data fpp( 5, 2,1),fpp( 5, 2,2)/-1.10428587d-01, 6.17439376d-05/
      data fpp( 5, 3,1),fpp( 5, 3,2)/-1.70557494d-01, 1.57741218d-04/
      data fpp( 5, 4,1),fpp( 5, 4,2)/-4.19564715d-01,-1.77224811d-04/
      data fpp( 5, 5,1),fpp( 5, 5,2)/-4.19032611d-01,-1.78873176d-04/
      data fpp( 5, 6,1),fpp( 5, 6,2)/-1.69899750d-01, 1.55004676d-04/
      data fpp( 5, 7,1),fpp( 5, 7,2)/-1.09664682d-01, 6.22424711d-05/
      data fpp( 5, 8,1),fpp( 5, 8,2)/-8.26253971d-02, 7.23654396d-05/
      data fpp( 5, 9,1),fpp( 5, 9,2)/-6.53867089d-02, 4.47817705d-05/
      data fpp( 5,10,1),fpp( 5,10,2)/-5.15626340d-02, 2.60134783d-05/
      data fpp( 5,11,1),fpp( 5,11,2)/-3.82949315d-02, 9.66631627d-06/
      data fpp( 5,12,1),fpp( 5,12,2)/-2.43564220d-02,-4.78743366d-07/
      data fpp( 5,13,1),fpp( 5,13,2)/-9.00058951d-03,-6.71934280d-06/
      data fpp( 5,14,1),fpp( 5,14,2)/ 7.66397278d-03,-1.05938854d-05/
      data fpp( 5,15,1),fpp( 5,15,2)/ 2.58208383d-02,-1.27771155d-05/
      data fpp( 5,16,1),fpp( 5,16,2)/ 4.59875628d-02,-1.66036524d-05/
      data fpp( 5,17,1),fpp( 5,17,2)/ 5.22141475d-02,-4.04242747d-05/
      data fpp( 5,18,1),fpp( 5,18,2)/ 1.24206893d-02,-3.28632488d-05/
      data fpp( 5,19,1),fpp( 5,19,2)/-6.79243216d-02, 5.68632699d-05/
      data fpp( 5,20,1),fpp( 5,20,2)/-1.75995420d-01, 2.38076169d-04/
      data fpp( 5,21,1),fpp( 5,21,2)/-3.29806977d-01,-1.57455947d-04/
      data fpp( 5,22,1),fpp( 5,22,2)/-3.31199401d-01,-3.37975245d-04/
      data fpp( 5,23,1),fpp( 5,23,2)/ 1.32204714d-02, 4.57221361d-04/
      data fpp( 5,24,1),fpp( 5,24,2)/ 4.27175462d-01, 7.14365799d-04/
      data fpp( 5,25,1),fpp( 5,25,2)/ 1.08303383d+00,-1.17579256d-03/
      data fpp( 5,26,1),fpp( 5,26,2)/ 7.32167005d-01, 1.02454433d-04/
      data fpp( 5,27,1),fpp( 5,27,2)/ 1.54657071d-01, 5.44538827d-04/
      data fpp( 5,28,1),fpp( 5,28,2)/ 5.30613427d-02,-1.41225740d-04/
      data fpp( 5,29,1),fpp( 5,29,2)/ 3.22448667d-02,-1.28645866d-04/
      data fpp( 5,30,1),fpp( 5,30,2)/ 3.75565466d-03,-3.80427955d-05/
      data fpp( 5,31,1),fpp( 5,31,2)/-1.97434704d-02,-1.25495192d-06/
      data fpp( 5,32,1),fpp( 5,32,2)/-3.72088645d-02, 1.65966032d-05/
      data fpp( 5,33,1),fpp( 5,33,2)/-5.17042194d-02, 3.34245392d-05/
      data fpp( 5,34,1),fpp( 5,34,2)/-6.60893489d-02, 5.05672399d-05/
      data fpp( 5,35,1),fpp( 5,35,2)/-8.33389302d-02, 7.64145010d-05/
      data fpp( 5,36,1),fpp( 5,36,2)/-1.10428587d-01, 6.50827559d-05/
      data fpp( 5,37,1),fpp( 5,37,2)/-1.70557494d-01, 1.56850475d-04/
      data fpp( 5,38,1),fpp( 5,38,2)/-4.19564715d-01,-1.77000657d-04/
      data fpp( 5,39,1),fpp( 5,39,2)/-4.19032611d-01,-1.79100267d-04/
      data fpp( 5,40,1),fpp( 5,40,2)/-1.69899750d-01, 1.55918918d-04/
      data fpp( 5,41,1),fpp( 5,41,2)/-1.09664682d-01, 5.88125948d-05/
      data fpp( 5,42,1),fpp( 5,42,2)/-8.26253971d-02, 8.51707026d-05/
      data fpp( 6, 1,1),fpp( 6, 1,2)/-7.09390696d-02, 8.42597363d-05/
      data fpp( 6, 2,1),fpp( 6, 2,2)/-9.21245244d-02, 5.51925273d-05/
      data fpp( 6, 3,1),fpp( 6, 3,2)/-1.30154248d-01, 1.29742154d-04/
      data fpp( 6, 4,1),fpp( 6, 4,2)/-1.80247918d-01,-1.58367145d-04/
      data fpp( 6, 5,1),fpp( 6, 5,2)/-1.81065692d-01,-1.60215143d-04/
      data fpp( 6, 6,1),fpp( 6, 6,2)/-1.30422092d-01, 1.27018148d-04/
      data fpp( 6, 7,1),fpp( 6, 7,2)/-9.22057993d-02, 5.76105527d-05/
      data fpp( 6, 8,1),fpp( 6, 8,2)/-7.10310955d-02, 6.30016415d-05/
      data fpp( 6, 9,1),fpp( 6, 9,2)/-5.62704007d-02, 3.91568814d-05/
      data fpp( 6,10,1),fpp( 6,10,2)/-4.35792421d-02, 2.21588328d-05/
      data fpp( 6,11,1),fpp( 6,11,2)/-3.10607197d-02, 7.81978722d-06/
      data fpp( 6,12,1),fpp( 6,12,2)/-1.78019612d-02,-6.07981724d-07/
      data fpp( 6,13,1),fpp( 6,13,2)/-4.17231028d-03,-5.36386032d-06/
      data fpp( 6,14,1),fpp( 6,14,2)/ 9.56950366d-03,-8.17657698d-06/
      data fpp( 6,15,1),fpp( 6,15,2)/ 2.28472581d-02,-1.01338318d-05/
      data fpp( 6,16,1),fpp( 6,16,2)/ 3.49740957d-02,-1.21220960d-05/
      data fpp( 6,17,1),fpp( 6,17,2)/ 4.18641868d-02,-1.96537843d-05/
      data fpp( 6,18,1),fpp( 6,18,2)/ 2.68479431d-02,-8.56876676d-06/
      data fpp( 6,19,1),fpp( 6,19,2)/-1.66876863d-02, 4.91468513d-05/
      data fpp( 6,20,1),fpp( 6,20,2)/-4.30432274d-02, 1.37511361d-04/
      data fpp( 6,21,1),fpp( 6,21,2)/ 1.17556260d-02,-9.46642969d-05/
      data fpp( 6,22,1),fpp( 6,22,2)/-2.80444007d-02,-2.89509790d-04/
      data fpp( 6,23,1),fpp( 6,23,2)/-2.51217336d-02, 2.34843334d-04/
      data fpp( 6,24,1),fpp( 6,24,2)/ 2.20255027d-01, 3.77540455d-04/
      data fpp( 6,25,1),fpp( 6,25,2)/ 6.12306158d-01,-4.17097156d-04/
      data fpp( 6,26,1),fpp( 6,26,2)/ 3.80518031d-01, 7.91361669d-05/
      data fpp( 6,27,1),fpp( 6,27,2)/ 1.00480031d-01, 2.56882488d-04/
      data fpp( 6,28,1),fpp( 6,28,2)/ 3.61022829d-02,-1.21658119d-04/
      data fpp( 6,29,1),fpp( 6,29,2)/ 2.74480749d-02,-9.84620108d-05/
      data fpp( 6,30,1),fpp( 6,30,2)/ 8.21662901d-03,-3.22638375d-05/
      data fpp( 6,31,1),fpp( 6,31,2)/-1.12458629d-02,-2.83463918d-06/
      data fpp( 6,32,1),fpp( 6,32,2)/-2.79499850d-02, 1.27203942d-05/
      data fpp( 6,33,1),fpp( 6,33,2)/-4.22627584d-02, 2.78410622d-05/
      data fpp( 6,34,1),fpp( 6,34,2)/-5.58332803d-02, 4.36693569d-05/
      data fpp( 6,35,1),fpp( 6,35,2)/-7.09390696d-02, 6.62875101d-05/
      data fpp( 6,36,1),fpp( 6,36,2)/-9.21245244d-02, 6.00066026d-05/
      data fpp( 6,37,1),fpp( 6,37,2)/-1.30154248d-01, 1.28458079d-04/
      data fpp( 6,38,1),fpp( 6,38,2)/-1.80247918d-01,-1.58044920d-04/
      data fpp( 6,39,1),fpp( 6,39,2)/-1.81065692d-01,-1.60539780d-04/
      data fpp( 6,40,1),fpp( 6,40,2)/-1.30422092d-01, 1.28321518d-04/
      data fpp( 6,41,1),fpp( 6,41,2)/-9.22057993d-02, 5.27217093d-05/
      data fpp( 6,42,1),fpp( 6,42,2)/-7.10310955d-02, 8.12536454d-05/
      data fpp( 7, 1,1),fpp( 7, 1,2)/-4.63371478d-02, 7.34911258d-05/
      data fpp( 7, 2,1),fpp( 7, 2,2)/-5.15791937d-02, 4.01207483d-05/
      data fpp( 7, 3,1),fpp( 7, 3,2)/-4.67608427d-02, 5.12598808d-05/
      data fpp( 7, 4,1),fpp( 7, 4,2)/-3.01379508d-03,-9.33842716d-05/
      data fpp( 7, 5,1),fpp( 7, 5,2)/-3.15928408d-03,-9.44851255d-05/
      data fpp( 7, 6,1),fpp( 7, 6,2)/-4.72365250d-02, 4.80612964d-05/
      data fpp( 7, 7,1),fpp( 7, 7,2)/-5.21708808d-02, 4.54359400d-05/
      data fpp( 7, 8,1),fpp( 7, 8,2)/-4.71460837d-02, 4.47609435d-05/
      data fpp( 7, 9,1),fpp( 7, 9,2)/-3.94741918d-02, 2.99862859d-05/
      data fpp( 7,10,1),fpp( 7,10,2)/-3.05307704d-02, 1.63919129d-05/
      data fpp( 7,11,1),fpp( 7,11,2)/-2.06309799d-02, 5.73206268d-06/
      data fpp( 7,12,1),fpp( 7,12,2)/-1.02691813d-02,-5.06163569d-07/
      data fpp( 7,13,1),fpp( 7,13,2)/ 6.47606058d-05,-3.25740840d-06/
      data fpp( 7,14,1),fpp( 7,14,2)/ 9.40900595d-03,-4.90820281d-06/
      data fpp( 7,15,1),fpp( 7,15,2)/ 1.75119140d-02,-6.42578034d-06/
      data fpp( 7,16,1),fpp( 7,16,2)/ 2.44113060d-02,-7.34467582d-06/
      data fpp( 7,17,1),fpp( 7,17,2)/ 2.87532791d-02,-6.83751638d-06/
      data fpp( 7,18,1),fpp( 7,18,2)/ 2.67063969d-02, 4.09474133d-06/
      data fpp( 7,19,1),fpp( 7,19,2)/ 1.85585021d-02, 3.56445510d-05/
      data fpp( 7,20,1),fpp( 7,20,2)/ 1.67543711d-02, 5.87670545d-05/
      data fpp( 7,21,1),fpp( 7,21,2)/ 3.80292315d-02,-5.01707690d-05/
      data fpp( 7,22,1),fpp( 7,22,2)/ 3.15109362d-02,-1.80935220d-04/
      data fpp( 7,23,1),fpp( 7,23,2)/-4.13786901d-03, 3.17928600d-05/
      data fpp( 7,24,1),fpp( 7,24,2)/ 6.54429344d-02, 1.78149780d-04/
      data fpp( 7,25,1),fpp( 7,25,2)/ 1.68813589d-01,-1.73839809d-05/
      data fpp( 7,26,1),fpp( 7,26,2)/ 1.28641892d-01, 8.68901435d-05/
      data fpp( 7,27,1),fpp( 7,27,2)/ 3.57485174d-02, 6.46174071d-05/
      data fpp( 7,28,1),fpp( 7,28,2)/ 1.82581617d-02,-9.15237717d-05/
      data fpp( 7,29,1),fpp( 7,29,2)/ 1.77398392d-02,-6.46243203d-05/
      data fpp( 7,30,1),fpp( 7,30,2)/ 9.62413354d-03,-2.17989472d-05/
      data fpp( 7,31,1),fpp( 7,31,2)/-3.44814335d-03,-3.11189090d-06/
      data fpp( 7,32,1),fpp( 7,32,2)/-1.63908068d-02, 8.75251079d-06/
      data fpp( 7,33,1),fpp( 7,33,2)/-2.81179923d-02, 2.00378477d-05/
      data fpp( 7,34,1),fpp( 7,34,2)/-3.81461663d-02, 3.30100983d-05/
      data fpp( 7,35,1),fpp( 7,35,2)/-4.63371478d-02, 4.71037590d-05/
      data fpp( 7,36,1),fpp( 7,36,2)/-5.15791937d-02, 4.71888656d-05/
      data fpp( 7,37,1),fpp( 7,37,2)/-4.67608427d-02, 4.93747785d-05/
      data fpp( 7,38,1),fpp( 7,38,2)/-3.01379508d-03,-9.29119797d-05/
      data fpp( 7,39,1),fpp( 7,39,2)/-3.15928408d-03,-9.49594500d-05/
      data fpp( 7,40,1),fpp( 7,40,2)/-4.72365250d-02, 4.99626596d-05/
      data fpp( 7,41,1),fpp( 7,41,2)/-5.21708808d-02, 3.83048115d-05/
      data fpp( 7,42,1),fpp( 7,42,2)/-4.71460837d-02, 7.13840942d-05/
      data fpp( 8, 1,1),fpp( 8, 1,2)/-1.79192853d-02, 3.55746314d-05/
      data fpp( 8, 2,1),fpp( 8, 2,2)/-1.39958655d-02, 1.68017373d-05/
      data fpp( 8, 3,1),fpp( 8, 3,2)/-2.52315440d-03, 7.31241960d-06/
      data fpp( 8, 4,1),fpp( 8, 4,2)/ 1.14704953d-02,-3.46694157d-05/
      data fpp( 8, 5,1),fpp( 8, 5,2)/ 1.15283245d-02,-3.50649628d-05/
      data fpp( 8, 6,1),fpp( 8, 6,2)/-2.59466446d-03, 5.58860831d-06/
      data fpp( 8, 7,1),fpp( 8, 7,2)/-1.43401018d-02, 1.92325296d-05/
      data fpp( 8, 8,1),fpp( 8, 8,2)/-1.86378749d-02, 2.16172733d-05/
      data fpp( 8, 9,1),fpp( 8, 9,2)/-1.78291458d-02, 1.59063773d-05/
      data fpp( 8,10,1),fpp( 8,10,2)/-1.41635895d-02, 8.91521743d-06/
      data fpp( 8,11,1),fpp( 8,11,2)/-9.19723240d-03, 3.15275294d-06/
      data fpp( 8,12,1),fpp( 8,12,2)/-3.78384315d-03,-1.48229182d-07/
      data fpp( 8,13,1),fpp( 8,13,2)/ 1.48095223d-03,-1.43783621d-06/
      data fpp( 8,14,1),fpp( 8,14,2)/ 6.30387878d-03,-1.73842598d-06/
      data fpp( 8,15,1),fpp( 8,15,2)/ 1.02351202d-02,-2.30045988d-06/
      data fpp( 8,16,1),fpp( 8,16,2)/ 1.32097634d-02,-2.63173450d-06/
      data fpp( 8,17,1),fpp( 8,17,2)/ 1.52333949d-02,-1.11660213d-06/
      data fpp( 8,18,1),fpp( 8,18,2)/ 1.66043640d-02, 5.40614303d-06/
      data fpp( 8,19,1),fpp( 8,19,2)/ 1.82790050d-02, 1.71300300d-05/
      data fpp( 8,20,1),fpp( 8,20,2)/ 2.38343490d-02, 1.75857369d-05/
      data fpp( 8,21,1),fpp( 8,21,2)/ 3.42938837d-02,-2.16169776d-05/
      data fpp( 8,22,1),fpp( 8,22,2)/ 3.25524446d-02,-7.65239355d-05/
      data fpp( 8,23,1),fpp( 8,23,2)/ 1.07518210d-02,-3.33504316d-05/
      data fpp( 8,24,1),fpp( 8,24,2)/-3.02880631d-03, 5.48496621d-05/
      data fpp( 8,25,1),fpp( 8,25,2)/ 2.82962155d-03, 7.88877832d-05/
      data fpp( 8,26,1),fpp( 8,26,2)/-1.99367290d-03, 5.96612050d-05/
      data fpp( 8,27,1),fpp( 8,27,2)/-1.95687415d-03,-7.29660328d-06/
      data fpp( 8,28,1),fpp( 8,28,2)/ 6.88531272d-03,-4.65307919d-05/
      data fpp( 8,29,1),fpp( 8,29,2)/ 1.06820696d-02,-2.90842291d-05/
      data fpp( 8,30,1),fpp( 8,30,2)/ 6.95279526d-03,-1.11622916d-05/
      data fpp( 8,31,1),fpp( 8,31,2)/ 8.03176469d-04,-1.54860464d-06/
      data fpp( 8,32,1),fpp( 8,32,2)/-5.96822710d-03, 4.46271010d-06/
      data fpp( 8,33,1),fpp( 8,33,2)/-1.21039697d-02, 1.06137642d-05/
      data fpp( 8,34,1),fpp( 8,34,2)/-1.65754996d-02, 1.74622330d-05/
      data fpp( 8,35,1),fpp( 8,35,2)/-1.79192853d-02, 2.28933037d-05/
      data fpp( 8,36,1),fpp( 8,36,2)/-1.39958655d-02, 2.01985522d-05/
      data fpp( 8,37,1),fpp( 8,37,2)/-2.52315440d-03, 6.40648746d-06/
      data fpp( 8,38,1),fpp( 8,38,2)/ 1.14704953d-02,-3.44425021d-05/
      data fpp( 8,39,1),fpp( 8,39,2)/ 1.15283245d-02,-3.52927375d-05/
      data fpp( 8,40,1),fpp( 8,40,2)/-2.59466446d-03, 6.50142934d-06/
      data fpp( 8,41,1),fpp( 8,41,2)/-1.43401018d-02, 1.58090202d-05/
      data fpp( 8,42,1),fpp( 8,42,2)/-1.86378749d-02, 3.43984899d-05/
      data fpp( 9, 1,1),fpp( 9, 1,2)/-6.63211084d-03, 1.46178476d-05/
      data fpp( 9, 2,1),fpp( 9, 2,2)/-4.01094445d-03, 6.47230480d-06/
      data fpp( 9, 3,1),fpp( 9, 3,2)/ 8.87860278d-04, 7.84933190d-07/
      data fpp( 9, 4,1),fpp( 9, 4,2)/ 6.82141382d-03,-1.35060376d-05/
      data fpp( 9, 5,1),fpp( 9, 5,2)/ 6.85078592d-03,-1.36973539d-05/
      data fpp( 9, 6,1),fpp( 9, 6,2)/ 8.93582852d-04, 7.41986086d-08/
      data fpp( 9, 7,1),fpp( 9, 7,2)/-4.11831200d-03, 7.24455948d-06/
      data fpp( 9, 8,1),fpp( 9, 8,2)/-6.97121674d-03, 9.42556347d-06/
      data fpp( 9, 9,1),fpp( 9, 9,2)/-7.45962481d-03, 7.39718664d-06/
      data fpp( 9,10,1),fpp( 9,10,2)/-6.23007165d-03, 4.24568996d-06/
      data fpp( 9,11,1),fpp( 9,11,2)/-4.04649048d-03, 1.55805350d-06/
      data fpp( 9,12,1),fpp( 9,12,2)/-1.54264610d-03,-1.09903975d-07/
      data fpp( 9,13,1),fpp( 9,13,2)/ 1.00263047d-03,-7.76437607d-07/
      data fpp( 9,14,1),fpp( 9,14,2)/ 3.45147893d-03,-7.50345596d-07/
      data fpp( 9,15,1),fpp( 9,15,2)/ 5.78600499d-03,-5.96180010d-07/
      data fpp( 9,16,1),fpp( 9,16,2)/ 7.36884022d-03,-5.06934368d-07/
      data fpp( 9,17,1),fpp( 9,17,2)/ 8.49954143d-03, 3.43917479d-07/
      data fpp( 9,18,1),fpp( 9,18,2)/ 9.29854714d-03, 3.01926445d-06/
      data fpp( 9,19,1),fpp( 9,19,2)/ 1.07238777d-02, 7.01902473d-06/
      data fpp( 9,20,1),fpp( 9,20,2)/ 1.40786330d-02, 5.97863664d-06/
      data fpp( 9,21,1),fpp( 9,21,2)/ 1.90176336d-02,-9.06357127d-06/
      data fpp( 9,22,1),fpp( 9,22,2)/ 1.90256854d-02,-3.23861045d-05/
      data fpp( 9,23,1),fpp( 9,23,2)/ 8.80658505d-03,-2.06832304d-05/
      data fpp( 9,24,1),fpp( 9,24,2)/-3.60450911d-03, 1.83750262d-05/
      data fpp( 9,25,1),fpp( 9,25,2)/-1.09296748d-02, 4.36271258d-05/
      data fpp( 9,26,1),fpp( 9,26,2)/-8.98560030d-03, 2.92364707d-05/
      data fpp( 9,27,1),fpp( 9,27,2)/-1.90262083d-03,-5.25100865d-06/
      data fpp( 9,28,1),fpp( 9,28,2)/ 4.21178739d-03,-2.00404361d-05/
      data fpp( 9,29,1),fpp( 9,29,2)/ 5.65668227d-03,-1.31912469d-05/
      data fpp( 9,30,1),fpp( 9,30,2)/ 4.00788543d-03,-5.42257629d-06/
      data fpp( 9,31,1),fpp( 9,31,2)/ 9.65037475d-04,-8.30447922d-07/
      data fpp( 9,32,1),fpp( 9,32,2)/-2.28108476d-03, 2.04836798d-06/
      data fpp( 9,33,1),fpp( 9,33,2)/-5.07572894d-03, 5.05697599d-06/
      data fpp( 9,34,1),fpp( 9,34,2)/-6.76783530d-03, 8.21572806d-06/
      data fpp( 9,35,1),fpp( 9,35,2)/-6.63211084d-03, 1.00501118d-05/
      data fpp( 9,36,1),fpp( 9,36,2)/-4.01094445d-03, 7.69582491d-06/
      data fpp( 9,37,1),fpp( 9,37,2)/ 8.87860278d-04, 4.58588616d-07/
      data fpp( 9,38,1),fpp( 9,38,2)/ 6.82141382d-03,-1.34241794d-05/
      data fpp( 9,39,1),fpp( 9,39,2)/ 6.85078592d-03,-1.37797562d-05/
      data fpp( 9,40,1),fpp( 9,40,2)/ 8.93582852d-04, 4.04895898d-07/
      data fpp( 9,41,1),fpp( 9,41,2)/-4.11831200d-03, 6.00417260d-06/
      data fpp( 9,42,1),fpp( 9,42,2)/-6.97121674d-03, 1.40564137d-05/
      data fpp(10, 1,1),fpp(10, 1,2)/-2.32347130d-03, 5.95514833d-06/
      data fpp(10, 2,1),fpp(10, 2,2)/-9.94756738d-04, 2.56770334d-06/
      data fpp(10, 3,1),fpp(10, 3,2)/ 1.16291329d-03,-1.39616766d-08/
      data fpp(10, 4,1),fpp(10, 4,2)/ 3.16704941d-03,-5.41585663d-06/
      data fpp(10, 5,1),fpp(10, 5,2)/ 3.18613179d-03,-5.51794926d-06/
      data fpp(10, 6,1),fpp(10, 6,2)/ 1.17793305d-03,-3.07591145d-07/
      data fpp(10, 7,1),fpp(10, 7,2)/-1.02505022d-03, 2.82431384d-06/
      data fpp(10, 8,1),fpp(10, 8,2)/-2.45165816d-03, 3.98033577d-06/
      data fpp(10, 9,1),fpp(10, 9,2)/-2.88835491d-03, 3.22034310d-06/
      data fpp(10,10,1),fpp(10,10,2)/-2.52012392d-03, 1.83429185d-06/
      data fpp(10,11,1),fpp(10,11,2)/-1.66000570d-03, 6.20489488d-07/
      data fpp(10,12,1),fpp(10,12,2)/-5.83972442d-04,-9.82498090d-08/
      data fpp(10,13,1),fpp(10,13,2)/ 5.06125891d-04,-5.87490255d-07/
      data fpp(10,14,1),fpp(10,14,2)/ 1.53100548d-03,-7.77891714d-08/
      data fpp(10,15,1),fpp(10,15,2)/ 2.40725981d-03,-9.01353061d-07/
      data fpp(10,16,1),fpp(10,16,2)/ 3.47167568d-03, 5.33201411d-07/
      data fpp(10,17,1),fpp(10,17,2)/ 4.26683940d-03, 5.80547411d-07/
      data fpp(10,18,1),fpp(10,18,2)/ 4.99184745d-03, 1.48860894d-06/
      data fpp(10,19,1),fpp(10,19,2)/ 6.03988416d-03, 2.53701683d-06/
      data fpp(10,20,1),fpp(10,20,2)/ 7.90231920d-03, 2.03132372d-06/
      data fpp(10,21,1),fpp(10,21,2)/ 1.03075817d-02,-3.31831173d-06/
      data fpp(10,22,1),fpp(10,22,2)/ 1.04784139d-02,-1.33912267d-05/
      data fpp(10,23,1),fpp(10,23,2)/ 6.03703880d-03,-9.41501653d-06/
      data fpp(10,24,1),fpp(10,24,2)/-1.97957226d-04, 6.28529279d-06/
      data fpp(10,25,1),fpp(10,25,2)/-4.14212222d-03, 1.79098454d-05/
      data fpp(10,26,1),fpp(10,26,2)/-3.61512591d-03, 1.34193258d-05/
      data fpp(10,27,1),fpp(10,27,2)/-2.89442526d-04,-6.43148512d-07/
      data fpp(10,28,1),fpp(10,28,2)/ 2.24753772d-03,-8.05073174d-06/
      data fpp(10,29,1),fpp(10,29,2)/ 2.77040130d-03,-6.20192452d-06/
      data fpp(10,30,1),fpp(10,30,2)/ 1.95646303d-03,-2.66157019d-06/
      data fpp(10,31,1),fpp(10,31,2)/ 6.16673632d-04,-5.99794713d-07/
      data fpp(10,32,1),fpp(10,32,2)/-8.07433853d-04, 7.64749045d-07/
      data fpp(10,33,1),fpp(10,33,2)/-1.97791454d-03, 2.20279854d-06/
      data fpp(10,34,1),fpp(10,34,2)/-2.59155920d-03, 3.60605682d-06/
      data fpp(10,35,1),fpp(10,35,2)/-2.32347130d-03, 4.25897421d-06/
      data fpp(10,36,1),fpp(10,36,2)/-9.94756738d-04, 3.02204635d-06/
      data fpp(10,37,1),fpp(10,37,2)/ 1.16291329d-03,-1.35159622d-07/
      data fpp(10,38,1),fpp(10,38,2)/ 3.16704941d-03,-5.38540787d-06/
      data fpp(10,39,1),fpp(10,39,2)/ 3.18613179d-03,-5.54869658d-06/
      data fpp(10,40,1),fpp(10,40,2)/ 1.17793305d-03,-1.84004766d-07/
      data fpp(10,41,1),fpp(10,41,2)/-1.02505022d-03, 2.36071565d-06/
      data fpp(10,42,1),fpp(10,42,2)/-2.45165816d-03, 5.71114218d-06/
      data fpp(11, 1,1),fpp(11, 1,2)/-2.88530679d-04, 1.04630304d-06/
      data fpp(11, 2,1),fpp(11, 2,2)/-9.52575589d-05, 4.61393913d-07/
      data fpp(11, 3,1),fpp(11, 3,2)/ 1.56330001d-04, 1.21304971d-10/
      data fpp(11, 4,1),fpp(11, 4,2)/ 4.00344869d-04,-8.93879133d-07/
      data fpp(11, 5,1),fpp(11, 5,2)/ 4.03411667d-04,-9.18423255d-07/
      data fpp(11, 6,1),fpp(11, 6,2)/ 1.57609425d-04,-6.37022028d-08/
      data fpp(11, 7,1),fpp(11, 7,2)/-9.94933498d-05, 4.83232066d-07/
      data fpp(11, 8,1),fpp(11, 8,2)/-3.03217157d-04, 7.04773941d-07/
      data fpp(11, 9,1),fpp(11, 9,2)/-3.91122851d-04, 5.85672174d-07/
      data fpp(11,10,1),fpp(11,10,2)/-3.74192427d-04, 3.06537363d-07/
      data fpp(11,11,1),fpp(11,11,2)/-2.90937671d-04, 3.61783737d-08/
      data fpp(11,12,1),fpp(11,12,2)/-1.77959624d-04,-1.57250860d-07/
      data fpp(11,13,1),fpp(11,13,2)/-3.90929066d-05,-2.83174937d-07/
      data fpp(11,14,1),fpp(11,14,2)/ 1.48644082d-04,-3.06049395d-07/
      data fpp(11,15,1),fpp(11,15,2)/ 3.35418085d-04,-1.84627485d-07/
      data fpp(11,16,1),fpp(11,16,2)/ 4.54752857d-04, 9.05593308d-08/
      data fpp(11,17,1),fpp(11,17,2)/ 6.62911096d-04, 3.68390158d-07/
      data fpp(11,18,1),fpp(11,18,2)/ 9.09584083d-04, 3.13880033d-07/
      data fpp(11,19,1),fpp(11,19,2)/ 1.22160867d-03, 1.88089712d-07/
      data fpp(11,20,1),fpp(11,20,2)/ 1.59492593d-03, 4.81761120d-07/
      data fpp(11,21,1),fpp(11,21,2)/ 1.91943795d-03,-1.05134191d-07/
      data fpp(11,22,1),fpp(11,22,2)/ 2.02811561d-03,-2.22797799d-06/
      data fpp(11,23,1),fpp(11,23,2)/ 1.54079107d-03,-1.70086370d-06/
      data fpp(11,24,1),fpp(11,24,2)/ 7.60526237d-04, 5.23432796d-07/
      data fpp(11,25,1),fpp(11,25,2)/ 9.22040842d-05, 2.90113252d-06/
      data fpp(11,26,1),fpp(11,26,2)/-9.08221357d-05, 2.99803714d-06/
      data fpp(11,27,1),fpp(11,27,2)/ 9.58379950d-05, 6.46718917d-07/
      data fpp(11,28,1),fpp(11,28,2)/ 3.66293152d-04,-1.24691281d-06/
      data fpp(11,29,1),fpp(11,29,2)/ 4.39254957d-04,-1.34106767d-06/
      data fpp(11,30,1),fpp(11,30,2)/ 3.34068197d-04,-8.46816521d-07/
      data fpp(11,31,1),fpp(11,31,2)/ 7.94603681d-05,-4.31666248d-07/
      data fpp(11,32,1),fpp(11,32,2)/-1.35556060d-04,-7.25184871d-08/
      data fpp(11,33,1),fpp(11,33,2)/-2.94391918d-04, 2.95740196d-07/
      data fpp(11,34,1),fpp(11,34,2)/-3.56604744d-04, 6.35557705d-07/
      data fpp(11,35,1),fpp(11,35,2)/-2.88530679d-04, 7.74028987d-07/
      data fpp(11,36,1),fpp(11,36,2)/-9.52575589d-05, 5.34326348d-07/
      data fpp(11,37,1),fpp(11,37,2)/ 1.56330001d-04,-1.93343787d-08/
      data fpp(11,38,1),fpp(11,38,2)/ 4.00344869d-04,-8.88988832d-07/
      data fpp(11,39,1),fpp(11,39,2)/ 4.03411667d-04,-9.23366314d-07/
      data fpp(11,40,1),fpp(11,40,2)/ 1.57609425d-04,-4.38244539d-08/
      data fpp(11,41,1),fpp(11,41,2)/-9.94933498d-05, 4.08664129d-07/
      data fpp(11,42,1),fpp(11,42,2)/-3.03217157d-04, 9.83167936d-07/
      data fpp(12, 1,1),fpp(12, 1,2)/-1.15805982d-04, 1.91502964d-07/
      data fpp(12, 2,1),fpp(12, 2,2)/-7.98130259d-05, 9.29940704d-08/
      data fpp(12, 3,1),fpp(12, 3,2)/-5.63328993d-06, 1.25207521d-08/
      data fpp(12, 4,1),fpp(12, 4,2)/ 4.95711179d-05,-1.31077081d-07/
      data fpp(12, 5,1),fpp(12, 5,2)/ 4.88215401d-05,-1.41029134d-07/
      data fpp(12, 6,1),fpp(12, 6,2)/-7.77074782d-06,-1.67103063d-09/
      data fpp(12, 7,1),fpp(12, 7,2)/-8.53763834d-05, 8.17132576d-08/
      data fpp(12, 8,1),fpp(12, 8,2)/-1.26273214d-04, 1.18817999d-07/
      data fpp(12, 9,1),fpp(12, 9,2)/-1.36553683d-04, 9.10147475d-08/
      data fpp(12,10,1),fpp(12,10,2)/-1.20706377d-04, 3.31230089d-08/
      data fpp(12,11,1),fpp(12,11,2)/-9.10436176d-05, 4.49321604d-09/
      data fpp(12,12,1),fpp(12,12,2)/-4.63890605d-05,-1.83095876d-07/
      data fpp(12,13,1),fpp(12,13,2)/-2.33542644d-05, 2.95890287d-07/
      data fpp(12,14,1),fpp(12,14,2)/-4.47818118d-05,-8.08465270d-07/
      data fpp(12,15,1),fpp(12,15,2)/-1.87321478d-05, 3.03970790d-07/
      data fpp(12,16,1),fpp(12,16,2)/-6.48710612d-06,-1.19417894d-07/
      data fpp(12,17,1),fpp(12,17,2)/-1.24837800d-05, 1.31700782d-07/
      data fpp(12,18,1),fpp(12,18,2)/ 5.61622083d-06, 8.46147632d-08/
      data fpp(12,19,1),fpp(12,19,2)/ 3.08811574d-05,-2.15983310d-09/
      data fpp(12,20,1),fpp(12,20,2)/ 6.99770831d-05, 8.60245701d-08/
      data fpp(12,21,1),fpp(12,21,2)/ 1.52666444d-04, 2.46061551d-07/
      data fpp(12,22,1),fpp(12,22,2)/ 1.81923647d-04,-3.98696937d-07/
      data fpp(12,23,1),fpp(12,23,2)/ 6.97969315d-05,-4.60941477d-07/
      data fpp(12,24,1),fpp(12,24,2)/-6.85477200d-05, 7.64628465d-08/
      data fpp(12,25,1),fpp(12,25,2)/-1.80094114d-04, 7.61090091d-07/
      data fpp(12,26,1),fpp(12,26,2)/-2.09585552d-04, 7.31176791d-07/
      data fpp(12,27,1),fpp(12,27,2)/-1.34709454d-04, 2.68202741d-07/
      data fpp(12,28,1),fpp(12,28,2)/-4.13103275d-05,-2.73987758d-07/
      data fpp(12,29,1),fpp(12,29,2)/ 1.57788691d-05, 1.07748287d-07/
      data fpp(12,30,1),fpp(12,30,2)/-2.15358172d-05,-9.91005394d-07/
      data fpp(12,31,1),fpp(12,31,2)/-1.89151040d-05, 1.48273287d-07/
      data fpp(12,32,1),fpp(12,32,2)/-5.55419082d-05,-2.50087756d-07/
      data fpp(12,33,1),fpp(12,33,2)/-1.00717792d-04, 3.60777339d-08/
      data fpp(12,34,1),fpp(12,34,2)/-1.20221822d-04, 1.05776820d-07/
      data fpp(12,35,1),fpp(12,35,2)/-1.15805982d-04, 1.46814991d-07/
      data fpp(12,36,1),fpp(12,36,2)/-7.98130259d-05, 1.04963219d-07/
      data fpp(12,37,1),fpp(12,37,2)/-5.63328993d-06, 9.33213415d-09/
      data fpp(12,38,1),fpp(12,38,2)/ 4.95711179d-05,-1.30291756d-07/
      data fpp(12,39,1),fpp(12,39,2)/ 4.88215401d-05,-1.41790796d-07/
      data fpp(12,40,1),fpp(12,40,2)/-7.77074782d-06, 1.32829131d-09/
      data fpp(12,41,1),fpp(12,41,2)/-8.53763834d-05, 7.04776300d-08/
      data fpp(12,42,1),fpp(12,42,2)/-1.26273214d-04, 1.60761184d-07/
      data fpp(13, 1,1),fpp(13, 1,2)/ 1.03328537d-06, 4.37535510d-07/
      data fpp(13, 2,1),fpp(13, 2,2)/-4.53214265d-06, 1.92928977d-07/
      data fpp(13, 3,1),fpp(13, 3,2)/-2.90151306d-05,-2.73251422d-07/
      data fpp(13, 4,1),fpp(13, 4,2)/-3.68857880d-05, 3.60767115d-08/
      data fpp(13, 5,1),fpp(13, 5,2)/-3.67704537d-05, 4.33955752d-08/
      data fpp(13, 6,1),fpp(13, 6,2)/-2.87924688d-05,-3.14526872d-07/
      data fpp(13, 7,1),fpp(13, 7,2)/-3.87417494d-06, 3.26711913d-07/
      data fpp(13, 8,1),fpp(13, 8,2)/ 2.12821972d-06,-9.23207796d-08/
      data fpp(13, 9,1),fpp(13, 9,2)/ 4.02247379d-06, 3.65712091d-08/
      data fpp(13,10,1),fpp(13,10,2)/ 2.76534335d-06,-1.07964059d-07/
      data fpp(13,11,1),fpp(13,11,2)/ 9.96886279d-08, 3.11285026d-07/
      data fpp(13,12,1),fpp(13,12,2)/-1.80030063d-05,-3.45176046d-07/
      data fpp(13,13,1),fpp(13,13,2)/-2.01907534d-05, 8.54191575d-08/
      data fpp(13,14,1),fpp(13,14,2)/-8.82660580d-06,-4.45005842d-08/
      data fpp(13,15,1),fpp(13,15,2)/-2.64625991d-05, 9.25831777d-08/
      data fpp(13,16,1),fpp(13,16,2)/-3.85651102d-05,-3.37832129d-07/
      data fpp(13,17,1),fpp(13,17,2)/-3.37542080d-05, 3.04745333d-07/
      data fpp(13,18,1),fpp(13,18,2)/-4.32407037d-05,-7.11492054d-08/
      data fpp(13,19,1),fpp(13,19,2)/-5.16978074d-05,-3.21485103d-08/
      data fpp(13,20,1),fpp(13,20,2)/-6.41942140d-05, 3.13743247d-07/
      data fpp(13,21,1),fpp(13,21,2)/-9.87683076d-05,-1.06824479d-07/
      data fpp(13,22,1),fpp(13,22,2)/-1.01378748d-04,-2.03898186d-07/
      data fpp(13,23,1),fpp(13,23,2)/-6.79363278d-05, 2.58038073d-07/
      data fpp(13,24,1),fpp(13,24,2)/-5.17699583d-05,-6.25410561d-09/
      data fpp(13,25,1),fpp(13,25,2)/-4.34196996d-05, 1.38978348d-07/
      data fpp(13,26,1),fpp(13,26,2)/-4.05822752d-05, 8.63407082d-08/
      data fpp(13,27,1),fpp(13,27,2)/-4.54906362d-05,-9.43411859d-08/
      data fpp(13,28,1),fpp(13,28,2)/-4.57155938d-05, 2.91024031d-07/
      data fpp(13,29,1),fpp(13,29,2)/-5.05140858d-05,-3.55754940d-07/
      data fpp(13,30,1),fpp(13,30,2)/-2.11266468d-05, 2.19957261d-08/
      data fpp(13,31,1),fpp(13,31,2)/-2.27348719d-05, 2.77720306d-08/
      data fpp(13,32,1),fpp(13,32,2)/-1.54962454d-05,-3.49083849d-07/
      data fpp(13,33,1),fpp(13,33,2)/ 2.64933544d-06, 3.06563367d-07/
      data fpp(13,34,1),fpp(13,34,2)/ 3.01783897d-06,-6.71696161d-08/
      data fpp(13,35,1),fpp(13,35,2)/ 1.03328537d-06,-6.18848971d-08/
      data fpp(13,36,1),fpp(13,36,2)/-4.53214265d-06, 3.26709208d-07/
      data fpp(13,37,1),fpp(13,37,2)/-2.90151306d-05,-3.08951934d-07/
      data fpp(13,38,1),fpp(13,38,2)/-3.68857880d-05, 4.50985296d-08/
      data fpp(13,39,1),fpp(13,39,2)/-3.67704537d-05, 3.41803794d-08/
      data fpp(13,40,1),fpp(13,40,2)/-2.87924688d-05,-2.77279333d-07/
      data fpp(13,41,1),fpp(13,41,2)/-3.87417494d-06, 1.86936952d-07/
      data fpp(13,42,1),fpp(13,42,2)/ 2.12821972d-06, 4.29531525d-07/
      data fpp(14, 1,1),fpp(14, 1,2)/-1.43271596d-05,-1.91715612d-09/
      data fpp(14, 2,1),fpp(14, 2,2)/-1.21584034d-05,-1.65690638d-10/
      data fpp(14, 3,1),fpp(14, 3,2)/-4.90618777d-06, 2.57991690d-09/
      data fpp(14, 4,1),fpp(14, 4,2)/-1.32796585d-06, 1.84602347d-09/
      data fpp(14, 5,1),fpp(14, 5,2)/-1.33972518d-06, 2.17197068d-09/
      data fpp(14, 6,1),fpp(14, 6,2)/-5.00937711d-06, 1.27613056d-09/
      data fpp(14, 7,1),fpp(14, 7,2)/-1.25269168d-05,-1.27649276d-09/
      data fpp(14, 8,1),fpp(14, 8,2)/-1.51396652d-05,-2.17016051d-09/
      data fpp(14, 9,1),fpp(14, 9,2)/-1.57362123d-05,-2.04286167d-09/
      data fpp(14,10,1),fpp(14,10,2)/-1.47049968d-05,-7.65839427d-09/
      data fpp(14,11,1),fpp(14,11,2)/-1.28551368d-05,-3.32356186d-09/
      data fpp(14,12,1),fpp(14,12,2)/-7.74891450d-06,-3.04735940d-09/
      data fpp(14,13,1),fpp(14,13,2)/-6.73272189d-06,-2.48700256d-09/
      data fpp(14,14,1),fpp(14,14,2)/-8.56176503d-06, 9.95369009d-10/
      data fpp(14,15,1),fpp(14,15,2)/-7.71745568d-06,-1.49447643d-09/
      data fpp(14,16,1),fpp(14,16,2)/-7.70245307d-06,-7.01746599d-09/
      data fpp(14,17,1),fpp(14,17,2)/-1.13493881d-05,-6.43566303d-09/
      data fpp(14,18,1),fpp(14,18,2)/-1.10034058d-05,-3.23988737d-09/
      data fpp(14,19,1),fpp(14,19,2)/-1.00899277d-05, 1.39521190d-09/
      data fpp(14,20,1),fpp(14,20,2)/-8.05022696d-06, 1.56590403d-08/
      data fpp(14,21,1),fpp(14,21,2)/-4.43213355d-07, 1.39686268d-08/
      data fpp(14,22,1),fpp(14,22,2)/ 1.44134400d-06,-2.35399455d-10/
      data fpp(14,23,1),fpp(14,23,2)/-9.25162037d-06, 4.75143141d-10/
      data fpp(14,24,1),fpp(14,24,2)/-1.95724468d-05, 1.03348246d-08/
      data fpp(14,25,1),fpp(14,25,2)/-2.73770875d-05, 1.81855575d-08/
      data fpp(14,26,1),fpp(14,26,2)/-2.82853470d-05, 1.29229421d-08/
      data fpp(14,27,1),fpp(14,27,2)/-2.14280016d-05, 2.12267082d-09/
      data fpp(14,28,1),fpp(14,28,2)/-1.32772973d-05,-9.41362785d-09/
      data fpp(14,29,1),fpp(14,29,2)/-5.27252604d-06,-6.46816151d-09/
      data fpp(14,30,1),fpp(14,30,2)/-6.15759573d-06,-1.27137280d-08/
      data fpp(14,31,1),fpp(14,31,2)/-5.34540830d-06,-8.67692823d-09/
      data fpp(14,32,1),fpp(14,32,2)/-7.42311035d-06,-6.57855912d-09/
      data fpp(14,33,1),fpp(14,33,2)/-1.29295495d-05,-7.00883383d-09/
      data fpp(14,34,1),fpp(14,34,2)/-1.43995336d-05,-1.38610291d-09/
      data fpp(14,35,1),fpp(14,35,2)/-1.43271596d-05, 5.53248740d-10/
      data fpp(14,36,1),fpp(14,36,2)/-1.21584034d-05,-8.26891224d-10/
      data fpp(14,37,1),fpp(14,37,2)/-4.90618777d-06, 2.75431602d-09/
      data fpp(14,38,1),fpp(14,38,2)/-1.32796585d-06, 1.80962947d-09/
      data fpp(14,39,1),fpp(14,39,2)/-1.33972518d-06, 2.19395494d-09/
      data fpp(14,40,1),fpp(14,40,2)/-5.00937711d-06, 1.21701225d-09/
      data fpp(14,41,1),fpp(14,41,2)/-1.25269168d-05,-1.06200443d-09/
      data fpp(14,42,1),fpp(14,42,2)/-1.51396652d-05,-2.96899804d-09/
      data fpp(15, 1,1),fpp(15, 1,2)/ 1.12350083d-05,-2.95287920d-11/
      data fpp(15, 2,1),fpp(15, 2,2)/ 6.88277312d-06, 5.90563085d-11/
      data fpp(15, 3,1),fpp(15, 3,2)/ 1.37973796d-05,-2.06698406d-10/
      data fpp(15, 4,1),fpp(15, 4,2)/ 7.15041149d-06, 7.67736570d-10/
      data fpp(15, 5,1),fpp(15, 5,2)/ 7.31271973d-06, 8.00138662d-10/
      data fpp(15, 6,1),fpp(15, 6,2)/ 1.41929028d-05,-3.36303906d-10/
      data fpp(15, 7,1),fpp(15, 7,2)/ 7.63917268d-06, 5.45078909d-10/
      data fpp(15, 8,1),fpp(15, 8,2)/ 1.25134040d-05,-1.84401162d-09/
      data fpp(15, 9,1),fpp(15, 9,2)/ 1.35723919d-05, 8.30970596d-10/
      data fpp(15,10,1),fpp(15,10,2)/ 1.09064269d-05,-1.47987154d-09/
      data fpp(15,11,1),fpp(15,11,2)/ 5.98399698d-06,-9.11484459d-10/
      data fpp(15,12,1),fpp(15,12,2)/ 1.42983858d-05,-8.74191928d-10/
      data fpp(15,13,1),fpp(15,13,2)/ 9.66957523d-06,-1.59174854d-09/
      data fpp(15,14,1),fpp(15,14,2)/ 4.95695394d-06, 1.24118653d-09/
      data fpp(15,15,1),fpp(15,15,2)/ 1.06665850d-05,-3.37300196d-09/
      data fpp(15,16,1),fpp(15,16,2)/ 1.54515837d-05, 2.50818273d-10/
      data fpp(15,17,1),fpp(15,17,2)/ 6.20076544d-06,-3.63027574d-09/
      data fpp(15,18,1),fpp(15,18,2)/ 7.53848863d-06, 2.27028008d-09/
      data fpp(15,19,1),fpp(15,19,2)/ 6.66496382d-06, 5.49156148d-10/
      data fpp(15,20,1),fpp(15,20,2)/ 6.19689918d-06, 1.53309605d-09/
      data fpp(15,21,1),fpp(15,21,2)/ 1.84562495d-05, 5.31846031d-09/
      data fpp(15,22,1),fpp(15,22,2)/ 1.37146851d-05,-1.72192832d-09/
      data fpp(15,23,1),fpp(15,23,2)/ 6.56295304d-06,-3.05350151d-10/
      data fpp(15,24,1),fpp(15,24,2)/ 2.30547948d-05, 2.94332817d-09/
      data fpp(15,25,1),fpp(15,25,2)/ 4.10367580d-05, 5.32037305d-10/
      data fpp(15,26,1),fpp(15,26,2)/ 4.77726735d-05, 6.92852112d-09/
      data fpp(15,27,1),fpp(15,27,2)/ 3.86204294d-05, 1.75387252d-09/
      data fpp(15,28,1),fpp(15,28,2)/ 2.18347200d-05,-1.94401541d-09/
      data fpp(15,29,1),fpp(15,29,2)/ 2.15844773d-05, 2.21866947d-11/
      data fpp(15,30,1),fpp(15,30,2)/ 1.09430836d-05,-4.14473456d-09/
      data fpp(15,31,1),fpp(15,31,2)/ 1.29412756d-05,-1.44324866d-09/
      data fpp(15,32,1),fpp(15,32,2)/ 1.64411980d-05,-2.08227237d-09/
      data fpp(15,33,1),fpp(15,33,2)/ 7.43227476d-06,-2.22766358d-09/
      data fpp(15,34,1),fpp(15,34,2)/ 1.11865525d-05,-1.00707297d-09/
      data fpp(15,35,1),fpp(15,35,2)/ 1.12350083d-05, 2.55960888d-10/
      data fpp(15,36,1),fpp(15,36,2)/ 6.88277312d-06,-1.67672336d-11/
      data fpp(15,37,1),fpp(15,37,2)/ 1.37973796d-05,-1.88891808d-10/
      data fpp(15,38,1),fpp(15,38,2)/ 7.15041149d-06, 7.72335796d-10/
      data fpp(15,39,1),fpp(15,39,2)/ 7.31271973d-06, 7.77439960d-10/
      data fpp(15,40,1),fpp(15,40,2)/ 1.41929028d-05,-2.09310347d-10/
      data fpp(15,41,1),fpp(15,41,2)/ 7.63917268d-06, 5.98024380d-11/
      data fpp(15,42,1),fpp(15,42,2)/ 1.25134040d-05,-2.99020758d-11/
 
      data fpppp( 1, 1),fpppp( 1, 2)/ 6.88517847d-04, 2.88224139d-04/
      data fpppp( 1, 3),fpppp( 1, 4)/-2.34150021d-04,-3.29242598d-04/
      data fpppp( 1, 5),fpppp( 1, 6)/-3.21265513d-04,-2.65425244d-04/
      data fpppp( 1, 7),fpppp( 1, 8)/ 4.41385378d-04, 1.47928606d-04/
      data fpppp( 1, 9),fpppp( 1,10)/ 1.12943126d-04, 4.09073771d-05/
      data fpppp( 1,11),fpppp( 1,12)/ 1.17605373d-05, 3.72623130d-05/
      data fpppp( 1,13),fpppp( 1,14)/-1.19680517d-04, 6.10399177d-04/
      data fpppp( 1,15),fpppp( 1,16)/-1.64577353d-03, 8.88264537d-03/
      data fpppp( 1,17),fpppp( 1,18)/-2.84912287d-02, 4.52662466d-02/
      data fpppp( 1,19),fpppp( 1,20)/-3.17052649d-02, 1.44194761d-02/
      data fpppp( 1,21),fpppp( 1,22)/-2.03518336d-02, 4.99592828d-02/
      data fpppp( 1,23),fpppp( 1,24)/-2.73430327d-01, 1.07100317d+00/
      data fpppp( 1,25),fpppp( 1,26)/-1.65576056d+00, 9.68640137d-01/
      data fpppp( 1,27),fpppp( 1,28)/-2.03318316d-01, 5.02065346d-02/
      data fpppp( 1,29),fpppp( 1,30)/-1.23256111d-02, 4.35268148d-03/
      data fpppp( 1,31),fpppp( 1,32)/-1.18453947d-03, 2.67485914d-04/
      data fpppp( 1,33),fpppp( 1,34)/-4.98814849d-05, 1.12831918d-04/
      data fpppp( 1,35),fpppp( 1,36)/ 1.36729412d-04, 4.36023584d-04/
      data fpppp( 1,37),fpppp( 1,38)/-2.73559367d-04,-3.19404662d-04/
      data fpppp( 1,39),fpppp( 1,40)/-3.31074649d-04,-2.26246303d-04/
      data fpppp( 1,41),fpppp( 1,42)/ 2.94478751d-04, 6.96376175d-04/
      data fpppp( 2, 1),fpppp( 2, 2)/ 2.12747338d-04, 1.32910658d-04/
      data fpppp( 2, 3),fpppp( 2, 4)/ 3.14731268d-04,-4.19248638d-04/
      data fpppp( 2, 5),fpppp( 2, 6)/-4.19270584d-04, 3.13702818d-04/
      data fpppp( 2, 7),fpppp( 2, 8)/ 1.65921529d-04, 1.07571312d-04/
      data fpppp( 2, 9),fpppp( 2,10)/ 5.71073640d-05, 2.61822591d-05/
      data fpppp( 2,11),fpppp( 2,12)/ 8.04725617d-06, 3.29050377d-05/
      data fpppp( 2,13),fpppp( 2,14)/-5.52759510d-05, 4.05019925d-04/
      data fpppp( 2,15),fpppp( 2,16)/-9.78189074d-04, 5.45303552d-03/
      data fpppp( 2,17),fpppp( 2,18)/-1.81889116d-02, 2.76949562d-02/
      data fpppp( 2,19),fpppp( 2,20)/-1.75121490d-02, 7.83021324d-03/
      data fpppp( 2,21),fpppp( 2,22)/-1.23687158d-02, 2.94325253d-02/
      data fpppp( 2,23),fpppp( 2,24)/-1.60624226d-01, 6.47261795d-01/
      data fpppp( 2,25),fpppp( 2,26)/-1.00231652d+00, 5.72544246d-01/
      data fpppp( 2,27),fpppp( 2,28)/-1.10134713d-01, 2.76918441d-02/
      data fpppp( 2,29),fpppp( 2,30)/-6.86643470d-03, 2.63330170d-03/
      data fpppp( 2,31),fpppp( 2,32)/-6.48722728d-04, 1.62020160d-04/
      data fpppp( 2,33),fpppp( 2,34)/-2.86033235d-05, 5.61093495d-05/
      data fpppp( 2,35),fpppp( 2,36)/ 1.00464732d-04, 1.62985424d-04/
      data fpppp( 2,37),fpppp( 2,38)/ 3.06714807d-04,-4.17257562d-04/
      data fpppp( 2,39),fpppp( 2,40)/-4.21235581d-04, 3.21510650d-04/
      data fpppp( 2,41),fpppp( 2,42)/ 1.36655199d-04, 2.16828800d-04/
      data fpppp( 3, 1),fpppp( 3, 2)/-2.79727176d-04, 9.92318349d-06/
      data fpppp( 3, 3),fpppp( 3, 4)/ 1.17058511d-03,-7.17293452d-04/
      data fpppp( 3, 5),fpppp( 3, 6)/-7.30415424d-04, 1.20800481d-03/
      data fpppp( 3, 7),fpppp( 3, 8)/-8.64715747d-05, 6.82956275d-05/
      data fpppp( 3, 9),fpppp( 3,10)/-9.41042732d-06, 1.30054883d-05/
      data fpppp( 3,11),fpppp( 3,12)/-1.57932352d-06, 3.03946810d-05/
      data fpppp( 3,13),fpppp( 3,14)/ 3.86055036d-05, 1.54159248d-04/
      data fpppp( 3,15),fpppp( 3,16)/-7.24438636d-05, 1.06346920d-03/
      data fpppp( 3,17),fpppp( 3,18)/-5.84697789d-03, 7.27128339d-03/
      data fpppp( 3,19),fpppp( 3,20)/-2.22205705d-04, 1.35418214d-03/
      data fpppp( 3,21),fpppp( 3,22)/-3.97708155d-03, 2.80745060d-04/
      data fpppp( 3,23),fpppp( 3,24)/ 9.94011875d-04, 5.48889966d-02/
      data fpppp( 3,25),fpppp( 3,26)/-8.76501136d-02, 8.02976945d-03/
      data fpppp( 3,27),fpppp( 3,28)/ 3.00045636d-02,-6.40527661d-03/
      data fpppp( 3,29),fpppp( 3,30)/ 1.40431903d-03, 1.97301020d-04/
      data fpppp( 3,31),fpppp( 3,32)/ 1.23504070d-04, 4.64936891d-06/
      data fpppp( 3,33),fpppp( 3,34)/-1.04261350d-06,-5.73567086d-06/
      data fpppp( 3,35),fpppp( 3,36)/ 6.01144744d-05,-8.11101837d-05/
      data fpppp( 3,37),fpppp( 3,38)/ 1.19487693d-03,-7.23427357d-04/
      data fpppp( 3,39),fpppp( 3,40)/-7.24159618d-04, 1.18273778d-03/
      data fpppp( 3,41),fpppp( 3,42)/ 8.34071458d-06,-2.85686506d-04/
      data fpppp( 4, 1),fpppp( 4, 2)/-7.13737671d-04,-2.26205315d-04/
      data fpppp( 4, 3),fpppp( 4, 4)/ 9.52035010d-04,-2.87202559d-04/
      data fpppp( 4, 5),fpppp( 4, 6)/-2.95571069d-04, 9.99198050d-04/
      data fpppp( 4, 7),fpppp( 4, 8)/-4.19612288d-04, 2.52343081d-05/
      data fpppp( 4, 9),fpppp( 4,10)/-3.85411158d-05,-5.59049787d-06/
      data fpppp( 4,11),fpppp( 4,12)/ 9.49064161d-06, 2.14201093d-05/
      data fpppp( 4,13),fpppp( 4,14)/ 2.93178496d-05, 6.24835594d-05/
      data fpppp( 4,15),fpppp( 4,16)/-2.61293844d-07, 3.37504822d-05/
      data fpppp( 4,17),fpppp( 4,18)/-6.43702304d-04,-3.16905088d-03/
      data fpppp( 4,19),fpppp( 4,20)/ 6.22884164d-03,-5.51816004d-03/
      data fpppp( 4,21),fpppp( 4,22)/ 2.98474507d-03, 1.31654436d-03/
      data fpppp( 4,23),fpppp( 4,24)/-8.23022734d-03, 5.27261909d-02/
      data fpppp( 4,25),fpppp( 4,26)/-8.72620082d-02, 3.29803417d-02/
      data fpppp( 4,27),fpppp( 4,28)/ 5.79898126d-03, 3.61084207d-05/
      data fpppp( 4,29),fpppp( 4,30)/-1.65447752d-04, 2.69473497d-04/
      data fpppp( 4,31),fpppp( 4,32)/ 6.82956651d-05, 2.89462095d-05/
      data fpppp( 4,33),fpppp( 4,34)/ 4.52917658d-06,-4.96521082d-05/
      data fpppp( 4,35),fpppp( 4,36)/ 3.40637392d-05,-4.26504722d-04/
      data fpppp( 4,37),fpppp( 4,38)/ 1.00543123d-03,-3.00488023d-04/
      data fpppp( 4,39),fpppp( 4,40)/-2.82412787d-04, 9.46819284d-04/
      data fpppp( 4,41),fpppp( 4,42)/-2.23255507d-04,-7.07814051d-04/
      data fpppp( 5, 1),fpppp( 5, 2)/ 1.00715034d-03, 1.11303113d-04/
      data fpppp( 5, 3),fpppp( 5, 4)/-3.43471778d-03, 2.29486914d-03/
      data fpppp( 5, 5),fpppp( 5, 6)/ 2.31094965d-03,-3.52342762d-03/
      data fpppp( 5, 7),fpppp( 5, 8)/ 4.48893221d-04,-2.63892226d-04/
      data fpppp( 5, 9),fpppp( 5,10)/ 1.86398627d-05,-1.55440182d-05/
      data fpppp( 5,11),fpppp( 5,12)/ 1.01538702d-05, 1.51769501d-05/
      data fpppp( 5,13),fpppp( 5,14)/ 1.41777111d-05, 6.63599357d-06/
      data fpppp( 5,15),fpppp( 5,16)/ 4.88165085d-05,-8.13104896d-05/
      data fpppp( 5,17),fpppp( 5,18)/-5.59982937d-04,-4.39960334d-04/
      data fpppp( 5,19),fpppp( 5,20)/-1.13268890d-04,-7.70529336d-04/
      data fpppp( 5,21),fpppp( 5,22)/ 4.50958677d-04, 3.62584900d-03/
      data fpppp( 5,23),fpppp( 5,24)/-1.95004631d-03, 8.34644336d-03/
      data fpppp( 5,25),fpppp( 5,26)/-1.69215247d-02,-1.06385555d-03/
      data fpppp( 5,27),fpppp( 5,28)/ 7.57836011d-03,-6.94732465d-04/
      data fpppp( 5,29),fpppp( 5,30)/ 4.73248578d-05, 4.50688750d-05/
      data fpppp( 5,31),fpppp( 5,32)/ 7.18048573d-05, 2.97355577d-05/
      data fpppp( 5,33),fpppp( 5,34)/-1.25447389d-05, 2.70569233d-05/
      data fpppp( 5,35),fpppp( 5,36)/-2.67550064d-04, 4.52738784d-04/
      data fpppp( 5,37),fpppp( 5,38)/-3.52576005d-03, 2.31760258d-03/
      data fpppp( 5,39),fpppp( 5,40)/ 2.28827048d-03,-3.43281946d-03/
      data fpppp( 5,41),fpppp( 5,42)/ 1.09139752d-04, 1.00451349d-03/
      data fpppp( 6, 1),fpppp( 6, 2)/-2.34377786d-04,-1.32178962d-04/
      data fpppp( 6, 3),fpppp( 6, 4)/-2.47562515d-04, 3.98592254d-04/
      data fpppp( 6, 5),fpppp( 6, 6)/ 4.18547986d-04,-2.45323202d-04/
      data fpppp( 6, 7),fpppp( 6, 8)/-1.82893590d-04,-4.55977992d-05/
      data fpppp( 6, 9),fpppp( 6,10)/-1.95557550d-05,-3.51353179d-07/
      data fpppp( 6,11),fpppp( 6,12)/ 1.06029923d-05, 2.35355442d-06/
      data fpppp( 6,13),fpppp( 6,14)/ 2.23633490d-06,-4.56911367d-06/
      data fpppp( 6,15),fpppp( 6,16)/-1.18034484d-05,-1.72721103d-05/
      data fpppp( 6,17),fpppp( 6,18)/-2.33312893d-04,-3.63856408d-04/
      data fpppp( 6,19),fpppp( 6,20)/-2.24246133d-05, 1.48436016d-03/
      data fpppp( 6,21),fpppp( 6,22)/-1.04575236d-03, 1.54110996d-04/
      data fpppp( 6,23),fpppp( 6,24)/ 2.53619956d-03, 4.24833637d-03/
      data fpppp( 6,25),fpppp( 6,26)/-1.07290828d-02, 1.23763953d-03/
      data fpppp( 6,27),fpppp( 6,28)/ 2.88353230d-03, 1.67846443d-04/
      data fpppp( 6,29),fpppp( 6,30)/-2.11505694d-04, 4.35420600d-05/
      data fpppp( 6,31),fpppp( 6,32)/ 2.34746931d-05, 2.80613540d-05/
      data fpppp( 6,33),fpppp( 6,34)/ 7.76081610d-06,-1.45695282d-05/
      data fpppp( 6,35),fpppp( 6,36)/-4.15987481d-05,-1.83815409d-04/
      data fpppp( 6,37),fpppp( 6,38)/-2.33795766d-04, 3.95161705d-04/
      data fpppp( 6,39),fpppp( 6,40)/ 4.21956259d-04,-2.58911742d-04/
      data fpppp( 6,41),fpppp( 6,42)/-1.31947701d-04,-2.35792815d-04/
      data fpppp( 7, 1),fpppp( 7, 2)/-1.46152154d-04, 1.67502252d-05/
      data fpppp( 7, 3),fpppp( 7, 4)/ 6.82775072d-04,-4.12128717d-04/
      data fpppp( 7, 5),fpppp( 7, 6)/-4.19595147d-04, 7.01558530d-04/
      data fpppp( 7, 7),fpppp( 7, 8)/-3.80658635d-05, 4.82541000d-05/
      data fpppp( 7, 9),fpppp( 7,10)/ 3.87515003d-06, 1.25370701d-05/
      data fpppp( 7,11),fpppp( 7,12)/ 3.35871385d-06, 1.74856462d-06/
      data fpppp( 7,13),fpppp( 7,14)/-1.20243771d-05,-1.30328495d-05/
      data fpppp( 7,15),fpppp( 7,16)/-1.03244606d-05,-1.78802748d-05/
      data fpppp( 7,17),fpppp( 7,18)/-7.15995727d-05,-7.90527491d-05/
      data fpppp( 7,19),fpppp( 7,20)/ 2.17498083d-05, 3.72679344d-04/
      data fpppp( 7,21),fpppp( 7,22)/-1.27727697d-04,-5.39176821d-04/
      data fpppp( 7,23),fpppp( 7,24)/ 1.54713687d-03, 6.64405875d-04/
      data fpppp( 7,25),fpppp( 7,26)/-2.17736931d-03,-5.67469686d-04/
      data fpppp( 7,27),fpppp( 7,28)/ 1.28394739d-03,-4.41387449d-05/
      data fpppp( 7,29),fpppp( 7,30)/-8.90704198d-05,-5.54225631d-05/
      data fpppp( 7,31),fpppp( 7,32)/ 1.33663975d-05, 9.73377784d-06/
      data fpppp( 7,33),fpppp( 7,34)/ 2.06271745d-05, 9.69820642d-06/
      data fpppp( 7,35),fpppp( 7,36)/ 5.08115555d-05,-3.60082974d-05/
      data fpppp( 7,37),fpppp( 7,38)/ 6.96845453d-04,-4.15651719d-04/
      data fpppp( 7,39),fpppp( 7,40)/-4.16061332d-04, 6.87401641d-04/
      data fpppp( 7,41),fpppp( 7,42)/ 1.50278750d-05,-1.49963966d-04/
      data fpppp( 8, 1),fpppp( 8, 2)/ 1.29062118d-04, 6.89215503d-05/
      data fpppp( 8, 3),fpppp( 8, 4)/ 4.82091516d-05,-1.10501837d-04/
      data fpppp( 8, 5),fpppp( 8, 6)/-1.11541117d-04, 4.11361602d-05/
      data fpppp( 8, 7),fpppp( 8, 8)/ 8.96495758d-05, 4.71253912d-05/
      data fpppp( 8, 9),fpppp( 8,10)/ 2.82389877d-05, 1.13282970d-05/
      data fpppp( 8,11),fpppp( 8,12)/ 4.49586821d-06,-2.48984038d-06/
      data fpppp( 8,13),fpppp( 8,14)/-3.45213845d-06,-1.02137359d-05/
      data fpppp( 8,15),fpppp( 8,16)/-9.19402274d-06,-1.04060692d-05/
      data fpppp( 8,17),fpppp( 8,18)/-6.24240716d-06,-3.78404097d-06/
      data fpppp( 8,19),fpppp( 8,20)/ 3.95988885d-05, 7.82306596d-05/
      data fpppp( 8,21),fpppp( 8,22)/-5.82700794d-05,-2.04212720d-04/
      data fpppp( 8,23),fpppp( 8,24)/ 8.60222360d-05, 3.41323555d-04/
      data fpppp( 8,25),fpppp( 8,26)/-2.72973147d-04, 1.09665693d-04/
      data fpppp( 8,27),fpppp( 8,28)/ 1.25915967d-04,-8.50062726d-05/
      data fpppp( 8,29),fpppp( 8,30)/-8.86166736d-05,-1.20889105d-05/
      data fpppp( 8,31),fpppp( 8,32)/-8.24834914d-06, 7.77522008d-06/
      data fpppp( 8,33),fpppp( 8,34)/ 1.52871271d-05, 3.09290336d-05/
      data fpppp( 8,35),fpppp( 8,36)/ 4.86613871d-05, 9.04577563d-05/
      data fpppp( 8,37),fpppp( 8,38)/ 4.24650577d-05,-1.09061668d-04/
      data fpppp( 8,39),fpppp( 8,40)/-1.12989578d-04, 4.69465850d-05/
      data fpppp( 8,41),fpppp( 8,42)/ 6.78563371d-05, 1.28487921d-04/
      data fpppp( 9, 1),fpppp( 9, 2)/ 3.69367401d-05, 1.93134607d-05/
      data fpppp( 9, 3),fpppp( 9, 4)/ 2.24677177d-05,-4.70994028d-05/
      data fpppp( 9, 5),fpppp( 9, 6)/-4.75016752d-05, 2.08955101d-05/
      data fpppp( 9, 7),fpppp( 9, 8)/ 2.06381276d-05, 2.60913859d-05/
      data fpppp( 9, 9),fpppp( 9,10)/ 1.68661288d-05, 9.52177282d-06/
      data fpppp( 9,11),fpppp( 9,12)/ 2.28846067d-06, 5.40176613d-07/
      data fpppp( 9,13),fpppp( 9,14)/-1.96323533d-06, 1.52707829d-06/
      data fpppp( 9,15),fpppp( 9,16)/-1.10044226d-05,-2.61083716d-06/
      data fpppp( 9,17),fpppp( 9,18)/-5.68026985d-06, 5.43018625d-06/
      data fpppp( 9,19),fpppp( 9,20)/ 2.15390156d-05, 2.41792333d-05/
      data fpppp( 9,21),fpppp( 9,22)/-2.32012233d-05,-9.05351910d-05/
      data fpppp( 9,23),fpppp( 9,24)/-2.37739790d-05, 5.41114761d-05/
      data fpppp( 9,25),fpppp( 9,26)/ 1.12483782d-04, 5.21078127d-05/
      data fpppp( 9,27),fpppp( 9,28)/-1.25807365d-05,-5.98991413d-05/
      data fpppp( 9,29),fpppp( 9,30)/-2.79934993d-05,-1.37483644d-05/
      data fpppp( 9,31),fpppp( 9,32)/-6.56109992d-07, 4.17634744d-06/
      data fpppp( 9,33),fpppp( 9,34)/ 1.10394037d-05, 1.78183070d-05/
      data fpppp( 9,35),fpppp( 9,36)/ 2.73572175d-05, 2.18793383d-05/
      data fpppp( 9,37),fpppp( 9,38)/ 2.17837296d-05,-4.69293280d-05/
      data fpppp( 9,39),fpppp( 9,40)/-4.76699056d-05, 2.15647430d-05/
      data fpppp( 9,41),fpppp( 9,42)/ 1.81294266d-05, 3.54569573d-05/
      data fpppp(10, 1),fpppp(10, 2)/ 1.82489503d-05, 8.02055072d-06/
      data fpppp(10, 3),fpppp(10, 4)/-5.93825352d-07,-1.48572836d-05/
      data fpppp(10, 5),fpppp(10, 6)/-1.49690845d-05,-1.53532218d-06/
      data fpppp(10, 7),fpppp(10, 8)/ 9.42330162d-06, 1.04246352d-05/
      data fpppp(10, 9),fpppp(10,10)/ 8.27282842d-06, 4.77971641d-06/
      data fpppp(10,11),fpppp(10,12)/ 2.12153921d-06,-3.10971083d-07/
      data fpppp(10,13),fpppp(10,14)/-3.37502648d-08,-3.46715220d-06/
      data fpppp(10,15),fpppp(10,16)/ 4.98484290d-06,-5.18252658d-06/
      data fpppp(10,17),fpppp(10,18)/-4.09865753d-07, 2.61264969d-06/
      data fpppp(10,19),fpppp(10,20)/ 9.34098652d-06, 8.88730382d-06/
      data fpppp(10,21),fpppp(10,22)/-1.23205513d-05,-3.70773919d-05/
      data fpppp(10,23),fpppp(10,24)/-2.45020166d-05, 2.74682024d-05/
      data fpppp(10,25),fpppp(10,26)/ 5.20790689d-05, 3.24852007d-05/
      data fpppp(10,27),fpppp(10,28)/-1.40986481d-05,-2.34127964d-05/
      data fpppp(10,29),fpppp(10,30)/-1.30971659d-05,-4.40665163d-06/
      data fpppp(10,31),fpppp(10,32)/-8.27295029d-07, 2.65674655d-06/
      data fpppp(10,33),fpppp(10,34)/ 5.41791684d-06, 9.08174728d-06/
      data fpppp(10,35),fpppp(10,36)/ 1.11590480d-05, 9.91966032d-06/
      data fpppp(10,37),fpppp(10,38)/-1.10036151d-06,-1.47302486d-05/
      data fpppp(10,39),fpppp(10,40)/-1.50969214d-05,-1.02237051d-06/
      data fpppp(10,41),fpppp(10,42)/ 7.49933191d-06, 1.76075625d-05/
      data fpppp(11, 1),fpppp(11, 2)/ 1.28409862d-06, 4.98978562d-07/
      data fpppp(11, 3),fpppp(11, 4)/ 2.18853482d-07,-1.82875401d-06/
      data fpppp(11, 5),fpppp(11, 6)/-1.89760877d-06, 2.03022151d-07/
      data fpppp(11, 7),fpppp(11, 8)/ 4.07488271d-07, 1.36976280d-06/
      data fpppp(11, 9),fpppp(11,10)/ 1.06254737d-06, 6.70214748d-07/
      data fpppp(11,11),fpppp(11,12)/ 2.36053522d-07, 1.68968650d-07/
      data fpppp(11,13),fpppp(11,14)/ 6.41392144d-07, 1.97679018d-07/
      data fpppp(11,15),fpppp(11,16)/-1.48988734d-06, 1.71551647d-06/
      data fpppp(11,17),fpppp(11,18)/-4.27705261d-08, 7.66450489d-07/
      data fpppp(11,19),fpppp(11,20)/ 8.98064648d-07,-6.81148822d-07/
      data fpppp(11,21),fpppp(11,22)/-1.10178351d-06,-4.45927088d-06/
      data fpppp(11,23),fpppp(11,24)/-3.54061030d-06, 1.04529511d-06/
      data fpppp(11,25),fpppp(11,26)/ 6.07599052d-06, 3.76849875d-06/
      data fpppp(11,27),fpppp(11,28)/ 1.03119550d-06,-2.86557913d-06/
      data fpppp(11,29),fpppp(11,30)/-1.41848017d-06,-2.14941408d-06/
      data fpppp(11,31),fpppp(11,32)/ 1.05087236d-06, 3.21408694d-07/
      data fpppp(11,33),fpppp(11,34)/ 1.03432705d-06, 1.33866498d-06/
      data fpppp(11,35),fpppp(11,36)/ 1.42822648d-06, 4.60372458d-07/
      data fpppp(11,37),fpppp(11,38)/ 2.29150040d-07,-1.83133413d-06/
      data fpppp(11,39),fpppp(11,40)/-1.89501668d-06, 1.92629861d-07/
      data fpppp(11,41),fpppp(11,42)/ 4.46465333d-07, 1.22424683d-06/
      data fpppp(12, 1),fpppp(12, 2)/ 9.38926526d-07, 4.10992516d-07/
      data fpppp(12, 3),fpppp(12, 4)/-2.91689782d-07,-3.82753074d-07/
      data fpppp(12, 5),fpppp(12, 6)/-3.73271791d-07,-3.67913049d-07/
      data fpppp(12, 7),fpppp(12, 8)/ 5.84123122d-07, 2.33948874d-07/
      data fpppp(12, 9),fpppp(12,10)/ 3.17063056d-07, 6.54654172d-08/
      data fpppp(12,11),fpppp(12,12)/ 2.50002446d-07,-1.65967308d-07/
      data fpppp(12,13),fpppp(12,14)/-8.83318881d-07, 1.03150222d-06/
      data fpppp(12,15),fpppp(12,16)/-3.94057345d-07,-2.83550179d-07/
      data fpppp(12,17),fpppp(12,18)/ 4.33755123d-07,-5.66983078d-09/
      data fpppp(12,19),fpppp(12,20)/ 1.88203462d-08, 7.60247794d-07/
      data fpppp(12,21),fpppp(12,22)/-4.44205421d-07,-1.08933040d-06/
      data fpppp(12,23),fpppp(12,24)/-1.80925802d-07, 2.39957444d-07/
      data fpppp(12,25),fpppp(12,26)/ 8.28991462d-07, 1.36737406d-06/
      data fpppp(12,27),fpppp(12,28)/-3.64355099d-08,-1.10250362d-07/
      data fpppp(12,29),fpppp(12,30)/-1.70115883d-06, 1.25065270d-06/
      data fpppp(12,31),fpppp(12,32)/-9.05327999d-07, 1.58082525d-08/
      data fpppp(12,33),fpppp(12,34)/ 3.29150207d-07, 2.07902152d-07/
      data fpppp(12,35),fpppp(12,36)/ 2.74433419d-07, 5.88991105d-07/
      data fpppp(12,37),fpppp(12,38)/-3.39191030d-07,-3.70746670d-07/
      data fpppp(12,39),fpppp(12,40)/-3.85540376d-07,-3.18314338d-07/
      data fpppp(12,41),fpppp(12,42)/ 3.97996871d-07, 9.28855173d-07/
      data fpppp(13, 1),fpppp(13, 2)/-5.25379831d-07,-2.27364941d-07/
      data fpppp(13, 3),fpppp(13, 4)/ 2.99786002d-07, 2.49607592d-08/
      data fpppp(13, 5),fpppp(13, 6)/ 1.30744597d-08, 3.46850792d-07/
      data fpppp(13, 7),fpppp(13, 8)/-3.84059094d-07, 5.44316357d-08/
      data fpppp(13, 9),fpppp(13,10)/-8.01558848d-08, 7.71088340d-08/
      data fpppp(13,11),fpppp(13,12)/-3.12790909d-07, 2.47832391d-07/
      data fpppp(13,13),fpppp(13,14)/ 2.76358207d-07,-5.40151531d-07/
      data fpppp(13,15),fpppp(13,16)/ 1.44239461d-07, 2.95202622d-07/
      data fpppp(13,17),fpppp(13,18)/-3.10245152d-07, 8.79341046d-08/
      data fpppp(13,19),fpppp(13,20)/ 2.02722564d-08,-4.11381305d-07/
      data fpppp(13,21),fpppp(13,22)/ 3.00591746d-07, 3.01981618d-07/
      data fpppp(13,23),fpppp(13,24)/-3.28214795d-07,-2.56854654d-08/
      data fpppp(13,25),fpppp(13,26)/-3.80099875d-08,-1.53044639d-07/
      data fpppp(13,27),fpppp(13,28)/ 1.85441419d-07,-3.07716835d-07/
      data fpppp(13,29),fpppp(13,30)/ 7.71013862d-07,-7.25182759d-07/
      data fpppp(13,31),fpppp(13,32)/ 2.69977325d-07, 1.76084560d-07/
      data fpppp(13,33),fpppp(13,34)/-3.19898313d-07, 3.68840553d-08/
      data fpppp(13,35),fpppp(13,36)/ 3.11786618d-08,-3.76451172d-07/
      data fpppp(13,37),fpppp(13,38)/ 3.39572430d-07, 1.49012801d-08/
      data fpppp(13,39),fpppp(13,40)/ 2.33596823d-08, 3.05258412d-07/
      data fpppp(13,41),fpppp(13,42)/-2.27974799d-07,-5.28313169d-07/
      data fpppp(14, 1),fpppp(14, 2)/ 1.34364981d-07, 5.89228859d-08/
      data fpppp(14, 3),fpppp(14, 4)/-6.50489565d-08,-1.91666834d-08/
      data fpppp(14, 5),fpppp(14, 6)/-1.74985192d-08,-7.65018534d-08/
      data fpppp(14, 7),fpppp(14, 8)/ 9.26326643d-08, 2.58680024d-10/
      data fpppp(14, 9),fpppp(14,10)/ 2.73046844d-08,-1.18116535d-08/
      data fpppp(14,11),fpppp(14,12)/ 6.90605917d-08,-6.90489701d-08/
      data fpppp(14,13),fpppp(14,14)/-3.82664939d-08, 5.14008009d-08/
      data fpppp(14,15),fpppp(14,16)/-6.93556024d-09,-7.34169646d-08/
      data fpppp(14,17),fpppp(14,18)/ 8.08871632d-08,-1.05566577d-08/
      data fpppp(14,19),fpppp(14,20)/-4.61077293d-09, 9.65731015d-08/
      data fpppp(14,21),fpppp(14,22)/-4.76428591d-08,-1.05300021d-07/
      data fpppp(14,23),fpppp(14,24)/ 2.89712641d-08, 1.17432410d-08/
      data fpppp(14,25),fpppp(14,26)/ 7.50269152d-08, 1.01931969d-07/
      data fpppp(14,27),fpppp(14,28)/-1.68184917d-08, 4.29435299d-08/
      data fpppp(14,29),fpppp(14,30)/-1.63711614d-07, 7.85124745d-08/
      data fpppp(14,31),fpppp(14,32)/-4.85028568d-08,-5.78944162d-08/
      data fpppp(14,33),fpppp(14,34)/ 7.43562936d-08, 2.65655059d-09/
      data fpppp(14,35),fpppp(14,36)/ 7.55898367d-09, 9.28904489d-08/
      data fpppp(14,37),fpppp(14,38)/-7.41132107d-08,-1.68772296d-08/
      data fpppp(14,39),fpppp(14,40)/-1.98347534d-08,-6.70633556d-08/
      data fpppp(14,41),fpppp(14,42)/ 5.72149077d-08, 1.32491209d-07/
      data fpppp(15, 1),fpppp(15, 2)/ 3.43081035d-07, 1.48411507d-07/
      data fpppp(15, 3),fpppp(15, 4)/-2.60716563d-07, 8.07602687d-08/
      data fpppp(15, 5),fpppp(15, 6)/ 8.99211408d-08,-2.93105643d-07/
      data fpppp(15, 7),fpppp(15, 8)/ 2.76466635d-07,-1.27083210d-07/
      data fpppp(15, 9),fpppp(15,10)/ 2.95160070d-09,-1.08220361d-07/
      data fpppp(15,11),fpppp(15,12)/ 2.94541940d-07,-2.75738269d-07/
      data fpppp(15,13),fpppp(15,14)/ 3.18191711d-08, 1.43432943d-07/
      data fpppp(15,15),fpppp(15,16)/ 1.97841974d-08,-2.78047673d-07/
      data fpppp(15,17),fpppp(15,18)/ 2.50257478d-07,-8.76697505d-08/
      data fpppp(15,19),fpppp(15,20)/-3.22533539d-08, 2.41010776d-07/
      data fpppp(15,21),fpppp(15,22)/-1.68144851d-07,-5.49748128d-08/
      data fpppp(15,23),fpppp(15,24)/ 3.79281584d-07,-4.35370876d-08/
      data fpppp(15,25),fpppp(15,26)/-1.15725948d-07,-1.68321984d-07/
      data fpppp(15,27),fpppp(15,28)/-1.64275696d-07, 3.67416857d-07/
      data fpppp(15,29),fpppp(15,30)/-3.13263739d-07, 2.62169041d-07/
      data fpppp(15,31),fpppp(15,32)/ 2.29627177d-08,-2.63916085d-07/
      data fpppp(15,33),fpppp(15,34)/ 2.82170877d-07,-9.89753654d-08/
      data fpppp(15,35),fpppp(15,36)/-1.08618725d-07, 2.69408800d-07/
      data fpppp(15,37),fpppp(15,38)/-2.93005973d-07, 8.89206162d-08/
      data fpppp(15,39),fpppp(15,40)/ 8.15848041d-08,-2.59408317d-07/
      data fpppp(15,41),fpppp(15,42)/ 1.50013667d-07, 3.45031335d-07/
 
      data x( 1), x( 2) /  3.20000000d+00 ,  3.40000000d+00 /
      data x( 3), x( 4) /  3.60000000d+00 ,  3.80000000d+00 /
      data x( 5), x( 6) /  4.00000000d+00 ,  4.20000000d+00 /
      data x( 7), x( 8) /  4.50000000d+00 ,  5.00000000d+00 /
      data x( 9), x(10) /  5.50000000d+00 ,  6.00000000d+00 /
      data x(11), x(12) /  7.00000000d+00 ,  8.00000000d+00 /
      data x(13), x(14) /  1.00000000d+01 ,  1.20000000d+01 /
      data x(15) /         1.50000000d+01 /
 
      data y( 1), y( 2) / -2.20000000d+02 , -2.10000000d+02 /
      data y( 3), y( 4) / -2.00000000d+02 , -1.90000000d+02 /
      data y( 5), y( 6) / -1.70000000d+02 , -1.60000000d+02 /
      data y( 7), y( 8) / -1.50000000d+02 , -1.40000000d+02 /
      data y( 9), y(10) / -1.30000000d+02 , -1.20000000d+02 /
      data y(11), y(12) / -1.10000000d+02 , -1.00000000d+02 /
      data y(13), y(14) / -9.00000000d+01 , -8.00000000d+01 /
      data y(15), y(16) / -7.00000000d+01 , -6.00000000d+01 /
      data y(17), y(18) / -5.00000000d+01 , -4.00000000d+01 /
      data y(19), y(20) / -3.00000000d+01 , -2.00000000d+01 /
      data y(21), y(22) / -1.00000000d+01 ,  1.00000000d+01 /
      data y(23), y(24) /  2.00000000d+01 ,  3.00000000d+01 /
      data y(25), y(26) /  4.00000000d+01 ,  5.00000000d+01 /
      data y(27), y(28) /  6.00000000d+01 ,  7.00000000d+01 /
      data y(29), y(30) /  8.00000000d+01 ,  9.00000000d+01 /
      data y(31), y(32) /  1.00000000d+02 ,  1.10000000d+02 /
      data y(33), y(34) /  1.20000000d+02 ,  1.30000000d+02 /
      data y(35), y(36) /  1.40000000d+02 ,  1.50000000d+02 /
      data y(37), y(38) /  1.60000000d+02 ,  1.70000000d+02 /
      data y(39), y(40) /  1.90000000d+02 ,  2.00000000d+02 /
      data y(41), y(42) /  2.10000000d+02 ,  2.20000000d+02 /
 
      data delx( 1), delx( 2) /  2.00000000d-01 ,  2.00000000d-01 /
      data delx( 3), delx( 4) /  2.00000000d-01 ,  2.00000000d-01 /
      data delx( 5), delx( 6) /  2.00000000d-01 ,  3.00000000d-01 /
      data delx( 7), delx( 8) /  5.00000000d-01 ,  5.00000000d-01 /
      data delx( 9), delx(10) /  5.00000000d-01 ,  1.00000000d+00 /
      data delx(11), delx(12) /  1.00000000d+00 ,  2.00000000d+00 /
      data delx(13), delx(14) /  2.00000000d+00 ,  3.00000000d+00 /
      data dely( 1), dely( 2) /  1.00000000d+01 ,  1.00000000d+01 /
      data dely( 3), dely( 4) /  1.00000000d+01 ,  2.00000000d+01 /
      data dely( 5), dely( 6) /  1.00000000d+01 ,  1.00000000d+01 /
      data dely( 7), dely( 8) /  1.00000000d+01 ,  1.00000000d+01 /
      data dely( 9), dely(10) /  1.00000000d+01 ,  1.00000000d+01 /
      data dely(11), dely(12) /  1.00000000d+01 ,  1.00000000d+01 /
      data dely(13), dely(14) /  1.00000000d+01 ,  1.00000000d+01 /
      data dely(15), dely(16) /  1.00000000d+01 ,  1.00000000d+01 /
      data dely(17), dely(18) /  1.00000000d+01 ,  1.00000000d+01 /
      data dely(19), dely(20) /  1.00000000d+01 ,  1.00000000d+01 /
      data dely(21), dely(22) /  2.00000000d+01 ,  1.00000000d+01 /
      data dely(23), dely(24) /  1.00000000d+01 ,  1.00000000d+01 /
      data dely(25), dely(26) /  1.00000000d+01 ,  1.00000000d+01 /
      data dely(27), dely(28) /  1.00000000d+01 ,  1.00000000d+01 /
      data dely(29), dely(30) /  1.00000000d+01 ,  1.00000000d+01 /
      data dely(31), dely(32) /  1.00000000d+01 ,  1.00000000d+01 /
      data dely(33), dely(34) /  1.00000000d+01 ,  1.00000000d+01 /
      data dely(35), dely(36) /  1.00000000d+01 ,  1.00000000d+01 /
      data dely(37), dely(38) /  1.00000000d+01 ,  2.00000000d+01 /
      data dely(39), dely(40) /  1.00000000d+01 ,  1.00000000d+01 /
      data dely(41) /            1.00000000d+01 /
      data nptx,npty /  15 , 42 /

      if(xi .le. x(1)) then
        ix=1
      else if( xi .ge. x(nptx)) then
        ix=nptx-1
      else
        do 10 i=1,nptx
          if(xi .gt. x(i))go to 10
          ix=i-1
          go to 15
 10     continue
      endif
 15   xix=x(ix)
      xixp1=x(ix+1)
      delxi = delx(ix)
      if(iprint .gt. 2) then
        write(6,'(a,i3,a,2f10.5,a,1f10.5)') ' ix=',ix,
     x       '  xix,xixp1=',xix,xixp1,'  delxi=',delxi
      endif
c
      if(yi .le. y(1)) then
        iy=1
      else if( yi .ge. y(npty)) then
        iy=npty-1
      else
        do 20 i=1,npty
          if(yi .gt. y(i))go to 20
          iy=i-1
          go to 25
 20     continue
      endif
 25   yiy=y(iy)
      yiyp1=y(iy+1)
      delyi = dely(iy)
      if(iprint .gt. 2) then
        write(6,'(a,i3,a,2f10.5,a,1f10.5)') ' iy=',iy,
     x       '  yiy,yiyp1=',yiy,yiyp1,'  delyi=',delyi
      endif
c
   30 c(1,1)=fpppp(ix+1,iy+1)
      c(1,2)=fpppp(ix+1,iy  )
      c(2,1)=fpppp(ix  ,iy+1)
      c(2,2)=fpppp(ix,  iy  )
      c(1,3)=fpp(ix+1,iy+1,1)
      c(1,4)=fpp(ix+1,iy  ,1)
      c(2,3)=fpp(ix,  iy+1,1)
      c(2,4)=fpp(ix,  iy,  1)
      c(3,1)=fpp(ix+1,iy+1,2)
      c(3,2)=fpp(ix+1,iy  ,2)
      c(4,1)=fpp(ix,  iy+1,2)
      c(4,2)=fpp(ix,  iy,  2)
      c(3,3)=f(ix+1,iy+1)
      c(3,4)=f(ix+1,iy  )
      c(4,3)=f(ix,  iy+1)
      c(4,4)=f(ix,  iy  )
      px(1)=((xi-xix)**3/(6.0d0*delxi))-(xi-xix)*delxi/6.0d0
      px(2)=(xi-xixp1)*delxi/6.0d0-((xi-xixp1)**3/(6.0d0*delxi))
      px(3)=(xi-xix)/delxi
      px(4)=(xixp1-xi)/delxi
      py(1)=((yi-yiy)**3/(6.0d0*delyi))-(yi-yiy)*delyi/6.0d0
      py(2)=(yi-yiyp1)*delyi/6.0d0-((yi-yiyp1)**3/(6.0d0*delyi))
      py(3)=(yi-yiy)/delyi
      py(4)=(yiyp1-yi)/delyi

      fi=0.0d 00
      do l=1,4
        sum=0.0d 00
        do i=1,4
          sum=sum + c(i,l) * px(i)
        enddo
        fi = fi + sum * py(l)
      enddo
      return
      end
