
      real*8 function c2h3_h(r, rpar, ipar)

c
c
c  ***  coordinate system  ***
c
c             hd
c            /                     r(cha) = 2.05 au
c           /                      r(chb) = 2.05 au
c       ha /                       r(chc) = 2.05 au
c        \/                        r(cc)  = 2.50 au
c         ca==cb                   ha-c-c = 120.0 deg
c        /     \                   hb-c-c = 135.0 deg
c       hc      hb                 hc-c-c = 120.0 deg
c
c  ***   input   ***
c
c     rd :     r(c-hd) au
c     alpha :  hd-ca-cb angle  (degrees)
c     phi :    dihedral angle between (hd-ca-cb) and (ha-ca-cb)
c
c     ranges :     3.5 < rd < 12.0
c                  0 < alpha < 180
c                  phi arbitrary
c
c
c  ***   output   ***
c
c     energy - potential energy relative to h+c2h3 in au

      implicit double precision (a-h,o-z)


      parameter (nfrag=2, natommx=100, ndim = 3)

c      dimension dmsst(nfrag),dmss(nfrag,natommx)

      dimension r(nfrag,natommx,ndim)
c      dimension natom(nfrag)
      dimension r12(ndim),r23(ndim),r34(ndim),tmp1(ndim),tmp2(ndim)
      dimension r25(ndim),r35(ndim),rhp(ndim),r12p(ndim)

      include 'data.fi'

      pi2 = asin(1.0d0)
      pi = 2.0d0*pi2

c
c     read in the initial parameters
c

c      dmu12 = dmsst(1)*dmsst(2)/(dmsst(1)+dmsst(2))
c      dmu12p = dmsst(1)*(dmsst(1)+dmsst(2))/(2.0d0*dmsst(1)+dmsst(2))

  100 continue

c
c     for c2h3 + h -- just need to calculate r, theta, phi
c

      r122 = 0.0d0
      r232 = 0.0d0
      r342 = 0.0d0
      r252 = 0.0d0
      r352 = 0.0d0

      do 1100 idim = 1 , ndim

      r12(idim) = r(1,1,idim) - r(2,1,idim)
      r23(idim) = r(1,2,idim) - r(1,1,idim)
      r34(idim) = r(1,3,idim) - r(1,2,idim)
      r25(idim) = r(1,4,idim) - r(1,1,idim)
      r35(idim) = r(1,4,idim) - r(1,2,idim)
      r122 = r122 + r12(idim)**2
      r232 = r232 + r23(idim)**2
      r342 = r342 + r34(idim)**2
      r252 = r252 + r25(idim)**2
      r352 = r352 + r35(idim)**2

1100  continue

      rr = sqrt(r122)
      rmepi = rr
      rcc = sqrt(r232)
      r340 = sqrt(r342)
      ra = sqrt(r122)
      r250 = sqrt(r252)
      r350 = sqrt(r352)
c     ra = sqrt((r(1,3,1)-r(2,1,1))**2 + (r(1,3,2)-r(2,1,2))**2 + 
c    $ (r(1,3,3)-r(2,1,3))**2)
      rd = sqrt((r(2,1,1)-r(1,2,1))**2 + (r(2,1,2)-r(1,2,2))**2 + 
     $ (r(2,1,3)-r(1,2,3))**2)
      rp = sqrt((r(1,2,1)-r(2,1,1))**2 + (r(1,2,2)-r(2,1,2))**2 + 
     $ (r(1,2,3)-r(2,1,3))**2)
      rpp = sqrt((r(1,3,1)-r(1,1,1))**2 + (r(1,3,2)-r(1,1,2))**2 + 
     $ (r(1,3,3)-r(1,1,3))**2)

      cthe = (rr**2 + rcc**2 - rp**2)/(2.0d0*rr*rcc)
      cthep = (r342 + rcc**2 - rpp**2)/(2.0d0*r340*rcc)
      calp = (rd**2 + r232 - ra**2)/(2.0d0*rd*rcc)
      if (abs(cthe).gt.1.0d0) then
		write (7,*) 'error in cthe',cthe
	    if (cthe.gt.1.0d0) then 
			the = 0.0d0
		else
			the = pi
		endif
	else
	    the = acos(cthe)
	endif
      if (abs(cthep).gt.1.0d0) then
		write (7,*) 'error in cthep',cthep
	    if (cthep.gt.1.0d0) then 
			thep = 0.0d0
		else
			thep = pi
		endif
	else
	    thep = acos(cthep)
	endif
      if (abs(calp).gt.1.0d0) then
		write (7,*) 'error in calp',calp
	    if (calp.gt.1.0d0) then 
			alpha = 0.0d0
		else
			alpha = pi
		endif
	else
		alpha = acos(calp)
	endif
      call cross(r12,r23,tmp1)
      call cross(r23,r34,tmp2)
      tdot = 0.0d0
      do 1200 idim = 1 , ndim
      tdot = tdot + tmp1(idim)*tmp2(idim)
1200  continue
      rdenom = r232*sqrt(r122*r342)
c      ctau = tdot/(rdenom*sin(acos(cthe))*sin(acos(cthep)))
      ctau = tdot/(rdenom*sin(the)*sin(thep))
      if (abs(ctau).gt.1.0d0) then 
	   write (6,*) 'error in ctau',ctau
         if (ctau.gt.1.0d0) then
	      tau = 0.0d0
	   else
	      tau = pi
	   endif
	else
         tau = acos(ctau)
	endif
c     if (abs(tau).gt.pi2) alpha = -alpha 
      if (rd.lt.3.5) then
        c2h3_h = 10.
        return
      endif
              
      if (rd.gt.12.0) rd = 11.9999
      alpha = alpha*180.0d0/pi
      phi = tau*180.0d0/pi
      call spl_c2h4(rd,alpha,phi,energy)
      c2h3_h = energy


      return
      end


      subroutine spl_c2h4(rd,alpha,phi,energy)
      implicit real*8 (a-h,o-z)
c
c     (2e,2o)-cas+1+2+q2/cc-pvdz potential
c
      data ezero  / -1.17206474d 00 /
      data degrad / 57.29577951308232d 00 /
c
c     find location in spline grids
c
      call fnd_grd(rd,alpha,ix,iy,delxi,delyi,xix,xixp1,yiy,yiyp1)
c
      call c0_spl(rd,alpha,ix,iy,delxi,delyi,xix,xixp1,yiy,yiyp1,c0)
      call c1_spl(rd,alpha,ix,iy,delxi,delyi,xix,xixp1,yiy,yiyp1,c1)
      call c2_spl(rd,alpha,ix,iy,delxi,delyi,xix,xixp1,yiy,yiyp1,c2)
      call c3_spl(rd,alpha,ix,iy,delxi,delyi,xix,xixp1,yiy,yiyp1,c3)
      call c4_spl(rd,alpha,ix,iy,delxi,delyi,xix,xixp1,yiy,yiyp1,c4)
      call c5_spl(rd,alpha,ix,iy,delxi,delyi,xix,xixp1,yiy,yiyp1,c5)
      call c6_spl(rd,alpha,ix,iy,delxi,delyi,xix,xixp1,yiy,yiyp1,c6)
      call c7_spl(rd,alpha,ix,iy,delxi,delyi,xix,xixp1,yiy,yiyp1,c7)
      call c8_spl(rd,alpha,ix,iy,delxi,delyi,xix,xixp1,yiy,yiyp1,c8)
      call c9_spl(rd,alpha,ix,iy,delxi,delyi,xix,xixp1,yiy,yiyp1,c9)
      call c10_spl(rd,alpha,ix,iy,delxi,delyi,xix,xixp1,yiy,yiyp1,c10)
      call c11_spl(rd,alpha,ix,iy,delxi,delyi,xix,xixp1,yiy,yiyp1,c11)
      call c12_spl(rd,alpha,ix,iy,delxi,delyi,xix,xixp1,yiy,yiyp1,c12)
c
      p = phi / degrad
      energy = c0 + c1*cos(p) +         c2*cos(2.0d0* p) +
     x              c3*cos(3.0d0* p) +  c4*cos(4.0d0* p) +
     x              c5*cos(5.0d0* p) +  c6*cos(6.0d0* p) +
     x              c7*cos(7.0d0* p) +  c8*cos(8.0d0* p) +
     x              c9*cos(9.0d0* p) + c10*cos(10.0d0*p) +
     x             c11*cos(11.0d0*p) + c12*cos(12.0d0*p) - ezero

      return
      end
      subroutine fnd_grd(xi,yi,ix,iy,delxi,delyi,xix,xixp1,yiy,yiyp1)
      implicit real*8 (a-h,o-z)
      dimension delx(27),dely(22),x(28),y(23)
      data x( 1), x( 2) /  3.50000000d+00 ,  3.60000000d+00 /
      data x( 3), x( 4) /  3.70000000d+00 ,  3.80000000d+00 /
      data x( 5), x( 6) /  3.90000000d+00 ,  4.00000000d+00 /
      data x( 7), x( 8) /  4.20000000d+00 ,  4.40000000d+00 /
      data x( 9), x(10) /  4.60000000d+00 ,  4.80000000d+00 /
      data x(11), x(12) /  5.00000000d+00 ,  5.20000000d+00 /
      data x(13), x(14) /  5.50000000d+00 ,  5.80000000d+00 /
      data x(15), x(16) /  6.00000000d+00 ,  6.20000000d+00 /
      data x(17), x(18) /  6.50000000d+00 ,  6.80000000d+00 /
      data x(19), x(20) /  7.00000000d+00 ,  7.20000000d+00 /
      data x(21), x(22) /  7.50000000d+00 ,  8.00000000d+00 /
      data x(23), x(24) /  8.50000000d+00 ,  9.00000000d+00 /
      data x(25), x(26) /  9.50000000d+00 ,  1.00000000d+01 /
      data x(27), x(28) /  1.10000000d+01 ,  1.20000000d+01 /
 
      data y( 1), y( 2) /  0.00000000d+00 ,  5.00000000d+00 /
      data y( 3), y( 4) /  1.00000000d+01 ,  1.50000000d+01 /
      data y( 5), y( 6) /  2.00000000d+01 ,  2.50000000d+01 /
      data y( 7), y( 8) /  3.00000000d+01 ,  3.50000000d+01 /
      data y( 9), y(10) /  4.00000000d+01 ,  5.00000000d+01 /
      data y(11), y(12) /  6.00000000d+01 ,  7.00000000d+01 /
      data y(13), y(14) /  8.00000000d+01 ,  9.00000000d+01 /
      data y(15), y(16) /  1.00000000d+02 ,  1.10000000d+02 /
      data y(17), y(18) /  1.20000000d+02 ,  1.30000000d+02 /
      data y(19), y(20) /  1.40000000d+02 ,  1.50000000d+02 /
      data y(21), y(22) /  1.60000000d+02 ,  1.70000000d+02 /
      data y(23) /         1.80000000d+02 /
 
      data delx( 1), delx( 2) /  1.00000000d-01 ,  1.00000000d-01 /
      data delx( 3), delx( 4) /  1.00000000d-01 ,  1.00000000d-01 /
      data delx( 5), delx( 6) /  1.00000000d-01 ,  2.00000000d-01 /
      data delx( 7), delx( 8) /  2.00000000d-01 ,  2.00000000d-01 /
      data delx( 9), delx(10) /  2.00000000d-01 ,  2.00000000d-01 /
      data delx(11), delx(12) /  2.00000000d-01 ,  3.00000000d-01 /
      data delx(13), delx(14) /  3.00000000d-01 ,  2.00000000d-01 /
      data delx(15), delx(16) /  2.00000000d-01 ,  3.00000000d-01 /
      data delx(17), delx(18) /  3.00000000d-01 ,  2.00000000d-01 /
      data delx(19), delx(20) /  2.00000000d-01 ,  3.00000000d-01 /
      data delx(21), delx(22) /  5.00000000d-01 ,  5.00000000d-01 /
      data delx(23), delx(24) /  5.00000000d-01 ,  5.00000000d-01 /
      data delx(25), delx(26) /  5.00000000d-01 ,  1.00000000d+00 /
      data delx(27) /            1.00000000d+00 /
      data dely( 1), dely( 2) /  5.00000000d+00 ,  5.00000000d+00 /
      data dely( 3), dely( 4) /  5.00000000d+00 ,  5.00000000d+00 /
      data dely( 5), dely( 6) /  5.00000000d+00 ,  5.00000000d+00 /
      data dely( 7), dely( 8) /  5.00000000d+00 ,  5.00000000d+00 /
      data dely( 9), dely(10) /  1.00000000d+01 ,  1.00000000d+01 /
      data dely(11), dely(12) /  1.00000000d+01 ,  1.00000000d+01 /
      data dely(13), dely(14) /  1.00000000d+01 ,  1.00000000d+01 /
      data dely(15), dely(16) /  1.00000000d+01 ,  1.00000000d+01 /
      data dely(17), dely(18) /  1.00000000d+01 ,  1.00000000d+01 /
      data dely(19), dely(20) /  1.00000000d+01 ,  1.00000000d+01 /
      data dely(21), dely(22) /  1.00000000d+01 ,  1.00000000d+01 /
 
      data nptx,npty /  28 , 23 /

      iprint = 0

      if(xi .le. x(1)) then
        ix=1
      else if( xi .ge. x(nptx)) then
        ix=nptx-1
      else
        do 10 i=1,nptx
          if(xi .gt. x(i))go to 10
          ix=i-1
          go to 15
 10     continue
      endif
 15   xix=x(ix)
      xixp1=x(ix+1)
      delxi = delx(ix)
      if(iprint .gt. 2) then
        write(6,'(a,i3,a,2f10.5,a,1f10.5)') ' ix=',ix,
     x       '  xix,xixp1=',xix,xixp1,'  delxi=',delxi
      endif
c
      if(yi .le. y(1)) then
        iy=1
      else if( yi .ge. y(npty)) then
        iy=npty-1
      else
        do 20 i=1,npty
          if(yi .gt. y(i))go to 20
          iy=i-1
          go to 25
 20     continue
      endif
 25   yiy=y(iy)
      yiyp1=y(iy+1)
      delyi = dely(iy)
      if(iprint .gt. 2) then
        write(6,'(a,i3,a,2f10.5,a,1f10.5)') ' iy=',iy,
     x       '  yiy,yiyp1=',yiy,yiyp1,'  delyi=',delyi
      endif
c
      return
      end  
      subroutine c0_spl(xi,yi,ix,iy,delxi,delyi,xix,xixp1,
     x                    yiy,yiyp1,fi)
      implicit real*8 (a-h,o-z)
      dimension fpp(28,23,2),f(28,23),fpppp(28,23)
      dimension c(4,4),px(4),py(4)
 
      data f( 1, 1),f( 1, 2) / -3.88779460d-01 , -4.70918110d-01 /
      data f( 1, 3),f( 1, 4) / -6.58867720d-01 , -8.55652400d-01 /
      data f( 1, 5),f( 1, 6) / -1.01058788d+00 , -1.12609340d+00 /
      data f( 1, 7),f( 1, 8) / -1.19727885d+00 , -1.23001649d+00 /
      data f( 1, 9),f( 1,10) / -1.23663176d+00 , -1.21611960d+00 /
      data f( 1,11),f( 1,12) / -1.18488538d+00 , -1.16001628d+00 /
      data f( 1,13),f( 1,14) / -1.14561533d+00 , -1.14263455d+00 /
      data f( 1,15),f( 1,16) / -1.14603106d+00 , -1.14956912d+00 /
      data f( 1,17),f( 1,18) / -1.15150910d+00 , -1.15263081d+00 /
      data f( 1,19),f( 1,20) / -1.15216472d+00 , -1.14980160d+00 /
      data f( 1,21),f( 1,22) / -1.14699817d+00 , -1.14507168d+00 /
      data f( 1,23) /          -1.14442138d+00 /
      data f( 2, 1),f( 2, 2) / -6.21154380d-01 , -6.75270020d-01 /
      data f( 2, 3),f( 2, 4) / -7.99851950d-01 , -9.30392250d-01 /
      data f( 2, 5),f( 2, 6) / -1.04007117d+00 , -1.13835087d+00 /
      data f( 2, 7),f( 2, 8) / -1.20290514d+00 , -1.23126743d+00 /
      data f( 2, 9),f( 2,10) / -1.23599954d+00 , -1.21440043d+00 /
      data f( 2,11),f( 2,12) / -1.18457616d+00 , -1.16144793d+00 /
      data f( 2,13),f( 2,14) / -1.14869870d+00 , -1.14610862d+00 /
      data f( 2,15),f( 2,16) / -1.14913497d+00 , -1.15263233d+00 /
      data f( 2,17),f( 2,18) / -1.15473275d+00 , -1.15563982d+00 /
      data f( 2,19),f( 2,20) / -1.15491920d+00 , -1.15267041d+00 /
      data f( 2,21),f( 2,22) / -1.15018058d+00 , -1.14849996d+00 /
      data f( 2,23) /          -1.14793451d+00 /
      data f( 3, 1),f( 3, 2) / -7.89069740d-01 , -8.24097270d-01 /
      data f( 3, 3),f( 3, 4) / -9.03377130d-01 , -9.81408490d-01 /
      data f( 3, 5),f( 3, 6) / -1.05255173d+00 , -1.14227482d+00 /
      data f( 3, 7),f( 3, 8) / -1.20495073d+00 , -1.23129541d+00 /
      data f( 3, 9),f( 3,10) / -1.23445391d+00 , -1.21249779d+00 /
      data f( 3,11),f( 3,12) / -1.18429065d+00 , -1.16286622d+00 /
      data f( 3,13),f( 3,14) / -1.15150614d+00 , -1.14920411d+00 /
      data f( 3,15),f( 3,16) / -1.15187558d+00 , -1.15521168d+00 /
      data f( 3,17),f( 3,18) / -1.15734107d+00 , -1.15809814d+00 /
      data f( 3,19),f( 3,20) / -1.15726425d+00 , -1.15517822d+00 /
      data f( 3,21),f( 3,22) / -1.15297939d+00 , -1.15151493d+00 /
      data f( 3,23) /          -1.15102328d+00 /
      data f( 4, 1),f( 4, 2) / -9.10454270d-01 , -9.32254580d-01 /
      data f( 4, 3),f( 4, 4) / -9.78542570d-01 , -1.01293395d+00 /
      data f( 4, 5),f( 4, 6) / -1.04948159d+00 , -1.13861712d+00 /
      data f( 4, 7),f( 4, 8) / -1.20479366d+00 , -1.23012809d+00 /
      data f( 4, 9),f( 4,10) / -1.23232682d+00 , -1.21005289d+00 /
      data f( 4,11),f( 4,12) / -1.18387745d+00 , -1.16419076d+00 /
      data f( 4,13),f( 4,14) / -1.15403223d+00 , -1.15195675d+00 /
      data f( 4,15),f( 4,16) / -1.15429278d+00 , -1.15739603d+00 /
      data f( 4,17),f( 4,18) / -1.15946571d+00 , -1.16012147d+00 /
      data f( 4,19),f( 4,20) / -1.15926486d+00 , -1.15736890d+00 /
      data f( 4,21),f( 4,22) / -1.15543842d+00 , -1.15416481d+00 /
      data f( 4,23) /          -1.15373758d+00 /
      data f( 5, 1),f( 5, 2) / -9.98020640d-01 , -1.01057994d+00 /
      data f( 5, 3),f( 5, 4) / -1.03258183d+00 , -1.02934160d+00 /
      data f( 5, 5),f( 5, 6) / -1.04391402d+00 , -1.12983112d+00 /
      data f( 5, 7),f( 5, 8) / -1.20279785d+00 , -1.22790004d+00 /
      data f( 5, 9),f( 5,10) / -1.22954738d+00 , -1.20810252d+00 /
      data f( 5,11),f( 5,12) / -1.18341551d+00 , -1.16538877d+00 /
      data f( 5,13),f( 5,14) / -1.15628940d+00 , -1.15440154d+00 /
      data f( 5,15),f( 5,16) / -1.15642567d+00 , -1.15926136d+00 /
      data f( 5,17),f( 5,18) / -1.16121838d+00 , -1.16179985d+00 /
      data f( 5,19),f( 5,20) / -1.16097713d+00 , -1.15928252d+00 /
      data f( 5,21),f( 5,22) / -1.15759788d+00 , -1.15649300d+00 /
      data f( 5,23) /          -1.15612233d+00 /
      data f( 6, 1),f( 6, 2) / -1.06086267d+00 , -1.06699546d+00 /
      data f( 6, 3),f( 6, 4) / -1.07151624d+00 , -1.03643801d+00 /
      data f( 6, 5),f( 6, 6) / -1.04280821d+00 , -1.11943651d+00 /
      data f( 6, 7),f( 6, 8) / -1.19988208d+00 , -1.22505517d+00 /
      data f( 6, 9),f( 6,10) / -1.22642112d+00 , -1.20602511d+00 /
      data f( 6,11),f( 6,12) / -1.18290944d+00 , -1.16645178d+00 /
      data f( 6,13),f( 6,14) / -1.15829646d+00 , -1.15657103d+00 /
      data f( 6,15),f( 6,16) / -1.15831038d+00 , -1.16086495d+00 /
      data f( 6,17),f( 6,18) / -1.16267973d+00 , -1.16320391d+00 /
      data f( 6,19),f( 6,20) / -1.16244842d+00 , -1.16095497d+00 /
      data f( 6,21),f( 6,22) / -1.15949363d+00 , -1.15853819d+00 /
      data f( 6,23) /          -1.15821735d+00 /
      data f( 7, 1),f( 7, 2) / -1.13676349d+00 , -1.13577869d+00 /
      data f( 7, 3),f( 7, 4) / -1.12086776d+00 , -1.05445188d+00 /
      data f( 7, 5),f( 7, 6) / -1.04717486d+00 , -1.11344675d+00 /
      data f( 7, 7),f( 7, 8) / -1.19401834d+00 , -1.21815923d+00 /
      data f( 7, 9),f( 7,10) / -1.21943161d+00 , -1.20165985d+00 /
      data f( 7,11),f( 7,12) / -1.18179590d+00 , -1.16819262d+00 /
      data f( 7,13),f( 7,14) / -1.16164801d+00 , -1.16019872d+00 /
      data f( 7,15),f( 7,16) / -1.16145518d+00 , -1.16346210d+00 /
      data f( 7,17),f( 7,18) / -1.16495938d+00 , -1.16539959d+00 /
      data f( 7,19),f( 7,20) / -1.16481841d+00 , -1.16369817d+00 /
      data f( 7,21),f( 7,22) / -1.16261761d+00 , -1.16191144d+00 /
      data f( 7,23) /          -1.16167341d+00 /
      data f( 8, 1),f( 8, 2) / -1.17214648d+00 , -1.16851004d+00 /
      data f( 8, 3),f( 8, 4) / -1.14910339d+00 , -1.08524987d+00 /
      data f( 8, 5),f( 8, 6) / -1.05948318d+00 , -1.12311209d+00 /
      data f( 8, 7),f( 8, 8) / -1.19112542d+00 , -1.21206323d+00 /
      data f( 8, 9),f( 8,10) / -1.21264368d+00 , -1.19735753d+00 /
      data f( 8,11),f( 8,12) / -1.18061402d+00 , -1.16948945d+00 /
      data f( 8,13),f( 8,14) / -1.16425619d+00 , -1.16304114d+00 /
      data f( 8,15),f( 8,16) / -1.16392615d+00 , -1.16545585d+00 /
      data f( 8,17),f( 8,18) / -1.16664599d+00 , -1.16702148d+00 /
      data f( 8,19),f( 8,20) / -1.16661138d+00 , -1.16580153d+00 /
      data f( 8,21),f( 8,22) / -1.16502018d+00 , -1.16450779d+00 /
      data f( 8,23) /          -1.16433422d+00 /
      data f( 9, 1),f( 9, 2) / -1.18466061d+00 , -1.18096124d+00 /
      data f( 9, 3),f( 9, 4) / -1.16480628d+00 , -1.12489865d+00 /
      data f( 9, 5),f( 9, 6) / -1.09677040d+00 , -1.14678951d+00 /
      data f( 9, 7),f( 9, 8) / -1.19131408d+00 , -1.20624575d+00 /
      data f( 9, 9),f( 9,10) / -1.20639801d+00 , -1.19333488d+00 /
      data f( 9,11),f( 9,12) / -1.17943677d+00 , -1.17043384d+00 /
      data f( 9,13),f( 9,14) / -1.16626934d+00 , -1.16525721d+00 /
      data f( 9,15),f( 9,16) / -1.16586917d+00 , -1.16701285d+00 /
      data f( 9,17),f( 9,18) / -1.16793666d+00 , -1.16825491d+00 /
      data f( 9,19),f( 9,20) / -1.16798373d+00 , -1.16741475d+00 /
      data f( 9,21),f( 9,22) / -1.16686131d+00 , -1.16649669d+00 /
      data f( 9,23) /          -1.16637277d+00 /
      data f(10, 1),f(10, 2) / -1.18489749d+00 , -1.18195108d+00 /
      data f(10, 3),f(10, 4) / -1.17089021d+00 , -1.15011504d+00 /
      data f(10, 5),f(10, 6) / -1.13894863d+00 , -1.16444158d+00 /
      data f(10, 7),f(10, 8) / -1.19098989d+00 , -1.20098419d+00 /
      data f(10, 9),f(10,10) / -1.20065843d+00 , -1.18969806d+00 /
      data f(10,11),f(10,12) / -1.17831930d+00 , -1.17110712d+00 /
      data f(10,13),f(10,14) / -1.16781066d+00 , -1.16697539d+00 /
      data f(10,15),f(10,16) / -1.16739231d+00 , -1.16823775d+00 /
      data f(10,17),f(10,18) / -1.16894381d+00 , -1.16920934d+00 /
      data f(10,19),f(10,20) / -1.16903973d+00 , -1.16864871d+00 /
      data f(10,21),f(10,22) / -1.16826338d+00 , -1.16800874d+00 /
      data f(10,23) /          -1.16792216d+00 /
      data f(11, 1),f(11, 2) / -1.17901808d+00 , -1.17683324d+00 /
      data f(11, 3),f(11, 4) / -1.16982974d+00 , -1.16025565d+00 /
      data f(11, 5),f(11, 6) / -1.15769884d+00 , -1.17355573d+00 /
      data f(11, 7),f(11, 8) / -1.18980368d+00 , -1.19621772d+00 /
      data f(11, 9),f(11,10) / -1.19555497d+00 , -1.18649194d+00 /
      data f(11,11),f(11,12) / -1.17729834d+00 , -1.17157623d+00 /
      data f(11,13),f(11,14) / -1.16898099d+00 , -1.16829842d+00 /
      data f(11,15),f(11,16) / -1.16857939d+00 , -1.16920045d+00 /
      data f(11,17),f(11,18) / -1.16973481d+00 , -1.16995233d+00 /
      data f(11,19),f(11,20) / -1.16985194d+00 , -1.16958726d+00 /
      data f(11,21),f(11,22) / -1.16932208d+00 , -1.16914679d+00 /
      data f(11,23) /          -1.16908738d+00 /
      data f(12, 1),f(12, 2) / -1.17121853d+00 , -1.16949936d+00 /
      data f(12, 3),f(12, 4) / -1.16457373d+00 , -1.16069493d+00 /
      data f(12, 5),f(12, 6) / -1.16521588d+00 , -1.17735929d+00 /
      data f(12, 7),f(12, 8) / -1.18781633d+00 , -1.19191643d+00 /
      data f(12, 9),f(12,10) / -1.19110327d+00 , -1.18372542d+00 /
      data f(12,11),f(12,12) / -1.17639302d+00 , -1.17189448d+00 /
      data f(12,13),f(12,14) / -1.16986200d+00 , -1.16930925d+00 /
      data f(12,15),f(12,16) / -1.16949763d+00 , -1.16995222d+00 /
      data f(12,17),f(12,18) / -1.17035411d+00 , -1.17052923d+00 /
      data f(12,19),f(12,20) / -1.17047309d+00 , -1.17029520d+00 /
      data f(12,21),f(12,22) / -1.17011347d+00 , -1.16999350d+00 /
      data f(12,23) /          -1.16995309d+00 /
      data f(13, 1),f(13, 2) / -1.16197504d+00 , -1.16086832d+00 /
      data f(13, 3),f(13, 4) / -1.15826337d+00 , -1.16116351d+00 /
      data f(13, 5),f(13, 6) / -1.16945457d+00 , -1.17806334d+00 /
      data f(13, 7),f(13, 8) / -1.18413536d+00 , -1.18636796d+00 /
      data f(13, 9),f(13,10) / -1.18560585d+00 , -1.18036672d+00 /
      data f(13,11),f(13,12) / -1.17526580d+00 , -1.17217742d+00 /
      data f(13,13),f(13,14) / -1.17078053d+00 , -1.17038372d+00 /
      data f(13,15),f(13,16) / -1.17048542d+00 , -1.17077061d+00 /
      data f(13,17),f(13,18) / -1.17103100d+00 , -1.17115368d+00 /
      data f(13,19),f(13,20) / -1.17113274d+00 , -1.17103386d+00 /
      data f(13,21),f(13,22) / -1.17092933d+00 , -1.17086014d+00 /
      data f(13,23) /          -1.17083687d+00 /
      data f(14, 1),f(14, 2) / -1.15872697d+00 , -1.15859521d+00 /
      data f(14, 3),f(14, 4) / -1.15942600d+00 , -1.16384627d+00 /
      data f(14, 5),f(14, 6) / -1.17055085d+00 , -1.17665125d+00 /
      data f(14, 7),f(14, 8) / -1.18057601d+00 , -1.18196387d+00 /
      data f(14, 9),f(14,10) / -1.18142035d+00 , -1.17785967d+00 /
      data f(14,11),f(14,12) / -1.17440167d+00 , -1.17231135d+00 /
      data f(14,13),f(14,14) / -1.17135841d+00 , -1.17107699d+00 /
      data f(14,15),f(14,16) / -1.17113138d+00 , -1.17131084d+00 /
      data f(14,17),f(14,18) / -1.17147882d+00 , -1.17156204d+00 /
      data f(14,19),f(14,20) / -1.17155499d+00 , -1.17149737d+00 /
      data f(14,21),f(14,22) / -1.17143417d+00 , -1.17139146d+00 /
      data f(14,23) /          -1.17137722d+00 /
      data f(15, 1),f(15, 2) / -1.15910674d+00 , -1.15940757d+00 /
      data f(15, 3),f(15, 4) / -1.16108703d+00 , -1.16522849d+00 /
      data f(15, 5),f(15, 6) / -1.17071000d+00 , -1.17553237d+00 /
      data f(15, 7),f(15, 8) / -1.17857137d+00 , -1.17966027d+00 /
      data f(15, 9),f(15,10) / -1.17927751d+00 , -1.17658994d+00 /
      data f(15,11),f(15,12) / -1.17395301d+00 , -1.17235011d+00 /
      data f(15,13),f(15,14) / -1.17161285d+00 , -1.17139020d+00 /
      data f(15,15),f(15,16) / -1.17142575d+00 , -1.17155791d+00 /
      data f(15,17),f(15,18) / -1.17168310d+00 , -1.17174623d+00 /
      data f(15,19),f(15,20) / -1.17174249d+00 , -1.17170053d+00 /
      data f(15,21),f(15,22) / -1.17165335d+00 , -1.17162073d+00 /
      data f(15,23) /          -1.17160968d+00 /
      data f(16, 1),f(16, 2) / -1.16048563d+00 , -1.16097207d+00 /
      data f(16, 3),f(16, 4) / -1.16282136d+00 , -1.16638270d+00 /
      data f(16, 5),f(16, 6) / -1.17075956d+00 , -1.17454950d+00 /
      data f(16, 7),f(16, 8) / -1.17693489d+00 , -1.17782289d+00 /
      data f(16, 9),f(16,10) / -1.17758045d+00 , -1.17558620d+00 /
      data f(16,11),f(16,12) / -1.17359003d+00 , -1.17236306d+00 /
      data f(16,13),f(16,14) / -1.17179261d+00 , -1.17161697d+00 /
      data f(16,15),f(16,16) / -1.17164012d+00 , -1.17173767d+00 /
      data f(16,17),f(16,18) / -1.17183078d+00 , -1.17187800d+00 /
      data f(16,19),f(16,20) / -1.17187524d+00 , -1.17184327d+00 /
      data f(16,21),f(16,22) / -1.17180668d+00 , -1.17178087d+00 /
      data f(16,23) /          -1.17177195d+00 /
      data f(17, 1),f(17, 2) / -1.16313846d+00 , -1.16363757d+00 /
      data f(17, 3),f(17, 4) / -1.16522600d+00 , -1.16784266d+00 /
      data f(17, 5),f(17, 6) / -1.17087137d+00 , -1.17347538d+00 /
      data f(17, 7),f(17, 8) / -1.17514222d+00 , -1.17581288d+00 /
      data f(17, 9),f(17,10) / -1.17572109d+00 , -1.17447838d+00 /
      data f(17,11),f(17,12) / -1.17317373d+00 , -1.17235231d+00 /
      data f(17,13),f(17,14) / -1.17196344d+00 , -1.17184078d+00 /
      data f(17,15),f(17,16) / -1.17185256d+00 , -1.17191468d+00 /
      data f(17,17),f(17,18) / -1.17197421d+00 , -1.17200388d+00 /
      data f(17,19),f(17,20) / -1.17200064d+00 , -1.17197769d+00 /
      data f(17,21),f(17,22) / -1.17195119d+00 , -1.17193211d+00 /
      data f(17,23) /          -1.17192542d+00 /
      data f(18, 1),f(18, 2) / -1.16564338d+00 , -1.16604170d+00 /
      data f(18, 3),f(18, 4) / -1.16722626d+00 , -1.16904621d+00 /
      data f(18, 5),f(18, 6) / -1.17108703d+00 , -1.17284345d+00 /
      data f(18, 7),f(18, 8) / -1.17399508d+00 , -1.17449553d+00 /
      data f(18, 9),f(18,10) / -1.17448629d+00 , -1.17372533d+00 /
      data f(18,11),f(18,12) / -1.17287425d+00 , -1.17232244d+00 /
      data f(18,13),f(18,14) / -1.17205640d+00 , -1.17197066d+00 /
      data f(18,15),f(18,16) / -1.17197627d+00 , -1.17201567d+00 /
      data f(18,17),f(18,18) / -1.17205356d+00 , -1.17207156d+00 /
      data f(18,19),f(18,20) / -1.17206742d+00 , -1.17204980d+00 /
      data f(18,21),f(18,22) / -1.17202978d+00 , -1.17201531d+00 /
      data f(18,23) /          -1.17201015d+00 /
      data f(19, 1),f(19, 2) / -1.16705255d+00 , -1.16737508d+00 /
      data f(19, 3),f(19, 4) / -1.16831149d+00 , -1.16971233d+00 /
      data f(19, 5),f(19, 6) / -1.17126269d+00 , -1.17259997d+00 /
      data f(19, 7),f(19, 8) / -1.17349074d+00 , -1.17389540d+00 /
      data f(19, 9),f(19,10) / -1.17391296d+00 , -1.17336492d+00 /
      data f(19,11),f(19,12) / -1.17272255d+00 , -1.17229795d+00 /
      data f(19,13),f(19,14) / -1.17209104d+00 , -1.17202330d+00 /
      data f(19,15),f(19,16) / -1.17202625d+00 , -1.17205531d+00 /
      data f(19,17),f(19,18) / -1.17208320d+00 , -1.17209580d+00 /
      data f(19,19),f(19,20) / -1.17209127d+00 , -1.17207633d+00 /
      data f(19,21),f(19,22) / -1.17205955d+00 , -1.17204745d+00 /
      data f(19,23) /          -1.17204313d+00 /
      data f(20, 1),f(20, 2) / -1.16822792d+00 , -1.16848162d+00 /
      data f(20, 3),f(20, 4) / -1.16920673d+00 , -1.17027197d+00 /
      data f(20, 5),f(20, 6) / -1.17144017d+00 , -1.17245054d+00 /
      data f(20, 7),f(20, 8) / -1.17313338d+00 , -1.17345526d+00 /
      data f(20, 9),f(20,10) / -1.17348436d+00 , -1.17308709d+00 /
      data f(20,11),f(20,12) / -1.17260006d+00 , -1.17227254d+00 /
      data f(20,13),f(20,14) / -1.17211135d+00 , -1.17205773d+00 /
      data f(20,15),f(20,16) / -1.17205870d+00 , -1.17208006d+00 /
      data f(20,17),f(20,18) / -1.17210055d+00 , -1.17210920d+00 /
      data f(20,19),f(20,20) / -1.17210455d+00 , -1.17209183d+00 /
      data f(20,21),f(20,22) / -1.17207783d+00 , -1.17206770d+00 /
      data f(20,23) /          -1.17206410d+00 /
      data f(21, 1),f(21, 2) / -1.16958252d+00 , -1.16975296d+00 /
      data f(21, 3),f(21, 4) / -1.17023296d+00 , -1.17092599d+00 /
      data f(21, 5),f(21, 6) / -1.17167950d+00 , -1.17233413d+00 /
      data f(21, 7),f(21, 8) / -1.17278451d+00 , -1.17300535d+00 /
      data f(21, 9),f(21,10) / -1.17303510d+00 , -1.17278366d+00 /
      data f(21,11),f(21,12) / -1.17245883d+00 , -1.17223576d+00 /
      data f(21,13),f(21,14) / -1.17212443d+00 , -1.17208612d+00 /
      data f(21,15),f(21,16) / -1.17208547d+00 , -1.17209885d+00 /
      data f(21,17),f(21,18) / -1.17211172d+00 , -1.17211648d+00 /
      data f(21,19),f(21,20) / -1.17211208d+00 , -1.17210218d+00 /
      data f(21,21),f(21,22) / -1.17209158d+00 , -1.17208394d+00 /
      data f(21,23) /          -1.17208121d+00 /
      data f(22, 1),f(22, 2) / -1.17097498d+00 , -1.17105657d+00 /
      data f(22, 3),f(22, 4) / -1.17128427d+00 , -1.17160874d+00 /
      data f(22, 5),f(22, 6) / -1.17195951d+00 , -1.17226601d+00 /
      data f(22, 7),f(22, 8) / -1.17247988d+00 , -1.17258673d+00 /
      data f(22, 9),f(22,10) / -1.17260124d+00 , -1.17247286d+00 /
      data f(22,11),f(22,12) / -1.17230219d+00 , -1.17218300d+00 /
      data f(22,13),f(22,14) / -1.17212210d+00 , -1.17209996d+00 /
      data f(22,15),f(22,16) / -1.17209820d+00 , -1.17210437d+00 /
      data f(22,17),f(22,18) / -1.17211036d+00 , -1.17211194d+00 /
      data f(22,19),f(22,20) / -1.17210863d+00 , -1.17210243d+00 /
      data f(22,21),f(22,22) / -1.17209602d+00 , -1.17209147d+00 /
      data f(22,23) /          -1.17208985d+00 /
      data f(23, 1),f(23, 2) / -1.17165490d+00 , -1.17169166d+00 /
      data f(23, 3),f(23, 4) / -1.17179406d+00 , -1.17193956d+00 /
      data f(23, 5),f(23, 6) / -1.17209649d+00 , -1.17223332d+00 /
      data f(23, 7),f(23, 8) / -1.17232782d+00 , -1.17237261d+00 /
      data f(23, 9),f(23,10) / -1.17237378d+00 , -1.17230033d+00 /
      data f(23,11),f(23,12) / -1.17220792d+00 , -1.17214294d+00 /
      data f(23,13),f(23,14) / -1.17210905d+00 , -1.17209626d+00 /
      data f(23,15),f(23,16) / -1.17209486d+00 , -1.17209793d+00 /
      data f(23,17),f(23,18) / -1.17210086d+00 , -1.17210136d+00 /
      data f(23,19),f(23,20) / -1.17209920d+00 , -1.17209554d+00 /
      data f(23,21),f(23,22) / -1.17209184d+00 , -1.17208923d+00 /
      data f(23,23) /          -1.17208829d+00 /
      data f(24, 1),f(24, 2) / -1.17194799d+00 , -1.17196408d+00 /
      data f(24, 3),f(24, 4) / -1.17200892d+00 , -1.17207227d+00 /
      data f(24, 5),f(24, 6) / -1.17214000d+00 , -1.17219800d+00 /
      data f(24, 7),f(24, 8) / -1.17223635d+00 , -1.17225173d+00 /
      data f(24, 9),f(24,10) / -1.17224682d+00 , -1.17220226d+00 /
      data f(24,11),f(24,12) / -1.17215057d+00 , -1.17211447d+00 /
      data f(24,13),f(24,14) / -1.17209553d+00 , -1.17208844d+00 /
      data f(24,15),f(24,16) / -1.17208783d+00 , -1.17208962d+00 /
      data f(24,17),f(24,18) / -1.17209121d+00 , -1.17209137d+00 /
      data f(24,19),f(24,20) / -1.17209005d+00 , -1.17208788d+00 /
      data f(24,21),f(24,22) / -1.17208567d+00 , -1.17208410d+00 /
      data f(24,23) /          -1.17208353d+00 /
      data f(25, 1),f(25, 2) / -1.17205731d+00 , -1.17206426d+00 /
      data f(25, 3),f(25, 4) / -1.17208350d+00 , -1.17211043d+00 /
      data f(25, 5),f(25, 6) / -1.17213872d+00 , -1.17216207d+00 /
      data f(25, 7),f(25, 8) / -1.17217603d+00 , -1.17217927d+00 /
      data f(25, 9),f(25,10) / -1.17217317d+00 , -1.17214527d+00 /
      data f(25,11),f(25,12) / -1.17211571d+00 , -1.17209540d+00 /
      data f(25,13),f(25,14) / -1.17208493d+00 , -1.17208123d+00 /
      data f(25,15),f(25,16) / -1.17208128d+00 , -1.17208250d+00 /
      data f(25,17),f(25,18) / -1.17208346d+00 , -1.17208352d+00 /
      data f(25,19),f(25,20) / -1.17208266d+00 , -1.17208127d+00 /
      data f(25,21),f(25,22) / -1.17207983d+00 , -1.17207877d+00 /
      data f(25,23) /          -1.17207839d+00 /
      data f(26, 1),f(26, 2) / -1.17208954d+00 , -1.17209253d+00 /
      data f(26, 3),f(26, 4) / -1.17210071d+00 , -1.17211194d+00 /
      data f(26, 5),f(26, 6) / -1.17212330d+00 , -1.17213194d+00 /
      data f(26, 7),f(26, 8) / -1.17213598d+00 , -1.17213490d+00 /
      data f(26, 9),f(26,10) / -1.17212949d+00 , -1.17211196d+00 /
      data f(26,11),f(26,12) / -1.17209482d+00 , -1.17208335d+00 /
      data f(26,13),f(26,14) / -1.17207763d+00 , -1.17207592d+00 /
      data f(26,15),f(26,16) / -1.17207618d+00 , -1.17207705d+00 /
      data f(26,17),f(26,18) / -1.17207767d+00 , -1.17207767d+00 /
      data f(26,19),f(26,20) / -1.17207708d+00 , -1.17207612d+00 /
      data f(26,21),f(26,22) / -1.17207511d+00 , -1.17207437d+00 /
      data f(26,23) /          -1.17207409d+00 /
      data f(27, 1),f(27, 2) / -1.17208986d+00 , -1.17209031d+00 /
      data f(27, 3),f(27, 4) / -1.17209149d+00 , -1.17209293d+00 /
      data f(27, 5),f(27, 6) / -1.17209405d+00 , -1.17209430d+00 /
      data f(27, 7),f(27, 8) / -1.17209338d+00 , -1.17209131d+00 /
      data f(27, 9),f(27,10) / -1.17208837d+00 , -1.17208147d+00 /
      data f(27,11),f(27,12) / -1.17207554d+00 , -1.17207180d+00 /
      data f(27,13),f(27,14) / -1.17207009d+00 , -1.17206969d+00 /
      data f(27,15),f(27,16) / -1.17206992d+00 , -1.17207027d+00 /
      data f(27,17),f(27,18) / -1.17207050d+00 , -1.17207048d+00 /
      data f(27,19),f(27,20) / -1.17207022d+00 , -1.17206979d+00 /
      data f(27,21),f(27,22) / -1.17206935d+00 , -1.17206903d+00 /
      data f(27,23) /          -1.17206892d+00 /
      data f(28, 1),f(28, 2) / -1.17207873d+00 , -1.17207874d+00 /
      data f(28, 3),f(28, 4) / -1.17207871d+00 , -1.17207856d+00 /
      data f(28, 5),f(28, 6) / -1.17207822d+00 , -1.17207758d+00 /
      data f(28, 7),f(28, 8) / -1.17207663d+00 , -1.17207542d+00 /
      data f(28, 9),f(28,10) / -1.17207403d+00 , -1.17207126d+00 /
      data f(28,11),f(28,12) / -1.17206910d+00 , -1.17206782d+00 /
      data f(28,13),f(28,14) / -1.17206721d+00 , -1.17206704d+00 /
      data f(28,15),f(28,16) / -1.17206710d+00 , -1.17206718d+00 /
      data f(28,17),f(28,18) / -1.17206725d+00 , -1.17206724d+00 /
      data f(28,19),f(28,20) / -1.17206716d+00 , -1.17206702d+00 /
      data f(28,21),f(28,22) / -1.17206685d+00 , -1.17206679d+00 /
      data f(28,23) /          -1.17206676d+00 /
 
      data fpp( 1, 1,1),fpp( 1, 1,2)/ 8.22064045d+00,-8.05947416d-03/
      data fpp( 1, 2,1),fpp( 1, 2,2)/ 7.02406509d+00,-4.33643808d-03/
      data fpp( 1, 3,1),fpp( 1, 3,2)/ 4.64912408d+00, 1.05960877d-05/
      data fpp( 1, 4,1),fpp( 1, 4,2)/ 2.79634677d+00, 2.17363693d-03/
      data fpp( 1, 5,1),fpp( 1, 5,2)/ 1.89772537d+00, 1.33866419d-03/
      data fpp( 1, 6,1),fpp( 1, 6,2)/ 9.15803374d-01, 1.93489672d-03/
      data fpp( 1, 7,1),fpp( 1, 7,2)/ 4.91009040d-01, 1.55856573d-03/
      data fpp( 1, 8,1),fpp( 1, 8,2)/ 1.25020383d-01, 1.05831476d-03/
      data fpp( 1, 9,1),fpp( 1, 9,2)/ 1.22358330d-01, 4.77544031d-04/
      data fpp( 1,10,1),fpp( 1,10,2)/-9.71874133d-03, 6.27725266d-05/
      data fpp( 1,11,1),fpp( 1,11,2)/-1.64733430d-02,-8.53105374d-05/
      data fpp( 1,12,1),fpp( 1,12,2)/-6.52957455d-03,-1.03437577d-04/
      data fpp( 1,13,1),fpp( 1,13,2)/ 2.71188720d-02,-1.29028155d-04/
      data fpp( 1,14,1),fpp( 1,14,2)/ 4.14300456d-02,-6.56600031d-05/
      data fpp( 1,15,1),fpp( 1,15,2)/ 4.03180022d-02, 9.03076744d-06/
      data fpp( 1,16,1),fpp( 1,16,2)/ 5.72369927d-02, 2.10439333d-05/
      data fpp( 1,17,1),fpp( 1,17,2)/ 7.46454524d-02, 2.67829920d-06/
      data fpp( 1,18,1),fpp( 1,18,2)/ 6.65510301d-02, 1.73390699d-05/
      data fpp( 1,19,1),fpp( 1,19,2)/ 4.74132258d-02, 2.32334213d-05/
      data fpp( 1,20,1),fpp( 1,20,2)/ 4.04750670d-02, 3.54904480d-06/
      data fpp( 1,21,1),fpp( 1,21,2)/ 4.27311203d-02,-1.10110005d-05/
      data fpp( 1,22,1),fpp( 1,22,2)/ 4.61373388d-02,-1.21214427d-05/
      data fpp( 1,23,1),fpp( 1,23,2)/ 4.74090921d-02,-1.70746286d-05/
      data fpp( 2, 1,1),fpp( 2, 1,2)/ 6.48233309d+00,-5.35688665d-03/
      data fpp( 2, 2,1),fpp( 2, 2,2)/ 5.58021182d+00,-2.90281509d-03/
      data fpp( 2, 3,1),fpp( 2, 3,2)/ 3.75932884d+00, 5.62374290d-05/
      data fpp( 2, 4,1),fpp( 2, 4,2)/ 2.37095547d+00, 1.24785658d-03/
      data fpp( 2, 5,1),fpp( 2, 5,2)/ 1.59577427d+00,-4.09325406d-05/
      data fpp( 2, 6,1),fpp( 2, 6,2)/ 8.18823252d-01, 1.65168638d-03/
      data fpp( 2, 7,1),fpp( 2, 7,2)/ 3.67799920d-01, 1.52829020d-03/
      data fpp( 2, 8,1),fpp( 2, 8,2)/ 1.22379234d-01, 9.21228005d-04/
      data fpp( 2, 9,1),fpp( 2, 9,2)/ 9.56963403d-02, 4.58040976d-04/
      data fpp( 2,10,1),fpp( 2,10,2)/ 2.72048267d-03, 2.90628690d-05/
      data fpp( 2,11,1),fpp( 2,11,2)/-4.44631395d-03,-8.07828522d-05/
      data fpp( 2,12,1),fpp( 2,12,2)/ 9.89149097d-04,-1.07693860d-04/
      data fpp( 2,13,1),fpp( 2,13,2)/ 2.74572560d-02,-1.11181707d-04/
      data fpp( 2,14,1),fpp( 2,14,2)/ 3.78599087d-02,-5.71283127d-05/
      data fpp( 2,15,1),fpp( 2,15,2)/ 3.63319956d-02, 2.70915743d-06/
      data fpp( 2,16,1),fpp( 2,16,2)/ 4.84560146d-02, 1.80310830d-05/
      data fpp( 2,17,1),fpp( 2,17,2)/ 6.16380952d-02, 8.98291076d-06/
      data fpp( 2,18,1),fpp( 2,18,2)/ 5.52449399d-02, 1.76382740d-05/
      data fpp( 2,19,1),fpp( 2,19,2)/ 4.10005483d-02, 1.81253931d-05/
      data fpp( 2,20,1),fpp( 2,20,2)/ 3.61238659d-02, 1.55035338d-06/
      data fpp( 2,21,1),fpp( 2,21,2)/ 3.83817594d-02,-9.86440668d-06/
      data fpp( 2,22,1),fpp( 2,22,2)/ 4.13623224d-02,-1.06453267d-05/
      data fpp( 2,23,1),fpp( 2,23,2)/ 4.24678157d-02,-1.44644867d-05/
      data fpp( 3, 1,1),fpp( 3, 1,2)/ 4.52576317d+00,-3.54728482d-03/
      data fpp( 3, 2,1),fpp( 3, 2,2)/ 3.96988364d+00,-1.85577636d-03/
      data fpp( 3, 3,1),fpp( 3, 3,2)/ 2.78899057d+00, 3.49831077d-04/
      data fpp( 3, 4,1),fpp( 3, 4,2)/ 1.95399736d+00, 7.56092058d-04/
      data fpp( 3, 5,1),fpp( 3, 5,2)/ 1.92081556d+00,-1.72105051d-03/
      data fpp( 3, 6,1),fpp( 3, 6,2)/ 8.09015617d-01, 1.66894598d-03/
      data fpp( 3, 7,1),fpp( 3, 7,2)/ 1.86211282d-01, 1.53658980d-03/
      data fpp( 3, 8,1),fpp( 3, 8,2)/ 1.19238681d-01, 9.04190013d-04/
      data fpp( 3, 9,1),fpp( 3, 9,2)/ 4.29023091d-02, 4.11333345d-04/
      data fpp( 3,10,1),fpp( 3,10,2)/ 1.08918811d-01, 1.02921575d-05/
      data fpp( 3,11,1),fpp( 3,11,2)/ 2.00325988d-02,-7.74407752d-05/
      data fpp( 3,12,1),fpp( 3,12,2)/ 1.05889782d-02,-1.07491657d-04/
      data fpp( 3,13,1),fpp( 3,13,2)/ 2.86101041d-02,-9.64535984d-05/
      data fpp( 3,14,1),fpp( 3,14,2)/ 3.42783194d-02,-5.01769498d-05/
      data fpp( 3,15,1),fpp( 3,15,2)/ 3.23340152d-02,-1.24860258d-06/
      data fpp( 3,16,1),fpp( 3,16,2)/ 3.92549489d-02, 1.52935601d-05/
      data fpp( 3,17,1),fpp( 3,17,2)/ 4.80001668d-02, 1.24769623d-05/
      data fpp( 3,18,1),fpp( 3,18,2)/ 4.28832105d-02, 1.71377908d-05/
      data fpp( 3,19,1),fpp( 3,19,2)/ 3.42425809d-02, 1.44294746d-05/
      data fpp( 3,20,1),fpp( 3,20,2)/ 3.16294692d-02, 2.72710940d-07/
      data fpp( 3,21,1),fpp( 3,21,2)/ 3.39018422d-02,-8.75231833d-06/
      data fpp( 3,22,1),fpp( 3,22,2)/ 3.63993716d-02,-9.32563762d-06/
      data fpp( 3,23,1),fpp( 3,23,2)/ 3.73356450d-02,-1.23137312d-05/
      data fpp( 4, 1,1),fpp( 4, 1,2)/ 3.33311221d+00,-2.38393545d-03/
      data fpp( 4, 2,1),fpp( 4, 2,2)/ 2.94221762d+00,-1.08139390d-03/
      data fpp( 4, 3,1),fpp( 4, 3,2)/ 2.10055290d+00, 8.32467857d-04/
      data fpp( 4, 4,1),fpp( 4, 4,2)/ 1.50752311d+00, 6.06708874d-04/
      data fpp( 4, 5,1),fpp( 4, 5,2)/ 5.13834968d-02,-3.77680575d-03/
      data fpp( 4, 6,1),fpp( 4, 6,2)/ 4.94104279d-01, 1.87942054d-03/
      data fpp( 4, 7,1),fpp( 4, 7,2)/ 2.08950954d-01, 1.76928120d-03/
      data fpp( 4, 8,1),fpp( 4, 8,2)/ 1.17846041d-01, 8.45561080d-04/
      data fpp( 4, 9,1),fpp( 4, 9,2)/ 8.15704233d-02, 4.01042486d-04/
      data fpp( 4,10,1),fpp( 4,10,2)/-1.13039725d-01,-2.56245975d-05/
      data fpp( 4,11,1),fpp( 4,11,2)/ 9.29918642d-04,-6.44534960d-05/
      data fpp( 4,12,1),fpp( 4,12,2)/ 1.29049383d-02,-1.05886419d-04/
      data fpp( 4,13,1),fpp( 4,13,2)/ 2.69123278d-02,-8.36904299d-05/
      data fpp( 4,14,1),fpp( 4,14,2)/ 3.07368135d-02,-4.43348620d-05/
      data fpp( 4,15,1),fpp( 4,15,2)/ 2.83779434d-02,-3.66072224d-06/
      data fpp( 4,16,1),fpp( 4,16,2)/ 3.15241898d-02, 1.29445509d-05/
      data fpp( 4,17,1),fpp( 4,17,2)/ 3.65692378d-02, 1.38967185d-05/
      data fpp( 4,18,1),fpp( 4,18,2)/ 3.42162181d-02, 1.63037749d-05/
      data fpp( 4,19,1),fpp( 4,19,2)/ 2.86931282d-02, 1.16303819d-05/
      data fpp( 4,20,1),fpp( 4,20,2)/ 2.76362571d-02,-4.64302355d-07/
      data fpp( 4,21,1),fpp( 4,21,2)/ 2.98788719d-02,-7.70197244d-06/
      data fpp( 4,22,1),fpp( 4,22,2)/ 3.20941913d-02,-8.14000787d-06/
      data fpp( 4,23,1),fpp( 4,23,2)/ 3.28716042d-02,-1.05207961d-05/
      data fpp( 5, 1,1),fpp( 5, 1,2)/ 2.43268399d+00,-1.65830369d-03/
      data fpp( 5, 2,1),fpp( 5, 2,2)/ 2.16041588d+00,-5.91280227d-04/
      data fpp( 5, 3,1),fpp( 5, 3,2)/ 1.48450583d+00, 1.75720299d-03/
      data fpp( 5, 4,1),fpp( 5, 4,2)/ 1.08659622d+00,-3.79422945d-04/
      data fpp( 5, 5,1),fpp( 5, 5,2)/-6.27891546d-01,-4.51454721d-03/
      data fpp( 5, 6,1),fpp( 5, 6,2)/ 2.91547266d-01, 1.31488860d-03/
      data fpp( 5, 7,1),fpp( 5, 7,2)/ 8.12289008d-02, 2.36308163d-03/
      data fpp( 5, 8,1),fpp( 5, 8,2)/ 4.58151549d-02, 7.20274492d-04/
      data fpp( 5, 9,1),fpp( 5, 9,2)/ 2.22259978d-02, 3.84984404d-04/
      data fpp( 5,10,1),fpp( 5,10,2)/ 4.65220907d-02,-3.07180592d-05/
      data fpp( 5,11,1),fpp( 5,11,2)/ 5.49172661d-03,-6.75831677d-05/
      data fpp( 5,12,1),fpp( 5,12,2)/ 1.37092688d-02,-9.85654699d-05/
      data fpp( 5,13,1),fpp( 5,13,2)/ 2.50925848d-02,-7.37971527d-05/
      data fpp( 5,14,1),fpp( 5,14,2)/ 2.74844264d-02,-3.89365193d-05/
      data fpp( 5,15,1),fpp( 5,15,2)/ 2.47402111d-02,-5.17617002d-06/
      data fpp( 5,16,1),fpp( 5,16,2)/ 2.60602919d-02, 1.09475994d-05/
      data fpp( 5,17,1),fpp( 5,17,2)/ 2.89048821d-02, 1.41059725d-05/
      data fpp( 5,18,1),fpp( 5,18,2)/ 2.72219172d-02, 1.51615108d-05/
      data fpp( 5,19,1),fpp( 5,19,2)/ 2.39889062d-02, 9.49938440d-06/
      data fpp( 5,20,1),fpp( 5,20,2)/ 2.40615023d-02,-8.45648397d-07/
      data fpp( 5,21,1),fpp( 5,21,2)/ 2.63246702d-02,-6.71499082d-06/
      data fpp( 5,22,1),fpp( 5,22,2)/ 2.82378634d-02,-7.07998834d-06/
      data fpp( 5,23,1),fpp( 5,23,2)/ 2.89079381d-02,-9.01765583d-06/
      data fpp( 6, 1,1),fpp( 6, 1,2)/ 1.77075584d+00,-1.24518967d-03/
      data fpp( 6, 2,1),fpp( 6, 2,2)/ 1.56202285d+00,-3.55139469d-04/
      data fpp( 6, 3,1),fpp( 6, 3,2)/ 1.02433377d+00, 3.05262994d-03/
      data fpp( 6, 4,1),fpp( 6, 4,2)/-2.67163974d-01,-2.35161790d-03/
      data fpp( 6, 5,1),fpp( 6, 5,2)/-2.16873314d-01,-3.59378155d-03/
      data fpp( 6, 6,1),fpp( 6, 6,2)/-6.95127344d-01,-1.35199911d-04/
      data fpp( 6, 7,1),fpp( 6, 7,2)/ 1.81094422d-02, 3.21843639d-03/
      data fpp( 6, 8,1),fpp( 6, 8,2)/ 6.89853396d-02, 5.26849538d-04/
      data fpp( 6, 9,1),fpp( 6, 9,2)/ 3.76175856d-02, 3.87879056d-04/
      data fpp( 6,10,1),fpp( 6,10,2)/ 3.17536254d-03,-3.93873369d-05/
      data fpp( 6,11,1),fpp( 6,11,2)/ 3.58117493d-03,-6.71501083d-05/
      data fpp( 6,12,1),fpp( 6,12,2)/ 1.32579865d-02,-9.14928298d-05/
      data fpp( 6,13,1),fpp( 6,13,2)/ 2.27833331d-02,-6.50189725d-05/
      data fpp( 6,14,1),fpp( 6,14,2)/ 2.45054809d-02,-3.42246803d-05/
      data fpp( 6,15,1),fpp( 6,15,2)/ 2.15692122d-02,-5.96910634d-06/
      data fpp( 6,16,1),fpp( 6,16,2)/ 2.12786427d-02, 9.18790565d-06/
      data fpp( 6,17,1),fpp( 6,17,2)/ 2.26032338d-02, 1.36048838d-05/
      data fpp( 6,18,1),fpp( 6,18,2)/ 2.14881130d-02, 1.38285594d-05/
      data fpp( 6,19,1),fpp( 6,19,2)/ 1.99392470d-02, 7.86107885d-06/
      data fpp( 6,20,1),fpp( 6,20,2)/ 2.08197337d-02,-9.95274743d-07/
      data fpp( 6,21,1),fpp( 6,21,2)/ 2.30484475d-02,-5.80657988d-06/
      data fpp( 6,22,1),fpp( 6,22,2)/ 2.47543552d-02,-6.13240575d-06/
      data fpp( 6,23,1),fpp( 6,23,2)/ 2.53346433d-02,-7.73979713d-06/
      data fpp( 7, 1,1),fpp( 7, 1,2)/ 9.38876497d-01,-6.65062844d-04/
      data fpp( 7, 2,1),fpp( 7, 2,2)/ 8.40894995d-01,-5.04431235d-06/
      data fpp( 7, 3,1),fpp( 7, 3,2)/ 4.62340763d-01, 4.02751129d-03/
      data fpp( 7, 4,1),fpp( 7, 4,2)/-3.14963685d-01,-3.74381286d-03/
      data fpp( 7, 5,1),fpp( 7, 5,2)/-2.21747850d-02,-3.24558625d-03/
      data fpp( 7, 6,1),fpp( 7, 6,2)/-2.80310602d-01,-9.25580536d-04/
      data fpp( 7, 7,1),fpp( 7, 7,2)/-9.01127772d-02, 3.51598039d-03/
      data fpp( 7, 8,1),fpp( 7, 8,2)/-4.89335963d-02, 4.05026959d-04/
      data fpp( 7, 9,1),fpp( 7, 9,2)/-1.34172558d-02, 3.52354171d-04/
      data fpp( 7,10,1),fpp( 7,10,2)/-1.22113297d-03,-4.05847913d-05/
      data fpp( 7,11,1),fpp( 7,11,2)/ 1.72061190d-03,-6.44836055d-05/
      data fpp( 7,12,1),fpp( 7,12,2)/ 1.11484061d-02,-7.71209867d-05/
      data fpp( 7,13,1),fpp( 7,13,2)/ 1.84892083d-02,-5.05526477d-05/
      data fpp( 7,14,1),fpp( 7,14,2)/ 1.94348441d-02,-2.63876226d-05/
      data fpp( 7,15,1),fpp( 7,15,2)/ 1.66152578d-02,-6.24186200d-06/
      data fpp( 7,16,1),fpp( 7,16,2)/ 1.46384261d-02, 6.32747057d-06/
      data fpp( 7,17,1),fpp( 7,17,2)/ 1.41953576d-02, 1.15103797d-05/
      data fpp( 7,18,1),fpp( 7,18,2)/ 1.37907025d-02, 1.10552106d-05/
      data fpp( 7,19,1),fpp( 7,19,2)/ 1.40763058d-02, 5.55217782d-06/
      data fpp( 7,20,1),fpp( 7,20,2)/ 1.57650477d-02,-9.20321889d-07/
      data fpp( 7,21,1),fpp( 7,21,2)/ 1.78203225d-02,-4.25169026d-06/
      data fpp( 7,22,1),fpp( 7,22,2)/ 1.91875027d-02,-4.53631707d-06/
      data fpp( 7,23,1),fpp( 7,23,2)/ 1.96391009d-02,-5.69144147d-06/
      data fpp( 8, 1,1),fpp( 8, 1,2)/ 5.51412674d-01,-3.34596060d-04/
      data fpp( 8, 2,1),fpp( 8, 2,2)/ 4.82179167d-01, 2.67484520d-04/
      data fpp( 8, 3,1),fpp( 8, 3,2)/ 2.93686673d-01, 3.04950838d-03/
      data fpp( 8, 4,1),fpp( 8, 4,2)/-3.90599284d-01,-1.79826924d-03/
      data fpp( 8, 5,1),fpp( 8, 5,2)/-8.85678046d-01,-4.99727061d-03/
      data fpp( 8, 6,1),fpp( 8, 6,2)/-5.31895248d-01, 3.32407692d-04/
      data fpp( 8, 7,1),fpp( 8, 7,2)/-1.03281334d-01, 2.61537905d-03/
      data fpp( 8, 8,1),fpp( 8, 8,2)/ 6.75804556d-03, 5.04200924d-04/
      data fpp( 8, 9,1),fpp( 8, 9,2)/-1.41855625d-02, 2.53583659d-04/
      data fpp( 8,10,1),fpp( 8,10,2)/-7.73183067d-03,-2.60284393d-05/
      data fpp( 8,11,1),fpp( 8,11,2)/-2.12622542d-04,-6.20283019d-05/
      data fpp( 8,12,1),fpp( 8,12,2)/ 8.74988921d-03,-6.29947529d-05/
      data fpp( 8,13,1),fpp( 8,13,2)/ 1.47653335d-02,-3.94712864d-05/
      data fpp( 8,14,1),fpp( 8,14,2)/ 1.55456426d-02,-2.02127016d-05/
      data fpp( 8,15,1),fpp( 8,15,2)/ 1.30442566d-02,-5.68150738d-06/
      data fpp( 8,16,1),fpp( 8,16,2)/ 1.06776531d-02, 4.25733107d-06/
      data fpp( 8,17,1),fpp( 8,17,2)/ 9.57133570d-03, 9.02578309d-06/
      data fpp( 8,18,1),fpp( 8,18,2)/ 9.41757697d-03, 8.51853658d-06/
      data fpp( 8,19,1),fpp( 8,19,2)/ 1.03085296d-02, 4.03547058d-06/
      data fpp( 8,20,1),fpp( 8,20,2)/ 1.20960753d-02,-6.75418919d-07/
      data fpp( 8,21,1),fpp( 8,21,2)/ 1.38817624d-02,-3.04379491d-06/
      data fpp( 8,22,1),fpp( 8,22,2)/ 1.50306341d-02,-3.28700146d-06/
      data fpp( 8,23,1),fpp( 8,23,2)/ 1.53964529d-02,-4.13739927d-06/
      data fpp( 9, 1,1),fpp( 9, 1,2)/ 2.85801805d-01, 9.08719181d-05/
      data fpp( 9, 2,1),fpp( 9, 2,2)/ 2.72410838d-01, 4.09160564d-04/
      data fpp( 9, 3,1),fpp( 9, 3,2)/ 2.42823545d-01, 1.26182743d-03/
      data fpp( 9, 4,1),fpp( 9, 4,2)/ 5.49742322d-01, 2.44170530d-04/
      data fpp( 9, 5,1),fpp( 9, 5,2)/-1.81948032d-01,-5.06556075d-03/
      data fpp( 9, 6,1),fpp( 9, 6,2)/ 3.06079595d-01, 1.26270605d-03/
      data fpp( 9, 7,1),fpp( 9, 7,2)/ 4.10011117d-02, 1.33342613d-03/
      data fpp( 9, 8,1),fpp( 9, 8,2)/-1.98765859d-02, 5.05885437d-04/
      data fpp( 9, 9,1),fpp( 9, 9,2)/-1.11794941d-02, 1.90090525d-04/
      data fpp( 9,10,1),fpp( 9,10,2)/-9.80204433d-03,-2.11552921d-05/
      data fpp( 9,11,1),fpp( 9,11,2)/-1.56462174d-03,-5.53705561d-05/
      data fpp( 9,12,1),fpp( 9,12,2)/ 6.71803708d-03,-5.10732834d-05/
      data fpp( 9,13,1),fpp( 9,13,2)/ 1.17039576d-02,-3.06421101d-05/
      data fpp( 9,14,1),fpp( 9,14,2)/ 1.23350856d-02,-1.55004761d-05/
      data fpp( 9,15,1),fpp( 9,15,2)/ 1.04002158d-02,-4.80138545d-06/
      data fpp( 9,16,1),fpp( 9,16,2)/ 8.16346160d-03, 2.80281790d-06/
      data fpp( 9,17,1),fpp( 9,17,2)/ 6.91029956d-03, 6.78231385d-06/
      data fpp( 9,18,1),fpp( 9,18,2)/ 6.80798958d-03, 6.40152671d-06/
      data fpp( 9,19,1),fpp( 9,19,2)/ 7.78257577d-03, 2.97737931d-06/
      data fpp( 9,20,1),fpp( 9,20,2)/ 9.37165091d-03,-4.43043938d-07/
      data fpp( 9,21,1),fpp( 9,21,2)/ 1.08686278d-02,-2.13760356d-06/
      data fpp( 9,22,1),fpp( 9,22,2)/ 1.18074608d-02,-2.33574184d-06/
      data fpp( 9,23,1),fpp( 9,23,2)/ 1.21140874d-02,-2.96142908d-06/
      data fpp(10, 1,1),fpp(10, 1,2)/ 1.46967605d-01, 2.84013128d-04/
      data fpp(10, 2,1),fpp(10, 2,2)/ 1.47381483d-01, 2.77721745d-04/
      data fpp(10, 3,1),fpp(10, 3,2)/ 1.77863145d-01, 5.52570293d-04/
      data fpp(10, 4,1),fpp(10, 4,2)/ 3.56488495d-01,-1.56570918d-04/
      data fpp(10, 5,1),fpp(10, 5,2)/ 8.79818673d-01,-2.23238902d-03/
      data fpp(10, 6,1),fpp(10, 6,2)/ 2.11379367d-01, 2.87880602d-04/
      data fpp(10, 7,1),fpp(10, 7,2)/ 1.62043868d-02, 8.27580214d-04/
      data fpp(10, 8,1),fpp(10, 8,2)/-1.06397018d-02, 3.74760943d-04/
      data fpp(10, 9,1),fpp(10, 9,2)/-1.70099612d-02, 1.50190413d-04/
      data fpp(10,10,1),fpp(10,10,2)/-1.09344920d-02,-1.94207118d-05/
      data fpp(10,11,1),fpp(10,11,2)/-2.49589051d-03,-4.74041661d-05/
      data fpp(10,12,1),fpp(10,12,2)/ 5.04446247d-03,-4.09574237d-05/
      data fpp(10,13,1),fpp(10,13,2)/ 9.19333624d-03,-2.37093389d-05/
      data fpp(10,14,1),fpp(10,14,2)/ 9.79751519d-03,-1.18766206d-05/
      data fpp(10,15,1),fpp(10,15,2)/ 8.33688034d-03,-3.91557865d-06/
      data fpp(10,16,1),fpp(10,16,2)/ 6.48350053d-03, 1.82773520d-06/
      data fpp(10,17,1),fpp(10,17,2)/ 5.31546608d-03, 4.96743783d-06/
      data fpp(10,18,1),fpp(10,18,2)/ 5.20046469d-03, 4.73431348d-06/
      data fpp(10,19,1),fpp(10,19,2)/ 6.01366733d-03, 2.20370827d-06/
      data fpp(10,20,1),fpp(10,20,2)/ 7.30632102d-03,-2.64546546d-07/
      data fpp(10,21,1),fpp(10,21,2)/ 8.50272628d-03,-1.48692208d-06/
      data fpp(10,22,1),fpp(10,22,2)/ 9.26702249d-03,-1.62916512d-06/
      data fpp(10,23,1),fpp(10,23,2)/ 9.52119750d-03,-2.08001744d-06/
      data fpp(11, 1,1),fpp(11, 1,2)/ 4.37712732d-02, 2.90392223d-04/
      data fpp(11, 2,1),fpp(11, 2,2)/ 5.42152314d-02, 1.77300355d-04/
      data fpp(11, 3,1),fpp(11, 3,2)/ 1.17383873d-01, 1.56884758d-04/
      data fpp(11, 4,1),fpp(11, 4,2)/ 2.85670697d-01,-1.87897788d-04/
      data fpp(11, 5,1),fpp(11, 5,2)/ 1.76876341d-01,-1.08944081d-03/
      data fpp(11, 6,1),fpp(11, 6,2)/ 1.29090937d-01, 1.26373013d-04/
      data fpp(11, 7,1),fpp(11, 7,2)/ 2.34843412d-02, 4.90094355d-04/
      data fpp(11, 8,1),fpp(11, 8,2)/-1.18281068d-02, 2.73387967d-04/
      data fpp(11, 9,1),fpp(11, 9,2)/-1.61986613d-02, 1.14783375d-04/
      data fpp(11,10,1),fpp(11,10,2)/-1.10649877d-02,-1.67923094d-05/
      data fpp(11,11,1),fpp(11,11,2)/-2.92831621d-03,-3.97799377d-05/
      data fpp(11,12,1),fpp(11,12,2)/ 3.72961304d-03,-3.23773399d-05/
      data fpp(11,13,1),fpp(11,13,2)/ 7.17119749d-03,-1.83229028d-05/
      data fpp(11,14,1),fpp(11,14,2)/ 7.74735367d-03,-9.09124879d-06/
      data fpp(11,15,1),fpp(11,15,2)/ 6.66126286d-03,-3.12450202d-06/
      data fpp(11,16,1),fpp(11,16,2)/ 5.23253629d-03, 1.18385686d-06/
      data fpp(11,17,1),fpp(11,17,2)/ 4.25033614d-03, 3.59107457d-06/
      data fpp(11,18,1),fpp(11,18,2)/ 4.10615165d-03, 3.46224486d-06/
      data fpp(11,19,1),fpp(11,19,2)/ 4.73125492d-03, 1.63454599d-06/
      data fpp(11,20,1),fpp(11,20,2)/ 5.71456500d-03,-1.43028822d-07/
      data fpp(11,21,1),fpp(11,21,2)/ 6.62596705d-03,-1.03243070d-06/
      data fpp(11,22,1),fpp(11,22,2)/ 7.22444918d-03,-1.12064837d-06/
      data fpp(11,23,1),fpp(11,23,2)/ 7.42662262d-03,-1.43777581d-06/
      data fpp(12, 1,1),fpp(12, 1,2)/-3.40316983d-02, 3.06027228d-04/
      data fpp(12, 2,1),fpp(12, 2,2)/-3.18364084d-02, 1.12983944d-04/
      data fpp(12, 3,1),fpp(12, 3,2)/-1.80676390d-02, 1.15873971d-05/
      data fpp(12, 4,1),fpp(12, 4,2)/-4.39717825d-02,-4.10572732d-04/
      data fpp(12, 5,1),fpp(12, 5,2)/ 9.76514631d-02,-3.85236468d-04/
      data fpp(12, 6,1),fpp(12, 6,2)/ 6.88453834d-02, 1.22128206d-04/
      data fpp(12, 7,1),fpp(12, 7,2)/ 1.00292482d-02, 3.01452445d-04/
      data fpp(12, 8,1),fpp(12, 8,2)/-1.18248709d-02, 1.97727613d-04/
      data fpp(12, 9,1),fpp(12, 9,2)/-1.59593938d-02, 8.68195012d-05/
      data fpp(12,10,1),fpp(12,10,2)/-1.07455571d-02,-1.42305103d-05/
      data fpp(12,11,1),fpp(12,11,2)/-3.13684465d-03,-3.26244599d-05/
      data fpp(12,12,1),fpp(12,12,2)/ 2.66608535d-03,-2.53032501d-05/
      data fpp(12,13,1),fpp(12,13,2)/ 5.51987378d-03,-1.41261396d-05/
      data fpp(12,14,1),fpp(12,14,2)/ 6.04307011d-03,-6.97599154d-06/
      data fpp(12,15,1),fpp(12,15,2)/ 5.34406820d-03,-2.43769425d-06/
      data fpp(12,16,1),fpp(12,16,2)/ 4.22585430d-03, 7.54168551d-07/
      data fpp(12,17,1),fpp(12,17,2)/ 3.43818935d-03, 2.58302005d-06/
      data fpp(12,18,1),fpp(12,18,2)/ 3.28842872d-03, 2.51995125d-06/
      data fpp(12,19,1),fpp(12,19,2)/ 3.72031298d-03, 1.21277494d-06/
      data fpp(12,20,1),fpp(12,20,2)/ 4.42691896d-03,-6.60510150d-08/
      data fpp(12,21,1),fpp(12,21,2)/ 5.08990552d-03,-7.18170881d-07/
      data fpp(12,22,1),fpp(12,22,2)/ 5.53618079d-03,-7.66865463d-07/
      data fpp(12,23,1),fpp(12,23,2)/ 5.69881203d-03,-9.87967269d-07/
      data fpp(13, 1,1),fpp(13, 1,2)/-7.94641877d-02, 3.30695254d-04/
      data fpp(13, 2,1),fpp(13, 2,2)/-8.80074597d-02, 7.86626921d-05/
      data fpp(13, 3,1),fpp(13, 3,2)/-1.22940786d-01,-2.85770822d-04/
      data fpp(13, 4,1),fpp(13, 4,2)/-3.11851894d-02,-2.56801003d-04/
      data fpp(13, 5,1),fpp(13, 5,2)/ 2.57022288d-02, 1.91540346d-05/
      data fpp(13, 6,1),fpp(13, 6,2)/ 1.78740972d-02, 1.03934465d-04/
      data fpp(13, 7,1),fpp(13, 7,2)/-2.42405499d-03, 1.73928107d-04/
      data fpp(13, 8,1),fpp(13, 8,2)/-1.29293593d-02, 1.21813909d-04/
      data fpp(13, 9,1),fpp(13, 9,2)/-1.46782466d-02, 5.75466593d-05/
      data fpp(13,10,1),fpp(13,10,2)/-9.54348440d-03,-1.06523320d-05/
      data fpp(13,11,1),fpp(13,11,2)/-2.97564036d-03,-2.32299311d-05/
      data fpp(13,12,1),fpp(13,12,2)/ 1.58897346d-03,-1.71803434d-05/
      data fpp(13,13,1),fpp(13,13,2)/ 3.68528905d-03,-9.53809515d-06/
      data fpp(13,14,1),fpp(13,14,2)/ 4.14319718d-03,-4.67207596d-06/
      data fpp(13,15,1),fpp(13,15,2)/ 3.71693076d-03,-1.68420102d-06/
      data fpp(13,16,1),fpp(13,16,2)/ 3.04312813d-03, 3.99480053d-07/
      data fpp(13,17,1),fpp(13,17,2)/ 2.50981139d-03, 1.57428081d-06/
      data fpp(13,18,1),fpp(13,18,2)/ 2.36113649d-03, 1.56599670d-06/
      data fpp(13,19,1),fpp(13,19,2)/ 2.58312013d-03, 7.78932375d-07/
      data fpp(13,20,1),fpp(13,20,2)/ 2.98389346d-03,-5.32620361d-09/
      data fpp(13,21,1),fpp(13,21,2)/ 3.36467022d-03,-4.18627561d-07/
      data fpp(13,22,1),fpp(13,22,2)/ 3.62476459d-03,-4.40563554d-07/
      data fpp(13,23,1),fpp(13,23,2)/ 3.70521148d-03,-5.74318223d-07/
      data fpp(14, 1,1),fpp(14, 1,2)/-4.78062174d-02, 6.08845720d-05/
      data fpp(14, 2,1),fpp(14, 2,2)/-3.99957528d-02,-2.71207439d-05/
      data fpp(14, 3,1),fpp(14, 3,2)/ 1.16314487d-02,-1.83413596d-04/
      data fpp(14, 4,1),fpp(14, 4,2)/ 2.11005402d-02,-1.00700071d-04/
      data fpp(14, 5,1),fpp(14, 5,2)/ 9.03362148d-03, 3.79794799d-05/
      data fpp(14, 6,1),fpp(14, 6,2)/ 7.34228005d-04, 9.37853512d-05/
      data fpp(14, 7,1),fpp(14, 7,2)/-8.44102828d-03, 1.09032715d-04/
      data fpp(14, 8,1),fpp(14, 8,2)/-1.27496921d-02, 7.89397877d-05/
      data fpp(14, 9,1),fpp(14, 9,2)/-1.27889533d-02, 3.87393339d-05/
      data fpp(14,10,1),fpp(14,10,2)/-7.85717194d-03,-7.26949547d-06/
      data fpp(14,11,1),fpp(14,11,2)/-2.49992726d-03,-1.58221520d-05/
      data fpp(14,12,1),fpp(14,12,2)/ 9.12020814d-04,-1.15026965d-05/
      data fpp(14,13,1),fpp(14,13,2)/ 2.44897000d-03,-6.40986196d-06/
      data fpp(14,14,1),fpp(14,14,2)/ 2.79747452d-03,-3.14905565d-06/
      data fpp(14,15,1),fpp(14,15,2)/ 2.57687541d-03,-1.14251545d-06/
      data fpp(14,16,1),fpp(14,16,2)/ 2.14563317d-03, 2.14917458d-07/
      data fpp(14,17,1),fpp(14,17,2)/ 1.79389842d-03, 9.71645620d-07/
      data fpp(14,18,1),fpp(14,18,2)/ 1.67302531d-03, 9.84100063d-07/
      data fpp(14,19,1),fpp(14,19,2)/ 1.77387318d-03, 5.08154127d-07/
      data fpp(14,20,1),fpp(14,20,2)/ 1.98084053d-03, 1.74834300d-08/
      data fpp(14,21,1),fpp(14,21,2)/ 2.18608026d-03,-2.43287847d-07/
      data fpp(14,22,1),fpp(14,22,2)/ 2.31942754d-03,-2.73732044d-07/
      data fpp(14,23,1),fpp(14,23,2)/ 2.37567536d-03,-3.69983978d-07/
      data fpp(15, 1,1),fpp(15, 1,2)/-2.35451316d-02,-1.49986424d-05/
      data fpp(15, 2,1),fpp(15, 2,2)/-1.71750467d-02,-4.87687153d-05/
      data fpp(15, 3,1),fpp(15, 3,2)/-6.63756488d-03,-1.20797696d-04/
      data fpp(15, 4,1),fpp(15, 4,2)/ 2.21808324d-03,-5.89204988d-05/
      data fpp(15, 5,1),fpp(15, 5,2)/ 2.03404932d-03, 3.48676917d-05/
      data fpp(15, 6,1),fpp(15, 6,2)/-3.85928576d-03, 7.76433319d-05/
      data fpp(15, 7,1),fpp(15, 7,2)/-9.39777612d-03, 8.25677806d-05/
      data fpp(15, 8,1),fpp(15, 8,2)/-1.17265007d-02, 6.01095456d-05/
      data fpp(15, 9,1),fpp(15, 9,2)/-1.11618637d-02, 3.01924370d-05/
      data fpp(15,10,1),fpp(15,10,2)/-6.64441371d-03,-5.30908375d-06/
      data fpp(15,11,1),fpp(15,11,2)/-2.15090319d-03,-1.19945020d-05/
      data fpp(15,12,1),fpp(15,12,2)/ 6.35435741d-04,-8.75470835d-06/
      data fpp(15,13,1),fpp(15,13,2)/ 1.84921643d-03,-4.92506462d-06/
      data fpp(15,14,1),fpp(15,14,2)/ 2.14333166d-03,-2.42163315d-06/
      data fpp(15,15,1),fpp(15,15,2)/ 1.98072680d-03,-8.80402776d-07/
      data fpp(15,16,1),fpp(15,16,2)/ 1.66964195d-03, 1.46644252d-07/
      data fpp(15,17,1),fpp(15,17,2)/ 1.40579083d-03, 7.12025767d-07/
      data fpp(15,18,1),fpp(15,18,2)/ 1.30066871d-03, 7.28852681d-07/
      data fpp(15,19,1),fpp(15,19,2)/ 1.35595390d-03, 3.84763508d-07/
      data fpp(15,20,1),fpp(15,20,2)/ 1.49695715d-03, 2.52932865d-08/
      data fpp(15,21,1),fpp(15,21,2)/ 1.62959335d-03,-1.72736654d-07/
      data fpp(15,22,1),fpp(15,22,2)/ 1.70721544d-03,-2.07946670d-07/
      data fpp(15,23,1),fpp(15,23,2)/ 1.72980595d-03,-2.89676665d-07/
      data fpp(16, 1,1),fpp(16, 1,2)/-7.88125615d-03,-4.23366960d-05/
      data fpp(16, 2,1),fpp(16, 2,2)/-4.12506062d-03,-5.09326081d-05/
      data fpp(16, 3,1),fpp(16, 3,2)/ 3.92381081d-03,-8.10168717d-05/
      data fpp(16, 4,1),fpp(16, 4,2)/ 4.22862686d-03,-3.58919051d-05/
      data fpp(16, 5,1),fpp(16, 5,2)/-7.31318758d-04, 2.88596922d-05/
      data fpp(16, 6,1),fpp(16, 6,2)/-5.69858495d-03, 6.13139365d-05/
      data fpp(16, 7,1),fpp(16, 7,2)/-9.19186726d-03, 6.29765618d-05/
      data fpp(16, 8,1),fpp(16, 8,2)/-1.02773050d-02, 4.61534163d-05/
      data fpp(16, 9,1),fpp(16, 9,2)/-9.43059192d-03, 2.37153732d-05/
      data fpp(16,10,1),fpp(16,10,2)/-5.46367321d-03,-3.66062759d-06/
      data fpp(16,11,1),fpp(16,11,2)/-1.74846000d-03,-8.95766280d-06/
      data fpp(16,12,1),fpp(16,12,2)/ 4.17736223d-04,-6.66072123d-06/
      data fpp(16,13,1),fpp(16,13,2)/ 1.35616428d-03,-3.79065230d-06/
      data fpp(16,14,1),fpp(16,14,2)/ 1.59519885d-03,-1.86526959d-06/
      data fpp(16,15,1),fpp(16,15,2)/ 1.50021739d-03,-6.75669351d-07/
      data fpp(16,16,1),fpp(16,16,2)/ 1.27229904d-03, 1.03946993d-07/
      data fpp(16,17,1),fpp(16,17,2)/ 1.07293826d-03, 5.26281379d-07/
      data fpp(16,18,1),fpp(16,18,2)/ 9.87299866d-04, 5.44327491d-07/
      data fpp(16,19,1),fpp(16,19,2)/ 1.01481123d-03, 2.95208656d-07/
      data fpp(16,20,1),fpp(16,20,2)/ 1.09433087d-03, 2.74378861d-08/
      data fpp(16,21,1),fpp(16,21,2)/ 1.17304635d-03,-1.27760200d-07/
      data fpp(16,22,1),fpp(16,22,2)/ 1.22121070d-03,-1.63197086d-07/
      data fpp(16,23,1),fpp(16,23,2)/ 1.23360083d-03,-2.32851457d-07/
      data fpp(17, 1,1),fpp(17, 1,2)/ 3.00127491d-03,-4.68123959d-05/
      data fpp(17, 2,1),fpp(17, 2,2)/ 3.95023316d-03,-4.19808083d-05/
      data fpp(17, 3,1),fpp(17, 3,2)/ 4.46934056d-03,-4.67011711d-05/
      data fpp(17, 4,1),fpp(17, 4,2)/ 2.51618830d-03,-1.79897074d-05/
      data fpp(17, 5,1),fpp(17, 5,2)/-1.41630369d-03, 1.97680007d-05/
      data fpp(17, 6,1),fpp(17, 6,2)/-5.11085965d-03, 4.08457045d-05/
      data fpp(17, 7,1),fpp(17, 7,2)/-7.23192507d-03, 4.17699812d-05/
      data fpp(17, 8,1),fpp(17, 8,2)/-7.66198283d-03, 3.11575708d-05/
      data fpp(17, 9,1),fpp(17, 9,2)/-6.87211779d-03, 1.65877357d-05/
      data fpp(17,10,1),fpp(17,10,2)/-3.87748015d-03,-1.79419236d-06/
      data fpp(17,11,1),fpp(17,11,2)/-1.28253120d-03,-5.69456620d-06/
      data fpp(17,12,1),fpp(17,12,2)/ 1.95588764d-04,-4.42134283d-06/
      data fpp(17,13,1),fpp(17,13,2)/ 8.33974786d-04,-2.57306246d-06/
      data fpp(17,14,1),fpp(17,14,2)/ 1.01011605d-03,-1.25900731d-06/
      data fpp(17,15,1),fpp(17,15,2)/ 9.53124178d-04,-4.57308308d-07/
      data fpp(17,16,1),fpp(17,16,2)/ 8.21241913d-04, 6.78405371d-08/
      data fpp(17,17,1),fpp(17,17,2)/ 6.92345251d-04, 3.41346159d-07/
      data fpp(17,18,1),fpp(17,18,2)/ 6.26887977d-04, 3.58374826d-07/
      data fpp(17,19,1),fpp(17,19,2)/ 6.28326650d-04, 1.99754535d-07/
      data fpp(17,20,1),fpp(17,20,2)/ 6.66925653d-04, 2.52070317d-08/
      data fpp(17,21,1),fpp(17,21,2)/ 7.02449948d-04,-8.75826624d-08/
      data fpp(17,22,1),fpp(17,22,2)/ 7.22487360d-04,-1.20076382d-07/
      data fpp(17,23,1),fpp(17,23,2)/ 7.30459942d-04,-1.75511809d-07/
      data fpp(18, 1,1),fpp(18, 1,2)/ 5.73682318d-03,-3.78657641d-05/
      data fpp(18, 2,1),fpp(18, 2,2)/ 5.74879463d-03,-3.06852719d-05/
      data fpp(18, 3,1),fpp(18, 3,2)/ 5.15749363d-03,-2.80907484d-05/
      data fpp(18, 4,1),fpp(18, 4,2)/ 2.80061993d-03,-9.44533437d-06/
      data fpp(18, 5,1),fpp(18, 5,2)/-5.26799826d-04, 1.28632859d-05/
      data fpp(18, 6,1),fpp(18, 6,2)/-3.33730978d-03, 2.62481907d-05/
      data fpp(18, 7,1),fpp(18, 7,2)/-4.91576581d-03, 2.72935511d-05/
      data fpp(18, 8,1),fpp(18, 8,2)/-5.25209700d-03, 2.08608047d-05/
      data fpp(18, 9,1),fpp(18, 9,2)/-4.71827026d-03, 1.15888301d-05/
      data fpp(18,10,1),fpp(18,10,2)/-2.67773953d-03,-6.48092758d-07/
      data fpp(18,11,1),fpp(18,11,2)/-9.09415195d-04,-3.58925911d-06/
      data fpp(18,12,1),fpp(18,12,2)/ 7.45753881d-05,-2.95107081d-06/
      data fpp(18,13,1),fpp(18,13,2)/ 4.99269911d-04,-1.75265766d-06/
      data fpp(18,14,1),fpp(18,14,2)/ 6.26336957d-04,-8.56298566d-07/
      data fpp(18,15,1),fpp(18,15,2)/ 6.02619235d-04,-3.03148079d-07/
      data fpp(18,16,1),fpp(18,16,2)/ 5.10733312d-04, 4.14908813d-08/
      data fpp(18,17,1),fpp(18,17,2)/ 4.29680736d-04, 2.27784554d-07/
      data fpp(18,18,1),fpp(18,18,2)/ 3.85148228d-04, 2.40770904d-07/
      data fpp(18,19,1),fpp(18,19,2)/ 3.79882174d-04, 1.37531830d-07/
      data fpp(18,20,1),fpp(18,20,2)/ 3.91966512d-04, 1.79017777d-08/
      data fpp(18,21,1),fpp(18,21,2)/ 4.11820527d-04,-6.51389401d-08/
      data fpp(18,22,1),fpp(18,22,2)/ 4.24839858d-04,-9.03460171d-08/
      data fpp(18,23,1),fpp(18,23,2)/ 4.27226073d-04,-1.32076991d-07/
      data fpp(19, 1,1),fpp(19, 1,2)/ 5.93047174d-03,-3.07761124d-05/
      data fpp(19, 2,1),fpp(19, 2,2)/ 5.73667711d-03,-2.40693752d-05/
      data fpp(19, 3,1),fpp(19, 3,2)/ 4.75002102d-03,-2.02775869d-05/
      data fpp(19, 4,1),fpp(19, 4,2)/ 2.65961790d-03,-6.28347712d-06/
      data fpp(19, 5,1),fpp(19, 5,2)/-2.45453371d-05, 9.52669541d-06/
      data fpp(19, 6,1),fpp(19, 6,2)/-2.31816161d-03, 1.93158955d-05/
      data fpp(19, 7,1),fpp(19, 7,2)/-3.63628335d-03, 2.03721227d-05/
      data fpp(19, 8,1),fpp(19, 8,2)/-3.96204073d-03, 1.58620138d-05/
      data fpp(19, 9,1),fpp(19, 9,2)/-3.58097200d-03, 9.08382204d-06/
      data fpp(19,10,1),fpp(19,10,2)/-2.03858212d-03,-1.92873017d-07/
      data fpp(19,11,1),fpp(19,11,2)/-7.22127224d-04,-2.65252997d-06/
      data fpp(19,12,1),fpp(19,12,2)/ 2.02399136d-05,-2.26320712d-06/
      data fpp(19,13,1),fpp(19,13,2)/ 3.52688265d-04,-1.35604155d-06/
      data fpp(19,14,1),fpp(19,14,2)/ 4.45141144d-04,-6.62826672d-07/
      data fpp(19,15,1),fpp(19,15,2)/ 4.31217560d-04,-2.34051760d-07/
      data fpp(19,16,1),fpp(19,16,2)/ 3.67470570d-04, 3.24337129d-08/
      data fpp(19,17,1),fpp(19,17,2)/ 3.02078443d-04, 1.74516909d-07/
      data fpp(19,18,1),fpp(19,18,2)/ 2.65926895d-04, 1.86898652d-07/
      data fpp(19,19,1),fpp(19,19,2)/ 2.58599153d-04, 1.05688483d-07/
      data fpp(19,20,1),fpp(19,20,2)/ 2.71278959d-04, 1.49474170d-08/
      data fpp(19,21,1),fpp(19,21,2)/ 2.80722442d-04,-5.50781507d-08/
      data fpp(19,22,1),fpp(19,22,2)/ 2.91069673d-04,-7.54348141d-08/
      data fpp(19,23,1),fpp(19,23,2)/ 2.94179724d-04,-1.09982593d-07/
      data fpp(20, 1,1),fpp(20, 1,2)/ 5.61128987d-03,-2.42654183d-05/
      data fpp(20, 2,1),fpp(20, 2,2)/ 5.33049695d-03,-1.85407633d-05/
      data fpp(20, 3,1),fpp(20, 3,2)/ 4.34092229d-03,-1.47099284d-05/
      data fpp(20, 4,1),fpp(20, 4,2)/ 2.53290848d-03,-4.25072305d-06/
      data fpp(20, 5,1),fpp(20, 5,2)/ 3.51981175d-04, 7.00242061d-06/
      data fpp(20, 6,1),fpp(20, 6,2)/-1.49754379d-03, 1.41202406d-05/
      data fpp(20, 7,1),fpp(20, 7,2)/-2.58610079d-03, 1.51238170d-05/
      data fpp(20, 8,1),fpp(20, 8,2)/-2.89824006d-03, 1.20148914d-05/
      data fpp(20, 9,1),fpp(20, 9,2)/-2.66734174d-03, 7.08381754d-06/
      data fpp(20,10,1),fpp(20,10,2)/-1.55493199d-03, 6.93016950d-08/
      data fpp(20,11,1),fpp(20,11,2)/-5.83575908d-04,-1.97542432d-06/
      data fpp(20,12,1),fpp(20,12,2)/-1.75350425d-05,-1.73820441d-06/
      data fpp(20,13,1),fpp(20,13,2)/ 2.39477027d-04,-1.05155804d-06/
      data fpp(20,14,1),fpp(20,14,2)/ 3.24598465d-04,-5.09763435d-07/
      data fpp(20,15,1),fpp(20,15,2)/ 3.02010526d-04,-1.84788220d-07/
      data fpp(20,16,1),fpp(20,16,2)/ 2.52884408d-04, 2.55163153d-08/
      data fpp(20,17,1),fpp(20,17,2)/ 2.05505493d-04, 1.34922959d-07/
      data fpp(20,18,1),fpp(20,18,2)/ 1.77144191d-04, 1.45191850d-07/
      data fpp(20,19,1),fpp(20,19,2)/ 1.71221214d-04, 8.23096425d-08/
      data fpp(20,20,1),fpp(20,20,2)/ 1.77417654d-04, 9.76958037d-09/
      data fpp(20,21,1),fpp(20,21,2)/ 1.88789706d-04,-4.45879639d-08/
      data fpp(20,22,1),fpp(20,22,2)/ 1.94381451d-04,-6.36177246d-08/
      data fpp(20,23,1),fpp(20,23,2)/ 1.97555031d-04,-9.27411377d-08/
      data fpp(21, 1,1),fpp(21, 1,2)/ 4.57238595d-03,-1.63291115d-05/
      data fpp(21, 2,1),fpp(21, 2,2)/ 4.30522544d-03,-1.22113769d-05/
      data fpp(21, 3,1),fpp(21, 3,2)/ 3.47224502d-03,-9.11978069d-06/
      data fpp(21, 4,1),fpp(21, 4,2)/ 2.14655979d-03,-2.43670029d-06/
      data fpp(21, 5,1),fpp(21, 5,2)/ 6.35759642d-04, 4.35138184d-06/
      data fpp(21, 6,1),fpp(21, 6,2)/-6.45079615d-04, 8.76237294d-06/
      data fpp(21, 7,1),fpp(21, 7,2)/-1.43347513d-03, 9.61912641d-06/
      data fpp(21, 8,1),fpp(21, 8,2)/-1.71783932d-03, 7.85072144d-06/
      data fpp(21, 9,1),fpp(21, 9,2)/-1.63087953d-03, 4.83958784d-06/
      data fpp(21,10,1),fpp(21,10,2)/-1.01217195d-03, 2.12275771d-07/
      data fpp(21,11,1),fpp(21,11,2)/-4.06995491d-04,-1.28529092d-06/
      data fpp(21,12,1),fpp(21,12,2)/-4.40431342d-05,-1.17671209d-06/
      data fpp(21,13,1),fpp(21,13,2)/ 1.25617732d-04,-7.12260709d-07/
      data fpp(21,14,1),fpp(21,14,2)/ 1.71577686d-04,-3.55445071d-07/
      data fpp(21,15,1),fpp(21,15,2)/ 1.66153207d-04,-1.25559007d-07/
      data fpp(21,16,1),fpp(21,16,2)/ 1.34404925d-04, 1.58810975d-08/
      data fpp(21,17,1),fpp(21,17,2)/ 1.03929394d-04, 9.26346167d-08/
      data fpp(21,18,1),fpp(21,18,2)/ 8.69014344d-05, 1.00180436d-07/
      data fpp(21,19,1),fpp(21,19,2)/ 8.28631838d-05, 5.62436401d-08/
      data fpp(21,20,1),fpp(21,20,2)/ 8.77551822d-05, 4.84500368d-09/
      data fpp(21,21,1),fpp(21,21,2)/ 9.48860193d-05,-3.36236548d-08/
      data fpp(21,22,1),fpp(21,22,2)/ 1.00348716d-04,-4.79503843d-08/
      data fpp(21,23,1),fpp(21,23,2)/ 1.01696746d-04,-6.91748078d-08/
      data fpp(22, 1,1),fpp(22, 1,2)/ 2.76655103d-03,-7.85121763d-06/
      data fpp(22, 2,1),fpp(22, 2,2)/ 2.59194043d-03,-5.77796474d-06/
      data fpp(22, 3,1),fpp(22, 3,2)/ 2.10202256d-03,-4.10332341d-06/
      data fpp(22, 4,1),fpp(22, 4,2)/ 1.38606358d-03,-1.03354161d-06/
      data fpp(22, 5,1),fpp(22, 5,2)/ 6.07340440d-04, 1.92548987d-06/
      data fpp(22, 6,1),fpp(22, 6,2)/-5.87389545d-05, 3.95638214d-06/
      data fpp(22, 7,1),fpp(22, 7,2)/-5.04899109d-04, 4.48018156d-06/
      data fpp(22, 8,1),fpp(22, 8,2)/-7.13490154d-04, 3.80769161d-06/
      data fpp(22, 9,1),fpp(22, 9,2)/-7.38540449d-04, 2.45065198d-06/
      data fpp(22,10,1),fpp(22,10,2)/-5.06090561d-04, 1.88198240d-07/
      data fpp(22,11,1),fpp(22,11,2)/-2.37308884d-04,-6.66044944d-07/
      data fpp(22,12,1),fpp(22,12,2)/-5.35009451d-05,-6.12818463d-07/
      data fpp(22,13,1),fpp(22,13,2)/ 3.34570417d-05,-3.80081204d-07/
      data fpp(22,14,1),fpp(22,14,2)/ 5.96323249d-05,-1.92456723d-07/
      data fpp(22,15,1),fpp(22,15,2)/ 5.23834235d-05,-7.28919054d-08/
      data fpp(22,16,1),fpp(22,16,2)/ 3.72935936d-05, 8.22434431d-09/
      data fpp(22,17,1),fpp(22,17,2)/ 2.35626443d-05, 5.07945281d-08/
      data fpp(22,18,1),fpp(22,18,2)/ 1.57888957d-05, 5.31975432d-08/
      data fpp(22,19,1),fpp(22,19,2)/ 1.61050833d-05, 2.98152992d-08/
      data fpp(22,20,1),fpp(22,20,2)/ 2.07328247d-05, 9.41260009d-10/
      data fpp(22,21,1),fpp(22,21,2)/ 2.65309148d-05,-2.09803392d-08/
      data fpp(22,22,1),fpp(22,22,2)/ 3.11352386d-05,-2.86199031d-08/
      data fpp(22,23,1),fpp(22,23,2)/ 3.30773943d-05,-4.03400485d-08/
      data fpp(23, 1,1),fpp(23, 1,2)/ 1.46236991d-03,-3.54166877d-06/
      data fpp(23, 2,1),fpp(23, 2,2)/ 1.37149284d-03,-2.59666245d-06/
      data fpp(23, 3,1),fpp(23, 3,2)/ 1.11614472d-03,-1.82528141d-06/
      data fpp(23, 4,1),fpp(23, 4,2)/ 7.55505905d-04,-4.46211909d-07/
      data fpp(23, 5,1),fpp(23, 5,2)/ 3.67598597d-04, 8.66929047d-07/
      data fpp(23, 6,1),fpp(23, 6,2)/ 2.97154332d-05, 1.80249572d-06/
      data fpp(23, 7,1),fpp(23, 7,2)/-2.08608435d-04, 2.08228806d-06/
      data fpp(23, 8,1),fpp(23, 8,2)/-3.36200067d-04, 1.79875203d-06/
      data fpp(23, 9,1),fpp(23, 9,2)/-3.68558670d-04, 1.19150383d-06/
      data fpp(23,10,1),fpp(23,10,2)/-2.81945805d-04, 7.35124953d-08/
      data fpp(23,11,1),fpp(23,11,2)/-1.40648973d-04,-3.47953812d-07/
      data fpp(23,12,1),fpp(23,12,2)/-4.67530854d-05,-3.27497249d-07/
      data fpp(23,13,1),fpp(23,13,2)/-2.16589845d-06,-2.07457194d-07/
      data fpp(23,14,1),fpp(23,14,2)/ 1.08530143d-05,-1.08673976d-07/
      data fpp(23,15,1),fpp(23,15,2)/ 9.99309960d-06,-4.12469013d-08/
      data fpp(23,16,1),fpp(23,16,2)/ 3.46070008d-06, 5.46158135d-09/
      data fpp(23,17,1),fpp(23,17,2)/-2.81997094d-06, 2.78005759d-08/
      data fpp(23,18,1),fpp(23,18,2)/-5.09701703d-06, 2.91361151d-08/
      data fpp(23,19,1),fpp(23,19,2)/-3.76351714d-06, 1.52549636d-08/
      data fpp(23,20,1),fpp(23,20,2)/ 6.73519041d-07,-1.55969625d-10/
      data fpp(23,21,1),fpp(23,21,2)/ 5.87032139d-06,-1.22310851d-08/
      data fpp(23,22,1),fpp(23,22,2)/ 9.59032955d-06,-1.63196900d-08/
      data fpp(23,23,1),fpp(23,23,2)/ 1.07936769d-05,-2.26901550d-08/
      data fpp(24, 1,1),fpp(24, 1,2)/ 6.67889311d-04,-1.56572772d-06/
      data fpp(24, 2,1),fpp(24, 2,2)/ 6.26168219d-04,-1.13774456d-06/
      data fpp(24, 3,1),fpp(24, 3,2)/ 5.11718537d-04,-7.83294040d-07/
      data fpp(24, 4,1),fpp(24, 4,2)/ 3.46552804d-04,-1.71479280d-07/
      data fpp(24, 5,1),fpp(24, 5,2)/ 1.65545172d-04, 4.18011161d-07/
      data fpp(24, 6,1),fpp(24, 6,2)/ 2.99722175d-06, 8.34634636d-07/
      data fpp(24, 7,1),fpp(24, 7,2)/-1.14827153d-04, 9.59450296d-07/
      data fpp(24, 8,1),fpp(24, 8,2)/-1.79469576d-04, 8.40364181d-07/
      data fpp(24, 9,1),fpp(24, 9,2)/-1.99224873d-04, 5.48692981d-07/
      data fpp(24,10,1),fpp(24,10,2)/-1.53166218d-04, 1.81389659d-08/
      data fpp(24,11,1),fpp(24,11,2)/-8.61752230d-05,-1.93448845d-07/
      data fpp(24,12,1),fpp(24,12,2)/-3.76467133d-05,-1.79743587d-07/
      data fpp(24,13,1),fpp(24,13,2)/-1.35134478d-05,-1.17176808d-07/
      data fpp(24,14,1),fpp(24,14,2)/-4.16438205d-06,-6.25491805d-08/
      data fpp(24,15,1),fpp(24,15,2)/-3.79582185d-06,-2.14264698d-08/
      data fpp(24,16,1),fpp(24,16,2)/-6.25639393d-06, 4.25505983d-09/
      data fpp(24,17,1),fpp(24,17,2)/-8.68276054d-06, 1.64062305d-08/
      data fpp(24,18,1),fpp(24,18,2)/-9.56082755d-06, 1.59200182d-08/
      data fpp(24,19,1),fpp(24,19,2)/-7.77101478d-06, 8.71369678d-09/
      data fpp(24,20,1),fpp(24,20,2)/-4.94690085d-06, 2.25194682d-10/
      data fpp(24,21,1),fpp(24,21,2)/-2.25220037d-06,-7.21447549d-09/
      data fpp(24,22,1),fpp(24,22,2)/-1.36556794d-07,-9.76729272d-09/
      data fpp(24,23,1),fpp(24,23,2)/ 5.47898262d-07,-1.37163536d-08/
      data fpp(25, 1,1),fpp(25, 1,2)/ 2.76552843d-04,-6.78341466d-07/
      data fpp(25, 2,1),fpp(25, 2,2)/ 2.57594288d-04,-4.86117067d-07/
      data fpp(25, 3,1),fpp(25, 3,2)/ 2.03701128d-04,-3.26790265d-07/
      data fpp(25, 4,1),fpp(25, 4,2)/ 1.27482879d-04,-5.23218747d-08/
      data fpp(25, 5,1),fpp(25, 5,2)/ 4.51807134d-05, 2.09677763d-07/
      data fpp(25, 6,1),fpp(25, 6,2)/-2.70643202d-05, 3.99210822d-07/
      data fpp(25, 7,1),fpp(25, 7,2)/-7.96829530d-05, 4.47078949d-07/
      data fpp(25, 8,1),fpp(25, 8,2)/-1.08001628d-04, 3.85273380d-07/
      data fpp(25, 9,1),fpp(25, 9,2)/-1.13981840d-04, 2.53427529d-07/
      data fpp(25,10,1),fpp(25,10,2)/-9.13093221d-05,-1.09192784d-08/
      data fpp(25,11,1),fpp(25,11,2)/-5.44101347d-05,-1.10150416d-07/
      data fpp(25,12,1),fpp(25,12,2)/-2.82600613d-05,-1.03479059d-07/
      data fpp(25,13,1),fpp(25,13,2)/-1.38603102d-05,-6.63333491d-08/
      data fpp(25,14,1),fpp(25,14,2)/-8.83548608d-06,-3.73875447d-08/
      data fpp(25,15,1),fpp(25,15,2)/-6.32981220d-06,-9.11647213d-09/
      data fpp(25,16,1),fpp(25,16,2)/-6.99512435d-06, 3.65343319d-09/
      data fpp(25,17,1),fpp(25,17,2)/-8.04898689d-06, 1.01027393d-08/
      data fpp(25,18,1),fpp(25,18,2)/-8.01967278d-06, 9.93560944d-09/
      data fpp(25,19,1),fpp(25,19,2)/-7.39242371d-06, 5.35482288d-09/
      data fpp(25,20,1),fpp(25,20,2)/-6.08591564d-06, 4.45099025d-10/
      data fpp(25,21,1),fpp(25,21,2)/-4.78151990d-06,-4.13521897d-09/
      data fpp(25,22,1),fpp(25,22,2)/-4.24410235d-06,-6.70422315d-09/
      data fpp(25,23,1),fpp(25,23,2)/-3.86526989d-06,-9.84788842d-09/
      data fpp(26, 1,1),fpp(26, 1,2)/ 7.60593185d-05,-2.94442832d-07/
      data fpp(26, 2,1),fpp(26, 2,2)/ 6.92946312d-05,-2.05114336d-07/
      data fpp(26, 3,1),fpp(26, 3,2)/ 5.03569500d-05,-1.30699824d-07/
      data fpp(26, 4,1),fpp(26, 4,2)/ 2.31156802d-05,-4.08636953d-09/
      data fpp(26, 5,1),fpp(26, 5,2)/-6.90802616d-06, 1.15845302d-07/
      data fpp(26, 6,1),fpp(26, 6,2)/-3.39399410d-05, 1.93505163d-07/
      data fpp(26, 7,1),fpp(26, 7,2)/-5.29210350d-05, 2.14134047d-07/
      data fpp(26, 8,1),fpp(26, 8,2)/-6.26839106d-05, 1.78758649d-07/
      data fpp(26, 9,1),fpp(26, 9,2)/-6.41277663d-05, 1.10031358d-07/
      data fpp(26,10,1),fpp(26,10,2)/-4.99164933d-05,-1.68733979d-08/
      data fpp(26,11,1),fpp(26,11,2)/-3.14642384d-05,-6.59377662d-08/
      data fpp(26,12,1),fpp(26,12,2)/-1.77930413d-05,-5.95755373d-08/
      data fpp(26,13,1),fpp(26,13,2)/-1.02453113d-05,-4.07600845d-08/
      data fpp(26,14,1),fpp(26,14,2)/-6.09367362d-06,-1.79841248d-08/
      data fpp(26,15,1),fpp(26,15,2)/-5.68492933d-06,-5.50341646d-09/
      data fpp(26,16,1),fpp(26,16,2)/-5.84310867d-06, 3.39779060d-09/
      data fpp(26,17,1),fpp(26,17,2)/-6.16129189d-06, 6.91225404d-09/
      data fpp(26,18,1),fpp(26,18,2)/-6.36048133d-06, 6.15319322d-09/
      data fpp(26,19,1),fpp(26,19,2)/-6.09929037d-06, 3.87497308d-09/
      data fpp(26,20,1),fpp(26,20,2)/-5.74943659d-06, 5.46914435d-10/
      data fpp(26,21,1),fpp(26,21,2)/-5.50172002d-06,-3.06263081d-09/
      data fpp(26,22,1),fpp(26,22,2)/-5.20703378d-06,-4.49639120d-09/
      data fpp(26,23,1),fpp(26,23,2)/-5.24681871d-06,-6.55180440d-09/
      data fpp(27, 1,1),fpp(27, 1,2)/ 1.83856233d-05,-4.81741997d-08/
      data fpp(27, 2,1),fpp(27, 2,2)/ 1.58789625d-05,-2.88516005d-08/
      data fpp(27, 3,1),fpp(27, 3,2)/ 8.91858570d-06,-1.16193983d-08/
      data fpp(27, 4,1),fpp(27, 4,2)/-9.08480054d-07, 1.29291935d-08/
      data fpp(27, 5,1),fpp(27, 5,2)/-1.14062782d-05, 3.67026242d-08/
      data fpp(27, 6,1),fpp(27, 6,2)/-2.03680169d-05, 4.90603096d-08/
      data fpp(27, 7,1),fpp(27, 7,2)/-2.63954186d-05, 4.78561374d-08/
      data fpp(27, 8,1),fpp(27, 8,2)/-2.88474541d-05, 3.55151410d-08/
      data fpp(27, 9,1),fpp(27, 9,2)/-2.80657811d-05, 1.88832989d-08/
      data fpp(27,10,1),fpp(27,10,2)/-2.13758591d-05,-1.32074672d-08/
      data fpp(27,11,1),fpp(27,11,2)/-1.34022176d-05,-2.42534301d-08/
      data fpp(27,12,1),fpp(27,12,2)/-7.79084533d-06,-2.11788126d-08/
      data fpp(27,13,1),fpp(27,13,2)/-4.69391106d-06,-1.28313197d-08/
      data fpp(27,14,1),fpp(27,14,2)/-3.64123611d-06,-6.09590878d-09/
      data fpp(27,15,1),fpp(27,15,2)/-3.42030590d-06,-5.85045207d-10/
      data fpp(27,16,1),fpp(27,16,2)/-3.69311181d-06, 1.23608960d-09/
      data fpp(27,17,1),fpp(27,17,2)/-3.95163089d-06, 2.84068681d-09/
      data fpp(27,18,1),fpp(27,18,2)/-3.96871962d-06, 2.40116312d-09/
      data fpp(27,19,1),fpp(27,19,2)/-3.80591704d-06, 1.95466071d-09/
      data fpp(27,20,1),fpp(27,20,2)/-3.52873240d-06,-1.98059629d-11/
      data fpp(27,21,1),fpp(27,21,2)/-3.18408000d-06,-1.27543686d-09/
      data fpp(27,22,1),fpp(27,22,2)/-3.01684749d-06,-2.07844661d-09/
      data fpp(27,23,1),fpp(27,23,2)/-2.90690894d-06,-3.01077669d-09/
      data fpp(28, 1,1),fpp(28, 1,2)/-8.09018117d-05,-1.55557436d-09/
      data fpp(28, 2,1),fpp(28, 2,2)/-7.67104813d-05, 1.51114869d-09/
      data fpp(28, 3,1),fpp(28, 3,2)/-6.46712929d-05, 5.11097947d-09/
      data fpp(28, 4,1),fpp(28, 4,2)/-4.73217600d-05, 6.84493329d-09/
      data fpp(28, 5,1),fpp(28, 5,2)/-2.79868609d-05, 1.31092873d-08/
      data fpp(28, 6,1),fpp(28, 6,2)/-1.01079916d-05, 1.27179172d-08/
      data fpp(28, 7,1),fpp(28, 7,2)/ 3.40270929d-06, 1.04190438d-08/
      data fpp(28, 8,1),fpp(28, 8,2)/ 1.18737271d-05, 8.00590745d-09/
      data fpp(28, 9,1),fpp(28, 9,2)/ 1.57108905d-05, 7.57326400d-10/
      data fpp(28,10,1),fpp(28,10,2)/ 1.37399295d-05,-6.87493290d-09/
      data fpp(28,11,1),fpp(28,11,2)/ 8.03310880d-06,-9.85759480d-09/
      data fpp(28,12,1),fpp(28,12,2)/ 3.53642267d-06,-6.49468795d-09/
      data fpp(28,13,1),fpp(28,13,2)/ 1.06095553d-06,-4.36365343d-09/
      data fpp(28,14,1),fpp(28,14,2)/-8.21381945d-07,-2.45069834d-09/
      data fpp(28,15,1),fpp(28,15,2)/-1.27384705d-06, 3.66446770d-10/
      data fpp(28,16,1),fpp(28,16,2)/-1.52444410d-06,-2.15088728d-10/
      data fpp(28,17,1),fpp(28,17,2)/-1.55218456d-06, 1.09390814d-09/
      data fpp(28,18,1),fpp(28,18,2)/-1.46464019d-06, 6.39456145d-10/
      data fpp(28,19,1),fpp(28,19,2)/-1.47704148d-06, 5.48267270d-10/
      data fpp(28,20,1),fpp(28,20,2)/-1.49563380d-06, 7.67474755d-10/
      data fpp(28,21,1),fpp(28,21,2)/-1.32196000d-06,-1.81816628d-09/
      data fpp(28,22,1),fpp(28,22,2)/-1.32557626d-06,-9.48096391d-11/
      data fpp(28,23,1),fpp(28,23,2)/-1.18554553d-06, 3.97404818d-10/
 
      data fpppp( 1, 1),fpppp( 1, 2)/-1.13950064d-01,-4.95460979d-02/
      data fpppp( 1, 3),fpppp( 1, 4)/ 2.93266995d-02, 5.75585867d-02/
      data fpppp( 1, 5),fpppp( 1, 6)/-3.05636266d-02, 4.47037775d-02/
      data fpppp( 1, 7),fpppp( 1, 8)/-1.45408453d-02, 2.75729663d-02/
      data fpppp( 1, 9),fpppp( 1,10)/-8.55263470d-03, 4.26624309d-03/
      data fpppp( 1,11),fpppp( 1,12)/-9.92989477d-04, 7.07617029d-04/
      data fpppp( 1,13),fpppp( 1,14)/-4.15197955d-04,-2.07061586d-04/
      data fpppp( 1,15),fpppp( 1,16)/ 3.18051273d-04, 1.67185316d-05/
      data fpppp( 1,17),fpppp( 1,18)/-3.55557250d-04,-1.24662454d-04/
      data fpppp( 1,19),fpppp( 1,20)/ 1.91604150d-04, 9.02245805d-05/
      data fpppp( 1,21),fpppp( 1,22)/-8.49746901d-07,-1.78156802d-05/
      data fpppp( 1,23) /            -5.59554405d-05 /
      data fpppp( 2, 1),fpppp( 2, 2)/-8.93422144d-02,-3.96686805d-02/
      data fpppp( 2, 3),fpppp( 2, 4)/ 2.75141277d-02, 3.34144761d-02/
      data fpppp( 2, 5),fpppp( 2, 6)/-1.40059117d-02, 2.21844150d-02/
      data fpppp( 2, 7),fpppp( 2, 8)/ 3.49089589d-03, 1.31966367d-02/
      data fpppp( 2, 9),fpppp( 2,10)/-3.78037269d-03, 2.36619549d-03/
      data fpppp( 2,11),fpppp( 2,12)/-5.35865623d-04, 5.33402580d-04/
      data fpppp( 2,13),fpppp( 2,14)/-3.35786065d-04,-1.54185568d-04/
      data fpppp( 2,15),fpppp( 2,16)/ 2.36694387d-04, 2.65239434d-05/
      data fpppp( 2,17),fpppp( 2,18)/-2.79306461d-04,-8.38122592d-05/
      data fpppp( 2,19),fpppp( 2,20)/ 1.43481328d-04, 7.19494956d-05/
      data fpppp( 2,21),fpppp( 2,22)/-3.20475987d-06,-1.57702813d-05/
      data fpppp( 2,23) /            -4.62182982d-05 /
      data fpppp( 3, 1),fpppp( 3, 2)/-6.44724810d-02,-2.37297357d-02/
      data fpppp( 3, 3),fpppp( 3, 4)/ 9.38817366d-03, 6.91930090d-02/
      data fpppp( 3, 5),fpppp( 3, 6)/-9.37254708d-02, 4.68405195d-02/
      data fpppp( 3, 7),fpppp( 3, 8)/ 2.37223382d-02,-8.33025589d-03/
      data fpppp( 3, 9),fpppp( 3,10)/ 7.35138005d-03,-4.76765747d-03/
      data fpppp( 3,11),fpppp( 3,12)/ 2.42508702d-03,-1.66135128d-04/
      data fpppp( 3,13),fpppp( 3,14)/-1.12661710d-04,-1.24392662d-04/
      data fpppp( 3,15),fpppp( 3,16)/ 1.53481184d-04, 4.23821978d-05/
      data fpppp( 3,17),fpppp( 3,18)/-2.13552924d-04,-1.99009461d-05/
      data fpppp( 3,19),fpppp( 3,20)/ 8.17363021d-05, 5.46068201d-05/
      data fpppp( 3,21),fpppp( 3,22)/-7.03450903d-06,-1.29593958d-05/
      data fpppp( 3,23) /            -3.48032661d-05 /
      data fpppp( 4, 1),fpppp( 4, 2)/-4.05193415d-02,-2.90061367d-02/
      data fpppp( 4, 3),fpppp( 4, 4)/ 4.83590572d-02,-1.04757710d-01/
      data fpppp( 4, 5),fpppp( 4, 6)/ 1.63525429d-01,-9.36175103d-02/
      data fpppp( 4, 7),fpppp( 4, 8)/ 3.62548267d-02,-4.83017774d-03/
      data fpppp( 4, 9),fpppp( 4,10)/-3.77508476d-03, 6.41680835d-03/
      data fpppp( 4,11),fpppp( 4,12)/-3.37736110d-03, 9.72958568d-04/
      data fpppp( 4,13),fpppp( 4,14)/-3.92530983d-04,-1.38088645d-05/
      data fpppp( 4,15),fpppp( 4,16)/ 7.67650880d-05, 3.70555030d-05/
      data fpppp( 4,17),fpppp( 4,18)/-1.11059004d-04,-3.67035476d-05/
      data fpppp( 4,19),fpppp( 4,20)/ 6.76689894d-05, 3.40007119d-05/
      data fpppp( 4,21),fpppp( 4,22)/-5.70268154d-06,-1.28277133d-05/
      data fpppp( 4,23) /            -2.92608483d-05 /
      data fpppp( 5, 1),fpppp( 5, 2)/-3.60807167d-02,-3.08069901d-02/
      data fpppp( 5, 3),fpppp( 5, 4)/ 6.24346107d-02,-1.52211348d-01/
      data fpppp( 5, 5),fpppp( 5, 6)/ 2.30432027d-01,-1.37374382d-01/
      data fpppp( 5, 7),fpppp( 5, 8)/ 4.79237792d-02,-1.23436259d-02/
      data fpppp( 5, 9),fpppp( 5,10)/ 4.28862579d-03,-2.40560000d-03/
      data fpppp( 5,11),fpppp( 5,12)/ 1.41418679d-03,-2.96272798d-04/
      data fpppp( 5,13),fpppp( 5,14)/-3.91491766d-05,-8.66189572d-05/
      data fpppp( 5,15),fpppp( 5,16)/ 7.74615905d-05, 2.06303607d-05/
      data fpppp( 5,17),fpppp( 5,18)/-6.85124672d-05,-1.82337976d-05/
      data fpppp( 5,19),fpppp( 5,20)/ 4.84448857d-05, 2.27906852d-05/
      data fpppp( 5,21),fpppp( 5,22)/-8.17332133d-06,-1.10958778d-05/
      data fpppp( 5,23) /            -2.20302772d-05 /
      data fpppp( 6, 1),fpppp( 6, 2)/-2.66843644d-03,-1.49653813d-04/
      data fpppp( 6, 3),fpppp( 6, 4)/-7.56824123d-02, 1.21965223d-01/
      data fpppp( 6, 5),fpppp( 6, 6)/-9.01492623d-02, 1.11781100d-01/
      data fpppp( 6, 7),fpppp( 6, 8)/-7.10173438d-02, 1.33216615d-02/
      data fpppp( 6, 9),fpppp( 6,10)/-2.00777856d-03, 1.06010202d-03/
      data fpppp( 6,11),fpppp( 6,12)/-1.41747391d-04, 6.31474938d-05/
      data fpppp( 6,13),fpppp( 6,14)/-1.19930485d-04,-5.16174823d-05/
      data fpppp( 6,15),fpppp( 6,16)/ 4.68954253d-05, 2.27777278d-05/
      data fpppp( 6,17),fpppp( 6,18)/-4.10966969d-05,-4.77365547d-06/
      data fpppp( 6,19),fpppp( 6,20)/ 3.41666120d-05, 1.38683645d-05/
      data fpppp( 6,21),fpppp( 6,22)/-8.74644542d-06,-1.02509433d-05/
      data fpppp( 6,23) /            -1.77869590d-05 /
      data fpppp( 7, 1),fpppp( 7, 2)/-1.08695155d-02,-2.47549723d-03/
      data fpppp( 7, 3),fpppp( 7, 4)/-4.65659504d-02, 9.30392465d-02/
      data fpppp( 7, 5),fpppp( 7, 6)/-6.87686317d-02, 4.98133484d-02/
      data fpppp( 7, 7),fpppp( 7, 8)/-2.28846877d-02, 5.96092789d-03/
      data fpppp( 7, 9),fpppp( 7,10)/-2.31810552d-03, 4.43659118d-04/
      data fpppp( 7,11),fpppp( 7,12)/-1.17936287d-05,-7.32164491d-06/
      data fpppp( 7,13),fpppp( 7,14)/-8.41393050d-05,-3.98311246d-05/
      data fpppp( 7,15),fpppp( 7,16)/ 1.75504757d-05, 2.01944984d-05/
      data fpppp( 7,17),fpppp( 7,18)/-6.30267139d-06, 7.32098622d-06/
      data fpppp( 7,19),fpppp( 7,20)/ 1.84342330d-05, 3.13039584d-06/
      data fpppp( 7,21),fpppp( 7,22)/-8.96384244d-06,-8.56070553d-06/
      data fpppp( 7,23) /            -1.17282472d-05 /
      data fpppp( 8, 1),fpppp( 8, 2)/ 8.69749282d-03,-1.58330597d-03/
      data fpppp( 8, 3),fpppp( 8, 4)/-3.09864258d-02, 6.53857803d-03/
      data fpppp( 8, 5),fpppp( 8, 6)/ 5.02418406d-02,-3.77916618d-03/
      data fpppp( 8, 7),fpppp( 8, 8)/-1.71657077d-02,-4.01589149d-03/
      data fpppp( 8, 9),fpppp( 8,10)/ 1.79335672d-03,-4.71667541d-04/
      data fpppp( 8,11),fpppp( 8,12)/ 1.57242017d-04,-7.07023109d-05/
      data fpppp( 8,13),fpppp( 8,14)/-5.12568202d-05,-3.83785237d-05/
      data fpppp( 8,15),fpppp( 8,16)/ 7.86921395d-06, 1.49886143d-05/
      data fpppp( 8,17),fpppp( 8,18)/ 7.79349763d-06, 1.09909144d-05/
      data fpppp( 8,19),fpppp( 8,20)/ 1.09255258d-05,-8.97430452d-07/
      data fpppp( 8,21),fpppp( 8,22)/-7.44732412d-06,-7.52219474d-06/
      data fpppp( 8,23) /            -9.44707195d-06 /
      data fpppp( 9, 1),fpppp( 9, 2)/-9.67027664d-03,-1.08191971d-02/
      data fpppp( 9, 3),fpppp( 9, 4)/ 4.90599473d-02,-1.04659136d-01/
      data fpppp( 9, 5),fpppp( 9, 6)/ 1.20310404d-01,-8.38501633d-02/
      data fpppp( 9, 7),fpppp( 9, 8)/ 3.43447829d-02,-4.52077964d-03/
      data fpppp( 9, 9),fpppp( 9,10)/ 4.36285150d-04,-9.46966955d-06/
      data fpppp( 9,11),fpppp( 9,12)/ 1.31919001d-05,-4.05837579d-05/
      data fpppp( 9,13),fpppp( 9,14)/-4.86611688d-05,-2.60591160d-05/
      data fpppp( 9,15),fpppp( 9,16)/-1.06223497d-06, 1.21949938d-05/
      data fpppp( 9,17),fpppp( 9,18)/ 1.12977873d-05, 1.16649813d-05/
      data fpppp( 9,19),fpppp( 9,20)/ 6.65605706d-06,-1.41987223d-06/
      data fpppp( 9,21),fpppp( 9,22)/-6.50246157d-06,-6.05891537d-06/
      data fpppp( 9,23) /            -7.19426504d-06 /
      data fpppp(10, 1),fpppp(10, 2)/-4.86540151d-03, 3.89286507d-03/
      data fpppp(10, 3),fpppp(10, 4)/-3.48979033d-03, 4.56207812d-02/
      data fpppp(10, 5),fpppp(10, 6)/-9.62641760d-02, 5.34112468d-02/
      data fpppp(10, 7),fpppp(10, 8)/-3.79737294d-03, 2.17765894d-03/
      data fpppp(10, 9),fpppp(10,10)/ 4.56208566d-07, 3.87611801d-05/
      data fpppp(10,11),fpppp(10,12)/-1.37129913d-05,-3.78041242d-05/
      data fpppp(10,13),fpppp(10,14)/-3.85592649d-05,-2.06405049d-05/
      data fpppp(10,15),fpppp(10,16)/-2.76754386d-06, 8.14598228d-06/
      data fpppp(10,17),fpppp(10,18)/ 1.13043366d-05, 9.81865567d-06/
      data fpppp(10,19),fpppp(10,20)/ 5.11328176d-06,-1.50471907d-06/
      data fpppp(10,21),fpppp(10,22)/-4.86931156d-06,-4.94457750d-06/
      data fpppp(10,23) /            -5.95965103d-06 /
      data fpppp(11, 1),fpppp(11, 2)/ 1.11756552d-03,-9.96487858d-05/
      data fpppp(11, 3),fpppp(11, 4)/ 1.19349537d-02,-2.24118027d-02/
      data fpppp(11, 5),fpppp(11, 6)/ 1.12127739d-02,-7.79714429d-03/
      data fpppp(11, 7),fpppp(11, 8)/ 6.09871706d-03, 2.72871617d-04/
      data fpppp(11, 9),fpppp(11,10)/ 2.35850954d-04,-1.15017258d-05/
      data fpppp(11,11),fpppp(11,12)/-9.66417272d-06,-3.85661188d-05/
      data fpppp(11,13),fpppp(11,14)/-2.90520404d-05,-1.71514160d-05/
      data fpppp(11,15),fpppp(11,16)/-2.07711496d-06, 4.90173007d-06/
      data fpppp(11,17),fpppp(11,18)/ 9.26178002d-06, 8.33208907d-06/
      data fpppp(11,19),fpppp(11,20)/ 3.56713019d-06,-1.10820169d-06/
      data fpppp(11,21),fpppp(11,22)/-3.44880558d-06,-3.87177080d-06/
      data fpppp(11,23) /            -4.84263277d-06 /
      data fpppp(12, 1),fpppp(12, 2)/ 1.78352601d-03, 1.92147691d-03/
      data fpppp(12, 3),fpppp(12, 4)/-6.69179857d-03, 1.53242182d-02/
      data fpppp(12, 5),fpppp(12, 6)/-1.43985010d-02, 1.36674766d-03/
      data fpppp(12, 7),fpppp(12, 8)/ 1.72909708d-03, 5.87747849d-04/
      data fpppp(12, 9),fpppp(12,10)/ 1.72614604d-04,-2.74478563d-06/
      data fpppp(12,11),fpppp(12,12)/-1.79429103d-05,-3.38305219d-05/
      data fpppp(12,13),fpppp(12,14)/-2.36834966d-05,-1.12710181d-05/
      data fpppp(12,15),fpppp(12,16)/-4.56432571d-06, 4.37560204d-06/
      data fpppp(12,17),fpppp(12,18)/ 6.89485442d-06, 6.31923928d-06/
      data fpppp(12,19),fpppp(12,20)/ 2.72688154d-06,-7.43461630d-07/
      data fpppp(12,21),fpppp(12,22)/-2.37020026d-06,-2.77841528d-06/
      data fpppp(12,23) /            -3.53477990d-06 /
      data fpppp(13, 1),fpppp(13, 2)/-6.60909589d-03,-2.19493283d-03/
      data fpppp(13, 3),fpppp(13, 4)/ 9.05521423d-03,-3.62058271d-03/
      data fpppp(13, 5),fpppp(13, 6)/-2.94124614d-03,-1.46164716d-04/
      data fpppp(13, 7),fpppp(13, 8)/ 5.33100091d-04, 3.64047840d-04/
      data fpppp(13, 9),fpppp(13,10)/ 1.12248623d-04,-8.17582352d-07/
      data fpppp(13,11),fpppp(13,12)/-2.29933809d-05,-2.74027076d-05/
      data fpppp(13,13),fpppp(13,14)/-1.54936816d-05,-8.92701449d-06/
      data fpppp(13,15),fpppp(13,16)/-1.84873248d-06, 1.46977115d-06/
      data fpppp(13,17),fpppp(13,18)/ 4.39880138d-06, 4.01353384d-06/
      data fpppp(13,19),fpppp(13,20)/ 1.78657535d-06,-4.32453399d-07/
      data fpppp(13,21),fpppp(13,22)/-1.25655619d-06,-1.78226546d-06/
      data fpppp(13,23) /            -2.39323001d-06 /
      data fpppp(14, 1),fpppp(14, 2)/ 5.02094369d-03, 2.09410879d-03/
      data fpppp(14, 3),fpppp(14, 4)/-2.88136199d-03,-6.86607207d-04/
      data fpppp(14, 5),fpppp(14, 6)/ 4.59148386d-04,-2.45780287d-04/
      data fpppp(14, 7),fpppp(14, 8)/ 3.13765689d-04, 1.58699730d-04/
      data fpppp(14, 9),fpppp(14,10)/ 7.60920099d-05,-7.00766736d-06/
      data fpppp(14,11),fpppp(14,12)/-2.25335407d-05,-1.95759666d-05/
      data fpppp(14,13),fpppp(14,14)/-1.16625260d-05,-5.08060915d-06/
      data fpppp(14,15),fpppp(14,16)/-2.16125477d-06, 1.08704017d-06/
      data fpppp(14,17),fpppp(14,18)/ 2.58354321d-06, 2.43048596d-06/
      data fpppp(14,19),fpppp(14,20)/ 9.97771522d-07,-5.44032971d-08/
      data fpppp(14,21),fpppp(14,22)/-8.83815390d-07,-7.23882786d-07/
      data fpppp(14,23) /            -8.46620096d-07 /
      data fpppp(15, 1),fpppp(15, 2)/ 4.07511427d-04, 1.53003200d-04/
      data fpppp(15, 3),fpppp(15, 4)/-1.93489938d-05,-4.79247303d-04/
      data fpppp(15, 5),fpppp(15, 6)/-2.33185485d-04, 4.17569635d-05/
      data fpppp(15, 7),fpppp(15, 8)/ 1.51320365d-04, 1.23305352d-04/
      data fpppp(15, 9),fpppp(15,10)/ 4.98650227d-05,-7.95718921d-06/
      data fpppp(15,11),fpppp(15,12)/-1.94726333d-05,-1.65825736d-05/
      data fpppp(15,13),fpppp(15,14)/-8.55056632d-06,-4.39508893d-06/
      data fpppp(15,15),fpppp(15,16)/-1.27228296d-06, 5.75421006d-07/
      data fpppp(15,17),fpppp(15,18)/ 1.80462308d-06, 1.72982615d-06/
      data fpppp(15,19),fpppp(15,20)/ 9.00511405d-07,-1.88788295d-07/
      data fpppp(15,21),fpppp(15,22)/-6.47381303d-07,-5.22532877d-07/
      data fpppp(15,23) /            -5.64382003d-07 /
      data fpppp(16, 1),fpppp(16, 2)/ 6.30784705d-04, 2.16490199d-04/
      data fpppp(16, 3),fpppp(16, 4)/-4.66503287d-04,-2.09050340d-04/
      data fpppp(16, 5),fpppp(16, 6)/ 3.91618465d-05, 5.06460157d-05/
      data fpppp(16, 7),fpppp(16, 8)/ 1.12010225d-04, 7.91957791d-05/
      data fpppp(16, 9),fpppp(16,10)/ 3.49228573d-05,-7.95690828d-06/
      data fpppp(16,11),fpppp(16,12)/-1.81975542d-05,-1.21938940d-05/
      data fpppp(16,13),fpppp(16,14)/-6.69295983d-06,-2.99787537d-06/
      data fpppp(16,15),fpppp(16,16)/-1.35650135d-06, 4.47667848d-07/
      data fpppp(16,17),fpppp(16,18)/ 1.27928426d-06, 1.25853827d-06/
      data fpppp(16,19),fpppp(16,20)/ 4.75547791d-07,-4.02320632d-08/
      data fpppp(16,21),fpppp(16,22)/-3.62870174d-07,-3.41354055d-07/
      data fpppp(16,23) /            -4.18167718d-07 /
      data fpppp(17, 1),fpppp(17, 2)/ 6.11353985d-05,-1.04601973d-05/
      data fpppp(17, 3),fpppp(17, 4)/-1.22458816d-04,-9.30468543d-05/
      data fpppp(17, 5),fpppp(17, 6)/ 1.96046969d-05, 7.17327135d-05/
      data fpppp(17, 7),fpppp(17, 8)/ 7.11021797d-05, 4.97004044d-05/
      data fpppp(17, 9),fpppp(17,10)/ 2.28776772d-05,-8.58878086d-06/
      data fpppp(17,11),fpppp(17,12)/-1.25038753d-05,-8.40545686d-06/
      data fpppp(17,13),fpppp(17,14)/-4.25833381d-06,-2.29589357d-06/
      data fpppp(17,15),fpppp(17,16)/-5.46079721d-07,-1.32113141d-08/
      data fpppp(17,17),fpppp(17,18)/ 7.78061208d-07, 7.07329676d-07/
      data fpppp(17,19),fpppp(17,20)/ 4.06376990d-07,-1.03217847d-07/
      data fpppp(17,21),fpppp(17,22)/-1.77988099d-07,-1.14042788d-07/
      data fpppp(17,23) /            -8.97304938d-08 /
      data fpppp(18, 1),fpppp(18, 2)/ 1.94958158d-05,-1.84003059d-05/
      data fpppp(18, 3),fpppp(18, 4)/-9.06799803d-05,-4.26172202d-05/
      data fpppp(18, 5),fpppp(18, 6)/ 2.82178072d-05, 5.38043431d-05/
      data fpppp(18, 7),fpppp(18, 8)/ 5.22577641d-05, 3.52745601d-05/
      data fpppp(18, 9),fpppp(18,10)/ 1.54818994d-05,-5.71034290d-06/
      data fpppp(18,11),fpppp(18,12)/-8.97291148d-06,-5.45803642d-06/
      data fpppp(18,13),fpppp(18,14)/-2.75270646d-06,-1.38878639d-06/
      data fpppp(18,15),fpppp(18,16)/-7.39234093d-07, 2.55630752d-07/
      data fpppp(18,17),fpppp(18,18)/ 3.66711861d-07, 4.68725887d-07/
      data fpppp(18,19),fpppp(18,20)/ 1.14371865d-07, 1.14810138d-07/
      data fpppp(18,21),fpppp(18,22)/-1.07431795d-07,-9.51640235d-08/
      data fpppp(18,23) /            -1.49899024d-07 /
      data fpppp(19, 1),fpppp(19, 2)/-2.03976105d-05,-2.94773066d-05/
      data fpppp(19, 3),fpppp(19, 4)/-5.19799119d-05,-2.75023350d-05/
      data fpppp(19, 5),fpppp(19, 6)/ 1.94868255d-05, 4.32863047d-05/
      data fpppp(19, 7),fpppp(19, 8)/ 4.14866414d-05, 2.89345760d-05/
      data fpppp(19, 9),fpppp(19,10)/ 1.24133234d-05,-4.89211376d-06/
      data fpppp(19,11),fpppp(19,12)/-6.40096745d-06,-3.94928188d-06/
      data fpppp(19,13),fpppp(19,14)/-2.39703221d-06,-8.62317639d-07/
      data fpppp(19,15),fpppp(19,16)/-5.36285053d-07, 1.80535300d-08/
      data fpppp(19,17),fpppp(19,18)/ 3.65362702d-07, 2.74930456d-07/
      data fpppp(19,19),fpppp(19,20)/ 2.64343762d-07,-1.31852605d-07/
      data fpppp(19,21),fpppp(19,22)/ 6.88873101d-08,-8.94717534d-08/
      data fpppp(19,23) /            -1.45231110d-07 /
      data fpppp(20, 1),fpppp(20, 2)/-2.47490095d-05,-2.67831968d-05/
      data fpppp(20, 3),fpppp(20, 4)/-3.82258207d-05,-1.67389164d-05/
      data fpppp(20, 5),fpppp(20, 6)/ 1.56822459d-05, 3.35464940d-05/
      data fpppp(20, 7),fpppp(20, 8)/ 3.27640915d-05, 2.17373951d-05/
      data fpppp(20, 9),fpppp(20,10)/ 1.06153485d-05,-3.67795624d-06/
      data fpppp(20,11),fpppp(20,12)/-4.36674352d-06,-3.17398271d-06/
      data fpppp(20,13),fpppp(20,14)/-1.47905338d-06,-1.22324170d-06/
      data fpppp(20,15),fpppp(20,16)/-9.05424425d-08,-6.87924040d-09/
      data fpppp(20,17),fpppp(20,18)/ 2.22891560d-07, 2.56369736d-07/
      data fpppp(20,19),fpppp(20,20)/ 9.79290793d-08, 7.90788829d-08/
      data fpppp(20,21),fpppp(20,22)/-1.03707835d-07,-1.10659937d-08/
      data fpppp(20,23) /             2.88197482d-09 /
      data fpppp(21, 1),fpppp(21, 2)/-2.58871811d-05,-2.19732338d-05/
      data fpppp(21, 3),fpppp(21, 4)/-2.20166606d-05,-8.20927792d-06/
      data fpppp(21, 5),fpppp(21, 6)/ 1.04261909d-05, 2.16951285d-05/
      data fpppp(21, 7),fpppp(21, 8)/ 2.09797934d-05, 1.53532168d-05/
      data fpppp(21, 9),fpppp(21,10)/ 6.72509183d-06,-1.16460288d-06/
      data fpppp(21,11),fpppp(21,12)/-2.87854759d-06,-1.85465298d-06/
      data fpppp(21,13),fpppp(21,14)/-1.30032994d-06,-3.66081955d-07/
      data fpppp(21,15),fpppp(21,16)/-3.18408285d-07, 6.02870129d-08/
      data fpppp(21,17),fpppp(21,18)/ 1.53625195d-07, 1.32066558d-07/
      data fpppp(21,19),fpppp(21,20)/ 9.74910931d-08, 1.37840126d-08/
      data fpppp(21,21),fpppp(21,22)/-1.82968292d-08,-4.06851171d-08/
      data fpppp(21,23) /            -6.58427067d-08 /
      data fpppp(22, 1),fpppp(22, 2)/-1.62944339d-05,-1.23892955d-05/
      data fpppp(22, 3),fpppp(22, 4)/-9.82212755d-06,-2.57206329d-06/
      data fpppp(22, 5),fpppp(22, 6)/ 5.04698538d-06, 9.41861956d-06/
      data fpppp(22, 7),fpppp(22, 8)/ 1.00591541d-05, 7.36135030d-06/
      data fpppp(22, 9),fpppp(22,10)/ 4.54522479d-06,-3.63320806d-07/
      data fpppp(22,11),fpppp(22,12)/-9.12034267d-07,-1.08696641d-06/
      data fpppp(22,13),fpppp(22,14)/-5.51097217d-07,-3.55606933d-07/
      data fpppp(22,15),fpppp(22,16)/-3.19261287d-08, 1.28557406d-08/
      data fpppp(22,17),fpppp(22,18)/ 6.20359984d-08, 9.64323038d-08/
      data fpppp(22,19),fpppp(22,20)/ 3.76309666d-08, 1.17370495d-08/
      data fpppp(22,21),fpppp(22,22)/-1.43582355d-08,-2.59300890d-08/
      data fpppp(22,23) /            -4.16514942d-08 /
      data fpppp(23, 1),fpppp(23, 2)/-8.97536427d-06,-6.52022214d-06/
      data fpppp(23, 3),fpppp(23, 4)/-4.41679586d-06,-1.08236412d-06/
      data fpppp(23, 5),fpppp(23, 6)/ 2.20181512d-06, 4.28089834d-06/
      data fpppp(23, 7),fpppp(23, 8)/ 4.56882256d-06, 4.01954777d-06/
      data fpppp(23, 9),fpppp(23,10)/ 2.20891375d-06, 4.43288970d-07/
      data fpppp(23,11),fpppp(23,12)/-7.01031567d-07,-4.83219351d-07/
      data fpppp(23,13),fpppp(23,14)/-3.24613086d-07,-1.12424758d-07/
      data fpppp(23,15),fpppp(23,16)/-5.84175301d-08, 5.74578927d-09/
      data fpppp(23,17),fpppp(23,18)/ 5.05380827d-08, 3.23193767d-08/
      data fpppp(23,19),fpppp(23,20)/ 3.68171687d-08, 6.62412614d-09/
      data fpppp(23,21),fpppp(23,22)/-1.77277038d-08,-2.43209622d-08/
      data fpppp(23,23) /            -3.59880983d-08 /
      data fpppp(24, 1),fpppp(24, 2)/-3.81069634d-06,-2.86704126d-06/
      data fpppp(24, 3),fpppp(24, 4)/-2.17600022d-06,-6.00810021d-07/
      data fpppp(24, 5),fpppp(24, 6)/ 7.77184585d-07, 1.92239509d-06/
      data fpppp(24, 7),fpppp(24, 8)/ 2.26689325d-06, 1.77370040d-06/
      data fpppp(24, 9),fpppp(24,10)/ 1.41121552d-06, 1.36580924d-08/
      data fpppp(24,11),fpppp(24,12)/-2.09907443d-07,-2.81777448d-07/
      data fpppp(24,13),fpppp(24,14)/-1.26697420d-07,-9.84848548d-08/
      data fpppp(24,15),fpppp(24,16)/-1.81934948d-08, 1.51089692d-09/
      data fpppp(24,17),fpppp(24,18)/ 1.42022359d-08, 3.45781354d-08/
      data fpppp(24,19),fpppp(24,20)/ 7.55800871d-09,-2.75209950d-09/
      data fpppp(24,21),fpppp(24,22)/-4.31441807d-09,-1.47336426d-08/
      data fpppp(24,23) /            -2.26223225d-08 /
      data fpppp(25, 1),fpppp(25, 2)/-1.90716556d-06,-1.38658248d-06/
      data fpppp(25, 3),fpppp(25, 4)/-9.30809502d-07,-2.48201155d-07/
      data fpppp(25, 5),fpppp(25, 6)/ 4.63474240d-07, 8.08015853d-07/
      data fpppp(25, 7),fpppp(25, 8)/ 1.01479855d-06, 9.64779739d-07/
      data fpppp(25, 9),fpppp(25,10)/ 4.87313717d-07, 1.33645503d-07/
      data fpppp(25,11),fpppp(25,12)/-1.68295570d-07,-1.05410073d-07/
      data fpppp(25,13),fpppp(25,14)/-1.15083471d-07, 3.24833885d-09/
      data fpppp(25,15),fpppp(25,16)/-4.90589001d-08, 2.72810024d-09/
      data fpppp(25,17),fpppp(25,18)/ 1.48334750d-08, 2.92859888d-09/
      data fpppp(25,19),fpppp(25,20)/ 9.32822706d-09, 5.14032712d-10/
      data fpppp(25,21),fpppp(25,22)/-1.15110981d-08,-4.88331831d-10/
      data fpppp(25,23) /             3.94932085d-09 /
      data fpppp(26, 1),fpppp(26, 2)/-6.44344295d-07,-4.81623117d-07/
      data fpppp(26, 3),fpppp(26, 4)/-3.50681797d-07,-1.08510972d-07/
      data fpppp(26, 5),fpppp(26, 6)/ 1.16940929d-07, 3.58777216d-07/
      data fpppp(26, 7),fpppp(26, 8)/ 3.80147223d-07, 3.33006303d-07/
      data fpppp(26, 9),fpppp(26,10)/ 2.84392339d-07, 6.25889147d-09/
      data fpppp(26,11),fpppp(26,12)/-5.49689873d-08,-7.32464173d-08/
      data fpppp(26,13),fpppp(26,14)/-1.94533612d-08,-5.27056818d-08/
      data fpppp(26,15),fpppp(26,16)/ 5.70248624d-09,-4.11968076d-09/
      data fpppp(26,17),fpppp(26,18)/ 1.17600445d-09, 6.55528958d-09/
      data fpppp(26,19),fpppp(26,20)/ 2.25661322d-10,-2.13816574d-09/
      data fpppp(26,21),fpppp(26,22)/ 2.19876957d-09,-3.83873254d-09/
      data fpppp(26,23) /            -6.91210965d-09 /
      data fpppp(27, 1),fpppp(27, 2)/-2.42556156d-07,-1.76295772d-07/
      data fpppp(27, 3),fpppp(27, 4)/-1.21152597d-07,-2.70991885d-08/
      data fpppp(27, 5),fpppp(27, 6)/ 6.85735680d-08, 1.21459214d-07/
      data fpppp(27, 7),fpppp(27, 8)/ 1.49830429d-07, 1.37306951d-07/
      data fpppp(27, 9),fpppp(27,10)/ 7.70318288d-08, 7.84559197d-09/
      data fpppp(27,11),fpppp(27,12)/-3.13910303d-08,-2.40176206d-08/
      data fpppp(27,13),fpppp(27,14)/-2.34047678d-08,-5.01886703d-09/
      data fpppp(27,15),fpppp(27,16)/-6.42444914d-09, 1.09249723d-09/
      data fpppp(27,17),fpppp(27,18)/ 2.91166948d-09, 1.74664585d-09/
      data fpppp(27,19),fpppp(27,20)/ 8.95225920d-10, 1.53537356d-09/
      data fpppp(27,21),fpppp(27,22)/-2.98865385d-09,-2.25952440d-10/
      data fpppp(27,23) /             4.54826477d-10 /
      data fpppp(28, 1),fpppp(28, 2)/ 4.16668878d-07, 3.11406285d-07/
      data fpppp(28, 3),fpppp(28, 4)/ 2.21191901d-07, 7.83087869d-08/
      data fpppp(28, 5),fpppp(28, 6)/-5.79391576d-08,-1.95999306d-07/
      data fpppp(28, 7),fpppp(28, 8)/-2.06424043d-07,-1.87828463d-07/
      data fpppp(28, 9),fpppp(28,10)/-1.54387136d-07,-2.16416377d-08/
      data fpppp(28,11),fpppp(28,12)/ 1.68021034d-08, 2.70412990d-08/
      data fpppp(28,13),fpppp(28,14)/-3.69415905d-09, 2.33231167d-08/
      data fpppp(28,15),fpppp(28,16)/-3.80596535d-09, 4.01282794d-09/
      data fpppp(28,17),fpppp(28,18)/ 1.12604891d-09,-1.59993422d-09/
      data fpppp(28,19),fpppp(28,20)/-7.23051431d-10, 4.12067818d-09/
      data fpppp(28,21),fpppp(28,22)/-4.22369440d-09, 2.13669657d-09/
      data fpppp(28,23) /             4.29572659d-09 /
 
      c(1,1)=fpppp(ix+1,iy+1)
      c(1,2)=fpppp(ix+1,iy  )
      c(2,1)=fpppp(ix  ,iy+1)
      c(2,2)=fpppp(ix,  iy  )
      c(1,3)=fpp(ix+1,iy+1,1)
      c(1,4)=fpp(ix+1,iy  ,1)
      c(2,3)=fpp(ix,  iy+1,1)
      c(2,4)=fpp(ix,  iy,  1)
      c(3,1)=fpp(ix+1,iy+1,2)
      c(3,2)=fpp(ix+1,iy  ,2)
      c(4,1)=fpp(ix,  iy+1,2)
      c(4,2)=fpp(ix,  iy,  2)
      c(3,3)=f(ix+1,iy+1)
      c(3,4)=f(ix+1,iy  )
      c(4,3)=f(ix,  iy+1)
      c(4,4)=f(ix,  iy  )
      px(1)=((xi-xix)**3/(6.0*delxi))-(xi-xix)*delxi/6.0
      px(2)=(xi-xixp1)*delxi/6.0-((xi-xixp1)**3/(6.0*delxi))
      px(3)=(xi-xix)/delxi
      px(4)=(xixp1-xi)/delxi
      py(1)=((yi-yiy)**3/(6.0*delyi))-(yi-yiy)*delyi/6.0
      py(2)=(yi-yiyp1)*delyi/6.0-((yi-yiyp1)**3/(6.0*delyi))
      py(3)=(yi-yiy)/delyi
      py(4)=(yiyp1-yi)/delyi

      fi=0.0d 00
      do l=1,4
        sum=0.0d 00
        do i=1,4
          sum=sum + c(i,l) * px(i)
        enddo
        fi = fi + sum * py(l)
      enddo
      return
      end  
      subroutine c1_spl(xi,yi,ix,iy,delxi,delyi,xix,xixp1,
     x                    yiy,yiyp1,fi)
      implicit real*8 (a-h,o-z)
      dimension fpp(28,23,2),f(28,23),fpppp(28,23)
      dimension c(4,4),px(4),py(4)
 
      data f( 1, 1),f( 1, 2) /  0.00000000d+00 , -7.86550800d-02 /
      data f( 1, 3),f( 1, 4) / -1.50767010d-01 , -2.06828080d-01 /
      data f( 1, 5),f( 1, 6) / -2.23048010d-01 , -1.89029110d-01 /
      data f( 1, 7),f( 1, 8) / -1.42387660d-01 , -1.05565100d-01 /
      data f( 1, 9),f( 1,10) / -8.00234900d-02 , -4.71169400d-02 /
      data f( 1,11),f( 1,12) / -2.60931100d-02 , -1.23373900d-02 /
      data f( 1,13),f( 1,14) / -4.20947000d-03 ,  6.69110000d-04 /
      data f( 1,15),f( 1,16) /  4.10804000d-03 ,  6.93769000d-03 /
      data f( 1,17),f( 1,18) /  9.29768000d-03 ,  1.10144000d-02 /
      data f( 1,19),f( 1,20) /  1.16702600d-02 ,  1.08255300d-02 /
      data f( 1,21),f( 1,22) /  8.28586000d-03 ,  4.44672000d-03 /
      data f( 1,23) /           0.00000000d+00 /
      data f( 2, 1),f( 2, 2) /  0.00000000d+00 , -7.95013700d-02 /
      data f( 2, 3),f( 2, 4) / -1.57758320d-01 , -2.28232390d-01 /
      data f( 2, 5),f( 2, 6) / -2.55708910d-01 , -2.09757910d-01 /
      data f( 2, 7),f( 2, 8) / -1.50143370d-01 , -1.07618080d-01 /
      data f( 2, 9),f( 2,10) / -8.03183800d-02 , -4.65102500d-02 /
      data f( 2,11),f( 2,12) / -2.51215000d-02 , -1.14890700d-02 /
      data f( 2,13),f( 2,14) / -3.76445000d-03 ,  5.84530000d-04 /
      data f( 2,15),f( 2,16) /  3.70240000d-03 ,  6.37540000d-03 /
      data f( 2,17),f( 2,18) /  8.59879000d-03 ,  1.01426200d-02 /
      data f( 2,19),f( 2,20) /  1.06372100d-02 ,  9.73658000d-03 /
      data f( 2,21),f( 2,22) /  7.36480000d-03 ,  3.92515000d-03 /
      data f( 2,23) /           0.00000000d+00 /
      data f( 3, 1),f( 3, 2) /  0.00000000d+00 , -8.05577500d-02 /
      data f( 3, 3),f( 3, 4) / -1.65739400d-01 , -2.56013680d-01 /
      data f( 3, 5),f( 3, 6) / -3.00488650d-01 , -2.34746340d-01 /
      data f( 3, 7),f( 3, 8) / -1.57432340d-01 , -1.09031850d-01 /
      data f( 3, 9),f( 3,10) / -8.00498900d-02 , -4.55347000d-02 /
      data f( 3,11),f( 3,12) / -2.39791800d-02 , -1.06601300d-02 /
      data f( 3,13),f( 3,14) / -3.39785000d-03 ,  5.03990000d-04 /
      data f( 3,15),f( 3,16) /  3.33008000d-03 ,  5.82348000d-03 /
      data f( 3,17),f( 3,18) /  7.90133000d-03 ,  9.28582000d-03 /
      data f( 3,19),f( 3,20) /  9.65594000d-03 ,  8.73536000d-03 /
      data f( 3,21),f( 3,22) /  6.54050000d-03 ,  3.46492000d-03 /
      data f( 3,23) /           0.00000000d+00 /
      data f( 4, 1),f( 4, 2) /  0.00000000d+00 , -8.14590000d-02 /
      data f( 4, 3),f( 4, 4) / -1.73817020d-01 , -2.89836240d-01 /
      data f( 4, 5),f( 4, 6) / -3.56429340d-01 , -2.63515420d-01 /
      data f( 4, 7),f( 4, 8) / -1.64086950d-01 , -1.09518730d-01 /
      data f( 4, 9),f( 4,10) / -7.90527400d-02 , -4.44677900d-02 /
      data f( 4,11),f( 4,12) / -2.27887600d-02 , -9.87131000d-03 /
      data f( 4,13),f( 4,14) / -3.08721000d-03 ,  4.28020000d-04 /
      data f( 4,15),f( 4,16) /  2.98625000d-03 ,  5.28883000d-03 /
      data f( 4,17),f( 4,18) /  7.21150000d-03 ,  8.45995000d-03 /
      data f( 4,19),f( 4,20) /  8.72986000d-03 ,  7.81628000d-03 /
      data f( 4,21),f( 4,22) /  5.80096000d-03 ,  3.05722000d-03 /
      data f( 4,23) /           0.00000000d+00 /
      data f( 5, 1),f( 5, 2) /  0.00000000d+00 , -8.18588800d-02 /
      data f( 5, 3),f( 5, 4) / -1.80640950d-01 , -3.27026190d-01 /
      data f( 5, 5),f( 5, 6) / -4.02831540d-01 , -2.94539050d-01 /
      data f( 5, 7),f( 5, 8) / -1.69413050d-01 , -1.09251130d-01 /
      data f( 5, 9),f( 5,10) / -7.76856300d-02 , -4.28011700d-02 /
      data f( 5,11),f( 5,12) / -2.15418100d-02 , -9.12660000d-03 /
      data f( 5,13),f( 5,14) / -2.81727000d-03 ,  3.57210000d-04 /
      data f( 5,15),f( 5,16) /  2.66821000d-03 ,  4.78255000d-03 /
      data f( 5,17),f( 5,18) /  6.55096000d-03 ,  7.67167000d-03 /
      data f( 5,19),f( 5,20) /  7.86105000d-03 ,  6.97455000d-03 /
      data f( 5,21),f( 5,22) /  5.13706000d-03 ,  2.69508000d-03 /
      data f( 5,23) /           0.00000000d+00 /
      data f( 6, 1),f( 6, 2) /  0.00000000d+00 , -8.14847900d-02 /
      data f( 6, 3),f( 6, 4) / -1.85179200d-01 , -3.61151070d-01 /
      data f( 6, 5),f( 6, 6) / -4.28242260d-01 , -3.21608310d-01 /
      data f( 6, 7),f( 6, 8) / -1.72577210d-01 , -1.08000010d-01 /
      data f( 6, 9),f( 6,10) / -7.57910100d-02 , -4.09600800d-02 /
      data f( 6,11),f( 6,12) / -2.02644400d-02 , -8.42470000d-03 /
      data f( 6,13),f( 6,14) / -2.57717000d-03 ,  2.92260000d-04 /
      data f( 6,15),f( 6,16) /  2.37453000d-03 ,  4.30555000d-03 /
      data f( 6,17),f( 6,18) /  5.92340000d-03 ,  6.92444000d-03 /
      data f( 6,19),f( 6,20) /  7.05068000d-03 ,  6.20621000d-03 /
      data f( 6,21),f( 6,22) /  4.54112000d-03 ,  2.37335000d-03 /
      data f( 6,23) /           0.00000000d+00 /
      data f( 7, 1),f( 7, 2) /  0.00000000d+00 , -7.77107400d-02 /
      data f( 7, 3),f( 7, 4) / -1.82686250d-01 , -3.79066560d-01 /
      data f( 7, 5),f( 7, 6) / -4.39137750d-01 , -3.30929790d-01 /
      data f( 7, 7),f( 7, 8) / -1.69604020d-01 , -1.02667400d-01 /
      data f( 7, 9),f( 7,10) / -7.06928400d-02 , -3.69370100d-02 /
      data f( 7,11),f( 7,12) / -1.77004500d-02 , -7.13945000d-03 /
      data f( 7,13),f( 7,14) / -2.16189000d-03 ,  1.81540000d-04 /
      data f( 7,15),f( 7,16) /  1.85770000d-03 ,  3.44089000d-03 /
      data f( 7,17),f( 7,18) /  4.77291000d-03 ,  5.56398000d-03 /
      data f( 7,19),f( 7,20) /  5.60730000d-03 ,  4.87327000d-03 /
      data f( 7,21),f( 7,22) /  3.52931000d-03 ,  1.83383000d-03 /
      data f( 7,23) /           0.00000000d+00 /
      data f( 8, 1),f( 8, 2) /  0.00000000d+00 , -7.08082400d-02 /
      data f( 8, 3),f( 8, 4) / -1.64508640d-01 , -3.33459330d-01 /
      data f( 8, 5),f( 8, 6) / -4.11881420d-01 , -2.96559340d-01 /
      data f( 8, 7),f( 8, 8) / -1.54065910d-01 , -9.33421300d-02 /
      data f( 8, 9),f( 8,10) / -6.41008700d-02 , -3.26486400d-02 /
      data f( 8,11),f( 8,12) / -1.52213800d-02 , -5.99896000d-03 /
      data f( 8,13),f( 8,14) / -1.80902000d-03 ,  9.76500000d-05 /
      data f( 8,15),f( 8,16) /  1.43150000d-03 ,  2.70138000d-03 /
      data f( 8,17),f( 8,18) /  3.77486000d-03 ,  4.39445000d-03 /
      data f( 8,19),f( 8,20) /  4.39635000d-03 ,  3.78694000d-03 /
      data f( 8,21),f( 8,22) /  2.72348000d-03 ,  1.40997000d-03 /
      data f( 8,23) /           0.00000000d+00 /
      data f( 9, 1),f( 9, 2) /  0.00000000d+00 , -6.25207100d-02 /
      data f( 9, 3),f( 9, 4) / -1.38738330d-01 , -2.48983230d-01 /
      data f( 9, 5),f( 9, 6) / -3.22198720d-01 , -2.27206860d-01 /
      data f( 9, 7),f( 9, 8) / -1.30391060d-01 , -8.21060800d-02 /
      data f( 9, 9),f( 9,10) / -5.65452400d-02 , -2.83300400d-02 /
      data f( 9,11),f( 9,12) / -1.29057000d-02 , -4.99256000d-03 /
      data f( 9,13),f( 9,14) / -1.50399000d-03 ,  3.82500000d-05 /
      data f( 9,15),f( 9,16) /  1.08936000d-03 ,  2.08916000d-03 /
      data f( 9,17),f( 9,18) /  2.93786000d-03 ,  3.41940000d-03 /
      data f( 9,19),f( 9,20) /  3.40520000d-03 ,  2.91646000d-03 /
      data f( 9,21),f( 9,22) /  2.08865000d-03 ,  1.07905000d-03 /
      data f( 9,23) /           0.00000000d+00 /
      data f(10, 1),f(10, 2) /  0.00000000d+00 , -5.47717800d-02 /
      data f(10, 3),f(10, 4) / -1.14654190d-01 , -1.81380610d-01 /
      data f(10, 5),f(10, 6) / -2.16455190d-01 , -1.67370670d-01 /
      data f(10, 7),f(10, 8) / -1.06831950d-01 , -7.02710500d-02 /
      data f(10, 9),f(10,10) / -4.88514200d-02 , -2.41778400d-02 /
      data f(10,11),f(10,12) / -1.08000000d-02 , -4.11358000d-03 /
      data f(10,13),f(10,14) / -1.23993000d-03 , -3.50000000d-07 /
      data f(10,15),f(10,16) /  8.21350000d-04 ,  1.59694000d-03 /
      data f(10,17),f(10,18) /  2.25714000d-03 ,  2.62877000d-03 /
      data f(10,19),f(10,20) /  2.61165000d-03 ,  2.22967000d-03 /
      data f(10,21),f(10,22) /  1.59345000d-03 ,  8.22340000d-04 /
      data f(10,23) /           0.00000000d+00 /
      data f(11, 1),f(11, 2) /  0.00000000d+00 , -4.86665100d-02 /
      data f(11, 3),f(11, 4) / -9.66878600d-02 , -1.38260830d-01 /
      data f(11, 5),f(11, 6) / -1.54407450d-01 , -1.25038450d-01 /
      data f(11, 7),f(11, 8) / -8.60852100d-02 , -5.89613100d-02 /
      data f(11, 9),f(11,10) / -4.14505200d-02 , -2.03303200d-02 /
      data f(11,11),f(11,12) / -8.92755000d-03 , -3.35532000d-03 /
      data f(11,13),f(11,14) / -1.01288000d-03 , -2.30100000d-05 /
      data f(11,15),f(11,16) /  6.15220000d-04 ,  1.21033000d-03 /
      data f(11,17),f(11,18) /  1.71729000d-03 ,  2.00237000d-03 /
      data f(11,19),f(11,20) /  1.98770000d-03 ,  1.69499000d-03 /
      data f(11,21),f(11,22) /  1.21046000d-03 ,  6.24410000d-04 /
      data f(11,23) /           0.00000000d+00 /
      data f(12, 1),f(12, 2) /  0.00000000d+00 , -4.40464800d-02 /
      data f(12, 3),f(12, 4) / -8.51125600d-02 , -1.13499360d-01 /
      data f(12, 5),f(12, 6) / -1.16091930d-01 , -9.51354300d-02 /
      data f(12, 7),f(12, 8) / -6.89712800d-02 , -4.87844200d-02 /
      data f(12, 9),f(12,10) / -3.46483900d-02 , -1.68682300d-02 /
      data f(12,11),f(12,12) / -7.29470000d-03 , -2.71016000d-03 /
      data f(12,13),f(12,14) / -8.19860000d-04 , -3.42500000d-05 /
      data f(12,15),f(12,16) /  4.59150000d-04 ,  9.11740000d-04 /
      data f(12,17),f(12,18) /  1.29739000d-03 ,  1.51470000d-03 /
      data f(12,19),f(12,20) /  1.50418000d-03 ,  1.28286000d-03 /
      data f(12,21),f(12,22) /  9.16310000d-04 ,  4.72700000d-04 /
      data f(12,23) /           0.00000000d+00 /
      data f(13, 1),f(13, 2) /  0.00000000d+00 , -3.69890700d-02 /
      data f(13, 3),f(13, 4) / -6.95661300d-02 , -8.31970100d-02 /
      data f(13, 5),f(13, 6) / -7.84906100d-02 , -6.50208900d-02 /
      data f(13, 7),f(13, 8) / -4.93364100d-02 , -3.60430700d-02 /
      data f(13, 9),f(13,10) / -2.58795500d-02 , -1.24633700d-02 /
      data f(13,11),f(13,12) / -5.27920000d-03 , -1.93337000d-03 /
      data f(13,13),f(13,14) / -5.87040000d-04 , -3.77600000d-05 /
      data f(13,15),f(13,16) /  2.94860000d-04 ,  5.92010000d-04 /
      data f(13,17),f(13,18) /  8.44560000d-04 ,  9.87970000d-04 /
      data f(13,19),f(13,20) /  9.82750000d-04 ,  8.39370000d-04 /
      data f(13,21),f(13,22) /  6.00290000d-04 ,  3.09870000d-04 /
      data f(13,23) /           0.00000000d+00 /
      data f(14, 1),f(14, 2) /  0.00000000d+00 , -2.77241700d-02 /
      data f(14, 3),f(14, 4) / -4.89731200d-02 , -5.70261800d-02 /
      data f(14, 5),f(14, 6) / -5.38746200d-02 , -4.52250600d-02 /
      data f(14, 7),f(14, 8) / -3.51796200d-02 , -2.61660400d-02 /
      data f(14, 9),f(14,10) / -1.88815000d-02 , -8.98324000d-03 /
      data f(14,11),f(14,12) / -3.73556000d-03 , -1.35318000d-03 /
      data f(14,13),f(14,14) / -4.12360000d-04 , -3.33300000d-05 /
      data f(14,15),f(14,16) /  1.89110000d-04 ,  3.82430000d-04 /
      data f(14,17),f(14,18) /  5.46000000d-04 ,  6.39810000d-04 /
      data f(14,19),f(14,20) /  6.37840000d-04 ,  5.46000000d-04 /
      data f(14,21),f(14,22) /  3.91100000d-04 ,  2.02140000d-04 /
      data f(14,23) /           0.00000000d+00 /
      data f(15, 1),f(15, 2) /  0.00000000d+00 , -2.17429100d-02 /
      data f(15, 3),f(15, 4) / -3.77724600d-02 , -4.40301400d-02 /
      data f(15, 5),f(15, 6) / -4.19620100d-02 , -3.55667400d-02 /
      data f(15, 7),f(15, 8) / -2.79632300d-02 , -2.09367100d-02 /
      data f(15, 9),f(15,10) / -1.51180400d-02 , -7.12994000d-03 /
      data f(15,11),f(15,12) / -2.93280000d-03 , -1.05637000d-03 /
      data f(15,13),f(15,14) / -3.22470000d-04 , -2.85900000d-05 /
      data f(15,15),f(15,16) /  1.40570000d-04 ,  2.85220000d-04 /
      data f(15,17),f(15,18) /  4.07120000d-04 ,  4.77510000d-04 /
      data f(15,19),f(15,20) /  4.76780000d-04 ,  4.08770000d-04 /
      data f(15,21),f(15,22) /  2.93250000d-04 ,  1.51690000d-04 /
      data f(15,23) /           0.00000000d+00 /
      data f(16, 1),f(16, 2) /  0.00000000d+00 , -1.66831600d-02 /
      data f(16, 3),f(16, 4) / -2.88566900d-02 , -3.38490000d-02 /
      data f(16, 5),f(16, 6) / -3.25991000d-02 , -2.78964800d-02 /
      data f(16, 7),f(16, 8) / -2.21069800d-02 , -1.66166400d-02 /
      data f(16, 9),f(16,10) / -1.19903500d-02 , -5.60512000d-03 /
      data f(16,11),f(16,12) / -2.28332000d-03 , -8.18730000d-04 /
      data f(16,13),f(16,14) / -2.50380000d-04 , -2.36300000d-05 /
      data f(16,15),f(16,16) /  1.04550000d-04 ,  2.12350000d-04 /
      data f(16,17),f(16,18) /  3.03040000d-04 ,  3.55700000d-04 /
      data f(16,19),f(16,20) /  3.55660000d-04 ,  3.05420000d-04 /
      data f(16,21),f(16,22) /  2.19330000d-04 ,  1.13650000d-04 /
      data f(16,23) /           0.00000000d+00 /
      data f(17, 1),f(17, 2) /  0.00000000d+00 , -1.09557700d-02 /
      data f(17, 3),f(17, 4) / -1.90125100d-02 , -2.25883100d-02 /
      data f(17, 5),f(17, 6) / -2.21093100d-02 , -1.91762700d-02 /
      data f(17, 7),f(17, 8) / -1.53314300d-02 , -1.15590800d-02 /
      data f(17, 9),f(17,10) / -8.32246000d-03 , -3.84225000d-03 /
      data f(17,11),f(17,12) / -1.54622000d-03 , -5.51740000d-04 /
      data f(17,13),f(17,14) / -1.68760000d-04 , -1.69200000d-05 /
      data f(17,15),f(17,16) /  6.70800000d-05 ,  1.36110000d-04 /
      data f(17,17),f(17,18) /  1.94030000d-04 ,  2.27930000d-04 /
      data f(17,19),f(17,20) /  2.28370000d-04 ,  1.96570000d-04 /
      data f(17,21),f(17,22) /  1.41480000d-04 ,  7.34800000d-05 /
      data f(17,23) /           0.00000000d+00 /
      data f(18, 1),f(18, 2) /  0.00000000d+00 , -7.07602000d-03 /
      data f(18, 3),f(18, 4) / -1.23637600d-02 , -1.48768000d-02 /
      data f(18, 5),f(18, 6) / -1.47748600d-02 , -1.29662000d-02 /
      data f(18, 7),f(18, 8) / -1.04375700d-02 , -7.88282000d-03 /
      data f(18, 9),f(18,10) / -5.66196000d-03 , -2.58586000d-03 /
      data f(18,11),f(18,12) / -1.03045000d-03 , -3.66550000d-04 /
      data f(18,13),f(18,14) / -1.11940000d-04 , -1.13300000d-05 /
      data f(18,15),f(18,16) /  4.31900000d-05 ,  8.71100000d-05 /
      data f(18,17),f(18,18) /  1.23870000d-04 ,  1.45620000d-04 /
      data f(18,19),f(18,20) /  1.46190000d-04 ,  1.26060000d-04 /
      data f(18,21),f(18,22) /  9.09800000d-05 ,  4.74200000d-05 /
      data f(18,23) /           0.00000000d+00 /
      data f(19, 1),f(19, 2) /  0.00000000d+00 , -5.25539000d-03 /
      data f(19, 3),f(19, 4) / -9.22498000d-03 , -1.11825900d-02 /
      data f(19, 5),f(19, 6) / -1.11978100d-02 , -9.89282000d-03 /
      data f(19, 7),f(19, 8) / -7.99418000d-03 , -6.04293000d-03 /
      data f(19, 9),f(19,10) / -4.33419000d-03 , -1.96714000d-03 /
      data f(19,11),f(19,12) / -7.79730000d-04 , -2.76880000d-04 /
      data f(19,13),f(19,14) / -8.43500000d-05 , -8.41000000d-06 /
      data f(19,15),f(19,16) /  3.22800000d-05 ,  6.46500000d-05 /
      data f(19,17),f(19,18) /  9.17800000d-05 ,  1.07930000d-04 /
      data f(19,19),f(19,20) /  1.08460000d-04 ,  9.36600000d-05 /
      data f(19,21),f(19,22) /  6.76500000d-05 ,  3.52900000d-05 /
      data f(19,23) /           0.00000000d+00 /
      data f(20, 1),f(20, 2) /  0.00000000d+00 , -3.88956000d-03 /
      data f(20, 3),f(20, 4) / -6.85565000d-03 , -8.36314000d-03 /
      data f(20, 5),f(20, 6) / -8.43285000d-03 , -7.49269000d-03 /
      data f(20, 7),f(20, 8) / -6.07482000d-03 , -4.59563000d-03 /
      data f(20, 9),f(20,10) / -3.29188000d-03 , -1.48577000d-03 /
      data f(20,11),f(20,12) / -5.86320000d-04 , -2.07900000d-04 /
      data f(20,13),f(20,14) / -6.31200000d-05 , -6.01000000d-06 /
      data f(20,15),f(20,16) /  2.41800000d-05 ,  4.79200000d-05 /
      data f(20,17),f(20,18) /  6.79900000d-05 ,  7.99600000d-05 /
      data f(20,19),f(20,20) /  8.04200000d-05 ,  6.94600000d-05 /
      data f(20,21),f(20,22) /  5.02900000d-05 ,  2.62300000d-05 /
      data f(20,23) /           0.00000000d+00 /
      data f(21, 1),f(21, 2) /  0.00000000d+00 , -2.46369000d-03 /
      data f(21, 3),f(21, 4) / -4.36387000d-03 , -5.36280000d-03 /
      data f(21, 5),f(21, 6) / -5.45142000d-03 , -4.87645000d-03 /
      data f(21, 7),f(21, 8) / -3.96945000d-03 , -3.00546000d-03 /
      data f(21, 9),f(21,10) / -2.14898000d-03 , -9.62710000d-04 /
      data f(21,11),f(21,12) / -3.77990000d-04 , -1.33720000d-04 /
      data f(21,13),f(21,14) / -4.02300000d-05 , -3.40000000d-06 /
      data f(21,15),f(21,16) /  1.57800000d-05 ,  3.07300000d-05 /
      data f(21,17),f(21,18) /  4.34200000d-05 ,  5.10400000d-05 /
      data f(21,19),f(21,20) /  5.13400000d-05 ,  4.43700000d-05 /
      data f(21,21),f(21,22) /  3.21500000d-05 ,  1.67700000d-05 /
      data f(21,23) /           0.00000000d+00 /
      data f(22, 1),f(22, 2) /  0.00000000d+00 , -1.13614000d-03 /
      data f(22, 3),f(22, 4) / -2.02246000d-03 , -2.50384000d-03 /
      data f(22, 5),f(22, 6) / -2.56641000d-03 , -2.31189000d-03 /
      data f(22, 7),f(22, 8) / -1.88934000d-03 , -1.43069000d-03 /
      data f(22, 9),f(22,10) / -1.01962000d-03 , -4.51990000d-04 /
      data f(22,11),f(22,12) / -1.76260000d-04 , -6.19300000d-05 /
      data f(22,13),f(22,14) / -1.79600000d-05 , -8.10000000d-07 /
      data f(22,15),f(22,16) /  7.89000000d-06 ,  1.47800000d-05 /
      data f(22,17),f(22,18) /  2.06700000d-05 ,  2.42100000d-05 /
      data f(22,19),f(22,20) /  2.42800000d-05 ,  2.09500000d-05 /
      data f(22,21),f(22,22) /  1.51300000d-05 ,  7.87000000d-06 /
      data f(22,23) /           0.00000000d+00 /
      data f(23, 1),f(23, 2) /  0.00000000d+00 , -5.12890000d-04 /
      data f(23, 3),f(23, 4) / -9.15320000d-04 , -1.13758000d-03 /
      data f(23, 5),f(23, 6) / -1.17073000d-03 , -1.05784000d-03 /
      data f(23, 7),f(23, 8) / -8.65260000d-04 , -6.54120000d-04 /
      data f(23, 9),f(23,10) / -4.64450000d-04 , -2.04020000d-04 /
      data f(23,11),f(23,12) / -7.87100000d-05 , -2.69200000d-05 /
      data f(23,13),f(23,14) / -7.17000000d-06 ,  2.70000000d-07 /
      data f(23,15),f(23,16) /  4.05000000d-06 ,  7.23000000d-06 /
      data f(23,17),f(23,18) /  1.00000000d-05 ,  1.16000000d-05 /
      data f(23,19),f(23,20) /  1.15300000d-05 ,  9.87000000d-06 /
      data f(23,21),f(23,22) /  7.08000000d-06 ,  3.67000000d-06 /
      data f(23,23) /           0.00000000d+00 /
      data f(24, 1),f(24, 2) /  0.00000000d+00 , -2.25780000d-04 /
      data f(24, 3),f(24, 4) / -4.03580000d-04 , -5.02290000d-04 /
      data f(24, 5),f(24, 6) / -5.17530000d-04 , -4.67690000d-04 /
      data f(24, 7),f(24, 8) / -3.82000000d-04 , -2.87850000d-04 /
      data f(24, 9),f(24,10) / -2.03410000d-04 , -8.78900000d-05 /
      data f(24,11),f(24,12) / -3.27900000d-05 , -1.03100000d-05 /
      data f(24,13),f(24,14) / -2.22000000d-06 ,  5.70000000d-07 /
      data f(24,15),f(24,16) /  2.12000000d-06 ,  3.61000000d-06 /
      data f(24,17),f(24,18) /  4.92000000d-06 ,  5.61000000d-06 /
      data f(24,19),f(24,20) /  5.50000000d-06 ,  4.65000000d-06 /
      data f(24,21),f(24,22) /  3.30000000d-06 ,  1.70000000d-06 /
      data f(24,23) /           0.00000000d+00 /
      data f(25, 1),f(25, 2) /  0.00000000d+00 , -9.71400000d-05 /
      data f(25, 3),f(25, 4) / -1.73470000d-04 , -2.15760000d-04 /
      data f(25, 5),f(25, 6) / -2.21980000d-04 , -2.00020000d-04 /
      data f(25, 7),f(25, 8) / -1.62620000d-04 , -1.21580000d-04 /
      data f(25, 9),f(25,10) / -8.48300000d-05 , -3.50200000d-05 /
      data f(25,11),f(25,12) / -1.16500000d-05 , -2.79000000d-06 /
      data f(25,13),f(25,14) / -1.80000000d-07 ,  5.40000000d-07 /
      data f(25,15),f(25,16) /  1.13000000d-06 ,  1.84000000d-06 /
      data f(25,17),f(25,18) /  2.45000000d-06 ,  2.74000000d-06 /
      data f(25,19),f(25,20) /  2.62000000d-06 ,  2.18000000d-06 /
      data f(25,21),f(25,22) /  1.52000000d-06 ,  7.80000000d-07 /
      data f(25,23) /           0.00000000d+00 /
      data f(26, 1),f(26, 2) /  0.00000000d+00 , -4.06400000d-05 /
      data f(26, 3),f(26, 4) / -7.23900000d-05 , -8.96900000d-05 /
      data f(26, 5),f(26, 6) / -9.17300000d-05 , -8.19200000d-05 /
      data f(26, 7),f(26, 8) / -6.56500000d-05 , -4.80000000d-05 /
      data f(26, 9),f(26,10) / -3.23200000d-05 , -1.14100000d-05 /
      data f(26,11),f(26,12) / -2.33000000d-06 ,  2.70000000d-07 /
      data f(26,13),f(26,14) /  4.80000000d-07 ,  4.30000000d-07 /
      data f(26,15),f(26,16) /  6.00000000d-07 ,  9.50000000d-07 /
      data f(26,17),f(26,18) /  1.24000000d-06 ,  1.34000000d-06 /
      data f(26,19),f(26,20) /  1.25000000d-06 ,  1.01000000d-06 /
      data f(26,21),f(26,22) /  6.90000000d-07 ,  3.50000000d-07 /
      data f(26,23) /           0.00000000d+00 /
      data f(27, 1),f(27, 2) /  0.00000000d+00 , -5.88000000d-06 /
      data f(27, 3),f(27, 4) / -1.02700000d-05 , -1.22200000d-05 /
      data f(27, 5),f(27, 6) / -1.16500000d-05 , -9.20000000d-06 /
      data f(27, 7),f(27, 8) / -5.90000000d-06 , -2.65000000d-06 /
      data f(27, 9),f(27,10) / -7.00000000d-08 ,  2.42000000d-06 /
      data f(27,11),f(27,12) /  2.24000000d-06 ,  1.19000000d-06 /
      data f(27,13),f(27,14) /  4.40000000d-07 ,  1.30000000d-07 /
      data f(27,15),f(27,16) /  2.00000000d-07 ,  2.50000000d-07 /
      data f(27,17),f(27,18) /  3.10000000d-07 ,  3.10000000d-07 /
      data f(27,19),f(27,20) /  2.70000000d-07 ,  2.10000000d-07 /
      data f(27,21),f(27,22) /  1.40000000d-07 ,  8.00000000d-08 /
      data f(27,23) /           0.00000000d+00 /
      data f(28, 1),f(28, 2) /  0.00000000d+00 ,  1.30000000d-07 /
      data f(28, 3),f(28, 4) /  4.30000000d-07 ,  9.90000000d-07 /
      data f(28, 5),f(28, 6) /  1.75000000d-06 ,  2.55000000d-06 /
      data f(28, 7),f(28, 8) /  3.19000000d-06 ,  3.53000000d-06 /
      data f(28, 9),f(28,10) /  3.51000000d-06 ,  2.64000000d-06 /
      data f(28,11),f(28,12) /  1.44000000d-06 ,  5.80000000d-07 /
      data f(28,13),f(28,14) /  2.00000000d-07 ,  5.00000000d-08 /
      data f(28,15),f(28,16) /  7.00000000d-08 ,  7.00000000d-08 /
      data f(28,17),f(28,18) /  8.00000000d-08 ,  8.00000000d-08 /
      data f(28,19),f(28,20) /  6.00000000d-08 ,  6.00000000d-08 /
      data f(28,21),f(28,22) /  2.00000000d-08 , -2.00000000d-08 /
      data f(28,23) /           0.00000000d+00 /
 
      data fpp( 1, 1,1),fpp( 1, 1,2)/ 0.00000000d+00,-1.42179129d-04/
      data fpp( 1, 2,1),fpp( 1, 2,2)/-5.75541914d-02, 3.08919459d-04/
      data fpp( 1, 3,1),fpp( 1, 3,2)/-1.90725008d-01, 4.76857294d-04/
      data fpp( 1, 4,1),fpp( 1, 4,2)/-6.79664263d-01, 1.63585777d-03/
      data fpp( 1, 5,1),fpp( 1, 5,2)/-1.39457859d+00, 2.54158524d-03/
      data fpp( 1, 6,1),fpp( 1, 6,2)/-4.75544521d-01, 2.55120462d-04/
      data fpp( 1, 7,1),fpp( 1, 7,2)/ 2.78308091d-02,-5.32655093d-04/
      data fpp( 1, 8,1),fpp( 1, 8,2)/ 3.76089847d-02,-4.81033691d-04/
      data fpp( 1, 9,1),fpp( 1, 9,2)/ 4.26257961d-02,-2.50638141d-04/
      data fpp( 1,10,1),fpp( 1,10,2)/ 6.02364790d-02,-9.81689300d-05/
      data fpp( 1,11,1),fpp( 1,11,2)/ 2.87497258d-02,-6.96493387d-05/
      data fpp( 1,12,1),fpp( 1,12,2)/ 7.20529913d-05,-5.93203153d-05/
      data fpp( 1,13,1),fpp( 1,13,2)/-1.00620034d-02,-3.07374000d-05/
      data fpp( 1,14,1),fpp( 1,14,2)/ 3.50950417d-04,-1.26904847d-05/
      data fpp( 1,15,1),fpp( 1,15,2)/ 3.80738341d-03,-4.87966114d-06/
      data fpp( 1,16,1),fpp( 1,16,2)/ 3.18559492d-04,-4.34767072d-06/
      data fpp( 1,17,1),fpp( 1,17,2)/-5.60227737d-04,-5.90925598d-06/
      data fpp( 1,18,1),fpp( 1,18,2)/-6.19153526d-05,-1.06115054d-05/
      data fpp( 1,19,1),fpp( 1,19,2)/ 4.84154758d-03,-1.52963226d-05/
      data fpp( 1,20,1),fpp( 1,20,2)/ 9.32970852d-03,-1.82386043d-05/
      data fpp( 1,21,1),fpp( 1,21,2)/ 1.08652612d-02,-1.34456604d-05/
      data fpp( 1,22,1),fpp( 1,22,2)/ 7.00927172d-03,-5.94695417d-06/
      data fpp( 1,23,1),fpp( 1,23,2)/ 0.00000000d+00, 7.78677087d-07/
      data fpp( 2, 1,1),fpp( 2, 1,2)/ 0.00000000d+00,-2.50036578d-04/
      data fpp( 2, 2,1),fpp( 2, 2,2)/-2.09626172d-02, 1.26326756d-04/
      data fpp( 2, 3,1),fpp( 2, 3,2)/-9.41269844d-02, 4.33903555d-05/
      data fpp( 2, 4,1),fpp( 2, 4,2)/-6.20907474d-01, 1.56800302d-03/
      data fpp( 2, 5,1),fpp( 2, 5,2)/-1.03807282d+00, 4.00400955d-03/
      data fpp( 2, 6,1),fpp( 2, 6,2)/-4.22595959d-01, 3.85635609d-05/
      data fpp( 2, 7,1),fpp( 2, 7,2)/ 5.08363817d-02,-8.79014198d-04/
      data fpp( 2, 8,1),fpp( 2, 8,2)/ 5.90090306d-02,-6.23926770d-04/
      data fpp( 2, 9,1),fpp( 2, 9,2)/ 5.07064077d-02,-2.79420322d-04/
      data fpp( 2,10,1),fpp( 2,10,2)/ 4.56850421d-02,-9.72518491d-05/
      data fpp( 2,11,1),fpp( 2,11,2)/ 1.82355484d-02,-7.67350817d-05/
      data fpp( 2,12,1),fpp( 2,12,2)/-1.81010598d-03,-6.11870240d-05/
      data fpp( 2,13,1),fpp( 2,13,2)/-7.89399313d-03,-3.29854224d-05/
      data fpp( 2,14,1),fpp( 2,14,2)/ 4.04099165d-04,-9.40968639d-06/
      data fpp( 2,15,1),fpp( 2,15,2)/ 3.34723318d-03,-3.24243203d-06/
      data fpp( 2,16,1),fpp( 2,16,2)/ 1.09388102d-03,-4.31278550d-06/
      data fpp( 2,17,1),fpp( 2,17,2)/ 3.09455474d-04,-6.48302598d-06/
      data fpp( 2,18,1),fpp( 2,18,2)/ 1.42783071d-03,-1.05287106d-05/
      data fpp( 2,19,1),fpp( 2,19,2)/ 5.16890484d-03,-1.43565317d-05/
      data fpp( 2,20,1),fpp( 2,20,2)/ 8.77758295d-03,-1.57583626d-05/
      data fpp( 2,21,1),fpp( 2,21,2)/ 9.69747761d-03,-1.08790178d-05/
      data fpp( 2,22,1),fpp( 2,22,2)/ 6.14545656d-03,-4.79776636d-06/
      data fpp( 2,23,1),fpp( 2,23,2)/ 0.00000000d+00, 9.40083178d-07/
      data fpp( 3, 1,1),fpp( 3, 1,2)/ 0.00000000d+00,-2.24512153d-04/
      data fpp( 3, 2,1),fpp( 3, 2,2)/ 1.53506601d-02,-6.83452942d-05/
      data fpp( 3, 3,1),fpp( 3, 3,2)/-2.66290546d-02,-6.11842670d-04/
      data fpp( 3, 4,1),fpp( 3, 4,2)/-6.62893840d-01, 1.29348478d-03/
      data fpp( 3, 5,1),fpp( 3, 5,2)/-1.72443413d+00, 6.42973797d-03/
      data fpp( 3, 6,1),fpp( 3, 6,2)/-3.89849644d-01,-5.60289446d-04/
      data fpp( 3, 7,1),fpp( 3, 7,2)/ 4.88676639d-02,-1.41137458d-03/
      data fpp( 3, 8,1),fpp( 3, 8,2)/ 1.09880893d-01,-7.33454617d-04/
      data fpp( 3, 9,1),fpp( 3, 9,2)/ 9.25765730d-02,-3.15254146d-04/
      data fpp( 3,10,1),fpp( 3,10,2)/-2.16606472d-02,-9.44340531d-05/
      data fpp( 3,11,1),fpp( 3,11,2)/ 7.34080613d-04,-8.45898414d-05/
      data fpp( 3,12,1),fpp( 3,12,2)/-4.45962906d-03,-6.13947813d-05/
      data fpp( 3,13,1),fpp( 3,13,2)/-5.41402404d-03,-3.32372334d-05/
      data fpp( 3,14,1),fpp( 3,14,2)/ 4.56652921d-04,-7.28268499d-06/
      data fpp( 3,15,1),fpp( 3,15,2)/ 2.79568387d-03,-2.17702661d-06/
      data fpp( 3,16,1),fpp( 3,16,2)/ 1.52791645d-03,-3.97060856d-06/
      data fpp( 3,17,1),fpp( 3,17,2)/ 1.80405839d-04,-6.87353916d-06/
      data fpp( 3,18,1),fpp( 3,18,2)/ 3.33859253d-03,-1.01368348d-05/
      data fpp( 3,19,1),fpp( 3,19,2)/ 5.55083304d-03,-1.34413216d-05/
      data fpp( 3,20,1),fpp( 3,20,2)/ 8.19795967d-03,-1.35398787d-05/
      data fpp( 3,21,1),fpp( 3,21,2)/ 8.40082836d-03,-8.85596342d-06/
      data fpp( 3,22,1),fpp( 3,22,2)/ 5.21290205d-03,-3.87946760d-06/
      data fpp( 3,23,1),fpp( 3,23,2)/ 0.00000000d+00, 1.01343380d-06/
      data fpp( 4, 1,1),fpp( 4, 1,2)/ 0.00000000d+00,-1.74517664d-05/
      data fpp( 4, 2,1),fpp( 4, 2,2)/ 5.26379769d-02,-2.52004467d-04/
      data fpp( 4, 3,1),fpp( 4, 3,2)/ 1.42719203d-01,-1.59029516d-03/
      data fpp( 4, 4,1),fpp( 4, 4,2)/-3.52279166d-01, 9.34497126d-04/
      data fpp( 4, 5,1),fpp( 4, 5,2)/ 1.23923934d+00, 9.71457546d-03/
      data fpp( 4, 6,1),fpp( 4, 6,2)/-2.86395464d-01,-1.51111418d-03/
      data fpp( 4, 7,1),fpp( 4, 7,2)/ 1.34308963d-01,-2.10662676d-03/
      data fpp( 4, 8,1),fpp( 4, 8,2)/ 5.76013982d-02,-8.28838781d-04/
      data fpp( 4, 9,1),fpp( 4, 9,2)/ 1.61833002d-02,-3.62553314d-04/
      data fpp( 4,10,1),fpp( 4,10,2)/ 9.57735468d-02,-7.87424674d-05/
      data fpp( 4,11,1),fpp( 4,11,2)/ 7.68812915d-03,-9.68320163d-05/
      data fpp( 4,12,1),fpp( 4,12,2)/-4.42337777d-03,-5.96242673d-05/
      data fpp( 4,13,1),fpp( 4,13,2)/-4.02591070d-03,-3.26719144d-05/
      data fpp( 4,14,1),fpp( 4,14,2)/ 5.11289150d-04,-5.82027520d-06/
      data fpp( 4,15,1),fpp( 4,15,2)/ 2.56403132d-03,-1.46698484d-06/
      data fpp( 4,16,1),fpp( 4,16,2)/ 3.15645320d-03,-3.65078543d-06/
      data fpp( 4,17,1),fpp( 4,17,2)/ 3.54692117d-03,-6.72447344d-06/
      data fpp( 4,18,1),fpp( 4,18,2)/ 3.77579917d-03,-9.90452081d-06/
      data fpp( 4,19,1),fpp( 4,19,2)/ 5.74176298d-03,-1.23698433d-05/
      data fpp( 4,20,1),fpp( 4,20,2)/ 7.71457836d-03,-1.16255059d-05/
      data fpp( 4,21,1),fpp( 4,21,2)/ 7.55520895d-03,-7.23253302d-06/
      data fpp( 4,22,1),fpp( 4,22,2)/ 4.52093526d-03,-3.14956199d-06/
      data fpp( 4,23,1),fpp( 4,23,2)/ 0.00000000d+00, 1.02198100d-06/
      data fpp( 5, 1,1),fpp( 5, 1,2)/ 0.00000000d+00, 3.36479269d-04/
      data fpp( 5, 2,1),fpp( 5, 2,2)/ 7.49194324d-02,-2.49342937d-04/
      data fpp( 5, 3,1),fpp( 5, 3,2)/ 2.07966243d-01,-3.40067312d-03/
      data fpp( 5, 4,1),fpp( 5, 4,2)/ 5.15765021d-02, 2.42727461d-03/
      data fpp( 5, 5,1),fpp( 5, 5,2)/ 2.49057076d+00, 1.06307483d-02/
      data fpp( 5, 6,1),fpp( 5, 6,2)/ 1.82701501d-01,-7.66786077d-04/
      data fpp( 5, 7,1),fpp( 5, 7,2)/ 2.11002486d-01,-3.52356156d-03/
      data fpp( 5, 8,1),fpp( 5, 8,2)/ 1.12401514d-01,-7.30346886d-04/
      data fpp( 5, 9,1),fpp( 5, 9,2)/ 6.46662260d-02,-4.18191697d-04/
      data fpp( 5,10,1),fpp( 5,10,2)/-1.60753998d-03,-7.50438648d-05/
      data fpp( 5,11,1),fpp( 5,11,2)/ 2.43140279d-03,-9.91388433d-05/
      data fpp( 5,12,1),fpp( 5,12,2)/-4.31285984d-03,-5.90497619d-05/
      data fpp( 5,13,1),fpp( 5,13,2)/-2.90233316d-03,-3.10149089d-05/
      data fpp( 5,14,1),fpp( 5,14,2)/ 5.94190478d-04,-4.98160243d-06/
      data fpp( 5,15,1),fpp( 5,15,2)/ 2.42219084d-03,-8.67481379d-07/
      data fpp( 5,16,1),fpp( 5,16,2)/ 2.86827077d-03,-3.34807206d-06/
      data fpp( 5,17,1),fpp( 5,17,2)/ 3.20590949d-03,-6.49603039d-06/
      data fpp( 5,18,1),fpp( 5,18,2)/ 4.11221080d-03,-9.52980636d-06/
      data fpp( 5,19,1),fpp( 5,19,2)/ 5.84411504d-03,-1.12645442d-05/
      data fpp( 5,20,1),fpp( 5,20,2)/ 7.35372687d-03,-9.96481703d-06/
      data fpp( 5,21,1),fpp( 5,21,2)/ 6.76233585d-03,-5.93558772d-06/
      data fpp( 5,22,1),fpp( 5,22,2)/ 4.03935693d-03,-2.56223208d-06/
      data fpp( 5,23,1),fpp( 5,23,2)/ 0.00000000d+00, 9.98516040d-07/
      data fpp( 6, 1,1),fpp( 6, 1,2)/ 0.00000000d+00, 7.01168834d-04/
      data fpp( 6, 2,1),fpp( 6, 2,2)/ 1.12066293d-01,-6.20648676d-05/
      data fpp( 6, 3,1),fpp( 6, 3,2)/ 3.96823824d-01,-5.78321816d-03/
      data fpp( 6, 4,1),fpp( 6, 4,2)/ 1.98501516d+00, 5.84834712d-03/
      data fpp( 6, 5,1),fpp( 6, 5,2)/ 1.39336563d+00, 8.52119288d-03/
      data fpp( 6, 6,1),fpp( 6, 6,2)/ 1.92821146d+00, 1.76091497d-03/
      data fpp( 6, 7,1),fpp( 6, 7,2)/ 3.18845094d-01,-5.38953674d-03/
      data fpp( 6, 8,1),fpp( 6, 8,2)/ 8.29045443d-02,-4.71703996d-04/
      data fpp( 6, 9,1),fpp( 6, 9,2)/ 4.16577957d-02,-4.92015275d-04/
      data fpp( 6,10,1),fpp( 6,10,2)/ 1.53386131d-02,-6.33263769d-05/
      data fpp( 6,11,1),fpp( 6,11,2)/ 8.38259706d-04,-1.02796617d-04/
      data fpp( 6,12,1),fpp( 6,12,2)/-4.01118287d-03,-5.68411533d-05/
      data fpp( 6,13,1),fpp( 6,13,2)/-2.26875665d-03,-2.93713694d-05/
      data fpp( 6,14,1),fpp( 6,14,2)/ 6.27948938d-04,-4.35936925d-06/
      data fpp( 6,15,1),fpp( 6,15,2)/ 2.36320534d-03,-4.20753630d-07/
      data fpp( 6,16,1),fpp( 6,16,2)/ 2.93846373d-03,-3.03261623d-06/
      data fpp( 6,17,1),fpp( 6,17,2)/ 3.41744088d-03,-6.23898145d-06/
      data fpp( 6,18,1),fpp( 6,18,2)/ 4.40535764d-03,-9.02005797d-06/
      data fpp( 6,19,1),fpp( 6,19,2)/ 5.94577685d-03,-1.01687867d-05/
      data fpp( 6,20,1),fpp( 6,20,2)/ 6.90451414d-03,-8.54739532d-06/
      data fpp( 6,21,1),fpp( 6,21,2)/ 6.17144766d-03,-4.87883203d-06/
      data fpp( 6,22,1),fpp( 6,22,2)/ 3.56763703d-03,-2.09807656d-06/
      data fpp( 6,23,1),fpp( 6,23,2)/ 0.00000000d+00, 9.36338282d-07/
      data fpp( 7, 1,1),fpp( 7, 1,2)/ 0.00000000d+00, 9.18773991d-04/
      data fpp( 7, 2,1),fpp( 7, 2,2)/ 8.02219037d-02, 2.18820186d-05/
      data fpp( 7, 3,1),fpp( 7, 3,2)/ 4.40962908d-01,-7.54984687d-03/
      data fpp( 7, 4,1),fpp( 7, 4,2)/ 1.56930678d+00, 8.24035344d-03/
      data fpp( 7, 5,1),fpp( 7, 5,2)/ 5.63510241d-01, 7.30262190d-03/
      data fpp( 7, 6,1),fpp( 7, 6,2)/ 8.46570865d-01, 2.93615497d-03/
      data fpp( 7, 7,1),fpp( 7, 7,2)/ 3.33189976d-01,-6.29896737d-03/
      data fpp( 7, 8,1),fpp( 7, 8,2)/ 1.19641110d-01,-3.93681505d-04/
      data fpp( 7, 9,1),fpp( 7, 9,2)/ 3.90329998d-02,-5.17201015d-04/
      data fpp( 7,10,1),fpp( 7,10,2)/ 5.92143066d-03,-6.31536018d-05/
      data fpp( 7,11,1),fpp( 7,11,2)/-2.34298051d-03,-1.01340777d-04/
      data fpp( 7,12,1),fpp( 7,12,2)/-3.59252148d-03,-5.20168884d-05/
      data fpp( 7,13,1),fpp( 7,13,2)/-1.48056346d-03,-2.55980688d-05/
      data fpp( 7,14,1),fpp( 7,14,2)/ 6.96057948d-04,-3.63863630d-06/
      data fpp( 7,15,1),fpp( 7,15,2)/ 2.27878858d-03, 1.16414029d-07/
      data fpp( 7,16,1),fpp( 7,16,2)/ 3.15147342d-03,-2.40521981d-06/
      data fpp( 7,17,1),fpp( 7,17,2)/ 3.83922262d-03,-5.56573477d-06/
      data fpp( 7,18,1),fpp( 7,18,2)/ 4.82782169d-03,-7.78884109d-06/
      data fpp( 7,19,1),fpp( 7,19,2)/ 5.84461193d-03,-8.14390087d-06/
      data fpp( 7,20,1),fpp( 7,20,2)/ 6.17059414d-03,-6.27655544d-06/
      data fpp( 7,21,1),fpp( 7,21,2)/ 5.11498911d-03,-3.34567738d-06/
      data fpp( 7,22,1),fpp( 7,22,2)/ 2.86841044d-03,-1.43193503d-06/
      data fpp( 7,23,1),fpp( 7,23,2)/ 0.00000000d+00, 7.72417517d-07/
      data fpp( 8, 1,1),fpp( 8, 1,2)/ 0.00000000d+00, 8.21693296d-04/
      data fpp( 8, 2,1),fpp( 8, 2,2)/ 3.63135917d-02,-2.01795393d-04/
      data fpp( 8, 3,1),fpp( 8, 3,2)/ 1.92023545d-01,-5.50863012d-03/
      data fpp( 8, 4,1),fpp( 8, 4,2)/ 1.26616573d+00, 4.17624629d-03/
      data fpp( 8, 5,1),fpp( 8, 5,2)/ 2.07536641d+00, 1.05305090d-02/
      data fpp( 8, 6,1),fpp( 8, 6,2)/ 1.23929458d+00, 2.00318693d-04/
      data fpp( 8, 7,1),fpp( 8, 7,2)/ 2.33133001d-01,-4.81065972d-03/
      data fpp( 8, 8,1),fpp( 8, 8,2)/ 3.74300155d-02,-5.82395794d-04/
      data fpp( 8, 9,1),fpp( 8, 9,2)/ 2.62802051d-02,-4.15561901d-04/
      data fpp( 8,10,1),fpp( 8,10,2)/ 7.70664251d-04,-8.39338007d-05/
      data fpp( 8,11,1),fpp( 8,11,2)/-4.20433766d-03,-9.02010964d-05/
      data fpp( 8,12,1),fpp( 8,12,2)/-3.33273120d-03,-4.75522137d-05/
      data fpp( 8,13,1),fpp( 8,13,2)/-1.17048950d-03,-2.15388489d-05/
      data fpp( 8,14,1),fpp( 8,14,2)/ 6.12319271d-04,-3.28859075d-06/
      data fpp( 8,15,1),fpp( 8,15,2)/ 2.11614036d-03, 3.24011907d-07/
      data fpp( 8,16,1),fpp( 8,16,2)/ 3.22814260d-03,-1.84565688d-06/
      data fpp( 8,17,1),fpp( 8,17,2)/ 4.09166866d-03,-4.72538440d-06/
      data fpp( 8,18,1),fpp( 8,18,2)/ 4.92285561d-03,-6.48620551d-06/
      data fpp( 8,19,1),fpp( 8,19,2)/ 5.54027541d-03,-6.39119355d-06/
      data fpp( 8,20,1),fpp( 8,20,2)/ 5.40460928d-03,-4.62762029d-06/
      data fpp( 8,21,1),fpp( 8,21,2)/ 4.26559592d-03,-2.34132531d-06/
      data fpp( 8,22,1),fpp( 8,22,2)/ 2.30772121d-03,-1.01007848d-06/
      data fpp( 8,23,1),fpp( 8,23,2)/ 0.00000000d+00, 5.94039242d-07/
      data fpp( 9, 1,1),fpp( 9, 1,2)/ 0.00000000d+00, 1.78973844d-04/
      data fpp( 9, 2,1),fpp( 9, 2,2)/-1.77217704d-02,-3.75147288d-04/
      data fpp( 9, 3,1),fpp( 9, 3,2)/-7.01520896d-02,-1.96564309d-03/
      data fpp( 9, 4,1),fpp( 9, 4,2)/-8.03639206d-01, 7.11724553d-05/
      data fpp( 9, 5,1),fpp( 9, 5,2)/ 4.98979628d-01, 1.05680117d-02/
      data fpp( 9, 6,1),fpp( 9, 6,2)/-5.56444679d-01,-1.97345514d-03/
      data fpp( 9, 7,1),fpp( 9, 7,2)/-4.52109817d-02,-2.23644552d-03/
      data fpp( 9, 8,1),fpp( 9, 8,2)/ 1.72558278d-02,-7.28159581d-04/
      data fpp( 9, 9,1),fpp( 9, 9,2)/ 3.95179775d-04,-3.04709756d-04/
      data fpp( 9,10,1),fpp( 9,10,2)/-4.46958767d-03,-9.61797406d-05/
      data fpp( 9,11,1),fpp( 9,11,2)/-5.34816883d-03,-7.80228813d-05/
      data fpp( 9,12,1),fpp( 9,12,2)/-3.19005373d-03,-4.24007342d-05/
      data fpp( 9,13,1),fpp( 9,13,2)/-1.01347856d-03,-1.78483819d-05/
      data fpp( 9,14,1),fpp( 9,14,2)/ 5.28164967d-04,-2.98553827d-06/
      data fpp( 9,15,1),fpp( 9,15,2)/ 1.86564997d-03, 3.22734948d-07/
      data fpp( 9,16,1),fpp( 9,16,2)/ 3.02945619d-03,-1.38400153d-06/
      data fpp( 9,17,1),fpp( 9,17,2)/ 3.95160276d-03,-3.85272885d-06/
      data fpp( 9,18,1),fpp( 9,18,2)/ 4.65275588d-03,-5.23468309d-06/
      data fpp( 9,19,1),fpp( 9,19,2)/ 4.96428641d-03,-4.95293878d-06/
      data fpp( 9,20,1),fpp( 9,20,2)/ 4.58846873d-03,-3.42596177d-06/
      data fpp( 9,21,1),fpp( 9,21,2)/ 3.47262721d-03,-1.68741414d-06/
      data fpp( 9,22,1),fpp( 9,22,2)/ 1.84170471d-03,-7.31781675d-07/
      data fpp( 9,23,1),fpp( 9,23,2)/ 0.00000000d+00, 4.47540837d-07/
      data fpp(10, 1,1),fpp(10, 1,2)/ 0.00000000d+00,-1.79850163d-04/
      data fpp(10, 2,1),fpp(10, 2,2)/-4.62165100d-02,-1.14904874d-04/
      data fpp(10, 3,1),fpp(10, 3,2)/-1.64340687d-01,-5.87081542d-04/
      data fpp(10, 4,1),fpp(10, 4,2)/-5.82630908d-01, 8.20668641d-04/
      data fpp(10, 5,1),fpp(10, 5,2)/-1.66216042d+00, 4.90084858d-03/
      data fpp(10, 6,1),fpp(10, 6,2)/-4.40959363d-01,-2.25878954d-04/
      data fpp(10, 7,1),fpp(10, 7,2)/-6.96500745d-02,-1.24832476d-03/
      data fpp(10, 8,1),fpp(10, 8,2)/-1.66063267d-02,-5.35498803d-04/
      data fpp(10, 9,1),fpp(10, 9,2)/-7.13242421d-03,-2.43584829d-04/
      data fpp(10,10,1),fpp(10,10,2)/-7.85231359d-03,-9.14369131d-05/
      data fpp(10,11,1),fpp(10,11,2)/-5.89998701d-03,-6.84119190d-05/
      data fpp(10,12,1),fpp(10,12,2)/-3.02005389d-03,-3.64006107d-05/
      data fpp(10,13,1),fpp(10,13,2)/-9.21096283d-04,-1.47518380d-05/
      data fpp(10,14,1),fpp(10,14,2)/ 3.95020859d-04,-2.63623709d-06/
      data fpp(10,15,1),fpp(10,15,2)/ 1.54075976d-03, 2.23986401d-07/
      data fpp(10,16,1),fpp(10,16,2)/ 2.65403264d-03,-1.02630852d-06/
      data fpp(10,17,1),fpp(10,17,2)/ 3.54392032d-03,-3.04215234d-06/
      data fpp(10,18,1),fpp(10,18,2)/ 4.12912086d-03,-4.11928213d-06/
      data fpp(10,19,1),fpp(10,19,2)/ 4.24257894d-03,-3.80571915d-06/
      data fpp(10,20,1),fpp(10,20,2)/ 3.79501579d-03,-2.54944126d-06/
      data fpp(10,21,1),fpp(10,21,2)/ 2.78839523d-03,-1.25091582d-06/
      data fpp(10,22,1),fpp(10,22,2)/ 1.45695995d-03,-5.40295481d-07/
      data fpp(10,23,1),fpp(10,23,2)/ 0.00000000d+00, 3.38297741d-07/
      data fpp(11, 1,1),fpp(11, 1,2)/ 0.00000000d+00,-2.20736942d-04/
      data fpp(11, 2,1),fpp(11, 2,2)/-4.39611894d-02, 5.46354837d-05/
      data fpp(11, 3,1),fpp(11, 3,2)/-1.90156662d-01, 1.57033407d-04/
      data fpp(11, 4,1),fpp(11, 4,2)/-5.38263164d-01, 8.64842088d-04/
      data fpp(11, 5,1),fpp(11, 5,2)/-4.04706448d-01, 2.48592224d-03/
      data fpp(11, 6,1),fpp(11, 6,2)/-3.05313368d-01, 1.15217745d-04/
      data fpp(11, 7,1),fpp(11, 7,2)/-9.80442201d-02,-6.46575621d-04/
      data fpp(11, 8,1),fpp(11, 8,2)/-2.96240212d-02,-3.67956862d-04/
      data fpp(11, 9,1),fpp(11, 9,2)/-1.58034829d-02,-1.88743331d-04/
      data fpp(11,10,1),fpp(11,10,2)/-9.82315798d-03,-8.38743763d-05/
      data fpp(11,11,1),fpp(11,11,2)/-6.03938312d-03,-5.88049640d-05/
      data fpp(11,12,1),fpp(11,12,2)/-2.83773071d-03,-3.07381675d-05/
      data fpp(11,13,1),fpp(11,13,2)/-8.53636312d-04,-1.20297658d-05/
      data fpp(11,14,1),fpp(11,14,2)/ 2.82751596d-04,-2.29696934d-06/
      data fpp(11,15,1),fpp(11,15,2)/ 1.25331099d-03, 1.19243136d-07/
      data fpp(11,16,1),fpp(11,16,2)/ 2.19591326d-03,-7.67203204d-07/
      data fpp(11,17,1),fpp(11,17,2)/ 3.00321596d-03,-2.33943032d-06/
      data fpp(11,18,1),fpp(11,18,2)/ 3.46526068d-03,-3.18787552d-06/
      data fpp(11,19,1),fpp(11,19,2)/ 3.50539784d-03,-2.89406761d-06/
      data fpp(11,20,1),fpp(11,20,2)/ 3.04796810d-03,-1.91825404d-06/
      data fpp(11,21,1),fpp(11,21,2)/ 2.20529187d-03,-9.42116219d-07/
      data fpp(11,22,1),fpp(11,22,2)/ 1.14745550d-03,-4.04481080d-07/
      data fpp(11,23,1),fpp(11,23,2)/ 0.00000000d+00, 2.58440540d-07/
      data fpp(12, 1,1),fpp(12, 1,2)/ 0.00000000d+00,-2.79172285d-04/
      data fpp(12, 2,1),fpp(12, 2,2)/-7.24732314d-04, 1.40082170d-04/
      data fpp(12, 3,1),fpp(12, 3,2)/-3.36871661d-02, 4.34139605d-04/
      data fpp(12, 4,1),fpp(12, 4,2)/-1.80629383d-02, 1.16638661d-03/
      data fpp(12, 5,1),fpp(12, 5,2)/-2.78846787d-01, 1.09092915d-03/
      data fpp(12, 6,1),fpp(12, 6,2)/-2.02167166d-01, 1.21673583d-04/
      data fpp(12, 7,1),fpp(12, 7,2)/-8.30945449d-02,-3.27787483d-04/
      data fpp(12, 8,1),fpp(12, 8,2)/-3.48250887d-02,-2.45073251d-04/
      data fpp(12, 9,1),fpp(12, 9,2)/-1.94691440d-02,-1.44118712d-04/
      data fpp(12,10,1),fpp(12,10,2)/-1.06695545d-02,-7.46212388d-05/
      data fpp(12,11,1),fpp(12,11,2)/-5.88248050d-03,-4.97941330d-05/
      data fpp(12,12,1),fpp(12,12,2)/-2.59402327d-03,-2.55416291d-05/
      data fpp(12,13,1),fpp(12,13,2)/-7.68858467d-04,-9.69375073d-06/
      data fpp(12,14,1),fpp(12,14,2)/ 1.86972758d-04,-1.96476801d-06/
      data fpp(12,15,1),fpp(12,15,2)/ 9.54996295d-04, 2.02227743d-08/
      data fpp(12,16,1),fpp(12,16,2)/ 1.76531433d-03,-5.64723087d-07/
      data fpp(12,17,1),fpp(12,17,2)/ 2.43571583d-03,-1.77773043d-06/
      data fpp(12,18,1),fpp(12,18,2)/ 2.81933641d-03,-2.42475521d-06/
      data fpp(12,19,1),fpp(12,19,2)/ 2.80032971d-03,-2.19304874d-06/
      data fpp(12,20,1),fpp(12,20,2)/ 2.39561180d-03,-1.45104982d-06/
      data fpp(12,21,1),fpp(12,21,2)/ 1.71643728d-03,-7.16551971d-07/
      data fpp(12,22,1),fpp(12,22,2)/ 8.86218043d-04,-3.06342294d-07/
      data fpp(12,23,1),fpp(12,23,2)/ 0.00000000d+00, 1.96521147d-07/
      data fpp(13, 1,1),fpp(13, 1,2)/ 0.00000000d+00,-3.84089035d-04/
      data fpp(13, 2,1),fpp(13, 2,2)/ 4.02142340d-02, 1.34885670d-04/
      data fpp(13, 3,1),fpp(13, 3,2)/ 1.17960328d-01, 9.03428755d-04/
      data fpp(13, 4,1),fpp(13, 4,2)/-3.69384298d-02, 7.98482508d-04/
      data fpp(13, 5,1),fpp(13, 5,2)/-1.25503745d-01, 3.03588412d-04/
      data fpp(13, 6,1),fpp(13, 6,2)/-1.05233202d-01, 9.03606454d-05/
      data fpp(13, 7,1),fpp(13, 7,2)/-6.00570368d-02,-1.33488593d-04/
      data fpp(13, 8,1),fpp(13, 8,2)/-3.24326903d-02,-1.30279872d-04/
      data fpp(13, 9,1),fpp(13, 9,2)/-2.01908646d-02,-9.65487185d-05/
      data fpp(13,10,1),fpp(13,10,2)/-1.04377130d-02,-5.98655085d-05/
      data fpp(13,11,1),fpp(13,11,2)/-5.28380957d-03,-3.79098475d-05/
      data fpp(13,12,1),fpp(13,12,2)/-2.19143528d-03,-1.87955014d-05/
      data fpp(13,13,1),fpp(13,13,2)/-6.48714235d-04,-6.87814677d-06/
      data fpp(13,14,1),fpp(13,14,2)/ 7.82564105d-05,-1.51491149d-06/
      data fpp(13,15,1),fpp(13,15,2)/ 6.35471692d-04,-6.18072555d-08/
      data fpp(13,16,1),fpp(13,16,2)/ 1.19534338d-03,-3.66059484d-07/
      data fpp(13,17,1),fpp(13,17,2)/ 1.68013659d-03,-1.14995481d-06/
      data fpp(13,18,1),fpp(13,18,2)/ 1.94370486d-03,-1.58252129d-06/
      data fpp(13,19,1),fpp(13,19,2)/ 1.91863576d-03,-1.43776004d-06/
      data fpp(13,20,1),fpp(13,20,2)/ 1.62964860d-03,-9.56038546d-07/
      data fpp(13,21,1),fpp(13,21,2)/ 1.15534781d-03,-4.80085776d-07/
      data fpp(13,22,1),fpp(13,22,2)/ 5.96636190d-04,-2.04018350d-07/
      data fpp(13,23,1),fpp(13,23,2)/ 0.00000000d+00, 1.29159175d-07/
      data fpp(14, 1,1),fpp(14, 1,2)/ 0.00000000d+00, 2.82573569d-06/
      data fpp(14, 2,1),fpp(14, 2,2)/-1.29662036d-02, 2.33721329d-04/
      data fpp(14, 3,1),fpp(14, 3,2)/-1.01715479d-01, 6.16341750d-04/
      data fpp(14, 4,1),fpp(14, 4,2)/-1.09618009d-01, 4.67925272d-04/
      data fpp(14, 5,1),fpp(14, 5,2)/-8.48269013d-02, 2.01065962d-04/
      data fpp(14, 6,1),fpp(14, 6,2)/-6.48140278d-02, 4.73308795d-05/
      data fpp(14, 7,1),fpp(14, 7,2)/-4.18826411d-02,-5.53782802d-05/
      data fpp(14, 8,1),fpp(14, 8,2)/-2.63988168d-02,-7.34641586d-05/
      data fpp(14, 9,1),fpp(14, 9,2)/-1.78200643d-02,-6.57346852d-05/
      data fpp(14,10,1),fpp(14,10,2)/-9.22826018d-03,-4.63130650d-05/
      data fpp(14,11,1),fpp(14,11,2)/-4.43961455d-03,-2.80478549d-05/
      data fpp(14,12,1),fpp(14,12,2)/-1.74690227d-03,-1.34135155d-05/
      data fpp(14,13,1),fpp(14,13,2)/-5.12284593d-04,-4.79168327d-06/
      data fpp(14,14,1),fpp(14,14,2)/ 2.93349336d-05,-1.12715145d-06/
      data fpp(14,15,1),fpp(14,15,2)/ 4.05783605d-04,-9.51109087d-08/
      data fpp(14,16,1),fpp(14,16,2)/ 7.96645476d-04,-2.39604910d-07/
      data fpp(14,17,1),fpp(14,17,2)/ 1.12840448d-03,-7.31469450d-07/
      data fpp(14,18,1),fpp(14,18,2)/ 1.31051083d-03,-1.02011729d-06/
      data fpp(14,19,1),fpp(14,19,2)/ 1.29312727d-03,-9.34861389d-07/
      data fpp(14,20,1),fpp(14,20,2)/ 1.09379381d-03,-6.32637153d-07/
      data fpp(14,21,1),fpp(14,21,2)/ 7.84171486d-04,-3.18189997d-07/
      data fpp(14,22,1),fpp(14,22,2)/ 4.00570532d-04,-1.38202858d-07/
      data fpp(14,23,1),fpp(14,23,2)/ 0.00000000d+00, 8.02014290d-08/
      data fpp(15, 1,1),fpp(15, 1,2)/ 0.00000000d+00, 7.41160667d-05/
      data fpp(15, 2,1),fpp(15, 2,2)/-2.47913328d-02, 2.12690267d-04/
      data fpp(15, 3,1),fpp(15, 3,2)/-4.75650956d-02, 4.46329267d-04/
      data fpp(15, 4,1),fpp(15, 4,2)/-6.41793103d-02, 3.47241466d-04/
      data fpp(15, 5,1),fpp(15, 5,2)/-6.23173767d-02, 1.62899268d-04/
      data fpp(15, 6,1),fpp(15, 6,2)/-4.89150588d-02, 3.96750612d-05/
      data fpp(15, 7,1),fpp(15, 7,2)/-3.37217391d-02,-3.16219128d-05/
      data fpp(15, 8,1),fpp(15, 8,2)/-2.26603806d-02,-5.16650099d-05/
      data fpp(15, 9,1),fpp(15, 9,2)/-1.58993816d-02,-5.16020474d-05/
      data fpp(15,10,1),fpp(15,10,2)/-8.22012960d-03,-3.83157527d-05/
      data fpp(15,11,1),fpp(15,11,2)/-3.82621291d-03,-2.25925416d-05/
      data fpp(15,12,1),fpp(15,12,2)/-1.47583572d-03,-1.05566807d-05/
      data fpp(15,13,1),fpp(15,13,2)/-4.50005683d-04,-3.73253552d-06/
      data fpp(15,14,1),fpp(15,14,2)/ 3.94071628d-06,-9.14377204d-07/
      data fpp(15,15,1),fpp(15,15,2)/ 3.11874437d-04,-9.31556609d-08/
      data fpp(15,16,1),fpp(15,16,2)/ 6.00257551d-04,-1.83600152d-07/
      data fpp(15,17,1),fpp(15,17,2)/ 8.61772735d-04,-5.37443732d-07/
      data fpp(15,18,1),fpp(15,18,2)/ 1.00288855d-03,-7.57224922d-07/
      data fpp(15,19,1),fpp(15,19,2)/ 9.88410015d-04,-7.00856582d-07/
      data fpp(15,20,1),fpp(15,20,2)/ 8.39058042d-04,-4.76148751d-07/
      data fpp(15,21,1),fpp(15,21,2)/ 5.87620860d-04,-2.45148413d-07/
      data fpp(15,22,1),fpp(15,22,2)/ 3.07693057d-04,-1.05657596d-07/
      data fpp(15,23,1),fpp(15,23,2)/ 0.00000000d+00, 5.99787981d-08/
      data fpp(16, 1,1),fpp(16, 1,2)/ 0.00000000d+00, 7.86608181d-05/
      data fpp(16, 2,1),fpp(16, 2,2)/-2.60949651d-02, 1.70106764d-04/
      data fpp(16, 3,1),fpp(16, 3,2)/-5.07576383d-02, 3.23223327d-04/
      data fpp(16, 4,1),fpp(16, 4,2)/-5.58997499d-02, 2.60492728d-04/
      data fpp(16, 5,1),fpp(16, 5,2)/-4.83585919d-02, 1.32936160d-04/
      data fpp(16, 6,1),fpp(16, 6,2)/-3.77347371d-02, 3.64154307d-05/
      data fpp(16, 7,1),fpp(16, 7,2)/-2.72514024d-02,-1.77466832d-05/
      data fpp(16, 8,1),fpp(16, 8,2)/-1.93486607d-02,-3.72270980d-05/
      data fpp(16, 9,1),fpp(16, 9,2)/-1.39479094d-02,-4.07169248d-05/
      data fpp(16,10,1),fpp(16,10,2)/-7.16322144d-03,-3.12766765d-05/
      data fpp(16,11,1),fpp(16,11,2)/-3.24753382d-03,-1.79821693d-05/
      data fpp(16,12,1),fpp(16,12,2)/-1.22525485d-03,-8.22724651d-06/
      data fpp(16,13,1),fpp(16,13,2)/-3.57692676d-04,-2.88324471d-06/
      data fpp(16,14,1),fpp(16,14,2)/-1.20977987d-05,-7.35774655d-07/
      data fpp(16,15,1),fpp(16,15,2)/ 2.24718648d-04,-8.78566716d-08/
      data fpp(16,16,1),fpp(16,16,2)/ 4.53324322d-04,-1.35598659d-07/
      data fpp(16,17,1),fpp(16,17,2)/ 6.44504583d-04,-3.96348693d-07/
      data fpp(16,18,1),fpp(16,18,2)/ 7.51434983d-04,-5.60806568d-07/
      data fpp(16,19,1),fpp(16,19,2)/ 7.44232668d-04,-5.22425036d-07/
      data fpp(16,20,1),fpp(16,20,2)/ 6.31974019d-04,-3.61493289d-07/
      data fpp(16,21,1),fpp(16,21,2)/ 4.54845072d-04,-1.82601807d-07/
      data fpp(16,22,1),fpp(16,22,2)/ 2.30157240d-04,-8.34994838d-08/
      data fpp(16,23,1),fpp(16,23,2)/ 0.00000000d+00, 3.83997419d-08/
      data fpp(17, 1,1),fpp(17, 1,2)/ 0.00000000d+00, 5.54994442d-05/
      data fpp(17, 2,1),fpp(17, 2,2)/-2.06382278d-02, 1.10331912d-04/
      data fpp(17, 3,1),fpp(17, 3,2)/-3.43961418d-02, 1.98940109d-04/
      data fpp(17, 4,1),fpp(17, 4,2)/-3.82826269d-02, 1.69333251d-04/
      data fpp(17, 5,1),fpp(17, 5,2)/-3.42314424d-02, 9.68788870d-05/
      data fpp(17, 6,1),fpp(17, 6,2)/-2.72861705d-02, 3.21208013d-05/
      data fpp(17, 7,1),fpp(17, 7,2)/-2.06024992d-02,-6.53009203d-06/
      data fpp(17, 8,1),fpp(17, 8,2)/-1.52338774d-02,-2.33980332d-05/
      data fpp(17, 9,1),fpp(17, 9,2)/-1.11503811d-02,-2.84529753d-05/
      data fpp(17,10,1),fpp(17,10,2)/-5.59984215d-03,-2.25238574d-05/
      data fpp(17,11,1),fpp(17,11,2)/-2.43207866d-03,-1.25023950d-05/
      data fpp(17,12,1),fpp(17,12,2)/-8.96593348d-04,-5.55956243d-06/
      data fpp(17,13,1),fpp(17,13,2)/-2.75353959d-04,-1.94935522d-06/
      data fpp(17,14,1),fpp(17,14,2)/-1.09678151d-05,-5.11416681d-07/
      data fpp(17,15,1),fpp(17,15,2)/ 1.47021549d-04,-7.53780554d-08/
      data fpp(17,16,1),fpp(17,16,2)/ 2.93080559d-04,-8.52710977d-08/
      data fpp(17,17,1),fpp(17,17,2)/ 4.17802900d-04,-2.50137554d-07/
      data fpp(17,18,1),fpp(17,18,2)/ 4.89624360d-04,-3.55378687d-07/
      data fpp(17,19,1),fpp(17,19,2)/ 4.86284428d-04,-3.35947700d-07/
      data fpp(17,20,1),fpp(17,20,2)/ 4.12381241d-04,-2.35230513d-07/
      data fpp(17,21,1),fpp(17,21,2)/ 2.94102518d-04,-1.20530246d-07/
      data fpp(17,22,1),fpp(17,22,2)/ 1.53680496d-04,-5.72485010d-08/
      data fpp(17,23,1),fpp(17,23,2)/ 0.00000000d+00, 2.07242505d-08/
      data fpp(18, 1,1),fpp(18, 1,2)/ 0.00000000d+00, 3.36585043d-05/
      data fpp(18, 2,1),fpp(18, 2,2)/-1.45281237d-02, 6.83629914d-05/
      data fpp(18, 3,1),fpp(18, 3,2)/-2.46864612d-02, 1.22076730d-04/
      data fpp(18, 4,1),fpp(18, 4,2)/-2.75817427d-02, 1.09258088d-04/
      data fpp(18, 5,1),fpp(18, 5,2)/-2.50716385d-02, 6.84861181d-05/
      data fpp(18, 6,1),fpp(18, 6,2)/-2.04632475d-02, 2.64102398d-05/
      data fpp(18, 7,1),fpp(18, 7,2)/-1.57846008d-02,-1.33427718d-06/
      data fpp(18, 8,1),fpp(18, 8,2)/-1.18024964d-02,-1.48043311d-05/
      data fpp(18, 9,1),fpp(18, 9,2)/-8.60989976d-03,-1.95819986d-05/
      data fpp(18,10,1),fpp(18,10,2)/-4.20274330d-03,-1.57890388d-05/
      data fpp(18,11,1),fpp(18,11,2)/-1.77948486d-03,-8.50324631d-06/
      data fpp(18,12,1),fpp(18,12,2)/-6.41705089d-04,-3.68857599d-06/
      data fpp(18,13,1),fpp(18,13,2)/-1.94224820d-04,-1.29984972d-06/
      data fpp(18,14,1),fpp(18,14,2)/-1.86976075d-05,-3.52025131d-07/
      data fpp(18,15,1),fpp(18,15,2)/ 9.25284900d-05,-5.74497581d-08/
      data fpp(18,16,1),fpp(18,16,2)/ 1.90353440d-04,-5.41758367d-08/
      data fpp(18,17,1),fpp(18,17,2)/ 2.74283819d-04,-1.55446895d-07/
      data fpp(18,18,1),fpp(18,18,2)/ 3.20734243d-04,-2.24636583d-07/
      data fpp(18,19,1),fpp(18,19,2)/ 3.17962952d-04,-2.16806772d-07/
      data fpp(18,20,1),fpp(18,20,2)/ 2.74501018d-04,-1.50136329d-07/
      data fpp(18,21,1),fpp(18,21,2)/ 1.92078188d-04,-7.96479114d-08/
      data fpp(18,22,1),fpp(18,22,2)/ 9.57874431d-05,-4.00720253d-08/
      data fpp(18,23,1),fpp(18,23,2)/ 0.00000000d+00, 8.33601266d-09/
      data fpp(19, 1,1),fpp(19, 1,2)/ 0.00000000d+00, 2.34753326d-05/
      data fpp(19, 2,1),fpp(19, 2,2)/-1.12825397d-02, 4.92509348d-05/
      data fpp(19, 3,1),fpp(19, 3,2)/-1.90314815d-02, 8.81129281d-05/
      data fpp(19, 4,1),fpp(19, 4,2)/-2.16868463d-02, 8.11725527d-05/
      data fpp(19, 5,1),fpp(19, 5,2)/-2.01821439d-02, 5.33704610d-05/
      data fpp(19, 6,1),fpp(19, 6,2)/-1.67545069d-02, 2.21960035d-05/
      data fpp(19, 7,1),fpp(19, 7,2)/-1.30507471d-02, 3.21525198d-07/
      data fpp(19, 8,1),fpp(19, 8,2)/-9.77920188d-03,-1.08557043d-05/
      data fpp(19, 9,1),fpp(19, 9,2)/-7.10942962d-03,-1.51011082d-05/
      data fpp(19,10,1),fpp(19,10,2)/-3.41752026d-03,-1.22946233d-05/
      data fpp(19,11,1),fpp(19,11,2)/-1.42345769d-03,-6.49879851d-06/
      data fpp(19,12,1),fpp(19,12,2)/-5.15084532d-04,-2.78378262d-06/
      data fpp(19,13,1),fpp(19,13,2)/-1.59344959d-04,-9.85271016d-07/
      data fpp(19,14,1),fpp(19,14,2)/-1.10602400d-05,-2.70533318d-07/
      data fpp(19,15,1),fpp(19,15,2)/ 6.93252268d-05,-4.75957118d-08/
      data fpp(19,16,1),fpp(19,16,2)/ 1.39611960d-04,-3.82838349d-08/
      data fpp(19,17,1),fpp(19,17,2)/ 2.04376557d-04,-1.13668949d-07/
      data fpp(19,18,1),fpp(19,18,2)/ 2.39392246d-04,-1.65840371d-07/
      data fpp(19,19,1),fpp(19,19,2)/ 2.39258597d-04,-1.60169569d-07/
      data fpp(19,20,1),fpp(19,20,2)/ 1.99923050d-04,-1.13281353d-07/
      data fpp(19,21,1),fpp(19,21,2)/ 1.48955282d-04,-5.93050205d-08/
      data fpp(19,22,1),fpp(19,22,2)/ 7.70420405d-05,-3.04985656d-08/
      data fpp(19,23,1),fpp(19,23,2)/ 0.00000000d+00, 5.49928279d-09/
      data fpp(20, 1,1),fpp(20, 1,2)/ 0.00000000d+00, 1.62893820d-05/
      data fpp(20, 2,1),fpp(20, 2,2)/-8.56171766d-03, 3.54272360d-05/
      data fpp(20, 3,1),fpp(20, 3,2)/-1.46051130d-02, 6.36344741d-05/
      data fpp(20, 4,1),fpp(20, 4,2)/-1.68848722d-02, 6.00988675d-05/
      data fpp(20, 5,1),fpp(20, 5,2)/-1.60132860d-02, 4.10372557d-05/
      data fpp(20, 6,1),fpp(20, 6,2)/-1.35062250d-02, 1.81209096d-05/
      data fpp(20, 7,1),fpp(20, 7,2)/-1.06169108d-02, 1.12950572d-06/
      data fpp(20, 8,1),fpp(20, 8,2)/-7.96919608d-03,-7.92213251d-06/
      data fpp(20, 9,1),fpp(20, 9,2)/-5.77138175d-03,-1.15465757d-05/
      data fpp(20,10,1),fpp(20,10,2)/-2.72967565d-03,-9.48260670d-06/
      data fpp(20,11,1),fpp(20,11,2)/-1.12318438d-03,-4.92259751d-06/
      data fpp(20,12,1),fpp(20,12,2)/-4.01456784d-04,-2.08880327d-06/
      data fpp(20,13,1),fpp(20,13,2)/-1.22395343d-04,-7.40589415d-07/
      data fpp(20,14,1),fpp(20,14,2)/-1.50614324d-05,-2.09039070d-07/
      data fpp(20,15,1),fpp(20,15,2)/ 5.16706029d-05,-3.84543065d-08/
      data fpp(20,16,1),fpp(20,16,2)/ 1.10698721d-04,-2.41437045d-08/
      data fpp(20,17,1),fpp(20,17,2)/ 1.53209952d-04,-8.51708757d-08/
      data fpp(20,18,1),fpp(20,18,2)/ 1.79696772d-04,-1.21172793d-07/
      data fpp(20,19,1),fpp(20,19,2)/ 1.78502661d-04,-1.20737953d-07/
      data fpp(20,20,1),fpp(20,20,2)/ 1.55806782d-04,-8.10753940d-08/
      data fpp(20,21,1),fpp(20,21,2)/ 1.07600683d-04,-4.75604709d-08/
      data fpp(20,22,1),fpp(20,22,2)/ 5.65443948d-05,-2.20827226d-08/
      data fpp(20,23,1),fpp(20,23,2)/ 0.00000000d+00, 5.69136131d-09/
      data fpp(21, 1,1),fpp(21, 1,2)/ 0.00000000d+00, 9.47327413d-06/
      data fpp(21, 2,1),fpp(21, 2,2)/-5.46424803d-03, 2.16554517d-05/
      data fpp(21, 3,1),fpp(21, 3,2)/-9.44296910d-03, 3.91473189d-05/
      data fpp(21, 4,1),fpp(21, 4,2)/-1.11815283d-02, 3.80552727d-05/
      data fpp(21, 5,1),fpp(21, 5,2)/-1.09016173d-02, 2.71059903d-05/
      data fpp(21, 6,1),fpp(21, 6,2)/-9.40657879d-03, 1.27823661d-05/
      data fpp(21, 7,1),fpp(21, 7,2)/-7.48779921d-03, 1.45174535d-06/
      data fpp(21, 8,1),fpp(21, 8,2)/-5.63521180d-03,-4.91174750d-06/
      data fpp(21, 9,1),fpp(21, 9,2)/-4.06010775d-03,-7.60715536d-06/
      data fpp(21,10,1),fpp(21,10,2)/-1.88906767d-03,-6.32406016d-06/
      data fpp(21,11,1),fpp(21,11,2)/-7.59413603d-04,-3.18960399d-06/
      data fpp(21,12,1),fpp(21,12,2)/-2.71087700d-04,-1.34452388d-06/
      data fpp(21,13,1),fpp(21,13,2)/-8.27855500d-05,-4.79100493d-07/
      data fpp(21,14,1),fpp(21,14,2)/-8.42173190d-06,-1.38674148d-07/
      data fpp(21,15,1),fpp(21,15,2)/ 3.15478392d-05,-2.52029142d-08/
      data fpp(21,16,1),fpp(21,16,2)/ 6.49296223d-05,-1.43141950d-08/
      data fpp(21,17,1),fpp(21,17,2)/ 9.40491220d-05,-5.31403060d-08/
      data fpp(21,18,1),fpp(21,18,2)/ 1.10415928d-04,-7.73245812d-08/
      data fpp(21,19,1),fpp(21,19,2)/ 1.10818733d-04,-7.67613691d-08/
      data fpp(21,20,1),fpp(21,20,2)/ 9.46953585d-05,-5.18299423d-08/
      data fpp(21,21,1),fpp(21,21,2)/ 6.86942028d-05,-3.09188617d-08/
      data fpp(21,22,1),fpp(21,22,2)/ 3.54906569d-05,-1.40946109d-08/
      data fpp(21,23,1),fpp(21,23,2)/ 0.00000000d+00, 3.89730547d-09/
      data fpp(22, 1,1),fpp(22, 1,2)/ 0.00000000d+00, 3.97670282d-06/
      data fpp(22, 2,1),fpp(22, 2,2)/-2.55097570d-03, 9.61539437d-06/
      data fpp(22, 3,1),fpp(22, 3,2)/-4.49679109d-03, 1.75185197d-05/
      data fpp(22, 4,1),fpp(22, 4,2)/-5.48674600d-03, 1.74961268d-05/
      data fpp(22, 5,1),fpp(22, 5,2)/-5.52381288d-03, 1.30113731d-05/
      data fpp(22, 6,1),fpp(22, 6,2)/-4.89537288d-03, 6.55998085d-06/
      data fpp(22, 7,1),fpp(22, 7,2)/-3.96105604d-03, 1.07590352d-06/
      data fpp(22, 8,1),fpp(22, 8,2)/-2.99812459d-03,-2.19959493d-06/
      data fpp(22, 9,1),fpp(22, 9,2)/-2.15618614d-03,-3.69672380d-06/
      data fpp(22,10,1),fpp(22,10,2)/-9.82298077d-04,-3.08063112d-06/
      data fpp(22,11,1),fpp(22,11,2)/-3.87645842d-04,-1.49475170d-06/
      data fpp(22,12,1),fpp(22,12,2)/-1.35885291d-04,-6.24362071d-07/
      data fpp(22,13,1),fpp(22,13,2)/-4.27690342d-05,-2.29400016d-07/
      data fpp(22,14,1),fpp(22,14,2)/-6.25359846d-06,-6.72378668d-08/
      data fpp(22,15,1),fpp(22,15,2)/ 1.46845527d-05,-8.64851707d-09/
      data fpp(22,16,1),fpp(22,16,2)/ 3.06059759d-05,-6.76806488d-09/
      data fpp(22,17,1),fpp(22,17,2)/ 4.39168384d-05,-2.42792234d-08/
      data fpp(22,18,1),fpp(22,18,2)/ 5.17309683d-05,-3.71150415d-08/
      data fpp(22,19,1),fpp(22,19,2)/ 5.20384576d-05,-3.54606104d-08/
      data fpp(22,20,1),fpp(22,20,2)/ 4.50107833d-05,-2.50425168d-08/
      data fpp(22,21,1),fpp(22,21,2)/ 3.27381414d-05,-1.37693224d-08/
      data fpp(22,22,1),fpp(22,22,2)/ 1.73032611d-05,-6.28019360d-09/
      data fpp(22,23,1),fpp(22,23,2)/ 0.00000000d+00, 2.29009680d-09/
      data fpp(23, 1,1),fpp(23, 1,2)/ 0.00000000d+00, 1.71045100d-06/
      data fpp(23, 2,1),fpp(23, 2,2)/-1.23504916d-03, 4.25749801d-06/
      data fpp(23, 3,1),fpp(23, 3,2)/-2.19234653d-03, 7.76995697d-06/
      data fpp(23, 4,1),fpp(23, 4,2)/-2.69628769d-03, 7.90347412d-06/
      data fpp(23, 5,1),fpp(23, 5,2)/-2.74705113d-03, 6.00254657d-06/
      data fpp(23, 6,1),fpp(23, 6,2)/-2.46416970d-03, 3.13593962d-06/
      data fpp(23, 7,1),fpp(23, 7,2)/-2.01269663d-03, 5.79294951d-07/
      data fpp(23, 8,1),fpp(23, 8,2)/-1.52908984d-03,-9.98719426d-07/
      data fpp(23, 9,1),fpp(23, 9,2)/-1.09570770d-03,-1.73721725d-06/
      data fpp(23,10,1),fpp(23,10,2)/-4.87740025d-04,-1.42358855d-06/
      data fpp(23,11,1),fpp(23,11,2)/-1.90323028d-04,-6.75628565d-07/
      data fpp(23,12,1),fpp(23,12,2)/-6.80911360d-05,-2.85097192d-07/
      data fpp(23,13,1),fpp(23,13,2)/-2.16583131d-05,-1.06382668d-07/
      data fpp(23,14,1),fpp(23,14,2)/-2.80387426d-06,-2.79721349d-08/
      data fpp(23,15,1),fpp(23,15,2)/ 6.91394978d-06,-1.32879185d-09/
      data fpp(23,16,1),fpp(23,16,2)/ 1.42464741d-05,-2.71269764d-09/
      data fpp(23,17,1),fpp(23,17,2)/ 2.02035243d-05,-1.24204176d-08/
      data fpp(23,18,1),fpp(23,18,2)/ 2.39401993d-05,-1.78056320d-08/
      data fpp(23,19,1),fpp(23,19,2)/ 2.44674365d-05,-1.65570544d-08/
      data fpp(23,20,1),fpp(23,20,2)/ 2.14215084d-05,-1.13661504d-08/
      data fpp(23,21,1),fpp(23,21,2)/ 1.56332315d-05,-5.77834413d-09/
      data fpp(23,22,1),fpp(23,22,2)/ 8.09629881d-06,-2.72047310d-09/
      data fpp(23,23,1),fpp(23,23,2)/ 0.00000000d+00, 1.06023655d-09/
      data fpp(24, 1,1),fpp(24, 1,2)/ 0.00000000d+00, 7.10292661d-07/
      data fpp(24, 2,1),fpp(24, 2,2)/-5.76187668d-04, 1.84821468d-06/
      data fpp(24, 3,1),fpp(24, 3,2)/-1.02342279d-03, 3.41204862d-06/
      data fpp(24, 4,1),fpp(24, 4,2)/-1.27138326d-03, 3.48519082d-06/
      data fpp(24, 5,1),fpp(24, 5,2)/-1.30750259d-03, 2.67998808d-06/
      data fpp(24, 6,1),fpp(24, 6,2)/-1.18154834d-03, 1.41405685d-06/
      data fpp(24, 7,1),fpp(24, 7,2)/-9.67837456d-04, 2.67784506d-07/
      data fpp(24, 8,1),fpp(24, 8,2)/-7.32716062d-04,-4.54794877d-07/
      data fpp(24, 9,1),fpp(24, 9,2)/-5.20103046d-04,-7.79004997d-07/
      data fpp(24,10,1),fpp(24,10,2)/-2.30901824d-04,-6.37187571d-07/
      data fpp(24,11,1),fpp(24,11,2)/-9.01820460d-05,-2.97444721d-07/
      data fpp(24,12,1),fpp(24,12,2)/-3.33501647d-05,-1.30233547d-07/
      data fpp(24,13,1),fpp(24,13,2)/-1.07577133d-05,-4.50210921d-08/
      data fpp(24,14,1),fpp(24,14,2)/-1.25090449d-06,-7.68208491d-09/
      data fpp(24,15,1),fpp(24,15,2)/ 3.49964812d-06, 1.34943172d-09/
      data fpp(24,16,1),fpp(24,16,2)/ 6.72812778d-06,-1.31564196d-09/
      data fpp(24,17,1),fpp(24,17,2)/ 9.42906454d-06,-6.88686389d-09/
      data fpp(24,18,1),fpp(24,18,2)/ 1.13882345d-05,-8.33690250d-09/
      data fpp(24,19,1),fpp(24,19,2)/ 1.13717965d-05,-7.76552613d-09/
      data fpp(24,20,1),fpp(24,20,2)/ 9.94318318d-06,-5.00099300d-09/
      data fpp(24,21,1),fpp(24,21,2)/ 7.20893253d-06,-2.23050189d-09/
      data fpp(24,22,1),fpp(24,22,2)/ 3.83154368d-06,-1.07699946d-09/
      data fpp(24,23,1),fpp(24,23,2)/ 0.00000000d+00, 5.38499731d-10/
      data fpp(25, 1,1),fpp(25, 1,2)/ 0.00000000d+00, 3.17945058d-07/
      data fpp(25, 2,1),fpp(25, 2,2)/-2.63480170d-04, 8.02909883d-07/
      data fpp(25, 3,1),fpp(25, 3,2)/-4.73082303d-04, 1.46481541d-06/
      data fpp(25, 4,1),fpp(25, 4,2)/-5.88419284d-04, 1.50742848d-06/
      data fpp(25, 5,1),fpp(25, 5,2)/-6.06538522d-04, 1.16227066d-06/
      data fpp(25, 6,1),fpp(25, 6,2)/-5.49156960d-04, 6.06688893d-07/
      data fpp(25, 7,1),fpp(25, 7,2)/-4.49073549d-04, 1.16573771d-07/
      data fpp(25, 8,1),fpp(25, 8,2)/-3.40045915d-04,-1.99383977d-07/
      data fpp(25, 9,1),fpp(25, 9,2)/-2.42920112d-04,-3.48637864d-07/
      data fpp(25,10,1),fpp(25,10,2)/-1.06892681d-04,-2.75794421d-07/
      data fpp(25,11,1),fpp(25,11,2)/-4.36687879d-05,-1.34584454d-07/
      data fpp(25,12,1),fpp(25,12,2)/-1.66682051d-05,-5.64677645d-08/
      data fpp(25,13,1),fpp(25,13,2)/-5.15083376d-06,-1.45444883d-08/
      data fpp(25,14,1),fpp(25,14,2)/-1.12507790d-07, 1.24571778d-09/
      data fpp(25,15,1),fpp(25,15,2)/ 1.64745773d-06, 1.76161719d-09/
      data fpp(25,16,1),fpp(25,16,2)/ 3.24101479d-06,-1.09218653d-09/
      data fpp(25,17,1),fpp(25,17,2)/ 4.72021757d-06,-3.39287108d-09/
      data fpp(25,18,1),fpp(25,18,2)/ 5.38686268d-06,-4.53632914d-09/
      data fpp(25,19,1),fpp(25,19,2)/ 5.64537746d-06,-3.06181236d-09/
      data fpp(25,20,1),fpp(25,20,2)/ 4.80575889d-06,-2.41642143d-09/
      data fpp(25,21,1),fpp(25,21,2)/ 3.53103837d-06,-4.72501923d-10/
      data fpp(25,22,1),fpp(25,22,2)/ 1.77752648d-06,-4.93570879d-10/
      data fpp(25,23,1),fpp(25,23,2)/ 0.00000000d+00, 4.67854396d-11/
      data fpp(26, 1,1),fpp(26, 1,2)/ 0.00000000d+00, 1.39435076d-07/
      data fpp(26, 2,1),fpp(26, 2,2)/-1.01251653d-04, 3.43129848d-07/
      data fpp(26, 3,1),fpp(26, 3,2)/-1.80967997d-04, 6.21645533d-07/
      data fpp(26, 4,1),fpp(26, 4,2)/-2.25979606d-04, 6.38288019d-07/
      data fpp(26, 5,1),fpp(26, 5,2)/-2.33543325d-04, 4.87602390d-07/
      data fpp(26, 6,1),fpp(26, 6,2)/-2.11503823d-04, 2.55302422d-07/
      data fpp(26, 7,1),fpp(26, 7,2)/-1.73708346d-04, 4.15879229d-08/
      data fpp(26, 8,1),fpp(26, 8,2)/-1.31660279d-04,-9.04541133d-08/
      data fpp(26, 9,1),fpp(26, 9,2)/-9.38965057d-05,-1.52571470d-07/
      data fpp(26,10,1),fpp(26,10,2)/-4.37674536d-05,-1.24058534d-07/
      data fpp(26,11,1),fpp(26,11,2)/-1.88228022d-05,-6.09943927d-08/
      data fpp(26,12,1),fpp(26,12,2)/-7.01701485d-06,-2.07638946d-08/
      data fpp(26,13,1),fpp(26,13,2)/-1.75895168d-06, 6.49971219d-10/
      data fpp(26,14,1),fpp(26,14,2)/-2.19064355d-07, 2.56400974d-09/
      data fpp(26,15,1),fpp(26,15,2)/ 9.50520944d-07, 2.29398981d-09/
      data fpp(26,16,1),fpp(26,16,2)/ 1.42781307d-06,-9.39968998d-10/
      data fpp(26,17,1),fpp(26,17,2)/ 1.93006518d-06,-2.13411382d-09/
      data fpp(26,18,1),fpp(26,18,2)/ 2.34431477d-06,-1.92357572d-09/
      data fpp(26,19,1),fpp(26,19,2)/ 2.28669362d-06,-1.57158330d-09/
      data fpp(26,20,1),fpp(26,20,2)/ 2.03378126d-06,-7.90091074d-10/
      data fpp(26,21,1),fpp(26,21,2)/ 1.46691398d-06,-6.80524032d-11/
      data fpp(26,22,1),fpp(26,22,2)/ 8.18350384d-07,-1.37699313d-10/
      data fpp(26,23,1),fpp(26,23,2)/ 0.00000000d+00, 1.88496567d-11/
      data fpp(27, 1,1),fpp(27, 1,2)/ 0.00000000d+00, 2.27715055d-08/
      data fpp(27, 2,1),fpp(27, 2,2)/-3.39449563d-05, 5.72569890d-08/
      data fpp(27, 3,1),fpp(27, 3,2)/-6.07948580d-05, 1.05800538d-07/
      data fpp(27, 4,1),fpp(27, 4,2)/-7.58715413d-05, 1.05140858d-07/
      data fpp(27, 5,1),fpp(27, 5,2)/-7.86207643d-05, 7.84360312d-08/
      data fpp(27, 6,1),fpp(27, 6,2)/-7.17900505d-05, 3.23150175d-08/
      data fpp(27, 7,1),fpp(27, 7,2)/-5.94781868d-05,-3.69610119d-09/
      data fpp(27, 8,1),fpp(27, 8,2)/-4.58562060d-05,-2.95306127d-08/
      data fpp(27, 9,1),fpp(27, 9,2)/-3.34704270d-05,-3.89814479d-08/
      data fpp(27,10,1),fpp(27,10,2)/-1.55912990d-05,-2.84903501d-08/
      data fpp(27,11,1),fpp(27,11,2)/-6.11719936d-06,-7.25715185d-09/
      data fpp(27,12,1),fpp(27,12,2)/-1.81485290d-06, 5.31895747d-09/
      data fpp(27,13,1),fpp(27,13,2)/-3.07728093d-07, 3.98132195d-09/
      data fpp(27,14,1),fpp(27,14,2)/ 2.33446958d-07, 5.15575471d-09/
      data fpp(27,15,1),fpp(27,15,2)/ 2.84708302d-07,-1.80434079d-09/
      data fpp(27,16,1),fpp(27,16,2)/ 5.76053410d-07, 8.61608453d-10/
      data fpp(27,17,1),fpp(27,17,2)/ 7.89695661d-07,-1.04209302d-09/
      data fpp(27,18,1),fpp(27,18,2)/ 8.93624352d-07,-2.93236363d-10/
      data fpp(27,19,1),fpp(27,19,2)/ 8.77230393d-07,-1.84961527d-10/
      data fpp(27,20,1),fpp(27,20,2)/ 7.35776784d-07,-1.66917529d-10/
      data fpp(27,21,1),fpp(27,21,2)/ 4.93738862d-07, 2.52631642d-10/
      data fpp(27,22,1),fpp(27,22,2)/ 1.96185604d-07,-2.43609041d-10/
      data fpp(27,23,1),fpp(27,23,2)/ 0.00000000d+00,-4.78195480d-10/
      data fpp(28, 1,1),fpp(28, 1,2)/ 0.00000000d+00, 3.41047189d-09/
      data fpp(28, 2,1),fpp(28, 2,2)/ 6.45314781d-05, 6.37905623d-09/
      data fpp(28, 3,1),fpp(28, 3,2)/ 1.15627429d-04, 1.18733032d-08/
      data fpp(28, 4,1),fpp(28, 4,2)/ 1.43905771d-04, 8.52773094d-09/
      data fpp(28, 5,1),fpp(28, 5,2)/ 1.47946382d-04, 2.01577305d-09/
      data fpp(28, 6,1),fpp(28, 6,2)/ 1.32844025d-04,-6.99082313d-09/
      data fpp(28, 7,1),fpp(28, 7,2)/ 1.07661093d-04,-1.24524805d-08/
      data fpp(28, 8,1),fpp(28, 8,2)/ 8.00651030d-05,-1.51992547d-08/
      data fpp(28, 9,1),fpp(28, 9,2)/ 5.57582135d-05,-1.31505006d-08/
      data fpp(28,10,1),fpp(28,10,2)/ 2.44726495d-05,-2.74887087d-09/
      data fpp(28,11,1),fpp(28,11,2)/ 1.10715997d-05, 4.34598409d-09/
      data fpp(28,12,1),fpp(28,12,2)/ 5.09642645d-06, 5.76493452d-09/
      data fpp(28,13,1),fpp(28,13,2)/ 1.78986405d-06, 1.39427782d-09/
      data fpp(28,14,1),fpp(28,14,2)/ 6.05276521d-07, 2.45795421d-09/
      data fpp(28,15,1),fpp(28,15,2)/-4.69354151d-07,-1.02609467d-09/
      data fpp(28,16,1),fpp(28,16,2)/-6.12026705d-07, 4.46424475d-10/
      data fpp(28,17,1),fpp(28,17,2)/-8.88847831d-07,-1.59603226d-10/
      data fpp(28,18,1),fpp(28,18,2)/-1.11881218d-06,-4.08011571d-10/
      data fpp(28,19,1),fpp(28,19,2)/-1.17561520d-06, 5.91649509d-10/
      data fpp(28,20,1),fpp(28,20,2)/-1.07688839d-06,-7.58586466d-10/
      data fpp(28,21,1),fpp(28,21,2)/-8.61869431d-07, 4.26963563d-11/
      data fpp(28,22,1),fpp(28,22,2)/-5.83092802d-07, 5.87801041d-10/
      data fpp(28,23,1),fpp(28,23,2)/ 0.00000000d+00, 1.20609948d-09/
 
      data fpppp( 1, 1),fpppp( 1, 2)/ 8.79274666d-03,-4.24734322d-03/
      data fpppp( 1, 3),fpppp( 1, 4)/-9.95136376d-03,-4.13316270d-02/
      data fpppp( 1, 5),fpppp( 1, 6)/ 1.21043854d-01,-5.06961756d-02/
      data fpppp( 1, 7),fpppp( 1, 8)/-1.80172494d-02, 4.30185635d-03/
      data fpppp( 1, 9),fpppp( 1,10)/-3.32903370d-04,-6.97594471d-04/
      data fpppp( 1,11),fpppp( 1,12)/ 1.77435097d-04, 1.56398906d-04/
      data fpppp( 1,13),fpppp( 1,14)/ 3.09586262d-04,-1.61923337d-04/
      data fpppp( 1,15),fpppp( 1,16)/-7.92841666d-05, 6.23445883d-05/
      data fpppp( 1,17),fpppp( 1,18)/-1.34919852d-05, 7.42493296d-05/
      data fpppp( 1,19),fpppp( 1,20)/-1.91963003d-05,-2.23822475d-05/
      data fpppp( 1,21),fpppp( 1,22)/-6.84312064d-05,-2.73854553d-05/
      data fpppp( 1,23) /            -1.12239071d-05 /
      data fpppp( 2, 1),fpppp( 2, 2)/ 1.27982510d-02, 2.52437893d-04/
      data fpppp( 2, 3),fpppp( 2, 4)/-2.63364225d-02,-3.77461717d-03/
      data fpppp( 2, 5),fpppp( 2, 6)/ 6.77425259d-02,-1.93613567d-02/
      data fpppp( 2, 7),fpppp( 2, 8)/-2.43877839d-02, 5.25016623d-03/
      data fpppp( 2, 9),fpppp( 2,10)/-5.66946269d-04,-2.29211495d-04/
      data fpppp( 2,11),fpppp( 2,12)/ 1.38104569d-04, 1.21023575d-04/
      data fpppp( 2,13),fpppp( 2,14)/ 2.15507165d-04,-1.20133469d-04/
      data fpppp( 2,15),fpppp( 2,16)/-5.62707869d-05, 3.34274458d-05/
      data fpppp( 2,17),fpppp( 2,18)/ 1.06966010d-05, 3.79541963d-05/
      data fpppp( 2,19),fpppp( 2,20)/-5.15145188d-06,-2.52921508d-05/
      data fpppp( 2,21),fpppp( 2,22)/-5.50069517d-05,-2.29949852d-05/
      data fpppp( 2,23) /            -8.61923790d-06 /
      data fpppp( 3, 1),fpppp( 3, 2)/ 2.00433735d-02,-4.01001621d-03/
      data fpppp( 3, 3),fpppp( 3, 4)/-1.77625986d-02,-6.75680065d-02/
      data fpppp( 3, 5),fpppp( 3, 6)/ 1.85968503d-01,-1.01236061d-01/
      data fpppp( 3, 7),fpppp( 3, 8)/ 3.96761600d-03,-5.28338250d-03/
      data fpppp( 3, 9),fpppp( 3,10)/-1.63029769d-03, 2.75486947d-03/
      data fpppp( 3,11),fpppp( 3,12)/-1.19126332d-03, 3.54877571d-04/
      data fpppp( 3,13),fpppp( 3,14)/ 2.61119227d-05,-4.98209447d-05/
      data fpppp( 3,15),fpppp( 3,16)/-3.87269046d-05,-1.16793399d-05/
      data fpppp( 3,17),fpppp( 3,18)/ 8.06596732d-05,-4.06175149d-05/
      data fpppp( 3,19),fpppp( 3,20)/ 2.50536155d-05,-3.35037803d-05/
      data fpppp( 3,21),fpppp( 3,22)/-3.76939707d-05,-1.91680371d-05/
      data fpppp( 3,23) /            -7.13242472d-06 /
      data fpppp( 4, 1),fpppp( 4, 2)/ 1.59498322d-02, 2.23953530d-02/
      data fpppp( 4, 3),fpppp( 4, 4)/-9.65448642d-02, 2.23365001d-01/
      data fpppp( 4, 5),fpppp( 4, 6)/-2.96151091d-01, 2.13122565d-01/
      data fpppp( 4, 7),fpppp( 4, 8)/-8.92177542d-02, 2.43695739d-02/
      data fpppp( 4, 9),fpppp( 4,10)/ 2.08930717d-04,-3.06599253d-03/
      data fpppp( 4,11),fpppp( 4,12)/ 1.99449956d-03,-3.53571079d-04/
      data fpppp( 4,13),fpppp( 4,14)/ 1.70323191d-04,-7.93377174d-05/
      data fpppp( 4,15),fpppp( 4,16)/-2.03978154d-06,-1.22374339d-07/
      data fpppp( 4,17),fpppp( 4,18)/-9.58795522d-06, 2.87787969d-05/
      data fpppp( 4,19),fpppp( 4,20)/-1.30208354d-06,-2.31593682d-05/
      data fpppp( 4,21),fpppp( 4,22)/-3.39915317d-05,-1.33687617d-05/
      data fpppp( 4,23) /            -1.73311554d-06 /
      data fpppp( 5, 1),fpppp( 5, 2)/ 4.27968686d-03, 2.62210262d-02/
      data fpppp( 5, 3),fpppp( 5, 4)/-9.52132207d-02, 2.85167084d-01/
      data fpppp( 5, 5),fpppp( 5, 6)/-4.22562956d-01, 2.65837497d-01/
      data fpppp( 5, 7),fpppp( 5, 8)/-8.01061722d-02, 2.41307227d-02/
      data fpppp( 5, 9),fpppp( 5,10)/-4.20895450d-03, 2.31331080d-03/
      data fpppp( 5,11),fpppp( 5,12)/-8.25526180d-04, 3.41801596d-04/
      data fpppp( 5,13),fpppp( 5,14)/-5.23928445d-05,-7.07040004d-06/
      data fpppp( 5,15),fpppp( 5,16)/-1.94369524d-05, 1.90298404d-06/
      data fpppp( 5,17),fpppp( 5,18)/ 5.31854351d-06, 1.09425974d-05/
      data fpppp( 5,19),fpppp( 5,20)/ 4.47242991d-07,-2.60691142d-05/
      data fpppp( 5,21),fpppp( 5,22)/-2.22309576d-05,-1.29023290d-05/
      data fpppp( 5,23) /            -5.14240670d-06 /
      data fpppp( 6, 1),fpppp( 6, 2)/-2.66134617d-02,-1.65095336d-02/
      data fpppp( 6, 3),fpppp( 6, 4)/ 1.34097493d-01,-2.07056325d-01/
      data fpppp( 6, 5),fpppp( 6, 6)/ 1.70965999d-01,-2.06448785d-01/
      data fpppp( 6, 7),fpppp( 6, 8)/ 1.40218212d-01,-2.48018677d-02/
      data fpppp( 6, 9),fpppp( 6,10)/ 5.71577073d-03,-1.37591946d-03/
      data fpppp( 6,11),fpppp( 6,12)/ 4.97036863d-04,-3.31733429d-05/
      data fpppp( 6,13),fpppp( 6,14)/ 3.11686357d-05,-2.22444372d-05/
      data fpppp( 6,15),fpppp( 6,16)/-1.18778384d-05, 1.55910640d-07/
      data fpppp( 6,17),fpppp( 6,18)/ 5.47732081d-06, 8.47118272d-06/
      data fpppp( 6,19),fpppp( 6,20)/-6.21190446d-06,-1.85244800d-05/
      data fpppp( 6,21),fpppp( 6,22)/-2.11984018d-05,-8.92656111d-06/
      data fpppp( 6,23) /            -9.24938242d-07 /
      data fpppp( 7, 1),fpppp( 7, 2)/ 9.34445570d-04,-7.17330036d-03/
      data fpppp( 7, 3),fpppp( 7, 4)/ 9.50833399d-02,-1.88935372d-01/
      data fpppp( 7, 5),fpppp( 7, 6)/ 1.48464449d-01,-9.55967056d-02/
      data fpppp( 7, 7),fpppp( 7, 8)/ 4.27764107d-02,-3.54925165d-03/
      data fpppp( 7, 9),fpppp( 7,10)/ 3.32637736d-03,-5.18227157d-04/
      data fpppp( 7,11),fpppp( 7,12)/ 2.37360751d-04,-1.03236366d-05/
      data fpppp( 7,13),fpppp( 7,14)/ 5.62373483d-06,-8.29149932d-06/
      data fpppp( 7,15),fpppp( 7,16)/-8.09118457d-06,-1.94650949d-06/
      data fpppp( 7,17),fpppp( 7,18)/ 4.78108390d-06, 8.73166378d-07/
      data fpppp( 7,19),fpppp( 7,20)/-6.58227907d-06,-1.59925322d-05/
      data fpppp( 7,21),fpppp( 7,22)/-1.23428270d-05,-6.09457752d-06/
      data fpppp( 7,23) /            -5.88769254d-07 /
      data fpppp( 8, 1),fpppp( 8, 2)/-2.43271983d-02,-9.40909618d-04/
      data fpppp( 8, 3),fpppp( 8, 4)/ 5.67459637d-02,-5.61920919d-03/
      data fpppp( 8, 5),fpppp( 8, 6)/-9.78550896d-02, 2.17416639d-03/
      data fpppp( 8, 7),fpppp( 8, 8)/ 4.83368845d-02,-1.01164262d-03/
      data fpppp( 8, 9),fpppp( 8,10)/ 2.44803497d-06, 3.05882005d-04/
      data fpppp( 8,11),fpppp( 8,12)/ 6.09628054d-06, 2.05293757d-05/
      data fpppp( 8,13),fpppp( 8,14)/-1.07756691d-05,-1.92675203d-07/
      data fpppp( 8,15),fpppp( 8,16)/-5.19289047d-06,-2.54489445d-06/
      data fpppp( 8,17),fpppp( 8,18)/ 4.63897810d-07,-1.25104336d-06/
      data fpppp( 8,19),fpppp( 8,20)/-8.28575294d-06,-1.07911012d-05/
      data fpppp( 8,21),fpppp( 8,22)/-8.75067597d-06,-3.33787577d-06/
      data fpppp( 8,23) /             1.11138873d-06 /
      data fpppp( 9, 1),fpppp( 9, 2)/ 1.45285339d-02, 1.84857663d-02/
      data fpppp( 9, 3),fpppp( 9, 4)/-9.68016507d-02, 2.05267205d-01/
      data fpppp( 9, 5),fpppp( 9, 6)/-2.35601741d-01, 1.71209407d-01/
      data fpppp( 9, 7),fpppp( 9, 8)/-7.32379643d-02, 1.40383974d-02/
      data fpppp( 9, 9),fpppp( 9,10)/-1.95421498d-03, 5.74837980d-04/
      data fpppp( 9,11),fpppp( 9,12)/-1.05965761d-04, 3.12268400d-05/
      data fpppp( 9,13),fpppp( 9,14)/-1.78339949d-05, 2.01324070d-06/
      data fpppp( 9,15),fpppp( 9,16)/-2.46847916d-06,-2.56005079d-06/
      data fpppp( 9,17),fpppp( 9,18)/-1.79089716d-06,-3.53596674d-06/
      data fpppp( 9,19),fpppp( 9,20)/-7.44259186d-06,-7.93455836d-06/
      data fpppp( 9,21),fpppp( 9,22)/-5.22060501d-06,-2.08788060d-06/
      data fpppp( 9,23) /             9.25194944d-07 /
      data fpppp(10, 1),fpppp(10, 2)/ 8.79737955d-03,-7.96300906d-03/
      data fpppp(10, 3),fpppp(10, 4)/ 5.79681657d-03,-8.72641076d-02/
      data fpppp(10, 5),fpppp(10, 6)/ 1.84562184d-01,-9.88092910d-02/
      data fpppp(10, 7),fpppp(10, 8)/ 6.70095578d-03,-4.37826202d-03/
      data fpppp(10, 9),fpppp(10,10)/ 3.55329391d-04,-5.69188173d-05/
      data fpppp(10,11),fpppp(10,12)/ 3.26788362d-05,-1.81401350d-05/
      data fpppp(10,13),fpppp(10,14)/-6.97682724d-06,-9.22984038d-07/
      data fpppp(10,15),fpppp(10,16)/ 4.46068984d-07,-2.80925343d-06/
      data fpppp(10,17),fpppp(10,18)/-2.61216690d-06,-5.02330767d-06/
      data fpppp(10,19),fpppp(10,20)/-5.59914992d-06,-6.24136610d-06/
      data fpppp(10,21),fpppp(10,22)/-2.97883071d-06,-1.33219421d-06/
      data fpppp(10,23) /             7.76127681d-07 /
      data fpppp(11, 1),fpppp(11, 2)/-2.02746782d-03,-2.39038576d-04/
      data fpppp(11, 3),fpppp(11, 4)/-2.15526058d-02, 3.79908146d-02/
      data fpppp(11, 5),fpppp(11, 6)/-1.48114804d-02, 1.30558346d-02/
      data fpppp(11, 7),fpppp(11, 8)/-1.15216018d-02,-2.93174910d-04/
      data fpppp(11, 9),fpppp(11,10)/-4.09617110d-04, 7.57936944d-05/
      data fpppp(11,11),fpppp(11,12)/-2.53506743d-05,-9.31834373d-06/
      data fpppp(11,13),fpppp(11,14)/-1.04294317d-05, 1.73681285d-07/
      data fpppp(11,15),fpppp(11,16)/-2.15004526d-07,-9.91090317d-07/
      data fpppp(11,17),fpppp(11,18)/-3.93860815d-06,-3.96995609d-06/
      data fpppp(11,19),fpppp(11,20)/-5.49602145d-06,-3.89997169d-06/
      data fpppp(11,21),fpppp(11,22)/-2.01888133d-06,-9.34111352d-07/
      data fpppp(11,23) /             3.78178735d-07 /
      data fpppp(12, 1),fpppp(12, 2)/-3.31979295d-03,-3.69488730d-03/
      data fpppp(12, 3),fpppp(12, 4)/ 1.03622938d-02,-2.60934892d-02/
      data fpppp(12, 5),fpppp(12, 6)/ 2.76737246d-02,-3.61017643d-03/
      data fpppp(12, 7),fpppp(12, 8)/-3.05869883d-03,-1.14778780d-03/
      data fpppp(12, 9),fpppp(12,10)/-2.49392740d-04, 7.33413614d-06/
      data fpppp(12,11),fpppp(12,12)/-2.06947369d-05,-1.44721949d-05/
      data fpppp(12,13),fpppp(12,14)/-9.21402896d-06,-8.31704238d-07/
      data fpppp(12,15),fpppp(12,16)/ 1.27238469d-06,-1.72016444d-06/
      data fpppp(12,17),fpppp(12,18)/-2.78671949d-06,-4.33981283d-06/
      data fpppp(12,19),fpppp(12,20)/-4.01166580d-06,-2.75619620d-06/
      data fpppp(12,21),fpppp(12,22)/-1.43094615d-06,-5.82702614d-07/
      data fpppp(12,23) /             4.01828496d-07 /
      data fpppp(13, 1),fpppp(13, 2)/ 1.12667060d-02, 3.58454806d-03/
      data fpppp(13, 3),fpppp(13, 4)/-1.65972519d-02, 6.96969505d-03/
      data fpppp(13, 5),fpppp(13, 6)/ 4.63849802d-03, 5.96918752d-04/
      data fpppp(13, 7),fpppp(13, 8)/-1.04882382d-03,-6.14059840d-04/
      data fpppp(13, 9),fpppp(13,10)/-1.86741808d-04,-1.65746471d-05/
      data fpppp(13,11),fpppp(13,12)/-2.29144932d-05,-1.54591280d-05/
      data fpppp(13,13),fpppp(13,14)/-8.22818936d-06,-5.73138516d-07/
      data fpppp(13,15),fpppp(13,16)/ 3.35421549d-07,-6.09163180d-07/
      data fpppp(13,17),fpppp(13,18)/-2.40347763d-06,-3.05042284d-06/
      data fpppp(13,19),fpppp(13,20)/-2.71307303d-06,-1.93236857d-06/
      data fpppp(13,21),fpppp(13,22)/-6.76270446d-07,-4.27199388d-07/
      data fpppp(13,23) /             1.09593690d-07 /
      data fpppp(14, 1),fpppp(14, 2)/-8.95826320d-03,-3.70782769d-03/
      data fpppp(14, 3),fpppp(14, 4)/ 5.60163666d-03, 7.04500068d-04/
      data fpppp(14, 5),fpppp(14, 6)/-5.73163950d-04, 4.41379520d-04/
      data fpppp(14, 7),fpppp(14, 8)/-4.91910978d-04,-2.61150560d-04/
      data fpppp(14, 9),fpppp(14,10)/-1.20704035d-04,-2.12546645d-05/
      data fpppp(14,11),fpppp(14,12)/-2.24668167d-05,-1.46340703d-05/
      data fpppp(14,13),fpppp(14,14)/-6.48257801d-06,-1.01550688d-06/
      data fpppp(14,15),fpppp(14,16)/ 6.34354220d-07,-6.57118076d-07/
      data fpppp(14,17),fpppp(14,18)/-1.55205413d-06,-2.11382397d-06/
      data fpppp(14,19),fpppp(14,20)/-1.96204531d-06,-9.54988435d-07/
      data fpppp(14,21),fpppp(14,22)/-8.35333126d-07,-1.42396675d-07/
      data fpppp(14,23) /             3.86745164d-07 /
      data fpppp(15, 1),fpppp(15, 2)/-1.06670505d-04, 1.24091171d-04/
      data fpppp(15, 3),fpppp(15, 4)/ 9.45226312d-05, 9.76109846d-04/
      data fpppp(15, 5),fpppp(15, 6)/ 4.35313571d-04, 5.23281081d-05/
      data fpppp(15, 7),fpppp(15, 8)/-2.14785580d-04,-1.84856477d-04/
      data fpppp(15, 9),fpppp(15,10)/-7.78747683d-05,-2.45122246d-05/
      data fpppp(15,11),fpppp(15,12)/-2.11964510d-05,-1.33143412d-05/
      data fpppp(15,13),fpppp(15,14)/-5.01901321d-06,-9.22624143d-07/
      data fpppp(15,15),fpppp(15,16)/-5.12509427d-08,-4.54084778d-08/
      data fpppp(15,17),fpppp(15,18)/-1.37919090d-06,-1.66179037d-06/
      data fpppp(15,19),fpppp(15,20)/-1.30930809d-06,-1.19338385d-06/
      data fpppp(15,21),fpppp(15,22)/-4.22690009d-08,-3.46977457d-07/
      data fpppp(15,23) /            -2.35736398d-07 /
      data fpppp(16, 1),fpppp(16, 2)/-6.26891714d-04,-2.14031387d-05/
      data fpppp(16, 3),fpppp(16, 4)/ 1.05625431d-03, 4.81320695d-04/
      data fpppp(16, 5),fpppp(16, 6)/ 6.24475825d-05, 8.73623538d-06/
      data fpppp(16, 7),fpppp(16, 8)/-1.31117372d-04,-1.03609043d-04/
      data fpppp(16, 9),fpppp(16,10)/-5.49241742d-05,-2.44318338d-05/
      data fpppp(16,11),fpppp(16,12)/-1.94885095d-05,-1.12186470d-05/
      data fpppp(16,13),fpppp(16,14)/-4.91990980d-06,-4.19751700d-07/
      data fpppp(16,15),fpppp(16,16)/ 7.22107907d-08,-3.61737824d-07/
      data fpppp(16,17),fpppp(16,18)/-8.70784275d-07,-1.21011676d-06/
      data fpppp(16,19),fpppp(16,20)/-1.13671153d-06,-5.46417207d-07/
      data fpppp(16,21),fpppp(16,22)/-5.69837513d-07,-2.77658840d-08/
      data fpppp(16,23) /             3.52736621d-07 /
      data fpppp(17, 1),fpppp(17, 2)/ 1.62185972d-04, 2.61976502d-04/
      data fpppp(17, 3),fpppp(17, 4)/ 4.41183332d-04, 3.42433112d-04/
      data fpppp(17, 5),fpppp(17, 6)/ 9.41249094d-05,-2.43517766d-05/
      data fpppp(17, 7),fpppp(17, 8)/-5.95019264d-05,-5.32524113d-05/
      data fpppp(17, 9),fpppp(17,10)/-3.59185324d-05,-2.26054252d-05/
      data fpppp(17,11),fpppp(17,12)/-1.66262919d-05,-8.82609743d-06/
      data fpppp(17,13),fpppp(17,14)/-2.92407391d-06,-8.88801594d-07/
      data fpppp(17,15),fpppp(17,16)/ 9.54734745d-08,-2.08913506d-07/
      data fpppp(17,17),fpppp(17,18)/-5.40019679d-07,-8.05060542d-07/
      data fpppp(17,19),fpppp(17,20)/-7.49421728d-07,-4.31047866d-07/
      data fpppp(17,21),fpppp(17,22)/-1.88918911d-07,-1.41874476d-07/
      data fpppp(17,23) /            -3.90916064d-08 /
      data fpppp(18, 1),fpppp(18, 2)/ 6.61767645d-05, 1.60559256d-04/
      data fpppp(18, 3),fpppp(18, 4)/ 3.40334922d-04, 2.21234476d-04/
      data fpppp(18, 5),fpppp(18, 6)/ 7.20197426d-05,-5.72459780d-06/
      data fpppp(18, 7),fpppp(18, 8)/-3.22600098d-05,-3.24054948d-05/
      data fpppp(18, 9),fpppp(18,10)/-2.75998779d-05,-1.96798288d-05/
      data fpppp(18,11),fpppp(18,12)/-1.27146881d-05,-6.59013883d-06/
      data fpppp(18,13),fpppp(18,14)/-2.34272692d-06,-3.56136847d-07/
      data fpppp(18,15),fpppp(18,16)/-9.07926222d-08,-8.47614957d-08/
      data fpppp(18,17),fpppp(18,18)/-4.03835707d-07,-5.48692942d-07/
      data fpppp(18,19),fpppp(18,20)/-3.54695395d-07,-4.73964116d-07/
      data fpppp(18,21),fpppp(18,22)/-8.71018621d-08,-9.70335019d-09/
      data fpppp(18,23) /             1.56113374d-07 /
      data fpppp(19, 1),fpppp(19, 2)/ 8.24554499d-05, 1.34322508d-04/
      data fpppp(19, 3),fpppp(19, 4)/ 2.28318001d-04, 1.74863971d-04/
      data fpppp(19, 5),fpppp(19, 6)/ 7.06422430d-05, 4.07135603d-06/
      data fpppp(19, 7),fpppp(19, 8)/-2.06581902d-05,-2.51700965d-05/
      data fpppp(19, 9),fpppp(19,10)/-2.30869329d-05,-1.70122620d-05/
      data fpppp(19,11),fpppp(19,12)/-1.07348264d-05,-5.18979732d-06/
      data fpppp(19,13),fpppp(19,14)/-1.66399935d-06,-6.01496478d-07/
      data fpppp(19,15),fpppp(19,16)/-3.96986916d-09, 1.14519142d-08/
      data fpppp(19,17),fpppp(19,18)/-3.73165890d-07,-3.03722889d-07/
      data fpppp(19,19),fpppp(19,20)/-5.20902851d-07, 3.52204478d-08/
      data fpppp(19,21),fpppp(19,22)/-3.17912188d-07,-2.03001454d-08/
      data fpppp(19,23) /             9.13848463d-08 /
      data fpppp(20, 1),fpppp(20, 2)/ 5.35846090d-05, 9.54043669d-05/
      data fpppp(20, 3),fpppp(20, 4)/ 1.69195286d-04, 1.31087142d-04/
      data fpppp(20, 5),fpppp(20, 6)/ 6.27790663d-05, 1.03105481d-05/
      data fpppp(20, 7),fpppp(20, 8)/-1.22805081d-05,-1.91723789d-05/
      data fpppp(20, 9),fpppp(20,10)/-1.90060720d-05,-1.46309486d-05/
      data fpppp(20,11),fpppp(20,12)/-8.58302384d-06,-4.12277616d-06/
      data fpppp(20,13),fpppp(20,14)/-1.48584094d-06,-2.37511882d-07/
      data fpppp(20,15),fpppp(20,16)/-2.24064263d-10,-2.23826867d-07/
      data fpppp(20,17),fpppp(20,18)/-9.54817467d-08,-3.55710744d-07/
      data fpppp(20,19),fpppp(20,20)/-1.42531218d-07,-3.64270372d-07/
      data fpppp(20,21),fpppp(20,22)/ 6.89994174d-08,-8.27385835d-08/
      data fpppp(20,23) /            -6.73315013d-08 /
      data fpppp(21, 1),fpppp(21, 2)/ 3.06022011d-05, 5.66880432d-05/
      data fpppp(21, 3),fpppp(21, 4)/ 9.91720971d-05, 8.42624098d-05/
      data fpppp(21, 5),fpppp(21, 6)/ 4.82111151d-05, 1.45237468d-05/
      data fpppp(21, 7),fpppp(21, 8)/-4.60825556d-06,-1.19768462d-05/
      data fpppp(21, 9),fpppp(21,10)/-1.40803669d-05,-1.05205563d-05/
      data fpppp(21,11),fpppp(21,12)/-6.32056916d-06,-2.67685670d-06/
      data fpppp(21,13),fpppp(21,14)/-9.73429258d-07,-2.65726160d-07/
      data fpppp(21,15),fpppp(21,16)/-2.73209154d-08,-2.02574635d-08/
      data fpppp(21,17),fpppp(21,18)/-1.47386228d-07,-1.55359273d-07/
      data fpppp(21,19),fpppp(21,20)/-1.89016682d-07,-8.01448093d-08/
      data fpppp(21,21),fpppp(21,22)/-8.30709480d-08,-1.97148108d-08/
      data fpppp(21,23) /             2.47035333d-08 /
      data fpppp(22, 1),fpppp(22, 2)/ 1.06487952d-05, 2.32656332d-05/
      data fpppp(22, 3),fpppp(22, 4)/ 4.15271470d-05, 4.00322957d-05/
      data fpppp(22, 5),fpppp(22, 6)/ 2.70367947d-05, 1.15421781d-05/
      data fpppp(22, 7),fpppp(22, 8)/ 2.04933180d-07,-5.49440346d-06/
      data fpppp(22, 9),fpppp(22,10)/-7.26563806d-06,-6.05521529d-06/
      data fpppp(22,11),fpppp(22,12)/-3.26765016d-06,-1.44768507d-06/
      data fpppp(22,13),fpppp(22,14)/-4.60267234d-07,-1.07295262d-07/
      data fpppp(22,15),fpppp(22,16)/-4.51887914d-08,-1.29532545d-08/
      data fpppp(22,17),fpppp(22,18)/-5.96318293d-08,-7.83233887d-08/
      data fpppp(22,19),fpppp(22,20)/-7.74730474d-08,-5.18942408d-08/
      data fpppp(22,21),fpppp(22,22)/-2.96480408d-08,-1.92479056d-08/
      data fpppp(22,23) /            -5.46318052d-09 /
      data fpppp(23, 1),fpppp(23, 2)/ 4.33028589d-06, 1.06212883d-05/
      data fpppp(23, 3),fpppp(23, 4)/ 1.98449896d-05, 1.88042446d-05/
      data fpppp(23, 5),fpppp(23, 6)/ 1.37006826d-05, 6.46779711d-06/
      data fpppp(23, 7),fpppp(23, 8)/ 8.90121164d-07,-2.31618947d-06/
      data fpppp(23, 9),fpppp(23,10)/-3.67928092d-06,-3.33185755d-06/
      data fpppp(23,11),fpppp(23,12)/-1.62632985d-06,-6.73929338d-07/
      data fpppp(23,13),fpppp(23,14)/-2.25896932d-07,-7.71859778d-08/
      data fpppp(23,15),fpppp(23,16)/-1.35560453d-08,-1.17078262d-08/
      data fpppp(23,17),fpppp(23,18)/-2.21410965d-08,-3.29502957d-08/
      data fpppp(23,19),fpppp(23,20)/-3.86239935d-08,-2.69436451d-08/
      data fpppp(23,21),fpppp(23,22)/-1.81423533d-08,-5.40629110d-09/
      data fpppp(23,23) /             6.20555102d-09 /
      data fpppp(24, 1),fpppp(24, 2)/ 2.41630489d-06, 5.01592641d-06/
      data fpppp(24, 3),fpppp(24, 4)/ 8.46860012d-06, 8.93559119d-06/
      data fpppp(24, 5),fpppp(24, 6)/ 6.63090782d-06, 3.43843652d-06/
      data fpppp(24, 7),fpppp(24, 8)/ 6.76937130d-07,-1.00766154d-06/
      data fpppp(24, 9),fpppp(24,10)/-2.04830166d-06,-1.51275290d-06/
      data fpppp(24,11),fpppp(24,12)/-8.09573416d-07,-2.82227210d-07/
      data fpppp(24,13),fpppp(24,14)/-1.15883539d-07,-3.93771912d-08/
      data fpppp(24,15),fpppp(24,16)/-1.19830668d-08,-4.01491806d-09/
      data fpppp(24,17),fpppp(24,18)/-3.60983513d-09,-2.60517495d-08/
      data fpppp(24,19),fpppp(24,20)/-1.07196438d-08,-1.58001962d-08/
      data fpppp(24,21),fpppp(24,22)/-4.41781037d-09,-5.11685441d-09/
      data fpppp(24,23) /            -2.36406134d-09 /
      data fpppp(25, 1),fpppp(25, 2)/ 5.91952147d-07, 2.05049091d-06/
      data fpppp(25, 3),fpppp(25, 4)/ 4.13681299d-06, 4.02589347d-06/
      data fpppp(25, 5),fpppp(25, 6)/ 3.09187158d-06, 1.72681220d-06/
      data fpppp(25, 7),fpppp(25, 8)/ 2.49323364d-07,-5.77491948d-07/
      data fpppp(25, 9),fpppp(25,10)/-7.95795258d-07,-8.17318678d-07/
      data fpppp(25,11),fpppp(25,12)/-3.03142349d-07,-1.43510522d-07/
      data fpppp(25,13),fpppp(25,14)/-5.18082519d-08,-3.79991933d-08/
      data fpppp(25,15),fpppp(25,16)/ 7.10339814d-09,-3.98907479d-10/
      data fpppp(25,17),fpppp(25,18)/-1.23690246d-08, 1.12154608d-09/
      data fpppp(25,19),fpppp(25,20)/-1.66049796d-08,-5.89629278d-10/
      data fpppp(25,21),fpppp(25,22)/-7.14262001d-09, 4.32627256d-10/
      data fpppp(25,23) /             3.97123510d-09 /
      data fpppp(26, 1),fpppp(26, 2)/ 3.47989411d-07, 8.34704166d-07/
      data fpppp(26, 3),fpppp(26, 4)/ 1.48166809d-06, 1.56775992d-06/
      data fpppp(26, 5),fpppp(26, 6)/ 1.23478568d-06, 5.97870415d-07/
      data fpppp(26, 7),fpppp(26, 8)/ 1.55166708d-07,-1.97915559d-07/
      data fpppp(26, 9),fpppp(26,10)/-3.91735054d-07,-2.49746716d-07/
      data fpppp(26,11),fpppp(26,12)/-1.20342130d-07,-5.72166021d-08/
      data fpppp(26,13),fpppp(26,14)/-4.36549139d-08, 8.74570660d-09/
      data fpppp(26,15),fpppp(26,16)/-1.35460339d-08, 3.90083824d-09/
      data fpppp(26,17),fpppp(26,18)/-5.59719254d-10,-6.94211334d-09/
      data fpppp(26,19),fpppp(26,20)/ 1.59289174d-11,-4.83907575d-09/
      data fpppp(26,21),fpppp(26,22)/ 5.03079784d-10,-2.07502300d-09/
      data fpppp(26,23) /            -2.39019484d-09 /
      data fpppp(27, 1),fpppp(27, 2)/ 1.02194055d-07, 2.72765323d-07/
      data fpppp(27, 3),fpppp(27, 4)/ 5.09557749d-07, 5.14576122d-07/
      data fpppp(27, 5),fpppp(27, 6)/ 3.90728208d-07, 2.21695888d-07/
      data fpppp(27, 7),fpppp(27, 8)/ 3.79642272d-08,-5.91247067d-08/
      data fpppp(27, 9),fpppp(27,10)/-9.81538050d-08,-8.95220436d-08/
      data fpppp(27,11),fpppp(27,12)/-4.80597217d-08,-2.85442588d-08/
      data fpppp(27,13),fpppp(27,14)/-5.47654244d-09,-7.50655684d-09/
      data fpppp(27,15),fpppp(27,16)/ 6.10794733d-09,-2.52020661d-09/
      data fpppp(27,17),fpppp(27,18)/-6.89292290d-10,-1.30543791d-09/
      data fpppp(27,19),fpppp(27,20)/-1.30831500d-09,-9.64881117d-10/
      data fpppp(27,21),fpppp(27,22)/-8.67219305d-10, 1.10283823d-09/
      data fpppp(27,23) /             2.53792556d-09 /
      data fpppp(28, 1),fpppp(28, 2)/-1.72950407d-07,-5.15795902d-07/
      data fpppp(28, 3),fpppp(28, 4)/-9.88392531d-07,-1.00686020d-06/
      data fpppp(28, 5),fpppp(28, 6)/-8.01221910d-07,-3.82564584d-07/
      data fpppp(28, 7),fpppp(28, 8)/-8.78577480d-08, 1.54861531d-07/
      data fpppp(28, 9),fpppp(28,10)/ 2.57795827d-07, 1.88874659d-07/
      data fpppp(28,11),fpppp(28,12)/ 5.97763871d-08, 1.75723870d-08/
      data fpppp(28,13),fpppp(28,14)/ 3.00507144d-08,-1.04567520d-08/
      data fpppp(28,15),fpppp(28,16)/ 1.83737049d-08,-7.12058039d-09/
      data fpppp(28,17),fpppp(28,18)/ 2.05970241d-09, 1.69317760d-09/
      data fpppp(28,19),fpppp(28,20)/ 1.55726665d-09, 1.40954532d-09/
      data fpppp(28,21),fpppp(28,22)/-2.17918553d-10, 3.28758894d-09/
      data fpppp(28,23) /             5.32653319d-09 /
 
      c(1,1)=fpppp(ix+1,iy+1)
      c(1,2)=fpppp(ix+1,iy  )
      c(2,1)=fpppp(ix  ,iy+1)
      c(2,2)=fpppp(ix,  iy  )
      c(1,3)=fpp(ix+1,iy+1,1)
      c(1,4)=fpp(ix+1,iy  ,1)
      c(2,3)=fpp(ix,  iy+1,1)
      c(2,4)=fpp(ix,  iy,  1)
      c(3,1)=fpp(ix+1,iy+1,2)
      c(3,2)=fpp(ix+1,iy  ,2)
      c(4,1)=fpp(ix,  iy+1,2)
      c(4,2)=fpp(ix,  iy,  2)
      c(3,3)=f(ix+1,iy+1)
      c(3,4)=f(ix+1,iy  )
      c(4,3)=f(ix,  iy+1)
      c(4,4)=f(ix,  iy  )
      px(1)=((xi-xix)**3/(6.0*delxi))-(xi-xix)*delxi/6.0
      px(2)=(xi-xixp1)*delxi/6.0-((xi-xixp1)**3/(6.0*delxi))
      px(3)=(xi-xix)/delxi
      px(4)=(xixp1-xi)/delxi
      py(1)=((yi-yiy)**3/(6.0*delyi))-(yi-yiy)*delyi/6.0
      py(2)=(yi-yiyp1)*delyi/6.0-((yi-yiyp1)**3/(6.0*delyi))
      py(3)=(yi-yiy)/delyi
      py(4)=(yiyp1-yi)/delyi

      fi=0.0d 00
      do l=1,4
        sum=0.0d 00
        do i=1,4
          sum=sum + c(i,l) * px(i)
        enddo
        fi = fi + sum * py(l)
      enddo
      return
      end  
      subroutine c2_spl(xi,yi,ix,iy,delxi,delyi,xix,xixp1,
     x                    yiy,yiyp1,fi)
      implicit real*8 (a-h,o-z)
      dimension fpp(28,23,2),f(28,23),fpppp(28,23)
      dimension c(4,4),px(4),py(4)
 
      data f( 1, 9),f( 1,10) / -2.06428500d-02 , -2.40021000d-02 /
      data f( 1,11),f( 1,12) / -1.81029000d-02 , -6.36788000d-03 /
      data f( 1,13),f( 1,14) /  3.99147000d-03 ,  7.78736000d-03 /
      data f( 1,15),f( 1,16) /  5.62964000d-03 ,  3.12356000d-03 /
      data f( 1,17),f( 1,18) /  1.26512000d-03 , -1.52707000d-03 /
      data f( 1,19),f( 1,20) / -3.37218000d-03 , -2.80817000d-03 /
      data f( 1,21),f( 1,22) / -1.31626000d-03 , -3.07240000d-04 /
      data f( 1,23) /           0.00000000d+00 /
      data f( 2, 1),f( 2, 2) /  0.00000000d+00 ,  7.95916000d-03 /
      data f( 2, 3),f( 2, 4) /  3.41660900d-02 ,  7.71899300d-02 /
      data f( 2, 5),f( 2, 6) /  9.73845400d-02 ,  6.12680900d-02 /
      data f( 2, 7),f( 2, 8) /  1.65646100d-02 , -9.51543000d-03 /
      data f( 2, 9),f( 2,10) / -2.03512900d-02 , -2.41820100d-02 /
      data f( 2,11),f( 2,12) / -1.78594200d-02 , -6.52904000d-03 /
      data f( 2,13),f( 2,14) /  3.25504000d-03 ,  6.61877000d-03 /
      data f( 2,15),f( 2,16) /  4.44884000d-03 ,  1.49989000d-03 /
      data f( 2,17),f( 2,18) / -6.78130000d-04 , -2.76870000d-03 /
      data f( 2,19),f( 2,20) / -3.64395000d-03 , -2.68765000d-03 /
      data f( 2,21),f( 2,22) / -1.21430000d-03 , -2.81230000d-04 /
      data f( 2,23) /           0.00000000d+00 /
      data f( 3, 1),f( 3, 2) /  0.00000000d+00 ,  9.20454000d-03 /
      data f( 3, 3),f( 3, 4) /  4.15512800d-02 ,  1.02319560d-01 /
      data f( 3, 5),f( 3, 6) /  1.38625960d-01 ,  8.46419200d-02 /
      data f( 3, 7),f( 3, 8) /  2.29552400d-02 , -7.97311000d-03 /
      data f( 3, 9),f( 3,10) / -2.01181300d-02 , -2.40962500d-02 /
      data f( 3,11),f( 3,12) / -1.73171400d-02 , -6.43502000d-03 /
      data f( 3,13),f( 3,14) /  2.67684000d-03 ,  5.66989000d-03 /
      data f( 3,15),f( 3,16) /  3.58510000d-03 ,  4.79740000d-04 /
      data f( 3,17),f( 3,18) / -1.82193000d-03 , -3.42193000d-03 /
      data f( 3,19),f( 3,20) / -3.67967000d-03 , -2.51669000d-03 /
      data f( 3,21),f( 3,22) / -1.10840000d-03 , -2.55270000d-04 /
      data f( 3,23) /           0.00000000d+00 /
      data f( 4, 1),f( 4, 2) /  0.00000000d+00 ,  1.03949100d-02 /
      data f( 4, 3),f( 4, 4) /  4.92032300d-02 ,  1.33314160d-01 /
      data f( 4, 5),f( 4, 6) /  1.90109320d-01 ,  1.11401520d-01 /
      data f( 4, 7),f( 4, 8) /  2.99610800d-02 , -6.58659000d-03 /
      data f( 4, 9),f( 4,10) / -1.97937300d-02 , -2.44753900d-02 /
      data f( 4,11),f( 4,12) / -1.67614200d-02 , -6.21251000d-03 /
      data f( 4,13),f( 4,14) /  2.20714000d-03 ,  4.88914000d-03 /
      data f( 4,15),f( 4,16) /  2.95418000d-03 , -1.17370000d-04 /
      data f( 4,17),f( 4,18) / -2.41155000d-03 , -3.67453000d-03 /
      data f( 4,19),f( 4,20) / -3.55457000d-03 , -2.31426000d-03 /
      data f( 4,21),f( 4,22) / -1.00152000d-03 , -2.30020000d-04 /
      data f( 4,23) /           0.00000000d+00 /
      data f( 5, 1),f( 5, 2) /  0.00000000d+00 ,  1.13775500d-02 /
      data f( 5, 3),f( 5, 4) /  5.63878900d-02 ,  1.68036350d-01 /
      data f( 5, 5),f( 5, 6) /  2.33499730d-01 ,  1.41497080d-01 /
      data f( 5, 7),f( 5, 8) /  3.60520300d-02 , -5.75554000d-03 /
      data f( 5, 9),f( 5,10) / -1.96879700d-02 , -2.37154800d-02 /
      data f( 5,11),f( 5,12) / -1.60955400d-02 , -5.92453000d-03 /
      data f( 5,13),f( 5,14) /  1.81919000d-03 ,  4.23881000d-03 /
      data f( 5,15),f( 5,16) /  2.49108000d-03 , -4.31450000d-04 /
      data f( 5,17),f( 5,18) / -2.63913000d-03 , -3.66028000d-03 /
      data f( 5,19),f( 5,20) / -3.32631000d-03 , -2.09554000d-03 /
      data f( 5,21),f( 5,22) / -8.96440000d-04 , -2.05570000d-04 /
      data f( 5,23) /           0.00000000d+00 /
      data f( 6, 1),f( 6, 2) /  0.00000000d+00 ,  1.20210400d-02 /
      data f( 6, 3),f( 6, 4) /  6.18516100d-02 ,  2.00232390d-01 /
      data f( 6, 5),f( 6, 6) /  2.57841890d-01 ,  1.68019550d-01 /
      data f( 6, 7),f( 6, 8) /  4.03726700d-02 , -5.38126000d-03 /
      data f( 6, 9),f( 6,10) / -1.96258300d-02 , -2.29407800d-02 /
      data f( 6,11),f( 6,12) / -1.53515800d-02 , -5.60300000d-03 /
      data f( 6,13),f( 6,14) /  1.49529000d-03 ,  3.69077000d-03 /
      data f( 6,15),f( 6,16) /  2.14725000d-03 , -5.59800000d-04 /
      data f( 6,17),f( 6,18) / -2.63188000d-03 , -3.47618000d-03 /
      data f( 6,19),f( 6,20) / -3.03857000d-03 , -1.87240000d-03 /
      data f( 6,21),f( 6,22) / -7.95010000d-04 , -1.82320000d-04 /
      data f( 6,23) /           0.00000000d+00 /
      data f( 7, 1),f( 7, 2) /  0.00000000d+00 ,  1.19004500d-02 /
      data f( 7, 3),f( 7, 4) /  6.44719100d-02 ,  2.21859530d-01 /
      data f( 7, 5),f( 7, 6) /  2.71580240d-01 ,  1.80280390d-01 /
      data f( 7, 7),f( 7, 8) /  4.05641500d-02 , -6.74861000d-03 /
      data f( 7, 9),f( 7,10) / -2.00096800d-02 , -2.13609500d-02 /
      data f( 7,11),f( 7,12) / -1.37278700d-02 , -4.92179000d-03 /
      data f( 7,13),f( 7,14) /  9.96450000d-04 ,  2.82227000d-03 /
      data f( 7,15),f( 7,16) /  1.68052000d-03 , -5.15480000d-04 /
      data f( 7,17),f( 7,18) / -2.24686000d-03 , -2.86128000d-03 /
      data f( 7,19),f( 7,20) / -2.40367000d-03 , -1.44506000d-03 /
      data f( 7,21),f( 7,22) / -6.08920000d-04 , -1.39940000d-04 /
      data f( 7,23) /           0.00000000d+00 /
      data f( 8, 1),f( 8, 2) /  0.00000000d+00 ,  1.03911500d-02 /
      data f( 8, 3),f( 8, 4) /  5.53130200d-02 ,  1.87648630d-01 /
      data f( 8, 5),f( 8, 6) /  2.54798950d-01 ,  1.54408830d-01 /
      data f( 8, 7),f( 8, 8) /  3.14100800d-02 , -8.36051000d-03 /
      data f( 8, 9),f( 8,10) / -1.97638100d-02 , -1.95782600d-02 /
      data f( 8,11),f( 8,12) / -1.20307400d-02 , -4.24306000d-03 /
      data f( 8,13),f( 8,14) /  6.46030000d-04 ,  2.17090000d-03 /
      data f( 8,15),f( 8,16) /  1.36934000d-03 , -3.24670000d-04 /
      data f( 8,17),f( 8,18) / -1.70426000d-03 , -2.17816000d-03 /
      data f( 8,19),f( 8,20) / -1.80548000d-03 , -1.07379000d-03 /
      data f( 8,21),f( 8,22) / -4.50810000d-04 , -1.03800000d-04 /
      data f( 8,23) /           0.00000000d+00 /
      data f( 9, 1),f( 9, 2) /  0.00000000d+00 ,  7.91753000d-03 /
      data f( 9, 3),f( 9, 4) /  4.02146700d-02 ,  1.19032990d-01 /
      data f( 9, 5),f( 9, 6) /  1.80596880d-01 ,  9.63634300d-02 /
      data f( 9, 7),f( 9, 8) /  1.83110500d-02 , -1.07780800d-02 /
      data f( 9, 9),f( 9,10) / -1.91069600d-02 , -1.76004400d-02 /
      data f( 9,11),f( 9,12) / -1.03508100d-02 , -3.60067000d-03 /
      data f( 9,13),f( 9,14) /  4.01530000d-04 ,  1.66982000d-03 /
      data f( 9,15),f( 9,16) /  1.13011000d-03 , -1.37100000d-04 /
      data f( 9,17),f( 9,18) / -1.20306000d-03 , -1.57804000d-03 /
      data f( 9,19),f( 9,20) / -1.30776000d-03 , -7.74170000d-04 /
      data f( 9,21),f( 9,22) / -3.23750000d-04 , -7.43600000d-05 /
      data f( 9,23) /           0.00000000d+00 /
      data f(10, 1),f(10, 2) /  0.00000000d+00 ,  5.56699000d-03 /
      data f(10, 3),f(10, 4) /  2.61771000d-02 ,  6.62102000d-02 /
      data f(10, 5),f(10, 6) /  9.12758600d-02 ,  4.92874600d-02 /
      data f(10, 7),f(10, 8) /  6.21319000d-03 , -1.27692900d-02 /
      data f(10, 9),f(10,10) / -1.81497800d-02 , -1.54983400d-02 /
      data f(10,11),f(10,12) / -8.75246000d-03 , -3.01354000d-03 /
      data f(10,13),f(10,14) /  2.32880000d-04 ,  1.28006000d-03 /
      data f(10,15),f(10,16) /  9.28220000d-04 , -1.92000000d-06 /
      data f(10,17),f(10,18) / -8.09520000d-04 , -1.10734000d-03 /
      data f(10,19),f(10,20) / -9.24030000d-04 , -5.45770000d-04 /
      data f(10,21),f(10,22) / -2.26700000d-04 , -5.17400000d-05 /
      data f(10,23) /           0.00000000d+00 /
      data f(11, 1),f(11, 2) /  0.00000000d+00 ,  3.92013000d-03 /
      data f(11, 3),f(11, 4) /  1.65574800d-02 ,  3.50556000d-02 /
      data f(11, 5),f(11, 6) /  4.24446500d-02 ,  2.11363600d-02 /
      data f(11, 7),f(11, 8) / -2.34691000d-03 , -1.37783600d-02 /
      data f(11, 9),f(11,10) / -1.67742900d-02 , -1.33636800d-02 /
      data f(11,11),f(11,12) / -7.28062000d-03 , -2.49095000d-03 /
      data f(11,13),f(11,14) /  1.18780000d-04 ,  9.75340000d-04 /
      data f(11,15),f(11,16) /  7.52390000d-04 ,  7.63600000d-05 /
      data f(11,17),f(11,18) / -5.27840000d-04 , -7.62840000d-04 /
      data f(11,19),f(11,20) / -6.44050000d-04 , -3.80090000d-04 /
      data f(11,21),f(11,22) / -1.56240000d-04 , -3.49200000d-05 /
      data f(11,23) /           0.00000000d+00 /
      data f(12, 1),f(12, 2) /  0.00000000d+00 ,  3.09011000d-03 /
      data f(12, 3),f(12, 4) /  1.20466100d-02 ,  1.99731200d-02 /
      data f(12, 5),f(12, 6) /  1.80845000d-02 ,  5.72447000d-03 /
      data f(12, 7),f(12, 8) / -7.20679000d-03 , -1.37208800d-02 /
      data f(12, 9),f(12,10) / -1.50380600d-02 , -1.12888100d-02 /
      data f(12,11),f(12,12) / -5.96584000d-03 , -2.03587000d-03 /
      data f(12,13),f(12,14) /  4.39300000d-05 ,  7.37270000d-04 /
      data f(12,15),f(12,16) /  6.00210000d-04 ,  1.10070000d-04 /
      data f(12,17),f(12,18) / -3.39100000d-04 , -5.22900000d-04 /
      data f(12,19),f(12,20) / -4.48070000d-04 , -2.64730000d-04 /
      data f(12,21),f(12,22) / -1.07670000d-04 , -2.35700000d-05 /
      data f(12,23) /           0.00000000d+00 /
      data f(13, 1),f(13, 2) /  0.00000000d+00 ,  2.39497000d-03 /
      data f(13, 3),f(13, 4) /  8.63270000d-03 ,  8.26979000d-03 /
      data f(13, 5),f(13, 6) /  2.75392000d-03 , -3.89704000d-03 /
      data f(13, 7),f(13, 8) / -9.54182000d-03 , -1.21225800d-02 /
      data f(13, 9),f(13,10) / -1.20654000d-02 , -8.45358000d-03 /
      data f(13,11),f(13,12) / -4.31465000d-03 , -1.47485000d-03 /
      data f(13,13),f(13,14) / -1.79100000d-05 ,  4.77150000d-04 /
      data f(13,15),f(13,16) /  4.11940000d-04 ,  1.08600000d-04 /
      data f(13,17),f(13,18) / -1.78480000d-04 , -3.03630000d-04 /
      data f(13,19),f(13,20) / -2.66750000d-04 , -1.59000000d-04 /
      data f(13,21),f(13,22) / -6.45400000d-05 , -1.39800000d-05 /
      data f(13,23) /           0.00000000d+00 /
      data f(14, 1),f(14, 2) /  0.00000000d+00 ,  1.27021000d-03 /
      data f(14, 3),f(14, 4) /  3.24878000d-03 ,  1.80109000d-03 /
      data f(14, 5),f(14, 6) / -2.07194000d-03 , -5.98094000d-03 /
      data f(14, 7),f(14, 8) / -8.70069000d-03 , -9.63609000d-03 /
      data f(14, 9),f(14,10) / -9.10533000d-03 , -6.09218000d-03 /
      data f(14,11),f(14,12) / -3.04113000d-03 , -1.04615000d-03 /
      data f(14,13),f(14,14) / -4.14800000d-05 ,  3.02640000d-04 /
      data f(14,15),f(14,16) /  2.70680000d-04 ,  7.94700000d-05 /
      data f(14,17),f(14,18) / -1.05160000d-04 , -1.88820000d-04 /
      data f(14,19),f(14,20) / -1.69600000d-04 , -1.03470000d-04 /
      data f(14,21),f(14,22) / -4.32300000d-05 , -9.72000000d-06 /
      data f(14,23) /           0.00000000d+00 /
      data f(15, 1),f(15, 2) /  0.00000000d+00 ,  6.68300000d-04 /
      data f(15, 3),f(15, 4) /  1.38528000d-03 ,  7.19000000d-06 /
      data f(15, 5),f(15, 6) / -2.89008000d-03 , -5.68473000d-03 /
      data f(15, 7),f(15, 8) / -7.45367000d-03 , -7.91233000d-03 /
      data f(15, 9),f(15,10) / -7.33138000d-03 , -4.80972000d-03 /
      data f(15,11),f(15,12) / -2.38063000d-03 , -8.22820000d-04 /
      data f(15,13),f(15,14) / -4.47700000d-05 ,  2.21260000d-04 /
      data f(15,15),f(15,16) /  1.99290000d-04 ,  5.67000000d-05 /
      data f(15,17),f(15,18) / -8.16800000d-05 , -1.45200000d-04 /
      data f(15,19),f(15,20) / -1.31690000d-04 , -8.19400000d-05 /
      data f(15,21),f(15,22) / -3.53900000d-05 , -8.15000000d-06 /
      data f(15,23) /           0.00000000d+00 /
      data f(16, 1),f(16, 2) /  0.00000000d+00 ,  3.03200000d-04 /
      data f(16, 3),f(16, 4) /  4.37380000d-04 , -7.40340000d-04 /
      data f(16, 5),f(16, 6) / -2.88294000d-03 , -4.89807000d-03 /
      data f(16, 7),f(16, 8) / -6.09765000d-03 , -6.32257000d-03 /
      data f(16, 9),f(16,10) / -5.79006000d-03 , -3.75262000d-03 /
      data f(16,11),f(16,12) / -1.84863000d-03 , -6.41800000d-04 /
      data f(16,13),f(16,14) / -4.26000000d-05 ,  1.60840000d-04 /
      data f(16,15),f(16,16) /  1.43860000d-04 ,  3.57700000d-05 /
      data f(16,17),f(16,18) / -6.86200000d-05 , -1.16560000d-04 /
      data f(16,19),f(16,20) / -1.06120000d-04 , -6.73500000d-05 /
      data f(16,21),f(16,22) / -2.99000000d-05 , -7.09000000d-06 /
      data f(16,23) /           0.00000000d+00 /
      data f(17, 1),f(17, 2) /  0.00000000d+00 ,  5.23600000d-05 /
      data f(17, 3),f(17, 4) / -1.19700000d-04 , -9.67790000d-04 /
      data f(17, 5),f(17, 6) / -2.30925000d-03 , -3.54878000d-03 /
      data f(17, 7),f(17, 8) / -4.25796000d-03 , -4.34431000d-03 /
      data f(17, 9),f(17,10) / -3.94794000d-03 , -2.54176000d-03 /
      data f(17,11),f(17,12) / -1.25082000d-03 , -4.35740000d-04 /
      data f(17,13),f(17,14) / -3.37900000d-05 ,  9.92800000d-05 /
      data f(17,15),f(17,16) /  8.47400000d-05 ,  1.16000000d-05 /
      data f(17,17),f(17,18) / -5.79000000d-05 , -8.90600000d-05 /
      data f(17,19),f(17,20) / -8.06300000d-05 , -5.22700000d-05 /
      data f(17,21),f(17,22) / -2.41000000d-05 , -5.86000000d-06 /
      data f(17,23) /           0.00000000d+00 /
      data f(18, 1),f(18, 2) /  0.00000000d+00 , -2.71000000d-05 /
      data f(18, 3),f(18, 4) / -2.41850000d-04 , -8.18010000d-04 /
      data f(18, 5),f(18, 6) / -1.64728000d-03 , -2.40776000d-03 /
      data f(18, 7),f(18, 8) / -2.84318000d-03 , -2.88858000d-03 /
      data f(18, 9),f(18,10) / -2.62527000d-03 , -1.69678000d-03 /
      data f(18,11),f(18,12) / -8.37060000d-04 , -2.90860000d-04 /
      data f(18,13),f(18,14) / -2.32700000d-05 ,  6.16800000d-05 /
      data f(18,15),f(18,16) /  4.80200000d-05 , -3.42000000d-06 /
      data f(18,17),f(18,18) / -5.04200000d-05 , -7.04000000d-05 /
      data f(18,19),f(18,20) / -6.28400000d-05 , -4.11200000d-05 /
      data f(18,21),f(18,22) / -1.92600000d-05 , -4.86000000d-06 /
      data f(18,23) /           0.00000000d+00 /
      data f(19, 1),f(19, 2) /  0.00000000d+00 , -4.10200000d-05 /
      data f(19, 3),f(19, 4) / -2.35730000d-04 , -6.72310000d-04 /
      data f(19, 5),f(19, 6) / -1.27168000d-03 , -1.82010000d-03 /
      data f(19, 7),f(19, 8) / -2.13843000d-03 , -2.17458000d-03 /
      data f(19, 9),f(19,10) / -1.98215000d-03 , -1.28885000d-03 /
      data f(19,11),f(19,12) / -6.37320000d-04 , -2.20120000d-04 /
      data f(19,13),f(19,14) / -1.68600000d-05 ,  4.53700000d-05 /
      data f(19,15),f(19,16) /  3.21200000d-05 , -9.10000000d-06 /
      data f(19,17),f(19,18) / -4.55100000d-05 , -6.03200000d-05 /
      data f(19,19),f(19,20) / -5.32600000d-05 , -3.50200000d-05 /
      data f(19,21),f(19,22) / -1.64400000d-05 , -4.17000000d-06 /
      data f(19,23) /           0.00000000d+00 /
      data f(20, 1),f(20, 2) /  0.00000000d+00 , -4.19200000d-05 /
      data f(20, 3),f(20, 4) / -2.05310000d-04 , -5.32280000d-04 /
      data f(20, 5),f(20, 6) / -9.65160000d-04 , -1.36131000d-03 /
      data f(20, 7),f(20, 8) / -1.59602000d-03 , -1.62775000d-03 /
      data f(20, 9),f(20,10) / -1.49048000d-03 , -9.76750000d-04 /
      data f(20,11),f(20,12) / -4.83910000d-04 , -1.65450000d-04 /
      data f(20,13),f(20,14) / -1.13700000d-05 ,  3.38300000d-05 /
      data f(20,15),f(20,16) /  2.10400000d-05 , -1.20600000d-05 /
      data f(20,17),f(20,18) / -4.04600000d-05 , -5.13700000d-05 /
      data f(20,19),f(20,20) / -4.49000000d-05 , -2.95100000d-05 /
      data f(20,21),f(20,22) / -1.39800000d-05 , -3.57000000d-06 /
      data f(20,23) /           0.00000000d+00 /
      data f(21, 1),f(21, 2) /  0.00000000d+00 , -3.40500000d-05 /
      data f(21, 3),f(21, 4) / -1.49870000d-04 , -3.58780000d-04 /
      data f(21, 5),f(21, 6) / -6.25190000d-04 , -8.70590000d-04 /
      data f(21, 7),f(21, 8) / -1.02177000d-03 , -1.04928000d-03 /
      data f(21, 9),f(21,10) / -9.68630000d-04 , -6.42940000d-04 /
      data f(21,11),f(21,12) / -3.18500000d-04 , -1.06400000d-04 /
      data f(21,13),f(21,14) / -5.31000000d-06 ,  2.16400000d-05 /
      data f(21,15),f(21,16) /  1.05000000d-05 , -1.35000000d-05 /
      data f(21,17),f(21,18) / -3.30400000d-05 , -3.98800000d-05 /
      data f(21,19),f(21,20) / -3.43700000d-05 , -2.25700000d-05 /
      data f(21,21),f(21,22) / -1.07600000d-05 , -2.82000000d-06 /
      data f(21,23) /           0.00000000d+00 /
      data f(22, 1),f(22, 2) /  0.00000000d+00 , -1.86900000d-05 /
      data f(22, 3),f(22, 4) / -7.73700000d-05 , -1.75680000d-04 /
      data f(22, 5),f(22, 6) / -2.97610000d-04 , -4.12370000d-04 /
      data f(22, 7),f(22, 8) / -4.87880000d-04 , -5.07440000d-04 /
      data f(22, 9),f(22,10) / -4.74710000d-04 , -3.19660000d-04 /
      data f(22,11),f(22,12) / -1.57020000d-04 , -4.97400000d-05 /
      data f(22,13),f(22,14) / -6.30000000d-07 ,  1.01000000d-05 /
      data f(22,15),f(22,16) /  1.71000000d-06 , -1.20900000d-05 /
      data f(22,17),f(22,18) / -2.24800000d-05 , -2.54100000d-05 /
      data f(22,19),f(22,20) / -2.14400000d-05 , -1.40000000d-05 /
      data f(22,21),f(22,22) / -6.68000000d-06 , -1.71000000d-06 /
      data f(22,23) /           0.00000000d+00 /
      data f(23, 1),f(23, 2) /  0.00000000d+00 , -9.52000000d-06 /
      data f(23, 3),f(23, 4) / -3.89000000d-05 , -8.67200000d-05 /
      data f(23, 5),f(23, 6) / -1.45860000d-04 , -2.01950000d-04 /
      data f(23, 7),f(23, 8) / -2.40030000d-04 , -2.51470000d-04 /
      data f(23, 9),f(23,10) / -2.36620000d-04 , -1.59630000d-04 /
      data f(23,11),f(23,12) / -7.68800000d-05 , -2.33600000d-05 /
      data f(23,13),f(23,14) / -2.90000000d-07 ,  3.28000000d-06 /
      data f(23,15),f(23,16) / -2.35000000d-06 , -1.00300000d-05 /
      data f(23,17),f(23,18) / -1.53000000d-05 , -1.62600000d-05 /
      data f(23,19),f(23,20) / -1.34300000d-05 , -8.73000000d-06 /
      data f(23,21),f(23,22) / -4.18000000d-06 , -1.06000000d-06 /
      data f(23,23) /           0.00000000d+00 /
      data f(24, 1),f(24, 2) /  0.00000000d+00 , -5.21000000d-06 /
      data f(24, 3),f(24, 4) / -2.09500000d-05 , -4.56500000d-05 /
      data f(24, 5),f(24, 6) / -7.54900000d-05 , -1.03450000d-04 /
      data f(24, 7),f(24, 8) / -1.22190000d-04 , -1.27440000d-04 /
      data f(24, 9),f(24,10) / -1.19470000d-04 , -7.98000000d-05 /
      data f(24,11),f(24,12) / -3.78600000d-05 , -1.17600000d-05 /
      data f(24,13),f(24,14) / -1.40000000d-06 , -6.90000000d-07 /
      data f(24,15),f(24,16) / -4.27000000d-06 , -8.45000000d-06 /
      data f(24,17),f(24,18) / -1.10000000d-05 , -1.10400000d-05 /
      data f(24,19),f(24,20) / -8.94000000d-06 , -5.81000000d-06 /
      data f(24,21),f(24,22) / -2.80000000d-06 , -7.20000000d-07 /
      data f(24,23) /           0.00000000d+00 /
      data f(25, 1),f(25, 2) /  0.00000000d+00 , -2.98000000d-06 /
      data f(25, 3),f(25, 4) / -1.16500000d-05 , -2.49600000d-05 /
      data f(25, 5),f(25, 6) / -4.04000000d-05 , -5.43200000d-05 /
      data f(25, 7),f(25, 8) / -6.32200000d-05 , -6.52400000d-05 /
      data f(25, 9),f(25,10) / -6.06800000d-05 , -3.99800000d-05 /
      data f(25,11),f(25,12) / -1.90800000d-05 , -6.70000000d-06 /
      data f(25,13),f(25,14) / -2.19000000d-06 , -2.54000000d-06 /
      data f(25,15),f(25,16) / -4.76000000d-06 , -7.09000000d-06 /
      data f(25,17),f(25,18) / -8.30000000d-06 , -7.96000000d-06 /
      data f(25,19),f(25,20) / -6.37000000d-06 , -4.15000000d-06 /
      data f(25,21),f(25,22) / -2.01000000d-06 , -5.30000000d-07 /
      data f(25,23) /           0.00000000d+00 /
      data f(26, 1),f(26, 2) /  0.00000000d+00 , -1.70000000d-06 /
      data f(26, 3),f(26, 4) / -6.58000000d-06 , -1.37600000d-05 /
      data f(26, 5),f(26, 6) / -2.17600000d-05 , -2.86800000d-05 /
      data f(26, 7),f(26, 8) / -3.28500000d-05 , -3.34800000d-05 /
      data f(26, 9),f(26,10) / -3.08400000d-05 , -2.02800000d-05 /
      data f(26,11),f(26,12) / -1.01000000d-05 , -4.20000000d-06 /
      data f(26,13),f(26,14) / -2.26000000d-06 , -2.67000000d-06 /
      data f(26,15),f(26,16) / -4.23000000d-06 , -5.58000000d-06 /
      data f(26,17),f(26,18) / -6.18000000d-06 , -5.79000000d-06 /
      data f(26,19),f(26,20) / -4.58000000d-06 , -2.99000000d-06 /
      data f(26,21),f(26,22) / -1.46000000d-06 , -3.80000000d-07 /
      data f(26,23) /           0.00000000d+00 /
      data f(27, 1),f(27, 2) /  0.00000000d+00 , -5.10000000d-07 /
      data f(27, 3),f(27, 4) / -1.94000000d-06 , -3.97000000d-06 /
      data f(27, 5),f(27, 6) / -6.13000000d-06 , -7.94000000d-06 /
      data f(27, 7),f(27, 8) / -9.00000000d-06 , -9.16000000d-06 /
      data f(27, 9),f(27,10) / -8.52000000d-06 , -5.95000000d-06 /
      data f(27,11),f(27,12) / -3.33000000d-06 , -1.71000000d-06 /
      data f(27,13),f(27,14) / -1.24000000d-06 , -1.59000000d-06 /
      data f(27,15),f(27,16) / -2.10000000d-06 , -2.61000000d-06 /
      data f(27,17),f(27,18) / -2.78000000d-06 , -2.54000000d-06 /
      data f(27,19),f(27,20) / -1.99000000d-06 , -1.29000000d-06 /
      data f(27,21),f(27,22) / -6.30000000d-07 , -1.80000000d-07 /
      data f(27,23) /           0.00000000d+00 /
      data f(28, 1),f(28, 2) /  0.00000000d+00 , -1.60000000d-07 /
      data f(28, 3),f(28, 4) / -6.50000000d-07 , -1.33000000d-06 /
      data f(28, 5),f(28, 6) / -2.05000000d-06 , -2.67000000d-06 /
      data f(28, 7),f(28, 8) / -3.06000000d-06 , -3.15000000d-06 /
      data f(28, 9),f(28,10) / -2.98000000d-06 , -2.11000000d-06 /
      data f(28,11),f(28,12) / -1.17000000d-06 , -6.10000000d-07 /
      data f(28,13),f(28,14) / -5.30000000d-07 , -6.10000000d-07 /
      data f(28,15),f(28,16) / -7.10000000d-07 , -8.90000000d-07 /
      data f(28,17),f(28,18) / -9.30000000d-07 , -8.40000000d-07 /
      data f(28,19),f(28,20) / -6.50000000d-07 , -4.00000000d-07 /
      data f(28,21),f(28,22) / -2.40000000d-07 , -2.00000000d-08 /
      data f(28,23) /           0.00000000d+00 /
 
      data fpp( 1, 1,1),fpp( 1, 1,2)/ 0.00000000d+00, 8.25998620d-04/
      data fpp( 1, 2,1),fpp( 1, 2,2)/ 2.31862802d-02, 4.99336761d-04/
      data fpp( 1, 3,1),fpp( 1, 3,2)/ 1.38589335d-01, 5.37434338d-04/
      data fpp( 1, 4,1),fpp( 1, 4,2)/ 3.19362942d-01,-7.01126113d-04/
      data fpp( 1, 5,1),fpp( 1, 5,2)/ 1.35721481d+00,-1.99754989d-03/
      data fpp( 1, 6,1),fpp( 1, 6,2)/ 5.25374419d-01,-8.58463424d-05/
      data fpp( 1, 7,1),fpp( 1, 7,2)/-1.18328823d-01, 6.59046456d-04/
      data fpp( 1, 8,1),fpp( 1, 8,2)/ 1.42462407d-01, 3.71473320d-04/
      data fpp( 1, 9,1),fpp( 1, 9,2)/-1.82220440d-02, 2.62039466d-04/
      data fpp( 1,10,1),fpp( 1,10,2)/ 8.66035876d-02, 5.34567421d-05/
      data fpp( 1,11,1),fpp( 1,11,2)/ 5.66886086d-02, 7.96405655d-05/
      data fpp( 1,12,1),fpp( 1,12,2)/ 3.79539464d-02,-2.18698041d-05/
      data fpp( 1,13,1),fpp( 1,13,2)/ 2.07092266d-02,-7.47015489d-05/
      data fpp( 1,14,1),fpp( 1,14,2)/ 2.70806615d-02,-7.31316001d-05/
      data fpp( 1,15,1),fpp( 1,15,2)/ 4.00660651d-02, 1.00113495d-05/
      data fpp( 1,16,1),fpp( 1,16,2)/ 7.82733490d-02, 1.21846021d-05/
      data fpp( 1,17,1),fpp( 1,17,2)/ 1.04315393d-01,-1.98913580d-05/
      data fpp( 1,18,1),fpp( 1,18,2)/ 7.74284095d-02, 1.13558299d-05/
      data fpp( 1,19,1),fpp( 1,19,2)/ 3.10682558d-02, 3.12928384d-05/
      data fpp( 1,20,1),fpp( 1,20,2)/ 6.92830147d-03, 8.02001651d-06/
      data fpp( 1,21,1),fpp( 1,21,2)/ 6.90253645d-04,-7.69890445d-06/
      data fpp( 1,22,1),fpp( 1,22,2)/ 5.82152278d-05,-6.19779873d-06/
      data fpp( 1,23,1),fpp( 1,23,2)/ 0.00000000d+00,-9.61670064d-06/
      data fpp( 2, 1,1),fpp( 2, 1,2)/ 0.00000000d+00, 8.43173656d-04/
      data fpp( 2, 2,1),fpp( 2, 2,2)/ 8.62943959d-03, 6.17853889d-04/
      data fpp( 2, 3,1),fpp( 2, 3,2)/ 8.24243298d-02, 1.06487559d-03/
      data fpp( 2, 4,1),fpp( 2, 4,2)/ 4.22275116d-01,-8.41297845d-04/
      data fpp( 2, 5,1),fpp( 2, 5,2)/ 1.00588238d+00,-3.17869941d-03/
      data fpp( 2, 6,1),fpp( 2, 6,2)/ 4.55567162d-01, 4.14410802d-05/
      data fpp( 2, 7,1),fpp( 2, 7,2)/-5.63693534d-02, 9.52047888d-04/
      data fpp( 2, 8,1),fpp( 2, 8,2)/ 6.56301863d-02, 6.19992968d-04/
      data fpp( 2, 9,1),fpp( 2, 9,2)/-1.10039120d-02, 2.26583441d-04/
      data fpp( 2,10,1),fpp( 2,10,2)/ 5.26078248d-02, 8.07131932d-05/
      data fpp( 2,11,1),fpp( 2,11,2)/ 3.33347829d-02, 5.97623864d-05/
      data fpp( 2,12,1),fpp( 2,12,2)/ 2.59841071d-02,-1.92953387d-05/
      data fpp( 2,13,1),fpp( 2,13,2)/ 1.59965467d-02,-7.53590317d-05/
      data fpp( 2,14,1),fpp( 2,14,2)/ 2.20676769d-02,-6.44895346d-05/
      data fpp( 2,15,1),fpp( 2,15,2)/ 3.18338698d-02, 1.29757006d-06/
      data fpp( 2,16,1),fpp( 2,16,2)/ 6.06053020d-02, 1.25580544d-05/
      data fpp( 2,17,1),fpp( 2,17,2)/ 8.02582145d-02,-5.27398751d-06/
      data fpp( 2,18,1),fpp( 2,18,2)/ 5.92171810d-02, 1.37848957d-05/
      data fpp( 2,19,1),fpp( 2,19,2)/ 2.37244884d-02, 2.30536047d-05/
      data fpp( 2,20,1),fpp( 2,20,2)/ 5.06939705d-03, 3.89368533d-06/
      data fpp( 2,21,1),fpp( 2,21,2)/ 3.93492710d-04,-7.60534605d-06/
      data fpp( 2,22,1),fpp( 2,22,2)/ 5.69544417d-07,-5.88910113d-06/
      data fpp( 2,23,1),fpp( 2,23,2)/ 0.00000000d+00,-7.94864944d-06/
      data fpp( 3, 1,1),fpp( 3, 1,2)/ 0.00000000d+00, 7.86555203d-04/
      data fpp( 3, 2,1),fpp( 3, 2,2)/-4.90403856d-03, 7.81606394d-04/
      data fpp( 3, 3,1),fpp( 3, 3,2)/ 2.72593457d-02, 1.64114722d-03/
      data fpp( 3, 4,1),fpp( 3, 4,2)/ 6.72330595d-01,-5.25025681d-04/
      data fpp( 3, 5,1),fpp( 3, 5,2)/ 1.54169567d+00,-5.41189570d-03/
      data fpp( 3, 6,1),fpp( 3, 6,2)/ 2.72520933d-01, 5.02902872d-04/
      data fpp( 3, 7,1),fpp( 3, 7,2)/ 1.39824237d-01, 1.55165061d-03/
      data fpp( 3, 8,1),fpp( 3, 8,2)/-2.17091520d-02, 6.72493882d-04/
      data fpp( 3, 9,1),fpp( 3, 9,2)/ 2.71976921d-02, 2.66373059d-04/
      data fpp( 3,10,1),fpp( 3,10,2)/-1.37632887d-01, 8.33490810d-05/
      data fpp( 3,11,1),fpp( 3,11,2)/-1.07477401d-02, 4.56644166d-05/
      data fpp( 3,12,1),fpp( 3,12,2)/ 1.12176251d-02,-1.98261475d-05/
      data fpp( 3,13,1),fpp( 3,13,2)/ 1.02425865d-02,-7.25754266d-05/
      data fpp( 3,14,1),fpp( 3,14,2)/ 1.64746307d-02,-5.70007461d-05/
      data fpp( 3,15,1),fpp( 3,15,2)/ 2.28344559d-02,-4.09198908d-06/
      data fpp( 3,16,1),fpp( 3,16,2)/ 4.14174429d-02, 1.21345024d-05/
      data fpp( 3,17,1),fpp( 3,17,2)/ 5.43217494d-02, 3.77537946d-06/
      data fpp( 3,18,1),fpp( 3,18,2)/ 3.87428667d-02, 1.48641797d-05/
      data fpp( 3,19,1),fpp( 3,19,2)/ 1.56637906d-02, 1.73035016d-05/
      data fpp( 3,20,1),fpp( 3,20,2)/ 3.05811031d-03, 1.16501401d-06/
      data fpp( 3,21,1),fpp( 3,21,2)/ 9.97755148d-05,-7.24495762d-06/
      data fpp( 3,22,1),fpp( 3,22,2)/-9.04934055d-05,-5.49478354d-06/
      data fpp( 3,23,1),fpp( 3,23,2)/ 0.00000000d+00,-6.64750823d-06/
      data fpp( 4, 1,1),fpp( 4, 1,2)/ 0.00000000d+00, 5.62775767d-04/
      data fpp( 4, 2,1),fpp( 4, 2,2)/-2.20192854d-02, 9.32921665d-04/
      data fpp( 4, 3,1),fpp( 4, 3,2)/-3.14057125d-02, 2.52475597d-03/
      data fpp( 4, 4,1),fpp( 4, 4,2)/ 4.07384504d-01,-1.59319154d-04/
      data fpp( 4, 5,1),fpp( 4, 5,2)/-1.02750105d+00,-8.44326416d-03/
      data fpp( 4, 6,1),fpp( 4, 6,2)/ 4.85811106d-01, 1.41166538d-03/
      data fpp( 4, 7,1),fpp( 4, 7,2)/-1.33801594d-01, 2.14076905d-03/
      data fpp( 4, 8,1),fpp( 4, 8,2)/-7.22735783d-02, 7.99523235d-04/
      data fpp( 4, 9,1),fpp( 4, 9,2)/-4.30428566d-02, 2.62865212d-04/
      data fpp( 4,10,1),fpp( 4,10,2)/ 2.18983722d-01, 1.15599947d-04/
      data fpp( 4,11,1),fpp( 4,11,2)/ 1.77201776d-02, 1.84728014d-05/
      data fpp( 4,12,1),fpp( 4,12,2)/ 6.23939263d-03,-1.93947524d-05/
      data fpp( 4,13,1),fpp( 4,13,2)/ 8.13310725d-03,-6.86493918d-05/
      data fpp( 4,14,1),fpp( 4,14,2)/ 1.29118003d-02,-5.02666803d-05/
      data fpp( 4,15,1),fpp( 4,15,2)/ 1.65203068d-02,-7.30148694d-06/
      data fpp( 4,16,1),fpp( 4,16,2)/ 2.75489262d-02, 1.12772281d-05/
      data fpp( 4,17,1),fpp( 4,17,2)/ 3.49627880d-02, 8.83477467d-06/
      data fpp( 4,18,1),fpp( 4,18,2)/ 2.61893524d-02, 1.52556733d-05/
      data fpp( 4,19,1),fpp( 4,19,2)/ 1.01123492d-02, 1.31189323d-05/
      data fpp( 4,20,1),fpp( 4,20,2)/ 1.58016169d-03,-5.10402473d-07/
      data fpp( 4,21,1),fpp( 4,21,2)/-2.04594769d-04,-6.73152241d-06/
      data fpp( 4,22,1),fpp( 4,22,2)/-6.45959226d-05,-5.03790788d-06/
      data fpp( 4,23,1),fpp( 4,23,2)/ 0.00000000d+00,-5.60564606d-06/
      data fpp( 5, 1,1),fpp( 5, 1,2)/ 0.00000000d+00, 2.36045562d-04/
      data fpp( 5, 2,1),fpp( 5, 2,2)/-3.16568200d-02, 9.23417276d-04/
      data fpp( 5, 3,1),fpp( 5, 3,2)/-1.82010496d-01, 4.14215493d-03/
      data fpp( 5, 4,1),fpp( 5, 4,2)/-6.53146129d-02,-1.49888821d-03/
      data fpp( 5, 5,1),fpp( 5, 5,2)/-2.28746146d+00,-9.23102131d-03/
      data fpp( 5, 6,1),fpp( 5, 6,2)/-2.14189356d-01, 6.31126234d-04/
      data fpp( 5, 7,1),fpp( 5, 7,2)/-1.53551861d-01, 3.48034037d-03/
      data fpp( 5, 8,1),fpp( 5, 8,2)/-2.24785349d-02, 7.20507480d-04/
      data fpp( 5, 9,1),fpp( 5, 9,2)/ 1.37897341d-02, 3.27663307d-04/
      data fpp( 5,10,1),fpp( 5,10,2)/-5.48720011d-02, 8.69973390d-05/
      data fpp( 5,11,1),fpp( 5,11,2)/ 5.96302980d-03, 2.31943370d-05/
      data fpp( 5,12,1),fpp( 5,12,2)/ 3.10680441d-03,-2.67104872d-05/
      data fpp( 5,13,1),fpp( 5,13,2)/ 6.27498450d-03,-6.19897884d-05/
      data fpp( 5,14,1),fpp( 5,14,2)/ 1.01301681d-02,-4.47763592d-05/
      data fpp( 5,15,1),fpp( 5,15,2)/ 1.17763169d-02,-8.94577496d-06/
      data fpp( 5,16,1),fpp( 5,16,2)/ 1.82048522d-02, 1.00714590d-05/
      data fpp( 5,17,1),fpp( 5,17,2)/ 2.30510986d-02, 1.15509390d-05/
      data fpp( 5,18,1),fpp( 5,18,2)/ 1.66097238d-02, 1.49165850d-05/
      data fpp( 5,19,1),fpp( 5,19,2)/ 5.78281278d-03, 1.00899212d-05/
      data fpp( 5,20,1),fpp( 5,20,2)/ 3.95242932d-04,-1.46826959d-06/
      data fpp( 5,21,1),fpp( 5,21,2)/-3.61396437d-04,-6.11704280d-06/
      data fpp( 5,22,1),fpp( 5,22,2)/-1.31122904d-04,-4.55735920d-06/
      data fpp( 5,23,1),fpp( 5,23,2)/ 0.00000000d+00,-4.77152040d-06/
      data fpp( 6, 1,1),fpp( 6, 1,2)/ 0.00000000d+00,-1.25909064d-04/
      data fpp( 6, 2,1),fpp( 6, 2,2)/-5.48434347d-02, 7.29707329d-04/
      data fpp( 6, 3,1),fpp( 6, 3,2)/-2.73116304d-01, 6.28136695d-03/
      data fpp( 6, 4,1),fpp( 6, 4,2)/-1.66181605d+00,-4.60312473d-03/
      data fpp( 6, 5,1),fpp( 6, 5,2)/-1.25160309d+00,-7.25397524d-03/
      data fpp( 6, 6,1),fpp( 6, 6,2)/-1.77290768d+00,-1.76461593d-03/
      data fpp( 6, 7,1),fpp( 6, 7,2)/-3.14176961d-01, 5.23454935d-03/
      data fpp( 6, 8,1),fpp( 6, 8,2)/-1.11874282d-01, 4.80726533d-04/
      data fpp( 6, 9,1),fpp( 6, 9,2)/-3.82880797d-02, 4.04790919d-04/
      data fpp( 6,10,1),fpp( 6,10,2)/ 9.37828250d-03, 5.57153751d-05/
      data fpp( 6,11,1),fpp( 6,11,2)/ 5.27570323d-03, 2.65965801d-05/
      data fpp( 6,12,1),fpp( 6,12,2)/ 1.46338972d-03,-3.25388954d-05/
      data fpp( 6,13,1),fpp( 6,13,2)/ 5.19695474d-03,-5.54583984d-05/
      data fpp( 6,14,1),fpp( 6,14,2)/ 7.94152722d-03,-3.97961109d-05/
      data fpp( 6,15,1),fpp( 6,15,2)/ 7.93642570d-03,-9.69715808d-06/
      data fpp( 6,16,1),fpp( 6,16,2)/ 1.10696652d-02, 8.77294319d-06/
      data fpp( 6,17,1),fpp( 6,17,2)/ 1.37308177d-02, 1.27035853d-05/
      data fpp( 6,18,1),fpp( 6,18,2)/ 9.28175241d-03, 1.40795155d-05/
      data fpp( 6,19,1),fpp( 6,19,2)/ 2.44439974d-03, 7.89295276d-06/
      data fpp( 6,20,1),fpp( 6,20,2)/-5.09133416d-04,-1.93772651d-06/
      data fpp( 6,21,1),fpp( 6,21,2)/-5.39819481d-04,-5.46884671d-06/
      data fpp( 6,22,1),fpp( 6,22,2)/-1.30912461d-04,-4.06888665d-06/
      data fpp( 6,23,1),fpp( 6,23,2)/ 0.00000000d+00,-4.07780667d-06/
      data fpp( 7, 1,1),fpp( 7, 1,2)/ 0.00000000d+00,-4.12400407d-04/
      data fpp( 7, 2,1),fpp( 7, 2,2)/-3.07767859d-02, 5.73710015d-04/
      data fpp( 7, 3,1),fpp( 7, 3,2)/-3.35716839d-01, 7.87860275d-03/
      data fpp( 7, 4,1),fpp( 7, 4,2)/-1.39663553d+00,-6.93224261d-03/
      data fpp( 7, 5,1),fpp( 7, 5,2)/-3.43355487d-01,-5.98969072d-03/
      data fpp( 7, 6,1),fpp( 7, 6,2)/-6.91797282d-01,-2.95392890d-03/
      data fpp( 7, 7,1),fpp( 7, 7,2)/-2.48163187d-01, 6.18547273d-03/
      data fpp( 7, 8,1),fpp( 7, 8,2)/ 2.94756138d-02, 3.88873174d-04/
      data fpp( 7, 9,1),fpp( 7, 9,2)/ 3.17498722d-02, 4.31440173d-04/
      data fpp( 7,10,1),fpp( 7,10,2)/ 3.86565307d-03, 2.14950929d-05/
      data fpp( 7,11,1),fpp( 7,11,2)/ 1.55987540d-03, 2.16404548d-05/
      data fpp( 7,12,1),fpp( 7,12,2)/-2.21071376d-04,-3.76769121d-05/
      data fpp( 7,13,1),fpp( 7,13,2)/ 3.61564352d-03,-4.42032063d-05/
      data fpp( 7,14,1),fpp( 7,14,2)/ 5.24733429d-03,-3.10554626d-05/
      data fpp( 7,15,1),fpp( 7,15,2)/ 3.44206446d-03,-9.62914318d-06/
      data fpp( 7,16,1),fpp( 7,16,2)/ 2.84157847d-03, 6.31703536d-06/
      data fpp( 7,17,1),fpp( 7,17,2)/ 2.85999754d-03, 1.22382018d-05/
      data fpp( 7,18,1),fpp( 7,18,2)/ 8.54880859d-04, 1.17477576d-05/
      data fpp( 7,19,1),fpp( 7,19,2)/-1.31160562d-03, 5.09256771d-06/
      data fpp( 7,20,1),fpp( 7,20,2)/-1.51122122d-03,-2.05802846d-06/
      data fpp( 7,21,1),fpp( 7,21,2)/-7.15343337d-04,-4.20865388d-06/
      data fpp( 7,22,1),fpp( 7,22,2)/-1.59701166d-04,-3.13695604d-06/
      data fpp( 7,23,1),fpp( 7,23,2)/ 0.00000000d+00,-2.98592198d-06/
      data fpp( 8, 1,1),fpp( 8, 1,2)/ 0.00000000d+00,-4.00305118d-04/
      data fpp( 8, 2,1),fpp( 8, 2,2)/-3.03559216d-02, 7.13655037d-04/
      data fpp( 8, 3,1),fpp( 8, 3,2)/-1.50894840d-01, 5.83305777d-03/
      data fpp( 8, 4,1),fpp( 8, 4,2)/-1.12734781d+00,-3.06658852d-03/
      data fpp( 8, 5,1),fpp( 8, 5,2)/-1.95292096d+00,-9.21117328d-03/
      data fpp( 8, 6,1),fpp( 8, 6,2)/-1.17976319d+00,-2.98423967d-04/
      data fpp( 8, 7,1),fpp( 8, 7,2)/-9.50027930d-02, 4.97879794d-03/
      data fpp( 8, 8,1),fpp( 8, 8,2)/-4.27106730d-02, 3.57990592d-04/
      data fpp( 8, 9,1),fpp( 8, 9,2)/ 5.74659104d-03, 3.97389287d-04/
      data fpp( 8,10,1),fpp( 8,10,2)/ 5.58810523d-03, 8.36584200d-06/
      data fpp( 8,11,1),fpp( 8,11,2)/-5.02204825d-04, 1.08655447d-05/
      data fpp( 8,12,1),fpp( 8,12,2)/-9.51104219d-04,-3.74184209d-05/
      data fpp( 8,13,1),fpp( 8,13,2)/ 2.60347118d-03,-3.51072613d-05/
      data fpp( 8,14,1),fpp( 8,14,2)/ 3.63863563d-03,-2.40057340d-05/
      data fpp( 8,15,1),fpp( 8,15,2)/ 1.62781644d-03,-8.45560284d-06/
      data fpp( 8,16,1),fpp( 8,16,2)/-4.62479032d-04, 4.28114533d-06/
      data fpp( 8,17,1),fpp( 8,17,2)/-1.53380788d-03, 1.01962215d-05/
      data fpp( 8,18,1),fpp( 8,18,2)/-2.46827585d-03, 9.27536855d-06/
      data fpp( 8,19,1),fpp( 8,19,2)/-2.70447728d-03, 3.49710428d-06/
      data fpp( 8,20,1),fpp( 8,20,2)/-1.85648171d-03,-1.72318568d-06/
      data fpp( 8,21,1),fpp( 8,21,2)/-7.95807171d-04,-3.12696155d-06/
      data fpp( 8,22,1),fpp( 8,22,2)/-1.66282874d-04,-2.32716813d-06/
      data fpp( 8,23,1),fpp( 8,23,2)/ 0.00000000d+00,-2.15696594d-06/
      data fpp( 9, 1,1),fpp( 9, 1,2)/ 0.00000000d+00, 1.66961273d-04/
      data fpp( 9, 2,1),fpp( 9, 2,2)/ 7.55247251d-03, 8.20305054d-04/
      data fpp( 9, 3,1),fpp( 9, 3,2)/ 4.83771978d-02, 2.40292491d-03/
      data fpp( 9, 4,1),fpp( 9, 4,2)/ 7.45315766d-01, 7.33078505d-04/
      data fpp( 9, 5,1),fpp( 9, 5,2)/-4.58077677d-01,-9.47630213d-03/
      data fpp( 9, 6,1),fpp( 9, 6,2)/ 5.84774053d-01, 2.18076842d-03/
      data fpp( 9, 7,1),fpp( 9, 7,2)/ 3.64303584d-02, 2.23668526d-03/
      data fpp( 9, 8,1),fpp( 9, 8,2)/ 2.05165781d-02, 6.23670531d-04/
      data fpp( 9, 9,1),fpp( 9, 9,2)/ 6.91076365d-03, 2.51092614d-04/
      data fpp( 9,10,1),fpp( 9,10,2)/ 3.05142602d-03, 2.47436926d-05/
      data fpp( 9,11,1),fpp( 9,11,2)/-2.13105610d-03,-5.48078442d-06/
      data fpp( 9,12,1),fpp( 9,12,2)/-1.42551175d-03,-3.27899549d-05/
      data fpp( 9,13,1),fpp( 9,13,2)/ 1.85847175d-03,-2.82357959d-05/
      data fpp( 9,14,1),fpp( 9,14,2)/ 2.74162317d-03,-1.83014614d-05/
      data fpp( 9,15,1),fpp( 9,15,2)/ 8.39169768d-04,-7.03835844d-06/
      data fpp( 9,16,1),fpp( 9,16,2)/-1.47766234d-03, 2.80489516d-06/
      data fpp( 9,17,1),fpp( 9,17,2)/-2.93476602d-03, 7.89377782d-06/
      data fpp( 9,18,1),fpp( 9,18,2)/-3.43177746d-03, 7.07879358d-06/
      data fpp( 9,19,1),fpp( 9,19,2)/-2.94098526d-03, 2.50664785d-06/
      data fpp( 9,20,1),fpp( 9,20,2)/-1.81035194d-03,-1.30678499d-06/
      data fpp( 9,21,1),fpp( 9,21,2)/-7.58927980d-04,-2.26970789d-06/
      data fpp( 9,22,1),fpp( 9,22,2)/-1.80167337d-04,-1.67618346d-06/
      data fpp( 9,23,1),fpp( 9,23,2)/ 0.00000000d+00,-1.52735827d-06/
      data fpp(10, 1,1),fpp(10, 1,2)/ 0.00000000d+00, 4.67904280d-04/
      data fpp(10, 2,1),fpp(10, 2,2)/ 1.86080316d-02, 5.18976239d-04/
      data fpp(10, 3,1),fpp(10, 3,2)/ 1.16503049d-01, 1.06653956d-03/
      data fpp(10, 4,1),fpp(10, 4,2)/ 5.15012244d-01,-1.23616890d-04/
      data fpp(10, 5,1),fpp(10, 5,2)/ 1.51738917d+00,-4.16425760d-03/
      data fpp(10, 6,1),fpp(10, 6,2)/ 4.86081482d-01, 6.87672907d-04/
      data fpp(10, 7,1),fpp(10, 7,2)/ 9.94568594d-02, 1.15295718d-03/
      data fpp(10, 8,1),fpp(10, 8,2)/ 2.45983604d-02, 4.82527991d-04/
      data fpp(10, 9,1),fpp(10, 9,2)/ 1.16598543d-02, 1.81408462d-04/
      data fpp(10,10,1),fpp(10,10,2)/ 8.48190705d-04, 1.92558199d-05/
      data fpp(10,11,1),fpp(10,11,2)/-3.21057079d-03,-1.27653413d-05/
      data fpp(10,12,1),fpp(10,12,2)/-1.63584879d-03,-2.86120548d-05/
      data fpp(10,13,1),fpp(10,13,2)/ 1.34014182d-03,-2.23364397d-05/
      data fpp(10,14,1),fpp(10,14,2)/ 2.09287167d-03,-1.39965866d-05/
      data fpp(10,15,1),fpp(10,15,2)/ 6.16504486d-04,-5.61841408d-06/
      data fpp(10,16,1),fpp(10,16,2)/-1.48537159d-03, 1.77224290d-06/
      data fpp(10,17,1),fpp(10,17,2)/-2.87612805d-03, 5.88184249d-06/
      data fpp(10,18,1),fpp(10,18,2)/-3.21761430d-03, 5.28718713d-06/
      data fpp(10,19,1),fpp(10,19,2)/-2.63008168d-03, 1.83720897d-06/
      data fpp(10,20,1),fpp(10,20,2)/-1.58511053d-03,-9.39023024d-07/
      data fpp(10,21,1),fpp(10,21,2)/-6.69980911d-04,-1.63251688d-06/
      data fpp(10,22,1),fpp(10,22,2)/-1.36047777d-04,-1.17750946d-06/
      data fpp(10,23,1),fpp(10,23,2)/ 0.00000000d+00,-1.05064527d-06/
      data fpp(11, 1,1),fpp(11, 1,2)/ 0.00000000d+00, 4.80578483d-04/
      data fpp(11, 2,1),fpp(11, 2,2)/ 2.35674010d-02, 3.13425435d-04/
      data fpp(11, 3,1),fpp(11, 3,2)/ 1.48303108d-01, 3.57852578d-04/
      data fpp(11, 4,1),fpp(11, 4,2)/ 4.44863757d-01,-3.38250945d-04/
      data fpp(11, 5,1),fpp(11, 5,2)/ 4.61992514d-01,-1.67102560d-03/
      data fpp(11, 6,1),fpp(11, 6,2)/ 3.09630521d-01, 1.34991733d-04/
      data fpp(11, 7,1),fpp(11, 7,2)/ 9.64062040d-02, 6.09063466d-04/
      data fpp(11, 8,1),fpp(11, 8,2)/ 2.84109802d-02, 3.21191205d-04/
      data fpp(11, 9,1),fpp(11, 9,2)/ 9.19631898d-03, 1.30696514d-04/
      data fpp(11,10,1),fpp(11,10,2)/-1.56018884d-03, 1.14630542d-05/
      data fpp(11,11,1),fpp(11,11,2)/-4.00316075d-03,-1.62017311d-05/
      data fpp(11,12,1),fpp(11,12,2)/-1.71209311d-03,-2.42595299d-05/
      data fpp(11,13,1),fpp(11,13,2)/ 9.63460960d-04,-1.75565494d-05/
      data fpp(11,14,1),fpp(11,14,2)/ 1.64289014d-03,-1.07044724d-05/
      data fpp(11,15,1),fpp(11,15,2)/ 6.03812287d-04,-4.39616106d-06/
      data fpp(11,16,1),fpp(11,16,2)/-1.11585128d-03, 1.10431660d-06/
      data fpp(11,17,1),fpp(11,17,2)/-2.33972177d-03, 4.28869466d-06/
      data fpp(11,18,1),fpp(11,18,2)/-2.62776534d-03, 3.89290476d-06/
      data fpp(11,19,1),fpp(11,19,2)/-2.10118803d-03, 1.36708629d-06/
      data fpp(11,20,1),fpp(11,20,2)/-1.25720594d-03,-6.51049934d-07/
      data fpp(11,21,1),fpp(11,21,2)/-5.49648378d-04,-1.16948656d-06/
      data fpp(11,22,1),fpp(11,22,2)/-1.45641555d-04,-8.22803841d-07/
      data fpp(11,23,1),fpp(11,23,2)/ 0.00000000d+00,-7.23298079d-07/
      data fpp(12, 1,1),fpp(12, 1,2)/ 0.00000000d+00, 5.15970703d-04/
      data fpp(12, 2,1),fpp(12, 2,2)/ 9.64836425d-03, 2.23735795d-04/
      data fpp(12, 3,1),fpp(12, 3,2)/ 5.65970210d-02,-2.98028124d-06/
      data fpp(12, 4,1),fpp(12, 4,2)/ 1.16350728d-01,-4.59012270d-04/
      data fpp(12, 5,1),fpp(12, 5,2)/ 3.05299779d-01,-5.16601840d-04/
      data fpp(12, 6,1),fpp(12, 6,2)/ 1.86277935d-01, 1.22812297d-05/
      data fpp(12, 7,1),fpp(12, 7,2)/ 6.99513247d-02, 3.30381721d-04/
      data fpp(12, 8,1),fpp(12, 8,2)/ 2.17402189d-02, 2.06312686d-04/
      data fpp(12, 9,1),fpp(12, 9,2)/ 5.66586972d-03, 9.16259351d-05/
      data fpp(12,10,1),fpp(12,10,2)/-3.57593536d-03, 4.98245177d-06/
      data fpp(12,11,1),fpp(12,11,2)/-4.33578622d-03,-1.71325421d-05/
      data fpp(12,12,1),fpp(12,12,2)/-1.64227879d-03,-2.00322832d-05/
      data fpp(12,13,1),fpp(12,13,2)/ 6.93514338d-04,-1.37485251d-05/
      data fpp(12,14,1),fpp(12,14,2)/ 1.33306777d-03,-8.16121631d-06/
      data fpp(12,15,1),fpp(12,15,2)/ 5.15746366d-04,-3.43060963d-06/
      data fpp(12,16,1),fpp(12,16,2)/-7.36723296d-04, 6.98854837d-07/
      data fpp(12,17,1),fpp(12,17,2)/-1.70598487d-03, 3.09339028d-06/
      data fpp(12,18,1),fpp(12,18,2)/-1.95532433d-03, 2.84978402d-06/
      data fpp(12,19,1),fpp(12,19,2)/-1.56516621d-03, 1.02527362d-06/
      data fpp(12,20,1),fpp(12,20,2)/-9.34065704d-04,-4.40278495d-07/
      data fpp(12,21,1),fpp(12,21,2)/-4.14925577d-04,-8.40959636d-07/
      data fpp(12,22,1),fpp(12,22,2)/-1.01886005d-04,-5.73482961d-07/
      data fpp(12,23,1),fpp(12,23,2)/ 0.00000000d+00,-4.96908519d-07/
      data fpp(13, 1,1),fpp(13, 1,2)/ 0.00000000d+00, 5.53111915d-04/
      data fpp(13, 2,1),fpp(13, 2,2)/-1.12134815d-02, 1.90379369d-04/
      data fpp(13, 3,1),fpp(13, 3,2)/-6.40324751d-02,-3.92366993d-04/
      data fpp(13, 4,1),fpp(13, 4,2)/ 4.36144026d-02,-2.05064997d-04/
      data fpp(13, 5,1),fpp(13, 5,2)/ 8.83153926d-02,-2.40834204d-05/
      data fpp(13, 6,1),fpp(13, 6,2)/ 7.24082038d-02, 2.89770783d-05/
      data fpp(13, 7,1),fpp(13, 7,2)/ 3.28774485d-02, 1.49658307d-04/
      data fpp(13, 8,1),fpp(13, 8,2)/ 9.39728346d-03, 1.07754492d-04/
      data fpp(13, 9,1),fpp(13, 9,2)/-4.62778393d-04, 5.24293241d-05/
      data fpp(13,10,1),fpp(13,10,2)/-5.51175623d-03,-1.31761840d-06/
      data fpp(13,11,1),fpp(13,11,2)/-4.27727212d-03,-1.55322505d-05/
      data fpp(13,12,1),fpp(13,12,2)/-1.49100864d-03,-1.45011796d-05/
      data fpp(13,13,1),fpp(13,13,2)/ 4.08311567d-04,-9.43463111d-06/
      data fpp(13,14,1),fpp(13,14,2)/ 9.26847354d-04,-5.47309595d-06/
      data fpp(13,15,1),fpp(13,15,2)/ 5.44970589d-04,-2.28918507d-06/
      data fpp(13,16,1),fpp(13,16,2)/-2.69354827d-04, 3.42036229d-07/
      data fpp(13,17,1),fpp(13,17,2)/-9.19569259d-04, 1.89664015d-06/
      data fpp(13,18,1),fpp(13,18,2)/-1.10640866d-03, 1.78720316d-06/
      data fpp(13,19,1),fpp(13,19,2)/-8.91987277d-04, 6.76347221d-07/
      data fpp(13,20,1),fpp(13,20,2)/-5.35643692d-04,-2.40392038d-07/
      data fpp(13,21,1),fpp(13,21,2)/-2.32149157d-04,-5.12179067d-07/
      data fpp(13,22,1),fpp(13,22,2)/-5.89522807d-05,-3.44891695d-07/
      data fpp(13,23,1),fpp(13,23,2)/ 0.00000000d+00,-3.03054152d-07/
      data fpp(14, 1,1),fpp(14, 1,2)/ 0.00000000d+00, 1.85946372d-04/
      data fpp(14, 2,1),fpp(14, 2,2)/ 6.56422854d-03, 4.38800570d-05/
      data fpp(14, 3,1),fpp(14, 3,2)/ 6.81988796d-02,-1.91460199d-04/
      data fpp(14, 4,1),fpp(14, 4,2)/ 5.81669953d-02,-1.00341659d-04/
      data fpp(14, 5,1),fpp(14, 5,2)/ 4.17533170d-02, 1.07452365d-05/
      data fpp(14, 6,1),fpp(14, 6,2)/ 2.65965833d-02, 4.87279131d-05/
      data fpp(14, 7,1),fpp(14, 7,2)/ 1.02828815d-02, 7.97631111d-05/
      data fpp(14, 8,1),fpp(14, 8,2)/-1.16686090d-04, 6.04636426d-05/
      data fpp(14, 9,1),fpp(14, 9,2)/-4.65408948d-03, 3.02607184d-05/
      data fpp(14,10,1),fpp(14,10,2)/-5.96570637d-03,-3.91617666d-06/
      data fpp(14,11,1),fpp(14,11,2)/-3.73312532d-03,-1.23220118d-05/
      data fpp(14,12,1),fpp(14,12,2)/-1.21501998d-03,-1.01599761d-05/
      data fpp(14,13,1),fpp(14,13,2)/ 2.24572728d-04,-6.45668387d-06/
      data fpp(14,14,1),fpp(14,14,2)/ 6.66876151d-04,-3.64628844d-06/
      data fpp(14,15,1),fpp(14,15,2)/ 4.38371277d-04,-1.52296236d-06/
      data fpp(14,16,1),fpp(14,16,2)/-2.98573946d-05, 1.83137870d-07/
      data fpp(14,17,1),fpp(14,17,2)/-4.35738097d-04, 1.18521088d-06/
      data fpp(14,18,1),fpp(14,18,2)/-5.83041031d-04, 1.13421863d-06/
      data fpp(14,19,1),fpp(14,19,2)/-4.78218012d-04, 4.50714622d-07/
      data fpp(14,20,1),fpp(14,20,2)/-2.70026196d-04,-1.22477115d-07/
      data fpp(14,21,1),fpp(14,21,2)/-1.11144461d-04,-3.14206161d-07/
      data fpp(14,22,1),fpp(14,22,2)/-1.76382055d-05,-2.24498240d-07/
      data fpp(14,23,1),fpp(14,23,2)/ 0.00000000d+00,-2.15200880d-07/
      data fpp(15, 1,1),fpp(15, 1,2)/ 0.00000000d+00, 8.37195520d-05/
      data fpp(15, 2,1),fpp(15, 2,2)/ 6.18857959d-03, 9.90249603d-06/
      data fpp(15, 3,1),fpp(15, 3,2)/ 1.39213150d-02,-1.11646336d-04/
      data fpp(15, 4,1),fpp(15, 4,2)/ 2.15284199d-02,-6.61339517d-05/
      data fpp(15, 5,1),fpp(15, 5,2)/ 1.86253264d-02, 1.15789427d-05/
      data fpp(15, 6,1),fpp(15, 6,2)/ 1.12262778d-02, 4.44469808d-05/
      data fpp(15, 7,1),fpp(15, 7,2)/ 2.20941981d-03, 5.68035341d-05/
      data fpp(15, 8,1),fpp(15, 8,2)/-3.59749474d-03, 4.28060830d-05/
      data fpp(15, 9,1),fpp(15, 9,2)/-5.94988500d-03, 2.14785340d-05/
      data fpp(15,10,1),fpp(15,10,2)/-5.67483379d-03,-4.25304353d-06/
      data fpp(15,11,1),fpp(15,11,2)/-3.19546523d-03,-1.00205599d-05/
      data fpp(15,12,1),fpp(15,12,2)/-1.05888716d-03,-7.94151691d-06/
      data fpp(15,13,1),fpp(15,13,2)/ 1.28169012d-04,-4.99897246d-06/
      data fpp(15,14,1),fpp(15,14,2)/ 5.19348212d-04,-2.78379324d-06/
      data fpp(15,15,1),fpp(15,15,2)/ 4.08187733d-04,-1.14585457d-06/
      data fpp(15,16,1),fpp(15,16,2)/ 5.08192141d-05, 1.30011524d-07/
      data fpp(15,17,1),fpp(15,17,2)/-2.51955625d-04, 8.78408475d-07/
      data fpp(15,18,1),fpp(15,18,2)/-3.63181859d-04, 8.47954576d-07/
      data fpp(15,19,1),fpp(15,19,2)/-2.99429022d-04, 3.51573221d-07/
      data fpp(15,20,1),fpp(15,20,2)/-1.69903483d-04,-7.98474614d-08/
      data fpp(15,21,1),fpp(15,21,2)/-5.10539616d-05,-2.24183376d-07/
      data fpp(15,22,1),fpp(15,22,2)/-1.38805515d-05,-1.82019035d-07/
      data fpp(15,23,1),fpp(15,23,2)/ 0.00000000d+00,-1.93140482d-07/
      data fpp(16, 1,1),fpp(16, 1,2)/ 0.00000000d+00, 3.68493051d-05/
      data fpp(16, 2,1),fpp(16, 2,2)/ 4.20295310d-03,-2.55061011d-06/
      data fpp(16, 3,1),fpp(16, 3,2)/ 1.34558606d-02,-6.72116646d-05/
      data fpp(16, 4,1),fpp(16, 4,2)/ 1.26748253d-02,-4.34587315d-05/
      data fpp(16, 5,1),fpp(16, 5,2)/ 7.53737760d-03, 9.47539050d-06/
      data fpp(16, 6,1),fpp(16, 6,2)/ 2.06580542d-03, 3.61499695d-05/
      data fpp(16, 7,1),fpp(16, 7,2)/-2.77056076d-03, 4.16567316d-05/
      data fpp(16, 8,1),fpp(16, 8,2)/-5.59333497d-03, 3.11415042d-05/
      data fpp(16, 9,1),fpp(16, 9,2)/-6.44087052d-03, 1.55604517d-05/
      data fpp(16,10,1),fpp(16,10,2)/-5.13895847d-03,-3.90690721d-06/
      data fpp(16,11,1),fpp(16,11,2)/-2.76001375d-03,-7.93982287d-06/
      data fpp(16,12,1),fpp(16,12,2)/-8.95931398d-04,-6.16340132d-06/
      data fpp(16,13,1),fpp(16,13,2)/ 8.17512253d-05,-3.86437187d-06/
      data fpp(16,14,1),fpp(16,14,2)/ 3.99731001d-04,-2.12471121d-06/
      data fpp(16,15,1),fpp(16,15,2)/ 3.22877792d-04,-8.61983278d-07/
      data fpp(16,16,1),fpp(16,16,2)/ 1.02580538d-04, 1.06044326d-07/
      data fpp(16,17,1),fpp(16,17,2)/-1.19439401d-04, 6.59805973d-07/
      data fpp(16,18,1),fpp(16,18,2)/-2.11231534d-04, 6.41731782d-07/
      data fpp(16,19,1),fpp(16,19,2)/-1.75065900d-04, 2.76066898d-07/
      data fpp(16,20,1),fpp(16,20,2)/-9.13598712d-05,-4.61993748d-08/
      data fpp(16,21,1),fpp(16,21,2)/-3.71396931d-05,-1.70469399d-07/
      data fpp(16,22,1),fpp(16,22,2)/-3.33958866d-06,-1.50323029d-07/
      data fpp(16,23,1),fpp(16,23,2)/ 0.00000000d+00,-1.71438486d-07/
      data fpp(17, 1,1),fpp(17, 1,2)/ 0.00000000d+00, 8.23018998d-06/
      data fpp(17, 2,1),fpp(17, 2,2)/ 1.65176994d-03,-7.26197995d-06/
      data fpp(17, 3,1),fpp(17, 3,2)/ 3.51758799d-03,-3.30430702d-05/
      data fpp(17, 4,1),fpp(17, 4,2)/ 2.98796918d-03,-2.28129394d-05/
      data fpp(17, 5,1),fpp(17, 5,2)/-9.47623905d-06, 5.88602759d-06/
      data fpp(17, 6,1),fpp(17, 6,2)/-3.08353662d-03, 2.37320290d-05/
      data fpp(17, 7,1),fpp(17, 7,2)/-5.19374401d-03, 2.64698564d-05/
      data fpp(17, 8,1),fpp(17, 8,2)/-6.04922028d-03, 1.98677455d-05/
      data fpp(17, 9,1),fpp(17, 9,2)/-5.88784159d-03, 9.91196165d-06/
      data fpp(17,10,1),fpp(17,10,2)/-4.07291590d-03,-2.86335769d-06/
      data fpp(17,11,1),fpp(17,11,2)/-2.01564401d-03,-5.37293088d-06/
      data fpp(17,12,1),fpp(17,12,2)/-6.72303903d-04,-4.19651880d-06/
      data fpp(17,13,1),fpp(17,13,2)/ 1.23832412d-05,-2.62879391d-06/
      data fpp(17,14,1),fpp(17,14,2)/ 2.59331189d-04,-1.42110557d-06/
      data fpp(17,15,1),fpp(17,15,2)/ 2.53282203d-04,-5.43383820d-07/
      data fpp(17,16,1),fpp(17,16,2)/ 1.05852063d-04, 7.86408470d-08/
      data fpp(17,17,1),fpp(17,17,2)/-2.52315784d-05, 4.47220432d-07/
      data fpp(17,18,1),fpp(17,18,2)/-8.44403130d-05, 4.32877427d-07/
      data fpp(17,19,1),fpp(17,19,2)/-7.44943193d-05, 1.96669861d-07/
      data fpp(17,20,1),fpp(17,20,2)/-3.58647737d-05,-2.37568699d-08/
      data fpp(17,21,1),fpp(17,21,2)/-4.49838193d-06,-1.13042381d-07/
      data fpp(17,22,1),fpp(17,22,2)/-3.61433684d-06,-1.19873605d-07/
      data fpp(17,23,1),fpp(17,23,2)/ 0.00000000d+00,-1.50263197d-07/
      data fpp(18, 1,1),fpp(18, 1,2)/ 0.00000000d+00,-9.25560204d-07/
      data fpp(18, 2,1),fpp(18, 2,2)/ 6.15300479d-04,-6.76607959d-06/
      data fpp(18, 3,1),fpp(18, 3,2)/ 1.46912075d-03,-1.70461214d-05/
      data fpp(18, 4,1),fpp(18, 4,2)/ 5.21964683d-04,-1.17878347d-05/
      data fpp(18, 5,1),fpp(18, 5,2)/-1.61413931d-03, 3.45106021d-06/
      data fpp(18, 6,1),fpp(18, 6,2)/-3.61632560d-03, 1.44931939d-05/
      data fpp(18, 7,1),fpp(18, 7,2)/-4.78179652d-03, 1.65905643d-05/
      data fpp(18, 8,1),fpp(18, 8,2)/-5.04511723d-03, 1.27493488d-05/
      data fpp(18, 9,1),fpp(18, 9,2)/-4.63776312d-03, 6.50244048d-06/
      data fpp(18,10,1),fpp(18,10,2)/-2.96137792d-03,-1.76979584d-06/
      data fpp(18,11,1),fpp(18,11,2)/-1.44741020d-03,-3.54945712d-06/
      data fpp(18,12,1),fpp(18,12,2)/-4.93519659d-04,-2.84357567d-06/
      data fpp(18,13,1),fpp(18,13,2)/-1.72841903d-05,-1.79284018d-06/
      data fpp(18,14,1),fpp(18,14,2)/ 1.60277578d-04,-9.43463588d-07/
      data fpp(18,15,1),fpp(18,15,2)/ 1.57326727d-04,-3.49905463d-07/
      data fpp(18,16,1),fpp(18,16,2)/ 8.40112102d-05, 7.62854411d-08/
      data fpp(18,17,1),fpp(18,17,2)/ 4.36571491d-06, 3.11163699d-07/
      data fpp(18,18,1),fpp(18,18,2)/-4.03405469d-05, 3.00259764d-07/
      data fpp(18,19,1),fpp(18,19,2)/-4.02901563d-05, 1.40197246d-07/
      data fpp(18,20,1),fpp(18,20,2)/-2.71810338d-05,-1.14487462d-08/
      data fpp(18,21,1),fpp(18,21,2)/-8.86677917d-06,-8.60022606d-08/
      data fpp(18,22,1),fpp(18,22,2)/ 2.46360266d-06,-9.21422112d-08/
      data fpp(18,23,1),fpp(18,23,2)/ 0.00000000d+00,-1.17828894d-07/
      data fpp(19, 1,1),fpp(19, 1,2)/ 0.00000000d+00,-2.83704316d-06/
      data fpp(19, 2,1),fpp(19, 2,2)/ 3.03842696d-04,-5.71431368d-06/
      data fpp(19, 3,1),fpp(19, 3,2)/ 5.11014276d-04,-1.11913021d-05/
      data fpp(19, 4,1),fpp(19, 4,2)/-2.14777183d-04,-7.56927786d-06/
      data fpp(19, 5,1),fpp(19, 5,2)/-1.77208909d-03, 2.39881354d-06/
      data fpp(19, 6,1),fpp(19, 6,2)/-3.24606709d-03, 1.02020237d-05/
      data fpp(19, 7,1),fpp(19, 7,2)/-4.06590137d-03, 1.20146917d-05/
      data fpp(19, 8,1),fpp(19, 8,2)/-4.17358342d-03, 9.46240947d-06/
      data fpp(19, 9,1),fpp(19, 9,2)/-3.77842202d-03, 4.99487040d-06/
      data fpp(19,10,1),fpp(19,10,2)/-2.39223653d-03,-1.20941592d-06/
      data fpp(19,11,1),fpp(19,11,2)/-1.15448300d-03,-2.66340670d-06/
      data fpp(19,12,1),fpp(19,12,2)/-4.00945853d-04,-2.19675727d-06/
      data fpp(19,13,1),fpp(19,13,2)/-2.26539106d-05,-1.38596422d-06/
      data fpp(19,14,1),fpp(19,14,2)/ 1.23115326d-04,-7.21185845d-07/
      data fpp(19,15,1),fpp(19,15,2)/ 1.20443058d-04,-2.58092398d-07/
      data fpp(19,16,1),fpp(19,16,2)/ 7.11658548d-05, 7.53554377d-08/
      data fpp(19,17,1),fpp(19,17,2)/ 4.51879301d-06, 2.45270647d-07/
      data fpp(19,18,1),fpp(19,18,2)/-2.56367960d-05, 2.39561973d-07/
      data fpp(19,19,1),fpp(19,19,2)/-2.88077395d-05, 1.08681460d-07/
      data fpp(19,20,1),fpp(19,20,2)/-1.02976704d-05,-3.48781409d-09/
      data fpp(19,21,1),fpp(19,21,2)/-9.91853124d-06,-7.43302039d-08/
      data fpp(19,22,1),fpp(19,22,2)/-3.39650807d-06,-7.77913703d-08/
      data fpp(19,23,1),fpp(19,23,2)/ 0.00000000d+00,-1.00504315d-07/
      data fpp(20, 1,1),fpp(20, 1,2)/ 0.00000000d+00,-3.30204873d-06/
      data fpp(20, 2,1),fpp(20, 2,2)/ 1.22328736d-04,-4.60350254d-06/
      data fpp(20, 3,1),fpp(20, 3,2)/ 1.31822150d-04,-7.43674112d-06/
      data fpp(20, 4,1),fpp(20, 4,2)/-5.13355951d-04,-4.90873298d-06/
      data fpp(20, 5,1),fpp(20, 5,2)/-1.65950433d-03, 1.65327304d-06/
      data fpp(20, 6,1),fpp(20, 6,2)/-2.72990606d-03, 7.11084081d-06/
      data fpp(20, 7,1),fpp(20, 7,2)/-3.30559800d-03, 8.64896371d-06/
      data fpp(20, 8,1),fpp(20, 8,2)/-3.33604911d-03, 7.00850434d-06/
      data fpp(20, 9,1),fpp(20, 9,2)/-2.96604879d-03, 3.87701893d-06/
      data fpp(20,10,1),fpp(20,10,2)/-1.84417595d-03,-7.83908964d-07/
      data fpp(20,11,1),fpp(20,11,2)/-8.84157822d-04,-1.99478308d-06/
      data fpp(20,12,1),fpp(20,12,2)/-3.13196929d-04,-1.69975873d-06/
      data fpp(20,13,1),fpp(20,13,2)/-3.01001675d-05,-1.06898200d-06/
      data fpp(20,14,1),fpp(20,14,2)/ 6.27611163d-05,-5.57113275d-07/
      data fpp(20,15,1),fpp(20,15,2)/ 8.39010418d-05,-1.81964900d-07/
      data fpp(20,16,1),fpp(20,16,2)/ 3.93253707d-05, 6.63728771d-08/
      data fpp(20,17,1),fpp(20,17,2)/-1.44088697d-06, 1.98473392d-07/
      data fpp(20,18,1),fpp(20,18,2)/-2.66122693d-05, 1.89133554d-07/
      data fpp(20,19,1),fpp(20,19,2)/-2.74788857d-05, 8.77923901d-08/
      data fpp(20,20,1),fpp(20,20,2)/-2.01282847d-05,-5.10311487d-09/
      data fpp(20,21,1),fpp(20,21,2)/-5.45909587d-06,-5.89799306d-08/
      data fpp(20,22,1),fpp(20,22,2)/-2.37757040d-06,-6.61771627d-08/
      data fpp(20,23,1),fpp(20,23,2)/ 0.00000000d+00,-8.67114187d-08/
      data fpp(21, 1,1),fpp(21, 1,2)/ 0.00000000d+00,-2.87714984d-06/
      data fpp(21, 2,1),fpp(21, 2,2)/ 4.34241538d-06,-3.15250032d-06/
      data fpp(21, 3,1),fpp(21, 3,2)/-1.26083350d-04,-4.13764888d-06/
      data fpp(21, 4,1),fpp(21, 4,2)/-5.81962041d-04,-2.63850416d-06/
      data fpp(21, 5,1),fpp(21, 5,2)/-1.27425951d-03, 8.91665536d-07/
      data fpp(21, 6,1),fpp(21, 6,2)/-1.90060175d-03, 4.11424202d-06/
      data fpp(21, 7,1),fpp(21, 7,2)/-2.22840577d-03, 5.26416639d-06/
      data fpp(21, 8,1),fpp(21, 8,2)/-2.21578071d-03, 4.50989243d-06/
      data fpp(21, 9,1),fpp(21, 9,2)/-1.97122267d-03, 2.65466388d-06/
      data fpp(21,10,1),fpp(21,10,2)/-1.21392249d-03,-3.55537846d-07/
      data fpp(21,11,1),fpp(21,11,2)/-5.96818596d-04,-1.30751249d-06/
      data fpp(21,12,1),fpp(21,12,2)/-2.19046333d-04,-1.15481218d-06/
      data fpp(21,13,1),fpp(21,13,2)/-2.95635013d-05,-7.33838790d-07/
      data fpp(21,14,1),fpp(21,14,2)/ 5.00527280d-05,-3.58232662d-07/
      data fpp(21,15,1),fpp(21,15,2)/ 4.53678222d-05,-1.18630561d-07/
      data fpp(21,16,1),fpp(21,16,2)/ 2.14715278d-05, 6.11549073d-08/
      data fpp(21,17,1),fpp(21,17,2)/-8.54290545d-06, 1.41610932d-07/
      data fpp(21,18,1),fpp(21,18,2)/-2.32012385d-05, 1.34401364d-07/
      data fpp(21,19,1),fpp(21,19,2)/-2.31985546d-05, 6.17836125d-08/
      data fpp(21,20,1),fpp(21,20,2)/-1.43739373d-05,-4.13581365d-09/
      data fpp(21,21,1),fpp(21,21,2)/-6.52399294d-06,-4.46403579d-08/
      data fpp(21,22,1),fpp(21,22,2)/ 1.89573380d-07,-4.95027549d-08/
      data fpp(21,23,1),fpp(21,23,2)/ 0.00000000d+00,-6.45486226d-08/
      data fpp(22, 1,1),fpp(22, 1,2)/ 0.00000000d+00,-1.63387916d-06/
      data fpp(22, 2,1),fpp(22, 2,2)/-3.34529709d-05,-1.55984168d-06/
      data fpp(22, 3,1),fpp(22, 3,2)/-1.53226570d-04,-1.72435411d-06/
      data fpp(22, 4,1),fpp(22, 4,2)/-3.75307898d-04,-1.05394187d-06/
      data fpp(22, 5,1),fpp(22, 5,2)/-6.63546983d-04, 2.71321594d-07/
      data fpp(22, 6,1),fpp(22, 6,2)/-9.11650771d-04, 1.68945549d-06/
      data fpp(22, 7,1),fpp(22, 7,2)/-1.04238275d-03, 2.39085643d-06/
      data fpp(22, 8,1),fpp(22, 8,2)/-1.04251228d-03, 2.17511878d-06/
      data fpp(22, 9,1),fpp(22, 9,2)/-9.32378174d-04, 1.45826845d-06/
      data fpp(22,10,1),fpp(22,10,2)/-6.02622453d-04,-8.69647369d-08/
      data fpp(22,11,1),fpp(22,11,2)/-3.00565800d-04,-6.55009501d-07/
      data fpp(22,12,1),fpp(22,12,2)/-1.13293576d-04,-6.14597258d-07/
      data fpp(22,13,1),fpp(22,13,2)/-1.74166952d-05,-3.76801468d-07/
      data fpp(22,14,1),fpp(22,14,2)/ 1.28146007d-05,-1.80996868d-07/
      data fpp(22,15,1),fpp(22,15,2)/ 1.51223438d-05,-4.64110575d-08/
      data fpp(22,16,1),fpp(22,16,2)/-8.64111354d-07, 4.20410986d-08/
      data fpp(22,17,1),fpp(22,17,2)/-1.51581704d-05, 8.28466632d-08/
      data fpp(22,18,1),fpp(22,18,2)/-2.21086753d-05, 7.41722486d-08/
      data fpp(22,19,1),fpp(22,19,2)/-2.01572938d-05, 3.44643422d-08/
      data fpp(22,20,1),fpp(22,20,2)/-1.38464298d-05,-3.82961750d-09/
      data fpp(22,21,1),fpp(22,21,2)/-6.72776507d-06,-2.63458722d-08/
      data fpp(22,22,1),fpp(22,22,2)/-2.54009258d-06,-3.17868937d-08/
      data fpp(22,23,1),fpp(22,23,2)/ 0.00000000d+00,-4.21065532d-08/
      data fpp(23, 1,1),fpp(23, 1,2)/ 0.00000000d+00,-8.57640067d-07/
      data fpp(23, 2,1),fpp(23, 2,2)/-1.90905318d-05,-7.81519866d-07/
      data fpp(23, 3,1),fpp(23, 3,2)/-7.77303703d-05,-7.82680467d-07/
      data fpp(23, 4,1),fpp(23, 4,2)/-1.76166369d-04,-5.13358264d-07/
      data fpp(23, 5,1),fpp(23, 5,2)/-2.91472563d-04, 1.19313523d-07/
      data fpp(23, 6,1),fpp(23, 6,2)/-3.99995167d-04, 7.68104172d-07/
      data fpp(23, 7,1),fpp(23, 7,2)/-4.67023221d-04, 1.13066979d-06/
      data fpp(23, 8,1),fpp(23, 8,2)/-4.75050182d-04, 1.10281667d-06/
      data fpp(23, 9,1),fpp(23, 9,2)/-4.39184632d-04, 7.67663548d-07/
      data fpp(23,10,1),fpp(23,10,2)/-2.93587695d-04,-1.69989762d-08/
      data fpp(23,11,1),fpp(23,11,2)/-1.53078203d-04,-3.54067643d-07/
      data fpp(23,12,1),fpp(23,12,2)/-5.44993643d-05,-3.20530451d-07/
      data fpp(23,13,1),fpp(23,13,2)/-4.92971784d-06,-1.90810552d-07/
      data fpp(23,14,1),fpp(23,14,2)/ 1.19688692d-05,-8.62273421d-08/
      data fpp(23,15,1),fpp(23,15,2)/ 7.66280260d-06,-1.62800801d-08/
      data fpp(23,16,1),fpp(23,16,2)/-2.41508238d-06, 2.83476624d-08/
      data fpp(23,17,1),fpp(23,17,2)/-1.19444131d-05, 4.74894304d-08/
      data fpp(23,18,1),fpp(23,18,2)/-1.60440603d-05, 4.02946160d-08/
      data fpp(23,19,1),fpp(23,19,2)/-1.42522703d-05, 1.87321057d-08/
      data fpp(23,20,1),fpp(23,20,2)/-9.44034358d-06,-3.02303863d-09/
      data fpp(23,21,1),fpp(23,21,2)/-4.48494678d-06,-1.56399511d-08/
      data fpp(23,22,1),fpp(23,22,2)/-1.06920308d-06,-2.02171568d-08/
      data fpp(23,23,1),fpp(23,23,2)/ 0.00000000d+00,-2.70914216d-08/
      data fpp(24, 1,1),fpp(24, 1,2)/ 0.00000000d+00,-4.86413303d-07/
      data fpp(24, 2,1),fpp(24, 2,2)/-6.82490202d-06,-4.16373394d-07/
      data fpp(24, 3,1),fpp(24, 3,2)/-2.83319489d-05,-3.75293122d-07/
      data fpp(24, 4,1),fpp(24, 4,2)/-6.93866283d-05,-2.32854117d-07/
      data fpp(24, 5,1),fpp(24, 5,2)/-1.23682764d-04, 7.31095901d-08/
      data fpp(24, 6,1),fpp(24, 6,2)/-1.74448562d-04, 3.91615756d-07/
      data fpp(24, 7,1),fpp(24, 7,2)/-2.09764363d-04, 5.73227384d-07/
      data fpp(24, 8,1),fpp(24, 8,2)/-2.23846996d-04, 5.53074707d-07/
      data fpp(24, 9,1),fpp(24, 9,2)/-2.13443300d-04, 3.87273789d-07/
      data fpp(24,10,1),fpp(24,10,2)/-1.47826768d-04,-1.45587209d-08/
      data fpp(24,11,1),fpp(24,11,2)/-7.40013886d-05,-1.92838906d-07/
      data fpp(24,12,1),fpp(24,12,2)/-2.34289671d-05,-1.64485657d-07/
      data fpp(24,13,1),fpp(24,13,2)/ 2.33556658d-06,-9.36184680d-08/
      data fpp(24,14,1),fpp(24,14,2)/ 7.70992244d-06,-4.00404716d-08/
      data fpp(24,15,1),fpp(24,15,2)/ 5.58644580d-06,-3.61964581d-09/
      data fpp(24,16,1),fpp(24,16,2)/-9.95559143d-07, 1.85190548d-08/
      data fpp(24,17,1),fpp(24,17,2)/-6.18417731d-06, 2.73434266d-08/
      data fpp(24,18,1),fpp(24,18,2)/-8.03508350d-06, 2.27072388d-08/
      data fpp(24,19,1),fpp(24,19,2)/-7.31362511d-06, 1.02276183d-08/
      data fpp(24,20,1),fpp(24,20,2)/-4.79219591d-06,-1.81771213d-09/
      data fpp(24,21,1),fpp(24,21,2)/-2.21244782d-06,-1.01567698d-08/
      data fpp(24,22,1),fpp(24,22,2)/-6.23095118d-07,-1.33552086d-08/
      data fpp(24,23,1),fpp(24,23,2)/ 0.00000000d+00,-1.80223957d-08/
      data fpp(25, 1,1),fpp(25, 1,2)/ 0.00000000d+00,-2.71533507d-07/
      data fpp(25, 2,1),fpp(25, 2,2)/-3.52986016d-06,-2.23732986d-07/
      data fpp(25, 3,1),fpp(25, 3,2)/-1.65418341d-05,-1.99134549d-07/
      data fpp(25, 4,1),fpp(25, 4,2)/-3.54071181d-05,-9.33288162d-08/
      data fpp(25, 5,1),fpp(25, 5,2)/-6.05163790d-05, 6.12498142d-08/
      data fpp(25, 6,1),fpp(25, 6,2)/-8.70905836d-05, 2.13129559d-07/
      data fpp(25, 7,1),fpp(25, 7,2)/-1.06799325d-04, 2.91031948d-07/
      data fpp(25, 8,1),fpp(25, 8,2)/-1.13481836d-04, 2.73942647d-07/
      data fpp(25, 9,1),fpp(25, 9,2)/-1.07682170d-04, 1.92397465d-07/
      data fpp(25,10,1),fpp(25,10,2)/-7.53452332d-05,-1.93637174d-08/
      data fpp(25,11,1),fpp(25,11,2)/-3.66762430d-05,-1.02942595d-07/
      data fpp(25,12,1),fpp(25,12,2)/-8.74476724d-06,-8.00659029d-08/
      data fpp(25,13,1),fpp(25,13,2)/ 3.26745152d-06,-4.89937936d-08/
      data fpp(25,14,1),fpp(25,14,2)/ 8.07144101d-06,-1.55589226d-08/
      data fpp(25,15,1),fpp(25,15,2)/ 4.31141420d-06,-9.70515954d-10/
      data fpp(25,16,1),fpp(25,16,2)/ 1.11731895d-06, 1.28409864d-08/
      data fpp(25,17,1),fpp(25,17,2)/-1.71887767d-06, 1.68065703d-08/
      data fpp(25,18,1),fpp(25,18,2)/-3.17560570d-06, 1.29327325d-08/
      data fpp(25,19,1),fpp(25,19,2)/-2.57322928d-06, 6.46249986d-09/
      data fpp(25,20,1),fpp(25,20,2)/-1.63087280d-06,-9.82731922d-10/
      data fpp(25,21,1),fpp(25,21,2)/-8.25261951d-07,-7.33157217d-09/
      data fpp(25,22,1),fpp(25,22,2)/-3.84164519d-08,-9.29097938d-09/
      data fpp(25,23,1),fpp(25,23,2)/ 0.00000000d+00,-1.25045103d-08/
      data fpp(26, 1,1),fpp(26, 1,2)/ 0.00000000d+00,-1.63201625d-07/
      data fpp(26, 2,1),fpp(26, 2,2)/-1.85565734d-06,-1.25596749d-07/
      data fpp(26, 3,1),fpp(26, 3,2)/-7.02071477d-06,-9.76113777d-08/
      data fpp(26, 4,1),fpp(26, 4,2)/-1.67448993d-05,-3.59577398d-08/
      data fpp(26, 5,1),fpp(26, 5,2)/-2.90517197d-05, 4.46423371d-08/
      data fpp(26, 6,1),fpp(26, 6,2)/-4.09491030d-05, 1.16588392d-07/
      data fpp(26, 7,1),fpp(26, 7,2)/-4.94383348d-05, 1.49004097d-07/
      data fpp(26, 8,1),fpp(26, 8,2)/-5.27856619d-05, 1.36995221d-07/
      data fpp(26, 9,1),fpp(26, 9,2)/-5.06280214d-05, 8.78150194d-08/
      data fpp(26,10,1),fpp(26,10,2)/-3.36722991d-05,-1.51426686d-08/
      data fpp(26,11,1),fpp(26,11,2)/-1.44936394d-05,-5.00443449d-08/
      data fpp(26,12,1),fpp(26,12,2)/-3.03196393d-06,-4.14799516d-08/
      data fpp(26,13,1),fpp(26,13,2)/ 1.87462735d-06,-2.16358486d-08/
      data fpp(26,14,1),fpp(26,14,2)/ 1.28431350d-06,-1.29766539d-08/
      data fpp(26,15,1),fpp(26,15,2)/ 1.64789738d-06, 4.54246428d-09/
      data fpp(26,16,1),fpp(26,16,2)/ 1.26283352d-07, 7.40679678d-09/
      data fpp(26,17,1),fpp(26,17,2)/-8.60312008d-07, 1.08303486d-08/
      data fpp(26,18,1),fpp(26,18,2)/-1.10249369d-06, 8.67180889d-09/
      data fpp(26,19,1),fpp(26,19,2)/-1.11345776d-06, 3.68241585d-09/
      data fpp(26,20,1),fpp(26,20,2)/-6.84312906d-07,-6.01472289d-10/
      data fpp(26,21,1),fpp(26,21,2)/-2.46504377d-07,-4.87652669d-09/
      data fpp(26,22,1),fpp(26,22,2)/-1.83239075d-07,-6.89242095d-09/
      data fpp(26,23,1),fpp(26,23,2)/ 0.00000000d+00,-9.55378953d-09/
      data fpp(27, 1,1),fpp(27, 1,2)/ 0.00000000d+00,-4.98409766d-08/
      data fpp(27, 2,1),fpp(27, 2,2)/-8.88097903d-07,-3.63180468d-08/
      data fpp(27, 3,1),fpp(27, 3,2)/-3.66693864d-06,-2.56868362d-08/
      data fpp(27, 4,1),fpp(27, 4,2)/-7.72174306d-06,-4.93460846d-09/
      data fpp(27, 5,1),fpp(27, 5,2)/-1.24866515d-05, 1.42252700d-08/
      data fpp(27, 6,1),fpp(27, 6,2)/-1.68473991d-05, 3.20335284d-08/
      data fpp(27, 7,1),fpp(27, 7,2)/-1.96253329d-05, 3.76406165d-08/
      data fpp(27, 8,1),fpp(27, 8,2)/-2.01020966d-05, 3.34040055d-08/
      data fpp(27, 9,1),fpp(27, 9,2)/-1.84348510d-05, 2.07433616d-08/
      data fpp(27,10,1),fpp(27,10,2)/-1.17304860d-05,-1.53208744d-09/
      data fpp(27,11,1),fpp(27,11,2)/-5.32096016d-06,-1.16150118d-08/
      data fpp(27,12,1),fpp(27,12,2)/-1.59172459d-06,-1.20078653d-08/
      data fpp(27,13,1),fpp(27,13,2)/-2.97607815d-07,-9.35352697d-09/
      data fpp(27,14,1),fpp(27,14,2)/ 1.51339001d-07, 2.21973180d-10/
      data fpp(27,15,1),fpp(27,15,2)/-6.79399252d-07,-1.13436575d-09/
      data fpp(27,16,1),fpp(27,16,2)/-1.23750953d-06, 4.31548983d-09/
      data fpp(27,17,1),fpp(27,17,2)/-1.59962514d-06, 4.27240643d-09/
      data fpp(27,18,1),fpp(27,18,2)/-1.64471609d-06, 3.19488443d-09/
      data fpp(27,19,1),fpp(27,19,2)/-1.31301207d-06, 1.54805583d-09/
      data fpp(27,20,1),fpp(27,20,2)/-8.51624884d-07,-3.87107748d-10/
      data fpp(27,21,1),fpp(27,21,2)/-4.67855892d-07,-2.39962484d-09/
      data fpp(27,22,1),fpp(27,22,2)/-3.10745501d-08,-2.61439290d-09/
      data fpp(27,23,1),fpp(27,23,2)/ 0.00000000d+00,-3.34280355d-09/
      data fpp(28, 1,1),fpp(28, 1,2)/ 0.00000000d+00,-1.88208021d-08/
      data fpp(28, 2,1),fpp(28, 2,2)/ 3.68048952d-07,-1.31583959d-08/
      data fpp(28, 3,1),fpp(28, 3,2)/ 1.58846932d-06,-7.74561451d-09/
      data fpp(28, 4,1),fpp(28, 4,2)/ 4.73187153d-06,-1.45914612d-09/
      data fpp(28, 5,1),fpp(28, 5,2)/ 9.69832576d-06, 3.98219899d-09/
      data fpp(28, 6,1),fpp(28, 6,2)/ 1.55186996d-05, 9.53035015d-09/
      data fpp(28, 7,1),fpp(28, 7,2)/ 2.04796665d-05, 1.30964004d-08/
      data fpp(28, 8,1),fpp(28, 8,2)/ 2.33340483d-05, 1.00840482d-08/
      data fpp(28, 9,1),fpp(28, 9,2)/ 2.36874255d-05, 8.96740686d-09/
      data fpp(28,10,1),fpp(28,10,2)/ 1.76542430d-05,-1.44244661d-10/
      data fpp(28,11,1),fpp(28,11,2)/ 8.11748008d-06,-4.19042821d-09/
      data fpp(28,12,1),fpp(28,12,2)/ 1.05886230d-06,-5.89404248d-09/
      data fpp(28,13,1),fpp(28,13,2)/-2.54419609d-06,-1.03340185d-09/
      data fpp(28,14,1),fpp(28,14,2)/-2.48966950d-06, 4.27649897d-10/
      data fpp(28,15,1),fpp(28,15,2)/-3.37030037d-06,-1.87719773d-09/
      data fpp(28,16,1),fpp(28,16,2)/-2.67624524d-06, 2.28114104d-09/
      data fpp(28,17,1),fpp(28,17,2)/-2.04118743d-06, 1.15263357d-09/
      data fpp(28,18,1),fpp(28,18,2)/-1.61864196d-06, 9.08324684d-10/
      data fpp(28,19,1),fpp(28,19,2)/-1.13449397d-06, 1.21406770d-09/
      data fpp(28,20,1),fpp(28,20,2)/-7.69187558d-07,-2.16459546d-09/
      data fpp(28,21,1),fpp(28,21,2)/-5.22072054d-07, 2.04431416d-09/
      data fpp(28,22,1),fpp(28,22,2)/ 6.75372750d-08,-2.41266119d-09/
      data fpp(28,23,1),fpp(28,23,2)/ 0.00000000d+00,-4.39366941d-09/
 
      data fpppp( 1, 1),fpppp( 1, 2)/ 1.25182047d-03, 1.07100698d-02/
      data fpppp( 1, 3),fpppp( 1, 4)/-2.19600739d-02, 9.28191582d-02/
      data fpppp( 1, 5),fpppp( 1, 6)/-1.43617776d-01, 3.29258053d-02/
      data fpppp( 1, 7),fpppp( 1, 8)/ 5.70674706d-02,-4.41170143d-02/
      data fpppp( 1, 9),fpppp( 1,10)/ 1.82464230d-02,-7.10908988d-03/
      data fpppp( 1,11),fpppp( 1,12)/ 2.10549988d-03,-6.42090628d-04/
      data fpppp( 1,13),fpppp( 1,14)/ 5.52259169d-04,-1.49976768d-04/
      data fpppp( 1,15),fpppp( 1,16)/ 4.44486027d-04,-1.14654522d-04/
      data fpppp( 1,17),fpppp( 1,18)/-7.15782346d-04,-1.97957717d-04/
      data fpppp( 1,19),fpppp( 1,20)/ 3.39222986d-04, 1.74277736d-04/
      data fpppp( 1,21),fpppp( 1,22)/ 3.77804612d-05, 1.09609841d-05/
      data fpppp( 1,23) /            -4.71950065d-05 /
      data fpppp( 2, 1),fpppp( 2, 2)/-5.96818845d-03, 3.68499537d-03/
      data fpppp( 2, 3),fpppp( 2, 4)/ 6.86791513d-03, 3.26967591d-02/
      data fpppp( 2, 5),fpppp( 2, 6)/-7.91533965d-02, 1.17754308d-02/
      data fpppp( 2, 7),fpppp( 2, 8)/ 4.12625621d-02,-2.46810260d-02/
      data fpppp( 2, 9),fpppp( 2,10)/ 9.78946880d-03,-4.01509738d-03/
      data fpppp( 2,11),fpppp( 2,12)/ 1.29783401d-03,-4.60896681d-04/
      data fpppp( 2,13),fpppp( 2,14)/ 3.87539638d-04,-1.25740432d-04/
      data fpppp( 2,15),fpppp( 2,16)/ 3.37125845d-04,-8.24485803d-05/
      data fpppp( 2,17),fpppp( 2,18)/-5.54442713d-04,-1.41417326d-04/
      data fpppp( 2,19),fpppp( 2,20)/ 2.53012474d-04, 1.39623502d-04/
      data fpppp( 2,21),fpppp( 2,22)/ 2.72447387d-05, 8.37641425d-06/
      data fpppp( 2,23) /            -3.72091784d-05 /
      data fpppp( 3, 1),fpppp( 3, 2)/-2.16551597d-02, 1.69117467d-03/
      data fpppp( 3, 3),fpppp( 3, 4)/ 2.37866425d-02, 5.02601431d-02/
      data fpppp( 3, 5),fpppp( 3, 6)/-1.70996697d-01, 1.20477093d-01/
      data fpppp( 3, 7),fpppp( 3, 8)/-3.81569443d-02, 2.52298781d-02/
      data fpppp( 3, 9),fpppp( 3,10)/-1.22569122d-02, 8.39714150d-03/
      data fpppp( 3,11),fpppp( 3,12)/-3.82871029d-03, 6.22512771d-04/
      data fpppp( 3,13),fpppp( 3,14)/-3.77650208d-05,-3.90277247d-05/
      data fpppp( 3,15),fpppp( 3,16)/ 2.01542779d-04,-3.37536760d-05/
      data fpppp( 3,17),fpppp( 3,18)/-4.07248913d-04,-4.62420208d-05/
      data fpppp( 3,19),fpppp( 3,20)/ 1.42205396d-04, 1.05824182d-04/
      data fpppp( 3,21),fpppp( 3,22)/ 1.33386043d-05, 6.90535311d-06/
      data fpppp( 3,23) /            -2.41142772d-05 /
      data fpppp( 4, 1),fpppp( 4, 2)/-7.70776283d-03,-1.79120342d-02/
      data fpppp( 4, 3),fpppp( 4, 4)/ 8.23877857d-02,-2.04076714d-01/
      data fpppp( 4, 5),fpppp( 4, 6)/ 2.84236884d-01,-2.25303373d-01/
      data fpppp( 4, 7),fpppp( 4, 8)/ 1.05074642d-01,-3.15214233d-02/
      data fpppp( 4, 9),fpppp( 4,10)/ 1.32597006d-02,-1.18044820d-02/
      data fpppp( 4,11),fpppp( 4,12)/ 6.16081989d-03,-1.45183205d-03/
      data fpppp( 4,13),fpppp( 4,14)/ 4.48978267d-04,-1.70982317d-04/
      data fpppp( 4,15),fpppp( 4,16)/ 1.64739808d-04,-4.27701420d-05/
      data fpppp( 4,17),fpppp( 4,18)/-2.10544697d-04,-8.62889146d-05/
      data fpppp( 4,19),fpppp( 4,20)/ 1.17486300d-04, 6.90326624d-05/
      data fpppp( 4,21),fpppp( 4,22)/ 1.12289111d-05, 1.53701130d-06/
      data fpppp( 4,23) /            -2.19011318d-05 /
      data fpppp( 5, 1),fpppp( 5, 2)/-9.28425104d-03,-2.65348338d-02/
      data fpppp( 5, 3),fpppp( 5, 4)/ 8.69363408d-02,-2.57118635d-01/
      data fpppp( 5, 5),fpppp( 5, 6)/ 3.80215944d-01,-2.32844590d-01/
      data fpppp( 5, 7),fpppp( 5, 8)/ 6.81301098d-02,-2.27712498d-02/
      data fpppp( 5, 9),fpppp( 5,10)/ 2.01675380d-04, 2.30870235d-03/
      data fpppp( 5,11),fpppp( 5,12)/-1.66667881d-03, 5.36537504d-04/
      data fpppp( 5,13),fpppp( 5,14)/-1.18006879d-04,-2.32897765d-05/
      data fpppp( 5,15),fpppp( 5,16)/ 7.86238928d-05,-4.26260262d-06/
      data fpppp( 5,17),fpppp( 5,18)/-1.56510815d-04,-4.69514081d-05/
      data fpppp( 5,19),fpppp( 5,20)/ 8.11842719d-05, 4.85747914d-05/
      data fpppp( 5,21),fpppp( 5,22)/ 2.37239096d-06, 1.15041887d-06/
      data fpppp( 5,23) /            -1.29231042d-05 /
      data fpppp( 6, 1),fpppp( 6, 2)/ 2.37101148d-02, 1.35280338d-02/
      data fpppp( 6, 3),fpppp( 6, 4)/-1.17045314d-01, 1.73750773d-01/
      data fpppp( 6, 5),fpppp( 6, 6)/-1.46218726d-01, 1.87559922d-01/
      data fpppp( 6, 7),fpppp( 6, 8)/-1.28812490d-01, 2.61473067d-02/
      data fpppp( 6, 9),fpppp( 6,10)/-6.66869158d-03, 9.62058823d-04/
      data fpppp( 6,11),fpppp( 6,12)/-2.85680201d-04, 1.98077927d-04/
      data fpppp( 6,13),fpppp( 6,14)/-5.38787947d-05,-4.19023010d-05/
      data fpppp( 6,15),fpppp( 6,16)/ 5.65075594d-05, 4.17252165d-06/
      data fpppp( 6,17),fpppp( 6,18)/-1.01522858d-04,-2.46941611d-05/
      data fpppp( 6,19),fpppp( 6,20)/ 5.70022613d-05, 2.97142868d-05/
      data fpppp( 6,21),fpppp( 6,22)/-4.88582830d-07,-1.38437026d-06/
      data fpppp( 6,23) /            -1.06536097d-05 /
      data fpppp( 7, 1),fpppp( 7, 2)/-8.75532404d-04, 7.39670280d-03/
      data fpppp( 7, 3),fpppp( 7, 4)/-9.45104629d-02, 1.89210275d-01/
      data fpppp( 7, 5),fpppp( 7, 6)/-1.54922937d-01, 9.40682305d-02/
      data fpppp( 7, 7),fpppp( 7, 8)/-3.12517716d-02,-8.90001496d-03/
      data fpppp( 7, 9),fpppp( 7,10)/ 7.64341374d-04, 2.11019202d-04/
      data fpppp( 7,11),fpppp( 7,12)/-7.37116967d-05, 1.15317439d-04/
      data fpppp( 7,13),fpppp( 7,14)/-5.04983575d-05,-4.56254559d-05/
      data fpppp( 7,15),fpppp( 7,16)/ 2.67825459d-05, 1.07823021d-05/
      data fpppp( 7,17),fpppp( 7,18)/-3.27774506d-05,-1.08464475d-06/
      data fpppp( 7,19),fpppp( 7,20)/ 2.74338419d-05, 9.36152950d-06/
      data fpppp( 7,21),fpppp( 7,22)/-5.15035079d-06,-3.17426899d-06/
      data fpppp( 7,23) /            -5.90903350d-06 /
      data fpppp( 8, 1),fpppp( 8, 2)/ 2.45800097d-02, 1.27650531d-03/
      data fpppp( 8, 3),fpppp( 8, 4)/-5.13299501d-02,-1.37607693d-03/
      data fpppp( 8, 5),fpppp( 8, 6)/ 9.30454138d-02, 1.28898420d-02/
      data fpppp( 8, 7),fpppp( 8, 8)/-6.98201497d-02, 1.85983698d-02/
      data fpppp( 8, 9),fpppp( 8,10)/-5.49369493d-03, 1.35751905d-03/
      data fpppp( 8,11),fpppp( 8,12)/-2.92290732d-04, 1.50128515d-04/
      data fpppp( 8,13),fpppp( 8,14)/-6.80148396d-05,-2.92338133d-05/
      data fpppp( 8,15),fpppp( 8,16)/ 2.19107424d-06, 1.57009395d-05/
      data fpppp( 8,17),fpppp( 8,18)/-3.85683485d-06, 7.93805271d-06/
      data fpppp( 8,19),fpppp( 8,20)/ 1.40006162d-05, 1.11130277d-06/
      data fpppp( 8,21),fpppp( 8,22)/-5.68508911d-06,-4.23996089d-06/
      data fpppp( 8,23) /            -5.14955269d-06 /
      data fpppp( 9, 1),fpppp( 9, 2)/-1.41688411d-02,-1.74969747d-02/
      data fpppp( 9, 3),fpppp( 9, 4)/ 9.21420805d-02,-1.93604025d-01/
      data fpppp( 9, 5),fpppp( 9, 6)/ 2.26194337d-01,-1.72074481d-01/
      data fpppp( 9, 7),fpppp( 9, 8)/ 8.02166868d-02,-2.10090863d-02/
      data fpppp( 9, 9),fpppp( 9,10)/ 4.37357027d-03,-1.21503018d-03/
      data fpppp( 9,11),fpppp( 9,12)/ 4.07161765d-04,-6.03352964d-05/
      data fpppp( 9,13),fpppp( 9,14)/-1.11142304d-05,-3.92577065d-05/
      data fpppp( 9,15),fpppp( 9,16)/ 1.00876638d-06, 1.03599186d-05/
      data fpppp( 9,17),fpppp( 9,18)/ 9.13526551d-06, 1.07045530d-05/
      data fpppp( 9,19),fpppp( 9,20)/ 7.31474164d-06,-1.57305245d-06/
      data fpppp( 9,21),fpppp( 9,22)/-5.77509341d-06,-3.68637299d-06/
      data fpppp( 9,23) /            -3.39501296d-06 /
      data fpppp(10, 1),fpppp(10, 2)/-7.85315287d-03, 7.51456853d-03/
      data fpppp(10, 3),fpppp(10, 4)/-3.17624476d-03, 7.73378134d-02/
      data fpppp(10, 5),fpppp(10, 6)/-1.61246755d-01, 7.95648995d-02/
      data fpppp(10, 7),fpppp(10, 8)/-2.28890839d-03, 4.41460368d-03/
      data fpppp(10, 9),fpppp(10,10)/-5.08708030d-04, 2.22743162d-04/
      data fpppp(10,11),fpppp(10,12)/ 2.29095112d-05, 2.36278033d-05/
      data fpppp(10,13),fpppp(10,14)/-3.33446081d-05,-2.36450166d-05/
      data fpppp(10,15),fpppp(10,16)/-5.82114762d-06, 9.39907330d-06/
      data fpppp(10,17),fpppp(10,18)/ 1.08920318d-05, 9.98901249d-06/
      data fpppp(10,19),fpppp(10,20)/ 4.89305024d-06,-2.11490178d-06/
      data fpppp(10,21),fpppp(10,22)/-4.22393488d-06,-3.86114784d-06/
      data fpppp(10,23) /            -4.20459513d-06 /
      data fpppp(11, 1),fpppp(11, 2)/ 2.34113176d-03, 1.80540215d-03/
      data fpppp(11, 3),fpppp(11, 4)/ 1.47176530d-02,-1.94380277d-02/
      data fpppp(11, 5),fpppp(11, 6)/-4.02919650d-03,-5.12296619d-03/
      data fpppp(11, 7),fpppp(11, 8)/ 9.91410345d-03, 3.21534734d-04/
      data fpppp(11, 9),fpppp(11,10)/ 5.07092647d-04,-2.16764368d-05/
      data fpppp(11,11),fpppp(11,12)/ 7.84252544d-05,-7.98220729d-06/
      data fpppp(11,13),fpppp(11,14)/-2.34272397d-05,-1.80763270d-05/
      data fpppp(11,15),fpppp(11,16)/-7.37787438d-06, 6.75268188d-06/
      data fpppp(11,17),fpppp(11,18)/ 1.01147312d-05, 8.93800864d-06/
      data fpppp(11,19),fpppp(11,20)/ 3.01048747d-06,-1.93567219d-06/
      data fpppp(11,21),fpppp(11,22)/-3.45327007d-06,-2.46429193d-06/
      data fpppp(11,23) /            -2.19147836d-06 /
      data fpppp(12, 1),fpppp(12, 2)/ 1.89632853d-03, 2.64299744d-03/
      data fpppp(12, 3),fpppp(12, 4)/-3.51624810d-03, 1.44952070d-02/
      data fpppp(12, 5),fpppp(12, 6)/-2.34576970d-02, 5.42256600d-03/
      data fpppp(12, 7),fpppp(12, 8)/ 2.41428941d-03, 1.26799739d-03/
      data fpppp(12, 9),fpppp(12,10)/ 2.26542604d-04, 6.07870932d-05/
      data fpppp(12,11),fpppp(12,12)/ 3.92262768d-05,-1.04907035d-05/
      data fpppp(12,13),fpppp(12,14)/-1.87263213d-05,-1.63783932d-05/
      data fpppp(12,15),fpppp(12,16)/-3.17259556d-06, 2.95987971d-06/
      data fpppp(12,17),fpppp(12,18)/ 8.32556213d-06, 6.93319817d-06/
      data fpppp(12,19),fpppp(12,20)/ 2.31150048d-06,-1.72265704d-06/
      data fpppp(12,21),fpppp(12,22)/-2.13849511d-06,-2.08939580d-06/
      data fpppp(12,23) /            -2.17313574d-06 /
      data fpppp(13, 1),fpppp(13, 2)/-8.94499078d-03,-3.26839056d-03/
      data fpppp(13, 3),fpppp(13, 4)/ 1.20332301d-02,-6.35272081d-03/
      data fpppp(13, 5),fpppp(13, 6)/-1.72935994d-03,-1.27580232d-03/
      data fpppp(13, 7),fpppp(13, 8)/ 1.16291320d-03, 4.76291199d-04/
      data fpppp(13, 9),fpppp(13,10)/ 2.00746759d-04, 3.98828750d-05/
      data fpppp(13,11),fpppp(13,12)/ 1.67294584d-05,-1.36939470d-05/
      data fpppp(13,13),fpppp(13,14)/-1.51702660d-05,-8.47205426d-06/
      data fpppp(13,15),fpppp(13,16)/-4.96627007d-06, 2.39021541d-06/
      data fpppp(13,17),fpppp(13,18)/ 5.25206756d-06, 4.40401622d-06/
      data fpppp(13,19),fpppp(13,20)/ 1.20751446d-06,-7.18741800d-07/
      data fpppp(13,21),fpppp(13,22)/-1.50349034d-06,-1.08515631d-06/
      data fpppp(13,23) /            -1.01056016d-06 /
      data fpppp(14, 1),fpppp(14, 2)/ 6.92985084d-03, 2.88770564d-03/
      data fpppp(14, 3),fpppp(14, 4)/-5.26377199d-03, 9.67413870d-04/
      data fpppp(14, 5),fpppp(14, 6)/-1.37514047d-04,-1.15690975d-04/
      data fpppp(14, 7),fpppp(14, 8)/ 3.22605602d-04, 2.44660773d-04/
      data fpppp(14, 9),fpppp(14,10)/ 1.05670713d-04, 2.64488678d-05/
      data fpppp(14,11),fpppp(14,12)/ 1.18569224d-06,-1.40601794d-05/
      data fpppp(14,13),fpppp(14,14)/-9.65573282d-06,-7.15424604d-06/
      data fpppp(14,15),fpppp(14,16)/-1.97578093d-06, 6.73941959d-07/
      data fpppp(14,17),fpppp(14,18)/ 3.02089120d-06, 2.75715940d-06/
      data fpppp(14,19),fpppp(14,20)/ 1.07802829d-06,-8.67144677d-07/
      data fpppp(14,21),fpppp(14,22)/-5.68054459d-07,-7.83166308d-07/
      data fpppp(14,23) /            -8.51363281d-07 /
      data fpppp(15, 1),fpppp(15, 2)/ 1.50763414d-04, 1.73547652d-05/
      data fpppp(15, 3),fpppp(15, 4)/ 1.50414913d-04,-6.49165727d-04/
      data fpppp(15, 5),fpppp(15, 6)/-7.61996252d-05,-1.25064979d-04/
      data fpppp(15, 7),fpppp(15, 8)/ 1.88185267d-04, 1.42710341d-04/
      data fpppp(15, 9),fpppp(15,10)/ 7.00591968d-05, 1.72571430d-05/
      data fpppp(15,11),fpppp(15,12)/-6.82872818d-06,-1.05096591d-05/
      data fpppp(15,13),fpppp(15,14)/-8.10394992d-06,-4.82715933d-06/
      data fpppp(15,15),fpppp(15,16)/-2.72779351d-06, 9.65851006d-07/
      data fpppp(15,17),fpppp(15,18)/ 2.14001024d-06, 1.96702438d-06/
      data fpppp(15,19),fpppp(15,20)/ 4.90636472d-07, 1.67918511d-08/
      data fpppp(15,21),fpppp(15,22)/-1.19836490d-06,-1.23898933d-07/
      data fpppp(15,23) /             2.96389115d-07 /
      data fpppp(16, 1),fpppp(16, 2)/ 7.70581393d-04, 2.71543524d-04/
      data fpppp(16, 3),fpppp(16, 4)/-6.44766432d-04,-1.00624080d-04/
      data fpppp(16, 5),fpppp(16, 6)/ 1.72379138d-06, 1.35390336d-05/
      data fpppp(16, 7),fpppp(16, 8)/ 9.65695134d-05, 8.34449860d-05/
      data fpppp(16, 9),fpppp(16,10)/ 4.37078192d-05, 6.97303912d-06/
      data fpppp(16,11),fpppp(16,12)/-6.97801543d-06,-9.95271965d-06/
      data fpppp(16,13),fpppp(16,14)/-6.39508966d-06,-4.04909257d-06/
      data fpppp(16,15),fpppp(16,16)/-1.09851912d-06,-1.63473666d-07/
      data fpppp(16,17),fpppp(16,18)/ 1.64905265d-06, 1.38093147d-06/
      data fpppp(16,19),fpppp(16,20)/ 5.04687497d-07,-5.47257817d-07/
      data fpppp(16,21),fpppp(16,22)/-8.48072558d-08,-3.38717581d-07/
      data fpppp(16,23) /            -3.87953367d-07 /
      data fpppp(17, 1),fpppp(17, 2)/ 1.09970103d-04, 1.45043670d-05/
      data fpppp(17, 3),fpppp(17, 4)/-1.16616023d-04,-1.22945125d-04/
      data fpppp(17, 5),fpppp(17, 6)/ 1.61181393d-05, 4.00849758d-05/
      data fpppp(17, 7),fpppp(17, 8)/ 5.48666763d-05, 4.15837876d-05/
      data fpppp(17, 9),fpppp(17,10)/ 2.28433648d-05, 2.08109875d-07/
      data fpppp(17,11),fpppp(17,12)/-9.13503230d-06,-6.50388730d-06/
      data fpppp(17,13),fpppp(17,14)/-4.36859653d-06,-2.28607838d-06/
      data fpppp(17,15),fpppp(17,16)/-1.66690591d-06, 4.70832681d-07/
      data fpppp(17,17),fpppp(17,18)/ 7.64365134d-07, 7.84201176d-07/
      data fpppp(17,19),fpppp(17,20)/ 2.48113863d-07,-5.56435173d-08/
      data fpppp(17,21),fpppp(17,22)/-4.61329019d-07, 7.20187893d-08/
      data fpppp(17,23) /             3.37071366d-07 /
      data fpppp(18, 1),fpppp(18, 2)/ 8.70958549d-05, 1.75903542d-05/
      data fpppp(18, 3),fpppp(18, 4)/-1.00212522d-04,-4.89745837d-05/
      data fpppp(18, 5),fpppp(18, 6)/ 1.07633539d-05, 3.80614182d-05/
      data fpppp(18, 7),fpppp(18, 8)/ 3.78026595d-05, 2.72439959d-05/
      data fpppp(18, 9),fpppp(18,10)/ 1.41833143d-05,-4.47132280d-06/
      data fpppp(18,11),fpppp(18,12)/-6.04307132d-06,-4.96102318d-06/
      data fpppp(18,13),fpppp(18,14)/-2.77214015d-06,-1.87083823d-06/
      data fpppp(18,15),fpppp(18,16)/-5.75264065d-07,-4.99854997d-08/
      data fpppp(18,17),fpppp(18,18)/ 3.95407384d-07, 5.64709973d-07/
      data fpppp(18,19),fpppp(18,20)/ 3.11518675d-08, 9.42064718d-08/
      data fpppp(18,21),fpppp(18,22)/-9.56698272d-08,-1.30559531d-07/
      data fpppp(18,23) /            -2.09731119d-07 /
      data fpppp(19, 1),fpppp(19, 2)/ 2.84181451d-05,-1.53347047d-06/
      data fpppp(19, 3),fpppp(19, 4)/-4.54853312d-05,-4.04363340d-05/
      data fpppp(19, 5),fpppp(19, 6)/ 7.66575981d-06, 2.97734332d-05/
      data fpppp(19, 7),fpppp(19, 8)/ 3.02349984d-05, 2.02031105d-05/
      data fpppp(19, 9),fpppp(19,10)/ 9.63498518d-06,-3.25474872d-06/
      data fpppp(19,11),fpppp(19,12)/-5.52190735d-06,-3.71060561d-06/
      data fpppp(19,13),fpppp(19,14)/-2.15038222d-06,-1.63922786d-06/
      data fpppp(19,15),fpppp(19,16)/-1.99196687d-07,-3.60281446d-07/
      data fpppp(19,17),fpppp(19,18)/ 5.98130941d-07, 1.57246050d-07/
      data fpppp(19,19),fpppp(19,20)/ 3.91963584d-07,-4.24239625d-07/
      data fpppp(19,21),fpppp(19,22)/ 2.17139117d-07,-7.57438016d-08/
      data fpppp(19,23) /            -1.01694817d-07 /
      data fpppp(20, 1),fpppp(20, 2)/ 1.62031719d-05,-2.59968723d-06/
      data fpppp(20, 3),fpppp(20, 4)/-3.28849004d-05,-2.29818745d-05/
      data fpppp(20, 5),fpppp(20, 6)/ 4.57953164d-06, 2.28429442d-05/
      data fpppp(20, 7),fpppp(20, 8)/ 2.27790411d-05, 1.68986904d-05/
      data fpppp(20, 9),fpppp(20,10)/ 5.73453808d-06,-2.74062580d-06/
      data fpppp(20,11),fpppp(20,12)/-4.48331841d-06,-2.66953436d-06/
      data fpppp(20,13),fpppp(20,14)/-2.11039201d-06,-3.03026299d-07/
      data fpppp(20,15),fpppp(20,16)/-9.80784299d-07, 2.83227702d-07/
      data fpppp(20,17),fpppp(20,18)/ 7.64382938d-08, 3.46711645d-07/
      data fpppp(20,19),fpppp(20,20)/-4.99892185d-09, 1.66317088d-07/
      data fpppp(20,21),fpppp(20,22)/-2.21154159d-07, 2.30397421d-08/
      data fpppp(20,23) /             8.67578862d-08 /
      data fpppp(21, 1),fpppp(21, 2)/ 1.87114676d-06,-4.65969559d-06/
      data fpppp(21, 3),fpppp(21, 4)/-1.55767278d-05,-1.11420955d-05/
      data fpppp(21, 5),fpppp(21, 6)/ 3.40460427d-06, 1.33529319d-05/
      data fpppp(21, 7),fpppp(21, 8)/ 1.48328421d-05, 9.01867822d-06/
      data fpppp(21, 9),fpppp(21,10)/ 4.75635901d-06,-2.68736959d-06/
      data fpppp(21,11),fpppp(21,12)/-2.41865746d-06,-1.99789870d-06/
      data fpppp(21,13),fpppp(21,14)/-8.87113564d-07,-1.04564321d-06/
      data fpppp(21,15),fpppp(21,16)/ 1.16182974d-08,-1.53513303d-07/
      data fpppp(21,17),fpppp(21,18)/ 2.35346585d-07, 1.33492977d-07/
      data fpppp(21,19),fpppp(21,20)/ 1.10342520d-07,-4.55470504d-08/
      data fpppp(21,21),fpppp(21,22)/ 1.33653044d-08,-7.60968498d-08/
      data fpppp(21,23) /            -1.23166287d-07 /
      data fpppp(22, 1),fpppp(22, 2)/-2.86703211d-06,-3.34544312d-06/
      data fpppp(22, 3),fpppp(22, 4)/-4.46814615d-06,-3.33582715d-06/
      data fpppp(22, 5),fpppp(22, 6)/ 1.93359297d-06, 5.23392643d-06/
      data fpppp(22, 7),fpppp(22, 8)/ 5.29993486d-06, 4.91092393d-06/
      data fpppp(22, 9),fpppp(22,10)/ 1.51964027d-06,-4.45131964d-07/
      data fpppp(22,11),fpppp(22,12)/-1.40105654d-06,-8.37707523d-07/
      data fpppp(22,13),fpppp(22,14)/-7.31834031d-07,-1.73691422d-07/
      data fpppp(22,15),fpppp(22,16)/-2.48813451d-07, 7.12933319d-08/
      data fpppp(22,17),fpppp(22,18)/ 6.51838914d-08, 1.08584347d-07/
      data fpppp(22,19),fpppp(22,20)/ 3.45919085d-08, 1.46169668d-08/
      data fpppp(22,21),fpppp(22,22)/-4.45917330d-08,-1.21095675d-08/
      data fpppp(22,23) /            -5.82479208d-09 /
      data fpppp(23, 1),fpppp(23, 2)/-1.61177647d-06,-1.50261564d-06/
      data fpppp(23, 3),fpppp(23, 4)/-1.86959459d-06,-5.70084328d-07/
      data fpppp(23, 5),fpppp(23, 6)/ 1.01084751d-07, 1.79380725d-06/
      data fpppp(23, 7),fpppp(23, 8)/ 2.68237804d-06, 1.63694300d-06/
      data fpppp(23, 9),fpppp(23,10)/ 1.30405254d-06,-2.98678910d-07/
      data fpppp(23,11),fpppp(23,12)/-4.14583581d-07,-5.58825980d-07/
      data fpppp(23,13),fpppp(23,14)/-2.90664016d-07,-2.38781520d-07/
      data fpppp(23,15),fpppp(23,16)/-2.64891244d-08,-1.57108472d-09/
      data fpppp(23,17),fpppp(23,18)/ 6.56867197d-08, 6.46052151d-08/
      data fpppp(23,19),fpppp(23,20)/ 2.93786543d-08,-9.11631538d-10/
      data fpppp(23,21),fpppp(23,22)/-1.71239221d-08,-2.29718659d-08/
      data fpppp(23,23) /            -3.17810517d-08 /
      data fpppp(24, 1),fpppp(24, 2)/-4.06157913d-07,-5.60302546d-07/
      data fpppp(24, 3),fpppp(24, 4)/-8.76346675d-07,-6.25742567d-07/
      data fpppp(24, 5),fpppp(24, 6)/ 2.01367344d-07, 6.67554337d-07/
      data fpppp(24, 7),fpppp(24, 8)/ 8.36414589d-07, 1.08274780d-06/
      data fpppp(24, 9),fpppp(24,10)/ 7.09313001d-07, 1.92354735d-08/
      data fpppp(24,11),fpppp(24,12)/-2.93724030d-07,-2.39516834d-07/
      data fpppp(24,13),fpppp(24,14)/-2.36681899d-07,-3.71662412d-08/
      data fpppp(24,15),fpppp(24,16)/-6.45230871d-08, 2.77468919d-08/
      data fpppp(24,17),fpppp(24,18)/ 3.71387260d-08, 2.39609232d-08/
      data fpppp(24,19),fpppp(24,20)/ 2.13594558d-08,-1.40049759d-09/
      data fpppp(24,21),fpppp(24,22)/-1.22583324d-08,-8.98989625d-09/
      data fpppp(24,23) /            -9.75753754d-09 /
      data fpppp(25, 1),fpppp(25, 2)/-5.15919103d-07,-3.96319739d-07/
      data fpppp(25, 3),fpppp(25, 4)/-1.74509243d-07,-3.10437712d-07/
      data fpppp(25, 5),fpppp(25, 6)/-8.22943578d-08, 2.88028636d-07/
      data fpppp(25, 7),fpppp(25, 8)/ 5.77890897d-07, 5.26703368d-07/
      data fpppp(25, 9),fpppp(25,10)/ 3.11017877d-07, 4.78509720d-08/
      data fpppp(25,11),fpppp(25,12)/-1.22498543d-07,-2.02107666d-07/
      data fpppp(25,13),fpppp(25,14)/-2.42262143d-08,-1.33481233d-07/
      data fpppp(25,15),fpppp(25,16)/ 4.43101667d-08,-9.80354095d-09/
      data fpppp(25,17),fpppp(25,18)/ 1.63779154d-08, 2.70599943d-08/
      data fpppp(25,19),fpppp(25,20)/-1.07162540d-09,-2.37468898d-09/
      data fpppp(25,21),fpppp(25,22)/ 2.36564298d-09,-8.21380375d-09/
      data fpppp(25,23) /            -1.44161708d-08 /
      data fpppp(26, 1),fpppp(26, 2)/-8.73156240d-08,-1.22518604d-07/
      data fpppp(26, 3),fpppp(26, 4)/-2.16865982d-07,-1.04207969d-07/
      data fpppp(26, 5),fpppp(26, 6)/ 1.38652580d-08, 1.47011820d-07/
      data fpppp(26, 7),fpppp(26, 8)/ 2.16043840d-07, 2.22869947d-07/
      data fpppp(26, 9),fpppp(26,10)/ 2.13668591d-07, 5.98572797d-09/
      data fpppp(26,11),fpppp(26,12)/-1.04235254d-07,-5.20637632d-08/
      data fpppp(26,13),fpppp(26,14)/-8.08147477d-08, 4.55084457d-08/
      data fpppp(26,15),fpppp(26,16)/-4.39851707d-08, 1.73203619d-08/
      data fpppp(26,17),fpppp(26,18)/ 6.80484354d-09, 1.25084891d-10/
      data fpppp(26,19),fpppp(26,20)/ 6.56787291d-09, 9.95963257d-12/
      data fpppp(26,21),fpppp(26,22)/-6.08789122d-09, 1.86901171d-09/
      data fpppp(26,23) /             5.81027070d-09 /
      data fpppp(27, 1),fpppp(27, 2)/-9.99122641d-08,-7.62469425d-08/
      data fpppp(27, 3),fpppp(27, 4)/-4.88782448d-08,-3.44713636d-08/
      data fpppp(27, 5),fpppp(27, 6)/ 1.63387281d-08, 6.61150560d-08/
      data fpppp(27, 7),fpppp(27, 8)/ 9.90763681d-08, 8.98602923d-08/
      data fpppp(27, 9),fpppp(27,10)/ 5.60446863d-08,-1.08717689d-08/
      data fpppp(27,11),fpppp(27,12)/-3.02479676d-08,-2.89537749d-08/
      data fpppp(27,13),fpppp(27,14)/-4.40600824d-11,-2.15801824d-08/
      data fpppp(27,15),fpppp(27,16)/ 9.58368555d-09,-3.96881201d-10/
      data fpppp(27,17),fpppp(27,18)/ 3.76351917d-09, 4.36428427d-09/
      data fpppp(27,19),fpppp(27,20)/ 1.38704204d-09,-2.13146276d-09/
      data fpppp(27,21),fpppp(27,22)/ 2.48171749d-09,-4.61466620d-09/
      data fpppp(27,23) /            -8.36546020d-09 /
      data fpppp(28, 1),fpppp(28, 2)/-7.07816516d-09, 3.07920657d-08/
      data fpppp(28, 3),fpppp(28, 4)/ 8.84790419d-08, 7.68074095d-08/
      data fpppp(28, 5),fpppp(28, 6)/ 4.18238057d-08,-3.91619346d-08/
      data fpppp(28, 7),fpppp(28, 8)/-9.14337272d-08,-1.00683567d-07/
      data fpppp(28, 9),fpppp(28,10)/-1.06073117d-07,-3.58350828d-08/
      data fpppp(28,11),fpppp(28,12)/ 3.91986270d-08, 2.77292820d-08/
      data fpppp(28,13),fpppp(28,14)/ 5.72178088d-08,-3.71454184d-08/
      data fpppp(28,15),fpppp(28,16)/ 3.52544168d-08,-9.39108805d-09/
      data fpppp(28,17),fpppp(28,18)/-1.22990452d-09, 1.55996628d-09/
      data fpppp(28,19),fpppp(28,20)/-1.31380974d-09,-3.43522216d-09/
      data fpppp(28,21),fpppp(28,22)/ 7.96324413d-09,-7.86812486d-09/
      data fpppp(28,23) /            -1.59195409d-08 /
 
      c(1,1)=fpppp(ix+1,iy+1)
      c(1,2)=fpppp(ix+1,iy  )
      c(2,1)=fpppp(ix  ,iy+1)
      c(2,2)=fpppp(ix,  iy  )
      c(1,3)=fpp(ix+1,iy+1,1)
      c(1,4)=fpp(ix+1,iy  ,1)
      c(2,3)=fpp(ix,  iy+1,1)
      c(2,4)=fpp(ix,  iy,  1)
      c(3,1)=fpp(ix+1,iy+1,2)
      c(3,2)=fpp(ix+1,iy  ,2)
      c(4,1)=fpp(ix,  iy+1,2)
      c(4,2)=fpp(ix,  iy,  2)
      c(3,3)=f(ix+1,iy+1)
      c(3,4)=f(ix+1,iy  )
      c(4,3)=f(ix,  iy+1)
      c(4,4)=f(ix,  iy  )
      px(1)=((xi-xix)**3/(6.0*delxi))-(xi-xix)*delxi/6.0
      px(2)=(xi-xixp1)*delxi/6.0-((xi-xixp1)**3/(6.0*delxi))
      px(3)=(xi-xix)/delxi
      px(4)=(xixp1-xi)/delxi
      py(1)=((yi-yiy)**3/(6.0*delyi))-(yi-yiy)*delyi/6.0
      py(2)=(yi-yiyp1)*delyi/6.0-((yi-yiyp1)**3/(6.0*delyi))
      py(3)=(yi-yiy)/delyi
      py(4)=(yiyp1-yi)/delyi

      fi=0.0d 00
      do l=1,4
        sum=0.0d 00
        do i=1,4
          sum=sum + c(i,l) * px(i)
        enddo
        fi = fi + sum * py(l)
      enddo
      return
      end  
      subroutine c3_spl(xi,yi,ix,iy,delxi,delyi,xix,xixp1,
     x                    yiy,yiyp1,fi)
      implicit real*8 (a-h,o-z)
      dimension fpp(28,23,2),f(28,23),fpppp(28,23)
      dimension c(4,4),px(4),py(4)
 
      data f( 1,17),f( 1,18) /  1.37605000d-03 ,  1.04201000d-03 /
      data f( 1,19),f( 1,20) /  7.02280000d-04 ,  4.19360000d-04 /
      data f( 1,21),f( 1,22) /  1.73470000d-04 ,  2.67200000d-05 /
      data f( 1,23) /           0.00000000d+00 /
      data f( 2, 1),f( 2, 2) /  0.00000000d+00 , -1.50802000d-03 /
      data f( 2, 3),f( 2, 4) / -1.29935000d-02 , -4.11105700d-02 /
      data f( 2, 5),f( 2, 6) / -6.12071400d-02 , -3.71866100d-02 /
      data f( 2, 7),f( 2, 8) / -5.37341000d-03 ,  9.82363000d-03 /
      data f( 2, 9),f( 2,10) /  1.47741400d-02 ,  1.41229300d-02 /
      data f( 2,11),f( 2,12) /  9.78824000d-03 ,  4.70335000d-03 /
      data f( 2,13),f( 2,14) /  1.65095000d-03 ,  1.00181000d-03 /
      data f( 2,15),f( 2,16) /  1.32639000d-03 ,  1.54799000d-03 /
      data f( 2,17),f( 2,18) /  1.44677000d-03 ,  1.14760000d-03 /
      data f( 2,19),f( 2,20) /  8.00300000d-04 ,  4.69620000d-04 /
      data f( 2,21),f( 2,22) /  1.85130000d-04 ,  2.77900000d-05 /
      data f( 2,23) /           0.00000000d+00 /
      data f( 3, 1),f( 3, 2) /  0.00000000d+00 , -1.95299000d-03 /
      data f( 3, 3),f( 3, 4) / -1.74907700d-02 , -6.12050700d-02 /
      data f( 3, 5),f( 3, 6) / -9.53123300d-02 , -5.66077300d-02 /
      data f( 3, 7),f( 3, 8) / -1.13005700d-02 ,  8.83970000d-03 /
      data f( 3, 9),f( 3,10) /  1.46618900d-02 ,  1.37710800d-02 /
      data f( 3,11),f( 3,12) /  8.82795000d-03 ,  4.01334000d-03 /
      data f( 3,13),f( 3,14) /  1.36462000d-03 ,  8.86540000d-04 /
      data f( 3,15),f( 3,16) /  1.24078000d-03 ,  1.50791000d-03 /
      data f( 3,17),f( 3,18) /  1.46437000d-03 ,  1.20058000d-03 /
      data f( 3,19),f( 3,20) /  8.54540000d-04 ,  4.94020000d-04 /
      data f( 3,21),f( 3,22) /  1.89030000d-04 ,  2.77200000d-05 /
      data f( 3,23) /           0.00000000d+00 /
      data f( 4, 1),f( 4, 2) /  0.00000000d+00 , -2.40222000d-03 /
      data f( 4, 3),f( 4, 4) / -2.23690200d-02 , -8.57655400d-02 /
      data f( 4, 5),f( 4, 6) / -1.39778510d-01 , -8.03291000d-02 /
      data f( 4, 7),f( 4, 8) / -1.72344700d-02 ,  7.64278000d-03 /
      data f( 4, 9),f( 4,10) /  1.40434300d-02 ,  1.38269600d-02 /
      data f( 4,11),f( 4,12) /  7.99833000d-03 ,  3.42662000d-03 /
      data f( 4,13),f( 4,14) /  1.14372000d-03 ,  7.84390000d-04 /
      data f( 4,15),f( 4,16) /  1.14653000d-03 ,  1.44005000d-03 /
      data f( 4,17),f( 4,18) /  1.44154000d-03 ,  1.21664000d-03 /
      data f( 4,19),f( 4,20) /  8.74720000d-04 ,  4.99030000d-04 /
      data f( 4,21),f( 4,22) /  1.86810000d-04 ,  2.70400000d-05 /
      data f( 4,23) /           0.00000000d+00 /
      data f( 5, 1),f( 5, 2) /  0.00000000d+00 , -2.80007000d-03 /
      data f( 5, 3),f( 5, 4) / -2.70797200d-02 , -1.14202930d-01 /
      data f( 5, 5),f( 5, 6) / -1.76067410d-01 , -1.06580450d-01 /
      data f( 5, 7),f( 5, 8) / -2.24322900d-02 ,  7.02530000d-03 /
      data f( 5, 9),f( 5,10) /  1.38870800d-02 ,  1.29261600d-02 /
      data f( 5,11),f( 5,12) /  7.21245000d-03 ,  2.93544000d-03 /
      data f( 5,13),f( 5,14) /  9.69400000d-04 ,  6.93110000d-04 /
      data f( 5,15),f( 5,16) /  1.04855000d-03 ,  1.35794000d-03 /
      data f( 5,17),f( 5,18) /  1.39672000d-03 ,  1.20282000d-03 /
      data f( 5,19),f( 5,20) /  8.68270000d-04 ,  4.89600000d-04 /
      data f( 5,21),f( 5,22) /  1.80320000d-04 ,  2.58100000d-05 /
      data f( 5,23) /           0.00000000d+00 /
      data f( 6, 1),f( 6, 2) /  0.00000000d+00 , -3.09335000d-03 /
      data f( 6, 3),f( 6, 4) / -3.10169500d-02 , -1.42153970d-01 /
      data f( 6, 5),f( 6, 6) / -1.95759420d-01 , -1.29683820d-01 /
      data f( 6, 7),f( 6, 8) / -2.61570800d-02 ,  6.66114000d-03 /
      data f( 6, 9),f( 6,10) /  1.36823000d-02 ,  1.20415900d-02 /
      data f( 6,11),f( 6,12) /  6.47883000d-03 ,  2.52441000d-03 /
      data f( 6,13),f( 6,14) /  8.28120000d-04 ,  6.11480000d-04 /
      data f( 6,15),f( 6,16) /  9.50400000d-04 ,  1.26546000d-03 /
      data f( 6,17),f( 6,18) /  1.33307000d-03 ,  1.16451000d-03 /
      data f( 6,19),f( 6,20) /  8.41760000d-04 ,  4.70120000d-04 /
      data f( 6,21),f( 6,22) /  1.70820000d-04 ,  2.42000000d-05 /
      data f( 6,23) /           0.00000000d+00 /
      data f( 7, 1),f( 7, 2) /  0.00000000d+00 , -3.15625000d-03 /
      data f( 7, 3),f( 7, 4) / -3.37738000d-02 , -1.61523950d-01 /
      data f( 7, 5),f( 7, 6) / -2.07937400d-01 , -1.41371760d-01 /
      data f( 7, 7),f( 7, 8) / -2.68500300d-02 ,  7.23864000d-03 /
      data f( 7, 9),f( 7,10) /  1.34224500d-02 ,  1.04015400d-02 /
      data f( 7,11),f( 7,12) /  5.18147000d-03 ,  1.88592000d-03 /
      data f( 7,13),f( 7,14) /  6.15140000d-04 ,  4.73010000d-04 /
      data f( 7,15),f( 7,16) /  7.62760000d-04 ,  1.06348000d-03 /
      data f( 7,17),f( 7,18) /  1.16424000d-03 ,  1.03767000d-03 /
      data f( 7,19),f( 7,20) /  7.49690000d-04 ,  4.11990000d-04 /
      data f( 7,21),f( 7,22) /  1.46710000d-04 ,  2.04700000d-05 /
      data f( 7,23) /           0.00000000d+00 /
      data f( 8, 1),f( 8, 2) /  0.00000000d+00 , -2.79931000d-03 /
      data f( 8, 3),f( 8, 4) / -2.87683000d-02 , -1.36146420d-01 /
      data f( 8, 5),f( 8, 6) / -1.98166100d-01 , -1.20446010d-01 /
      data f( 8, 7),f( 8, 8) / -1.95593000d-02 ,  7.46717000d-03 /
      data f( 8, 9),f( 8,10) /  1.26720000d-02 ,  8.83823000d-03 /
      data f( 8,11),f( 8,12) /  4.10156000d-03 ,  1.42219000d-03 /
      data f( 8,13),f( 8,14) /  4.63660000d-04 ,  3.62680000d-04 /
      data f( 8,15),f( 8,16) /  5.96660000d-04 ,  8.60140000d-04 /
      data f( 8,17),f( 8,18) /  9.69220000d-04 ,  8.76170000d-04 /
      data f( 8,19),f( 8,20) /  6.32170000d-04 ,  3.43340000d-04 /
      data f( 8,21),f( 8,22) /  1.20410000d-04 ,  1.66500000d-05 /
      data f( 8,23) /           0.00000000d+00 /
      data f( 9, 1),f( 9, 2) /  0.00000000d+00 , -2.01887000d-03 /
      data f( 9, 3),f( 9, 4) / -1.98237500d-02 , -8.15164900d-02 /
      data f( 9, 5),f( 9, 6) / -1.38121200d-01 , -7.07788000d-02 /
      data f( 9, 7),f( 9, 8) / -1.01559300d-02 ,  8.36612000d-03 /
      data f( 9, 9),f( 9,10) /  1.13955900d-02 ,  7.35791000d-03 /
      data f( 9,11),f( 9,12) /  3.21562000d-03 ,  1.07777000d-03 /
      data f( 9,13),f( 9,14) /  3.52300000d-04 ,  2.75770000d-04 /
      data f( 9,15),f( 9,16) /  4.57490000d-04 ,  6.75350000d-04 /
      data f( 9,17),f( 9,18) /  7.77540000d-04 ,  7.10470000d-04 /
      data f( 9,19),f( 9,20) /  5.12210000d-04 ,  2.75940000d-04 /
      data f( 9,21),f( 9,22) /  9.58100000d-05 ,  1.31900000d-05 /
      data f( 9,23) /           0.00000000d+00 /
      data f(10, 1),f(10, 2) /  0.00000000d+00 , -1.23474000d-03 /
      data f(10, 3),f(10, 4) / -1.14577100d-02 , -4.05518200d-02 /
      data f(10, 5),f(10, 6) / -6.31347000d-02 , -3.14835800d-02 /
      data f(10, 7),f(10, 8) / -1.77505000d-03 ,  8.86514000d-03 /
      data f(10, 9),f(10,10) /  1.00619200d-02 ,  5.99941000d-03 /
      data f(10,11),f(10,12) /  2.49726000d-03 ,  8.18630000d-04 /
      data f(10,13),f(10,14) /  2.68680000d-04 ,  2.08180000d-04 /
      data f(10,15),f(10,16) /  3.45670000d-04 ,  5.18520000d-04 /
      data f(10,17),f(10,18) /  6.06600000d-04 ,  5.58900000d-04 /
      data f(10,19),f(10,20) /  4.02980000d-04 ,  2.15900000d-04 /
      data f(10,21),f(10,22) /  7.45800000d-05 ,  1.04500000d-05 /
      data f(10,23) /           0.00000000d+00 /
      data f(11, 1),f(11, 2) /  0.00000000d+00 , -6.67570000d-04 /
      data f(11, 3),f(11, 4) / -5.66211000d-03 , -1.69235900d-02 /
      data f(11, 5),f(11, 6) / -2.26400000d-02 , -1.00504400d-02 /
      data f(11, 7),f(11, 8) /  3.51590000d-03 ,  8.69805000d-03 /
      data f(11, 9),f(11,10) /  8.62316000d-03 ,  4.79525000d-03 /
      data f(11,11),f(11,12) /  1.92151000d-03 ,  6.22090000d-04 /
      data f(11,13),f(11,14) /  2.05210000d-04 ,  1.56320000d-04 /
      data f(11,15),f(11,16) /  2.58360000d-04 ,  3.91960000d-04 /
      data f(11,17),f(11,18) /  4.63700000d-04 ,  4.30100000d-04 /
      data f(11,19),f(11,20) /  3.10310000d-04 ,  1.65920000d-04 /
      data f(11,21),f(11,22) /  5.73000000d-05 ,  7.85000000d-06 /
      data f(11,23) /           0.00000000d+00 /
      data f(12, 1),f(12, 2) /  0.00000000d+00 , -3.85370000d-04 /
      data f(12, 3),f(12, 4) / -2.99179000d-03 , -5.04411000d-03 /
      data f(12, 5),f(12, 6) / -4.73381000d-03 ,  7.60600000d-05 /
      data f(12, 7),f(12, 8) /  5.90173000d-03 ,  7.93228000d-03 /
      data f(12, 9),f(12,10) /  7.15718000d-03 ,  3.76237000d-03 /
      data f(12,11),f(12,12) /  1.46640000d-03 ,  4.72750000d-04 /
      data f(12,13),f(12,14) /  1.56760000d-04 ,  1.16810000d-04 /
      data f(12,15),f(12,16) /  1.91740000d-04 ,  2.92900000d-04 /
      data f(12,17),f(12,18) /  3.49490000d-04 ,  3.25740000d-04 /
      data f(12,19),f(12,20) /  2.35430000d-04 ,  1.25920000d-04 /
      data f(12,21),f(12,22) /  4.35100000d-05 ,  5.99000000d-06 /
      data f(12,23) /           0.00000000d+00 /
      data f(13, 1),f(13, 2) /  0.00000000d+00 , -2.53100000d-04 /
      data f(13, 3),f(13, 4) / -1.74143000d-03 ,  6.60160000d-04 /
      data f(13, 5),f(13, 6) /  2.86869000d-03 ,  4.65568000d-03 /
      data f(13, 7),f(13, 8) /  6.13229000d-03 ,  6.16457000d-03 /
      data f(13, 9),f(13,10) /  5.10871000d-03 ,  2.53549000d-03 /
      data f(13,11),f(13,12) /  9.65320000d-04 ,  3.12960000d-04 /
      data f(13,13),f(13,14) /  1.04360000d-04 ,  7.47200000d-05 /
      data f(13,15),f(13,16) /  1.21630000d-04 ,  1.87050000d-04 /
      data f(13,17),f(13,18) /  2.24910000d-04 ,  2.10940000d-04 /
      data f(13,19),f(13,20) /  1.52970000d-04 ,  8.20900000d-05 /
      data f(13,21),f(13,22) /  2.84400000d-05 ,  3.92000000d-06 /
      data f(13,23) /           0.00000000d+00 /
      data f(14, 1),f(14, 2) /  0.00000000d+00 , -5.66000000d-05 /
      data f(14, 3),f(14, 4) /  9.20900000d-05 ,  1.71385000d-03 /
      data f(14, 5),f(14, 6) /  3.39989000d-03 ,  4.39670000d-03 /
      data f(14, 7),f(14, 8) /  4.72666000d-03 ,  4.30914000d-03 /
      data f(14, 9),f(14,10) /  3.43178000d-03 ,  1.65747000d-03 /
      data f(14,11),f(14,12) /  6.28920000d-04 ,  2.07480000d-04 /
      data f(14,13),f(14,14) /  6.91300000d-05 ,  4.73600000d-05 /
      data f(14,15),f(14,16) /  7.65400000d-05 ,  1.18480000d-04 /
      data f(14,17),f(14,18) /  1.43280000d-04 ,  1.34940000d-04 /
      data f(14,19),f(14,20) /  9.81700000d-05 ,  5.28100000d-05 /
      data f(14,21),f(14,22) /  1.83000000d-05 ,  2.58000000d-06 /
      data f(14,23) /           0.00000000d+00 /
      data f(15, 1),f(15, 2) /  0.00000000d+00 ,  1.49000000d-05 /
      data f(15, 3),f(15, 4) /  3.63440000d-04 ,  1.53469000d-03 /
      data f(15, 5),f(15, 6) /  2.79215000d-03 ,  3.51878000d-03 /
      data f(15, 7),f(15, 8) /  3.64629000d-03 ,  3.24666000d-03 /
      data f(15, 9),f(15,10) /  2.56101000d-03 ,  1.23255000d-03 /
      data f(15,11),f(15,12) /  4.71330000d-04 ,  1.57690000d-04 /
      data f(15,13),f(15,14) /  5.22800000d-05 ,  3.46500000d-05 /
      data f(15,15),f(15,16) /  5.61000000d-05 ,  8.71500000d-05 /
      data f(15,17),f(15,18) /  1.05680000d-04 ,  9.97400000d-05 /
      data f(15,19),f(15,20) /  7.26900000d-05 ,  3.90900000d-05 /
      data f(15,21),f(15,22) /  1.36500000d-05 ,  1.87000000d-06 /
      data f(15,23) /           0.00000000d+00 /
      data f(16, 1),f(16, 2) /  0.00000000d+00 ,  3.47200000d-05 /
      data f(16, 3),f(16, 4) /  3.54640000d-04 ,  1.17277000d-03 /
      data f(16, 5),f(16, 6) /  2.07661000d-03 ,  2.61637000d-03 /
      data f(16, 7),f(16, 8) /  2.68936000d-03 ,  2.38181000d-03 /
      data f(16, 9),f(16,10) /  1.87892000d-03 ,  9.10020000d-04 /
      data f(16,11),f(16,12) /  3.52830000d-04 ,  1.19910000d-04 /
      data f(16,13),f(16,14) /  3.92200000d-05 ,  2.52700000d-05 /
      data f(16,15),f(16,16) /  4.09300000d-05 ,  6.40100000d-05 /
      data f(16,17),f(16,18) /  7.78100000d-05 ,  7.35500000d-05 /
      data f(16,19),f(16,20) /  5.36600000d-05 ,  2.88500000d-05 /
      data f(16,21),f(16,22) /  9.86000000d-06 ,  1.32000000d-06 /
      data f(16,23) /           0.00000000d+00 /
      data f(17, 1),f(17, 2) /  0.00000000d+00 ,  2.79500000d-05 /
      data f(17, 3),f(17, 4) /  2.27030000d-04 ,  6.76970000d-04 /
      data f(17, 5),f(17, 6) /  1.19987000d-03 ,  1.54485000d-03 /
      data f(17, 7),f(17, 8) /  1.61214000d-03 ,  1.44552000d-03 /
      data f(17, 9),f(17,10) /  1.15426000d-03 ,  5.72780000d-04 /
      data f(17,11),f(17,12) /  2.29010000d-04 ,  7.95600000d-05 /
      data f(17,13),f(17,14) /  2.53700000d-05 ,  1.58000000d-05 /
      data f(17,15),f(17,16) /  2.54200000d-05 ,  4.00400000d-05 /
      data f(17,17),f(17,18) /  4.88900000d-05 ,  4.63500000d-05 /
      data f(17,19),f(17,20) /  3.38400000d-05 ,  1.82500000d-05 /
      data f(17,21),f(17,22) /  6.28000000d-06 ,  7.70000000d-07 /
      data f(17,23) /           0.00000000d+00 /
      data f(18, 1),f(18, 2) /  0.00000000d+00 ,  1.58900000d-05 /
      data f(18, 3),f(18, 4) /  1.22750000d-04 ,  3.59600000d-04 /
      data f(18, 5),f(18, 6) /  6.51310000d-04 ,  8.67080000d-04 /
      data f(18, 7),f(18, 8) /  9.32230000d-04 ,  8.56580000d-04 /
      data f(18, 9),f(18,10) /  6.98300000d-04 ,  3.59810000d-04 /
      data f(18,11),f(18,12) /  1.49100000d-04 ,  5.24600000d-05 /
      data f(18,13),f(18,14) /  1.62600000d-05 ,  9.47000000d-06 /
      data f(18,15),f(18,16) /  1.56500000d-05 ,  2.50200000d-05 /
      data f(18,17),f(18,18) /  3.06800000d-05 ,  2.90900000d-05 /
      data f(18,19),f(18,20) /  2.12400000d-05 ,  1.13600000d-05 /
      data f(18,21),f(18,22) /  3.87000000d-06 ,  5.20000000d-07 /
      data f(18,23) /           0.00000000d+00 /
      data f(19, 1),f(19, 2) /  0.00000000d+00 ,  1.02400000d-05 /
      data f(19, 3),f(19, 4) /  7.88900000d-05 ,  2.32460000d-04 /
      data f(19, 5),f(19, 6) /  4.28720000d-04 ,  5.84300000d-04 /
      data f(19, 7),f(19, 8) /  6.42110000d-04 ,  6.01200000d-04 /
      data f(19, 9),f(19,10) /  4.98160000d-04 ,  2.64440000d-04 /
      data f(19,11),f(19,12) /  1.12450000d-04 ,  3.97900000d-05 /
      data f(19,13),f(19,14) /  1.20800000d-05 ,  6.78000000d-06 /
      data f(19,15),f(19,16) /  1.13100000d-05 ,  1.82600000d-05 /
      data f(19,17),f(19,18) /  2.24800000d-05 ,  2.13100000d-05 /
      data f(19,19),f(19,20) /  1.55700000d-05 ,  8.37000000d-06 /
      data f(19,21),f(19,22) /  2.79000000d-06 ,  3.70000000d-07 /
      data f(19,23) /           0.00000000d+00 /
      data f(20, 1),f(20, 2) /  0.00000000d+00 ,  6.51000000d-06 /
      data f(20, 3),f(20, 4) /  5.05900000d-05 ,  1.50530000d-04 /
      data f(20, 5),f(20, 6) /  2.83000000d-04 ,  3.94010000d-04 /
      data f(20, 7),f(20, 8) /  4.42240000d-04 ,  4.21990000d-04 /
      data f(20, 9),f(20,10) /  3.55850000d-04 ,  1.95040000d-04 /
      data f(20,11),f(20,12) /  8.50500000d-05 ,  3.02300000d-05 /
      data f(20,13),f(20,14) /  8.94000000d-06 ,  4.82000000d-06 /
      data f(20,15),f(20,16) /  8.20000000d-06 ,  1.32900000d-05 /
      data f(20,17),f(20,18) /  1.64300000d-05 ,  1.56000000d-05 /
      data f(20,19),f(20,20) /  1.13900000d-05 ,  6.03000000d-06 /
      data f(20,21),f(20,22) /  2.06000000d-06 ,  2.80000000d-07 /
      data f(20,23) /           0.00000000d+00 /
      data f(21, 1),f(21, 2) /  0.00000000d+00 ,  3.36000000d-06 /
      data f(21, 3),f(21, 4) /  2.66400000d-05 ,  8.02300000d-05 /
      data f(21, 5),f(21, 6) /  1.54030000d-04 ,  2.20470000d-04 /
      data f(21, 7),f(21, 8) /  2.54680000d-04 ,  2.50040000d-04 /
      data f(21, 9),f(21,10) /  2.16590000d-04 ,  1.24960000d-04 /
      data f(21,11),f(21,12) /  5.60700000d-05 ,  1.99800000d-05 /
      data f(21,13),f(21,14) /  5.69000000d-06 ,  2.93000000d-06 /
      data f(21,15),f(21,16) /  5.08000000d-06 ,  8.31000000d-06 /
      data f(21,17),f(21,18) /  1.03100000d-05 ,  9.78000000d-06 /
      data f(21,19),f(21,20) /  7.13000000d-06 ,  3.79000000d-06 /
      data f(21,21),f(21,22) /  1.33000000d-06 ,  2.70000000d-07 /
      data f(21,23) /           0.00000000d+00 /
      data f(22, 1),f(22, 2) /  0.00000000d+00 ,  1.29000000d-06 /
      data f(22, 3),f(22, 4) /  9.87000000d-06 ,  3.05700000d-05 /
      data f(22, 5),f(22, 6) /  5.91200000d-05 ,  8.76300000d-05 /
      data f(22, 7),f(22, 8) /  1.05720000d-04 ,  1.08600000d-04 /
      data f(22, 9),f(22,10) /  9.85800000d-05 ,  6.13200000d-05 /
      data f(22,11),f(22,12) /  2.85700000d-05 ,  1.00800000d-05 /
      data f(22,13),f(22,14) /  2.74000000d-06 ,  1.33000000d-06 /
      data f(22,15),f(22,16) /  2.36000000d-06 ,  3.88000000d-06 /
      data f(22,17),f(22,18) /  4.77000000d-06 ,  4.52000000d-06 /
      data f(22,19),f(22,20) /  3.30000000d-06 ,  1.77000000d-06 /
      data f(22,21),f(22,22) /  6.10000000d-07 ,  8.00000000d-08 /
      data f(22,23) /           0.00000000d+00 /
      data f(23, 1),f(23, 2) /  0.00000000d+00 ,  5.00000000d-07 /
      data f(23, 3),f(23, 4) /  3.93000000d-06 ,  1.22100000d-05 /
      data f(23, 5),f(23, 6) /  2.45600000d-05 ,  3.77900000d-05 /
      data f(23, 7),f(23, 8) /  4.74800000d-05 ,  5.09000000d-05 /
      data f(23, 9),f(23,10) /  4.78900000d-05 ,  3.12700000d-05 /
      data f(23,11),f(23,12) /  1.47500000d-05 ,  5.15000000d-06 /
      data f(23,13),f(23,14) /  1.37000000d-06 ,  6.70000000d-07 /
      data f(23,15),f(23,16) /  1.16000000d-06 ,  1.87000000d-06 /
      data f(23,17),f(23,18) /  2.27000000d-06 ,  2.13000000d-06 /
      data f(23,19),f(23,20) /  1.54000000d-06 ,  8.30000000d-07 /
      data f(23,21),f(23,22) /  2.80000000d-07 ,  3.00000000d-08 /
      data f(23,23) /           0.00000000d+00 /
      data f(24, 1),f(24, 2) /  0.00000000d+00 ,  2.30000000d-07 /
      data f(24, 3),f(24, 4) /  1.76000000d-06 ,  5.78000000d-06 /
      data f(24, 5),f(24, 6) /  1.17700000d-05 ,  1.84200000d-05 /
      data f(24, 7),f(24, 8) /  2.36100000d-05 ,  2.57100000d-05 /
      data f(24, 9),f(24,10) /  2.45400000d-05 ,  1.63300000d-05 /
      data f(24,11),f(24,12) /  7.68000000d-06 ,  2.68000000d-06 /
      data f(24,13),f(24,14) /  7.60000000d-07 ,  3.80000000d-07 /
      data f(24,15),f(24,16) /  6.00000000d-07 ,  9.40000000d-07 /
      data f(24,17),f(24,18) /  1.12000000d-06 ,  1.03000000d-06 /
      data f(24,19),f(24,20) /  7.40000000d-07 ,  3.90000000d-07 /
      data f(24,21),f(24,22) /  1.30000000d-07 ,  2.00000000d-08 /
      data f(24,23) /           0.00000000d+00 /
      data f(25, 1),f(25, 2) /  0.00000000d+00 ,  1.40000000d-07 /
      data f(25, 3),f(25, 4) /  9.90000000d-07 ,  3.08000000d-06 /
      data f(25, 5),f(25, 6) /  6.24000000d-06 ,  9.67000000d-06 /
      data f(25, 7),f(25, 8) /  1.23300000d-05 ,  1.34100000d-05 /
      data f(25, 9),f(25,10) /  1.28900000d-05 ,  8.55000000d-06 /
      data f(25,11),f(25,12) /  4.04000000d-06 ,  1.49000000d-06 /
      data f(25,13),f(25,14) /  4.70000000d-07 ,  2.70000000d-07 /
      data f(25,15),f(25,16) /  3.30000000d-07 ,  4.90000000d-07 /
      data f(25,17),f(25,18) /  5.70000000d-07 ,  5.20000000d-07 /
      data f(25,19),f(25,20) /  3.70000000d-07 ,  1.80000000d-07 /
      data f(25,21),f(25,22) /  6.00000000d-08 ,  0.00000000d+00 /
      data f(25,23) /           0.00000000d+00 /
      data f(26, 1),f(26, 2) /  0.00000000d+00 ,  7.00000000d-08 /
      data f(26, 3),f(26, 4) /  5.90000000d-07 ,  1.73000000d-06 /
      data f(26, 5),f(26, 6) /  3.42000000d-06 ,  5.21000000d-06 /
      data f(26, 7),f(26, 8) /  6.57000000d-06 ,  7.10000000d-06 /
      data f(26, 9),f(26,10) /  6.76000000d-06 ,  4.51000000d-06 /
      data f(26,11),f(26,12) /  2.25000000d-06 ,  9.20000000d-07 /
      data f(26,13),f(26,14) /  3.20000000d-07 ,  1.40000000d-07 /
      data f(26,15),f(26,16) /  1.70000000d-07 ,  2.70000000d-07 /
      data f(26,17),f(26,18) /  3.00000000d-07 ,  2.60000000d-07 /
      data f(26,19),f(26,20) /  1.80000000d-07 ,  9.00000000d-08 /
      data f(26,21),f(26,22) /  3.00000000d-08 ,  0.00000000d+00 /
      data f(26,23) /           0.00000000d+00 /
      data f(27, 1),f(27, 2) /  0.00000000d+00 ,  2.00000000d-08 /
      data f(27, 3),f(27, 4) /  1.70000000d-07 ,  5.00000000d-07 /
      data f(27, 5),f(27, 6) /  9.70000000d-07 ,  1.47000000d-06 /
      data f(27, 7),f(27, 8) /  1.85000000d-06 ,  2.03000000d-06 /
      data f(27, 9),f(27,10) /  1.99000000d-06 ,  1.52000000d-06 /
      data f(27,11),f(27,12) /  9.10000000d-07 ,  4.20000000d-07 /
      data f(27,13),f(27,14) /  1.40000000d-07 ,  9.00000000d-08 /
      data f(27,15),f(27,16) /  1.00000000d-08 ,  8.00000000d-08 /
      data f(27,17),f(27,18) /  9.00000000d-08 ,  7.00000000d-08 /
      data f(27,19),f(27,20) /  5.00000000d-08 ,  2.00000000d-08 /
      data f(27,21),f(27,22) /  0.00000000d+00 ,  0.00000000d+00 /
      data f(27,23) /           0.00000000d+00 /
      data f(28, 1),f(28, 2) /  0.00000000d+00 ,  1.00000000d-08 /
      data f(28, 3),f(28, 4) /  5.00000000d-08 ,  1.60000000d-07 /
      data f(28, 5),f(28, 6) /  3.20000000d-07 ,  5.10000000d-07 /
      data f(28, 7),f(28, 8) /  6.80000000d-07 ,  7.80000000d-07 /
      data f(28, 9),f(28,10) /  8.20000000d-07 ,  6.80000000d-07 /
      data f(28,11),f(28,12) /  4.00000000d-07 ,  1.70000000d-07 /
      data f(28,13),f(28,14) /  4.00000000d-08 ,  4.00000000d-08 /
      data f(28,15),f(28,16) /  2.00000000d-08 ,  3.00000000d-08 /
      data f(28,17),f(28,18) /  0.00000000d+00 ,  0.00000000d+00 /
      data f(28,19),f(28,20) /  1.00000000d-08 ,  0.00000000d+00 /
      data f(28,21),f(28,22) /  5.00000000d-08 ,  0.00000000d+00 /
      data f(28,23) /           0.00000000d+00 /
 
      data fpp( 1, 1,1),fpp( 1, 1,2)/ 0.00000000d+00,-2.14835527d-04/
      data fpp( 1, 2,1),fpp( 1, 2,2)/-9.35461854d-03,-2.26298947d-04/
      data fpp( 1, 3,1),fpp( 1, 3,2)/-9.62185445d-02,-5.45331086d-04/
      data fpp( 1, 4,1),fpp( 1, 4,2)/-6.19798065d-01, 2.12127290d-04/
      data fpp( 1, 5,1),fpp( 1, 5,2)/-9.36520056d-01, 1.38466753d-03/
      data fpp( 1, 6,1),fpp( 1, 6,2)/-4.01639110d-01, 2.00187400d-04/
      data fpp( 1, 7,1),fpp( 1, 7,2)/-2.19386519d-01,-5.74304328d-04/
      data fpp( 1, 8,1),fpp( 1, 8,2)/ 3.36514018d-02,-2.76502888d-04/
      data fpp( 1, 9,1),fpp( 1, 9,2)/ 3.52175620d-02,-1.20713719d-04/
      data fpp( 1,10,1),fpp( 1,10,2)/-7.16743185d-02,-8.48359754d-06/
      data fpp( 1,11,1),fpp( 1,11,2)/-3.24332838d-02,-2.75670904d-05/
      data fpp( 1,12,1),fpp( 1,12,2)/ 5.57585531d-03, 2.56409590d-05/
      data fpp( 1,13,1),fpp( 1,13,2)/ 1.24463989d-02, 2.89478544d-05/
      data fpp( 1,14,1),fpp( 1,14,2)/ 2.12546550d-03, 1.10696235d-05/
      data fpp( 1,15,1),fpp( 1,15,2)/-2.28593860d-03,-3.62394824d-06/
      data fpp( 1,16,1),fpp( 1,16,2)/-6.01756033d-03,-3.41563052d-06/
      data fpp( 1,17,1),fpp( 1,17,2)/-6.62181544d-03,-1.66872968d-06/
      data fpp( 1,18,1),fpp( 1,18,2)/-6.79622300d-03, 1.30549257d-07/
      data fpp( 1,19,1),fpp( 1,19,2)/-5.34125657d-03, 8.05132658d-07/
      data fpp( 1,20,1),fpp( 1,20,2)/-3.22688987d-03, 5.75201124d-08/
      data fpp( 1,21,1),fpp( 1,21,2)/-9.41483300d-04, 1.18658689d-06/
      data fpp( 1,22,1),fpp( 1,22,2)/-1.64935632d-04, 1.14453232d-06/
      data fpp( 1,23,1),fpp( 1,23,2)/ 0.00000000d+00, 1.43708384d-06/
      data fpp( 2, 1,1),fpp( 2, 1,2)/ 0.00000000d+00,-1.71017019d-04/
      data fpp( 2, 2,1),fpp( 2, 2,2)/-4.71876292d-03,-3.22930761d-04/
      data fpp( 2, 3,1),fpp( 2, 3,2)/-6.43669110d-02,-9.31850335d-04/
      data fpp( 2, 4,1),fpp( 2, 4,2)/-5.39549869d-01, 5.87505030d-05/
      data fpp( 2, 5,1),fpp( 2, 5,2)/-7.67076889d-01, 2.62176832d-03/
      data fpp( 2, 6,1),fpp( 2, 6,2)/-4.02246781d-01, 4.22802027d-05/
      data fpp( 2, 7,1),fpp( 2, 7,2)/-1.13618963d-01,-9.20648335d-04/
      data fpp( 2, 8,1),fpp( 2, 8,2)/ 2.12451965d-02,-3.47565265d-04/
      data fpp( 2, 9,1),fpp( 2, 9,2)/ 1.17918761d-02,-1.48257807d-04/
      data fpp( 2,10,1),fpp( 2,10,2)/-4.31423630d-02,-1.45777460d-05/
      data fpp( 2,11,1),fpp( 2,11,2)/-1.32824323d-02,-1.44400087d-05/
      data fpp( 2,12,1),fpp( 2,12,2)/ 7.64028937d-03, 2.73257808d-05/
      data fpp( 2,13,1),fpp( 2,13,2)/ 9.59620212d-03, 2.70862855d-05/
      data fpp( 2,14,1),fpp( 2,14,2)/ 1.73506900d-03, 8.52467735d-06/
      data fpp( 2,15,1),fpp( 2,15,2)/-1.59512280d-03,-2.76179487d-06/
      data fpp( 2,16,1),fpp( 2,16,2)/-4.39887934d-03,-3.65629786d-06/
      data fpp( 2,17,1),fpp( 2,17,2)/-5.23036913d-03,-1.98221370d-06/
      data fpp( 2,18,1),fpp( 2,18,2)/-5.32855400d-03,-2.91847327d-07/
      data fpp( 2,19,1),fpp( 2,19,2)/-4.39548686d-03, 2.61803013d-07/
      data fpp( 2,20,1),fpp( 2,20,2)/-2.59822026d-03, 2.41835275d-07/
      data fpp( 2,21,1),fpp( 2,21,2)/-7.73033401d-04, 1.54225589d-06/
      data fpp( 2,22,1),fpp( 2,22,2)/-1.18128736d-04, 1.21814117d-06/
      data fpp( 2,23,1),fpp( 2,23,2)/ 0.00000000d+00, 1.35817941d-06/
      data fpp( 3, 1,1),fpp( 3, 1,2)/ 0.00000000d+00,-1.91302056d-05/
      data fpp( 3, 2,1),fpp( 3, 2,2)/-9.06329787d-04,-4.24575989d-04/
      data fpp( 3, 3,1),fpp( 3, 3,2)/-4.59138116d-02,-1.54291544d-03/
      data fpp( 3, 4,1),fpp( 3, 4,2)/-4.28810457d-01,-1.66127055d-04/
      data fpp( 3, 5,1),fpp( 3, 5,2)/-1.64995039d+00, 4.51311326d-03/
      data fpp( 3, 6,1),fpp( 3, 6,2)/-4.68063768d-01,-4.11479576d-04/
      data fpp( 3, 7,1),fpp( 3, 7,2)/ 9.37436953d-03,-1.28258055d-03/
      data fpp( 3, 8,1),fpp( 3, 8,2)/-6.34921877d-02,-4.98251815d-04/
      data fpp( 3, 9,1),fpp( 3, 9,2)/-1.05203066d-01,-1.60751389d-04/
      data fpp( 3,10,1),fpp( 3,10,2)/ 1.18309771d-01,-2.07313266d-05/
      data fpp( 3,11,1),fpp( 3,11,2)/ 2.31450131d-02, 5.37495076d-07/
      data fpp( 3,12,1),fpp( 3,12,2)/ 1.12029872d-02, 2.62925463d-05/
      data fpp( 3,13,1),fpp( 3,13,2)/ 6.25879259d-03, 2.42457197d-05/
      data fpp( 3,14,1),fpp( 3,14,2)/ 1.26625849d-03, 6.96297475d-06/
      data fpp( 3,15,1),fpp( 3,15,2)/-8.07570196d-04,-2.15841874d-06/
      data fpp( 3,16,1),fpp( 3,16,2)/-2.77492232d-03,-3.55589979d-06/
      data fpp( 3,17,1),fpp( 3,17,2)/-4.32870805d-03,-2.25818209d-06/
      data fpp( 3,18,1),fpp( 3,18,2)/-3.45556099d-03,-6.26371861d-07/
      data fpp( 3,19,1),fpp( 3,19,2)/-3.34479598d-03,-1.71330468d-07/
      data fpp( 3,20,1),fpp( 3,20,2)/-1.89622908d-03, 4.42893734d-07/
      data fpp( 3,21,1),fpp( 3,21,2)/-6.22383097d-04, 1.73155553d-06/
      data fpp( 3,22,1),fpp( 3,22,2)/-4.65494232d-05, 1.25168413d-06/
      data fpp( 3,23,1),fpp( 3,23,2)/ 0.00000000d+00, 1.27710793d-06/
      data fpp( 4, 1,1),fpp( 4, 1,2)/ 0.00000000d+00, 2.51439212d-04/
      data fpp( 4, 2,1),fpp( 4, 2,2)/ 5.78808207d-03,-5.41416824d-04/
      data fpp( 4, 3,1),fpp( 4, 3,2)/ 1.94341574d-02,-2.30127112d-03/
      data fpp( 4, 4,1),fpp( 4, 4,2)/-4.24790302d-01,-6.76631514d-04/
      data fpp( 4, 5,1),fpp( 4, 5,2)/ 1.15028444d+00, 7.25984917d-03/
      data fpp( 4, 6,1),fpp( 4, 6,2)/-3.05648147d-01,-1.13179398d-03/
      data fpp( 4, 7,1),fpp( 4, 7,2)/ 7.20774846d-02,-1.85782046d-03/
      data fpp( 4, 8,1),fpp( 4, 8,2)/ 1.04929554d-01,-6.09095381d-04/
      data fpp( 4, 9,1),fpp( 4, 9,2)/ 1.05294389d-01,-1.40182015d-04/
      data fpp( 4,10,1),fpp( 4,10,2)/-1.85458719d-01,-5.59724644d-05/
      data fpp( 4,11,1),fpp( 4,11,2)/-8.95619935d-04, 2.73422726d-05/
      data fpp( 4,12,1),fpp( 4,12,2)/ 9.52176185d-03, 2.20185738d-05/
      data fpp( 4,13,1),fpp( 4,13,2)/ 4.62662752d-03, 2.19120320d-05/
      data fpp( 4,14,1),fpp( 4,14,2)/ 1.07189704d-03, 5.74749826d-06/
      data fpp( 4,15,1),fpp( 4,15,2)/-3.58596413d-04,-1.61382503d-06/
      data fpp( 4,16,1),fpp( 4,16,2)/-1.16943137d-03,-3.40939816d-06/
      data fpp( 4,17,1),fpp( 4,17,2)/-1.71279866d-03,-2.27038235d-06/
      data fpp( 4,18,1),fpp( 4,18,2)/-3.00120205d-03,-1.09247246d-06/
      data fpp( 4,19,1),fpp( 4,19,2)/-2.66132920d-03,-3.80927822d-07/
      data fpp( 4,20,1),fpp( 4,20,2)/-1.45086342d-03, 5.89983746d-07/
      data fpp( 4,21,1),fpp( 4,21,2)/-4.09434211d-04, 1.82919284d-06/
      data fpp( 4,22,1),fpp( 4,22,2)/-6.16735711d-05, 1.24024490d-06/
      data fpp( 4,23,1),fpp( 4,23,2)/ 0.00000000d+00, 1.17362755d-06/
      data fpp( 5, 1,1),fpp( 5, 1,2)/ 0.00000000d+00, 6.15840662d-04/
      data fpp( 5, 2,1),fpp( 5, 2,2)/ 8.58200152d-03,-5.00112525d-04/
      data fpp( 5, 3,1),fpp( 5, 3,2)/ 6.87071821d-02,-3.77048976d-03/
      data fpp( 5, 4,1),fpp( 5, 4,2)/-1.98180334d-01, 4.99617181d-04/
      data fpp( 5, 5,1),fpp( 5, 5,2)/ 1.95518062d+00, 7.83411624d-03/
      data fpp( 5, 6,1),fpp( 5, 6,2)/ 1.72668357d-01,-3.11736547d-04/
      data fpp( 5, 7,1),fpp( 5, 7,2)/ 1.43963692d-01,-3.06848205d-03/
      data fpp( 5, 8,1),fpp( 5, 8,2)/-8.56202956d-03,-5.40072041d-04/
      data fpp( 5, 9,1),fpp( 5, 9,2)/-3.87084887d-02,-1.94224183d-04/
      data fpp( 5,10,1),fpp( 5,10,2)/ 4.95171067d-02,-2.83602301d-05/
      data fpp( 5,11,1),fpp( 5,11,2)/ 6.68146668d-03, 2.24977034d-05/
      data fpp( 5,12,1),fpp( 5,12,2)/ 8.03396539d-03, 2.45714166d-05/
      data fpp( 5,13,1),fpp( 5,13,2)/ 3.18269734d-03, 1.78748302d-05/
      data fpp( 5,14,1),fpp( 5,14,2)/ 9.68153338d-04, 5.31426250d-06/
      data fpp( 5,15,1),fpp( 5,15,2)/ 3.95585020d-06,-1.22808022d-06/
      data fpp( 5,16,1),fpp( 5,16,2)/-1.09735219d-03,-3.16494160d-06/
      data fpp( 5,17,1),fpp( 5,17,2)/-2.01409730d-03,-2.34875337d-06/
      data fpp( 5,18,1),fpp( 5,18,2)/-2.46763081d-03,-1.40084491d-06/
      data fpp( 5,19,1),fpp( 5,19,2)/-1.98788720d-03,-4.86866970d-07/
      data fpp( 5,20,1),fpp( 5,20,2)/-9.64317246d-04, 7.01112796d-07/
      data fpp( 5,21,1),fpp( 5,21,2)/-3.01880060d-04, 1.84581579d-06/
      data fpp( 5,22,1),fpp( 5,22,2)/-3.67562923d-05, 1.20182406d-06/
      data fpp( 5,23,1),fpp( 5,23,2)/ 0.00000000d+00, 1.06888797d-06/
      data fpp( 6, 1,1),fpp( 6, 1,2)/ 0.00000000d+00, 9.92033254d-04/
      data fpp( 6, 2,1),fpp( 6, 2,2)/ 2.26259119d-02,-2.93042909d-04/
      data fpp( 6, 3,1),fpp( 6, 3,2)/ 1.69819114d-01,-5.77912162d-03/
      data fpp( 6, 4,1),fpp( 6, 4,2)/ 1.50932164d+00, 3.43830859d-03/
      data fpp( 6, 5,1),fpp( 6, 5,2)/ 9.87127093d-01, 5.83346407d-03/
      data fpp( 6, 6,1),fpp( 6, 6,2)/ 1.50376272d+00, 1.95128712d-03/
      data fpp( 6, 7,1),fpp( 6, 7,2)/ 2.35885747d-01,-4.65033896d-03/
      data fpp( 6, 8,1),fpp( 6, 8,2)/ 8.13105639d-02,-3.19976070d-04/
      data fpp( 6, 9,1),fpp( 6, 9,2)/ 2.04815662d-02,-2.61051155d-04/
      data fpp( 6,10,1),fpp( 6,10,2)/-2.87170766d-03, 2.15970032d-06/
      data fpp( 6,11,1),fpp( 6,11,2)/ 5.52575321d-03, 1.70893538d-05/
      data fpp( 6,12,1),fpp( 6,12,2)/ 6.43237657d-03, 2.59832847d-05/
      data fpp( 6,13,1),fpp( 6,13,2)/ 2.46658311d-03, 1.44653076d-05/
      data fpp( 6,14,1),fpp( 6,14,2)/ 8.45489604d-04, 4.93448499d-06/
      data fpp( 6,15,1),fpp( 6,15,2)/ 2.40773013d-04,-8.69647541d-07/
      data fpp( 6,16,1),fpp( 6,16,2)/-6.63159864d-04,-2.88749482d-06/
      data fpp( 6,17,1),fpp( 6,17,2)/-1.52881215d-03,-2.42737316d-06/
      data fpp( 6,18,1),fpp( 6,18,2)/-1.82227470d-03,-1.57321252d-06/
      data fpp( 6,19,1),fpp( 6,19,2)/-1.42312200d-03,-5.31176756d-07/
      data fpp( 6,20,1),fpp( 6,20,2)/-7.21867597d-04, 7.64519543d-07/
      data fpp( 6,21,1),fpp( 6,21,2)/-1.89045551d-04, 1.81349858d-06/
      data fpp( 6,22,1),fpp( 6,22,2)/-1.93012596d-05, 1.14228612d-06/
      data fpp( 6,23,1),fpp( 6,23,2)/ 0.00000000d+00, 9.62556941d-07/
      data fpp( 7, 1,1),fpp( 7, 1,2)/ 0.00000000d+00, 1.21961306d-03/
      data fpp( 7, 2,1),fpp( 7, 2,2)/ 6.38026367d-03,-1.60878129d-04/
      data fpp( 7, 3,1),fpp( 7, 3,2)/ 2.23830566d-01,-7.16681255d-03/
      data fpp( 7, 4,1),fpp( 7, 4,2)/ 1.05094025d+00, 5.51630432d-03/
      data fpp( 7, 5,1),fpp( 7, 5,2)/ 1.41934413d-01, 4.62240325d-03/
      data fpp( 7, 6,1),fpp( 7, 6,2)/ 5.80197664d-01, 3.10906426d-03/
      data fpp( 7, 7,1),fpp( 7, 7,2)/ 2.33855413d-01,-5.54919870d-03/
      data fpp( 7, 8,1),fpp( 7, 8,2)/-4.37776770d-02,-2.16203862d-04/
      data fpp( 7, 9,1),fpp( 7, 9,2)/-1.96339542d-02,-2.83152253d-04/
      data fpp( 7,10,1),fpp( 7,10,2)/ 3.22006960d-03, 3.42468893d-05/
      data fpp( 7,11,1),fpp( 7,11,2)/ 5.56400703d-03, 1.42150956d-05/
      data fpp( 7,12,1),fpp( 7,12,2)/ 4.22138759d-03, 2.43639283d-05/
      data fpp( 7,13,1),fpp( 7,13,2)/ 1.44590199d-03, 9.81539107d-06/
      data fpp( 7,14,1),fpp( 7,14,2)/ 6.97954518d-04, 4.09350738d-06/
      data fpp( 7,15,1),fpp( 7,15,2)/ 5.74703037d-04,-2.76620595d-07/
      data fpp( 7,16,1),fpp( 7,16,2)/-1.48443129d-05,-2.32882500d-06/
      data fpp( 7,17,1),fpp( 7,17,2)/-6.36014889d-04,-2.40567940d-06/
      data fpp( 7,18,1),fpp( 7,18,2)/-8.32360500d-04,-1.68825741d-06/
      data fpp( 7,19,1),fpp( 7,19,2)/-5.94190402d-04,-5.25890971d-07/
      data fpp( 7,20,1),fpp( 7,20,2)/-2.27738586d-04, 8.08621291d-07/
      data fpp( 7,21,1),fpp( 7,21,2)/-4.84233172d-05, 1.63660581d-06/
      data fpp( 7,22,1),fpp( 7,22,2)/-2.18075149d-07, 9.87355484d-07/
      data fpp( 7,23,1),fpp( 7,23,2)/ 0.00000000d+00, 7.60172258d-07/
      data fpp( 8, 1,1),fpp( 8, 1,2)/ 0.00000000d+00, 1.10603530d-03/
      data fpp( 8, 2,1),fpp( 8, 2,2)/ 1.48290335d-02,-3.33276196d-04/
      data fpp( 8, 3,1),fpp( 8, 3,2)/ 9.92111209d-02,-5.33365372d-03/
      data fpp( 8, 4,1),fpp( 8, 4,2)/ 9.99043850d-01, 2.12969986d-03/
      data fpp( 8, 5,1),fpp( 8, 5,2)/ 1.73752726d+00, 7.70087988d-03/
      data fpp( 8, 6,1),fpp( 8, 6,2)/ 1.06750013d+00, 6.04325413d-04/
      data fpp( 8, 7,1),fpp( 8, 7,2)/ 2.62446017d-02,-4.55819273d-03/
      data fpp( 8, 8,1),fpp( 8, 8,2)/ 4.14546441d-02,-9.80120765d-05/
      data fpp( 8, 9,1),fpp( 8, 9,2)/-1.55357494d-02,-2.86952560d-04/
      data fpp( 8,10,1),fpp( 8,10,2)/ 1.50242927d-03, 5.52579178d-05/
      data fpp( 8,11,1),fpp( 8,11,2)/ 4.83571866d-03, 1.17468888d-05/
      data fpp( 8,12,1),fpp( 8,12,2)/ 2.89607306d-03, 2.11925271d-05/
      data fpp( 8,13,1),fpp( 8,13,2)/ 9.74808931d-04, 6.73340291d-06/
      data fpp( 8,14,1),fpp( 8,14,2)/ 5.83692323d-04, 3.32686129d-06/
      data fpp( 8,15,1),fpp( 8,15,2)/ 6.91414840d-04, 5.67519294d-08/
      data fpp( 8,16,1),fpp( 8,16,2)/ 5.18537115d-04,-1.78386901d-06/
      data fpp( 8,17,1),fpp( 8,17,2)/ 1.44371712d-04,-2.18527590d-06/
      data fpp( 8,18,1),fpp( 8,18,2)/-4.72833007d-05,-1.60282741d-06/
      data fpp( 8,19,1),fpp( 8,19,2)/-1.76163943d-05,-4.60414480d-07/
      data fpp( 8,20,1),fpp( 8,20,2)/ 5.48219397d-05, 7.54685324d-07/
      data fpp( 8,21,1),fpp( 8,21,2)/ 5.42388197d-05, 1.39567318d-06/
      data fpp( 8,22,1),fpp( 8,22,2)/ 6.67356016d-06, 8.12821948d-07/
      data fpp( 8,23,1),fpp( 8,23,2)/ 0.00000000d+00, 5.79639026d-07/
      data fpp( 9, 1,1),fpp( 9, 1,2)/ 0.00000000d+00, 4.28064365d-04/
      data fpp( 9, 2,1),fpp( 9, 2,2)/-2.17139750d-03,-5.02301930d-04/
      data fpp( 9, 3,1),fpp( 9, 3,2)/-2.98175496d-02,-2.20749905d-03/
      data fpp( 9, 4,1),fpp( 9, 4,2)/-6.59255652d-01,-1.20078829d-03/
      data fpp( 9, 5,1),fpp( 9, 5,2)/ 4.48996561d-01, 8.23177939d-03/
      data fpp( 9, 6,1),fpp( 9, 6,2)/-5.38979169d-01,-1.97902287d-03/
      data fpp( 9, 7,1),fpp( 9, 7,2)/-2.19378195d-02,-1.92837511d-03/
      data fpp( 9, 8,1),fpp( 9, 8,2)/-2.14778993d-02,-4.11673472d-04/
      data fpp( 9, 9,1),fpp( 9, 9,2)/ 2.88295162d-03,-1.43150196d-04/
      data fpp( 9,10,1),fpp( 9,10,2)/ 3.21871331d-03, 2.94901249d-05/
      data fpp( 9,11,1),fpp( 9,11,2)/ 4.18861831d-03, 1.89130966d-05/
      data fpp( 9,12,1),fpp( 9,12,2)/ 2.09082015d-03, 1.51238888d-05/
      data fpp( 9,13,1),fpp( 9,13,2)/ 6.72862288d-04, 5.33414808d-06/
      data fpp( 9,14,1),fpp( 9,14,2)/ 4.80276189d-04, 2.47591882d-06/
      data fpp( 9,15,1),fpp( 9,15,2)/ 6.99137605d-04, 2.57176618d-07/
      data fpp( 9,16,1),fpp( 9,16,2)/ 7.23195852d-04,-1.33622530d-06/
      data fpp( 9,17,1),fpp( 9,17,2)/ 5.59528043d-04,-1.85247543d-06/
      data fpp( 9,18,1),fpp( 9,18,2)/ 3.91493703d-04,-1.40947298d-06/
      data fpp( 9,19,1),fpp( 9,19,2)/ 2.98655979d-04,-3.81032655d-07/
      data fpp( 9,20,1),fpp( 9,20,2)/ 1.95950827d-04, 6.53003598d-07/
      data fpp( 9,21,1),fpp( 9,21,2)/ 8.64680382d-05, 1.13741826d-06/
      data fpp( 9,22,1),fpp( 9,22,2)/ 2.75238345d-05, 6.47923354d-07/
      data fpp( 9,23,1),fpp( 9,23,2)/ 0.00000000d+00, 4.36688323d-07/
      data fpp(10, 1,1),fpp(10, 1,2)/ 0.00000000d+00, 6.21355184d-07/
      data fpp(10, 2,1),fpp(10, 2,2)/-5.58994347d-03,-2.89197510d-04/
      data fpp(10, 3,1),fpp(10, 3,2)/-6.67174223d-02,-1.00100651d-03/
      data fpp(10, 4,1),fpp(10, 4,2)/-4.11810240d-01,-2.35850035d-04/
      data fpp(10, 5,1),fpp(10, 5,2)/-1.29227350d+00, 3.50710185d-03/
      data fpp(10, 6,1),fpp(10, 6,2)/-4.67381952d-01,-7.76397377d-04/
      data fpp(10, 7,1),fpp(10, 7,2)/-9.18668236d-02,-8.67733946d-04/
      data fpp(10, 8,1),fpp(10, 8,2)/-1.55325470d-02,-3.29068440d-04/
      data fpp(10, 9,1),fpp(10, 9,2)/-4.58505712d-03,-8.24106958d-05/
      data fpp(10,10,1),fpp(10,10,2)/ 3.89571750d-03, 2.44021071d-05/
      data fpp(10,11,1),fpp(10,11,2)/ 3.54680808d-03, 1.84238673d-05/
      data fpp(10,12,1),fpp(10,12,2)/ 1.53264633d-03, 1.13136236d-05/
      data fpp(10,13,1),fpp(10,13,2)/ 4.94741917d-04, 4.04243835d-06/
      data fpp(10,14,1),fpp(10,14,2)/ 3.93202921d-04, 1.88362303d-06/
      data fpp(10,15,1),fpp(10,15,2)/ 6.14534742d-04, 3.02469546d-07/
      data fpp(10,16,1),fpp(10,16,2)/ 7.82679479d-04,-9.71901209d-07/
      data fpp(10,17,1),fpp(10,17,2)/ 7.28516118d-04,-1.50106471d-06/
      data fpp(10,18,1),fpp(10,18,2)/ 6.00808488d-04,-1.17063995d-06/
      data fpp(10,19,1),fpp(10,19,2)/ 4.32492480d-04,-3.09575482d-07/
      data fpp(10,20,1),fpp(10,20,2)/ 2.65374753d-04, 5.39341882d-07/
      data fpp(10,21,1),fpp(10,21,2)/ 1.05389027d-04, 8.97807955d-07/
      data fpp(10,22,1),fpp(10,22,2)/-8.76889820d-06, 5.00826299d-07/
      data fpp(10,23,1),fpp(10,23,2)/ 0.00000000d+00, 3.19686851d-07/
      data fpp(11, 1,1),fpp(11, 1,2)/ 0.00000000d+00,-1.14128430d-04/
      data fpp(11, 2,1),fpp(11, 2,2)/-8.01282864d-03,-1.35781940d-04/
      data fpp(11, 3,1),fpp(11, 3,2)/-8.88787612d-02,-3.81216611d-04/
      data fpp(11, 4,1),fpp(11, 4,2)/-2.93969386d-01, 1.56582784d-04/
      data fpp(11, 5,1),fpp(11, 5,2)/-4.53672557d-01, 1.08570227d-03/
      data fpp(11, 6,1),fpp(11, 6,2)/-2.70805023d-01,-1.05959079d-04/
      data fpp(11, 7,1),fpp(11, 7,2)/-7.40843861d-02,-4.27438759d-04/
      data fpp(11, 8,1),fpp(11, 8,2)/-1.63084127d-02,-1.96491486d-04/
      data fpp(11, 9,1),fpp(11, 9,2)/-3.06223132d-04,-4.82848956d-05/
      data fpp(11,10,1),fpp(11,10,2)/ 4.34941669d-03, 2.24126299d-05/
      data fpp(11,11,1),fpp(11,11,2)/ 3.01564938d-03, 1.58845761d-05/
      data fpp(11,12,1),fpp(11,12,2)/ 1.16859454d-03, 8.50826588d-06/
      data fpp(11,13,1),fpp(11,13,2)/ 3.70670045d-04, 3.03476043d-06/
      data fpp(11,14,1),fpp(11,14,2)/ 3.06412127d-04, 1.43209238d-06/
      data fpp(11,15,1),fpp(11,15,2)/ 5.19223427d-04, 2.92670025d-07/
      data fpp(11,16,1),fpp(11,16,2)/ 6.86586234d-04,-7.09172486d-07/
      data fpp(11,17,1),fpp(11,17,2)/ 7.32407487d-04,-1.16758008d-06/
      data fpp(11,18,1),fpp(11,18,2)/ 6.20772344d-04,-9.40907188d-07/
      data fpp(11,19,1),fpp(11,19,2)/ 4.55374101d-04,-2.40191168d-07/
      data fpp(11,20,1),fpp(11,20,2)/ 2.51550160d-04, 4.25671859d-07/
      data fpp(11,21,1),fpp(11,21,2)/ 8.44758526d-05, 6.83703730d-07/
      data fpp(11,22,1),fpp(11,22,2)/ 2.85517583d-05, 3.89713220d-07/
      data fpp(11,23,1),fpp(11,23,2)/ 0.00000000d+00, 2.53443390d-07/
      data fpp(12, 1,1),fpp(12, 1,2)/ 0.00000000d+00,-1.97519366d-04/
      data fpp(12, 2,1),fpp(12, 2,2)/-5.10424199d-03,-9.34992672d-05/
      data fpp(12, 3,1),fpp(12, 3,2)/-4.65595329d-02, 3.84644351d-05/
      data fpp(12, 4,1),fpp(12, 4,2)/-1.74624715d-01, 7.26255269d-05/
      data fpp(12, 5,1),fpp(12, 5,2)/-2.81312769d-01, 2.38062257d-04/
      data fpp(12, 6,1),fpp(12, 6,2)/-1.45393957d-01, 5.50222437d-05/
      data fpp(12, 7,1),fpp(12, 7,2)/-4.75636321d-02,-2.14359232d-04/
      data fpp(12, 8,1),fpp(12, 8,2)/-9.03580235d-03,-1.08414116d-04/
      data fpp(12, 9,1),fpp(12, 9,2)/ 1.72694965d-03,-2.53403054d-05/
      data fpp(12,10,1),fpp(12,10,2)/ 4.39861573d-03, 1.95513742d-05/
      data fpp(12,11,1),fpp(12,11,2)/ 2.48659441d-03, 1.30652088d-05/
      data fpp(12,12,1),fpp(12,12,2)/ 8.72975507d-04, 6.32699053d-06/
      data fpp(12,13,1),fpp(12,13,2)/ 2.75577903d-04, 2.28642905d-06/
      data fpp(12,14,1),fpp(12,14,2)/ 2.33648571d-04, 1.08969328d-06/
      data fpp(12,15,1),fpp(12,15,2)/ 4.12071550d-04, 2.47597815d-07/
      data fpp(12,16,1),fpp(12,16,2)/ 5.95975584d-04,-5.06284545d-07/
      data fpp(12,17,1),fpp(12,17,2)/ 6.45353934d-04,-8.96659635d-07/
      data fpp(12,18,1),fpp(12,18,2)/ 5.82102135d-04,-7.27476915d-07/
      data fpp(12,19,1),fpp(12,19,2)/ 4.14511114d-04,-1.87032705d-07/
      data fpp(12,20,1),fpp(12,20,2)/ 2.25424606d-04, 3.23607735d-07/
      data fpp(12,21,1),fpp(12,21,2)/ 8.02075624d-05, 5.18601764d-07/
      data fpp(12,22,1),fpp(12,22,2)/ 5.56186500d-06, 2.95385210d-07/
      data fpp(12,23,1),fpp(12,23,2)/ 0.00000000d+00, 1.91657395d-07/
      data fpp(13, 1,1),fpp(13, 1,2)/ 0.00000000d+00,-2.37526552d-04/
      data fpp(13, 2,1),fpp(13, 2,2)/ 2.95402572d-03,-8.31864953d-05/
      data fpp(13, 3,1),fpp(13, 3,2)/ 3.07762838d-02, 2.73817334d-04/
      data fpp(13, 4,1),fpp(13, 4,2)/-2.96013582d-02,-7.85020393d-05/
      data fpp(13, 5,1),fpp(13, 5,2)/-4.36280645d-02,-6.14357650d-06/
      data fpp(13, 6,1),fpp(13, 6,2)/-4.21587945d-02, 1.90674530d-06/
      data fpp(13, 7,1),fpp(13, 7,2)/-1.52773022d-02,-7.59746047d-05/
      data fpp(13, 8,1),fpp(13, 8,2)/-2.78717073d-04,-4.46475265d-05/
      data fpp(13, 9,1),fpp(13, 9,2)/ 4.48098325d-03,-6.58888929d-06/
      data fpp(13,10,1),fpp(13,10,2)/ 3.93433643d-03, 1.44004311d-05/
      data fpp(13,11,1),fpp(13,11,2)/ 1.80658571d-03, 9.17016477d-06/
      data fpp(13,12,1),fpp(13,12,2)/ 5.92351950d-04, 3.98750979d-06/
      data fpp(13,13,1),fpp(13,13,2)/ 1.85960293d-04, 1.50539608d-06/
      data fpp(13,14,1),fpp(13,14,2)/ 1.61896677d-04, 7.28505903d-07/
      data fpp(13,15,1),fpp(13,15,2)/ 2.68279217d-04, 1.73580313d-07/
      data fpp(13,16,1),fpp(13,16,2)/ 4.05023896d-04,-3.12227153d-07/
      data fpp(13,17,1),fpp(13,17,2)/ 4.76215228d-04,-5.78271701d-07/
      data fpp(13,18,1),fpp(13,18,2)/ 4.28477986d-04,-4.84486043d-07/
      data fpp(13,19,1),fpp(13,19,2)/ 3.05380218d-04,-1.23784127d-07/
      data fpp(13,20,1),fpp(13,20,2)/ 1.58884539d-04, 2.05022549d-07/
      data fpp(13,21,1),fpp(13,21,2)/ 5.06575569d-05, 3.37493929d-07/
      data fpp(13,22,1),fpp(13,22,2)/ 1.04259445d-05, 1.92801735d-07/
      data fpp(13,23,1),fpp(13,23,2)/ 0.00000000d+00, 1.27299133d-07/
      data fpp(14, 1,1),fpp(14, 1,2)/ 0.00000000d+00,-3.78689588d-05/
      data fpp(14, 2,1),fpp(14, 2,2)/-2.42986089d-03,-1.04968247d-06/
      data fpp(14, 3,1),fpp(14, 3,2)/-3.76682688d-02, 9.13372887d-05/
      data fpp(14, 4,1),fpp(14, 4,2)/-1.70085184d-02,-1.07626722d-05/
      data fpp(14, 5,1),fpp(14, 5,2)/-1.55949729d-02,-3.28594000d-05/
      data fpp(14, 6,1),fpp(14, 6,2)/-8.54419839d-03,-2.32149277d-05/
      data fpp(14, 7,1),fpp(14, 7,2)/-4.06492589d-04,-3.43248893d-05/
      data fpp(14, 8,1),fpp(14, 8,2)/ 4.30267064d-03,-1.88807153d-05/
      data fpp(14, 9,1),fpp(14, 9,2)/ 5.11845068d-03,-5.13849529d-07/
      data fpp(14,10,1),fpp(14,10,2)/ 3.12137190d-03, 9.80650624d-06/
      data fpp(14,11,1),fpp(14,11,2)/ 1.26572942d-03, 6.03342457d-06/
      data fpp(14,12,1),fpp(14,12,2)/ 3.78283359d-04, 2.48639547d-06/
      data fpp(14,13,1),fpp(14,13,2)/ 1.25247592d-04, 1.00639355d-06/
      data fpp(14,14,1),fpp(14,14,2)/ 1.00764720d-04, 4.82830331d-07/
      data fpp(14,15,1),fpp(14,15,2)/ 1.82811583d-04, 1.19285126d-07/
      data fpp(14,16,1),fpp(14,16,2)/ 2.69262167d-04,-1.94370835d-07/
      data fpp(14,17,1),fpp(14,17,2)/ 3.13118487d-04,-3.70201785d-07/
      data fpp(14,18,1),fpp(14,18,2)/ 2.90652588d-04,-3.13222023d-07/
      data fpp(14,19,1),fpp(14,19,2)/ 2.07968013d-04,-8.27101208d-08/
      data fpp(14,20,1),fpp(14,20,2)/ 1.09037237d-04, 1.28662507d-07/
      data fpp(14,21,1),fpp(14,21,2)/ 4.58288767d-05, 2.19060094d-07/
      data fpp(14,22,1),fpp(14,22,2)/ 1.40102375d-06, 1.22497116d-07/
      data fpp(14,23,1),fpp(14,23,2)/ 0.00000000d+00, 7.93514421d-08/
      data fpp(15, 1,1),fpp(15, 1,2)/ 0.00000000d+00,-4.19421504d-06/
      data fpp(15, 2,1),fpp(15, 2,2)/-1.20673415d-03, 9.29963007d-06/
      data fpp(15, 3,1),fpp(15, 3,2)/-4.72581496d-04, 4.70692947d-05/
      data fpp(15, 4,1),fpp(15, 4,2)/-2.79837073d-03,-1.26409050d-07/
      data fpp(15, 5,1),fpp(15, 5,2)/-8.64038710d-04,-2.58732585d-05/
      data fpp(15, 6,1),fpp(15, 6,2)/ 1.69183612d-04,-2.37797568d-05/
      data fpp(15, 7,1),fpp(15, 7,2)/ 3.45591617d-03,-2.27965144d-05/
      data fpp(15, 8,1),fpp(15, 8,2)/ 5.07572242d-03,-1.15477857d-05/
      data fpp(15, 9,1),fpp(15, 9,2)/ 4.76377172d-03, 3.42857360d-07/
      data fpp(15,10,1),fpp(15,10,2)/ 2.55563588d-03, 7.31572079d-06/
      data fpp(15,11,1),fpp(15,11,2)/ 9.62974338d-04, 4.42865947d-06/
      data fpp(15,12,1),fpp(15,12,2)/ 2.99555280d-04, 1.82444133d-06/
      data fpp(15,13,1),fpp(15,13,2)/ 9.03216011d-05, 7.67375199d-07/
      data fpp(15,14,1),fpp(15,14,2)/ 8.28313841d-05, 3.72857872d-07/
      data fpp(15,15,1),fpp(15,15,2)/ 1.26523259d-04, 8.59933149d-08/
      data fpp(15,16,1),fpp(15,16,2)/ 2.03653324d-04,-1.40831131d-07/
      data fpp(15,17,1),fpp(15,17,2)/ 2.43084722d-04,-2.73868791d-07/
      data fpp(15,18,1),fpp(15,18,2)/ 2.24020081d-04,-2.31893707d-07/
      data fpp(15,19,1),fpp(15,19,2)/ 1.60089607d-04,-6.51563824d-08/
      data fpp(15,20,1),fpp(15,20,2)/ 8.64870069d-05, 9.95192365d-08/
      data fpp(15,21,1),fpp(15,21,2)/ 1.13692810d-05, 1.56679436d-07/
      data fpp(15,22,1),fpp(15,22,2)/ 4.85596452d-06, 9.33630182d-08/
      data fpp(15,23,1),fpp(15,23,2)/ 0.00000000d+00, 6.44684909d-08/
      data fpp(16, 1,1),fpp(16, 1,2)/ 0.00000000d+00, 3.87207429d-06/
      data fpp(16, 2,1),fpp(16, 2,2)/-4.95202530d-04, 9.43905142d-06/
      data fpp(16, 3,1),fpp(16, 3,2)/-2.46390519d-03, 2.68197200d-05/
      data fpp(16, 4,1),fpp(16, 4,2)/ 7.88001316d-04, 2.85246850d-06/
      data fpp(16, 5,1),fpp(16, 5,2)/ 2.88112776d-03,-1.76591940d-05/
      data fpp(16, 6,1),fpp(16, 6,2)/ 4.19396394d-03,-1.95948924d-05/
      data fpp(16, 7,1),fpp(16, 7,2)/ 5.09882791d-03,-1.59860362d-05/
      data fpp(16, 8,1),fpp(16, 8,2)/ 5.03893970d-03,-7.79056266d-06/
      data fpp(16, 9,1),fpp(16, 9,2)/ 4.12846242d-03, 2.66686849d-07/
      data fpp(16,10,1),fpp(16,10,2)/ 2.01458458d-03, 5.30802078d-06/
      data fpp(16,11,1),fpp(16,11,2)/ 7.45873228d-04, 3.20383003d-06/
      data fpp(16,12,1),fpp(16,12,2)/ 2.24995521d-04, 1.33285910d-06/
      data fpp(16,13,1),fpp(16,13,2)/ 8.19660039d-05, 5.98533560d-07/
      data fpp(16,14,1),fpp(16,14,2)/ 6.74097437d-05, 2.77406658d-07/
      data fpp(16,15,1),fpp(16,15,2)/ 1.01595382d-04, 6.84398074d-08/
      data fpp(16,16,1),fpp(16,16,2)/ 1.44624537d-04,-1.05965888d-07/
      data fpp(16,17,1),fpp(16,17,2)/ 1.74042624d-04,-2.01376257d-07/
      data fpp(16,18,1),fpp(16,18,2)/ 1.64767089d-04,-1.72129086d-07/
      data fpp(16,19,1),fpp(16,19,2)/ 1.19173558d-04,-4.79073996d-08/
      data fpp(16,20,1),fpp(16,20,2)/ 6.70147357d-05, 6.85586844d-08/
      data fpp(16,21,1),fpp(16,21,2)/ 3.76939992d-05, 1.22872662d-07/
      data fpp(16,22,1),fpp(16,22,2)/ 3.17511815d-06, 6.69506680d-08/
      data fpp(16,23,1),fpp(16,23,2)/ 0.00000000d+00, 4.25246660d-08/
      data fpp(17, 1,1),fpp(17, 1,2)/ 0.00000000d+00, 4.03680093d-06/
      data fpp(17, 2,1),fpp(17, 2,2)/ 2.18311977d-05, 6.08359814d-06/
      data fpp(17, 3,1),fpp(17, 3,2)/ 9.00738286d-04, 1.27000065d-05/
      data fpp(17, 4,1),fpp(17, 4,2)/ 2.37757610d-03, 3.32277582d-06/
      data fpp(17, 5,1),fpp(17, 5,2)/ 4.07693329d-03,-8.48070979d-06/
      data fpp(17, 6,1),fpp(17, 6,2)/ 4.71366446d-03,-1.21007366d-05/
      data fpp(17, 7,1),fpp(17, 7,2)/ 4.57829620d-03,-9.76194363d-06/
      data fpp(17, 8,1),fpp(17, 8,2)/ 3.88538607d-03,-4.98988883d-06/
      data fpp(17, 9,1),fpp(17, 9,2)/ 2.96094411d-03,-1.92101051d-07/
      data fpp(17,10,1),fpp(17,10,2)/ 1.35129414d-03, 3.13364757d-06/
      data fpp(17,11,1),fpp(17,11,2)/ 4.67106347d-04, 1.92011079d-06/
      data fpp(17,12,1),fpp(17,12,2)/ 1.38311410d-04, 8.45109293d-07/
      data fpp(17,13,1),fpp(17,13,2)/ 4.92322531d-05, 4.15052044d-07/
      data fpp(17,14,1),fpp(17,14,2)/ 2.67465982d-05, 1.71882530d-07/
      data fpp(17,15,1),fpp(17,15,2)/ 5.99998877d-05, 4.88178342d-08/
      data fpp(17,16,1),fpp(17,16,2)/ 9.81493259d-05,-6.71538673d-08/
      data fpp(17,17,1),fpp(17,17,2)/ 1.16801438d-04,-1.26402365d-07/
      data fpp(17,18,1),fpp(17,18,2)/ 1.07096315d-04,-1.10636672d-07/
      data fpp(17,19,1),fpp(17,19,2)/ 7.76950700d-05,-2.92509470d-08/
      data fpp(17,20,1),fpp(17,20,2)/ 3.62928766d-05, 4.28404600d-08/
      data fpp(17,21,1),fpp(17,21,2)/ 7.10714861d-06, 7.50891069d-08/
      data fpp(17,22,1),fpp(17,22,2)/ 4.51229648d-06, 4.44031123d-08/
      data fpp(17,23,1),fpp(17,23,2)/ 0.00000000d+00, 3.16984438d-08/
      data fpp(18, 1,1),fpp(18, 1,2)/ 0.00000000d+00, 2.23816636d-06/
      data fpp(18, 2,1),fpp(18, 2,2)/ 5.52110725d-05, 3.31846727d-06/
      data fpp(18, 3,1),fpp(18, 3,2)/ 4.16285377d-04, 6.32076455d-06/
      data fpp(18, 4,1),fpp(18, 4,2)/ 1.59702760d-03, 2.59607452d-06/
      data fpp(18, 5,1),fpp(18, 5,2)/ 2.68980575d-03,-3.53866262d-06/
      data fpp(18, 6,1),fpp(18, 6,2)/ 3.20137820d-03,-6.66702403d-06/
      data fpp(18, 7,1),fpp(18, 7,2)/ 3.07532063d-03,-5.94204126d-06/
      data fpp(18, 8,1),fpp(18, 8,2)/ 2.57618270d-03,-3.35681094d-06/
      data fpp(18, 9,1),fpp(18, 9,2)/ 1.94109447d-03,-4.61914988d-07/
      data fpp(18,10,1),fpp(18,10,2)/ 8.64905514d-04, 1.74835043d-06/
      data fpp(18,11,1),fpp(18,11,2)/ 3.13034716d-04, 1.13531326d-06/
      data fpp(18,12,1),fpp(18,12,2)/ 1.05092171d-04, 5.54596545d-07/
      data fpp(18,13,1),fpp(18,13,2)/ 3.71049837d-05, 2.72700565d-07/
      data fpp(18,14,1),fpp(18,14,2)/ 3.49371968d-05, 1.19201193d-07/
      data fpp(18,15,1),fpp(18,15,2)/ 4.10717338d-05, 2.86946607d-08/
      data fpp(18,16,1),fpp(18,16,2)/ 5.94448256d-05,-4.25798363d-08/
      data fpp(18,17,1),fpp(18,17,2)/ 7.27516249d-05,-8.09753156d-08/
      data fpp(18,18,1),fpp(18,18,2)/ 6.95143185d-05,-6.85189014d-08/
      data fpp(18,19,1),fpp(18,19,2)/ 5.13794960d-05,-2.05490789d-08/
      data fpp(18,20,1),fpp(18,20,2)/ 3.51470914d-05, 2.89152170d-08/
      data fpp(18,21,1),fpp(18,21,2)/ 1.18774064d-05, 4.82882108d-08/
      data fpp(18,22,1),fpp(18,22,2)/-1.22430407d-06, 2.63319398d-08/
      data fpp(18,23,1),fpp(18,23,2)/ 0.00000000d+00, 1.61840301d-08/
      data fpp(19, 1,1),fpp(19, 1,2)/ 0.00000000d+00, 1.37006796d-06/
      data fpp(19, 2,1),fpp(19, 2,2)/ 4.96978409d-05, 2.14826409d-06/
      data fpp(19, 3,1),fpp(19, 3,2)/ 4.16465685d-04, 4.05527569d-06/
      data fpp(19, 4,1),fpp(19, 4,2)/ 1.11449784d-03, 2.01143316d-06/
      data fpp(19, 5,1),fpp(19, 5,2)/ 1.90307130d-03,-1.85540832d-06/
      data fpp(19, 6,1),fpp(19, 6,2)/ 2.28261228d-03,-4.35299987d-06/
      data fpp(19, 7,1),fpp(19, 7,2)/ 2.22895253d-03,-4.19739218d-06/
      data fpp(19, 8,1),fpp(19, 8,2)/ 1.87800740d-03,-2.55023140d-06/
      data fpp(19, 9,1),fpp(19, 9,2)/ 1.42811149d-03,-5.12882207d-07/
      data fpp(19,10,1),fpp(19,10,2)/ 6.40031214d-04, 1.15536232d-06/
      data fpp(19,11,1),fpp(19,11,2)/ 2.27666901d-04, 7.95232915d-07/
      data fpp(19,12,1),fpp(19,12,2)/ 7.65720300d-05, 4.23506017d-07/
      data fpp(19,13,1),fpp(19,13,2)/ 2.46267017d-05, 2.07743017d-07/
      data fpp(19,14,1),fpp(19,14,2)/ 1.46941189d-05, 9.01219160d-08/
      data fpp(19,15,1),fpp(19,15,2)/ 3.06414994d-05, 2.15693191d-08/
      data fpp(19,16,1),fpp(19,16,2)/ 4.35518830d-05,-3.11991926d-08/
      data fpp(19,17,1),fpp(19,17,2)/ 5.20397187d-05,-6.05725488d-08/
      data fpp(19,18,1),fpp(19,18,2)/ 5.07839354d-05,-4.99106124d-08/
      data fpp(19,19,1),fpp(19,19,2)/ 3.60599153d-05,-1.39850016d-08/
      data fpp(19,20,1),fpp(19,20,2)/ 1.03252280d-05, 1.82506190d-08/
      data fpp(19,21,1),fpp(19,21,2)/ 8.95224531d-06, 3.81825257d-08/
      data fpp(19,22,1),fpp(19,22,2)/ 1.85307562d-06, 1.86192784d-08/
      data fpp(19,23,1),fpp(19,23,2)/ 0.00000000d+00, 1.03403608d-08/
      data fpp(20, 1,1),fpp(20, 1,2)/ 0.00000000d+00, 8.25997178d-07/
      data fpp(20, 2,1),fpp(20, 2,2)/ 3.39975640d-05, 1.39320564d-06/
      data fpp(20, 3,1),fpp(20, 3,2)/ 2.51851884d-04, 2.61798025d-06/
      data fpp(20, 4,1),fpp(20, 4,2)/ 7.26481051d-04, 1.54127336d-06/
      data fpp(20, 5,1),fpp(20, 5,2)/ 1.22840904d-03,-9.75873699d-07/
      data fpp(20, 6,1),fpp(20, 6,2)/ 1.54167268d-03,-2.78817857d-06/
      data fpp(20, 7,1),fpp(20, 7,2)/ 1.54636924d-03,-2.93861203d-06/
      data fpp(20, 8,1),fpp(20, 8,2)/ 1.33728770d-03,-1.89257330d-06/
      data fpp(20, 9,1),fpp(20, 9,2)/ 1.02095956d-03,-5.04694753d-07/
      data fpp(20,10,1),fpp(20,10,2)/ 4.70469631d-04, 7.48570910d-07/
      data fpp(20,11,1),fpp(20,11,2)/ 1.63797680d-04, 5.59611114d-07/
      data fpp(20,12,1),fpp(20,12,2)/ 5.51197093d-05, 3.23184636d-07/
      data fpp(20,13,1),fpp(20,13,2)/ 2.03882095d-05, 1.59450344d-07/
      data fpp(20,14,1),fpp(20,14,2)/ 1.57863276d-05, 6.92139899d-08/
      data fpp(20,15,1),fpp(20,15,2)/ 2.08622686d-05, 1.36936968d-08/
      data fpp(20,16,1),fpp(20,16,2)/ 3.48476422d-05,-2.13887771d-08/
      data fpp(20,17,1),fpp(20,17,2)/ 4.15895001d-05,-4.51385883d-08/
      data fpp(20,18,1),fpp(20,18,2)/ 3.78499397d-05,-3.62568698d-08/
      data fpp(20,19,1),fpp(20,19,2)/ 2.78808429d-05,-1.26339327d-08/
      data fpp(20,20,1),fpp(20,20,2)/ 2.10519966d-05, 1.77926005d-08/
      data fpp(20,21,1),fpp(20,21,2)/ 4.81361241d-06, 2.48635306d-08/
      data fpp(20,22,1),fpp(20,22,2)/ 2.81200159d-06, 1.41532770d-08/
      data fpp(20,23,1),fpp(20,23,2)/ 0.00000000d+00, 8.52336152d-09/
      data fpp(21, 1,1),fpp(21, 1,2)/ 0.00000000d+00, 4.07549251d-07/
      data fpp(21, 2,1),fpp(21, 2,2)/ 1.65428929d-05, 7.44101498d-07/
      data fpp(21, 3,1),fpp(21, 3,2)/ 1.16183262d-04, 1.39684476d-06/
      data fpp(21, 4,1),fpp(21, 4,2)/ 3.41731271d-04, 9.42919479d-07/
      data fpp(21, 5,1),fpp(21, 5,2)/ 6.10589012d-04,-3.18122672d-07/
      data fpp(21, 6,1),fpp(21, 6,2)/ 7.99016224d-04,-1.43682879d-06/
      data fpp(21, 7,1),fpp(21, 7,2)/ 8.42467501d-04,-1.66976217d-06/
      data fpp(21, 8,1),fpp(21, 8,2)/ 7.48036073d-04,-1.20812253d-06/
      data fpp(21, 9,1),fpp(21, 9,2)/ 5.91727145d-04,-4.12147709d-07/
      data fpp(21,10,1),fpp(21,10,2)/ 2.73080419d-04, 3.56704393d-07/
      data fpp(21,11,1),fpp(21,11,2)/ 1.10229800d-04, 3.49730139d-07/
      data fpp(21,12,1),fpp(21,12,2)/ 3.78862824d-05, 2.12375053d-07/
      data fpp(21,13,1),fpp(21,13,2)/ 1.29548338d-05, 1.08769651d-07/
      data fpp(21,14,1),fpp(21,14,2)/ 7.58282875d-06, 4.43463438d-08/
      data fpp(21,15,1),fpp(21,15,2)/ 1.30314384d-05, 8.44497408d-09/
      data fpp(21,16,1),fpp(21,16,2)/ 1.98066038d-05,-1.33262401d-08/
      data fpp(21,17,1),fpp(21,17,2)/ 2.36751873d-05,-2.89400138d-08/
      data fpp(21,18,1),fpp(21,18,2)/ 2.29775773d-05,-2.27137047d-08/
      data fpp(21,19,1),fpp(21,19,2)/ 1.70239133d-05,-7.40516754d-09/
      data fpp(21,20,1),fpp(21,20,2)/ 7.60985949d-06, 1.09343748d-08/
      data fpp(21,21,1),fpp(21,21,2)/ 2.31979508d-06, 1.64676683d-08/
      data fpp(21,22,1),fpp(21,22,2)/-2.27538904d-06, 7.19495191d-09/
      data fpp(21,23,1),fpp(21,23,2)/ 0.00000000d+00, 2.15252405d-09/
      data fpp(22, 1,1),fpp(22, 1,2)/ 0.00000000d+00, 1.12301678d-07/
      data fpp(22, 2,1),fpp(22, 2,2)/ 2.98420447d-06, 2.63796644d-07/
      data fpp(22, 3,1),fpp(22, 3,2)/ 3.26224303d-05, 5.82111746d-07/
      data fpp(22, 4,1),fpp(22, 4,2)/ 9.07313009d-05, 3.16556372d-07/
      data fpp(22, 5,1),fpp(22, 5,2)/ 1.90029739d-04, 3.56627655d-08/
      data fpp(22, 6,1),fpp(22, 6,2)/ 2.71584478d-04,-4.68807434d-07/
      data fpp(22, 7,1),fpp(22, 7,2)/ 3.03642451d-04,-6.61233029d-07/
      data fpp(22, 8,1),fpp(22, 8,2)/ 2.87351947d-04,-5.36660449d-07/
      data fpp(22, 9,1),fpp(22, 9,2)/ 2.32057400d-04,-2.88125174d-07/
      data fpp(22,10,1),fpp(22,10,2)/ 1.19700879d-04, 9.95057463d-08/
      data fpp(22,11,1),fpp(22,11,2)/ 4.81860321d-05, 1.60702189d-07/
      data fpp(22,12,1),fpp(22,12,2)/ 1.80920708d-05, 1.13285498d-07/
      data fpp(22,13,1),fpp(22,13,2)/ 5.51160627d-06, 5.51558172d-08/
      data fpp(22,14,1),fpp(22,14,2)/ 3.46315145d-06, 2.18912326d-08/
      data fpp(22,15,1),fpp(22,15,2)/ 5.30203605d-06, 3.67925236d-09/
      data fpp(22,16,1),fpp(22,16,2)/ 8.59028245d-06,-7.20824204d-09/
      data fpp(22,17,1),fpp(22,17,2)/ 1.11257007d-05,-1.26462842d-08/
      data fpp(22,18,1),fpp(22,18,2)/ 1.03217888d-05,-1.06066211d-08/
      data fpp(22,19,1),fpp(22,19,2)/ 7.27497157d-06,-3.12723136d-09/
      data fpp(22,20,1),fpp(22,20,2)/ 4.13725169d-06, 4.51554655d-09/
      data fpp(22,21,1),fpp(22,21,2)/ 1.60848828d-06, 7.26504516d-09/
      data fpp(22,22,1),fpp(22,22,2)/ 1.43404398d-06, 4.22427281d-09/
      data fpp(22,23,1),fpp(22,23,2)/ 0.00000000d+00, 2.83786359d-09/
      data fpp(23, 1,1),fpp(23, 1,2)/ 0.00000000d+00, 4.39892946d-08/
      data fpp(23, 2,1),fpp(23, 2,2)/ 2.24028926d-06, 1.10021411d-07/
      data fpp(23, 3,1),fpp(23, 3,2)/ 1.32470167d-05, 2.19125062d-07/
      data fpp(23, 4,1),fpp(23, 4,2)/ 4.65435249d-05, 1.77478341d-07/
      data fpp(23, 5,1),fpp(23, 5,2)/ 7.76920303d-05, 4.77615728d-08/
      data fpp(23, 6,1),fpp(23, 6,2)/ 1.06645863d-04,-1.57324633d-07/
      data fpp(23, 7,1),fpp(23, 7,2)/ 1.20242695d-04,-2.68063043d-07/
      data fpp(23, 8,1),fpp(23, 8,2)/ 1.12316139d-04,-2.75223197d-07/
      data fpp(23, 9,1),fpp(23, 9,2)/ 9.57232552d-05,-1.74244168d-07/
      data fpp(23,10,1),fpp(23,10,2)/ 5.42760651d-05, 2.43441022d-08/
      data fpp(23,11,1),fpp(23,11,2)/ 2.53460715d-05, 8.28677590d-08/
      data fpp(23,12,1),fpp(23,12,2)/ 9.02543431d-06, 5.93848619d-08/
      data fpp(23,13,1),fpp(23,13,2)/ 2.91874118d-06, 2.87927934d-08/
      data fpp(23,14,1),fpp(23,14,2)/ 1.12456545d-06, 1.02439644d-08/
      data fpp(23,15,1),fpp(23,15,2)/ 2.24041743d-06, 1.63134911d-09/
      data fpp(23,16,1),fpp(23,16,2)/ 3.91226639d-06,-3.56936080d-09/
      data fpp(23,17,1),fpp(23,17,2)/ 4.78201000d-06,-5.95390590d-09/
      data fpp(23,18,1),fpp(23,18,2)/ 4.61526767d-06,-5.01501559d-09/
      data fpp(23,19,1),fpp(23,19,2)/ 3.55620040d-06,-9.86031734d-10/
      data fpp(23,20,1),fpp(23,20,2)/ 1.76113375d-06, 1.75914253d-09/
      data fpp(23,21,1),fpp(23,21,2)/ 6.06251780d-07, 3.54946163d-09/
      data fpp(23,22,1),fpp(23,22,2)/-1.00786869d-07, 2.04301096d-09/
      data fpp(23,23,1),fpp(23,23,2)/ 0.00000000d+00, 1.47849452d-09/
      data fpp(24, 1,1),fpp(24, 1,2)/ 0.00000000d+00, 6.98625702d-09/
      data fpp(24, 2,1),fpp(24, 2,2)/ 5.34638482d-07, 4.68274860d-08/
      data fpp(24, 3,1),fpp(24, 3,2)/ 4.86950291d-06, 1.17703799d-07/
      data fpp(24, 4,1),fpp(24, 4,2)/ 9.41459942d-06, 7.99573174d-08/
      data fpp(24, 5,1),fpp(24, 5,2)/ 2.16821395d-05, 3.52669313d-08/
      data fpp(24, 6,1),fpp(24, 6,2)/ 3.31120699d-05,-6.26250427d-08/
      data fpp(24, 7,1),fpp(24, 7,2)/ 4.02667699d-05,-1.35166761d-07/
      data fpp(24, 8,1),fpp(24, 8,2)/ 4.36234979d-05,-1.38307915d-07/
      data fpp(24, 9,1),fpp(24, 9,2)/ 4.12095793d-05,-9.64015791d-08/
      data fpp(24,10,1),fpp(24,10,2)/ 2.58348608d-05, 6.15869488d-09/
      data fpp(24,11,1),fpp(24,11,2)/ 1.24296820d-05, 4.53667996d-08/
      data fpp(24,12,1),fpp(24,12,2)/ 4.84619193d-06, 3.13741067d-08/
      data fpp(24,13,1),fpp(24,13,2)/ 1.05342902d-06, 1.39367735d-08/
      data fpp(24,14,1),fpp(24,14,2)/ 9.18586733d-07, 5.27879919d-09/
      data fpp(24,15,1),fpp(24,15,2)/ 1.09629423d-06, 9.48029728d-10/
      data fpp(24,16,1),fpp(24,16,2)/ 1.68065198d-06,-1.87091810d-09/
      data fpp(24,17,1),fpp(24,17,2)/ 2.14625932d-06,-3.06435733d-09/
      data fpp(24,18,1),fpp(24,18,2)/ 2.17714057d-06,-2.07165259d-09/
      data fpp(24,19,1),fpp(24,19,2)/ 1.54022683d-06,-6.49032317d-10/
      data fpp(24,20,1),fpp(24,20,2)/ 8.18213294d-07, 1.06778186d-09/
      data fpp(24,21,1),fpp(24,21,2)/ 2.86504598d-07, 1.77790488d-09/
      data fpp(24,22,1),fpp(24,22,2)/-7.08965019d-08, 8.20598604d-10/
      data fpp(24,23,1),fpp(24,23,2)/ 0.00000000d+00, 3.39700698d-10/
      data fpp(25, 1,1),fpp(25, 1,2)/ 0.00000000d+00, 8.11034504d-09/
      data fpp(25, 2,1),fpp(25, 2,2)/-5.88431883d-08, 2.65793099d-08/
      data fpp(25, 3,1),fpp(25, 3,2)/ 8.74971651d-07, 5.59724153d-08/
      data fpp(25, 4,1),fpp(25, 4,2)/ 5.31807739d-06, 4.71310288d-08/
      data fpp(25, 5,1),fpp(25, 5,2)/ 9.81941172d-06, 1.23034693d-08/
      data fpp(25, 6,1),fpp(25, 6,2)/ 1.57858575d-05,-3.15449061d-08/
      data fpp(25, 7,1),fpp(25, 7,2)/ 2.08502258d-05,-7.09238449d-08/
      data fpp(25, 8,1),fpp(25, 8,2)/ 2.25498695d-05,-6.39597144d-08/
      data fpp(25, 9,1),fpp(25, 9,2)/ 2.02384275d-05,-5.72372976d-08/
      data fpp(25,10,1),fpp(25,10,2)/ 1.42244916d-05, 5.69175009d-09/
      data fpp(25,11,1),fpp(25,11,2)/ 7.25520058d-06, 2.42702973d-08/
      data fpp(25,12,1),fpp(25,12,2)/ 2.30979798d-06, 1.48270608d-08/
      data fpp(25,13,1),fpp(25,13,2)/ 5.47542739d-07, 8.22145962d-09/
      data fpp(25,14,1),fpp(25,14,2)/-4.78912385d-07, 1.48710076d-09/
      data fpp(25,15,1),fpp(25,15,2)/ 3.34405650d-07, 1.43013734d-09/
      data fpp(25,16,1),fpp(25,16,2)/ 8.85125688d-07,-1.20765013d-09/
      data fpp(25,17,1),fpp(25,17,2)/ 1.03295273d-06,-1.39953683d-09/
      data fpp(25,18,1),fpp(25,18,2)/ 8.36170058d-07,-9.94202568d-10/
      data fpp(25,19,1),fpp(25,19,2)/ 6.02892279d-07,-6.23652903d-10/
      data fpp(25,20,1),fpp(25,20,2)/ 4.86013068d-07, 1.08881418d-09/
      data fpp(25,21,1),fpp(25,21,2)/ 1.67729830d-07, 4.68396182d-10/
      data fpp(25,22,1),fpp(25,22,2)/ 1.44372876d-07, 6.37601091d-10/
      data fpp(25,23,1),fpp(25,23,2)/ 0.00000000d+00, 5.81199455d-10/
      data fpp(26, 1,1),fpp(26, 1,2)/ 0.00000000d+00, 1.14402434d-08/
      data fpp(26, 2,1),fpp(26, 2,2)/ 1.80734272d-07, 1.75195132d-08/
      data fpp(26, 3,1),fpp(26, 3,2)/ 5.10610485d-07, 2.64817039d-08/
      data fpp(26, 4,1),fpp(26, 4,2)/ 1.71309101d-06, 2.53536711d-08/
      data fpp(26, 5,1),fpp(26, 5,2)/ 4.08021363d-06, 4.10361151d-09/
      data fpp(26, 6,1),fpp(26, 6,2)/ 6.70449993d-06,-1.77681172d-08/
      data fpp(26, 7,1),fpp(26, 7,2)/ 8.81232682d-06,-3.62311427d-08/
      data fpp(26, 8,1),fpp(26, 8,2)/ 9.93702404d-06,-3.65073118d-08/
      data fpp(26, 9,1),fpp(26, 9,2)/ 1.03167107d-05,-2.65396099d-08/
      data fpp(26,10,1),fpp(26,10,2)/ 7.02717259d-06, 3.67248567d-09/
      data fpp(26,11,1),fpp(26,11,2)/ 2.94951568d-06, 1.12496672d-08/
      data fpp(26,12,1),fpp(26,12,2)/ 7.94616162d-07, 7.12884543d-09/
      data fpp(26,13,1),fpp(26,13,2)/ 1.16400022d-07, 4.03495105d-09/
      data fpp(26,14,1),fpp(26,14,2)/ 5.17062808d-07, 1.93135038d-09/
      data fpp(26,15,1),fpp(26,15,2)/ 2.06083170d-07, 8.39647422d-10/
      data fpp(26,16,1),fpp(26,16,2)/ 2.98845268d-07,-1.08994007d-09/
      data fpp(26,17,1),fpp(26,17,2)/ 4.41929760d-07,-6.79887141d-10/
      data fpp(26,18,1),fpp(26,18,2)/ 4.78179200d-07,-3.90511366d-10/
      data fpp(26,19,1),fpp(26,19,2)/ 3.68204054d-07,-1.58067397d-10/
      data fpp(26,20,1),fpp(26,20,2)/ 1.17734435d-07, 4.22780952d-10/
      data fpp(26,21,1),fpp(26,21,2)/ 2.57608403d-09, 2.66943590d-10/
      data fpp(26,22,1),fpp(26,22,2)/-2.65950035d-08, 3.09444689d-10/
      data fpp(26,23,1),fpp(26,23,2)/ 0.00000000d+00, 2.95277656d-10/
      data fpp(27, 1,1),fpp(27, 1,2)/ 0.00000000d+00, 3.32481065d-09/
      data fpp(27, 2,1),fpp(27, 2,2)/ 2.72187796d-08, 4.95037870d-09/
      data fpp(27, 3,1),fpp(27, 3,2)/ 3.10682718d-07, 8.07367454d-09/
      data fpp(27, 4,1),fpp(27, 4,2)/ 1.02168828d-06, 5.95492314d-09/
      data fpp(27, 5,1),fpp(27, 5,2)/ 1.98965325d-06, 1.70663291d-09/
      data fpp(27, 6,1),fpp(27, 6,2)/ 3.07357145d-06,-5.58145480d-09/
      data fpp(27, 7,1),fpp(27, 7,2)/ 3.93790662d-06,-8.18081373d-09/
      data fpp(27, 8,1),fpp(27, 8,2)/ 4.21399313d-06,-9.69529027d-09/
      data fpp(27, 9,1),fpp(27, 9,2)/ 3.87065408d-06,-5.83802519d-09/
      data fpp(27,10,1),fpp(27,10,2)/ 2.34623640d-06,-1.03827930d-09/
      data fpp(27,11,1),fpp(27,11,2)/ 9.63852662d-07, 1.59114240d-09/
      data fpp(27,12,1),fpp(27,12,2)/ 3.01252525d-07, 1.87370971d-09/
      data fpp(27,13,1),fpp(27,13,2)/ 9.70285652d-08, 3.51401874d-09/
      data fpp(27,14,1),fpp(27,14,2)/-5.17322308d-08,-2.12978469d-09/
      data fpp(27,15,1),fpp(27,15,2)/ 1.74547666d-07, 3.20512002d-09/
      data fpp(27,16,1),fpp(27,16,2)/ 1.60901352d-07,-1.69069539d-09/
      data fpp(27,17,1),fpp(27,17,2)/ 1.37734354d-07,-4.23384627d-11/
      data fpp(27,18,1),fpp(27,18,2)/ 1.27377371d-07, 6.00492402d-11/
      data fpp(27,19,1),fpp(27,19,2)/ 9.39416989d-08,-1.97858498d-10/
      data fpp(27,20,1),fpp(27,20,2)/ 6.37901615d-08, 1.31384752d-10/
      data fpp(27,21,1),fpp(27,21,2)/ 8.84068331d-08, 2.72319490d-10/
      data fpp(27,22,1),fpp(27,22,2)/ 7.59857244d-09,-2.06627114d-11/
      data fpp(27,23,1),fpp(27,23,2)/ 0.00000000d+00,-1.89668644d-10/
      data fpp(28, 1,1),fpp(28, 1,2)/ 0.00000000d+00,-2.97540851d-10/
      data fpp(28, 2,1),fpp(28, 2,2)/-4.96093898d-08, 9.95081702d-10/
      data fpp(28, 3,1),fpp(28, 3,2)/ 4.66586408d-08, 3.51721404d-09/
      data fpp(28, 4,1),fpp(28, 4,2)/-4.59844142d-07, 1.73606212d-09/
      data fpp(28, 5,1),fpp(28, 5,2)/-1.23882662d-06, 1.53853746d-09/
      data fpp(28, 6,1),fpp(28, 6,2)/-2.31878572d-06,-6.90211957d-10/
      data fpp(28, 7,1),fpp(28, 7,2)/-3.26395331d-06,-3.57768963d-09/
      data fpp(28, 8,1),fpp(28, 8,2)/-3.87299657d-06,-1.79902952d-09/
      data fpp(28, 9,1),fpp(28, 9,2)/-4.19932704d-06,-3.62619229d-09/
      data fpp(28,10,1),fpp(28,10,2)/-3.51211820d-06,-1.42190837d-09/
      data fpp(28,11,1),fpp(28,11,2)/-1.82492633d-06, 9.13825778d-10/
      data fpp(28,12,1),fpp(28,12,2)/-4.99626263d-07, 7.66605258d-10/
      data fpp(28,13,1),fpp(28,13,2)/-2.45142826d-08, 2.01975319d-09/
      data fpp(28,14,1),fpp(28,14,2)/-3.10133885d-07,-1.04561801d-09/
      data fpp(28,15,1),fpp(28,15,2)/ 1.15726167d-07, 9.62718852d-10/
      data fpp(28,16,1),fpp(28,16,2)/-1.02450676d-07,-1.00525740d-09/
      data fpp(28,17,1),fpp(28,17,2)/-2.72867177d-07, 6.58310739d-10/
      data fpp(28,18,1),fpp(28,18,2)/-2.67688686d-07, 1.72014443d-10/
      data fpp(28,19,1),fpp(28,19,2)/-2.03970849d-07,-7.46368511d-10/
      data fpp(28,20,1),fpp(28,20,2)/-7.28950807d-08, 1.61345960d-09/
      data fpp(28,21,1),fpp(28,21,2)/ 1.23796583d-07,-2.10746989d-09/
      data fpp(28,22,1),fpp(28,22,2)/-3.79928622d-09, 8.16419969d-10/
      data fpp(28,23,1),fpp(28,23,2)/ 0.00000000d+00, 1.84179002d-09/
 
      data fpppp( 1, 1),fpppp( 1, 2)/ 9.88530180d-03,-3.35217507d-04/
      data fpppp( 1, 3),fpppp( 1, 4)/-2.71466656d-02, 4.11013699d-03/
      data fpppp( 1, 5),fpppp( 1, 6)/ 6.03519249d-02,-4.11331321d-02/
      data fpppp( 1, 7),fpppp( 1, 8)/ 1.95497985d-02,-2.00775829d-02/
      data fpppp( 1, 9),fpppp( 1,10)/ 4.07310494d-04, 2.21540790d-03/
      data fpppp( 1,11),fpppp( 1,12)/-5.00967175d-04,-2.85452927d-04/
      data fpppp( 1,13),fpppp( 1,14)/-2.25536849d-04, 1.56111698d-04/
      data fpppp( 1,15),fpppp( 1,16)/-4.43381838d-05, 6.20279790d-05/
      data fpppp( 1,17),fpppp( 1,18)/-1.61317343d-05, 2.82898107d-05/
      data fpppp( 1,19),fpppp( 1,20)/ 7.34931027d-07, 8.33448150d-06/
      data fpppp( 1,21),fpppp( 1,22)/-2.38104649d-05,-3.62415581d-06/
      data fpppp( 1,23) /             1.61036602d-06 /
      data fpppp( 2, 1),fpppp( 2, 2)/ 1.05270289d-02, 1.20285001d-03/
      data fpppp( 2, 3),fpppp( 2, 4)/-2.85214814d-02, 1.31547209d-02/
      data fpppp( 2, 5),fpppp( 2, 6)/ 3.53400230d-02,-1.23491020d-02/
      data fpppp( 2, 7),fpppp( 2, 8)/-4.23216452d-03,-7.62551794d-03/
      data fpppp( 2, 9),fpppp( 2,10)/ 9.80411600d-05, 1.35697960d-03/
      data fpppp( 2,11),fpppp( 2,12)/-4.38309354d-04,-1.39974723d-04/
      data fpppp( 2,13),fpppp( 2,14)/-1.39800290d-04, 1.10153132d-04/
      data fpppp( 2,15),fpppp( 2,16)/-2.89557604d-05, 3.72560254d-05/
      data fpppp( 2,17),fpppp( 2,18)/-1.73233657d-06, 1.36716158d-05/
      data fpppp( 2,19),fpppp( 2,20)/ 8.92099428d-06, 2.49637447d-06/
      data fpppp( 2,21),fpppp( 2,22)/-1.72312764d-05,-3.78820089d-06/
      data fpppp( 2,23) /             1.77524211d-07 /
      data fpppp( 3, 1),fpppp( 3, 2)/ 1.28475666d-02,-7.48423041d-03/
      data fpppp( 3, 3),fpppp( 3, 4)/ 6.50507862d-03,-9.96294833d-02/
      data fpppp( 3, 5),fpppp( 3, 6)/ 1.90834466d-01,-8.69820087d-02/
      data fpppp( 3, 7),fpppp( 3, 8)/-1.19740671d-02, 2.80515033d-03/
      data fpppp( 3, 9),fpppp( 3,10)/ 8.23082867d-03,-7.67898555d-03/
      data fpppp( 3,11),fpppp( 3,12)/ 3.36445786d-03,-7.85481978d-04/
      data fpppp( 3,13),fpppp( 3,14)/ 1.97339933d-04,-6.77812455d-06/
      data fpppp( 3,15),fpppp( 3,16)/ 4.89489013d-06,-6.41284248d-06/
      data fpppp( 3,17),fpppp( 3,18)/ 4.55704636d-05,-3.02530443d-05/
      data fpppp( 3,19),fpppp( 3,20)/ 2.96987900d-05,-8.27400156d-06/
      data fpppp( 3,21),fpppp( 3,22)/-7.08603904d-06,-5.26258081d-06/
      data fpppp( 3,23) /            -3.62069278d-06 /
      data fpppp( 4, 1),fpppp( 4, 2)/ 9.29226725d-03, 1.96167069d-02/
      data fpppp( 4, 3),fpppp( 4, 4)/-8.58731766d-02, 2.13987071d-01/
      data fpppp( 4, 5),fpppp( 4, 6)/-2.85443299d-01, 2.00344363d-01/
      data fpppp( 4, 7),fpppp( 4, 8)/-7.58561813d-02, 2.03107069d-02/
      data fpppp( 4, 9),fpppp( 4,10)/-1.31835828d-02, 1.19064283d-02/
      data fpppp( 4,11),fpppp( 4,12)/-5.92315780d-03, 1.33745987d-03/
      data fpppp( 4,13),fpppp( 4,14)/-3.45432670d-04, 1.24695036d-04/
      data fpppp( 4,15),fpppp( 4,16)/-2.58932540d-05, 1.60574897d-05/
      data fpppp( 4,17),fpppp( 4,18)/-2.22886449d-05, 2.83949242d-05/
      data fpppp( 4,19),fpppp( 4,20)/ 6.40552208d-06,-1.78143612d-06/
      data fpppp( 4,21),fpppp( 4,22)/-9.42197229d-06,-2.15078880d-06/
      data fpppp( 4,23) /             8.59903364d-07 /
      data fpppp( 5, 1),fpppp( 5, 2)/ 6.28258394d-03, 2.39044837d-02/
      data fpppp( 5, 3),fpppp( 5, 4)/-8.95301556d-02, 2.55733092d-01/
      data fpppp( 5, 5),fpppp( 5, 6)/-3.52542579d-01, 2.09827655d-01/
      data fpppp( 5, 7),fpppp( 5, 8)/-6.58542187d-02, 2.38721661d-02/
      data fpppp( 5, 9),fpppp( 5,10)/-2.63422684d-04,-2.23470417d-03/
      data fpppp( 5,11),fpppp( 5,12)/ 1.33856522d-03,-4.68268396d-04/
      data fpppp( 5,13),fpppp( 5,14)/ 1.62282356d-04,-2.26575862d-05/
      data fpppp( 5,15),fpppp( 5,16)/ 3.36877954d-06, 9.55834858d-07/
      data fpppp( 5,17),fpppp( 5,18)/ 3.88165724d-06, 1.13102314d-05/
      data fpppp( 5,19),fpppp( 5,20)/ 6.87404508d-06,-6.17683137d-06/
      data fpppp( 5,21),fpppp( 5,22)/-3.83468557d-06,-2.32323150d-06/
      data fpppp( 5,23) /            -5.74436930d-07 /
      data fpppp( 6, 1),fpppp( 6, 2)/-2.73479179d-02,-1.57754519d-02/
      data fpppp( 6, 3),fpppp( 6, 4)/ 1.20345875d-01,-1.79453811d-01/
      data fpppp( 6, 5),fpppp( 6, 6)/ 1.50662073d-01,-1.73875241d-01/
      data fpppp( 6, 7),fpppp( 6, 8)/ 1.16555866d-01,-2.51557931d-02/
      data fpppp( 6, 9),fpppp( 6,10)/ 6.56639128d-03,-1.22299398d-03/
      data fpppp( 6,11),fpppp( 6,12)/ 2.30628709d-04,-1.48971107d-04/
      data fpppp( 6,13),fpppp( 6,14)/ 7.29107111d-05,-1.98974021d-06/
      data fpppp( 6,15),fpppp( 6,16)/-3.96913518d-06,-8.66961620d-08/
      data fpppp( 6,17),fpppp( 6,18)/ 6.61275499d-06, 7.96706101d-06/
      data fpppp( 6,19),fpppp( 6,20)/ 3.07591544d-06,-2.14462049d-06/
      data fpppp( 6,21),fpppp( 6,22)/-4.60337485d-06,-1.22654537d-06/
      data fpppp( 6,23) /             4.82974436d-07 /
      data fpppp( 7, 1),fpppp( 7, 2)/ 1.81655539d-04,-6.92205404d-03/
      data fpppp( 7, 3),fpppp( 7, 4)/ 7.81633700d-02,-1.59413174d-01/
      data fpppp( 7, 5),fpppp( 7, 6)/ 1.42821598d-01,-8.85286357d-02/
      data fpppp( 7, 7),fpppp( 7, 8)/ 2.29876244d-02, 1.30683365d-02/
      data fpppp( 7, 9),fpppp( 7,10)/-2.83453561d-03, 4.43433252d-04/
      data fpppp( 7,11),fpppp( 7,12)/-1.69802579d-04, 1.45836517d-05/
      data fpppp( 7,13),fpppp( 7,14)/ 2.54960025d-05, 5.08462604d-06/
      data fpppp( 7,15),fpppp( 7,16)/-8.35274732d-06, 3.48611110d-07/
      data fpppp( 7,17),fpppp( 7,18)/ 5.06090927d-06, 4.89724971d-06/
      data fpppp( 7,19),fpppp( 7,20)/ 1.42103446d-06,-2.88448455d-06/
      data fpppp( 7,21),fpppp( 7,22)/-1.11128912d-06,-5.36960568d-07/
      data fpppp( 7,23) /             3.79901376d-07 /
      data fpppp( 8, 1),fpppp( 8, 2)/-2.45523408d-02,-2.22075892d-03/
      data fpppp( 8, 3),fpppp( 8, 4)/ 5.01281094d-02,-2.58352486d-03/
      data fpppp( 8, 5),fpppp( 8, 6)/-7.85178473d-02,-2.13876148d-02/
      data fpppp( 8, 7),fpppp( 8, 8)/ 7.49734919d-02,-2.49546166d-02/
      data fpppp( 8, 9),fpppp( 8,10)/ 7.51686977d-03,-2.21216311d-03/
      data fpppp( 8,11),fpppp( 8,12)/ 5.09489312d-04,-1.42170239d-04/
      data fpppp( 8,13),fpppp( 8,14)/ 6.02945317d-05,-7.19903635d-06/
      data fpppp( 8,15),fpppp( 8,16)/-1.56803890d-06,-3.36482249d-06/
      data fpppp( 8,17),fpppp( 8,18)/ 2.95006809d-06, 2.51517359d-06/
      data fpppp( 8,19),fpppp( 8,20)/ 2.68552661d-07,-1.02309858d-06/
      data fpppp( 8,21),fpppp( 8,22)/-5.57445566d-07, 4.33952471d-07/
      data fpppp( 8,23) /             1.27513765d-06 /
      data fpppp( 9, 1),fpppp( 9, 2)/ 1.33687328d-02, 1.63109396d-02/
      data fpppp( 9, 3),fpppp( 9, 4)/-8.47264322d-02, 1.78164721d-01/
      data fpppp( 9, 5),fpppp( 9, 6)/-2.10886777d-01, 1.62287680d-01/
      data fpppp( 9, 7),fpppp( 9, 8)/-7.70598438d-02, 2.19721525d-02/
      data fpppp( 9, 9),fpppp( 9,10)/-5.09254288d-03, 1.38839599d-03/
      data fpppp( 9,11),fpppp( 9,12)/-4.22992485d-04, 1.19511758d-04/
      data fpppp( 9,13),fpppp( 9,14)/-1.42641288d-05, 1.10670630d-05/
      data fpppp( 9,15),fpppp( 9,16)/-5.31727242d-06,-1.48616347d-06/
      data fpppp( 9,17),fpppp( 9,18)/-1.63703111d-09, 1.23071975d-06/
      data fpppp( 9,19),fpppp( 9,20)/-4.09445087d-07,-1.84985042d-07/
      data fpppp( 9,21),fpppp( 9,22)/ 7.42727052d-07, 2.46391920d-07/
      data fpppp( 9,23) /             1.56927423d-07 /
      data fpppp(10, 1),fpppp(10, 2)/ 8.65659825d-03,-5.70347643d-03/
      data fpppp(10, 3),fpppp(10, 4)/ 8.28298977d-04,-6.57614009d-02/
      data fpppp(10, 5),fpppp(10, 6)/ 1.33728398d-01,-5.98670388d-02/
      data fpppp(10, 7),fpppp(10, 8)/-2.11058411d-03,-3.49402925d-03/
      data fpppp(10, 9),fpppp(10,10)/ 3.93872307d-04,-2.39454607d-04/
      data fpppp(10,11),fpppp(10,12)/ 3.41650784d-05, 2.87915385d-06/
      data fpppp(10,13),fpppp(10,14)/ 1.28937466d-05, 1.72778449d-06/
      data fpppp(10,15),fpppp(10,16)/-4.32635597d-07,-3.18846718d-06/
      data fpppp(10,17),fpppp(10,18)/-1.51981541d-07,-6.16262761d-07/
      data fpppp(10,19),fpppp(10,20)/ 1.80529855d-07,-3.39597692d-08/
      data fpppp(10,21),fpppp(10,22)/ 3.83229266d-07, 1.25071073d-06/
      data fpppp(10,23) /             1.98953722d-06 /
      data fpppp(11, 1),fpppp(11, 2)/-1.09114212d-03,-2.45036117d-03/
      data fpppp(11, 3),fpppp(11, 4)/-6.59215816d-03,-9.94932353d-04/
      data fpppp(11, 5),fpppp(11, 6)/ 2.14648764d-02,-2.64760374d-03/
      data fpppp(11, 7),fpppp(11, 8)/-7.54971700d-03,-5.00247437d-04/
      data fpppp(11, 9),fpppp(11,10)/-4.75001386d-04, 3.42035228d-05/
      data fpppp(11,11),fpppp(11,12)/-2.11771334d-05, 1.97077595d-05/
      data fpppp(11,13),fpppp(11,14)/ 5.29391568d-06, 3.13657245d-06/
      data fpppp(11,15),fpppp(11,16)/-1.21605238d-06,-9.99272521d-07/
      data fpppp(11,17),fpppp(11,18)/-2.07935080d-06,-1.30708041d-07/
      data fpppp(11,19),fpppp(11,20)/-6.23603019d-07, 3.19578199d-07/
      data fpppp(11,21),fpppp(11,22)/ 1.55026825d-06, 1.48361613d-07/
      data fpppp(11,23) /            -5.01374540d-07 /
      data fpppp(12, 1),fpppp(12, 2)/ 4.11797587d-04,-1.16501364d-03/
      data fpppp(12, 3),fpppp(12, 4)/-4.47599479d-03,-1.71738119d-03/
      data fpppp(12, 5),fpppp(12, 6)/ 1.64760304d-02,-5.96109258d-03/
      data fpppp(12, 7),fpppp(12, 8)/-1.77289698d-03,-1.17991835d-03/
      data fpppp(12, 9),fpppp(12,10)/-1.71048281d-04,-2.81262558d-05/
      data fpppp(12,11),fpppp(12,12)/ 8.53205962d-06, 1.19021623d-05/
      data fpppp(12,13),fpppp(12,14)/ 4.83256927d-06, 2.09565692d-06/
      data fpppp(12,15),fpppp(12,16)/ 5.94163973d-09,-1.79056006d-06/
      data fpppp(12,17),fpppp(12,18)/-9.15242504d-07,-1.30627883d-06/
      data fpppp(12,19),fpppp(12,20)/-1.19995528d-07, 4.96531729d-07/
      data fpppp(12,21),fpppp(12,22)/ 7.66036468d-07, 6.73603180d-07/
      data fpppp(12,23) /             6.84580757d-07 /
      data fpppp(13, 1),fpppp(13, 2)/ 5.02671735d-03, 1.97620377d-03/
      data fpppp(13, 3),fpppp(13, 4)/-6.96315666d-03, 4.70844686d-03/
      data fpppp(13, 5),fpppp(13, 6)/-7.46406212d-04, 1.99621229d-03/
      data fpppp(13, 7),fpppp(13, 8)/-1.13950959d-03,-2.90071670d-04/
      data fpppp(13, 9),fpppp(13,10)/-1.57536074d-04, 1.36812076d-05/
      data fpppp(13,11),fpppp(13,12)/ 7.94500977d-06, 9.34977083d-06/
      data fpppp(13,13),fpppp(13,14)/ 3.12643295d-06, 1.08417985d-06/
      data fpppp(13,15),fpppp(13,16)/ 3.63616971d-07,-7.16919392d-07/
      data fpppp(13,17),fpppp(13,18)/-1.42914018d-06,-7.02234349d-07/
      data fpppp(13,19),fpppp(13,20)/-2.83553943d-07, 4.32575443d-07/
      data fpppp(13,21),fpppp(13,22)/ 8.49373967d-07, 2.49650889d-07/
      data fpppp(13,23) /            -5.96374460d-08 /
      data fpppp(14, 1),fpppp(14, 2)/-4.54101503d-03,-1.95153203d-03/
      data fpppp(14, 3),fpppp(14, 4)/ 4.47309186d-03,-2.52527738d-03/
      data fpppp(14, 5),fpppp(14, 6)/ 1.00892848d-03,-1.57501544d-04/
      data fpppp(14, 7),fpppp(14, 8)/-1.18058794d-04,-1.93113497d-04/
      data fpppp(14, 9),fpppp(14,10)/-4.38991837d-05, 1.05359675d-05/
      data fpppp(14,11),fpppp(14,12)/ 1.02414920d-05, 6.58984932d-06/
      data fpppp(14,13),fpppp(14,14)/ 1.46372833d-06, 1.26841106d-06/
      data fpppp(14,15),fpppp(14,16)/-1.45588463d-07,-4.21833995d-07/
      data fpppp(14,17),fpppp(14,18)/-7.22731315d-07,-6.66573925d-07/
      data fpppp(14,19),fpppp(14,20)/-2.24093548d-07, 5.88176047d-07/
      data fpppp(14,21),fpppp(14,22)/ 1.47343261d-08, 4.79717077d-07/
      data fpppp(14,23) /             6.48007121d-07 /
      data fpppp(15, 1),fpppp(15, 2)/ 2.50451304d-04, 1.32070102d-04/
      data fpppp(15, 3),fpppp(15, 4)/-3.12918880d-04, 3.85219366d-04/
      data fpppp(15, 5),fpppp(15, 6)/-2.05529479d-04, 2.20632224d-04/
      data fpppp(15, 7),fpppp(15, 8)/-1.36156960d-04,-7.60666976d-05/
      data fpppp(15, 9),fpppp(15,10)/-2.31979140d-05, 1.25730232d-05/
      data fpppp(15,11),fpppp(15,12)/ 9.83427932d-06, 3.84440861d-06/
      data fpppp(15,13),fpppp(15,14)/ 2.03920899d-06, 1.03363168d-07/
      data fpppp(15,15),fpppp(15,16)/ 6.18263841d-07,-5.70127094d-07/
      data fpppp(15,17),fpppp(15,18)/-5.99675494d-07,-5.40933309d-07/
      data fpppp(15,19),fpppp(15,20)/ 7.14588265d-08,-3.25229631d-07/
      data fpppp(15,21),fpppp(15,22)/ 1.13855217d-06,-1.12714503d-07/
      data fpppp(15,23) /            -5.88253043d-07 /
      data fpppp(16, 1),fpppp(16, 2)/-3.02058351d-04,-1.08232055d-04/
      data fpppp(16, 3),fpppp(16, 4)/ 3.81346542d-04,-1.64207914d-04/
      data fpppp(16, 5),fpppp(16, 6)/-2.62210238d-06,-1.25733384d-05/
      data fpppp(16, 7),fpppp(16, 8)/-4.49978755d-05,-3.89756824d-05/
      data fpppp(16, 9),fpppp(16,10)/-3.24077036d-06, 1.16347548d-05/
      data fpppp(16,11),fpppp(16,12)/ 7.41174046d-06, 3.58830211d-06/
      data fpppp(16,13),fpppp(16,14)/ 9.05942531d-07, 4.96323181d-07/
      data fpppp(16,15),fpppp(16,16)/ 3.32786472d-08,-9.88267331d-08/
      data fpppp(16,17),fpppp(16,18)/-4.54635834d-07,-4.04247227d-07/
      data fpppp(16,19),fpppp(16,20)/-1.07455086d-07, 4.40150173d-07/
      data fpppp(16,21),fpppp(16,22)/-2.82860479d-07, 3.79403067d-07/
      data fpppp(16,23) /             6.45873985d-07 /
      data fpppp(17, 1),fpppp(17, 2)/ 4.42464787d-05, 3.50877622d-05/
      data fpppp(17, 3),fpppp(17, 4)/ 2.11006863d-05, 2.40128681d-05/
      data fpppp(17, 5),fpppp(17, 6)/-6.37475107d-05,-2.40530680d-05/
      data fpppp(17, 7),fpppp(17, 8)/-2.53440830d-05,-8.38064759d-06/
      data fpppp(17, 9),fpppp(17,10)/ 3.29903500d-06, 8.64725553d-06/
      data fpppp(17,11),fpppp(17,12)/ 5.63967326d-06, 2.11762294d-06/
      data fpppp(17,13),fpppp(17,14)/ 2.72781777d-07, 7.86860100d-07/
      data fpppp(17,15),fpppp(17,16)/-7.58855110d-08,-1.89549137d-07/
      data fpppp(17,17),fpppp(17,18)/-3.35757526d-07,-1.68854850d-07/
      data fpppp(17,19),fpppp(17,20)/-1.70590374d-07, 1.31159427d-07/
      data fpppp(17,21),fpppp(17,22)/ 3.78940594d-07,-5.14692538d-08/
      data fpppp(17,23) /            -2.88110240d-07 /
      data fpppp(18, 1),fpppp(18, 2)/-5.81831054d-06, 7.23583404d-06/
      data fpppp(18, 3),fpppp(18, 4)/ 5.02821502d-05,-1.16441341d-05/
      data fpppp(18, 5),fpppp(18, 6)/-2.48169913d-05,-2.85772684d-05/
      data fpppp(18, 7),fpppp(18, 8)/-1.39051407d-05,-5.34145625d-06/
      data fpppp(18, 9),fpppp(18,10)/ 2.64289451d-06, 6.38129516d-06/
      data fpppp(18,11),fpppp(18,12)/ 3.29101412d-06, 1.09034363d-06/
      data fpppp(18,13),fpppp(18,14)/ 7.44932808d-07,-1.20910851d-07/
      data fpppp(18,15),fpppp(18,16)/ 2.36850039d-07,-9.21760186d-08/
      data fpppp(18,17),fpppp(18,18)/-1.72123515d-07,-2.11976267d-07/
      data fpppp(18,19),fpppp(18,20)/ 1.26177617d-07,-1.78589119d-07/
      data fpppp(18,21),fpppp(18,22)/ 1.65942026d-07, 1.24899494d-07/
      data fpppp(18,23) /             1.94020869d-07 /
      data fpppp(19, 1),fpppp(19, 2)/ 1.23705298d-05, 1.21717963d-05/
      data fpppp(19, 3),fpppp(19, 4)/ 1.50390858d-05, 7.17529476d-06/
      data fpppp(19, 5),fpppp(19, 6)/-2.20103495d-05,-1.73016942d-05/
      data fpppp(19, 7),fpppp(19, 8)/-1.27510478d-05,-3.04260614d-06/
      data fpppp(19, 9),fpppp(19,10)/ 1.17328580d-06, 4.70413771d-06/
      data fpppp(19,11),fpppp(19,12)/ 2.55312142d-06, 7.59543072d-07/
      data fpppp(19,13),fpppp(19,14)/ 3.57678868d-07, 3.30506185d-07/
      data fpppp(19,15),fpppp(19,16)/-1.26905812d-07,-5.10274729d-09/
      data fpppp(19,17),fpppp(19,18)/-1.18036074d-07,-1.07370098d-07/
      data fpppp(19,19),fpppp(19,20)/-2.60577744d-07, 4.89041050d-07/
      data fpppp(19,21),fpppp(19,22)/-2.33884182d-07, 1.02924458d-07/
      data fpppp(19,23) /             1.36951992d-07 /
      data fpppp(20, 1),fpppp(20, 2)/ 4.94033620d-06, 6.34869119d-06/
      data fpppp(20, 3),fpppp(20, 4)/ 1.37905206d-05, 1.15189535d-07/
      data fpppp(20, 5),fpppp(20, 6)/-7.69956249d-06,-1.45963820d-05/
      data fpppp(20, 7),fpppp(20, 8)/-7.97100760d-06,-4.82633461d-06/
      data fpppp(20, 9),fpppp(20,10)/ 1.53716335d-06, 2.73165851d-06/
      data fpppp(20,11),fpppp(20,12)/ 2.16528109d-06, 4.86856024d-07/
      data fpppp(20,13),fpppp(20,14)/ 3.24083060d-07, 2.45888060d-08/
      data fpppp(20,15),fpppp(20,16)/ 1.58231094d-07,-1.22947225d-07/
      data fpppp(20,17),fpppp(20,18)/-1.01053144d-07,-1.01725289d-07/
      data fpppp(20,19),fpppp(20,20)/ 1.34182115d-07,-2.46588150d-07/
      data fpppp(20,21),fpppp(20,22)/ 2.87598220d-07,-4.95983326d-08/
      data fpppp(20,23) /            -1.37828336d-07 /
      data fpppp(21, 1),fpppp(21, 2)/ 1.79574200d-06, 2.95540010d-06/
      data fpppp(21, 3),fpppp(21, 4)/ 6.32605193d-06, 1.95822571d-06/
      data fpppp(21, 5),fpppp(21, 6)/-3.76461915d-06,-6.20307621d-06/
      data fpppp(21, 7),fpppp(21, 8)/-6.21730019d-06,-2.01957222d-06/
      data fpppp(21, 9),fpppp(21,10)/-5.55010940d-07, 2.31308669d-06/
      data fpppp(21,11),fpppp(21,12)/ 6.50430570d-07, 5.15617137d-07/
      data fpppp(21,13),fpppp(21,14)/ 1.31825021d-07, 1.30649394d-07/
      data fpppp(21,15),fpppp(21,16)/-5.18572101d-09,-3.03131610d-08/
      data fpppp(21,17),fpppp(21,18)/-4.79565539d-08,-5.18322284d-08/
      data fpppp(21,19),fpppp(21,20)/-6.00777744d-08, 8.45199345d-08/
      data fpppp(21,21),fpppp(21,22)/-3.05625980d-08, 7.94232748d-08/
      data fpppp(21,23) /             1.25103889d-07 /
      data fpppp(22, 1),fpppp(22, 2)/ 9.41399218d-07, 1.17035424d-06/
      data fpppp(22, 3),fpppp(22, 4)/ 7.74148938d-07, 2.56600477d-06/
      data fpppp(22, 5),fpppp(22, 6)/-1.15267177d-06,-2.21380555d-06/
      data fpppp(22, 7),fpppp(22, 8)/-1.87132994d-06,-1.90450913d-06/
      data fpppp(22, 9),fpppp(22,10)/ 1.28396104d-07, 4.61020656d-07/
      data fpppp(22,11),fpppp(22,12)/ 4.78021725d-07, 1.12145571d-07/
      data fpppp(22,13),fpppp(22,14)/ 1.24205795d-07, 2.29518328d-08/
      data fpppp(22,15),fpppp(22,16)/ 1.72272388d-08,-4.89907997d-09/
      data fpppp(22,17),fpppp(22,18)/-4.28006088d-08,-2.42582943d-08/
      data fpppp(22,19),fpppp(22,20)/ 5.25947071d-09,-2.23375003d-09/
      data fpppp(22,21),fpppp(22,22)/ 4.02129179d-08,-1.73587758d-08/
      data fpppp(22,23) /            -4.63537948d-08 /
      data fpppp(23, 1),fpppp(23, 2)/-1.14894333d-07, 1.99893842d-07/
      data fpppp(23, 3),fpppp(23, 4)/ 1.41926413d-06,-5.27402978d-07/
      data fpppp(23, 5),fpppp(23, 6)/ 1.74827103d-07,-6.98626887d-07/
      data fpppp(23, 7),fpppp(23, 8)/-1.06599976d-06,-2.02987170d-07/
      data fpppp(23, 9),fpppp(23,10)/-2.01970179d-07, 2.11718740d-07/
      data fpppp(23,11),fpppp(23,12)/ 1.06127012d-07, 1.20334598d-07/
      data fpppp(23,13),fpppp(23,14)/ 2.53712354d-08, 3.69315043d-08/
      data fpppp(23,15),fpppp(23,16)/ 1.50440929d-09,-9.58932223d-09/
      data fpppp(23,17),fpppp(23,18)/-1.12734417d-08,-7.50606724d-09/
      data fpppp(23,19),fpppp(23,20)/-1.22417856d-08, 1.23132471d-08/
      data fpppp(23,21),fpppp(23,22)/ 1.39987749d-09, 8.95784254d-09/
      data fpppp(23,23) /             1.12382834d-08 /
      data fpppp(24, 1),fpppp(24, 2)/ 2.69602417d-07, 2.04021790d-07/
      data fpppp(24, 3),fpppp(24, 4)/-1.73635348d-07, 5.40975304d-07/
      data fpppp(24, 5),fpppp(24, 6)/-1.36879412d-07,-1.94483983d-07/
      data fpppp(24, 7),fpppp(24, 8)/-1.11239952d-07,-2.72069462d-07/
      data fpppp(24, 9),fpppp(24,10)/-1.85437404d-07, 5.95340668d-08/
      data fpppp(24,11),fpppp(24,12)/ 6.54735177d-08, 2.78731888d-08/
      data fpppp(24,13),fpppp(24,14)/ 5.04773562d-08,-1.03073765d-08/
      data fpppp(24,15),fpppp(24,16)/ 9.50513688d-09,-3.31415588d-09/
      data fpppp(24,17),fpppp(24,18)/-3.37353808d-09,-9.27525700d-09/
      data fpppp(24,19),fpppp(24,20)/ 4.06866757d-10, 2.54180212d-09/
      data fpppp(24,21),fpppp(24,22)/ 8.44215073d-10, 4.53979341d-09/
      data fpppp(24,23) /             6.69446736d-09 /
      data fpppp(25, 1),fpppp(25, 2)/-4.84643193d-08, 1.47169720d-08/
      data fpppp(25, 3),fpppp(25, 4)/ 2.27834358d-07,-8.38245875d-08/
      data fpppp(25, 5),fpppp(25, 6)/ 1.21438852d-07,-5.03040594d-08/
      data fpppp(25, 7),fpppp(25, 8)/-1.36721226d-07,-2.10344941d-07/
      data fpppp(25, 9),fpppp(25,10)/ 1.54404227d-08,-2.46119056d-08/
      data fpppp(25,11),fpppp(25,12)/ 2.56858863d-08, 4.33016680d-08/
      data fpppp(25,13),fpppp(25,14)/-7.90371621d-09, 3.24612037d-08/
      data fpppp(25,15),fpppp(25,16)/-1.15547089d-08,-1.99824777d-09/
      data fpppp(25,17),fpppp(25,18)/-4.62587971d-09,-1.74816306d-10/
      data fpppp(25,19),fpppp(25,20)/ 3.13543855d-09,-5.38302384d-09/
      data fpppp(25,21),fpppp(25,22)/ 6.31241521d-09,-2.17105991d-09/
      data fpppp(25,23) /            -4.88913097d-09 /
      data fpppp(26, 1),fpppp(26, 2)/-2.28056907d-08, 5.63142533d-09/
      data fpppp(26, 3),fpppp(26, 4)/ 3.60740556d-08, 5.94973862d-08/
      data fpppp(26, 5),fpppp(26, 6)/ 5.45050446d-09,-1.95801233d-08/
      data fpppp(26, 7),fpppp(26, 8)/-5.10802671d-08,-1.20499308d-08/
      data fpppp(26, 9),fpppp(26,10)/-7.95225367d-08, 1.65788474d-09/
      data fpppp(26,11),fpppp(26,12)/ 2.56038712d-08, 1.12920737d-08/
      data fpppp(26,13),fpppp(26,14)/ 1.78288367d-08,-1.78746851d-08/
      data fpppp(26,15),fpppp(26,16)/ 1.09713580d-08,-1.78624293d-09/
      data fpppp(26,17),fpppp(26,18)/-8.07042699d-10,-1.39568942d-09/
      data fpppp(26,19),fpppp(26,20)/-2.38367475d-09, 2.50072003d-09/
      data fpppp(26,21),fpppp(26,22)/ 4.99470721d-10, 6.60632886d-10/
      data fpppp(26,23) /             2.03963202d-10 /
      data fpppp(27, 1),fpppp(27, 2)/ 3.99785477d-09, 9.04999221d-09/
      data fpppp(27, 3),fpppp(27, 4)/ 2.13010146d-08, 8.35593964d-09/
      data fpppp(27, 5),fpppp(27, 6)/ 6.94548261d-09,-8.30909314d-09/
      data fpppp(27, 7),fpppp(27, 8)/-2.64090370d-08,-2.72344381d-08/
      data fpppp(27, 9),fpppp(27,10)/-1.33153456d-08, 3.29888169d-09/
      data fpppp(27,11),fpppp(27,12)/ 8.64185495d-09, 5.32071469d-09/
      data fpppp(27,13),fpppp(27,14)/-2.42214307d-09, 7.69564741d-09/
      data fpppp(27,15),fpppp(27,16)/-5.85800502d-09, 1.34080004d-09/
      data fpppp(27,17),fpppp(27,18)/-7.64361945d-11,-2.66454367d-10/
      data fpppp(27,19),fpppp(27,20)/-2.42467727d-10, 1.43337338d-09/
      data fpppp(27,21),fpppp(27,22)/-2.20493326d-09, 1.06086372d-09/
      data fpppp(27,23) /             2.35405967d-09 /
      data fpppp(28, 1),fpppp(28, 2)/ 3.37727593d-08, 9.85163059d-09/
      data fpppp(28, 3),fpppp(28, 4)/-3.81687007d-08,-1.84182278d-09/
      data fpppp(28, 5),fpppp(28, 6)/-1.98591360d-08, 9.04397846d-09/
      data fpppp(28, 7),fpppp(28, 8)/ 1.60331857d-08, 7.49311848d-09/
      data fpppp(28, 9),fpppp(28,10)/ 2.18454080d-08, 1.11094039d-08/
      data fpppp(28,11),fpppp(28,12)/-6.28404179d-09,-7.68674488d-09/
      data fpppp(28,13),fpppp(28,14)/-1.39802640d-08, 1.79639059d-08/
      data fpppp(28,15),fpppp(28,16)/-1.51865806d-08, 4.14020262d-09/
      data fpppp(28,17),fpppp(28,18)/ 1.49139062d-09, 4.29934473d-10/
      data fpppp(28,19),fpppp(28,20)/ 3.01232187d-10, 2.40661273d-09/
      data fpppp(28,21),fpppp(28,22)/-5.99072937d-09, 2.09905271d-09/
      data fpppp(28,23) /             5.47822788d-09 /
 
      c(1,1)=fpppp(ix+1,iy+1)
      c(1,2)=fpppp(ix+1,iy  )
      c(2,1)=fpppp(ix  ,iy+1)
      c(2,2)=fpppp(ix,  iy  )
      c(1,3)=fpp(ix+1,iy+1,1)
      c(1,4)=fpp(ix+1,iy  ,1)
      c(2,3)=fpp(ix,  iy+1,1)
      c(2,4)=fpp(ix,  iy,  1)
      c(3,1)=fpp(ix+1,iy+1,2)
      c(3,2)=fpp(ix+1,iy  ,2)
      c(4,1)=fpp(ix,  iy+1,2)
      c(4,2)=fpp(ix,  iy,  2)
      c(3,3)=f(ix+1,iy+1)
      c(3,4)=f(ix+1,iy  )
      c(4,3)=f(ix,  iy+1)
      c(4,4)=f(ix,  iy  )
      px(1)=((xi-xix)**3/(6.0*delxi))-(xi-xix)*delxi/6.0
      px(2)=(xi-xixp1)*delxi/6.0-((xi-xixp1)**3/(6.0*delxi))
      px(3)=(xi-xix)/delxi
      px(4)=(xixp1-xi)/delxi
      py(1)=((yi-yiy)**3/(6.0*delyi))-(yi-yiy)*delyi/6.0
      py(2)=(yi-yiyp1)*delyi/6.0-((yi-yiyp1)**3/(6.0*delyi))
      py(3)=(yi-yiy)/delyi
      py(4)=(yiyp1-yi)/delyi

      fi=0.0d 00
      do l=1,4
        sum=0.0d 00
        do i=1,4
          sum=sum + c(i,l) * px(i)
        enddo
        fi = fi + sum * py(l)
      enddo
      return
      end  
      subroutine c4_spl(xi,yi,ix,iy,delxi,delyi,xix,xixp1,
     x                    yiy,yiyp1,fi)
      implicit real*8 (a-h,o-z)
      dimension fpp(28,23,2),f(28,23),fpppp(28,23)
      dimension c(4,4),px(4),py(4)
 
      data f( 2, 1),f( 2, 2) /  0.00000000d+00 ,  3.48650000d-04 /
      data f( 2, 3),f( 2, 4) /  5.67745000d-03 ,  2.51333400d-02 /
      data f( 2, 5),f( 2, 6) /  4.33848000d-02 ,  3.08095500d-02 /
      data f( 2, 7),f( 2, 8) /  1.10939700d-02 ,  2.91587000d-03 /
      data f( 2, 9),f( 2,10) /  7.33420000d-04 ,  2.11715000d-03 /
      data f( 2,11),f( 2,12) /  3.43175000d-03 ,  2.83070000d-03 /
      data f( 2,13),f( 2,14) /  1.53353000d-03 ,  1.76090000d-04 /
      data f( 2,15),f( 2,16) / -7.14920000d-04 , -3.28990000d-04 /
      data f( 2,17),f( 2,18) /  4.28370000d-04 ,  1.51120000d-04 /
      data f( 2,19),f( 2,20) / -3.57500000d-04 , -3.09120000d-04 /
      data f( 2,21),f( 2,22) / -8.96900000d-05 , -6.51000000d-06 /
      data f( 2,23) /           0.00000000d+00 /
      data f( 3, 1),f( 3, 2) /  0.00000000d+00 ,  4.74190000d-04 /
      data f( 3, 3),f( 3, 4) /  8.02361000d-03 ,  3.83125900d-02 /
      data f( 3, 5),f( 3, 6) /  6.97639300d-02 ,  4.58199900d-02 /
      data f( 3, 7),f( 3, 8) /  1.57242500d-02 ,  3.51856000d-03 /
      data f( 3, 9),f( 3,10) /  5.98690000d-04 ,  1.82502000d-03 /
      data f( 3,11),f( 3,12) /  2.93375000d-03 ,  2.45734000d-03 /
      data f( 3,13),f( 3,14) /  1.38031000d-03 ,  2.02360000d-04 /
      data f( 3,15),f( 3,16) / -7.80940000d-04 , -8.31530000d-04 /
      data f( 3,17),f( 3,18) / -4.15370000d-04 , -4.62710000d-04 /
      data f( 3,19),f( 3,20) / -5.65840000d-04 , -3.33450000d-04 /
      data f( 3,21),f( 3,22) / -8.73900000d-05 , -6.08000000d-06 /
      data f( 3,23) /           0.00000000d+00 /
      data f( 4, 1),f( 4, 2) /  0.00000000d+00 ,  6.08770000d-04 /
      data f( 4, 3),f( 4, 4) /  1.07228200d-02 ,  5.62666900d-02 /
      data f( 4, 5),f( 4, 6) /  1.05461090d-01 ,  6.50805800d-02 /
      data f( 4, 7),f( 4, 8) /  2.05029300d-02 ,  4.27572000d-03 /
      data f( 4, 9),f( 4,10) /  8.04810000d-04 ,  1.85070000d-03 /
      data f( 4,11),f( 4,12) /  2.53938000d-03 ,  2.10458000d-03 /
      data f( 4,13),f( 4,14) /  1.23654000d-03 ,  2.24210000d-04 /
      data f( 4,15),f( 4,16) / -7.73280000d-04 , -1.09374000d-03 /
      data f( 4,17),f( 4,18) / -9.08080000d-04 , -8.23270000d-04 /
      data f( 4,19),f( 4,20) / -6.74230000d-04 , -3.36640000d-04 /
      data f( 4,21),f( 4,22) / -8.28400000d-05 , -5.64000000d-06 /
      data f( 4,23) /           0.00000000d+00 /
      data f( 5, 1),f( 5, 2) /  0.00000000d+00 ,  7.34740000d-04 /
      data f( 5, 3),f( 5, 4) /  1.35111000d-02 ,  7.79987800d-02 /
      data f( 5, 5),f( 5, 6) /  1.33375100d-01 ,  8.68966300d-02 /
      data f( 5, 7),f( 5, 8) /  2.47519900d-02 ,  4.67716000d-03 /
      data f( 5, 9),f( 5,10) /  6.57620000d-04 ,  1.48047000d-03 /
      data f( 5,11),f( 5,12) /  2.17568000d-03 ,  1.78972000d-03 /
      data f( 5,13),f( 5,14) /  1.10415000d-03 ,  2.40380000d-04 /
      data f( 5,15),f( 5,16) / -7.21540000d-04 , -1.19878000d-03 /
      data f( 5,17),f( 5,18) / -1.16686000d-03 , -1.00891000d-03 /
      data f( 5,19),f( 5,20) / -7.14050000d-04 , -3.25600000d-04 /
      data f( 5,21),f( 5,22) / -7.69700000d-05 , -5.09000000d-06 /
      data f( 5,23) /           0.00000000d+00 /
      data f( 6, 1),f( 6, 2) /  0.00000000d+00 ,  8.33540000d-04 /
      data f( 6, 3),f( 6, 4) /  1.59229000d-02 ,  1.00252650d-01 /
      data f( 6, 5),f( 6, 6) /  1.47306580d-01 ,  1.06212030d-01 /
      data f( 6, 7),f( 6, 8) /  2.78536900d-02 ,  4.88020000d-03 /
      data f( 6, 9),f( 6,10) /  5.11140000d-04 ,  1.19267000d-03 /
      data f( 6,11),f( 6,12) /  1.84503000d-03 ,  1.51612000d-03 /
      data f( 6,13),f( 6,14) /  9.82930000d-04 ,  2.50110000d-04 /
      data f( 6,15),f( 6,16) / -6.46980000d-04 , -1.20131000d-03 /
      data f( 6,17),f( 6,18) / -1.26860000d-03 , -1.07694000d-03 /
      data f( 6,19),f( 6,20) / -7.08400000d-04 , -3.05880000d-04 /
      data f( 6,21),f( 6,22) / -7.04200000d-05 , -4.59000000d-06 /
      data f( 6,23) /           0.00000000d+00 /
      data f( 7, 1),f( 7, 2) /  0.00000000d+00 ,  9.08380000d-04 /
      data f( 7, 3),f( 7, 4) /  1.78363700d-02 ,  1.15792900d-01 /
      data f( 7, 5),f( 7, 6) /  1.56931930d-01 ,  1.17044740d-01 /
      data f( 7, 7),f( 7, 8) /  2.96893100d-02 ,  4.97736000d-03 /
      data f( 7, 9),f( 7,10) /  4.97410000d-04 ,  7.86580000d-04 /
      data f( 7,11),f( 7,12) /  1.28746000d-03 ,  1.08165000d-03 /
      data f( 7,13),f( 7,14) /  7.73800000d-04 ,  2.51840000d-04 /
      data f( 7,15),f( 7,16) / -4.79150000d-04 , -1.04509000d-03 /
      data f( 7,17),f( 7,18) / -1.20582000d-03 , -1.01430000d-03 /
      data f( 7,19),f( 7,20) / -6.24620000d-04 , -2.54860000d-04 /
      data f( 7,21),f( 7,22) / -5.70400000d-05 , -3.65000000d-06 /
      data f( 7,23) /           0.00000000d+00 /
      data f( 8, 1),f( 8, 2) /  0.00000000d+00 ,  7.68070000d-04 /
      data f( 8, 3),f( 8, 4) /  1.51324200d-02 ,  9.85013500d-02 /
      data f( 8, 5),f( 8, 6) /  1.53621790d-01 ,  1.01336250d-01 /
      data f( 8, 7),f( 8, 8) /  2.42723900d-02 ,  3.86244000d-03 /
      data f( 8, 9),f( 8,10) / -4.80000000d-07 ,  4.74000000d-04 /
      data f( 8,11),f( 8,12) /  8.59540000d-04 ,  7.69440000d-04 /
      data f( 8,13),f( 8,14) /  6.05320000d-04 ,  2.36160000d-04 /
      data f( 8,15),f( 8,16) / -3.28480000d-04 , -8.18570000d-04 /
      data f( 8,17),f( 8,18) / -9.96780000d-04 , -8.42660000d-04 /
      data f( 8,19),f( 8,20) / -5.07320000d-04 , -2.02600000d-04 /
      data f( 8,21),f( 8,22) / -4.48100000d-05 , -2.83000000d-06 /
      data f( 8,23) /           0.00000000d+00 /
      data f( 9, 1),f( 9, 2) /  0.00000000d+00 ,  5.59810000d-04 /
      data f( 9, 3),f( 9, 4) /  1.02242700d-02 ,  5.73732600d-02 /
      data f( 9, 5),f( 9, 6) /  1.09318940d-01 ,  6.09714300d-02 /
      data f( 9, 7),f( 9, 8) /  1.56434500d-02 ,  2.27028000d-03 /
      data f( 9, 9),f( 9,10) / -3.01930000d-04 ,  2.25050000d-04 /
      data f( 9,11),f( 9,12) /  5.43090000d-04 ,  5.47300000d-04 /
      data f( 9,13),f( 9,14) /  4.72100000d-04 ,  2.12040000d-04 /
      data f( 9,15),f( 9,16) / -2.12250000d-04 , -6.05570000d-04 /
      data f( 9,17),f( 9,18) / -7.68720000d-04 , -6.57060000d-04 /
      data f( 9,19),f( 9,20) / -3.93940000d-04 , -1.56710000d-04 /
      data f( 9,21),f( 9,22) / -3.46800000d-05 , -2.19000000d-06 /
      data f( 9,23) /           0.00000000d+00 /
      data f(10, 1),f(10, 2) /  0.00000000d+00 ,  3.31480000d-04 /
      data f(10, 3),f(10, 4) /  5.71274000d-03 ,  2.74559800d-02 /
      data f(10, 5),f(10, 6) /  4.93160700d-02 ,  2.89522400d-02 /
      data f(10, 7),f(10, 8) /  8.37804000d-03 ,  8.68180000d-04 /
      data f(10, 9),f(10,10) / -5.44330000d-04 ,  2.99100000d-05 /
      data f(10,11),f(10,12) /  3.17740000d-04 ,  3.89760000d-04 /
      data f(10,13),f(10,14) /  3.67880000d-04 ,  1.84860000d-04 /
      data f(10,15),f(10,16) / -1.28960000d-04 , -4.32600000d-04 /
      data f(10,17),f(10,18) / -5.70000000d-04 , -4.93990000d-04 /
      data f(10,19),f(10,20) / -2.97470000d-04 , -1.18960000d-04 /
      data f(10,21),f(10,22) / -2.66700000d-05 , -1.79000000d-06 /
      data f(10,23) /           0.00000000d+00 /
      data f(11, 1),f(11, 2) /  0.00000000d+00 ,  1.60800000d-04 /
      data f(11, 3),f(11, 4) /  2.58503000d-03 ,  1.08757300d-02 /
      data f(11, 5),f(11, 6) /  1.72830700d-02 ,  1.18707500d-02 /
      data f(11, 7),f(11, 8) /  3.52203000d-03 , -1.11680000d-04 /
      data f(11, 9),f(11,10) / -6.98200000d-04 , -1.13650000d-04 /
      data f(11,11),f(11,12) /  1.63630000d-04 ,  2.77620000d-04 /
      data f(11,13),f(11,14) /  2.86220000d-04 ,  1.57860000d-04 /
      data f(11,15),f(11,16) / -7.23100000d-05 , -3.01890000d-04 /
      data f(11,17),f(11,18) / -4.12560000d-04 , -3.62910000d-04 /
      data f(11,19),f(11,20) / -2.20460000d-04 , -8.91800000d-05 /
      data f(11,21),f(11,22) / -2.03300000d-05 , -1.32000000d-06 /
      data f(11,23) /           0.00000000d+00 /
      data f(12, 1),f(12, 2) /  0.00000000d+00 ,  7.03800000d-05 /
      data f(12, 3),f(12, 4) /  1.09636000d-03 ,  1.71812000d-03 /
      data f(12, 5),f(12, 6) /  4.11465000d-03 ,  3.85266000d-03 /
      data f(12, 7),f(12, 8) /  8.21020000d-04 , -6.67320000d-04 /
      data f(12, 9),f(12,10) / -7.67610000d-04 , -2.08060000d-04 /
      data f(12,11),f(12,12) /  6.42000000d-05 ,  1.97460000d-04 /
      data f(12,13),f(12,14) /  2.22000000d-04 ,  1.32710000d-04 /
      data f(12,15),f(12,16) / -3.59300000d-05 , -2.07060000d-04 /
      data f(12,17),f(12,18) / -2.93850000d-04 , -2.62460000d-04 /
      data f(12,19),f(12,20) / -1.61080000d-04 , -6.60200000d-05 /
      data f(12,21),f(12,22) / -1.52800000d-05 , -1.01000000d-06 /
      data f(12,23) /           0.00000000d+00 /
      data f(13, 1),f(13, 2) /  0.00000000d+00 ,  3.87100000d-05 /
      data f(13, 3),f(13, 4) /  4.93590000d-04 , -1.27025000d-03 /
      data f(13, 5),f(13, 6) / -6.89670000d-04 , -2.83520000d-04 /
      data f(13, 7),f(13, 8) / -7.44140000d-04 , -9.35450000d-04 /
      data f(13, 9),f(13,10) / -7.47600000d-04 , -2.69830000d-04 /
      data f(13,11),f(13,12) / -1.47400000d-05 ,  1.17170000d-04 /
      data f(13,13),f(13,14) /  1.49700000d-04 ,  9.88100000d-05 /
      data f(13,15),f(13,16) / -5.88000000d-06 , -1.15210000d-04 /
      data f(13,17),f(13,18) / -1.73730000d-04 , -1.58570000d-04 /
      data f(13,19),f(13,20) / -9.85800000d-05 , -4.08500000d-05 /
      data f(13,21),f(13,22) / -9.59000000d-06 , -6.20000000d-07 /
      data f(13,23) /           0.00000000d+00 /
      data f(14, 1),f(14, 2) /  0.00000000d+00 , -3.10000000d-07 /
      data f(14, 3),f(14, 4) / -1.65250000d-04 , -8.60040000d-04 /
      data f(14, 5),f(14, 6) / -1.05100000d-03 , -9.73620000d-04 /
      data f(14, 7),f(14, 8) / -9.61960000d-04 , -8.48940000d-04 /
      data f(14, 9),f(14,10) / -6.36730000d-04 , -2.62710000d-04 /
      data f(14,11),f(14,12) / -4.29100000d-05 ,  6.86200000d-05 /
      data f(14,13),f(14,14) /  9.89900000d-05 ,  7.06100000d-05 /
      data f(14,15),f(14,16) /  5.60000000d-06 , -6.36200000d-05 /
      data f(14,17),f(14,18) / -1.01990000d-04 , -9.48200000d-05 /
      data f(14,19),f(14,20) / -5.93300000d-05 , -2.45700000d-05 /
      data f(14,21),f(14,22) / -5.64000000d-06 , -4.00000000d-07 /
      data f(14,23) /           0.00000000d+00 /
      data f(15, 1),f(15, 2) /  0.00000000d+00 , -8.86000000d-06 /
      data f(15, 3),f(15, 4) / -1.67600000d-04 , -5.96620000d-04 /
      data f(15, 5),f(15, 6) / -8.53880000d-04 , -8.90640000d-04 /
      data f(15, 7),f(15, 8) / -8.47000000d-04 , -7.18620000d-04 /
      data f(15, 9),f(15,10) / -5.42090000d-04 , -2.36600000d-04 /
      data f(15,11),f(15,12) / -4.65900000d-05 ,  4.75700000d-05 /
      data f(15,13),f(15,14) /  7.40100000d-05 ,  5.47600000d-05 /
      data f(15,15),f(15,16) /  7.73000000d-06 , -4.32300000d-05 /
      data f(15,17),f(15,18) / -7.19000000d-05 , -6.74400000d-05 /
      data f(15,19),f(15,20) / -4.22800000d-05 , -1.75000000d-05 /
      data f(15,21),f(15,22) / -4.09000000d-06 , -3.20000000d-07 /
      data f(15,23) /           0.00000000d+00 /
      data f(16, 1),f(16, 2) /  0.00000000d+00 , -8.13000000d-06 /
      data f(16, 3),f(16, 4) / -1.17080000d-04 , -3.90550000d-04 /
      data f(16, 5),f(16, 6) / -6.20700000d-04 , -7.03200000d-04 /
      data f(16, 7),f(16, 8) / -6.78790000d-04 , -5.79350000d-04 /
      data f(16, 9),f(16,10) / -4.46280000d-04 , -2.03230000d-04 /
      data f(16,11),f(16,12) / -4.47700000d-05 ,  3.27100000d-05 /
      data f(16,13),f(16,14) /  5.49500000d-05 ,  4.16000000d-05 /
      data f(16,15),f(16,16) /  7.32000000d-06 , -3.00900000d-05 /
      data f(16,17),f(16,18) / -5.13700000d-05 , -4.84600000d-05 /
      data f(16,19),f(16,20) / -3.04200000d-05 , -1.25600000d-05 /
      data f(16,21),f(16,22) / -2.83000000d-06 , -2.30000000d-07 /
      data f(16,23) /           0.00000000d+00 /
      data f(17, 1),f(17, 2) /  0.00000000d+00 , -4.36000000d-06 /
      data f(17, 3),f(17, 4) / -5.71700000d-05 , -1.94100000d-04 /
      data f(17, 5),f(17, 6) / -3.45510000d-04 , -4.33210000d-04 /
      data f(17, 7),f(17, 8) / -4.43550000d-04 , -3.95860000d-04 /
      data f(17, 9),f(17,10) / -3.17660000d-04 , -1.51770000d-04 /
      data f(17,11),f(17,12) / -3.68800000d-05 ,  1.86000000d-05 /
      data f(17,13),f(17,14) /  3.47100000d-05 ,  2.66300000d-05 /
      data f(17,15),f(17,16) /  4.82000000d-06 , -1.89100000d-05 /
      data f(17,17),f(17,18) / -3.23200000d-05 , -3.05100000d-05 /
      data f(17,19),f(17,20) / -1.91800000d-05 , -7.90000000d-06 /
      data f(17,21),f(17,22) / -1.90000000d-06 , -8.00000000d-08 /
      data f(17,23) /           0.00000000d+00 /
      data f(18, 1),f(18, 2) /  0.00000000d+00 , -1.97000000d-06 /
      data f(18, 3),f(18, 4) / -2.61000000d-05 , -9.33200000d-05 /
      data f(18, 5),f(18, 6) / -1.81860000d-04 , -2.49930000d-04 /
      data f(18, 7),f(18, 8) / -2.75420000d-04 , -2.59910000d-04 /
      data f(18, 9),f(18,10) / -2.16670000d-04 , -1.07260000d-04 /
      data f(18,11),f(18,12) / -2.83200000d-05 ,  1.02100000d-05 /
      data f(18,13),f(18,14) /  2.16500000d-05 ,  1.62700000d-05 /
      data f(18,15),f(18,16) /  1.94000000d-06 , -1.31500000d-05 /
      data f(18,17),f(18,18) / -2.14600000d-05 , -2.00800000d-05 /
      data f(18,19),f(18,20) / -1.26100000d-05 , -5.24000000d-06 /
      data f(18,21),f(18,22) / -1.24000000d-06 , -7.00000000d-08 /
      data f(18,23) /           0.00000000d+00 /
      data f(19, 1),f(19, 2) /  0.00000000d+00 , -1.13000000d-06 /
      data f(19, 3),f(19, 4) / -1.54600000d-05 , -5.75500000d-05 /
      data f(19, 5),f(19, 6) / -1.18400000d-04 , -1.72040000d-04 /
      data f(19, 7),f(19, 8) / -1.98700000d-04 , -1.93920000d-04 /
      data f(19, 9),f(19,10) / -1.65200000d-04 , -8.37900000d-05 /
      data f(19,11),f(19,12) / -2.32300000d-05 ,  6.75000000d-06 /
      data f(19,13),f(19,14) /  1.56800000d-05 ,  1.14900000d-05 /
      data f(19,15),f(19,16) /  5.30000000d-07 , -1.07900000d-05 /
      data f(19,17),f(19,18) / -1.68400000d-05 , -1.55600000d-05 /
      data f(19,19),f(19,20) / -9.76000000d-06 , -4.05000000d-06 /
      data f(19,21),f(19,22) / -9.20000000d-07 , -6.00000000d-08 /
      data f(19,23) /           0.00000000d+00 /
      data f(20, 1),f(20, 2) /  0.00000000d+00 , -6.40000000d-07 /
      data f(20, 3),f(20, 4) / -9.27000000d-06 , -3.59300000d-05 /
      data f(20, 5),f(20, 6) / -7.80900000d-05 , -1.19260000d-04 /
      data f(20, 7),f(20, 8) / -1.43450000d-04 , -1.43850000d-04 /
      data f(20, 9),f(20,10) / -1.24490000d-04 , -6.47300000d-05 /
      data f(20,11),f(20,12) / -1.86600000d-05 ,  4.36000000d-06 /
      data f(20,13),f(20,14) /  1.12600000d-05 ,  7.87000000d-06 /
      data f(20,15),f(20,16) / -4.90000000d-07 , -8.98000000d-06 /
      data f(20,17),f(20,18) / -1.33800000d-05 , -1.21700000d-05 /
      data f(20,19),f(20,20) / -7.59000000d-06 , -3.16000000d-06 /
      data f(20,21),f(20,22) / -7.10000000d-07 , -5.00000000d-08 /
      data f(20,23) /           0.00000000d+00 /
      data f(21, 1),f(21, 2) /  0.00000000d+00 , -2.90000000d-07 /
      data f(21, 3),f(21, 4) / -4.58000000d-06 , -1.87600000d-05 /
      data f(21, 5),f(21, 6) / -4.33600000d-05 , -7.02600000d-05 /
      data f(21, 7),f(21, 8) / -8.83000000d-05 , -9.12800000d-05 /
      data f(21, 9),f(21,10) / -8.07300000d-05 , -4.35900000d-05 /
      data f(21,11),f(21,12) / -1.35600000d-05 ,  2.11000000d-06 /
      data f(21,13),f(21,14) /  6.73000000d-06 ,  4.39000000d-06 /
      data f(21,15),f(21,16) / -1.40000000d-06 , -6.98000000d-06 /
      data f(21,17),f(21,18) / -9.65000000d-06 , -8.57000000d-06 /
      data f(21,19),f(21,20) / -5.29000000d-06 , -2.19000000d-06 /
      data f(21,21),f(21,22) / -5.30000000d-07 , -9.00000000d-08 /
      data f(21,23) /           0.00000000d+00 /
      data f(22, 1),f(22, 2) /  0.00000000d+00 , -1.10000000d-07 /
      data f(22, 3),f(22, 4) / -1.70000000d-06 , -7.67000000d-06 /
      data f(22, 5),f(22, 6) / -1.79400000d-05 , -3.05200000d-05 /
      data f(22, 7),f(22, 8) / -3.96600000d-05 , -4.22500000d-05 /
      data f(22, 9),f(22,10) / -3.86100000d-05 , -2.28600000d-05 /
      data f(22,11),f(22,12) / -7.75000000d-06 ,  3.70000000d-07 /
      data f(22,13),f(22,14) /  2.59000000d-06 ,  1.17000000d-06 /
      data f(22,15),f(22,16) / -1.77000000d-06 , -4.49000000d-06 /
      data f(22,17),f(22,18) / -5.63000000d-06 , -4.83000000d-06 /
      data f(22,19),f(22,20) / -2.95000000d-06 , -1.23000000d-06 /
      data f(22,21),f(22,22) / -2.90000000d-07 , -2.00000000d-08 /
      data f(22,23) /           0.00000000d+00 /
      data f(23, 1),f(23, 2) /  0.00000000d+00 , -5.00000000d-08 /
      data f(23, 3),f(23, 4) / -8.90000000d-07 , -3.19000000d-06 /
      data f(23, 5),f(23, 6) / -7.79000000d-06 , -1.34300000d-05 /
      data f(23, 7),f(23, 8) / -1.79900000d-05 , -1.98700000d-05 /
      data f(23, 9),f(23,10) / -1.88800000d-05 , -1.17700000d-05 /
      data f(23,11),f(23,12) / -4.39000000d-06 , -2.50000000d-07 /
      data f(23,13),f(23,14) /  7.70000000d-07 , -3.00000000d-08 /
      data f(23,15),f(23,16) / -1.51000000d-06 , -2.79000000d-06 /
      data f(23,17),f(23,18) / -3.21000000d-06 , -2.66000000d-06 /
      data f(23,19),f(23,20) / -1.59000000d-06 , -6.60000000d-07 /
      data f(23,21),f(23,22) / -1.60000000d-07 ,  0.00000000d+00 /
      data f(23,23) /           0.00000000d+00 /
      data f(24, 1),f(24, 2) /  0.00000000d+00 , -2.00000000d-08 /
      data f(24, 3),f(24, 4) / -3.00000000d-07 , -1.43000000d-06 /
      data f(24, 5),f(24, 6) / -3.60000000d-06 , -6.27000000d-06 /
      data f(24, 7),f(24, 8) / -8.60000000d-06 , -9.77000000d-06 /
      data f(24, 9),f(24,10) / -9.49000000d-06 , -6.17000000d-06 /
      data f(24,11),f(24,12) / -2.46000000d-06 , -4.50000000d-07 /
      data f(24,13),f(24,14) / -3.00000000d-08 , -4.60000000d-07 /
      data f(24,15),f(24,16) / -1.18000000d-06 , -1.74000000d-06 /
      data f(24,17),f(24,18) / -1.84000000d-06 , -1.46000000d-06 /
      data f(24,19),f(24,20) / -8.60000000d-07 , -3.50000000d-07 /
      data f(24,21),f(24,22) / -8.00000000d-08 ,  0.00000000d+00 /
      data f(24,23) /           0.00000000d+00 /
      data f(25, 1),f(25, 2) /  0.00000000d+00 , -2.00000000d-08 /
      data f(25, 3),f(25, 4) / -1.40000000d-07 , -7.00000000d-07 /
      data f(25, 5),f(25, 6) / -1.76000000d-06 , -3.06000000d-06 /
      data f(25, 7),f(25, 8) / -4.25000000d-06 , -4.83000000d-06 /
      data f(25, 9),f(25,10) / -4.83000000d-06 , -3.19000000d-06 /
      data f(25,11),f(25,12) / -1.37000000d-06 , -4.50000000d-07 /
      data f(25,13),f(25,14) / -3.30000000d-07 , -5.60000000d-07 /
      data f(25,15),f(25,16) / -9.50000000d-07 , -1.17000000d-06 /
      data f(25,17),f(25,18) / -1.14000000d-06 , -8.80000000d-07 /
      data f(25,19),f(25,20) / -5.00000000d-07 , -1.90000000d-07 /
      data f(25,21),f(25,22) / -5.00000000d-08 , -1.00000000d-08 /
      data f(25,23) /           0.00000000d+00 /
      data f(26, 1),f(26, 2) /  0.00000000d+00 ,  0.00000000d+00 /
      data f(26, 3),f(26, 4) / -9.00000000d-08 , -3.40000000d-07 /
      data f(26, 5),f(26, 6) / -8.60000000d-07 , -1.52000000d-06 /
      data f(26, 7),f(26, 8) / -2.13000000d-06 , -2.46000000d-06 /
      data f(26, 9),f(26,10) / -2.43000000d-06 , -1.63000000d-06 /
      data f(26,11),f(26,12) / -7.80000000d-07 , -4.00000000d-07 /
      data f(26,13),f(26,14) / -3.90000000d-07 , -6.00000000d-07 /
      data f(26,15),f(26,16) / -7.60000000d-07 , -8.70000000d-07 /
      data f(26,17),f(26,18) / -8.00000000d-07 , -5.90000000d-07 /
      data f(26,19),f(26,20) / -3.30000000d-07 , -1.30000000d-07 /
      data f(26,21),f(26,22) / -3.00000000d-08 ,  0.00000000d+00 /
      data f(26,23) /           0.00000000d+00 /
      data f(27, 1),f(27, 2) /  0.00000000d+00 ,  0.00000000d+00 /
      data f(27, 3),f(27, 4) / -2.00000000d-08 , -9.00000000d-08 /
      data f(27, 5),f(27, 6) / -2.20000000d-07 , -3.80000000d-07 /
      data f(27, 7),f(27, 8) / -5.10000000d-07 , -5.90000000d-07 /
      data f(27, 9),f(27,10) / -5.90000000d-07 , -4.60000000d-07 /
      data f(27,11),f(27,12) / -3.00000000d-07 , -2.30000000d-07 /
      data f(27,13),f(27,14) / -2.30000000d-07 , -2.30000000d-07 /
      data f(27,15),f(27,16) / -4.30000000d-07 , -4.40000000d-07 /
      data f(27,17),f(27,18) / -3.90000000d-07 , -2.90000000d-07 /
      data f(27,19),f(27,20) / -1.70000000d-07 , -6.00000000d-08 /
      data f(27,21),f(27,22) / -1.00000000d-08 ,  2.00000000d-08 /
      data f(27,23) /           0.00000000d+00 /
      data f(28, 1),f(28, 2) /  0.00000000d+00 ,  0.00000000d+00 /
      data f(28, 3),f(28, 4) / -1.00000000d-08 , -2.00000000d-08 /
      data f(28, 5),f(28, 6) / -5.00000000d-08 , -9.00000000d-08 /
      data f(28, 7),f(28, 8) / -1.40000000d-07 , -1.70000000d-07 /
      data f(28, 9),f(28,10) / -1.90000000d-07 , -1.90000000d-07 /
      data f(28,11),f(28,12) / -1.40000000d-07 , -9.00000000d-08 /
      data f(28,13),f(28,14) / -1.00000000d-08 , -7.00000000d-08 /
      data f(28,15),f(28,16) / -1.90000000d-07 , -1.70000000d-07 /
      data f(28,17),f(28,18) / -1.60000000d-07 , -1.20000000d-07 /
      data f(28,19),f(28,20) / -7.00000000d-08 , -5.00000000d-08 /
      data f(28,21),f(28,22) / -1.00000000d-08 ,  0.00000000d+00 /
      data f(28,23) /           0.00000000d+00 /
 
      data fpp( 1, 1,1),fpp( 1, 1,2)/ 0.00000000d+00,-5.32977429d-05/
      data fpp( 1, 2,1),fpp( 1, 2,2)/ 3.20327583d-03, 9.26270858d-05/
      data fpp( 1, 3,1),fpp( 1, 3,2)/ 5.73930164d-02, 4.76097400d-04/
      data fpp( 1, 4,1),fpp( 1, 4,2)/ 2.95955642d-01, 2.81585158d-05/
      data fpp( 1, 5,1),fpp( 1, 5,2)/ 9.70195339d-01,-9.85021863d-04/
      data fpp( 1, 6,1),fpp( 1, 6,2)/ 3.34392761d-01,-1.41315864d-04/
      data fpp( 1, 7,1),fpp( 1, 7,2)/ 2.72003028d-01, 3.26390919d-04/
      data fpp( 1, 8,1),fpp( 1, 8,2)/-8.26359048d-02, 2.02136987d-04/
      data fpp( 1, 9,1),fpp( 1, 9,2)/-2.48368539d-02, 3.95659322d-05/
      data fpp( 1,10,1),fpp( 1,10,2)/-2.81457003d-02,-1.29189028d-06/
      data fpp( 1,11,1),fpp( 1,11,2)/-9.97451983d-03,-3.33267711d-05/
      data fpp( 1,12,1),fpp( 1,12,2)/-7.49326973d-03,-2.21842518d-06/
      data fpp( 1,13,1),fpp( 1,13,2)/-8.73244638d-04,-2.08552814d-06/
      data fpp( 1,14,1),fpp( 1,14,2)/-1.53970956d-05, 7.55633776d-06/
      data fpp( 1,15,1),fpp( 1,15,2)/ 1.55165071d-02, 2.33155771d-05/
      data fpp( 1,16,1),fpp( 1,16,2)/ 4.78870583d-02, 4.17415376d-06/
      data fpp( 1,17,1),fpp( 1,17,2)/ 6.78893504d-02,-2.88497922d-05/
      data fpp( 1,18,1),fpp( 1,18,2)/ 4.78952964d-02,-3.39058507d-06/
      data fpp( 1,19,1),fpp( 1,19,2)/ 1.82120669d-02, 1.34033325d-05/
      data fpp( 1,20,1),fpp( 1,20,2)/ 3.84576054d-03, 3.33625522d-06/
      data fpp( 1,21,1),fpp( 1,21,2)/ 3.50579049d-04,-1.97795333d-06/
      data fpp( 1,22,1),fpp( 1,22,2)/ 4.33274328d-05,-4.30241906d-07/
      data fpp( 1,23,1),fpp( 1,23,2)/ 0.00000000d+00,-8.43079047d-07/
      data fpp( 2, 1,1),fpp( 2, 1,2)/ 0.00000000d+00,-1.38729244d-04/
      data fpp( 2, 2,1),fpp( 2, 2,2)/ 2.00044834d-03, 1.43321288d-04/
      data fpp( 2, 3,1),fpp( 2, 3,2)/ 4.52239672d-02, 7.60680091d-04/
      data fpp( 2, 4,1),fpp( 2, 4,2)/ 3.65948716d-01, 2.04459947d-04/
      data fpp( 2, 5,1),fpp( 2, 5,2)/ 7.51048321d-01,-1.86758308d-03/
      data fpp( 2, 6,1),fpp( 2, 6,2)/ 3.63254478d-01,-1.32538037d-04/
      data fpp( 2, 7,1),fpp( 2, 7,2)/ 1.50058944d-01, 6.84056025d-04/
      data fpp( 2, 8,1),fpp( 2, 8,2)/-4.60221904d-02, 1.65309136d-04/
      data fpp( 2, 9,1),fpp( 2, 9,2)/-8.89629228d-03, 9.36634311d-05/
      data fpp( 2,10,1),fpp( 2,10,2)/-1.26455993d-02,-1.87270613d-05/
      data fpp( 2,11,1),fpp( 2,11,2)/-1.86696034d-03,-2.29029861d-05/
      data fpp( 2,12,1),fpp( 2,12,2)/-3.00346054d-03,-4.59999443d-06/
      data fpp( 2,13,1),fpp( 2,13,2)/-3.35107237d-05,-4.64236184d-07/
      data fpp( 2,14,1),fpp( 2,14,2)/-2.20205809d-04, 2.84073917d-06/
      data fpp( 2,15,1),fpp( 2,15,2)/ 1.15409858d-02, 1.70870795d-05/
      data fpp( 2,16,1),fpp( 2,16,2)/ 3.62698834d-02, 5.42734283d-06/
      data fpp( 2,17,1),fpp( 2,17,2)/ 5.18902991d-02,-1.65106508d-05/
      data fpp( 2,18,1),fpp( 2,18,2)/ 3.69254072d-02,-1.46133953d-06/
      data fpp( 2,19,1),fpp( 2,19,2)/ 1.41858661d-02, 8.47380893d-06/
      data fpp( 2,20,1),fpp( 2,20,2)/ 2.99547892d-03, 9.86103791d-07/
      data fpp( 2,21,1),fpp( 2,21,2)/ 2.83841902d-04,-2.15522410d-06/
      data fpp( 2,22,1),fpp( 2,22,2)/ 2.63451344d-05,-5.40207401d-07/
      data fpp( 2,23,1),fpp( 2,23,2)/ 0.00000000d+00,-2.84146300d-07/
      data fpp( 3, 1,1),fpp( 3, 1,2)/ 0.00000000d+00,-3.10472733d-04/
      data fpp( 3, 2,1),fpp( 3, 2,2)/ 1.05293082d-03, 2.16826665d-04/
      data fpp( 3, 3,1),fpp( 3, 3,2)/ 3.84551148d-02, 1.14122127d-03/
      data fpp( 3, 4,1),fpp( 3, 4,2)/ 5.35645493d-01, 6.75782649d-04/
      data fpp( 3, 5,1),fpp( 3, 5,2)/ 1.49166538d+00,-3.56538547d-03/
      data fpp( 3, 6,1),fpp( 3, 6,2)/ 4.71073325d-01, 2.90892023d-04/
      data fpp( 3, 7,1),fpp( 3, 7,2)/-3.74480501d-03, 9.25385378d-04/
      data fpp( 3, 8,1),fpp( 3, 8,2)/ 5.02446665d-02, 3.01178466d-04/
      data fpp( 3, 9,1),fpp( 3, 9,2)/ 7.19420230d-02, 9.84975576d-05/
      data fpp( 3,10,1),fpp( 3,10,2)/ 7.22780977d-02,-2.21177058d-05/
      data fpp( 3,11,1),fpp( 3,11,2)/ 1.61343612d-02,-1.70827345d-05/
      data fpp( 3,12,1),fpp( 3,12,2)/ 2.86311188d-03,-4.65975638d-06/
      data fpp( 3,13,1),fpp( 3,13,2)/ 1.13928753d-03,-3.15440034d-07/
      data fpp( 3,14,1),fpp( 3,14,2)/-4.65779669d-04,-1.33683489d-07/
      data fpp( 3,15,1),fpp( 3,15,2)/ 7.09154963d-03, 1.25291740d-05/
      data fpp( 3,16,1),fpp( 3,16,2)/ 2.31654083d-02, 5.97958754d-06/
      data fpp( 3,17,1),fpp( 3,17,2)/ 3.39994531d-02,-8.44252413d-06/
      data fpp( 3,18,1),fpp( 3,18,2)/ 2.44470747d-02,-1.94910179d-08/
      data fpp( 3,19,1),fpp( 3,19,2)/ 9.76446852d-03, 5.17308820d-06/
      data fpp( 3,20,1),fpp( 3,20,2)/ 2.07032378d-03,-5.41661786d-07/
      data fpp( 3,21,1),fpp( 3,21,2)/ 2.36053344d-04,-2.18624106d-06/
      data fpp( 3,22,1),fpp( 3,22,2)/-1.07079705d-05,-5.98373984d-07/
      data fpp( 3,23,1),fpp( 3,23,2)/ 0.00000000d+00, 6.59369918d-08/
      data fpp( 4, 1,1),fpp( 4, 1,2)/ 0.00000000d+00,-6.10917160d-04/
      data fpp( 4, 2,1),fpp( 4, 2,2)/-7.88171605d-04, 2.88504719d-04/
      data fpp( 4, 3,1),fpp( 4, 3,2)/ 1.27855735d-02, 1.73816548d-03/
      data fpp( 4, 4,1),fpp( 4, 4,2)/ 3.56379313d-01, 1.26199015d-03/
      data fpp( 4, 5,1),fpp( 4, 5,2)/-1.12689182d+00,-5.90999888d-03/
      data fpp( 4, 6,1),fpp( 4, 6,2)/ 3.02542220d-01, 8.80026965d-04/
      data fpp( 4, 7,1),fpp( 4, 7,2)/-4.60397243d-02, 1.38257742d-03/
      data fpp( 4, 8,1),fpp( 4, 8,2)/-6.22744757d-02, 3.93768965d-04/
      data fpp( 4, 9,1),fpp( 4, 9,2)/-7.43617996d-02, 1.03858723d-04/
      data fpp( 4,10,1),fpp( 4,10,2)/-8.57807915d-02,-2.91980525d-05/
      data fpp( 4,11,1),fpp( 4,11,2)/-4.92484429d-04,-8.49911322d-06/
      data fpp( 4,12,1),fpp( 4,12,2)/ 3.91101301d-03,-4.21429457d-06/
      data fpp( 4,13,1),fpp( 4,13,2)/ 1.14636059d-03,-6.38108486d-07/
      data fpp( 4,14,1),fpp( 4,14,2)/-5.68675515d-04,-1.89067148d-06/
      data fpp( 4,15,1),fpp( 4,15,2)/ 4.30081568d-03, 9.09119442d-06/
      data fpp( 4,16,1),fpp( 4,16,2)/ 1.52664836d-02, 6.14769379d-06/
      data fpp( 4,17,1),fpp( 4,17,2)/ 2.27298886d-02,-3.31476960d-06/
      data fpp( 4,18,1),fpp( 4,18,2)/ 1.72482938d-02, 1.06038460d-06/
      data fpp( 4,19,1),fpp( 4,19,2)/ 6.72625977d-03, 2.92703120d-06/
      data fpp( 4,20,1),fpp( 4,20,2)/ 1.40722595d-03,-1.45550939d-06/
      data fpp( 4,21,1),fpp( 4,21,2)/ 1.21944721d-04,-2.13239362d-06/
      data fpp( 4,22,1),fpp( 4,22,2)/ 2.24867475d-05,-6.10916107d-07/
      data fpp( 4,23,1),fpp( 4,23,2)/ 0.00000000d+00, 2.82458054d-07/
      data fpp( 5, 1,1),fpp( 5, 1,2)/ 0.00000000d+00,-9.74148044d-04/
      data fpp( 5, 2,1),fpp( 5, 2,2)/-3.06624440d-03, 2.19714489d-04/
      data fpp( 5, 3,1),fpp( 5, 3,2)/-3.61554088d-02, 2.98527889d-03/
      data fpp( 5, 4,1),fpp( 5, 4,2)/ 3.05631257d-01, 2.49886754d-04/
      data fpp( 5, 5,1),fpp( 5, 5,2)/-1.65398808d+00,-6.17155231d-03/
      data fpp( 5, 6,1),fpp( 5, 6,2)/-1.47966206d-01,-8.82713350d-06/
      data fpp( 5, 7,1),fpp( 5, 7,2)/-1.29868298d-01, 2.44698004d-03/
      data fpp( 5, 8,1),fpp( 5, 8,2)/-1.45787639d-02, 3.17661377d-04/
      data fpp( 5, 9,1),fpp( 5, 9,2)/ 1.35191756d-02, 1.35644052d-04/
      data fpp( 5,10,1),fpp( 5,10,2)/ 3.32990684d-02,-3.40470458d-05/
      data fpp( 5,11,1),fpp( 5,11,2)/ 4.23757652d-03,-7.11426908d-06/
      data fpp( 5,12,1),fpp( 5,12,2)/ 4.23283607d-03,-2.36607786d-06/
      data fpp( 5,13,1),fpp( 5,13,2)/ 1.10327010d-03,-1.39801949d-06/
      data fpp( 5,14,1),fpp( 5,14,2)/-6.67518273d-04,-2.73384419d-06/
      data fpp( 5,15,1),fpp( 5,15,2)/ 2.15318766d-03, 6.44439626d-06/
      data fpp( 5,16,1),fpp( 5,16,2)/ 1.00706574d-02, 6.03705917d-06/
      data fpp( 5,17,1),fpp( 5,17,2)/ 1.54389924d-02,-4.30329308d-08/
      data fpp( 5,18,1),fpp( 5,18,2)/ 1.15117500d-02, 1.69687255d-06/
      data fpp( 5,19,1),fpp( 5,19,2)/ 4.47249242d-03, 1.47014271d-06/
      data fpp( 5,20,1),fpp( 5,20,2)/ 8.38772410d-04,-1.96204341d-06/
      data fpp( 5,21,1),fpp( 5,21,2)/ 6.81677700d-05,-2.01116908d-06/
      data fpp( 5,22,1),fpp( 5,22,2)/-1.32390197d-05,-5.98280262d-07/
      data fpp( 5,23,1),fpp( 5,23,2)/ 0.00000000d+00, 3.96890131d-07/
      data fpp( 6, 1,1),fpp( 6, 1,2)/ 0.00000000d+00,-1.34628094d-03/
      data fpp( 6, 2,1),fpp( 6, 2,2)/-3.24885080d-03, 4.49467126d-06/
      data fpp( 6, 3,1),fpp( 6, 3,2)/-9.40519385d-02, 4.74969905d-03/
      data fpp( 6, 4,1),fpp( 6, 4,2)/-1.26583634d+00,-2.38559727d-03/
      data fpp( 6, 5,1),fpp( 6, 5,2)/-6.46673850d-01,-4.15350676d-03/
      data fpp( 6, 6,1),fpp( 6, 6,2)/-1.21106740d+00,-2.15601090d-03/
      data fpp( 6, 7,1),fpp( 6, 7,2)/-1.22903084d-01, 3.83424076d-03/
      data fpp( 6, 8,1),fpp( 6, 8,2)/ 1.54953117d-03, 1.11411847d-04/
      data fpp( 6, 9,1),fpp( 6, 9,2)/ 2.07110973d-02, 1.85175050d-04/
      data fpp( 6,10,1),fpp( 6,10,2)/ 2.04251778d-03,-4.60520728d-05/
      data fpp( 6,11,1),fpp( 6,11,2)/ 3.37217834d-03,-2.71695872d-06/
      data fpp( 6,12,1),fpp( 6,12,2)/ 3.91364269d-03,-1.95629233d-06/
      data fpp( 6,13,1),fpp( 6,13,2)/ 1.14255901d-03,-1.71467195d-06/
      data fpp( 6,14,1),fpp( 6,14,2)/-6.25251394d-04,-3.16281986d-06/
      data fpp( 6,15,1),fpp( 6,15,2)/ 7.78433664d-04, 4.50975139d-06/
      data fpp( 6,16,1),fpp( 6,16,2)/ 5.95688685d-03, 5.68941430d-06/
      data fpp( 6,17,1),fpp( 6,17,2)/ 9.73814188d-03, 1.95499141d-06/
      data fpp( 6,18,1),fpp( 6,18,2)/ 7.27070627d-03, 2.02762007d-06/
      data fpp( 6,19,1),fpp( 6,19,2)/ 2.66577057d-03, 5.47328325d-07/
      data fpp( 6,20,1),fpp( 6,20,2)/ 4.45684407d-04,-2.17813337d-06/
      data fpp( 6,21,1),fpp( 6,21,2)/ 1.33841987d-05,-1.85839486d-06/
      data fpp( 6,22,1),fpp( 6,22,2)/ 4.69331230d-07,-5.66087182d-07/
      data fpp( 6,23,1),fpp( 6,23,2)/ 0.00000000d+00, 4.48343591d-07/
      data fpp( 7, 1,1),fpp( 7, 1,2)/ 0.00000000d+00,-1.57581848d-03/
      data fpp( 7, 2,1),fpp( 7, 2,2)/-7.13432540d-03,-1.26724243d-04/
      data fpp( 7, 3,1),fpp( 7, 3,2)/-1.36285980d-01, 5.92742185d-03/
      data fpp( 7, 4,1),fpp( 7, 4,2)/-7.00430109d-01,-4.13611356d-03/
      data fpp( 7, 5,1),fpp( 7, 5,2)/ 3.13740896d-02,-3.01916762d-03/
      data fpp( 7, 6,1),fpp( 7, 6,2)/-4.62528209d-01,-3.23350874d-03/
      data fpp( 7, 7,1),fpp( 7, 7,2)/-2.21523600d-01, 4.56082500d-03/
      data fpp( 7, 8,1),fpp( 7, 8,2)/-4.36972116d-02, 2.46439340d-05/
      data fpp( 7, 9,1),fpp( 7, 9,2)/-2.70083796d-02, 1.96279261d-04/
      data fpp( 7,10,1),fpp( 7,10,2)/ 2.64941245d-03,-4.62155512d-05/
      data fpp( 7,11,1),fpp( 7,11,2)/ 3.32417672d-03, 1.28554337d-06/
      data fpp( 7,12,1),fpp( 7,12,2)/ 3.05215388d-03,-1.32802231d-06/
      data fpp( 7,13,1),fpp( 7,13,2)/ 1.01718793d-03,-2.09585415d-06/
      data fpp( 7,14,1),fpp( 7,14,2)/-4.49986681d-04,-3.13516110d-06/
      data fpp( 7,15,1),fpp( 7,15,2)/-6.05394823d-04, 2.09469854d-06/
      data fpp( 7,16,1),fpp( 7,16,2)/ 1.28601076d-03, 4.65936693d-06/
      data fpp( 7,17,1),fpp( 7,17,2)/ 3.00507817d-03, 3.58043373d-06/
      data fpp( 7,18,1),fpp( 7,18,2)/ 2.23700621d-03, 2.15389814d-06/
      data fpp( 7,19,1),fpp( 7,19,2)/ 6.38442068d-04,-3.06426298d-07/
      data fpp( 7,20,1),fpp( 7,20,2)/-1.94394269d-05,-2.12339295d-06/
      data fpp( 7,21,1),fpp( 7,21,2)/-3.22364810d-05,-1.51640190d-06/
      data fpp( 7,22,1),fpp( 7,22,2)/-3.78848384d-06,-4.76799458d-07/
      data fpp( 7,23,1),fpp( 7,23,2)/ 0.00000000d+00, 4.39199729d-07/
      data fpp( 8, 1,1),fpp( 8, 1,2)/ 0.00000000d+00,-1.42952188d-03/
      data fpp( 8, 2,1),fpp( 8, 2,2)/-4.86347612d-04, 5.79333567d-05/
      data fpp( 8, 3,1),fpp( 8, 3,2)/-5.34171406d-02, 4.46089565d-03/
      data fpp( 8, 4,1),fpp( 8, 4,2)/-8.57213223d-01,-1.34041676d-03/
      data fpp( 8, 5,1),fpp( 8, 5,2)/-1.41914601d+00,-5.87886620d-03/
      data fpp( 8, 6,1),fpp( 8, 6,2)/-9.19999768d-01,-9.21553636d-04/
      data fpp( 8, 7,1),fpp( 8, 7,2)/-7.88835180d-02, 3.61828395d-03/
      data fpp( 8, 8,1),fpp( 8, 8,2)/-8.57268483d-03, 4.53562537d-05/
      data fpp( 8, 9,1),fpp( 8, 9,2)/ 1.46984211d-02, 1.71578240d-04/
      data fpp( 8,10,1),fpp( 8,10,2)/ 1.38633243d-03,-4.53936454d-05/
      data fpp( 8,11,1),fpp( 8,11,2)/ 2.77861476d-03, 4.65994201d-06/
      data fpp( 8,12,1),fpp( 8,12,2)/ 2.21674178d-03,-1.78452266d-06/
      data fpp( 8,13,1),fpp( 8,13,2)/ 8.86189272d-04,-1.96305135d-06/
      data fpp( 8,14,1),fpp( 8,14,2)/-1.86301882d-04,-2.66567193d-06/
      data fpp( 8,15,1),fpp( 8,15,2)/-9.30854370d-04, 8.96939059d-07/
      data fpp( 8,16,1),fpp( 8,16,2)/-5.55929872d-04, 3.55091569d-06/
      data fpp( 8,17,1),fpp( 8,17,2)/ 1.80545452d-04, 3.61219818d-06/
      data fpp( 8,18,1),fpp( 8,18,2)/ 1.31268891d-04, 1.94009161d-06/
      data fpp( 8,19,1),fpp( 8,19,2)/-1.91538848d-04,-4.99364602d-07/
      data fpp( 8,20,1),fpp( 8,20,2)/-1.81926700d-04,-1.77983320d-06/
      data fpp( 8,21,1),fpp( 8,21,2)/-5.69382748d-05,-1.19710260d-06/
      data fpp( 8,22,1),fpp( 8,22,2)/-3.31539586d-06,-3.80356400d-07/
      data fpp( 8,23,1),fpp( 8,23,2)/ 0.00000000d+00, 3.69528200d-07/
      data fpp( 9, 1,1),fpp( 9, 1,2)/ 0.00000000d+00,-7.28649117d-04/
      data fpp( 9, 2,1),fpp( 9, 2,2)/-1.11278415d-03, 2.79465835d-04/
      data fpp( 9, 3,1),fpp( 9, 3,2)/ 1.93245427d-02, 1.79590178d-03/
      data fpp( 9, 4,1),fpp( 9, 4,2)/ 5.53802000d-01, 1.53321425d-03/
      data fpp( 9, 5,1),fpp( 9, 5,2)/-5.03696554d-01,-6.77755317d-03/
      data fpp( 9, 6,1),fpp( 9, 6,2)/ 4.44077780d-01, 1.50663285d-03/
      data fpp( 9, 7,1),fpp( 9, 7,2)/ 5.52546716d-02, 1.47570899d-03/
      data fpp( 9, 8,1),fpp( 9, 8,2)/ 6.40195092d-03, 2.59685602d-04/
      data fpp( 9, 9,1),fpp( 9, 9,2)/-2.31930487d-03, 7.77790023d-05/
      data fpp( 9,10,1),fpp( 9,10,2)/ 1.34975784d-03,-2.28958082d-05/
      data fpp( 9,11,1),fpp( 9,11,2)/ 2.28186422d-03, 1.26783048d-06/
      data fpp( 9,12,1),fpp( 9,12,2)/ 1.59137901d-03,-1.00531372d-06/
      data fpp( 9,13,1),fpp( 9,13,2)/ 7.27054980d-04,-2.01117561d-06/
      data fpp( 9,14,1),fpp( 9,14,2)/-7.08057899d-05,-2.04158385d-06/
      data fpp( 9,15,1),fpp( 9,15,2)/-8.37187695d-04, 3.23711003d-07/
      data fpp( 9,16,1),fpp( 9,16,2)/-1.09029127d-03, 2.60493984d-06/
      data fpp( 9,17,1),fpp( 9,17,2)/-8.74259972d-04, 3.06672965d-06/
      data fpp( 9,18,1),fpp( 9,18,2)/-6.68081775d-04, 1.61674158d-06/
      data fpp( 9,19,1),fpp( 9,19,2)/-4.60286677d-04,-4.46095947d-07/
      data fpp( 9,20,1),fpp( 9,20,2)/-2.08353775d-04,-1.38575779d-06/
      data fpp( 9,21,1),fpp( 9,21,2)/-5.50104199d-05,-9.22872903d-07/
      data fpp( 9,22,1),fpp( 9,22,2)/-9.94993274d-06,-2.95150599d-07/
      data fpp( 9,23,1),fpp( 9,23,2)/ 0.00000000d+00, 2.85475300d-07/
      data fpp(10, 1,1),fpp(10, 1,2)/ 0.00000000d+00,-2.27180447d-04/
      data fpp(10, 2,1),fpp(10, 2,2)/ 1.92698423d-03, 1.55358495d-04/
      data fpp(10, 3,1),fpp(10, 3,2)/ 3.56119696d-02, 8.17693668d-04/
      data fpp(10, 4,1),fpp(10, 4,2)/ 3.23626722d-01, 5.00742031d-04/
      data fpp(10, 5,1),fpp(10, 5,2)/ 1.07892923d+00,-2.79261779d-03/
      data fpp(10, 6,1),fpp(10, 6,2)/ 3.95533148d-01, 5.35988344d-04/
      data fpp(10, 7,1),fpp(10, 7,2)/ 6.23943317d-02, 5.98175619d-04/
      data fpp(10, 8,1),fpp(10, 8,2)/ 1.14738812d-02, 2.06750782d-04/
      data fpp(10, 9,1),fpp(10, 9,2)/ 3.43629836d-03, 3.81852542d-05/
      data fpp(10,10,1),fpp(10,10,2)/ 1.28613620d-03,-1.39755534d-05/
      data fpp(10,11,1),fpp(10,11,2)/ 1.75892836d-03, 5.32359590d-07/
      data fpp(10,12,1),fpp(10,12,2)/ 1.10774218d-03,-1.10248492d-06/
      data fpp(10,13,1),fpp(10,13,2)/ 5.55590808d-04,-1.75641992d-06/
      data fpp(10,14,1),fpp(10,14,2)/ 1.05250418d-05,-1.54023540d-06/
      data fpp(10,15,1),fpp(10,15,2)/-6.61394848d-04, 6.93615340d-08/
      data fpp(10,16,1),fpp(10,16,2)/-1.08740506d-03, 1.87358927d-06/
      data fpp(10,17,1),fpp(10,17,2)/-1.08450556d-03, 2.41068140d-06/
      data fpp(10,18,1),fpp(10,18,2)/-8.38441792d-04, 1.28828515d-06/
      data fpp(10,19,1),fpp(10,19,2)/-5.03814444d-04,-3.33221987d-07/
      data fpp(10,20,1),fpp(10,20,2)/-2.05658201d-04,-1.03599720d-06/
      data fpp(10,21,1),fpp(10,21,2)/-4.10200457d-05,-6.95989216d-07/
      data fpp(10,22,1),fpp(10,22,2)/ 7.11512680d-06,-2.24645938d-07/
      data fpp(10,23,1),fpp(10,23,2)/ 0.00000000d+00, 2.09172969d-07/
      data fpp(11, 1,1),fpp(11, 1,2)/ 0.00000000d+00,-3.79340936d-05/
      data fpp(11, 2,1),fpp(11, 2,2)/ 2.05234724d-03, 5.92365873d-05/
      data fpp(11, 3,1),fpp(11, 3,2)/ 4.58005787d-02, 3.44210944d-04/
      data fpp(11, 4,1),fpp(11, 4,2)/ 1.52245614d-01,-2.81275652d-05/
      data fpp(11, 5,1),fpp(11, 5,2)/ 3.83460149d-01,-6.83707084d-04/
      data fpp(11, 6,1),fpp(11, 6,2)/ 2.14444630d-01,-7.37624997d-05/
      data fpp(11, 7,1),fpp(11, 7,2)/ 5.65780015d-02, 2.74021083d-04/
      data fpp(11, 8,1),fpp(11, 8,2)/ 1.10385244d-02, 1.09280569d-04/
      data fpp(11, 9,1),fpp(11, 9,2)/ 1.85361145d-03, 2.01822406d-05/
      data fpp(11,10,1),fpp(11,10,2)/ 1.24269737d-03,-9.73160638d-06/
      data fpp(11,11,1),fpp(11,11,2)/ 1.36842233d-03, 3.07984922d-07/
      data fpp(11,12,1),fpp(11,12,2)/ 7.87652269d-04,-1.29773331d-06/
      data fpp(11,13,1),fpp(11,13,2)/ 4.34581789d-04,-1.44045168d-06/
      data fpp(11,14,1),fpp(11,14,2)/ 5.57056227d-05,-1.15805995d-06/
      data fpp(11,15,1),fpp(11,15,2)/-5.13232912d-04,-3.59085004d-08/
      data fpp(11,16,1),fpp(11,16,2)/-8.99088482d-04, 1.33709396d-06/
      data fpp(11,17,1),fpp(11,17,2)/-9.79717779d-04, 1.82213268d-06/
      data fpp(11,18,1),fpp(11,18,2)/-7.76651058d-04, 9.93575330d-07/
      data fpp(11,19,1),fpp(11,19,2)/-4.43455546d-04,-2.28433997d-07/
      data fpp(11,20,1),fpp(11,20,2)/-1.64513420d-04,-7.50039341d-07/
      data fpp(11,21,1),fpp(11,21,2)/-3.14093974d-05,-5.17208639d-07/
      data fpp(11,22,1),fpp(11,22,2)/-8.01057445d-06,-1.71526103d-07/
      data fpp(11,23,1),fpp(11,23,2)/ 0.00000000d+00, 1.41913052d-07/
      data fpp(12, 1,1),fpp(12, 1,2)/ 0.00000000d+00, 8.34738793d-05/
      data fpp(12, 2,1),fpp(12, 2,2)/ 1.90262681d-03, 5.65098415d-05/
      data fpp(12, 3,1),fpp(12, 3,2)/ 2.70417157d-02,-8.01692452d-05/
      data fpp(12, 4,1),fpp(12, 4,2)/ 1.80786824d-01, 1.67154339d-04/
      data fpp(12, 5,1),fpp(12, 5,2)/ 2.16917177d-01,-1.62503312d-04/
      data fpp(12, 6,1),fpp(12, 6,2)/ 1.06198333d-01,-1.55185890d-04/
      data fpp(12, 7,1),fpp(12, 7,2)/ 3.45436624d-02, 1.18530872d-04/
      data fpp(12, 8,1),fpp(12, 8,2)/ 8.00502120d-03, 5.14544017d-05/
      data fpp(12, 9,1),fpp(12, 9,2)/ 1.81825586d-03, 8.78352103d-06/
      data fpp(12,10,1),fpp(12,10,2)/ 1.11557431d-03,-6.46996395d-06/
      data fpp(12,11,1),fpp(12,11,2)/ 9.69382315d-04,-1.41065217d-07/
      data fpp(12,12,1),fpp(12,12,2)/ 5.38648743d-04,-1.30577518d-06/
      data fpp(12,13,1),fpp(12,13,2)/ 3.22082035d-04,-1.15903407d-06/
      data fpp(12,14,1),fpp(12,14,2)/ 4.41524674d-05,-8.87888556d-07/
      data fpp(12,15,1),fpp(12,15,2)/-3.26173506d-04,-5.04117084d-08/
      data fpp(12,16,1),fpp(12,16,2)/-6.98241008d-04, 9.40135390d-07/
      data fpp(12,17,1),fpp(12,17,2)/-8.06123321d-04, 1.35027015d-06/
      data fpp(12,18,1),fpp(12,18,2)/-6.49453978d-04, 7.49584016d-07/
      data fpp(12,19,1),fpp(12,19,2)/-3.66863371d-04,-1.49206214d-07/
      data fpp(12,20,1),fpp(12,20,2)/-1.29288120d-04,-5.31959159d-07/
      data fpp(12,21,1),fpp(12,21,2)/-2.68423649d-05,-3.82157149d-07/
      data fpp(12,22,1),fpp(12,22,2)/ 9.27171004d-07,-1.27612243d-07/
      data fpp(12,23,1),fpp(12,23,2)/ 0.00000000d+00, 9.70061215d-08/
      data fpp(13, 1,1),fpp(13, 1,2)/ 0.00000000d+00, 1.06809719d-04/
      data fpp(13, 2,1),fpp(13, 2,2)/-7.79654178d-04, 4.71121619d-05/
      data fpp(13, 3,1),fpp(13, 3,2)/-1.19904381d-02,-1.95377567d-04/
      data fpp(13, 4,1),fpp(13, 4,2)/ 1.24165102d-02, 2.01905305d-04/
      data fpp(13, 5,1),fpp(13, 5,2)/ 1.78566432d-02,-4.95828528d-05/
      data fpp(13, 6,1),fpp(13, 6,2)/ 2.91061369d-02,-4.54370936d-05/
      data fpp(13, 7,1),fpp(13, 7,2)/ 1.28927910d-02, 2.33064272d-05/
      data fpp(13, 8,1),fpp(13, 8,2)/ 3.64624638d-03, 1.68457847d-05/
      data fpp(13, 9,1),fpp(13, 9,2)/ 9.78406164d-04, 3.08834149d-07/
      data fpp(13,10,1),fpp(13,10,2)/ 7.75954039d-04,-3.22519477d-06/
      data fpp(13,11,1),fpp(13,11,2)/ 5.36777398d-04,-7.68855058d-07/
      data fpp(13,12,1),fpp(13,12,2)/ 3.42736012d-04,-1.09018500d-06/
      data fpp(13,13,1),fpp(13,13,2)/ 2.38672023d-04,-8.33204960d-07/
      data fpp(13,14,1),fpp(13,14,2)/ 7.06880270d-05,-5.82195165d-07/
      data fpp(13,15,1),fpp(13,15,2)/-2.05266374d-04,-6.60143805d-08/
      data fpp(13,16,1),fpp(13,16,2)/-4.32804318d-04, 5.67852687d-07/
      data fpp(13,17,1),fpp(13,17,2)/-5.22777076d-04, 8.43203634d-07/
      data fpp(13,18,1),fpp(13,18,2)/-4.36386035d-04, 4.80132779d-07/
      data fpp(13,19,1),fpp(13,19,2)/-2.52818399d-04,-7.39347502d-08/
      data fpp(13,20,1),fpp(13,20,2)/-9.73639856d-05,-3.19993778d-07/
      data fpp(13,21,1),fpp(13,21,2)/-1.52525188d-05,-2.34290137d-07/
      data fpp(13,22,1),fpp(13,22,2)/-2.75018705d-06,-8.02456753d-08/
      data fpp(13,23,1),fpp(13,23,2)/ 0.00000000d+00, 5.42728376d-08/
      data fpp(14, 1,1),fpp(14, 1,2)/ 0.00000000d+00, 5.16913703d-06/
      data fpp(14, 2,1),fpp(14, 2,2)/ 7.25989907d-04,-8.76274059d-07/
      data fpp(14, 3,1),fpp(14, 3,2)/ 1.71820366d-02,-4.11752408d-05/
      data fpp(14, 4,1),fpp(14, 4,2)/-3.88086493d-03, 3.84132372d-05/
      data fpp(14, 5,1),fpp(14, 5,2)/ 7.85558342d-03, 8.44149188d-06/
      data fpp(14, 6,1),fpp(14, 6,2)/ 7.11578618d-03,-7.77760473d-06/
      data fpp(14, 7,1),fpp(14, 7,2)/ 3.70784037d-03, 6.89612705d-06/
      data fpp(14, 8,1),fpp(14, 8,2)/ 1.05265993d-03, 4.51949653d-06/
      data fpp(14, 9,1),fpp(14, 9,2)/ 3.25452817d-04,-1.16851317d-06/
      data fpp(14,10,1),fpp(14,10,2)/ 3.73276198d-04,-1.77820876d-06/
      data fpp(14,11,1),fpp(14,11,2)/ 2.68174762d-04,-9.71851782d-07/
      data fpp(14,12,1),fpp(14,12,2)/ 2.06407209d-04,-8.30584110d-07/
      data fpp(14,13,1),fpp(14,13,2)/ 1.62563205d-04,-5.75411779d-07/
      data fpp(14,14,1),fpp(14,14,2)/ 5.30954246d-05,-3.92768775d-07/
      data fpp(14,15,1),fpp(14,15,2)/-9.07610002d-05,-5.13131198d-08/
      data fpp(14,16,1),fpp(14,16,2)/-2.54541722d-04, 3.45421255d-07/
      data fpp(14,17,1),fpp(14,17,2)/-3.28101709d-04, 5.20628101d-07/
      data fpp(14,18,1),fpp(14,18,2)/-2.81001881d-04, 3.04466342d-07/
      data fpp(14,19,1),fpp(14,19,2)/-1.71863031d-04,-3.92934672d-08/
      data fpp(14,20,1),fpp(14,20,2)/-7.39226038d-05,-1.91092473d-07/
      data fpp(14,21,1),fpp(14,21,2)/-2.81475601d-05,-1.46136642d-07/
      data fpp(14,22,1),fpp(14,22,2)/-1.25975615d-06,-4.57609594d-08/
      data fpp(14,23,1),fpp(14,23,2)/ 0.00000000d+00, 3.87804797d-08/
      data fpp(15, 1,1),fpp(15, 1,2)/ 0.00000000d+00,-2.25913996d-06/
      data fpp(15, 2,1),fpp(15, 2,2)/ 1.59031734d-04,-3.83532008d-06/
      data fpp(15, 3,1),fpp(15, 3,2)/-2.39302606d-03,-1.83707797d-05/
      data fpp(15, 4,1),fpp(15, 4,2)/-7.28440613d-04, 1.24512390d-05/
      data fpp(15, 5,1),fpp(15, 5,2)/-3.61881853d-04, 9.78822381d-06/
      data fpp(15, 6,1),fpp(15, 6,2)/ 2.21886380d-03, 1.31586579d-06/
      data fpp(15, 7,1),fpp(15, 7,2)/ 1.14761169d-03, 4.24431304d-06/
      data fpp(15, 8,1),fpp(15, 8,2)/ 1.64330766d-04, 2.04448207d-06/
      data fpp(15, 9,1),fpp(15, 9,2)/ 1.41266697d-05,-8.66241316d-07/
      data fpp(15,10,1),fpp(15,10,2)/ 1.74187951d-04,-1.27771709d-06/
      data fpp(15,11,1),fpp(15,11,2)/ 1.18960094d-04,-9.51690332d-07/
      data fpp(15,12,1),fpp(15,12,2)/ 1.51359936d-04,-6.66521585d-07/
      data fpp(15,13,1),fpp(15,13,2)/ 1.53175938d-04,-4.45423328d-07/
      data fpp(15,14,1),fpp(15,14,2)/ 7.09908364d-05,-2.93185101d-07/
      data fpp(15,15,1),fpp(15,15,2)/-6.67954388d-05,-4.86362665d-08/
      data fpp(15,16,1),fpp(15,16,2)/-1.78584916d-04, 2.51930167d-07/
      data fpp(15,17,1),fpp(15,17,2)/-2.35825840d-04, 3.78315598d-07/
      data fpp(15,18,1),fpp(15,18,2)/-2.08411542d-04, 2.22607442d-07/
      data fpp(15,19,1),fpp(15,19,2)/-1.28957245d-04,-2.67453642d-08/
      data fpp(15,20,1),fpp(15,20,2)/-5.18410027d-05,-1.38425985d-07/
      data fpp(15,21,1),fpp(15,21,2)/ 1.11657855d-06,-1.01750696d-07/
      data fpp(15,22,1),fpp(15,22,2)/ 4.24061325d-07,-3.29712296d-08/
      data fpp(15,23,1),fpp(15,23,2)/ 0.00000000d+00, 2.66356148d-08/
      data fpp(16, 1,1),fpp(16, 1,2)/ 0.00000000d+00,-1.96339065d-06/
      data fpp(16, 2,1),fpp(16, 2,2)/ 2.98831586d-05,-3.07561869d-06/
      data fpp(16, 3,1),fpp(16, 3,2)/ 3.20567610d-04,-9.93093458d-06/
      data fpp(16, 4,1),fpp(16, 4,2)/-1.80787262d-03, 3.31455702d-06/
      data fpp(16, 5,1),fpp(16, 5,2)/-9.99056007d-04, 7.06950649d-06/
      data fpp(16, 6,1),fpp(16, 6,2)/-3.22241359d-04, 3.84341702d-06/
      data fpp(16, 7,1),fpp(16, 7,2)/-3.10787130d-04, 3.21522544d-06/
      data fpp(16, 8,1),fpp(16, 8,2)/-3.67482996d-04, 1.30288122d-06/
      data fpp(16, 9,1),fpp(16, 9,2)/-2.06459496d-04,-3.55550323d-07/
      data fpp(16,10,1),fpp(16,10,2)/ 1.89719959d-05,-9.70189641d-07/
      data fpp(16,11,1),fpp(16,11,2)/ 8.09848627d-05,-8.39091113d-07/
      data fpp(16,12,1),fpp(16,12,2)/ 1.16653048d-04,-5.32245909d-07/
      data fpp(16,13,1),fpp(16,13,2)/ 1.12733042d-04,-3.46325253d-07/
      data fpp(16,14,1),fpp(16,14,2)/ 6.64412297d-05,-2.17853080d-07/
      data fpp(16,15,1),fpp(16,15,2)/-2.30572445d-05,-3.80624254d-08/
      data fpp(16,16,1),fpp(16,16,2)/-1.18618616d-04, 1.82302782d-07/
      data fpp(16,17,1),fpp(16,17,2)/-1.62594930d-04, 2.76651297d-07/
      data fpp(16,18,1),fpp(16,18,2)/-1.45351950d-04, 1.62492028d-07/
      data fpp(16,19,1),fpp(16,19,2)/-9.08079905d-05,-1.88194109d-08/
      data fpp(16,20,1),fpp(16,20,2)/-3.82133853d-05,-9.80143847d-08/
      data fpp(16,21,1),fpp(16,21,2)/-1.98187541d-05,-7.69230503d-08/
      data fpp(16,22,1),fpp(16,22,2)/ 1.06351085d-06,-2.20934142d-08/
      data fpp(16,23,1),fpp(16,23,2)/ 0.00000000d+00, 2.30967071d-08/
      data fpp(17, 1,1),fpp(17, 1,2)/ 0.00000000d+00,-6.75307423d-07/
      data fpp(17, 2,1),fpp(17, 2,2)/-2.72983512d-05,-1.60978515d-06/
      data fpp(17, 3,1),fpp(17, 3,2)/-5.31207992d-04,-4.51355196d-06/
      data fpp(17, 4,1),fpp(17, 4,2)/-9.98464201d-04,-5.24807002d-07/
      data fpp(17, 5,1),fpp(17, 5,2)/-1.40055874d-03, 3.13757997d-06/
      data fpp(17, 6,1),fpp(17, 6,2)/-1.14977134d-03, 3.26488712d-06/
      data fpp(17, 7,1),fpp(17, 7,2)/-8.67450694d-04, 2.36927155d-06/
      data fpp(17, 8,1),fpp(17, 8,2)/-5.78943859d-04, 1.18522667d-06/
      data fpp(17, 9,1),fpp(17, 9,2)/-3.27552794d-04, 2.12221769d-07/
      data fpp(17,10,1),fpp(17,10,2)/-8.56986207d-05,-6.59878641d-07/
      data fpp(17,11,1),fpp(17,11,2)/-5.25627161d-06,-6.32707206d-07/
      data fpp(17,12,1),fpp(17,12,2)/ 5.55832167d-05,-3.73892536d-07/
      data fpp(17,13,1),fpp(17,13,2)/ 7.87725673d-05,-2.33922650d-07/
      data fpp(17,14,1),fpp(17,14,2)/ 4.92020099d-05,-1.41816864d-07/
      data fpp(17,15,1),fpp(17,15,2)/-4.27889231d-06,-2.26098948d-08/
      data fpp(17,16,1),fpp(17,16,2)/-5.42146700d-05, 1.17056443d-07/
      data fpp(17,17,1),fpp(17,17,2)/-8.37996745d-05, 1.73584122d-07/
      data fpp(17,18,1),fpp(17,18,2)/-7.78858047d-05, 1.01807067d-07/
      data fpp(17,19,1),fpp(17,19,2)/-4.80018686d-05,-9.61239091d-09/
      data fpp(17,20,1),fpp(17,20,2)/-2.13947138d-05,-6.63575035d-08/
      data fpp(17,21,1),fpp(17,21,2)/ 1.31812800d-06,-4.17575952d-08/
      data fpp(17,22,1),fpp(17,22,2)/-2.82774373d-06,-1.74121157d-08/
      data fpp(17,23,1),fpp(17,23,2)/ 0.00000000d+00, 7.00605783d-09/
      data fpp(18, 1,1),fpp(18, 1,2)/ 0.00000000d+00,-1.09426905d-07/
      data fpp(18, 2,1),fpp(18, 2,2)/-1.26897537d-05,-7.65946190d-07/
      data fpp(18, 3,1),fpp(18, 3,2)/-1.18402307d-04,-2.14518834d-06/
      data fpp(18, 4,1),fpp(18, 4,2)/-5.76270577d-04,-9.94900466d-07/
      data fpp(18, 5,1),fpp(18, 5,2)/-8.34709032d-04, 1.00799020d-06/
      data fpp(18, 6,1),fpp(18, 6,2)/-8.59339968d-04, 1.87573966d-06/
      data fpp(18, 7,1),fpp(18, 7,2)/-6.93410096d-04, 1.70825115d-06/
      data fpp(18, 8,1),fpp(18, 8,2)/-4.86074904d-04, 1.13125575d-06/
      data fpp(18, 9,1),fpp(18, 9,2)/-3.25329327d-04, 4.21925853d-07/
      data fpp(18,10,1),fpp(18,10,2)/-1.39510846d-04,-4.55605433d-07/
      data fpp(18,11,1),fpp(18,11,2)/-1.52931096d-05,-4.27704122d-07/
      data fpp(18,12,1),fpp(18,12,2)/ 4.23474188d-05,-2.58178081d-07/
      data fpp(18,13,1),fpp(18,13,2)/ 5.08433553d-05,-1.64983554d-07/
      data fpp(18,14,1),fpp(18,14,2)/ 4.40840638d-05,-9.10877035d-08/
      data fpp(18,15,1),fpp(18,15,2)/ 1.48394804d-05,-7.66563215d-09/
      data fpp(18,16,1),fpp(18,16,2)/-2.58560375d-05, 7.61502321d-08/
      data fpp(18,17,1),fpp(18,17,2)/-4.82063723d-05, 1.09864704d-07/
      data fpp(18,18,1),fpp(18,18,2)/-4.44381645d-05, 6.57909528d-08/
      data fpp(18,19,1),fpp(18,19,2)/-2.85178684d-05,-7.62851498d-09/
      data fpp(18,20,1),fpp(18,20,2)/-9.54109296d-06,-4.12768929d-08/
      data fpp(18,21,1),fpp(18,21,2)/-3.45375789d-06,-2.94639135d-08/
      data fpp(18,22,1),fpp(18,22,2)/ 9.14130715d-07,-1.06674533d-08/
      data fpp(18,23,1),fpp(18,23,2)/ 0.00000000d+00, 6.13372665d-09/
      data fpp(19, 1,1),fpp(19, 1,2)/ 0.00000000d+00, 2.32144537d-08/
      data fpp(19, 2,1),fpp(19, 2,2)/-8.60370486d-06,-4.65628907d-07/
      data fpp(19, 3,1),fpp(19, 3,2)/-1.22176477d-04,-1.32869882d-06/
      data fpp(19, 4,1),fpp(19, 4,2)/-3.33450812d-04,-8.81975797d-07/
      data fpp(19, 5,1),fpp(19, 5,2)/-5.71616732d-04, 3.54202012d-07/
      data fpp(19, 6,1),fpp(19, 6,2)/-6.23143160d-04, 1.19556775d-06/
      data fpp(19, 7,1),fpp(19, 7,2)/-5.36773482d-04, 1.33872700d-06/
      data fpp(19, 8,1),fpp(19, 8,2)/-3.97709694d-04, 9.95124268d-07/
      data fpp(19, 9,1),fpp(19, 9,2)/-2.60524174d-04, 4.26375933d-07/
      data fpp(19,10,1),fpp(19,10,2)/-1.04397837d-04,-3.38489932d-07/
      data fpp(19,11,1),fpp(19,11,2)/-8.15004450d-06,-3.23416205d-07/
      data fpp(19,12,1),fpp(19,12,2)/ 2.48880810d-05,-2.02645247d-07/
      data fpp(19,13,1),fpp(19,13,2)/ 3.81243725d-05,-1.29002807d-07/
      data fpp(19,14,1),fpp(19,14,2)/ 2.47766659d-05,-6.85435252d-08/
      data fpp(19,15,1),fpp(19,15,2)/ 8.72093623d-06,-3.02309240d-09/
      data fpp(19,16,1),fpp(19,16,2)/-1.13978074d-05, 5.90358948d-08/
      data fpp(19,17,1),fpp(19,17,2)/-2.62686269d-05, 8.30795133d-08/
      data fpp(19,18,1),fpp(19,18,2)/-2.59804703d-05, 4.84460519d-08/
      data fpp(19,19,1),fpp(19,19,2)/-1.49078550d-05,-5.66372110d-09/
      data fpp(19,20,1),fpp(19,20,2)/-7.70246458d-06,-3.11911675d-08/
      data fpp(19,21,1),fpp(19,21,2)/-2.70840256d-06,-2.43716087d-08/
      data fpp(19,22,1),fpp(19,22,2)/ 1.70962013d-07,-7.52239750d-09/
      data fpp(19,23,1),fpp(19,23,2)/ 0.00000000d+00, 6.46119875d-09/
      data fpp(20, 1,1),fpp(20, 1,2)/ 0.00000000d+00, 6.72047344d-08/
      data fpp(20, 2,1),fpp(20, 2,2)/-5.39542691d-06,-2.90009469d-07/
      data fpp(20, 3,1),fpp(20, 3,2)/-6.03917853d-05,-8.24766859d-07/
      data fpp(20, 4,1),fpp(20, 4,2)/-2.12426176d-04,-7.38123094d-07/
      data fpp(20, 5,1),fpp(20, 5,2)/-3.51324042d-04, 5.72592344d-08/
      data fpp(20, 6,1),fpp(20, 6,2)/-4.14587394d-04, 7.46686156d-07/
      data fpp(20, 7,1),fpp(20, 7,2)/-3.79995978d-04, 1.03119614d-06/
      data fpp(20, 8,1),fpp(20, 8,2)/-3.11086319d-04, 8.38129278d-07/
      data fpp(20, 9,1),fpp(20, 9,2)/-2.46573979d-04, 3.58686745d-07/
      data fpp(20,10,1),fpp(20,10,2)/-1.04397807d-04,-2.32724874d-07/
      data fpp(20,11,1),fpp(20,11,2)/-3.01067124d-05,-2.49187247d-07/
      data fpp(20,12,1),fpp(20,12,2)/ 1.86002571d-05,-1.53526137d-07/
      data fpp(20,13,1),fpp(20,13,2)/ 2.91591546d-05,-1.03908206d-07/
      data fpp(20,14,1),fpp(20,14,2)/ 3.08092725d-05,-4.82410375d-08/
      data fpp(20,15,1),fpp(20,15,2)/ 8.77677463d-06,-1.32764357d-09/
      data fpp(20,16,1),fpp(20,16,2)/-1.10527329d-05, 4.57516118d-08/
      data fpp(20,17,1),fpp(20,17,2)/-2.07191201d-05, 6.37211964d-08/
      data fpp(20,18,1),fpp(20,18,2)/-2.11399542d-05, 3.59636024d-08/
      data fpp(20,19,1),fpp(20,19,2)/-1.38507117d-05,-5.37560618d-09/
      data fpp(20,20,1),fpp(20,20,2)/-4.64904874d-06,-2.34611777d-08/
      data fpp(20,21,1),fpp(20,21,2)/-2.21263187d-06,-1.95796829d-08/
      data fpp(20,22,1),fpp(20,22,2)/-1.59797877d-06,-5.62009059d-09/
      data fpp(20,23,1),fpp(20,23,2)/ 0.00000000d+00, 5.46004530d-09/
      data fpp(21, 1,1),fpp(21, 1,2)/ 0.00000000d+00, 7.00902264d-08/
      data fpp(21, 2,1),fpp(21, 2,2)/-1.94610707d-06,-1.48980453d-07/
      data fpp(21, 3,1),fpp(21, 3,2)/-2.35763977d-05,-4.34168415d-07/
      data fpp(21, 4,1),fpp(21, 4,2)/-8.69455395d-05,-4.87945887d-07/
      data fpp(21, 5,1),fpp(21, 5,2)/-1.63508705d-04,-1.14848038d-07/
      data fpp(21, 6,1),fpp(21, 6,2)/-2.13946581d-04, 3.95338039d-07/
      data fpp(21, 7,1),fpp(21, 7,2)/-2.23831087d-04, 6.59895882d-07/
      data fpp(21, 8,1),fpp(21, 8,2)/-2.00239142d-04, 5.79478434d-07/
      data fpp(21, 9,1),fpp(21, 9,2)/-1.58070621d-04, 2.69390382d-07/
      data fpp(21,10,1),fpp(21,10,2)/-7.90754202d-05,-1.35510362d-07/
      data fpp(21,11,1),fpp(21,11,2)/-1.12109291d-05,-1.53948933d-07/
      data fpp(21,12,1),fpp(21,12,2)/ 1.04070889d-05,-1.10293906d-07/
      data fpp(21,13,1),fpp(21,13,2)/ 1.73865697d-05,-6.78754418d-08/
      data fpp(21,14,1),fpp(21,14,2)/ 1.07846476d-05,-3.58043265d-08/
      data fpp(21,15,1),fpp(21,15,2)/ 6.26346040d-06, 4.09274787d-09/
      data fpp(21,16,1),fpp(21,16,2)/-3.22568551d-06, 3.20333350d-08/
      data fpp(21,17,1),fpp(21,17,2)/-1.07571816d-05, 4.23739120d-08/
      data fpp(21,18,1),fpp(21,18,2)/-1.12131723d-05, 2.34710169d-08/
      data fpp(21,19,1),fpp(21,19,2)/-7.55905769d-06,-4.25797967d-09/
      data fpp(21,20,1),fpp(21,20,2)/-3.70152781d-06,-1.72390982d-08/
      data fpp(21,21,1),fpp(21,21,2)/ 1.81041259d-07,-1.31856274d-08/
      data fpp(21,22,1),fpp(21,22,2)/ 1.54595455d-06,-3.21839217d-09/
      data fpp(21,23,1),fpp(21,23,2)/ 0.00000000d+00, 5.05919609d-09/
      data fpp(22, 1,1),fpp(22, 1,2)/ 0.00000000d+00, 5.21993214d-08/
      data fpp(22, 2,1),fpp(22, 2,2)/-2.15201246d-07,-4.99986428d-08/
      data fpp(22, 3,1),fpp(22, 3,2)/-6.80045608d-06,-2.07404750d-07/
      data fpp(22, 4,1),fpp(22, 4,2)/-1.49585682d-05,-1.71582356d-07/
      data fpp(22, 5,1),fpp(22, 5,2)/-4.50977195d-05,-1.38265825d-07/
      data fpp(22, 6,1),fpp(22, 6,2)/-7.28585047d-05, 1.70245654d-07/
      data fpp(22, 7,1),fpp(22, 7,2)/-9.43829355d-05, 2.82883207d-07/
      data fpp(22, 8,1),fpp(22, 8,2)/-9.86629547d-05, 2.70221517d-07/
      data fpp(22, 9,1),fpp(22, 9,2)/-8.57496239d-05, 1.31430725d-07/
      data fpp(22,10,1),fpp(22,10,2)/-3.23999715d-05,-2.12029326d-08/
      data fpp(22,11,1),fpp(22,11,2)/-1.06209995d-05,-8.50189943d-08/
      data fpp(22,12,1),fpp(22,12,2)/ 3.77716121d-06,-5.81210904d-08/
      data fpp(22,13,1),fpp(22,13,2)/ 8.70748417d-06,-3.64966443d-08/
      data fpp(22,14,1),fpp(22,14,2)/ 8.92356423d-06,-1.42923325d-08/
      data fpp(22,15,1),fpp(22,15,2)/ 2.21086193d-06, 2.46597445d-09/
      data fpp(22,16,1),fpp(22,16,2)/-3.28616665d-06, 1.76284348d-08/
      data fpp(22,17,1),fpp(22,17,2)/-5.86554670d-06, 2.18202865d-08/
      data fpp(22,18,1),fpp(22,18,2)/-5.67387608d-06, 1.14904192d-08/
      data fpp(22,19,1),fpp(22,19,2)/-3.34058838d-06,-2.98196314d-09/
      data fpp(22,20,1),fpp(22,20,2)/-1.12568175d-06,-9.16256658d-09/
      data fpp(22,21,1),fpp(22,21,2)/-6.91752910d-07,-7.16777054d-09/
      data fpp(22,22,1),fpp(22,22,2)/-7.08267291d-07,-2.36635128d-09/
      data fpp(22,23,1),fpp(22,23,2)/ 0.00000000d+00, 1.63317564d-09/
      data fpp(23, 1,1),fpp(23, 1,2)/ 0.00000000d+00,-3.69410072d-09/
      data fpp(23, 2,1),fpp(23, 2,2)/-7.30879509d-08,-3.38117986d-08/
      data fpp(23, 3,1),fpp(23, 3,2)/ 1.09822204d-06,-5.06587051d-08/
      data fpp(23, 4,1),fpp(23, 4,2)/-1.18601879d-05,-1.13953381d-07/
      data fpp(23, 5,1),fpp(23, 5,2)/-2.25804172d-05,-4.55277701d-08/
      data fpp(23, 6,1),fpp(23, 6,2)/-3.82194001d-05, 4.64644615d-08/
      data fpp(23, 7,1),fpp(23, 7,2)/-4.59171710d-05, 1.18869924d-07/
      data fpp(23, 8,1),fpp(23, 8,2)/-4.47090393d-05, 1.21255842d-07/
      data fpp(23, 9,1),fpp(23, 9,2)/-3.62908828d-05, 8.49067071d-08/
      data fpp(23,10,1),fpp(23,10,2)/-2.26846937d-05,-7.54804231d-09/
      data fpp(23,11,1),fpp(23,11,2)/-5.10507279d-06,-3.85145378d-08/
      data fpp(23,12,1),fpp(23,12,2)/ 1.36426625d-06,-3.27938064d-08/
      data fpp(23,13,1),fpp(23,13,2)/ 3.46349361d-06,-1.75102364d-08/
      data fpp(23,14,1),fpp(23,14,2)/ 2.00109549d-06,-6.36524795d-09/
      data fpp(23,15,1),fpp(23,15,2)/ 1.30918593d-08, 2.17122819d-09/
      data fpp(23,16,1),fpp(23,16,2)/-2.58964789d-06, 9.68033520d-09/
      data fpp(23,17,1),fpp(23,17,2)/-4.18063158d-06, 1.07074310d-08/
      data fpp(23,18,1),fpp(23,18,2)/-3.77132336d-06, 5.68994077d-09/
      data fpp(23,19,1),fpp(23,19,2)/-2.59858878d-06,-2.26719407d-09/
      data fpp(23,20,1),fpp(23,20,2)/-1.15574518d-06,-5.02116448d-09/
      data fpp(23,21,1),fpp(23,21,2)/-5.40296209d-08,-3.44814803d-09/
      data fpp(23,22,1),fpp(23,22,2)/ 8.71146178d-08,-1.58624342d-09/
      data fpp(23,23,1),fpp(23,23,2)/ 0.00000000d+00, 1.93121711d-10/
      data fpp(24, 1,1),fpp(24, 1,2)/ 0.00000000d+00, 1.28279245d-08/
      data fpp(24, 2,1),fpp(24, 2,2)/-2.12446950d-07,-9.65584907d-09/
      data fpp(24, 3,1),fpp(24, 3,2)/-2.87243210d-06,-3.66045283d-08/
      data fpp(24, 4,1),fpp(24, 4,2)/-2.88068037d-06,-4.79260379d-08/
      data fpp(24, 5,1),fpp(24, 5,2)/-7.62061163d-06,-2.12913201d-08/
      data fpp(24, 6,1),fpp(24, 6,2)/-1.25838948d-05, 1.30913184d-08/
      data fpp(24, 7,1),fpp(24, 7,2)/-1.66683805d-05, 5.05260467d-08/
      data fpp(24, 8,1),fpp(24, 8,2)/-1.72208880d-05, 6.32044950d-08/
      data fpp(24, 9,1),fpp(24, 9,2)/-1.72468450d-05, 4.46559732d-08/
      data fpp(24,10,1),fpp(24,10,2)/-8.62125352d-06, 2.98327948d-11/
      data fpp(24,11,1),fpp(24,11,2)/-3.27870931d-06,-2.13753044d-08/
      data fpp(24,12,1),fpp(24,12,2)/ 8.45773789d-07,-1.65286152d-08/
      data fpp(24,13,1),fpp(24,13,2)/ 1.91854138d-06,-7.91023496d-09/
      data fpp(24,14,1),fpp(24,14,2)/ 1.55205379d-06,-2.83044500d-09/
      data fpp(24,15,1),fpp(24,15,2)/-5.83229372d-07, 1.83201498d-09/
      data fpp(24,16,1),fpp(24,16,2)/-1.95524180d-06, 5.10238510d-09/
      data fpp(24,17,1),fpp(24,17,2)/-2.61192698d-06, 5.35844461d-09/
      data fpp(24,18,1),fpp(24,18,2)/-2.52083047d-06, 2.26383646d-09/
      data fpp(24,19,1),fpp(24,19,2)/-1.38505651d-06,-1.21379043d-09/
      data fpp(24,20,1),fpp(24,20,2)/-4.91337545d-07,-2.80867473d-09/
      data fpp(24,21,1),fpp(24,21,2)/-2.92128607d-07,-1.95151065d-09/
      data fpp(24,22,1),fpp(24,22,2)/-1.20191180d-07,-7.85282672d-10/
      data fpp(24,23,1),fpp(24,23,2)/ 0.00000000d+00, 2.92641336d-10/
      data fpp(25, 1,1),fpp(25, 1,2)/ 0.00000000d+00, 9.27692527d-09/
      data fpp(25, 2,1),fpp(25, 2,2)/ 2.02875753d-07,-3.35385054d-09/
      data fpp(25, 3,1),fpp(25, 3,2)/ 7.15063425d-08,-1.98615231d-08/
      data fpp(25, 4,1),fpp(25, 4,2)/-1.33709066d-06,-2.28000570d-08/
      data fpp(25, 5,1),fpp(25, 5,2)/-3.33713626d-06,-8.93824891d-09/
      data fpp(25, 6,1),fpp(25, 6,2)/-6.24502067d-06, 9.53052618d-10/
      data fpp(25, 7,1),fpp(25, 7,2)/-8.36930719d-06, 3.15260384d-08/
      data fpp(25, 8,1),fpp(25, 8,2)/-1.02474087d-05, 1.93427936d-08/
      data fpp(25, 9,1),fpp(25, 9,2)/-8.24173717d-06, 3.03027870d-08/
      data fpp(25,10,1),fpp(25,10,2)/-5.71029218d-06,-2.17975776d-09/
      data fpp(25,11,1),fpp(25,11,2)/-1.94008997d-06,-1.07837559d-08/
      data fpp(25,12,1),fpp(25,12,2)/ 5.26385932d-08,-8.68521852d-09/
      data fpp(25,13,1),fpp(25,13,2)/ 8.62340881d-07,-2.47536998d-09/
      data fpp(25,14,1),fpp(25,14,2)/-2.89310648d-07,-2.41330157d-09/
      data fpp(25,15,1),fpp(25,15,2)/-8.01743715d-08, 2.52857625d-09/
      data fpp(25,16,1),fpp(25,16,2)/-1.10938491d-06, 2.49899658d-09/
      data fpp(25,17,1),fpp(25,17,2)/-1.45166052d-06, 2.47543745d-09/
      data fpp(25,18,1),fpp(25,18,2)/-1.02535477d-06, 1.39925362d-09/
      data fpp(25,19,1),fpp(25,19,2)/-7.41185191d-07,-8.72451937d-10/
      data fpp(25,20,1),fpp(25,20,2)/-4.78904643d-07,-2.10944587d-09/
      data fpp(25,21,1),fpp(25,21,2)/ 2.25440487d-08,-8.89764573d-10/
      data fpp(25,22,1),fpp(25,22,2)/ 1.53650102d-07,-3.31495836d-10/
      data fpp(25,23,1),fpp(25,23,2)/ 0.00000000d+00, 4.15747918d-10/
      data fpp(26, 1,1),fpp(26, 1,2)/ 0.00000000d+00,-6.31910091d-10/
      data fpp(26, 2,1),fpp(26, 2,2)/-1.19056060d-07,-3.93617982d-09/
      data fpp(26, 3,1),fpp(26, 3,2)/-5.35932736d-08,-5.22337064d-09/
      data fpp(26, 4,1),fpp(26, 4,2)/-6.50956983d-07,-1.35703376d-08/
      data fpp(26, 5,1),fpp(26, 5,2)/-1.59084332d-06,-5.29527883d-09/
      data fpp(26, 6,1),fpp(26, 6,2)/-2.51602251d-06, 1.15145294d-09/
      data fpp(26, 7,1),fpp(26, 7,2)/-3.37439078d-06, 1.26894671d-08/
      data fpp(26, 8,1),fpp(26, 8,2)/-3.46947735d-06, 1.52906788d-08/
      data fpp(26, 9,1),fpp(26, 9,2)/-4.02620631d-06, 1.25478176d-08/
      data fpp(26,10,1),fpp(26,10,2)/-2.61757776d-06,-8.88792317d-10/
      data fpp(26,11,1),fpp(26,11,2)/-9.60930794d-07,-5.99264837d-09/
      data fpp(26,12,1),fpp(26,12,2)/ 1.43671838d-07,-3.34061422d-09/
      data fpp(26,13,1),fpp(26,13,2)/ 3.92095101d-07,-2.84489475d-09/
      data fpp(26,14,1),fpp(26,14,2)/ 1.04518880d-06, 1.52019321d-09/
      data fpp(26,15,1),fpp(26,15,2)/-5.60731421d-08,-2.35878103d-10/
      data fpp(26,16,1),fpp(26,16,2)/-8.72185697d-08, 2.42331920d-09/
      data fpp(26,17,1),fpp(26,17,2)/-2.21430957d-07, 1.34260130d-09/
      data fpp(26,18,1),fpp(26,18,2)/-3.37750436d-07, 6.06275595d-10/
      data fpp(26,19,1),fpp(26,19,2)/-2.10202728d-07,-7.67703682d-10/
      data fpp(26,20,1),fpp(26,20,2)/ 6.95611850d-09,-1.13546087d-09/
      data fpp(26,21,1),fpp(26,21,2)/-3.80475879d-08,-6.90452843d-10/
      data fpp(26,22,1),fpp(26,22,2)/-1.44092294d-08,-3.02727759d-10/
      data fpp(26,23,1),fpp(26,23,2)/ 0.00000000d+00, 1.01363880d-10/
      data fpp(27, 1,1),fpp(27, 1,2)/ 0.00000000d+00, 3.79542506d-10/
      data fpp(27, 2,1),fpp(27, 2,2)/ 1.57303028d-08,-7.59085012d-10/
      data fpp(27, 3,1),fpp(27, 3,2)/-5.49733504d-08,-2.14320246d-09/
      data fpp(27, 4,1),fpp(27, 4,2)/-1.98583719d-07,-2.66810516d-09/
      data fpp(27, 5,1),fpp(27, 5,2)/-5.18901909d-07,-1.58437689d-09/
      data fpp(27, 6,1),fpp(27, 6,2)/-9.69422141d-07, 1.80561274d-09/
      data fpp(27, 7,1),fpp(27, 7,2)/-1.41217406d-06, 1.56192593d-09/
      data fpp(27, 8,1),fpp(27, 8,2)/-1.68786361d-06, 3.94668354d-09/
      data fpp(27, 9,1),fpp(27, 9,2)/-1.56051248d-06, 1.85133993d-09/
      data fpp(27,10,1),fpp(27,10,2)/-9.92120641d-07, 2.72638448d-10/
      data fpp(27,11,1),fpp(27,11,2)/-3.47162630d-07,-1.14189372d-09/
      data fpp(27,12,1),fpp(27,12,2)/-3.73348109d-08,-1.10506356d-09/
      data fpp(27,13,1),fpp(27,13,2)/ 7.25442569d-08, 1.36214797d-09/
      data fpp(27,14,1),fpp(27,14,2)/-2.90911087d-07,-4.34352831d-09/
      data fpp(27,15,1),fpp(27,15,2)/-9.16933880d-08, 4.01196526d-09/
      data fpp(27,16,1),fpp(27,16,2)/-2.03651837d-07,-3.04332722d-10/
      data fpp(27,17,1),fpp(27,17,2)/-2.29876869d-07, 8.05365630d-10/
      data fpp(27,18,1),fpp(27,18,2)/-1.54071304d-07, 8.28702013d-11/
      data fpp(27,19,1),fpp(27,19,2)/-7.87992206d-08, 6.31535649d-11/
      data fpp(27,20,1),fpp(27,20,2)/-8.14160339d-08,-9.35484461d-10/
      data fpp(27,21,1),fpp(27,21,2)/-1.71292606d-08, 7.87842779d-11/
      data fpp(27,22,1),fpp(27,22,2)/-3.35973630d-08,-5.79652651d-10/
      data fpp(27,23,1),fpp(27,23,2)/ 0.00000000d+00,-7.60173675d-10/
      data fpp(28, 1,1),fpp(28, 1,2)/ 0.00000000d+00,-7.34413675d-10/
      data fpp(28, 2,1),fpp(28, 2,2)/ 5.61348486d-08,-5.31172651d-10/
      data fpp(28, 3,1),fpp(28, 3,2)/-8.65133248d-08, 4.59104278d-10/
      data fpp(28, 4,1),fpp(28, 4,2)/ 3.65291860d-07,-1.30524446d-09/
      data fpp(28, 5,1),fpp(28, 5,2)/ 8.46450954d-07,-3.81264340d-11/
      data fpp(28, 6,1),fpp(28, 6,2)/ 1.29371107d-06,-9.42249803d-10/
      data fpp(28, 7,1),fpp(28, 7,2)/ 1.52308703d-06, 1.40712565d-09/
      data fpp(28, 8,1),fpp(28, 8,2)/ 1.52093181d-06, 1.13747216d-10/
      data fpp(28, 9,1),fpp(28, 9,2)/ 1.62825624d-06, 5.37885488d-10/
      data fpp(28,10,1),fpp(28,10,2)/ 1.18606032d-06, 7.29469929d-10/
      data fpp(28,11,1),fpp(28,11,2)/ 4.29581315d-07,-4.55765204d-10/
      data fpp(28,12,1),fpp(28,12,2)/-1.74332595d-07, 1.09359089d-09/
      data fpp(28,13,1),fpp(28,13,2)/-3.22272128d-07,-2.11859835d-09/
      data fpp(28,14,1),fpp(28,14,2)/-1.14154446d-06,-1.01919749d-09/
      data fpp(28,15,1),fpp(28,15,2)/-1.17153306d-07, 2.59538831d-09/
      data fpp(28,16,1),fpp(28,16,2)/-5.81740814d-08,-9.62355733d-10/
      data fpp(28,17,1),fpp(28,17,2)/ 6.09384347d-08, 6.54034628d-10/
      data fpp(28,18,1),fpp(28,18,2)/ 1.74035652d-07, 1.46217220d-10/
      data fpp(28,19,1),fpp(28,19,2)/ 1.65399610d-07,-6.38903509d-10/
      data fpp(28,20,1),fpp(28,20,2)/-4.12919831d-08, 6.09396817d-10/
      data fpp(28,21,1),fpp(28,21,2)/-1.34353697d-08,-5.98683758d-10/
      data fpp(28,22,1),fpp(28,22,2)/-9.12013185d-08,-1.46617833d-11/
      data fpp(28,23,1),fpp(28,23,2)/ 0.00000000d+00, 5.73308917d-11/
 
      data fpppp( 1, 1),fpppp( 1, 2)/-4.91468030d-03, 5.27682276d-03/
      data fpppp( 1, 3),fpppp( 1, 4)/-3.95585919d-03, 5.47961064d-02/
      data fpppp( 1, 5),fpppp( 1, 6)/-1.10666069d-01, 7.34580231d-02/
      data fpppp( 1, 7),fpppp( 1, 8)/-4.55469406d-02, 3.85899315d-02/
      data fpppp( 1, 9),fpppp( 1,10)/-9.82766912d-03, 3.05362474d-03/
      data fpppp( 1,11),fpppp( 1,12)/-1.09802821d-03, 3.97092289d-04/
      data fpppp( 1,13),fpppp( 1,14)/-2.42014444d-04, 2.25234835d-04/
      data fpppp( 1,15),fpppp( 1,16)/ 2.21518504d-04,-1.00990028d-04/
      data fpppp( 1,17),fpppp( 1,18)/-5.59653940d-04,-6.01749802d-05/
      data fpppp( 1,19),fpppp( 1,20)/ 2.19003336d-04, 1.03177019d-04/
      data fpppp( 1,21),fpppp( 1,22)/ 2.05560817d-05, 5.87444671d-06/
      data fpppp( 1,23) /            -2.82184175d-05 /
      data fpppp( 2, 1),fpppp( 2, 2)/-7.58644543d-03, 1.21740653d-03/
      data fpppp( 2, 3),fpppp( 2, 4)/ 1.26103562d-02, 1.49414638d-02/
      data fpppp( 2, 5),fpppp( 2, 6)/-5.69262461d-02, 2.72690933d-02/
      data fpppp( 2, 7),fpppp( 2, 8)/-1.02465329d-02, 1.78244942d-02/
      data fpppp( 2, 9),fpppp( 2,10)/-5.08175583d-03, 1.65295420d-03/
      data fpppp( 2,11),fpppp( 2,12)/-6.58384221d-04, 2.65674329d-04/
      data fpppp( 2,13),fpppp( 2,14)/-1.57926096d-04, 1.76631360d-04/
      data fpppp( 2,15),fpppp( 2,16)/ 1.68273858d-04,-7.16644382d-05/
      data fpppp( 2,17),fpppp( 2,18)/-4.28125011d-04,-5.09539799d-05/
      data fpppp( 2,19),fpppp( 2,20)/ 1.65461980d-04, 8.20552922d-05/
      data fpppp( 2,21),fpppp( 2,22)/ 1.50418631d-05, 5.02567045d-06/
      data fpppp( 2,23) /            -2.12754469d-05 /
      data fpppp( 3, 1),fpppp( 3, 2)/-1.65267304d-02, 3.54025598d-03/
      data fpppp( 3, 3),fpppp( 3, 4)/ 1.10895273d-02, 6.24508015d-02/
      data fpppp( 3, 5),fpppp( 3, 6)/-1.50773652d-01, 6.62569432d-02/
      data fpppp( 3, 7),fpppp( 3, 8)/ 1.67316201d-02,-6.26959918d-03/
      data fpppp( 3, 9),fpppp( 3,10)/ 5.96668991d-04,-1.23872567d-03/
      data fpppp( 3,11),fpppp( 3,12)/ 9.69445032d-04,-6.67052190d-05/
      data fpppp( 3,13),fpppp( 3,14)/-9.77865790d-06, 1.12945279d-04/
      data fpppp( 3,15),fpppp( 3,16)/ 1.07741330d-04,-3.29188386d-05/
      data fpppp( 3,17),fpppp( 3,18)/-2.90454806d-04,-2.84473225d-05/
      data fpppp( 3,19),fpppp( 3,20)/ 9.64304225d-05, 6.20333209d-05/
      data fpppp( 3,21),fpppp( 3,22)/ 7.02875203d-06, 5.10221834d-06/
      data fpppp( 3,23) /            -1.19894683d-05 /
      data fpppp( 4, 1),fpppp( 4, 2)/-3.52719587d-03,-1.64748244d-02/
      data fpppp( 4, 3),fpppp( 4, 4)/ 7.28733537d-02,-1.95813792d-01/
      data fpppp( 4, 5),fpppp( 4, 6)/ 2.71934243d-01,-1.92873936d-01/
      data fpppp( 4, 7),fpppp( 4, 8)/ 7.28376647d-02,-1.87133964d-02/
      data fpppp( 4, 9),fpppp( 4,10)/ 3.01130347d-03, 1.08812715d-03/
      data fpppp( 4,11),fpppp( 4,12)/-1.56137413d-03, 3.04280793d-04/
      data fpppp( 4,13),fpppp( 4,14)/-8.58380338d-05, 1.02048321d-04/
      data fpppp( 4,15),fpppp( 4,16)/ 7.27163891d-05,-2.71432742d-05/
      data fpppp( 4,17),fpppp( 4,18)/-1.74279063d-04,-5.24404647d-05/
      data fpppp( 4,19),fpppp( 4,20)/ 8.16145684d-05, 3.81622055d-05/
      data fpppp( 4,21),fpppp( 4,22)/ 7.76176455d-06, 1.94013170d-06/
      data fpppp( 4,23) /            -1.09040178d-05 /
      data fpppp( 5, 1),fpppp( 5, 2)/-7.03636083d-03,-2.19219287d-02/
      data fpppp( 5, 3),fpppp( 5, 4)/ 8.75185750d-02,-2.38182172d-01/
      data fpppp( 5, 5),fpppp( 5, 6)/ 3.12872672d-01,-1.81554624d-01/
      data fpppp( 5, 7),fpppp( 5, 8)/ 5.62440702d-02,-2.00956670d-02/
      data fpppp( 5, 9),fpppp( 5,10)/ 3.21261506d-03,-1.77497084d-03/
      data fpppp( 5,11),fpppp( 5,12)/ 9.56785235d-04,-3.08765007d-04/
      data fpppp( 5,13),fpppp( 5,14)/ 9.07852632d-05, 2.71506106d-05/
      data fpppp( 5,15),fpppp( 5,16)/ 7.61019530d-05,-2.57525951d-05/
      data fpppp( 5,17),fpppp( 5,18)/-1.26039658d-04,-2.78234168d-05/
      data fpppp( 5,19),fpppp( 5,20)/ 5.06124143d-05, 2.97060130d-05/
      data fpppp( 5,21),fpppp( 5,22)/ 2.35045548d-06, 2.24403610d-06/
      data fpppp( 5,23) /            -5.64785132d-06 /
      data fpppp( 6, 1),fpppp( 6, 2)/ 2.63314353d-02, 1.63047871d-02/
      data fpppp( 6, 3),fpppp( 6, 4)/-1.12563600d-01, 1.74514100d-01/
      data fpppp( 6, 5),fpppp( 6, 6)/-1.55665544d-01, 1.64094628d-01/
      data fpppp( 6, 7),fpppp( 6, 8)/-1.04099084d-01, 2.10108986d-02/
      data fpppp( 6, 9),fpppp( 6,10)/-5.21436269d-03, 1.71813604d-03/
      data fpppp( 6,11),fpppp( 6,12)/-4.58287085d-04, 6.77205250d-05/
      data fpppp( 6,13),fpppp( 6,14)/-1.13478973d-05, 3.78674614d-05/
      data fpppp( 6,15),fpppp( 6,16)/ 5.01677794d-05,-1.20524912d-05/
      data fpppp( 6,17),fpppp( 6,18)/-8.57897036d-05,-1.97101332d-05/
      data fpppp( 6,19),fpppp( 6,20)/ 3.63802321d-05, 1.72801764d-05/
      data fpppp( 6,21),fpppp( 6,22)/ 1.76621977d-06, 8.18064974d-07/
      data fpppp( 6,23) /            -4.29174749d-06 /
      data fpppp( 7, 1),fpppp( 7, 2)/ 1.73311040d-03, 6.92971126d-03/
      data fpppp( 7, 3),fpppp( 7, 4)/-5.87361145d-02, 1.23616553d-01/
      data fpppp( 7, 5),fpppp( 7, 6)/-1.24702498d-01, 8.10238805d-02/
      data fpppp( 7, 7),fpppp( 7, 8)/-2.30153659d-02,-4.12519015d-03/
      data fpppp( 7, 9),fpppp( 7,10)/ 8.43113050d-04,-6.89936391d-04/
      data fpppp( 7,11),fpppp( 7,12)/ 1.77650847d-04,-7.74742261d-05/
      data fpppp( 7,13),fpppp( 7,14)/ 2.64694704d-05, 5.66382492d-06/
      data fpppp( 7,15),fpppp( 7,16)/ 2.95812180d-05,-1.17987366d-06/
      data fpppp( 7,17),fpppp( 7,18)/-3.52020135d-05,-7.24043440d-06/
      data fpppp( 7,19),fpppp( 7,20)/ 1.43342199d-05, 6.34451366d-06/
      data fpppp( 7,21),fpppp( 7,22)/-1.00720805d-06, 1.59021598d-07/
      data fpppp( 7,23) /            -1.10844914d-06 /
      data fpppp( 8, 1),fpppp( 8, 2)/ 2.31112446d-02, 3.35784492d-03/
      data fpppp( 8, 3),fpppp( 8, 4)/-4.91292911d-02, 1.29516503d-02/
      data fpppp( 8, 5),fpppp( 8, 6)/ 5.53698810d-02, 2.02277921d-02/
      data fpppp( 8, 7),fpppp( 8, 8)/-5.42082472d-02, 1.16118968d-02/
      data fpppp( 8, 9),fpppp( 8,10)/-3.52887453d-03, 1.18941715d-03/
      data fpppp( 8,11),fpppp( 8,12)/-3.46531824d-04, 7.94608221d-05/
      data fpppp( 8,13),fpppp( 8,14)/-1.74322354d-05, 5.75180051d-06/
      data fpppp( 8,15),fpppp( 8,16)/ 1.41013534d-05, 5.01140515d-06/
      data fpppp( 8,17),fpppp( 8,18)/-1.24539244d-05,-2.34082059d-06/
      data fpppp( 8,19),fpppp( 8,20)/ 5.40533606d-06, 6.64669571d-07/
      data fpppp( 8,21),fpppp( 8,22)/-1.14143775d-06,-3.80851319d-07/
      data fpppp( 8,23) /            -3.53605959d-07 /
      data fpppp( 9, 1),fpppp( 9, 2)/-1.09916645d-02,-1.48298592d-02/
      data fpppp( 9, 3),fpppp( 9, 4)/ 7.54831280d-02,-1.63733021d-01/
      data fpppp( 9, 5),fpppp( 9, 6)/ 1.97374714d-01,-1.44500343d-01/
      data fpppp( 9, 7),fpppp( 9, 8)/ 5.98432696d-02,-1.32798427d-02/
      data fpppp( 9, 9),fpppp( 9,10)/ 2.90765277d-03,-8.16342520d-04/
      data fpppp( 9,11),fpppp( 9,12)/ 1.93499923d-04,-5.50126664d-05/
      data fpppp( 9,13),fpppp( 9,14)/ 1.61204132d-05,-5.48119097d-06/
      data fpppp( 9,15),fpppp( 9,16)/ 7.69308250d-06, 5.50556104d-06/
      data fpppp( 9,17),fpppp( 9,18)/-1.56723477d-06, 1.72192267d-07/
      data fpppp( 9,19),fpppp( 9,20)/ 9.75479717d-07,-1.42584287d-06/
      data fpppp( 9,21),fpppp( 9,22)/-1.18748108d-06,-3.21204856d-07/
      data fpppp( 9,23) /             3.65667245d-07 /
      data fpppp(10, 1),fpppp(10, 2)/-9.05520015d-03, 4.11561923d-03/
      data fpppp(10, 3),fpppp(10, 4)/ 2.14643532d-04, 5.60649506d-02/
      data fpppp(10, 5),fpppp(10, 6)/-1.12325385d-01, 4.79489303d-02/
      data fpppp(10, 7),fpppp(10, 8)/ 4.59140720d-03, 1.41784857d-03/
      data fpppp(10, 9),fpppp(10,10)/ 2.90867875d-05, 3.93155607d-05/
      data fpppp(10,11),fpppp(10,12)/-2.89717708d-05, 9.13282131d-06/
      data fpppp(10,13),fpppp(10,14)/-1.61742584d-06,-2.23798158d-06/
      data fpppp(10,15),fpppp(10,16)/ 2.95810471d-06, 5.16014326d-06/
      data fpppp(10,17),fpppp(10,18)/ 2.13590519d-06, 8.86092164d-07/
      data fpppp(10,19),fpppp(10,20)/-3.66459191d-07,-1.60852170d-06/
      data fpppp(10,21),fpppp(10,22)/-1.21053925d-06,-5.39500302d-07/
      data fpppp(10,23) /             5.35225015d-08 /
      data fpppp(11, 1),fpppp(11, 2)/ 3.79117707d-04, 2.56519715d-03/
      data fpppp(11, 3),fpppp(11, 4)/-6.32894085d-04, 1.50136120d-02/
      data fpppp(11, 5),fpppp(11, 6)/-2.94768739d-02, 6.83867026d-03/
      data fpppp(11, 7),fpppp(11, 8)/ 4.79792661d-03, 9.28139629d-04/
      data fpppp(11, 9),fpppp(11,10)/ 2.14610258d-04,-4.23658774d-05/
      data fpppp(11,11),fpppp(11,12)/-9.48406517d-07, 3.76980232d-06/
      data fpppp(11,13),fpppp(11,14)/-4.68827878d-07,-3.44283199d-06/
      data fpppp(11,15),fpppp(11,16)/ 2.83641379d-06, 3.08215466d-06/
      data fpppp(11,17),fpppp(11,18)/ 3.14854400d-06, 1.34543045d-06/
      data fpppp(11,19),fpppp(11,20)/-7.22538431d-07,-1.71047981d-06/
      data fpppp(11,21),fpppp(11,22)/-1.18582860d-06,-1.28517739d-07/
      data fpppp(11,23) /             7.76604651d-07 /
      data fpppp(12, 1),fpppp(12, 2)/-2.63702780d-03,-3.67133565d-04/
      data fpppp(12, 3),fpppp(12, 4)/ 9.68231296d-03,-7.49667354d-03/
      data fpppp(12, 5),fpppp(12, 6)/-7.92316011d-03, 3.94550666d-03/
      data fpppp(12, 7),fpppp(12, 8)/ 1.51653517d-03, 8.16199688d-04/
      data fpppp(12, 9),fpppp(12,10)/ 1.03116284d-04,-1.71977467d-05/
      data fpppp(12,11),fpppp(12,12)/-9.35923854d-07, 3.86894775d-06/
      data fpppp(12,13),fpppp(12,14)/-1.68985528d-06,-7.91298284d-07/
      data fpppp(12,15),fpppp(12,16)/-6.88735898d-07, 3.44175010d-06/
      data fpppp(12,17),fpppp(12,18)/ 2.77284689d-06, 1.33996177d-06/
      data fpppp(12,19),fpppp(12,20)/-5.77418156d-07,-1.73121053d-06/
      data fpppp(12,21),fpppp(12,22)/-6.05509408d-07,-3.27325008d-07/
      data fpppp(12,23) /             1.93007027d-07 /
      data fpppp(13, 1),fpppp(13, 2)/-2.04772712d-03,-8.40190270d-04/
      data fpppp(13, 3),fpppp(13, 4)/ 2.90501707d-03,-2.23162230d-03/
      data fpppp(13, 5),fpppp(13, 6)/ 1.46943645d-03,-2.25187693d-03/
      data fpppp(13, 7),fpppp(13, 8)/ 9.46989755d-04, 1.35950228d-04/
      data fpppp(13, 9),fpppp(13,10)/ 8.80983804d-05,-2.42765566d-05/
      data fpppp(13,11),fpppp(13,12)/ 6.80437503d-06,-2.32828170d-07/
      data fpppp(13,13),fpppp(13,14)/-4.74418556d-07,-1.70469804d-06/
      data fpppp(13,15),fpppp(13,16)/ 8.14986469d-07, 1.34973956d-06/
      data fpppp(13,17),fpppp(13,18)/ 2.03996643d-06, 1.07222262d-06/
      data fpppp(13,19),fpppp(13,20)/-4.98261196d-07,-7.65971157d-07/
      data fpppp(13,21),fpppp(13,22)/-8.38430994d-07,-5.68529774d-08/
      data fpppp(13,23) /             4.80714224d-07 /
      data fpppp(14, 1),fpppp(14, 2)/ 2.49617484d-03, 1.15517755d-03/
      data fpppp(14, 3),fpppp(14, 4)/-3.34167142d-03, 3.20696052d-03/
      data fpppp(14, 5),fpppp(14, 6)/-1.61432667d-03, 2.56047225d-04/
      data fpppp(14, 7),fpppp(14, 8)/-5.02178831d-05, 1.25487995d-04/
      data fpppp(14, 9),fpppp(14,10)/ 1.09794991d-05,-5.54823824d-06/
      data fpppp(14,11),fpppp(14,12)/ 2.03796488d-06,-3.58827728d-09/
      data fpppp(14,13),fpppp(14,14)/-9.48198836d-07,-1.41043000d-07/
      data fpppp(14,15),fpppp(14,16)/-5.50947801d-07, 1.14937641d-06/
      data fpppp(14,17),fpppp(14,18)/ 1.36668621d-06, 6.23467720d-07/
      data fpppp(14,19),fpppp(14,20)/-1.38215801d-07,-7.42509849d-07/
      data fpppp(14,21),fpppp(14,22)/-2.16678313d-08,-3.04053211d-07/
      data fpppp(14,23) /            -2.99802192d-07 /
      data fpppp(15, 1),fpppp(15, 2)/-3.59466848d-04,-1.60615670d-04/
      data fpppp(15, 3),fpppp(15, 4)/ 3.51268040d-04,-2.32462112d-04/
      data fpppp(15, 5),fpppp(15, 6)/ 2.67054001d-04,-3.04349041d-04/
      data fpppp(15, 7),fpppp(15, 8)/ 7.38627002d-05, 3.00113238d-05/
      data fpppp(15, 9),fpppp(15,10)/ 6.03044342d-06,-5.46882369d-06/
      data fpppp(15,11),fpppp(15,12)/ 2.92750296d-06,-9.83526192d-07/
      data fpppp(15,13),fpppp(15,14)/-8.28428570d-07,-7.42825772d-07/
      data fpppp(15,15),fpppp(15,16)/ 4.63661246d-07, 4.47988693d-07/
      data fpppp(15,17),fpppp(15,18)/ 1.01729711d-06, 5.62136227d-07/
      data fpppp(15,19),fpppp(15,20)/-1.43442043d-07,-1.28651402d-07/
      data fpppp(15,21),fpppp(15,22)/-7.91471981d-07, 7.55334149d-08/
      data fpppp(15,23) /             5.05445675d-07 /
      data fpppp(16, 1),fpppp(16, 2)/ 1.00296498d-04, 4.50972363d-05/
      data fpppp(16, 3),fpppp(16, 4)/-2.18093133d-04, 2.46685374d-04/
      data fpppp(16, 5),fpppp(16, 6)/-6.37067221d-05,-2.35389561d-05/
      data fpppp(16, 7),fpppp(16, 8)/-1.82395439d-06, 1.44787509d-05/
      data fpppp(16, 9),fpppp(16,10)/-3.83840162d-06,-1.52110112d-06/
      data fpppp(16,11),fpppp(16,12)/ 1.17688618d-07,-5.30334251d-07/
      data fpppp(16,13),fpppp(16,14)/-3.71643063d-07,-5.25401905d-07/
      data fpppp(16,15),fpppp(16,16)/-1.19149025d-07, 6.38224182d-07/
      data fpppp(16,17),fpppp(16,18)/ 6.61355754d-07, 3.89510387d-07/
      data fpppp(16,19),fpppp(16,20)/ 1.86615100d-08,-5.81117695d-07/
      data fpppp(16,21),fpppp(16,22)/ 2.53810834d-07,-2.84867614d-07/
      data fpppp(16,23) /            -4.31086926d-07 /
      data fpppp(17, 1),fpppp(17, 2)/-3.83798108d-05,-2.14949109d-05/
      data fpppp(17, 3),fpppp(17, 4)/ 9.97274497d-06,-9.59924523d-06/
      data fpppp(17, 5),fpppp(17, 6)/ 4.40630368d-05,-9.96123539d-06/
      data fpppp(17, 7),fpppp(17, 8)/ 3.34988149d-06,-1.95360412d-06/
      data fpppp(17, 9),fpppp(17,10)/-4.44325002d-06,-1.34912515d-06/
      data fpppp(17,11),fpppp(17,12)/ 1.55041165d-07,-4.47211155d-07/
      data fpppp(17,13),fpppp(17,14)/-6.25204806d-07,-2.17564100d-07/
      data fpppp(17,15),fpppp(17,16)/ 6.08405134d-08, 1.86909521d-07/
      data fpppp(17,17),fpppp(17,18)/ 4.12567788d-07, 2.92751795d-07/
      data fpppp(17,19),fpppp(17,20)/-1.45370997d-07, 9.21253196d-08/
      data fpppp(17,21),fpppp(17,22)/-4.56789066d-07, 1.23508135d-07/
      data fpppp(17,23) /             3.81173454d-07 /
      data fpppp(18, 1),fpppp(18, 2)/ 5.07589742d-06,-5.83897388d-07/
      data fpppp(18, 3),fpppp(18, 4)/-2.50657798d-05, 1.63296443d-05/
      data fpppp(18, 5),fpppp(18, 6)/ 7.61035825d-06, 9.34272711d-06/
      data fpppp(18, 7),fpppp(18, 8)/ 7.53327181d-07,-2.41875902d-06/
      data fpppp(18, 9),fpppp(18,10)/-2.25979880d-06,-1.51584428d-07/
      data fpppp(18,11),fpppp(18,12)/-8.29908107d-07,-5.23415649d-07/
      data fpppp(18,13),fpppp(18,14)/-2.51048105d-08,-2.91478788d-07/
      data fpppp(18,15),fpppp(18,16)/-1.58097553d-07, 2.36812925d-07/
      data fpppp(18,17),fpppp(18,18)/ 3.11556848d-07, 8.40722290d-08/
      data fpppp(18,19),fpppp(18,20)/ 8.12795399d-08,-2.25801627d-07/
      data fpppp(18,21),fpppp(18,22)/ 4.85605444d-08,-7.16073386d-08/
      data fpppp(18,23) /            -7.90523490d-08 /
      data fpppp(19, 1),fpppp(19, 2)/-4.50161884d-06,-4.17445075d-06/
      data fpppp(19, 3),fpppp(19, 4)/-3.99315430d-06,-3.30130711d-06/
      data fpppp(19, 5),fpppp(19, 6)/ 1.07444023d-05, 5.11717582d-06/
      data fpppp(19, 7),fpppp(19, 8)/ 1.88195988d-06, 1.57088313d-09/
      data fpppp(19, 9),fpppp(19,10)/-2.33902732d-06,-7.83857858d-08/
      data fpppp(19,11),fpppp(19,12)/-9.40142211d-07, 4.63746255d-08/
      data fpppp(19,13),fpppp(19,14)/-4.33466332d-07, 9.24508153d-08/
      data fpppp(19,15),fpppp(19,16)/-9.88183122d-08, 5.90415960d-08/
      data fpppp(19,17),fpppp(19,18)/ 1.77527376d-07, 1.40387466d-07/
      data fpppp(19,19),fpppp(19,20)/-9.20097160d-08,-4.38209834d-09/
      data fpppp(19,21),fpppp(19,22)/-2.31415933d-08,-2.99333748d-08/
      data fpppp(19,23) /            -4.01445029d-08 /
      data fpppp(20, 1),fpppp(20, 2)/-3.67083791d-07,-1.42297614d-06/
      data fpppp(20, 3),fpppp(20, 4)/-5.84523520d-06, 1.51478923d-06/
      data fpppp(20, 5),fpppp(20, 6)/ 2.93884406d-06, 4.88211812d-06/
      data fpppp(20, 7),fpppp(20, 8)/ 1.01782769d-06,-7.17050571d-07/
      data fpppp(20, 9),fpppp(20,10)/ 7.95017940d-07,-1.23743896d-06/
      data fpppp(20,11),fpppp(20,12)/ 8.16332282d-08,-6.24141434d-07/
      data fpppp(20,13),fpppp(20,14)/ 1.26048185d-07,-4.14578076d-07/
      data fpppp(20,15),fpppp(20,16)/ 1.11307165d-07, 1.01528841d-07/
      data fpppp(20,17),fpppp(20,18)/ 9.23646847d-08, 8.37456084d-08/
      data fpppp(20,19),fpppp(20,20)/ 3.52574817d-08,-1.10030310d-07/
      data fpppp(20,21),fpppp(20,22)/-1.05100519d-09, 4.92850452d-09/
      data fpppp(20,23) /             4.03365272d-08 /
      data fpppp(21, 1),fpppp(21, 2)/ 1.80299374d-08,-6.33788509d-07/
      data fpppp(21, 3),fpppp(21, 4)/-2.20707997d-06,-5.55215886d-07/
      data fpppp(21, 5),fpppp(21, 6)/ 1.26137787d-06, 1.77977376d-06/
      data fpppp(21, 7),fpppp(21, 8)/ 1.35233595d-06, 8.45230644d-07/
      data fpppp(21, 9),fpppp(21,10)/-2.74880392d-07, 8.15154780d-08/
      data fpppp(21,11),fpppp(21,12)/-7.19024135d-07, 1.97926754d-08/
      data fpppp(21,13),fpppp(21,14)/-2.38458798d-07, 1.19158339d-07/
      data fpppp(21,15),fpppp(21,16)/-1.13330461d-07, 3.60859807d-08/
      data fpppp(21,17),fpppp(21,18)/ 8.64455255d-08, 4.26622446d-08/
      data fpppp(21,19),fpppp(21,20)/-1.04881869d-08, 1.14954183d-08/
      data fpppp(21,21),fpppp(21,22)/-3.39911344d-08,-2.65902279d-08/
      data fpppp(21,23) /            -3.43000241d-08 /
      data fpppp(22, 1),fpppp(22, 2)/-3.82246927d-07,-3.83688283d-07/
      data fpppp(22, 3),fpppp(22, 4)/ 3.88187200d-07,-1.54654626d-06/
      data fpppp(22, 5),fpppp(22, 6)/ 5.22548401d-07, 2.71605256d-08/
      data fpppp(22, 7),fpppp(22, 8)/ 8.65534558d-07, 6.49360040d-07/
      data fpppp(22, 9),fpppp(22,10)/ 6.63429256d-07,-6.63588332d-07/
      data fpppp(22,11),fpppp(22,12)/ 9.66832459d-08,-1.65993327d-07/
      data fpppp(22,13),fpppp(22,14)/-7.80205973d-10,-1.13740423d-07/
      data fpppp(22,15),fpppp(22,16)/ 4.00149562d-08, 2.66210208d-08/
      data fpppp(22,17),fpppp(22,18)/ 2.85598730d-08, 2.54025267d-08/
      data fpppp(22,19),fpppp(22,20)/-1.67295460d-09,-2.58135724d-08/
      data fpppp(22,21),fpppp(22,22)/-1.93142309d-09, 6.51267126d-09/
      data fpppp(22,23) /             1.93676384d-08 /
      data fpppp(23, 1),fpppp(23, 2)/ 5.98897359d-07, 1.81462464d-07/
      data fpppp(23, 3),fpppp(23, 4)/-1.02609171d-06, 5.31771584d-07/
      data fpppp(23, 5),fpppp(23, 6)/-5.63831295d-07, 5.43052741d-07/
      data fpppp(23, 7),fpppp(23, 8)/ 2.97511216d-07, 4.04319011d-07/
      data fpppp(23, 9),fpppp(23,10)/-1.84381286d-07, 1.57176906d-07/
      data fpppp(23,11),fpppp(23,12)/-2.05920421d-07,-1.12137533d-10/
      data fpppp(23,13),fpppp(23,14)/-5.58377298d-08, 9.76552767d-09/
      data fpppp(23,15),fpppp(23,16)/-1.47607119d-08, 1.23931532d-08/
      data fpppp(23,17),fpppp(23,18)/ 2.58934621d-08, 4.05051339d-09/
      data fpppp(23,19),fpppp(23,20)/ 3.71006635d-09,-2.68423785d-09/
      data fpppp(23,21),fpppp(23,22)/-1.34407977d-08,-1.18685011d-09/
      data fpppp(23,23) /             4.49266680d-09 /
      data fpppp(24, 1),fpppp(24, 2)/-2.75371772d-07,-1.50903045d-07/
      data fpppp(24, 3),fpppp(24, 4)/ 2.91574785d-07,-3.78979243d-07/
      data fpppp(24, 5),fpppp(24, 6)/ 8.87382700d-08,-2.95782948d-08/
      data fpppp(24, 7),fpppp(24, 8)/ 2.40486315d-07,-8.46922213d-08/
      data fpppp(24, 9),fpppp(24,10)/ 2.24654699d-07,-1.10967655d-07/
      data fpppp(24,11),fpppp(24,12)/ 2.22330836d-08,-5.10483463d-08/
      data fpppp(24,13),fpppp(24,14)/-1.14262921d-09,-3.07364474d-08/
      data fpppp(24,15),fpppp(24,16)/ 1.79606845d-08, 4.68995334d-09/
      data fpppp(24,17),fpppp(24,18)/ 6.19913751d-09, 1.53803976d-08/
      data fpppp(24,19),fpppp(24,20)/-5.04008113d-09,-9.74337280d-09/
      data fpppp(24,21),fpppp(24,22)/ 2.34297086d-09,-1.26480132d-09/
      data fpppp(24,23) /            -3.88540399d-10 /
      data fpppp(25, 1),fpppp(25, 2)/ 2.08371411d-08,-6.34510711d-09/
      data fpppp(25, 3),fpppp(25, 4)/-7.56755517d-08, 2.51269105d-09/
      data fpppp(25, 5),fpppp(25, 6)/-7.63228753d-08, 8.48974958d-08/
      data fpppp(25, 7),fpppp(25, 8)/-7.52036143d-08, 2.75001373d-07/
      data fpppp(25, 9),fpppp(25,10)/-9.26963684d-08, 5.17945384d-08/
      data fpppp(25,11),fpppp(25,12)/-4.01563519d-08, 2.18245088d-09/
      data fpppp(25,13),fpppp(25,14)/-3.95550284d-08, 3.83564338d-08/
      data fpppp(25,15),fpppp(25,16)/-3.22234384d-08, 1.62365111d-08/
      data fpppp(25,17),fpppp(25,18)/ 8.49348962d-09,-4.09558845d-09/
      data fpppp(25,19),fpppp(25,20)/-6.39305355d-10, 5.33946772d-09/
      data fpppp(25,21),fpppp(25,22)/-6.36847686d-09,-2.08611857d-09/
      data fpppp(25,23) /            -2.37241823d-09 /
      data fpppp(26, 1),fpppp(26, 2)/ 3.94351415d-08, 1.10596058d-08/
      data fpppp(26, 3),fpppp(26, 4)/-3.93890416d-08,-1.25817983d-08/
      data fpppp(26, 5),fpppp(26, 6)/ 7.51080422d-09,-1.39317028d-08/
      data fpppp(26, 7),fpppp(26, 8)/ 6.42506265d-08,-5.98831949d-08/
      data fpppp(26, 9),fpppp(26,10)/ 6.44879801d-08,-1.21971544d-08/
      data fpppp(26,11),fpppp(26,12)/-8.18258034d-10,-1.76524732d-08/
      data fpppp(26,13),fpppp(26,14)/ 2.00573888d-08,-3.82968554d-08/
      data fpppp(26,15),fpppp(26,16)/ 2.78686941d-08,-8.97093000d-09/
      data fpppp(26,17),fpppp(26,18)/ 1.83100825d-09, 2.72047154d-09/
      data fpppp(26,19),fpppp(26,20)/ 1.91913683d-09,-5.02035057d-09/
      data fpppp(26,21),fpppp(26,22)/ 2.43251227d-09,-5.91174612d-10/
      data fpppp(26,23) /            -6.21561573d-10 /
      data fpppp(27, 1),fpppp(27, 2)/-3.74925519d-09,-3.95574356d-09/
      data fpppp(27, 3),fpppp(27, 4)/-1.17192000d-09,-8.85418816d-09/
      data fpppp(27, 5),fpppp(27, 6)/-5.82120435d-09, 8.90515341d-10/
      data fpppp(27, 7),fpppp(27, 8)/ 4.12353739d-09, 2.27103041d-08/
      data fpppp(27, 9),fpppp(27,10)/ 1.76500979d-09, 2.17119331d-09/
      data fpppp(27,11),fpppp(27,12)/-5.85581284d-09, 1.14424658d-09/
      data fpppp(27,13),fpppp(27,14)/-1.07180986d-08, 1.33280830d-08/
      data fpppp(27,15),fpppp(27,16)/-8.83385082d-09, 3.33675141d-09/
      data fpppp(27,17),fpppp(27,18)/ 6.30850219d-10, 2.61683565d-10/
      data fpppp(27,19),fpppp(27,20)/-1.70959340d-09, 1.90335625d-09/
      data fpppp(27,21),fpppp(27,22)/-1.88961641d-09, 8.09816841d-10/
      data fpppp(27,23) /             1.65427697d-09 /
      data fpppp(28, 1),fpppp(28, 2)/-3.71905734d-08,-1.29317262d-08/
      data fpppp(28, 3),fpppp(28, 4)/ 4.12095529d-08,-9.23767970d-09/
      data fpppp(28, 5),fpppp(28, 6)/ 2.78610436d-09,-1.00424926d-08/
      data fpppp(28, 7),fpppp(28, 8)/-1.49083310d-08, 1.41083322d-08/
      data fpppp(28, 9),fpppp(28,10)/-1.52498796d-08,-7.15214523d-10/
      data fpppp(28,11),fpppp(28,12)/-7.46247346d-10, 1.28541097d-08/
      data fpppp(28,13),fpppp(28,14)/-2.33117287d-08, 4.01128375d-08/
      data fpppp(28,15),fpppp(28,16)/-2.65198127d-08, 8.04169783d-09/
      data fpppp(28,17),fpppp(28,18)/-2.03898111d-09,-2.46691323d-10/
      data fpppp(28,19),fpppp(28,20)/-4.27824914d-09, 5.47635478d-09/
      data fpppp(28,21),fpppp(28,22)/-3.55427758d-09, 2.40340180d-09/
      data fpppp(28,23) /             4.07870640d-09 /
 
      c(1,1)=fpppp(ix+1,iy+1)
      c(1,2)=fpppp(ix+1,iy  )
      c(2,1)=fpppp(ix  ,iy+1)
      c(2,2)=fpppp(ix,  iy  )
      c(1,3)=fpp(ix+1,iy+1,1)
      c(1,4)=fpp(ix+1,iy  ,1)
      c(2,3)=fpp(ix,  iy+1,1)
      c(2,4)=fpp(ix,  iy,  1)
      c(3,1)=fpp(ix+1,iy+1,2)
      c(3,2)=fpp(ix+1,iy  ,2)
      c(4,1)=fpp(ix,  iy+1,2)
      c(4,2)=fpp(ix,  iy,  2)
      c(3,3)=f(ix+1,iy+1)
      c(3,4)=f(ix+1,iy  )
      c(4,3)=f(ix,  iy+1)
      c(4,4)=f(ix,  iy  )
      px(1)=((xi-xix)**3/(6.0*delxi))-(xi-xix)*delxi/6.0
      px(2)=(xi-xixp1)*delxi/6.0-((xi-xixp1)**3/(6.0*delxi))
      px(3)=(xi-xix)/delxi
      px(4)=(xixp1-xi)/delxi
      py(1)=((yi-yiy)**3/(6.0*delyi))-(yi-yiy)*delyi/6.0
      py(2)=(yi-yiyp1)*delyi/6.0-((yi-yiyp1)**3/(6.0*delyi))
      py(3)=(yi-yiy)/delyi
      py(4)=(yiyp1-yi)/delyi

      fi=0.0d 00
      do l=1,4
        sum=0.0d 00
        do i=1,4
          sum=sum + c(i,l) * px(i)
        enddo
        fi = fi + sum * py(l)
      enddo
      return
      end  
      subroutine c5_spl(xi,yi,ix,iy,delxi,delyi,xix,xixp1,
     x                    yiy,yiyp1,fi)
      implicit real*8 (a-h,o-z)
      dimension fpp(28,23,2),f(28,23),fpppp(28,23)
      dimension c(4,4),px(4),py(4)
 
      data f( 2, 9),f( 2,10) / -5.71923000d-03 , -4.78500000d-03 /
      data f( 2,11),f( 2,12) / -3.76386000d-03 , -1.58677000d-03 /
      data f( 2,13),f( 2,14) / -3.38120000d-04 ,  4.70900000d-05 /
      data f( 2,15),f( 2,16) /  1.11980000d-04 ,  4.48600000d-05 /
      data f( 2,17),f( 2,18) / -3.47200000d-05 , -6.89500000d-05 /
      data f( 2,19),f( 2,20) / -4.85300000d-05 , -1.62500000d-05 /
      data f( 2,21),f( 2,22) / -2.07000000d-06 , -6.00000000d-08 /
      data f( 2,23) /           0.00000000d+00 /
      data f( 3, 1),f( 3, 2) /  0.00000000d+00 , -1.10350000d-04 /
      data f( 3, 3),f( 3, 4) / -3.53690000d-03 , -2.42665300d-02 /
      data f( 3, 5),f( 3, 6) / -5.08789700d-02 , -3.70331400d-02 /
      data f( 3, 7),f( 3, 8) / -1.68531200d-02 , -8.56100000d-03 /
      data f( 3, 9),f( 3,10) / -5.72914000d-03 , -4.46801000d-03 /
      data f( 3,11),f( 3,12) / -3.01896000d-03 , -1.18824000d-03 /
      data f( 3,13),f( 3,14) / -2.38280000d-04 ,  5.15700000d-05 /
      data f( 3,15),f( 3,16) /  1.25900000d-04 ,  7.57400000d-05 /
      data f( 3,17),f( 3,18) / -2.17000000d-06 , -3.68600000d-05 /
      data f( 3,19),f( 3,20) / -2.71900000d-05 , -8.61000000d-06 /
      data f( 3,21),f( 3,22) / -8.00000000d-07 , -5.00000000d-08 /
      data f( 3,23) /           0.00000000d+00 /
      data f( 4, 1),f( 4, 2) /  0.00000000d+00 , -1.46470000d-04 /
      data f( 4, 3),f( 4, 4) / -4.92550000d-03 , -3.67716900d-02 /
      data f( 4, 5),f( 4, 6) / -7.72780600d-02 , -5.09490600d-02 /
      data f( 4, 7),f( 4, 8) / -2.07033400d-02 , -8.88795000d-03 /
      data f( 4, 9),f( 4,10) / -5.31902000d-03 , -4.70411000d-03 /
      data f( 4,11),f( 4,12) / -2.47378000d-03 , -8.82680000d-04 /
      data f( 4,13),f( 4,14) / -1.72180000d-04 ,  5.23700000d-05 /
      data f( 4,15),f( 4,16) /  1.32890000d-04 ,  1.02050000d-04 /
      data f( 4,17),f( 4,18) /  3.15800000d-05 , -5.60000000d-06 /
      data f( 4,19),f( 4,20) / -8.65000000d-06 , -2.00000000d-06 /
      data f( 4,21),f( 4,22) /  1.00000000d-07 ,  1.00000000d-08 /
      data f( 4,23) /           0.00000000d+00 /
      data f( 5, 1),f( 5, 2) /  0.00000000d+00 , -1.82110000d-04 /
      data f( 5, 3),f( 5, 4) / -6.48550000d-03 , -5.26857600d-02 /
      data f( 5, 5),f( 5, 6) / -9.70305800d-02 , -6.85126900d-02 /
      data f( 5, 7),f( 5, 8) / -2.41663700d-02 , -9.40307000d-03 /
      data f( 5, 9),f( 5,10) / -5.23023000d-03 , -3.99040000d-03 /
      data f( 5,11),f( 5,12) / -2.00648000d-03 , -6.55210000d-04 /
      data f( 5,13),f( 5,14) / -1.27010000d-04 ,  5.09700000d-05 /
      data f( 5,15),f( 5,16) /  1.34160000d-04 ,  1.21790000d-04 /
      data f( 5,17),f( 5,18) /  6.21700000d-05 ,  2.11600000d-05 /
      data f( 5,19),f( 5,20) /  6.89000000d-06 ,  3.20000000d-06 /
      data f( 5,21),f( 5,22) /  8.70000000d-07 , -1.00000000d-08 /
      data f( 5,23) /           0.00000000d+00 /
      data f( 6, 1),f( 6, 2) /  0.00000000d+00 , -2.11470000d-04 /
      data f( 6, 3),f( 6, 4) / -7.84296000d-03 , -6.86477200d-02 /
      data f( 6, 5),f( 6, 6) / -1.05152300d-01 , -8.44828300d-02 /
      data f( 6, 7),f( 6, 8) / -2.68619600d-02 , -9.70196000d-03 /
      data f( 6, 9),f( 6,10) / -5.06401000d-03 , -3.37383000d-03 /
      data f( 6,11),f( 6,12) / -1.61108000d-03 , -4.86860000d-04 /
      data f( 6,13),f( 6,14) / -9.48000000d-05 ,  4.80100000d-05 /
      data f( 6,15),f( 6,16) /  1.30580000d-04 ,  1.34040000d-04 /
      data f( 6,17),f( 6,18) /  8.60700000d-05 ,  4.24000000d-05 /
      data f( 6,19),f( 6,20) /  1.89400000d-05 ,  7.26000000d-06 /
      data f( 6,21),f( 6,22) /  1.49000000d-06 ,  2.00000000d-08 /
      data f( 6,23) /           0.00000000d+00 /
      data f( 7, 1),f( 7, 2) /  0.00000000d+00 , -2.57510000d-04 /
      data f( 7, 3),f( 7, 4) / -8.97763000d-03 , -8.00478100d-02 /
      data f( 7, 5),f( 7, 6) / -1.11026420d-01 , -9.33524100d-02 /
      data f( 7, 7),f( 7, 8) / -2.92929400d-02 , -1.00725100d-02 /
      data f( 7, 9),f( 7,10) / -4.93394000d-03 , -2.43756000d-03 /
      data f( 7,11),f( 7,12) / -1.00933000d-03 , -2.68620000d-04 /
      data f( 7,13),f( 7,14) / -5.45600000d-05 ,  3.97000000d-05 /
      data f( 7,15),f( 7,16) /  1.14740000d-04 ,  1.38790000d-04 /
      data f( 7,17),f( 7,18) /  1.10390000d-04 ,  6.78000000d-05 /
      data f( 7,19),f( 7,20) /  3.35900000d-05 ,  1.19500000d-05 /
      data f( 7,21),f( 7,22) /  2.17000000d-06 ,  4.00000000d-08 /
      data f( 7,23) /           0.00000000d+00 /
      data f( 8, 1),f( 8, 2) /  0.00000000d+00 , -1.96620000d-04 /
      data f( 8, 3),f( 8, 4) / -7.53380000d-03 , -6.86641600d-02 /
      data f( 8, 5),f( 8, 6) / -1.13049450d-01 , -8.27635300d-02 /
      data f( 8, 7),f( 8, 8) / -2.61234800d-02 , -8.24267000d-03 /
      data f( 8, 9),f( 8,10) / -4.09057000d-03 , -1.71217000d-03 /
      data f( 8,11),f( 8,12) / -6.05040000d-04 , -1.45890000d-04 /
      data f( 8,13),f( 8,14) / -3.20600000d-05 ,  3.09400000d-05 /
      data f( 8,15),f( 8,16) /  9.41300000d-05 ,  1.25680000d-04 /
      data f( 8,17),f( 8,18) /  1.11880000d-04 ,  7.50700000d-05 /
      data f( 8,19),f( 8,20) /  3.85100000d-05 ,  1.33600000d-05 /
      data f( 8,21),f( 8,22) /  2.35000000d-06 ,  4.00000000d-08 /
      data f( 8,23) /           0.00000000d+00 /
      data f( 9, 1),f( 9, 2) /  0.00000000d+00 , -1.42320000d-04 /
      data f( 9, 3),f( 9, 4) / -4.96784000d-03 , -3.89420700d-02 /
      data f( 9, 5),f( 9, 6) / -8.39478600d-02 , -5.15004600d-02 /
      data f( 9, 7),f( 9, 8) / -1.75936800d-02 , -6.27563000d-03 /
      data f( 9, 9),f( 9,10) / -3.01334000d-03 , -1.14084000d-03 /
      data f( 9,11),f( 9,12) / -3.41450000d-04 , -7.59000000d-05 /
      data f( 9,13),f( 9,14) / -1.91400000d-05 ,  2.31800000d-05 /
      data f( 9,15),f( 9,16) /  7.34600000d-05 ,  1.05030000d-04 /
      data f( 9,17),f( 9,18) /  1.00290000d-04 ,  7.08000000d-05 /
      data f( 9,19),f( 9,20) /  3.68700000d-05 ,  1.26700000d-05 /
      data f( 9,21),f( 9,22) /  2.09000000d-06 ,  4.00000000d-08 /
      data f( 9,23) /           0.00000000d+00 /
      data f(10, 1),f(10, 2) /  0.00000000d+00 , -8.47800000d-05 /
      data f(10, 3),f(10, 4) / -2.72022000d-03 , -1.80488600d-02 /
      data f(10, 5),f(10, 6) / -3.78141000d-02 , -2.63768800d-02 /
      data f(10, 7),f(10, 8) / -1.10660200d-02 , -4.36467000d-03 /
      data f(10, 9),f(10,10) / -2.10273000d-03 , -7.06150000d-04 /
      data f(10,11),f(10,12) / -1.75120000d-04 , -3.62300000d-05 /
      data f(10,13),f(10,14) / -1.14400000d-05 ,  1.68100000d-05 /
      data f(10,15),f(10,16) /  5.55200000d-05 ,  8.29100000d-05 /
      data f(10,17),f(10,18) /  8.32000000d-05 ,  6.06300000d-05 /
      data f(10,19),f(10,20) /  3.18400000d-05 ,  1.07300000d-05 /
      data f(10,21),f(10,22) /  1.75000000d-06 , -7.00000000d-08 /
      data f(10,23) /           0.00000000d+00 /
      data f(11, 1),f(11, 2) /  0.00000000d+00 , -3.96100000d-05 /
      data f(11, 3),f(11, 4) / -1.21536000d-03 , -7.39343000d-03 /
      data f(11, 5),f(11, 6) / -1.41474700d-02 , -1.27816600d-02 /
      data f(11, 7),f(11, 8) / -6.43334000d-03 , -2.79196000d-03 /
      data f(11, 9),f(11,10) / -1.35087000d-03 , -3.92960000d-04 /
      data f(11,11),f(11,12) / -7.40600000d-05 , -1.42500000d-05 /
      data f(11,13),f(11,14) / -6.93000000d-06 ,  1.19200000d-05 /
      data f(11,15),f(11,16) /  4.09300000d-05 ,  6.34100000d-05 /
      data f(11,17),f(11,18) /  6.55200000d-05 ,  4.88300000d-05 /
      data f(11,19),f(11,20) /  2.56900000d-05 ,  8.58000000d-06 /
      data f(11,21),f(11,22) /  1.33000000d-06 ,  4.00000000d-08 /
      data f(11,23) /           0.00000000d+00 /
      data f(12, 1),f(12, 2) /  0.00000000d+00 , -1.42300000d-05 /
      data f(12, 3),f(12, 4) / -5.14610000d-04 , -1.01227000d-03 /
      data f(12, 5),f(12, 6) / -4.93190000d-03 , -5.99512000d-03 /
      data f(12, 7),f(12, 8) / -3.48148000d-03 , -1.63124000d-03 /
      data f(12, 9),f(12,10) / -7.77740000d-04 , -1.82070000d-04 /
      data f(12,11),f(12,12) / -1.63500000d-05 , -2.63000000d-06 /
      data f(12,13),f(12,14) / -4.20000000d-06 ,  8.39000000d-06 /
      data f(12,15),f(12,16) /  2.94700000d-05 ,  4.70600000d-05 /
      data f(12,17),f(12,18) /  4.98600000d-05 ,  3.75800000d-05 /
      data f(12,19),f(12,20) /  1.98100000d-05 ,  6.57000000d-06 /
      data f(12,21),f(12,22) /  9.80000000d-07 ,  0.00000000d+00 /
      data f(12,23) /           0.00000000d+00 /
      data f(13, 1),f(13, 2) /  0.00000000d+00 , -6.90000000d-06 /
      data f(13, 3),f(13, 4) / -1.57980000d-04 ,  7.19040000d-04 /
      data f(13, 5),f(13, 6) / -1.01481000d-03 , -1.74867000d-03 /
      data f(13, 7),f(13, 8) / -1.18955000d-03 , -5.70070000d-04 /
      data f(13, 9),f(13,10) / -2.35540000d-04 , -8.88000000d-06 /
      data f(13,11),f(13,12) /  2.20000000d-05 ,  4.64000000d-06 /
      data f(13,13),f(13,14) / -1.96000000d-06 ,  4.82000000d-06 /
      data f(13,15),f(13,16) /  1.80500000d-05 ,  2.94600000d-05 /
      data f(13,17),f(13,18) /  3.18300000d-05 ,  2.42700000d-05 /
      data f(13,19),f(13,20) /  1.28200000d-05 ,  4.17000000d-06 /
      data f(13,21),f(13,22) /  6.20000000d-07 , -1.00000000d-08 /
      data f(13,23) /           0.00000000d+00 /
      data f(14, 1),f(14, 2) /  0.00000000d+00 ,  6.60000000d-07 /
      data f(14, 3),f(14, 4) /  6.44000000d-05 ,  1.93950000d-04 /
      data f(14, 5),f(14, 6) / -1.60220000d-04 , -3.89540000d-04 /
      data f(14, 7),f(14, 8) / -2.63860000d-04 , -8.25000000d-05 /
      data f(14, 9),f(14,10) /  1.52700000d-05 ,  5.60800000d-05 /
      data f(14,11),f(14,12) /  3.07700000d-05 ,  6.06000000d-06 /
      data f(14,13),f(14,14) / -9.20000000d-07 ,  2.81000000d-06 /
      data f(14,15),f(14,16) /  1.10100000d-05 ,  1.81400000d-05 /
      data f(14,17),f(14,18) /  1.99200000d-05 ,  1.53300000d-05 /
      data f(14,19),f(14,20) /  8.10000000d-06 ,  2.67000000d-06 /
      data f(14,21),f(14,22) /  4.60000000d-07 , -3.00000000d-08 /
      data f(14,23) /           0.00000000d+00 /
      data f(15, 1),f(15, 2) /  0.00000000d+00 ,  1.53000000d-06 /
      data f(15, 3),f(15, 4) /  4.09100000d-05 ,  1.03950000d-04 /
      data f(15, 5),f(15, 6) /  8.78000000d-06 , -6.70300000d-05 /
      data f(15, 7),f(15, 8) / -1.72500000d-05 ,  5.16400000d-05 /
      data f(15, 9),f(15,10) /  8.08500000d-05 ,  6.70400000d-05 /
      data f(15,11),f(15,12) /  2.94000000d-05 ,  5.77000000d-06 /
      data f(15,13),f(15,14) / -6.20000000d-07 ,  2.01000000d-06 /
      data f(15,15),f(15,16) /  8.03000000d-06 ,  1.32100000d-05 /
      data f(15,17),f(15,18) /  1.44600000d-05 ,  1.11700000d-05 /
      data f(15,19),f(15,20) /  5.98000000d-06 ,  2.03000000d-06 /
      data f(15,21),f(15,22) /  3.10000000d-07 ,  4.00000000d-08 /
      data f(15,23) /           0.00000000d+00 /
      data f(16, 1),f(16, 2) /  0.00000000d+00 ,  9.40000000d-07 /
      data f(16, 3),f(16, 4) /  2.17500000d-05 ,  6.47100000d-05 /
      data f(16, 5),f(16, 6) /  6.40300000d-05 ,  5.71400000d-05 /
      data f(16, 7),f(16, 8) /  8.11700000d-05 ,  1.02080000d-04 /
      data f(16, 9),f(16,10) /  1.01300000d-04 ,  6.52800000d-05 /
      data f(16,11),f(16,12) /  2.58100000d-05 ,  5.00000000d-06 /
      data f(16,13),f(16,14) / -3.50000000d-07 ,  1.41000000d-06 /
      data f(16,15),f(16,16) /  5.79000000d-06 ,  9.71000000d-06 /
      data f(16,17),f(16,18) /  1.06100000d-05 ,  8.22000000d-06 /
      data f(16,19),f(16,20) /  4.40000000d-06 ,  1.47000000d-06 /
      data f(16,21),f(16,22) /  4.10000000d-07 ,  8.00000000d-08 /
      data f(16,23) /           0.00000000d+00 /
      data f(17, 1),f(17, 2) /  0.00000000d+00 ,  4.30000000d-07 /
      data f(17, 3),f(17, 4) /  8.90000000d-06 ,  3.51800000d-05 /
      data f(17, 5),f(17, 6) /  6.50600000d-05 ,  8.81200000d-05 /
      data f(17, 7),f(17, 8) /  1.02720000d-04 ,  1.03830000d-04 /
      data f(17, 9),f(17,10) /  9.22100000d-05 ,  5.28800000d-05 /
      data f(17,11),f(17,12) /  1.93500000d-05 ,  3.97000000d-06 /
      data f(17,13),f(17,14) / -1.70000000d-07 ,  5.20000000d-07 /
      data f(17,15),f(17,16) /  3.63000000d-06 ,  6.02000000d-06 /
      data f(17,17),f(17,18) /  6.67000000d-06 ,  5.12000000d-06 /
      data f(17,19),f(17,20) /  2.72000000d-06 ,  1.01000000d-06 /
      data f(17,21),f(17,22) /  1.60000000d-07 ,  0.00000000d+00 /
      data f(17,23) /           0.00000000d+00 /
      data f(18, 1),f(18, 2) /  0.00000000d+00 ,  2.10000000d-07 /
      data f(18, 3),f(18, 4) /  4.11000000d-06 ,  1.90200000d-05 /
      data f(18, 5),f(18, 6) /  4.29600000d-05 ,  6.50700000d-05 /
      data f(18, 7),f(18, 8) /  7.75600000d-05 ,  7.81800000d-05 /
      data f(18, 9),f(18,10) /  6.90900000d-05 ,  3.85800000d-05 /
      data f(18,11),f(18,12) /  1.38100000d-05 ,  2.95000000d-06 /
      data f(18,13),f(18,14) / -6.00000000d-08 ,  4.30000000d-07 /
      data f(18,15),f(18,16) /  2.17000000d-06 ,  3.71000000d-06 /
      data f(18,17),f(18,18) /  4.16000000d-06 ,  3.31000000d-06 /
      data f(18,19),f(18,20) /  1.84000000d-06 ,  7.70000000d-07 /
      data f(18,21),f(18,22) /  1.20000000d-07 ,  2.00000000d-08 /
      data f(18,23) /           0.00000000d+00 /
      data f(19, 1),f(19, 2) /  0.00000000d+00 ,  1.60000000d-07 /
      data f(19, 3),f(19, 4) /  2.51000000d-06 ,  1.21700000d-05 /
      data f(19, 5),f(19, 6) /  2.96700000d-05 ,  4.76500000d-05 /
      data f(19, 7),f(19, 8) /  5.88500000d-05 ,  6.06700000d-05 /
      data f(19, 9),f(19,10) /  5.42000000d-05 ,  3.00700000d-05 /
      data f(19,11),f(19,12) /  1.08200000d-05 ,  2.40000000d-06 /
      data f(19,13),f(19,14) / -3.00000000d-08 ,  3.00000000d-07 /
      data f(19,15),f(19,16) /  1.58000000d-06 ,  2.82000000d-06 /
      data f(19,17),f(19,18) /  3.03000000d-06 ,  2.44000000d-06 /
      data f(19,19),f(19,20) /  1.35000000d-06 ,  3.70000000d-07 /
      data f(19,21),f(19,22) /  7.00000000d-08 ,  2.00000000d-08 /
      data f(19,23) /           0.00000000d+00 /
      data f(20, 1),f(20, 2) /  0.00000000d+00 ,  1.30000000d-07 /
      data f(20, 3),f(20, 4) /  1.57000000d-06 ,  7.89000000d-06 /
      data f(20, 5),f(20, 6) /  1.98000000d-05 ,  3.35800000d-05 /
      data f(20, 7),f(20, 8) /  4.32500000d-05 ,  4.60000000d-05 /
      data f(20, 9),f(20,10) /  4.17900000d-05 ,  2.30400000d-05 /
      data f(20,11),f(20,12) /  8.52000000d-06 ,  1.91000000d-06 /
      data f(20,13),f(20,14) / -2.00000000d-08 ,  1.40000000d-07 /
      data f(20,15),f(20,16) /  1.16000000d-06 ,  1.94000000d-06 /
      data f(20,17),f(20,18) /  2.20000000d-06 ,  1.70000000d-06 /
      data f(20,19),f(20,20) /  9.10000000d-07 ,  3.00000000d-07 /
      data f(20,21),f(20,22) /  1.00000000d-08 ,  1.00000000d-08 /
      data f(20,23) /           0.00000000d+00 /
      data f(21, 1),f(21, 2) /  0.00000000d+00 ,  1.00000000d-07 /
      data f(21, 3),f(21, 4) /  7.70000000d-07 ,  4.01000000d-06 /
      data f(21, 5),f(21, 6) /  1.08900000d-05 ,  1.97200000d-05 /
      data f(21, 7),f(21, 8) /  2.69100000d-05 ,  2.95700000d-05 /
      data f(21, 9),f(21,10) /  2.72900000d-05 ,  1.51400000d-05 /
      data f(21,11),f(21,12) /  5.77000000d-06 ,  1.41000000d-06 /
      data f(21,13),f(21,14) /  0.00000000d+00 ,  1.70000000d-07 /
      data f(21,15),f(21,16) /  7.30000000d-07 ,  1.24000000d-06 /
      data f(21,17),f(21,18) /  1.38000000d-06 ,  1.07000000d-06 /
      data f(21,19),f(21,20) /  6.00000000d-07 ,  1.50000000d-07 /
      data f(21,21),f(21,22) /  3.00000000d-08 , -6.00000000d-08 /
      data f(21,23) /           0.00000000d+00 /
      data f(22, 1),f(22, 2) /  0.00000000d+00 ,  2.00000000d-08 /
      data f(22, 3),f(22, 4) /  3.10000000d-07 ,  1.22000000d-06 /
      data f(22, 5),f(22, 6) /  4.46000000d-06 ,  8.43000000d-06 /
      data f(22, 7),f(22, 8) /  1.20600000d-05 ,  1.35900000d-05 /
      data f(22, 9),f(22,10) /  1.26300000d-05 ,  7.54000000d-06 /
      data f(22,11),f(22,12) /  3.01000000d-06 ,  7.90000000d-07 /
      data f(22,13),f(22,14) /  6.00000000d-08 ,  8.00000000d-08 /
      data f(22,15),f(22,16) /  3.40000000d-07 ,  5.60000000d-07 /
      data f(22,17),f(22,18) /  6.00000000d-07 ,  4.60000000d-07 /
      data f(22,19),f(22,20) /  2.50000000d-07 ,  8.00000000d-08 /
      data f(22,21),f(22,22) /  2.00000000d-08 ,  0.00000000d+00 /
      data f(22,23) /           0.00000000d+00 /
      data f(23, 1),f(23, 2) /  0.00000000d+00 ,  2.00000000d-08 /
      data f(23, 3),f(23, 4) /  1.00000000d-08 ,  6.30000000d-07 /
      data f(23, 5),f(23, 6) /  1.90000000d-06 ,  3.65000000d-06 /
      data f(23, 7),f(23, 8) /  5.31000000d-06 ,  6.07000000d-06 /
      data f(23, 9),f(23,10) /  5.90000000d-06 ,  3.75000000d-06 /
      data f(23,11),f(23,12) /  1.61000000d-06 ,  4.30000000d-07 /
      data f(23,13),f(23,14) /  5.00000000d-08 ,  5.00000000d-08 /
      data f(23,15),f(23,16) /  1.70000000d-07 ,  2.60000000d-07 /
      data f(23,17),f(23,18) /  2.70000000d-07 ,  2.10000000d-07 /
      data f(23,19),f(23,20) /  1.10000000d-07 ,  4.00000000d-08 /
      data f(23,21),f(23,22) /  1.00000000d-08 ,  1.00000000d-08 /
      data f(23,23) /           0.00000000d+00 /
      data f(24, 1),f(24, 2) /  0.00000000d+00 ,  1.00000000d-08 /
      data f(24, 3),f(24, 4) /  1.20000000d-07 ,  2.00000000d-07 /
      data f(24, 5),f(24, 6) /  7.70000000d-07 ,  1.56000000d-06 /
      data f(24, 7),f(24, 8) /  2.34000000d-06 ,  2.83000000d-06 /
      data f(24, 9),f(24,10) /  2.83000000d-06 ,  1.91000000d-06 /
      data f(24,11),f(24,12) /  8.40000000d-07 ,  2.30000000d-07 /
      data f(24,13),f(24,14) /  4.00000000d-08 ,  3.00000000d-08 /
      data f(24,15),f(24,16) /  9.00000000d-08 ,  1.20000000d-07 /
      data f(24,17),f(24,18) /  1.20000000d-07 ,  9.00000000d-08 /
      data f(24,19),f(24,20) /  4.00000000d-08 ,  1.00000000d-08 /
      data f(24,21),f(24,22) /  0.00000000d+00 ,  0.00000000d+00 /
      data f(24,23) /           0.00000000d+00 /
      data f(25, 1),f(25, 2) /  0.00000000d+00 ,  0.00000000d+00 /
      data f(25, 3),f(25, 4) / -1.00000000d-08 ,  1.20000000d-07 /
      data f(25, 5),f(25, 6) /  3.80000000d-07 ,  7.30000000d-07 /
      data f(25, 7),f(25, 8) /  1.11000000d-06 ,  1.29000000d-06 /
      data f(25, 9),f(25,10) /  1.36000000d-06 ,  9.60000000d-07 /
      data f(25,11),f(25,12) /  4.30000000d-07 ,  1.20000000d-07 /
      data f(25,13),f(25,14) /  2.00000000d-08 ,  3.00000000d-08 /
      data f(25,15),f(25,16) /  5.00000000d-08 ,  6.00000000d-08 /
      data f(25,17),f(25,18) /  6.00000000d-08 ,  4.00000000d-08 /
      data f(25,19),f(25,20) /  2.00000000d-08 ,  2.00000000d-08 /
      data f(25,21),f(25,22) /  0.00000000d+00 ,  1.00000000d-08 /
      data f(25,23) /           0.00000000d+00 /
      data f(26, 1),f(26, 2) /  0.00000000d+00 ,  0.00000000d+00 /
      data f(26, 3),f(26, 4) /  1.00000000d-08 ,  5.00000000d-08 /
      data f(26, 5),f(26, 6) /  1.60000000d-07 ,  3.40000000d-07 /
      data f(26, 7),f(26, 8) /  5.20000000d-07 ,  6.50000000d-07 /
      data f(26, 9),f(26,10) /  6.80000000d-07 ,  4.80000000d-07 /
      data f(26,11),f(26,12) /  2.00000000d-07 ,  5.00000000d-08 /
      data f(26,13),f(26,14) /  2.00000000d-08 , -1.00000000d-08 /
      data f(26,15),f(26,16) /  3.00000000d-08 ,  3.00000000d-08 /
      data f(26,17),f(26,18) /  4.00000000d-08 ,  3.00000000d-08 /
      data f(26,19),f(26,20) /  2.00000000d-08 ,  1.00000000d-08 /
      data f(26,21),f(26,22) /  0.00000000d+00 ,  1.00000000d-08 /
      data f(26,23) /           0.00000000d+00 /
      data f(27, 1),f(27, 2) /  0.00000000d+00 ,  0.00000000d+00 /
      data f(27, 3),f(27, 4) /  0.00000000d+00 ,  1.00000000d-08 /
      data f(27, 5),f(27, 6) /  4.00000000d-08 ,  8.00000000d-08 /
      data f(27, 7),f(27, 8) /  1.20000000d-07 ,  1.50000000d-07 /
      data f(27, 9),f(27,10) /  1.50000000d-07 ,  1.00000000d-07 /
      data f(27,11),f(27,12) /  5.00000000d-08 ,  2.00000000d-08 /
      data f(27,13),f(27,14) /  1.00000000d-08 ,  8.00000000d-08 /
      data f(27,15),f(27,16) /  6.00000000d-08 ,  1.00000000d-08 /
      data f(27,17),f(27,18) /  2.00000000d-08 ,  1.00000000d-08 /
      data f(27,19),f(27,20) /  0.00000000d+00 ,  1.00000000d-08 /
      data f(27,21),f(27,22) /  1.00000000d-08 ,  2.00000000d-08 /
      data f(27,23) /           0.00000000d+00 /
      data f(28, 1),f(28, 2) /  0.00000000d+00 , -1.00000000d-08 /
      data f(28, 3),f(28, 4) /  0.00000000d+00 ,  0.00000000d+00 /
      data f(28, 5),f(28, 6) /  0.00000000d+00 ,  1.00000000d-08 /
      data f(28, 7),f(28, 8) /  3.00000000d-08 ,  3.00000000d-08 /
      data f(28, 9),f(28,10) /  3.00000000d-08 ,  4.00000000d-08 /
      data f(28,11),f(28,12) /  2.00000000d-08 ,  1.00000000d-08 /
      data f(28,13),f(28,14) /  0.00000000d+00 , -2.00000000d-08 /
      data f(28,15),f(28,16) / -2.00000000d-08 ,  0.00000000d+00 /
      data f(28,17),f(28,18) /  1.00000000d-08 ,  0.00000000d+00 /
      data f(28,19),f(28,20) /  0.00000000d+00 , -3.00000000d-08 /
      data f(28,21),f(28,22) /  0.00000000d+00 ,  0.00000000d+00 /
      data f(28,23) /           0.00000000d+00 /
 
      data fpp( 1, 1,1),fpp( 1, 1,2)/ 0.00000000d+00, 8.28820031d-05/
      data fpp( 1, 2,1),fpp( 1, 2,2)/-1.06552327d-03,-6.94456061d-05/
      data fpp( 1, 3,1),fpp( 1, 3,2)/-3.16689961d-02,-1.66313979d-04/
      data fpp( 1, 4,1),fpp( 1, 4,2)/ 2.01161402d-01,-4.57289679d-04/
      data fpp( 1, 5,1),fpp( 1, 5,2)/-9.07268993d-01, 8.47269496d-04/
      data fpp( 1, 6,1),fpp( 1, 6,2)/-3.57080707d-01, 9.68988956d-05/
      data fpp( 1, 7,1),fpp( 1, 7,2)/ 6.83600108d-02,-8.84114784d-05/
      data fpp( 1, 8,1),fpp( 1, 8,2)/-8.67941116d-02,-1.24149782d-04/
      data fpp( 1, 9,1),fpp( 1, 9,2)/-2.82532268d-02,-4.06525930d-05/
      data fpp( 1,10,1),fpp( 1,10,2)/ 6.83462401d-02,-1.19812996d-06/
      data fpp( 1,11,1),fpp( 1,11,2)/ 2.47331975d-02, 3.36701128d-05/
      data fpp( 1,12,1),fpp( 1,12,2)/-6.63121997d-03,-1.86633213d-05/
      data fpp( 1,13,1),fpp( 1,13,2)/-8.35716550d-03,-9.72282757d-06/
      data fpp( 1,14,1),fpp( 1,14,2)/-8.97995606d-04,-4.50996843d-06/
      data fpp( 1,15,1),fpp( 1,15,2)/-9.17976634d-04,-9.98898732d-07/
      data fpp( 1,16,1),fpp( 1,16,2)/-1.19017919d-03, 2.17163353d-07/
      data fpp( 1,17,1),fpp( 1,17,2)/-9.81722975d-04, 5.49045321d-07/
      data fpp( 1,18,1),fpp( 1,18,2)/ 5.65674852d-04, 6.19655362d-07/
      data fpp( 1,19,1),fpp( 1,19,2)/-3.28995728d-05, 2.18333232d-07/
      data fpp( 1,20,1),fpp( 1,20,2)/-2.22020664d-04,-3.75188289d-07/
      data fpp( 1,21,1),fpp( 1,21,2)/-5.98116335d-05,-1.66580076d-07/
      data fpp( 1,22,1),fpp( 1,22,2)/-1.36985211d-05,-3.96914068d-08/
      data fpp( 1,23,1),fpp( 1,23,2)/ 0.00000000d+00, 1.10545703d-07/
      data fpp( 2, 1,1),fpp( 2, 1,2)/ 0.00000000d+00, 2.39335985d-04/
      data fpp( 2, 2,1),fpp( 2, 2,2)/-7.64953467d-04,-5.50107705d-05/
      data fpp( 2, 3,1),fpp( 2, 3,2)/-2.96640079d-02,-5.63970503d-04/
      data fpp( 2, 4,1),fpp( 2, 4,2)/-6.46978030d-02,-3.21784816d-04/
      data fpp( 2, 5,1),fpp( 2, 5,2)/-6.50397014d-01, 1.30683057d-03/
      data fpp( 2, 6,1),fpp( 2, 6,2)/-3.47523587d-01, 1.24327344d-04/
      data fpp( 2, 7,1),fpp( 2, 7,2)/ 2.28978481d-04,-3.02042342d-04/
      data fpp( 2, 8,1),fpp( 2, 8,2)/-4.21677768d-02,-1.67205974d-04/
      data fpp( 2, 9,1),fpp( 2, 9,2)/-8.42954645d-03,-4.35201605d-05/
      data fpp( 2,10,1),fpp( 2,10,2)/ 3.69405198d-02, 7.25046873d-06/
      data fpp( 2,11,1),fpp( 2,11,2)/ 6.36260507d-03, 1.97328856d-05/
      data fpp( 2,12,1),fpp( 2,12,2)/-7.67856006d-03,-1.68250112d-05/
      data fpp( 2,13,1),fpp( 2,13,2)/-5.98266900d-03,-8.13924096d-06/
      data fpp( 2,14,1),fpp( 2,14,2)/-6.43008787d-04,-2.42442500d-06/
      data fpp( 2,15,1),fpp( 2,15,2)/-8.03046733d-04,-1.38225904d-06/
      data fpp( 2,16,1),fpp( 2,16,2)/-8.85641624d-04, 3.28611446d-08/
      data fpp( 2,17,1),fpp( 2,17,2)/-5.36554051d-04, 5.03214457d-07/
      data fpp( 2,18,1),fpp( 2,18,2)/ 2.29650296d-04, 6.75281026d-07/
      data fpp( 2,19,1),fpp( 2,19,2)/-1.44200854d-04, 7.46614377d-08/
      data fpp( 2,20,1),fpp( 2,20,2)/-1.74958672d-04,-2.62326777d-07/
      data fpp( 2,21,1),fpp( 2,21,2)/-4.63767331d-05,-1.11354329d-07/
      data fpp( 2,22,1),fpp( 2,22,2)/-7.60295781d-06,-2.24559059d-08/
      data fpp( 2,23,1),fpp( 2,23,2)/ 0.00000000d+00, 8.41779530d-08/
      data fpp( 3, 1,1),fpp( 3, 1,2)/ 0.00000000d+00, 4.10085199d-04/
      data fpp( 3, 2,1),fpp( 3, 2,2)/-4.94662866d-04,-9.91639981d-05/
      data fpp( 3, 3,1),fpp( 3, 3,2)/-2.82829724d-02,-8.09317207d-04/
      data fpp( 3, 4,1),fpp( 3, 4,2)/-4.93404189d-01,-8.16306375d-04/
      data fpp( 3, 5,1),fpp( 3, 5,2)/-1.09340095d+00, 2.66266831d-03/
      data fpp( 3, 6,1),fpp( 3, 6,2)/-2.08950946d-01,-1.24382051d-04/
      data fpp( 3, 7,1),fpp( 3, 7,2)/-2.23109925d-01,-6.44934502d-04/
      data fpp( 3, 8,1),fpp( 3, 8,2)/ 7.41812187d-02,-1.48975942d-04/
      data fpp( 3, 9,1),fpp( 3, 9,2)/ 8.48554126d-02,-6.96241306d-05/
      data fpp( 3,10,1),fpp( 3,10,2)/-1.40490319d-01, 1.92049626d-05/
      data fpp( 3,11,1),fpp( 3,11,2)/-3.11216177d-02, 4.07948002d-06/
      data fpp( 3,12,1),fpp( 3,12,2)/-1.00965398d-02,-1.26226827d-05/
      data fpp( 3,13,1),fpp( 3,13,2)/-3.04615849d-03,-6.43434914d-06/
      data fpp( 3,14,1),fpp( 3,14,2)/-3.39969244d-04,-1.24652072d-06/
      data fpp( 3,15,1),fpp( 3,15,2)/-6.99836435d-04,-1.51076799d-06/
      data fpp( 3,16,1),fpp( 3,16,2)/-2.83254317d-04,-1.79807311d-07/
      data fpp( 3,17,1),fpp( 3,17,2)/ 4.15939177d-04, 5.64997239d-07/
      data fpp( 3,18,1),fpp( 3,18,2)/-5.02760350d-05, 5.13018356d-07/
      data fpp( 3,19,1),fpp( 3,19,2)/-3.14297009d-04, 4.45293354d-08/
      data fpp( 3,20,1),fpp( 3,20,2)/-6.81446472d-05,-1.56535698d-07/
      data fpp( 3,21,1),fpp( 3,21,2)/-4.26814343d-05,-6.45865428d-08/
      data fpp( 3,22,1),fpp( 3,22,2)/ 1.41103523d-05,-8.71813063d-09/
      data fpp( 3,23,1),fpp( 3,23,2)/ 0.00000000d+00, 5.74590653d-08/
      data fpp( 4, 1,1),fpp( 4, 1,2)/ 0.00000000d+00, 6.87210665d-04/
      data fpp( 4, 2,1),fpp( 4, 2,2)/-1.18395068d-04,-1.35560529d-04/
      data fpp( 4, 3,1),fpp( 4, 3,2)/-2.47181026d-02,-1.25678295d-03/
      data fpp( 4, 4,1),fpp( 4, 4,2)/-3.52145439d-01,-1.33342608d-03/
      data fpp( 4, 5,1),fpp( 4, 5,2)/ 9.13160822d-01, 4.51204407d-03/
      data fpp( 4, 6,1),fpp( 4, 6,2)/-5.21932629d-01,-6.74261418d-04/
      data fpp( 4, 7,1),fpp( 4, 7,2)/ 9.67787202d-02,-8.74985605d-04/
      data fpp( 4, 8,1),fpp( 4, 8,2)/-6.04990981d-02,-2.49075363d-04/
      data fpp( 4, 9,1),fpp( 4, 9,2)/-7.89741038d-02,-1.07863343d-04/
      data fpp( 4,10,1),fpp( 4,10,2)/ 1.93166758d-01, 5.67507095d-05/
      data fpp( 4,11,1),fpp( 4,11,2)/-1.70813415d-03,-2.22142954d-05/
      data fpp( 4,12,1),fpp( 4,12,2)/-7.71728079d-03,-6.24732801d-06/
      data fpp( 4,13,1),fpp( 4,13,2)/-2.07669704d-03,-5.63239259d-06/
      data fpp( 4,14,1),fpp( 4,14,2)/-2.05114236d-04,-3.80101644d-07/
      data fpp( 4,15,1),fpp( 4,15,2)/-5.55607526d-04,-1.48900084d-06/
      data fpp( 4,16,1),fpp( 4,16,2)/-7.23341108d-04,-3.45495009d-07/
      data fpp( 4,17,1),fpp( 4,17,2)/-4.07202657d-04, 4.93180872d-07/
      data fpp( 4,18,1),fpp( 4,18,2)/-5.26546156d-04, 3.70171521d-07/
      data fpp( 4,19,1),fpp( 4,19,2)/-2.78611108d-04, 7.39330456d-08/
      data fpp( 4,20,1),fpp( 4,20,2)/-1.70462739d-04,-8.39037029d-08/
      data fpp( 4,21,1),fpp( 4,21,2)/-4.89752974d-06,-1.13182338d-08/
      data fpp( 4,22,1),fpp( 4,22,2)/-1.88384515d-05,-2.22336176d-09/
      data fpp( 4,23,1),fpp( 4,23,2)/ 0.00000000d+00, 2.50116809d-08/
      data fpp( 5, 1,1),fpp( 5, 1,2)/ 0.00000000d+00, 1.00897907d-03/
      data fpp( 5, 2,1),fpp( 5, 2,2)/ 1.25624314d-03,-5.04645386d-05/
      data fpp( 5, 3,1),fpp( 5, 3,2)/ 2.43153827d-02,-2.27622811d-03/
      data fpp( 5, 4,1),fpp( 5, 4,2)/-1.43360054d-01,-4.19871802d-04/
      data fpp( 5, 5,1),fpp( 5, 5,2)/ 1.42869967d+00, 4.40102092d-03/
      data fpp( 5, 6,1),fpp( 5, 6,2)/ 1.08055460d-01, 3.02838508d-04/
      data fpp( 5, 7,1),fpp( 5, 7,2)/ 6.83090437d-02,-1.81355176d-03/
      data fpp( 5, 8,1),fpp( 5, 8,2)/ 5.49131735d-02,-1.48556286d-04/
      data fpp( 5, 9,1),fpp( 5, 9,2)/ 3.82430028d-02,-1.33933500d-04/
      data fpp( 5,10,1),fpp( 5,10,2)/-6.22907114d-02, 4.97276421d-05/
      data fpp( 5,11,1),fpp( 5,11,2)/-8.77384567d-03,-2.03316688d-05/
      data fpp( 5,12,1),fpp( 5,12,2)/-5.88833707d-03,-6.35996685d-06/
      data fpp( 5,13,1),fpp( 5,13,2)/-1.20505335d-03,-3.61266380d-06/
      data fpp( 5,14,1),fpp( 5,14,2)/-1.59573810d-04,-2.02577956d-07/
      data fpp( 5,15,1),fpp( 5,15,2)/-5.09733461d-04,-1.26442438d-06/
      data fpp( 5,16,1),fpp( 5,16,2)/-7.65381251d-04,-4.73324536d-07/
      data fpp( 5,17,1),fpp( 5,17,2)/-6.83128550d-04, 3.22722520d-07/
      data fpp( 5,18,1),fpp( 5,18,2)/-5.43539342d-04, 2.99034454d-07/
      data fpp( 5,19,1),fpp( 5,19,2)/-3.71258559d-04, 8.55396628d-08/
      data fpp( 5,20,1),fpp( 5,20,2)/-9.60043963d-05,-6.39310550d-09/
      data fpp( 5,21,1),fpp( 5,21,2)/-1.57284467d-05, 2.16327592d-08/
      data fpp( 5,22,1),fpp( 5,22,2)/ 1.32434538d-05, 6.86206881d-09/
      data fpp( 5,23,1),fpp( 5,23,2)/ 0.00000000d+00, 4.31896560d-09/
      data fpp( 6, 1,1),fpp( 6, 1,2)/ 0.00000000d+00, 1.31275455d-03/
      data fpp( 6, 2,1),fpp( 6, 2,2)/-1.13857748d-03, 1.44348497d-04/
      data fpp( 6, 3,1),fpp( 6, 3,2)/ 4.89805719d-02,-3.67095334d-03/
      data fpp( 6, 4,1),fpp( 6, 4,2)/ 8.96851655d-01, 1.77788006d-03/
      data fpp( 6, 5,1),fpp( 6, 5,2)/ 3.50520517d-01, 2.39147631d-03/
      data fpp( 6, 6,1),fpp( 6, 6,2)/ 1.04580479d+00, 2.37798670d-03/
      data fpp( 6, 7,1),fpp( 6, 7,2)/ 9.04491050d-02,-3.03508713d-03/
      data fpp( 6, 8,1),fpp( 6, 8,2)/-2.94155961d-02, 5.17530000d-05/
      data fpp( 6, 9,1),fpp( 6, 9,2)/-2.75399074d-02,-1.77216874d-04/
      data fpp( 6,10,1),fpp( 6,10,2)/-2.28791219d-03, 5.06309222d-05/
      data fpp( 6,11,1),fpp( 6,11,2)/-6.33648319d-03,-2.09526146d-05/
      data fpp( 6,12,1),fpp( 6,12,2)/-4.20137093d-03,-5.13226385d-06/
      data fpp( 6,13,1),fpp( 6,13,2)/-8.79089545d-04,-2.44793002d-06/
      data fpp( 6,14,1),fpp( 6,14,2)/-9.25905223d-05,-3.10160650d-08/
      data fpp( 6,15,1),fpp( 6,15,2)/-3.15458631d-04,-1.04240572d-06/
      data fpp( 6,16,1),fpp( 6,16,2)/-7.09133889d-04,-5.45961060d-07/
      data fpp( 6,17,1),fpp( 6,17,2)/-8.74283144d-04, 1.40449959d-07/
      data fpp( 6,18,1),fpp( 6,18,2)/-6.11296476d-04, 2.42161225d-07/
      data fpp( 6,19,1),fpp( 6,19,2)/-3.30354658d-04, 1.03505141d-07/
      data fpp( 6,20,1),fpp( 6,20,2)/-1.29519676d-04, 5.06182095d-08/
      data fpp( 6,21,1),fpp( 6,21,2)/-2.21886833d-05, 4.86220205d-08/
      data fpp( 6,22,1),fpp( 6,22,2)/-4.13536384d-06, 1.28937084d-08/
      data fpp( 6,23,1),fpp( 6,23,2)/ 0.00000000d+00,-1.31968542d-08/
      data fpp( 7, 1,1),fpp( 7, 1,2)/ 0.00000000d+00, 1.51344926d-03/
      data fpp( 7, 2,1),fpp( 7, 2,2)/ 4.68961088d-03, 2.68584280d-04/
      data fpp( 7, 3,1),fpp( 7, 3,2)/ 7.79380930d-02,-4.61881278d-03/
      data fpp( 7, 4,1),fpp( 7, 4,2)/ 4.59699561d-01, 3.24265243d-03/
      data fpp( 7, 5,1),fpp( 7, 5,2)/-2.10513385d-01, 1.27017984d-03/
      data fpp( 7, 6,1),fpp( 7, 6,2)/ 2.69162908d-01, 3.35325700d-03/
      data fpp( 7, 7,1),fpp( 7, 7,2)/ 1.38528163d-01,-3.55069744d-03/
      data fpp( 7, 8,1),fpp( 7, 8,2)/ 9.48747014d-02, 8.81631493d-05/
      data fpp( 7, 9,1),fpp( 7, 9,2)/ 3.31427208d-02,-1.81601560d-04/
      data fpp( 7,10,1),fpp( 7,10,2)/-6.52140774d-03, 3.38775055d-05/
      data fpp( 7,11,1),fpp( 7,11,2)/-4.96112760d-03,-1.79974618d-05/
      data fpp( 7,12,1),fpp( 7,12,2)/-2.22071866d-03,-3.13885810d-06/
      data fpp( 7,13,1),fpp( 7,13,2)/-3.87204689d-04,-1.04610577d-06/
      data fpp( 7,14,1),fpp( 7,14,2)/-9.41528016d-07, 1.35281194d-07/
      data fpp( 7,15,1),fpp( 7,15,2)/-1.00757377d-04,-6.48219000d-07/
      data fpp( 7,16,1),fpp( 7,16,2)/-4.52407707d-04,-6.01805192d-07/
      data fpp( 7,17,1),fpp( 7,17,2)/-5.57586292d-04,-9.15602312d-08/
      data fpp( 7,18,1),fpp( 7,18,2)/-4.56340901d-04, 1.16646117d-07/
      data fpp( 7,19,1),fpp( 7,19,2)/-2.40806747d-04, 1.27775764d-07/
      data fpp( 7,20,1),fpp( 7,20,2)/-7.79387747d-05, 1.26450826d-07/
      data fpp( 7,21,1),fpp( 7,21,2)/-9.56972680d-06, 7.80209314d-08/
      data fpp( 7,22,1),fpp( 7,22,2)/-2.15635399d-07, 2.04654482d-08/
      data fpp( 7,23,1),fpp( 7,23,2)/ 0.00000000d+00,-3.44827241d-08/
      data fpp( 8, 1,1),fpp( 8, 1,2)/ 0.00000000d+00, 1.39188398d-03/
      data fpp( 8, 2,1),fpp( 8, 2,2)/-1.58036602d-03, 9.15744480d-05/
      data fpp( 8, 3,1),fpp( 8, 3,2)/ 2.60420562d-02,-3.47191617d-03/
      data fpp( 8, 4,1),fpp( 8, 4,2)/ 6.81911099d-01, 8.85727023d-04/
      data fpp( 8, 5,1),fpp( 8, 5,2)/ 1.06919652d+00, 3.94782487d-03/
      data fpp( 8, 6,1),fpp( 8, 6,2)/ 7.96312581d-01, 1.24406388d-03/
      data fpp( 8, 7,1),fpp( 8, 7,2)/ 1.95504242d-01,-2.59908919d-03/
      data fpp( 8, 8,1),fpp( 8, 8,2)/-2.00247097d-02,-1.49924717d-04/
      data fpp( 8, 9,1),fpp( 8, 9,2)/ 1.96402418d-03,-9.61023414d-05/
      data fpp( 8,10,1),fpp( 8,10,2)/-3.25845685d-03, 7.72138259d-06/
      data fpp( 8,11,1),fpp( 8,11,2)/-3.43800639d-03,-1.10593890d-05/
      data fpp( 8,12,1),fpp( 8,12,2)/-1.24225442d-03,-2.36262654d-06/
      data fpp( 8,13,1),fpp( 8,13,2)/-2.33091699d-04,-2.09304842d-07/
      data fpp( 8,14,1),fpp( 8,14,2)/ 2.88566343d-05, 1.50045904d-07/
      data fpp( 8,15,1),fpp( 8,15,2)/ 2.98813911d-06,-3.79478772d-07/
      data fpp( 8,16,1),fpp( 8,16,2)/-1.60235282d-04,-5.30530814d-07/
      data fpp( 8,17,1),fpp( 8,17,2)/-3.19871687d-04,-2.19397971d-07/
      data fpp( 8,18,1),fpp( 8,18,2)/-2.82839920d-04, 2.75226984d-08/
      data fpp( 8,19,1),fpp( 8,19,2)/-1.65918353d-04, 1.24307178d-07/
      data fpp( 8,20,1),fpp( 8,20,2)/-5.07252254d-05, 1.59848592d-07/
      data fpp( 8,21,1),fpp( 8,21,2)/-1.45324095d-05, 8.46984561d-08/
      data fpp( 8,22,1),fpp( 8,22,2)/ 1.99790544d-06, 2.33575840d-08/
      data fpp( 8,23,1),fpp( 8,23,2)/ 0.00000000d+00,-4.19287920d-08/
      data fpp( 9, 1,1),fpp( 9, 1,2)/ 0.00000000d+00, 7.72841109d-04/
      data fpp( 9, 2,1),fpp( 9, 2,2)/ 6.43353219d-04,-1.50425419d-04/
      data fpp( 9, 3,1),fpp( 9, 3,2)/-1.37868179d-02,-1.29510743d-03/
      data fpp( 9, 4,1),fpp( 9, 4,2)/-4.36577957d-01,-1.66483524d-03/
      data fpp( 9, 5,1),fpp( 9, 5,2)/ 6.02420296d-01, 5.30687401d-03/
      data fpp( 9, 6,1),fpp( 9, 6,2)/-3.53284734d-01,-9.73895182d-04/
      data fpp( 9, 7,1),fpp( 9, 7,2)/-1.16494133d-01,-1.06104208d-03/
      data fpp( 9, 8,1),fpp( 9, 8,2)/ 5.80413723d-03,-2.03231711d-04/
      data fpp( 9, 9,1),fpp( 9, 9,2)/-5.91981753d-03,-5.94134806d-05/
      data fpp( 9,10,1),fpp( 9,10,2)/-3.55376486d-03, 7.31497231d-07/
      data fpp( 9,11,1),fpp( 9,11,2)/-2.39184682d-03,-7.89910829d-06/
      data fpp( 9,12,1),fpp( 9,12,2)/-7.21263647d-04,-1.16546407d-06/
      data fpp( 9,13,1),fpp( 9,13,2)/-1.17428515d-04, 3.35645859d-08/
      data fpp( 9,14,1),fpp( 9,14,2)/ 3.55149907d-05, 1.64805730d-07/
      data fpp( 9,15,1),fpp( 9,15,2)/ 7.98048206d-05,-2.15187508d-07/
      data fpp( 9,16,1),fpp( 9,16,2)/-3.76511647d-05,-4.26655699d-07/
      data fpp( 9,17,1),fpp( 9,17,2)/-1.24926959d-04,-2.56789697d-07/
      data fpp( 9,18,1),fpp( 9,18,2)/-1.43299417d-04,-3.11855143d-08/
      data fpp( 9,19,1),fpp( 9,19,2)/-7.95198422d-05, 1.15131754d-07/
      data fpp( 9,20,1),fpp( 9,20,2)/-3.41603236d-05, 1.54458499d-07/
      data fpp( 9,21,1),fpp( 9,21,2)/ 1.69936495d-06, 8.42342503d-08/
      data fpp( 9,22,1),fpp( 9,22,2)/-7.77598635d-06, 2.04044999d-08/
      data fpp( 9,23,1),fpp( 9,23,2)/ 0.00000000d+00,-4.52522500d-08/
      data fpp(10, 1,1),fpp(10, 1,2)/ 0.00000000d+00, 2.93159650d-04/
      data fpp(10, 2,1),fpp(10, 2,2)/-5.07046852d-04,-8.09953004d-05/
      data fpp(10, 3,1),fpp(10, 3,2)/-1.86457846d-02,-5.81336848d-04/
      data fpp(10, 4,1),fpp(10, 4,2)/-2.59931270d-01,-6.40025306d-04/
      data fpp(10, 5,1),fpp(10, 5,2)/-9.24052206d-01, 2.07665407d-03/
      data fpp(10, 6,1),fpp(10, 6,2)/-3.04097147d-01,-1.78000578d-04/
      data fpp(10, 7,1),fpp(10, 7,2)/-2.98487115d-02,-4.34978160d-04/
      data fpp(10, 8,1),fpp(10, 8,2)/-1.16038392d-02,-1.48369181d-04/
      data fpp(10, 9,1),fpp(10, 9,2)/-3.27775405d-03,-3.70035156d-05/
      data fpp(10,10,1),fpp(10,10,2)/-3.02248370d-03,-2.44286267d-06/
      data fpp(10,11,1),fpp(10,11,2)/-1.58360632d-03,-5.15803372d-06/
      data fpp(10,12,1),fpp(10,12,2)/-4.20690987d-04,-4.53402444d-07/
      data fpp(10,13,1),fpp(10,13,2)/-8.01942404d-05, 1.25643497d-07/
      data fpp(10,14,1),fpp(10,14,2)/ 3.75834030d-05, 1.58428455d-07/
      data fpp(10,15,1),fpp(10,15,2)/ 8.72925783d-05,-1.31757317d-07/
      data fpp(10,16,1),fpp(10,16,2)/ 9.03399407d-05,-3.10599187d-07/
      data fpp(10,17,1),fpp(10,17,2)/-5.42047603d-06,-2.51845934d-07/
      data fpp(10,18,1),fpp(10,18,2)/-2.89624108d-05,-5.36170777d-08/
      data fpp(10,19,1),fpp(10,19,2)/-2.45022787d-05, 9.31142446d-08/
      data fpp(10,20,1),fpp(10,20,2)/-1.33480328d-07, 1.41960099d-07/
      data fpp(10,21,1),fpp(10,21,2)/-4.26505027d-06, 6.68453579d-08/
      data fpp(10,22,1),fpp(10,22,2)/ 1.26060400d-05, 2.02584692d-08/
      data fpp(10,23,1),fpp(10,23,2)/ 0.00000000d+00,-3.44792346d-08/
      data fpp(11, 1,1),fpp(11, 1,2)/ 0.00000000d+00, 9.85448558d-05/
      data fpp(11, 2,1),fpp(11, 2,2)/-4.70665810d-04,-2.41321115d-05/
      data fpp(11, 3,1),fpp(11, 3,2)/-2.30440437d-02,-2.74690010d-04/
      data fpp(11, 4,1),fpp(11, 4,2)/-5.93639644d-02,-7.76646496d-05/
      data fpp(11, 5,1),fpp(11, 5,2)/-2.76280974d-01, 4.47115808d-04/
      data fpp(11, 6,1),fpp(11, 6,2)/-1.59580679d-01, 2.37965417d-04/
      data fpp(11, 7,1),fpp(11, 7,2)/-4.83580213d-02,-2.03175078d-04/
      data fpp(11, 8,1),fpp(11, 8,2)/-1.01262803d-02,-7.49307056d-05/
      data fpp(11, 9,1),fpp(11, 9,2)/-4.78166625d-03,-2.51716997d-05/
      data fpp(11,10,1),fpp(11,10,2)/-2.58130035d-03,-2.47574798d-06/
      data fpp(11,11,1),fpp(11,11,2)/-1.06422789d-03,-3.26590833d-06/
      data fpp(11,12,1),fpp(11,12,2)/-2.49472404d-04,-6.01869864d-09/
      data fpp(11,13,1),fpp(11,13,2)/-4.02945234d-05, 1.40583125d-07/
      data fpp(11,14,1),fpp(11,14,2)/ 3.61513973d-05, 1.35486200d-07/
      data fpp(11,15,1),fpp(11,15,2)/ 7.35248661d-05,-7.29279260d-08/
      data fpp(11,16,1),fpp(11,16,2)/ 6.92914020d-05,-2.35574496d-07/
      data fpp(11,17,1),fpp(11,17,2)/ 5.81088633d-05,-2.06974089d-07/
      data fpp(11,18,1),fpp(11,18,2)/ 1.46490605d-05,-6.45291487d-08/
      data fpp(11,19,1),fpp(11,19,2)/ 9.52895693d-06, 7.80906835d-08/
      data fpp(11,20,1),fpp(11,20,2)/ 3.19424487d-06, 1.13966415d-07/
      data fpp(11,21,1),fpp(11,21,2)/ 3.36083613d-06, 5.76436576d-08/
      data fpp(11,22,1),fpp(11,22,2)/-9.64817353d-06, 1.30589550d-08/
      data fpp(11,23,1),fpp(11,23,2)/ 0.00000000d+00,-3.48794775d-08/
      data fpp(12, 1,1),fpp(12, 1,2)/ 0.00000000d+00,-2.77287173d-05/
      data fpp(12, 2,1),fpp(12, 2,2)/-5.78789908d-04,-4.19901653d-05/
      data fpp(12, 3,1),fpp(12, 3,2)/-9.79454071d-03, 7.90133786d-05/
      data fpp(12, 4,1),fpp(12, 4,2)/-1.43753373d-01,-2.73410549d-04/
      data fpp(12, 5,1),fpp(12, 5,2)/-1.38482900d-01, 1.93356018d-04/
      data fpp(12, 6,1),fpp(12, 6,2)/-7.88821359d-02, 1.85524876d-04/
      data fpp(12, 7,1),fpp(12, 7,2)/-2.88422035d-02,-7.70091220d-05/
      data fpp(12, 8,1),fpp(12, 8,2)/-9.68953970d-03,-3.67043878d-05/
      data fpp(12, 9,1),fpp(12, 9,2)/-4.40508095d-03,-1.53909266d-05/
      data fpp(12,10,1),fpp(12,10,2)/-1.99731489d-03,-2.15482629d-06/
      data fpp(12,11,1),fpp(12,11,2)/-6.61982118d-04,-1.78676824d-06/
      data fpp(12,12,1),fpp(12,12,2)/-1.35419397d-04, 1.81899236d-07/
      data fpp(12,13,1),fpp(12,13,2)/-2.56276660d-05, 1.41771293d-07/
      data fpp(12,14,1),fpp(12,14,2)/ 2.18110077d-05, 1.00615592d-07/
      data fpp(12,15,1),fpp(12,15,2)/ 8.81079574d-05,-3.48336597d-08/
      data fpp(12,16,1),fpp(12,16,2)/ 1.04994451d-04,-1.70680953d-07/
      data fpp(12,17,1),fpp(12,17,2)/ 7.59850228d-05,-1.69842529d-07/
      data fpp(12,18,1),fpp(12,18,2)/ 5.28661687d-05,-5.47489300d-08/
      data fpp(12,19,1),fpp(12,19,2)/ 2.68864510d-05, 5.94382492d-08/
      data fpp(12,20,1),fpp(12,20,2)/ 8.35650084d-06, 8.87959332d-08/
      data fpp(12,21,1),fpp(12,21,2)/ 1.32170575d-06, 4.43780180d-08/
      data fpp(12,22,1),fpp(12,22,2)/ 3.48665415d-06, 1.02919949d-08/
      data fpp(12,23,1),fpp(12,23,2)/ 0.00000000d+00,-2.67459974d-08/
      data fpp(13, 1,1),fpp(13, 1,2)/ 0.00000000d+00,-4.11202487d-05/
      data fpp(13, 2,1),fpp(13, 2,2)/ 1.93743565d-04,-2.88435027d-05/
      data fpp(13, 3,1),fpp(13, 3,2)/ 1.71149816d-03, 1.21891059d-04/
      data fpp(13, 4,1),fpp(13, 4,2)/-3.94144813d-03,-2.11976734d-04/
      data fpp(13, 5,1),fpp(13, 5,2)/-1.46206842d-02, 9.94070786d-05/
      data fpp(13, 6,1),fpp(13, 6,2)/-2.62297607d-02, 5.43460200d-05/
      data fpp(13, 7,1),fpp(13, 7,2)/-1.40113076d-02,-6.47595875d-06/
      data fpp(13, 8,1),fpp(13, 8,2)/-6.27801416d-03,-1.39557850d-05/
      data fpp(13, 9,1),fpp(13, 9,2)/-3.29495268d-03,-6.08890117d-06/
      data fpp(13,10,1),fpp(13,10,2)/-1.16441680d-03,-1.29940399d-06/
      data fpp(13,11,1),fpp(13,11,2)/-2.98241014d-04,-4.60282888d-07/
      data fpp(13,12,1),fpp(13,12,2)/-5.96204072d-05, 2.46135536d-07/
      data fpp(13,13,1),fpp(13,13,2)/-1.13780978d-05, 1.21340743d-07/
      data fpp(13,14,1),fpp(13,14,2)/ 1.81957096d-05, 7.13014930d-08/
      data fpp(13,15,1),fpp(13,15,2)/ 4.19568979d-05,-1.95467148d-08/
      data fpp(13,16,1),fpp(13,16,2)/ 6.54908942d-05,-1.02314634d-07/
      data fpp(13,17,1),fpp(13,17,2)/ 7.19773484d-05,-1.13594750d-07/
      data fpp(13,18,1),fpp(13,18,2)/ 5.16800640d-05,-3.91063660d-08/
      data fpp(13,19,1),fpp(13,19,2)/ 2.60258589d-05, 3.66202141d-08/
      data fpp(13,20,1),fpp(13,20,2)/ 1.10155006d-05, 6.06255096d-08/
      data fpp(13,21,1),fpp(13,21,2)/ 4.35375674d-06, 2.68777474d-08/
      data fpp(13,22,1),fpp(13,22,2)/-1.85673148d-06, 7.06350074d-09/
      data fpp(13,23,1),fpp(13,23,2)/ 0.00000000d+00,-1.67317504d-08/
      data fpp(14, 1,1),fpp(14, 1,2)/ 0.00000000d+00, 3.87136879d-06/
      data fpp(14, 2,1),fpp(14, 2,2)/-1.80851020d-04,-3.91537575d-07/
      data fpp(14, 3,1),fpp(14, 3,2)/-6.00145193d-03, 1.28339815d-05/
      data fpp(14, 4,1),fpp(14, 4,2)/ 9.09249852d-03,-3.51499885d-05/
      data fpp(14, 5,1),fpp(14, 5,2)/-7.20103001d-03, 1.16731724d-05/
      data fpp(14, 6,1),fpp(14, 6,2)/-8.68682131d-03, 1.84212989d-05/
      data fpp(14, 7,1),fpp(14, 7,2)/-6.19523267d-03,-1.58367968d-07/
      data fpp(14, 8,1),fpp(14, 8,2)/-3.43840364d-03,-4.42462702d-06/
      data fpp(14, 9,1),fpp(14, 9,2)/-1.84110833d-03,-2.20472395d-06/
      data fpp(14,10,1),fpp(14,10,2)/-5.60351226d-04,-4.57314635d-07/
      data fpp(14,11,1),fpp(14,11,2)/-1.17053824d-04, 6.67824914d-08/
      data fpp(14,12,1),fpp(14,12,2)/-1.60989743d-05, 2.26184669d-07/
      data fpp(14,13,1),fpp(14,13,2)/-8.85994284d-06, 9.22788315d-08/
      data fpp(14,14,1),fpp(14,14,2)/ 9.40615394d-06, 4.73000049d-08/
      data fpp(14,15,1),fpp(14,15,2)/ 3.60644511d-05,-1.32788510d-08/
      data fpp(14,16,1),fpp(14,16,2)/ 5.17086386d-05,-5.83846008d-08/
      data fpp(14,17,1),fpp(14,17,2)/ 4.41055835d-05,-7.41827458d-08/
      data fpp(14,18,1),fpp(14,18,2)/ 3.17469085d-05,-2.70844160d-08/
      data fpp(14,19,1),fpp(14,19,2)/ 2.03434470d-05, 2.41204098d-08/
      data fpp(14,20,1),fpp(14,20,2)/ 7.58149672d-06, 3.86027768d-08/
      data fpp(14,21,1),fpp(14,21,2)/-5.40339939d-06, 1.46684832d-08/
      data fpp(14,22,1),fpp(14,22,2)/ 3.27360511d-06, 5.92329052d-09/
      data fpp(14,23,1),fpp(14,23,2)/ 0.00000000d+00,-7.16164526d-09/
      data fpp(15, 1,1),fpp(15, 1,2)/ 0.00000000d+00, 2.52077586d-06/
      data fpp(15, 2,1),fpp(15, 2,2)/-1.18602475d-05, 6.35648280d-07/
      data fpp(15, 3,1),fpp(15, 3,2)/ 1.67851240d-03, 4.02063102d-06/
      data fpp(15, 4,1),fpp(15, 4,2)/-5.41320388d-04,-1.10397724d-05/
      data fpp(15, 5,1),fpp(15, 5,2)/-2.17282373d-03, 2.16805843d-06/
      data fpp(15, 6,1),fpp(15, 6,2)/-4.75775244d-03, 7.01393865d-06/
      data fpp(15, 7,1),fpp(15, 7,2)/-3.58437521d-03,-8.22130277d-08/
      data fpp(15, 8,1),fpp(15, 8,2)/-2.02696054d-03,-2.09868654d-06/
      data fpp(15, 9,1),fpp(15, 9,2)/-1.09602934d-03,-1.04624082d-06/
      data fpp(15,10,1),fpp(15,10,2)/-3.03618663d-04,-1.45734282d-07/
      data fpp(15,11,1),fpp(15,11,2)/-4.98693563d-05, 1.99377946d-07/
      data fpp(15,12,1),fpp(15,12,2)/-1.55745179d-05, 1.88822500d-07/
      data fpp(15,13,1),fpp(15,13,2)/ 2.36686091d-06, 7.97320558d-08/
      data fpp(15,14,1),fpp(15,14,2)/ 6.67566588d-06, 3.34492773d-08/
      data fpp(15,15,1),fpp(15,15,2)/ 1.37423979d-05,-1.01291652d-08/
      data fpp(15,16,1),fpp(15,16,2)/ 3.57204658d-05,-4.33326167d-08/
      data fpp(15,17,1),fpp(15,17,2)/ 4.35060600d-05,-5.23403679d-08/
      data fpp(15,18,1),fpp(15,18,2)/ 3.37453613d-05,-1.97059118d-08/
      data fpp(15,19,1),fpp(15,19,2)/ 1.32439770d-05, 1.71640150d-08/
      data fpp(15,20,1),fpp(15,20,2)/-4.30734507d-07, 2.54498516d-08/
      data fpp(15,21,1),fpp(15,21,2)/ 1.39863618d-05, 1.48365784d-08/
      data fpp(15,22,1),fpp(15,22,2)/-1.08292832d-06, 2.20383474d-09/
      data fpp(15,23,1),fpp(15,23,2)/ 0.00000000d+00,-9.85191737d-09/
      data fpp(16, 1,1),fpp(16, 1,2)/ 0.00000000d+00, 8.60016591d-07/
      data fpp(16, 2,1),fpp(16, 2,2)/ 9.29201015d-06, 4.81966818d-07/
      data fpp(16, 3,1),fpp(16, 3,2)/-6.30976662d-05, 1.98091614d-06/
      data fpp(16, 4,1),fpp(16, 4,2)/ 6.86783036d-04,-3.08963136d-06/
      data fpp(16, 5,1),fpp(16, 5,2)/-1.17017506d-03,-9.59906776d-08/
      data fpp(16, 6,1),fpp(16, 6,2)/-2.03316895d-03, 1.98319408d-06/
      data fpp(16, 7,1),fpp(16, 7,2)/-1.69576649d-03,-4.15985623d-07/
      data fpp(16, 8,1),fpp(16, 8,2)/-1.00875422d-03,-1.06805158d-06/
      data fpp(16, 9,1),fpp(16, 9,2)/-5.44274314d-04,-5.17408041d-07/
      data fpp(16,10,1),fpp(16,10,2)/-1.33174123d-04, 1.86499140d-08/
      data fpp(16,11,1),fpp(16,11,2)/-1.64687506d-05, 2.35808385d-07/
      data fpp(16,12,1),fpp(16,12,2)/ 6.39704605d-06, 1.57716547d-07/
      data fpp(16,13,1),fpp(16,13,2)/-5.10750080d-06, 6.09254274d-08/
      data fpp(16,14,1),fpp(16,14,2)/-6.10881746d-06, 2.51817436d-08/
      data fpp(16,15,1),fpp(16,15,2)/ 1.99659574d-05,-4.45240181d-09/
      data fpp(16,16,1),fpp(16,16,2)/ 1.99094983d-05,-3.49721364d-08/
      data fpp(16,17,1),fpp(16,17,2)/ 2.33701765d-05,-3.68590527d-08/
      data fpp(16,18,1),fpp(16,18,2)/ 1.47716464d-05,-1.49916528d-08/
      data fpp(16,19,1),fpp(16,19,2)/ 7.68064523d-06, 1.10256639d-08/
      data fpp(16,20,1),fpp(16,20,2)/ 6.14144131d-06, 2.42889973d-08/
      data fpp(16,21,1),fpp(16,21,2)/-1.30420479d-05, 4.01834688d-09/
      data fpp(16,22,1),fpp(16,22,2)/-3.44189185d-06, 3.43761518d-09/
      data fpp(16,23,1),fpp(16,23,2)/ 0.00000000d+00,-2.76880759d-09/
      data fpp(17, 1,1),fpp(17, 1,2)/ 0.00000000d+00,-2.89465873d-08/
      data fpp(17, 2,1),fpp(17, 2,2)/ 1.93346451d-06, 2.41093175d-07/
      data fpp(17, 3,1),fpp(17, 3,2)/ 1.50650622d-04, 9.94173889d-07/
      data fpp(17, 4,1),fpp(17, 4,2)/ 2.69368061d-05, 5.66112710d-08/
      data fpp(17, 5,1),fpp(17, 5,2)/-1.07200638d-04,-3.56618973d-07/
      data fpp(17, 6,1),fpp(17, 6,2)/-4.02601862d-04,-2.66935380d-07/
      data fpp(17, 7,1),fpp(17, 7,2)/-3.63194902d-04,-6.06039507d-07/
      data fpp(17, 8,1),fpp(17, 8,2)/-2.13512259d-04,-5.46506593d-07/
      data fpp(17, 9,1),fpp(17, 9,2)/-1.06066061d-04,-2.63134122d-07/
      data fpp(17,10,1),fpp(17,10,2)/-4.34048075d-06, 9.72556634d-08/
      data fpp(17,11,1),fpp(17,11,2)/ 1.64754060d-05, 2.22111469d-07/
      data fpp(17,12,1),fpp(17,12,2)/-2.60714153d-06, 1.03298461d-07/
      data fpp(17,13,1),fpp(17,13,2)/ 4.47095397d-07, 3.90946866d-08/
      data fpp(17,14,1),fpp(17,14,2)/ 1.65789476d-05, 3.01227926d-08/
      data fpp(17,15,1),fpp(17,15,2)/ 4.28521005d-06,-1.43858569d-08/
      data fpp(17,16,1),fpp(17,16,2)/ 1.38213619d-05,-1.57793649d-08/
      data fpp(17,17,1),fpp(17,17,2)/ 1.54287050d-05,-2.68966835d-08/
      data fpp(17,18,1),fpp(17,18,2)/ 1.65976044d-05,-8.63390125d-09/
      data fpp(17,19,1),fpp(17,19,2)/ 1.15685313d-05, 1.04322885d-08/
      data fpp(17,20,1),fpp(17,20,2)/ 5.14901865d-06, 8.30474742d-09/
      data fpp(17,21,1),fpp(17,21,2)/ 7.48258503d-06, 7.94872185d-09/
      data fpp(17,22,1),fpp(17,22,2)/ 2.86159169d-06, 1.30036519d-09/
      data fpp(17,23,1),fpp(17,23,2)/ 0.00000000d+00,-3.55018259d-09/
      data fpp(18, 1,1),fpp(18, 1,2)/ 0.00000000d+00,-1.33946612d-07/
      data fpp(18, 2,1),fpp(18, 2,2)/ 2.30746516d-06, 1.25093224d-07/
      data fpp(18, 3,1),fpp(18, 3,2)/-2.17148692d-06, 5.19173715d-07/
      data fpp(18, 4,1),fpp(18, 4,2)/ 9.68030731d-05, 4.40611916d-07/
      data fpp(18, 5,1),fpp(18, 5,2)/ 5.69776159d-05,-1.14421380d-07/
      data fpp(18, 6,1),fpp(18, 6,2)/ 4.15764028d-05,-4.22126397d-07/
      data fpp(18, 7,1),fpp(18, 7,2)/ 3.45460967d-05,-5.05873031d-07/
      data fpp(18, 8,1),fpp(18, 8,2)/ 3.61365840d-05,-4.03181479d-07/
      data fpp(18, 9,1),fpp(18, 9,2)/ 3.32052235d-05,-2.11801053d-07/
      data fpp(18,10,1),fpp(18,10,2)/ 2.38693796d-05, 9.71938981d-08/
      data fpp(18,11,1),fpp(18,11,2)/ 1.19004598d-05, 1.67425461d-07/
      data fpp(18,12,1),fpp(18,12,2)/ 4.69818675d-06, 6.77042597d-08/
      data fpp(18,13,1),fpp(18,13,2)/-1.34754745d-06, 3.27575007d-08/
      data fpp(18,14,1),fpp(18,14,2)/-6.87363965d-06, 1.12657375d-08/
      data fpp(18,15,1),fpp(18,15,2)/ 9.55986908d-06,-2.82045088d-09/
      data fpp(18,16,1),fpp(18,16,2)/ 1.68050540d-05,-1.19839340d-08/
      data fpp(18,17,1),fpp(18,17,2)/ 1.02483369d-05,-1.46438130d-08/
      data fpp(18,18,1),fpp(18,18,2)/ 4.83793613d-06,-7.44081399d-09/
      data fpp(18,19,1),fpp(18,19,2)/-6.21437006d-07, 7.20706894d-09/
      data fpp(18,20,1),fpp(18,20,2)/-1.20708492d-05, 2.61253822d-09/
      data fpp(18,21,1),fpp(18,21,2)/-2.88829224d-06, 7.54277817d-09/
      data fpp(18,22,1),fpp(18,22,2)/-1.33780827d-06, 2.16349094d-10/
      data fpp(18,23,1),fpp(18,23,2)/ 0.00000000d+00,-3.60817455d-09/
      data fpp(19, 1,1),fpp(19, 1,2)/ 0.00000000d+00,-1.12984587d-07/
      data fpp(19, 2,1),fpp(19, 2,2)/ 6.24774524d-08, 7.91691747d-08/
      data fpp(19, 3,1),fpp(19, 3,2)/ 2.38815022d-05, 3.21907888d-07/
      data fpp(19, 4,1),fpp(19, 4,2)/ 6.40794252d-05, 3.87599271d-07/
      data fpp(19, 5,1),fpp(19, 5,2)/ 9.24128785d-05, 9.29502634d-09/
      data fpp(19, 6,1),fpp(19, 6,2)/ 8.80207791d-05,-3.09579377d-07/
      data fpp(19, 7,1),fpp(19, 7,2)/ 8.15618701d-05,-3.98177520d-07/
      data fpp(19, 8,1),fpp(19, 8,2)/ 7.80854683d-05,-3.48910544d-07/
      data fpp(19, 9,1),fpp(19, 9,2)/ 7.15729734d-05,-1.95780302d-07/
      data fpp(19,10,1),fpp(19,10,2)/ 4.06638233d-05, 9.03961793d-08/
      data fpp(19,11,1),fpp(19,11,2)/ 2.12845920d-05, 1.26995585d-07/
      data fpp(19,12,1),fpp(19,12,2)/-8.02214660d-08, 5.14214799d-08/
      data fpp(19,13,1),fpp(19,13,2)/-4.32905832d-07, 2.67184951d-08/
      data fpp(19,14,1),fpp(19,14,2)/-1.00022319d-06, 7.30453957d-09/
      data fpp(19,15,1),fpp(19,15,2)/ 3.27283955d-06, 1.06334661d-09/
      data fpp(19,16,1),fpp(19,16,2)/-7.25731286d-06,-1.39579260d-08/
      data fpp(19,17,1),fpp(19,17,2)/ 7.11525795d-06,-7.03164260d-09/
      data fpp(19,18,1),fpp(19,18,2)/ 1.41391279d-06,-5.91550361d-09/
      data fpp(19,19,1),fpp(19,19,2)/ 2.54388113d-07, 6.93657045d-10/
      data fpp(19,20,1),fpp(19,20,2)/ 1.66307181d-05, 9.74087543d-09/
      data fpp(19,21,1),fpp(19,21,2)/-2.82416328d-07, 1.14284123d-09/
      data fpp(19,22,1),fpp(19,22,2)/ 3.96653787d-07, 6.87759649d-10/
      data fpp(19,23,1),fpp(19,23,2)/ 0.00000000d+00,-2.09387982d-09/
      data fpp(20, 1,1),fpp(20, 1,2)/ 0.00000000d+00,-8.72745323d-08/
      data fpp(20, 2,1),fpp(20, 2,2)/ 4.42625033d-07, 4.61490646d-08/
      data fpp(20, 3,1),fpp(20, 3,2)/ 5.64547818d-06, 2.17078274d-07/
      data fpp(20, 4,1),fpp(20, 4,2)/ 3.23792262d-05, 2.56737840d-07/
      data fpp(20, 5,1),fpp(20, 5,2)/ 8.63708703d-05, 9.75703676d-08/
      data fpp(20, 6,1),fpp(20, 6,2)/ 1.08840481d-04,-1.98219310d-07/
      data fpp(20, 7,1),fpp(20, 7,2)/ 1.05706423d-04,-2.91093127d-07/
      data fpp(20, 8,1),fpp(20, 8,2)/ 7.75215427d-05,-2.98208182d-07/
      data fpp(20, 9,1),fpp(20, 9,2)/ 5.25028827d-05,-1.86474145d-07/
      data fpp(20,10,1),fpp(20,10,2)/ 3.54753272d-05, 8.87265251d-08/
      data fpp(20,11,1),fpp(20,11,2)/ 6.46117215d-06, 8.53680442d-08/
      data fpp(20,12,1),fpp(20,12,2)/ 4.62269911d-06, 4.44012982d-08/
      data fpp(20,13,1),fpp(20,13,2)/ 7.91707807d-08, 1.78267630d-08/
      data fpp(20,14,1),fpp(20,14,2)/ 6.37453240d-06, 9.69164988d-09/
      data fpp(20,15,1),fpp(20,15,2)/ 2.84877271d-06,-4.99336251d-09/
      data fpp(20,16,1),fpp(20,16,2)/ 1.37241974d-05,-4.11819983d-09/
      data fpp(20,17,1),fpp(20,17,2)/ 6.29063129d-06,-9.73383817d-09/
      data fpp(20,18,1),fpp(20,18,2)/ 9.00641269d-06,-2.54644751d-09/
      data fpp(20,19,1),fpp(20,19,2)/ 7.10388455d-06, 2.51962820d-09/
      data fpp(20,20,1),fpp(20,20,2)/-4.95202337d-06, 3.26793471d-09/
      data fpp(20,21,1),fpp(20,21,2)/ 2.51795755d-06, 3.60863296d-09/
      data fpp(20,22,1),fpp(20,22,2)/-1.74880688d-06,-3.02466561d-10/
      data fpp(20,23,1),fpp(20,23,2)/ 0.00000000d+00,-2.99876672d-09/
      data fpp(21, 1,1),fpp(21, 1,2)/ 0.00000000d+00,-5.66527220d-08/
      data fpp(21, 2,1),fpp(21, 2,2)/-5.17068410d-07, 2.17054439d-08/
      data fpp(21, 3,1),fpp(21, 3,2)/ 5.92740461d-06, 1.06630946d-07/
      data fpp(21, 4,1),fpp(21, 4,2)/ 1.86829625d-05, 1.68570771d-07/
      data fpp(21, 5,1),fpp(21, 5,2)/ 4.34885134d-05, 9.26859707d-08/
      data fpp(21, 6,1),fpp(21, 6,2)/ 6.15178777d-05,-7.13146536d-08/
      data fpp(21, 7,1),fpp(21, 7,2)/ 6.39373442d-05,-2.01027356d-07/
      data fpp(21, 8,1),fpp(21, 8,2)/ 6.12045453d-05,-2.11775922d-07/
      data fpp(21, 9,1),fpp(21, 9,2)/ 5.16084088d-05,-1.37468957d-07/
      data fpp(21,10,1),fpp(21,10,2)/ 3.09730272d-05, 6.28948316d-08/
      data fpp(21,11,1),fpp(21,11,2)/ 1.09396982d-05, 5.26896305d-08/
      data fpp(21,12,1),fpp(21,12,2)/ 3.11150609d-07, 2.69466465d-08/
      data fpp(21,13,1),fpp(21,13,2)/ 3.58034619d-07, 1.65237835d-08/
      data fpp(21,14,1),fpp(21,14,2)/-2.58162586d-06, 1.75821952d-09/
      data fpp(21,15,1),fpp(21,15,2)/ 1.65553127d-06,-1.56661590d-10/
      data fpp(21,16,1),fpp(21,16,2)/ 4.24217083d-07,-4.13157317d-09/
      data fpp(21,17,1),fpp(21,17,2)/ 2.62105707d-06,-5.51704575d-09/
      data fpp(21,18,1),fpp(21,18,2)/ 1.03601583d-06,-8.00243849d-10/
      data fpp(21,19,1),fpp(21,19,2)/-5.15873923d-07,-8.81978858d-10/
      data fpp(21,20,1),fpp(21,20,2)/ 2.41959913d-06, 5.52815928d-09/
      data fpp(21,21,1),fpp(21,21,2)/-8.71580960d-07,-1.43065827d-09/
      data fpp(21,22,1),fpp(21,22,2)/ 1.89825375d-06, 1.99447379d-09/
      data fpp(21,23,1),fpp(21,23,2)/ 0.00000000d+00, 2.45276310d-09/
      data fpp(22, 1,1),fpp(22, 1,2)/ 0.00000000d+00,-7.01878272d-09/
      data fpp(22, 2,1),fpp(22, 2,2)/ 6.69043893d-07, 1.84375654d-08/
      data fpp(22, 3,1),fpp(22, 3,2)/-1.39498166d-06,-1.93147906d-09/
      data fpp(22, 4,1),fpp(22, 4,2)/ 9.02698422d-06, 1.38088351d-07/
      data fpp(22, 5,1),fpp(22, 5,2)/ 1.10942349d-05, 8.77807583d-09/
      data fpp(22, 6,1),fpp(22, 6,2)/ 2.12785030d-05, 1.99934586d-09/
      data fpp(22, 7,1),fpp(22, 7,2)/ 2.91766449d-05,-9.83754593d-08/
      data fpp(22, 8,1),fpp(22, 8,2)/ 3.13125294d-05,-1.12497509d-07/
      data fpp(22, 9,1),fpp(22, 9,2)/ 3.15113623d-05,-4.92345056d-08/
      data fpp(22,10,1),fpp(22,10,2)/ 1.32011165d-05, 1.37522711d-08/
      data fpp(22,11,1),fpp(22,11,2)/ 4.87626260d-06, 2.78254213d-08/
      data fpp(22,12,1),fpp(22,12,2)/ 1.35069859d-06, 1.35460436d-08/
      data fpp(22,13,1),fpp(22,13,2)/-5.53213250d-07, 7.39040412d-09/
      data fpp(22,14,1),fpp(22,14,2)/ 1.07648333d-06, 1.89233987d-09/
      data fpp(22,15,1),fpp(22,15,2)/ 8.33036324d-07,-5.59763611d-10/
      data fpp(22,16,1),fpp(22,16,2)/ 2.08798687d-06,-2.05328543d-09/
      data fpp(22,17,1),fpp(22,17,2)/ 1.91823862d-06,-2.02709468d-09/
      data fpp(22,18,1),fpp(22,18,2)/ 1.84090172d-06,-6.38335844d-10/
      data fpp(22,19,1),fpp(22,19,2)/ 1.38846582d-06, 3.80438058d-10/
      data fpp(22,20,1),fpp(22,20,2)/-4.51503183d-07, 1.51658361d-09/
      data fpp(22,21,1),fpp(22,21,2)/ 2.38284541d-07, 1.53227489d-10/
      data fpp(22,22,1),fpp(22,22,2)/-7.85127858d-07, 2.70506432d-10/
      data fpp(22,23,1),fpp(22,23,2)/ 0.00000000d+00,-3.52532159d-11/
      data fpp(23, 1,1),fpp(23, 1,2)/ 0.00000000d+00,-2.65895677d-08/
      data fpp(23, 2,1),fpp(23, 2,2)/-2.39107163d-07,-3.22086453d-09/
      data fpp(23, 3,1),fpp(23, 3,2)/ 3.49252203d-06, 3.22730259d-08/
      data fpp(23, 4,1),fpp(23, 4,2)/-1.99089938d-06, 2.53287611d-08/
      data fpp(23, 5,1),fpp(23, 5,2)/ 5.01454706d-06, 2.24119298d-08/
      data fpp(23, 6,1),fpp(23, 6,2)/ 9.60811042d-06, 2.23519846d-10/
      data fpp(23, 7,1),fpp(23, 7,2)/ 1.37560764d-05,-4.49060091d-08/
      data fpp(23, 8,1),fpp(23, 8,2)/ 1.65853372d-05,-3.65994833d-08/
      data fpp(23, 9,1),fpp(23, 9,2)/ 1.26661422d-05,-3.18960579d-08/
      data fpp(23,10,1),fpp(23,10,2)/ 7.66250659d-06, 5.38791518d-09/
      data fpp(23,11,1),fpp(23,11,2)/ 2.19525144d-06, 1.09443971d-08/
      data fpp(23,12,1),fpp(23,12,2)/ 5.26055050d-07, 8.43449623d-09/
      data fpp(23,13,1),fpp(23,13,2)/ 1.74818379d-07, 3.31761793d-09/
      data fpp(23,14,1),fpp(23,14,2)/-2.84307446d-07, 1.09503204d-09/
      data fpp(23,15,1),fpp(23,15,2)/ 2.92323437d-07,-4.97746105d-10/
      data fpp(23,16,1),fpp(23,16,2)/ 3.43835452d-07,-9.04047624d-10/
      data fpp(23,17,1),fpp(23,17,2)/ 5.05988467d-07,-6.86063399d-10/
      data fpp(23,18,1),fpp(23,18,2)/ 2.40377296d-07,-5.51698778d-10/
      data fpp(23,19,1),fpp(23,19,2)/ 2.01064024d-09, 4.92858512d-10/
      data fpp(23,20,1),fpp(23,20,2)/ 1.06413606d-07, 3.80264729d-10/
      data fpp(23,21,1),fpp(23,21,2)/-8.15572027d-08, 3.86082573d-10/
      data fpp(23,22,1),fpp(23,22,2)/ 4.22576861d-08,-1.24595021d-10/
      data fpp(23,23,1),fpp(23,23,2)/ 0.00000000d+00,-4.87702490d-10/
      data fpp(24, 1,1),fpp(24, 1,2)/ 0.00000000d+00, 7.76492579d-09/
      data fpp(24, 2,1),fpp(24, 2,2)/ 4.73847575d-08, 6.87014842d-09/
      data fpp(24, 3,1),fpp(24, 3,2)/-2.73510645d-06,-1.12455195d-08/
      data fpp(24, 4,1),fpp(24, 4,2)/ 2.77661330d-06, 3.09119294d-08/
      data fpp(24, 5,1),fpp(24, 5,2)/ 3.16757689d-06, 5.19780177d-09/
      data fpp(24, 6,1),fpp(24, 6,2)/ 4.84905533d-06, 1.09686348d-09/
      data fpp(24, 7,1),fpp(24, 7,2)/ 6.51904968d-06,-1.19852557d-08/
      data fpp(24, 8,1),fpp(24, 8,2)/ 5.06612198d-06,-2.27558407d-08/
      data fpp(24, 9,1),fpp(24, 9,2)/ 5.66406897d-06,-1.45913815d-08/
      data fpp(24,10,1),fpp(24,10,2)/ 2.94885709d-06,-4.79352170d-11/
      data fpp(24,11,1),fpp(24,11,2)/ 1.46273162d-06, 5.78312234d-09/
      data fpp(24,12,1),fpp(24,12,2)/ 3.85081213d-07, 4.51544584d-09/
      data fpp(24,13,1),fpp(24,13,2)/-1.46060268d-07, 1.35509430d-09/
      data fpp(24,14,1),fpp(24,14,2)/ 3.00746457d-07, 8.64176963d-10/
      data fpp(24,15,1),fpp(24,15,2)/ 1.57669929d-07,-6.11802152d-10/
      data fpp(24,16,1),fpp(24,16,2)/ 3.76671328d-07,-2.16968356d-10/
      data fpp(24,17,1),fpp(24,17,2)/ 3.77807513d-07,-3.20324425d-10/
      data fpp(24,18,1),fpp(24,18,2)/ 3.17589100d-07,-3.01733944d-10/
      data fpp(24,19,1),fpp(24,19,2)/ 2.83491618d-07, 3.27260200d-10/
      data fpp(24,20,1),fpp(24,20,2)/ 2.65848759d-07, 1.92693142d-10/
      data fpp(24,21,1),fpp(24,21,2)/ 8.79442701d-08, 1.01967231d-10/
      data fpp(24,22,1),fpp(24,22,2)/ 1.36097113d-07,-5.62065988d-13/
      data fpp(24,23,1),fpp(24,23,2)/ 0.00000000d+00,-9.97189670d-11/
      data fpp(25, 1,1),fpp(25, 1,2)/ 0.00000000d+00,-6.15432296d-09/
      data fpp(25, 2,1),fpp(25, 2,2)/ 4.95681325d-08,-8.91354072d-10/
      data fpp(25, 3,1),fpp(25, 3,2)/ 1.68790376d-06, 7.31973925d-09/
      data fpp(25, 4,1),fpp(25, 4,2)/-7.15553831d-07, 5.21239706d-09/
      data fpp(25, 5,1),fpp(25, 5,2)/ 7.51453656d-08, 3.03067249d-09/
      data fpp(25, 6,1),fpp(25, 6,2)/ 1.23566826d-06, 4.26491297d-09/
      data fpp(25, 7,1),fpp(25, 7,2)/ 1.92772491d-06,-1.28903244d-08/
      data fpp(25, 8,1),fpp(25, 8,2)/ 3.95017493d-06,-7.03615500d-10/
      data fpp(25, 9,1),fpp(25, 9,2)/ 3.07758193d-06,-1.06952136d-08/
      data fpp(25,10,1),fpp(25,10,2)/ 1.90206504d-06, 3.74486494d-11/
      data fpp(25,11,1),fpp(25,11,2)/ 5.93822057d-07, 2.74541904d-09/
      data fpp(25,12,1),fpp(25,12,2)/ 9.36200958d-08, 2.18087521d-09/
      data fpp(25,13,1),fpp(25,13,2)/ 1.69422691d-07, 1.13108013d-09/
      data fpp(25,14,1),fpp(25,14,2)/-4.38678382d-07,-1.05195730d-10/
      data fpp(25,15,1),fpp(25,15,2)/ 3.69968461d-08,-1.10297211d-10/
      data fpp(25,16,1),fpp(25,16,2)/ 6.94792383d-08,-5.36154255d-11/
      data fpp(25,17,1),fpp(25,17,2)/ 1.42781479d-07,-2.75241087d-10/
      data fpp(25,18,1),fpp(25,18,2)/ 1.69266305d-07,-4.54202269d-11/
      data fpp(25,19,1),fpp(25,19,2)/ 6.40228862d-08, 4.56921995d-10/
      data fpp(25,20,1),fpp(25,20,2)/-2.09808640d-07,-5.82267751d-10/
      data fpp(25,21,1),fpp(25,21,2)/-3.02198777d-08, 6.72149010d-10/
      data fpp(25,22,1),fpp(25,22,2)/-1.06646140d-07,-3.06328289d-10/
      data fpp(25,23,1),fpp(25,23,2)/ 0.00000000d+00,-6.46835856d-10/
      data fpp(26, 1,1),fpp(26, 1,2)/ 0.00000000d+00,-4.41869869d-10/
      data fpp(26, 2,1),fpp(26, 2,2)/-5.65728757d-09, 4.83739737d-10/
      data fpp(26, 3,1),fpp(26, 3,2)/-4.16508587d-07, 9.06910920d-10/
      data fpp(26, 4,1),fpp(26, 4,2)/ 3.25602022d-07, 3.08861658d-09/
      data fpp(26, 5,1),fpp(26, 5,2)/ 6.11841643d-07, 3.53862275d-09/
      data fpp(26, 6,1),fpp(26, 6,2)/ 7.68271637d-07,-4.43107588d-10/
      data fpp(26, 7,1),fpp(26, 7,2)/ 1.13005067d-06,-1.76619240d-09/
      data fpp(26, 8,1),fpp(26, 8,2)/ 7.33178302d-07,-4.49212281d-09/
      data fpp(26, 9,1),fpp(26, 9,2)/ 9.85603330d-07,-4.26531636d-09/
      data fpp(26,10,1),fpp(26,10,2)/ 7.22882756d-07,-5.57989523d-10/
      data fpp(26,11,1),fpp(26,11,2)/ 4.81980147d-07, 1.69727445d-09/
      data fpp(26,12,1),fpp(26,12,2)/ 2.00438403d-07, 1.56889172d-09/
      data fpp(26,13,1),fpp(26,13,2)/-5.16304957d-08,-7.72841348d-10/
      data fpp(26,14,1),fpp(26,14,2)/ 4.93967070d-07, 1.52247367d-09/
      data fpp(26,15,1),fpp(26,15,2)/ 1.74342686d-07,-1.11705333d-09/
      data fpp(26,16,1),fpp(26,16,2)/ 6.54117193d-08, 5.45739644d-10/
      data fpp(26,17,1),fpp(26,17,2)/ 1.10665696d-08,-4.65905248d-10/
      data fpp(26,18,1),fpp(26,18,2)/-3.46543193d-08, 1.17881347d-10/
      data fpp(26,19,1),fpp(26,19,2)/-5.95831633d-08,-5.62013992d-12/
      data fpp(26,20,1),fpp(26,20,2)/ 9.33858021d-08,-9.54007872d-11/
      data fpp(26,21,1),fpp(26,21,2)/ 3.29352406d-08, 3.87223289d-10/
      data fpp(26,22,1),fpp(26,22,2)/ 5.04874469d-08,-2.53492368d-10/
      data fpp(26,23,1),fpp(26,23,2)/ 0.00000000d+00,-5.73253816d-10/
      data fpp(27, 1,1),fpp(27, 1,2)/ 0.00000000d+00,-4.08735667d-10/
      data fpp(27, 2,1),fpp(27, 2,2)/-7.81220355d-09, 1.74713341d-11/
      data fpp(27, 3,1),fpp(27, 3,2)/ 1.05573882d-07, 3.38850330d-10/
      data fpp(27, 4,1),fpp(27, 4,2)/-1.90291490d-08, 1.02712734d-09/
      data fpp(27, 5,1),fpp(27, 5,2)/ 4.69023877d-08, 3.52640294d-10/
      data fpp(27, 6,1),fpp(27, 6,2)/ 1.97350961d-07,-3.76885193d-11/
      data fpp(27, 7,1),fpp(27, 7,2)/ 3.25985522d-07,-2.01886217d-10/
      data fpp(27, 8,1),fpp(27, 8,2)/ 5.05377628d-07,-1.55476661d-09/
      data fpp(27, 9,1),fpp(27, 9,2)/ 4.84399049d-07,-7.79047325d-10/
      data fpp(27,10,1),fpp(27,10,2)/ 3.60319213d-07, 1.14525283d-10/
      data fpp(27,11,1),fpp(27,11,2)/ 1.17148529d-07, 3.20946194d-10/
      data fpp(27,12,1),fpp(27,12,2)/ 1.18747419d-08,-1.98310058d-10/
      data fpp(27,13,1),fpp(27,13,2)/ 1.01801416d-08, 1.67229404d-09/
      data fpp(27,14,1),fpp(27,14,2)/-2.42562020d-07,-1.69086609d-09/
      data fpp(27,15,1),fpp(27,15,2)/-1.21526482d-07,-3.08829675d-10/
      data fpp(27,16,1),fpp(27,16,2)/ 9.02522307d-09, 1.12618479d-09/
      data fpp(27,17,1),fpp(27,17,2)/ 1.54095515d-08,-5.95909491d-10/
      data fpp(27,18,1),fpp(27,18,2)/ 1.93298055d-08, 5.74531723d-11/
      data fpp(27,19,1),fpp(27,19,2)/ 2.67380466d-08, 3.66096802d-10/
      data fpp(27,20,1),fpp(27,20,2)/-5.52530863d-08,-3.21840380d-10/
      data fpp(27,21,1),fpp(27,21,2)/-2.36957830d-08, 3.21264718d-10/
      data fpp(27,22,1),fpp(27,22,2)/-3.81392705d-08,-3.63218491d-10/
      data fpp(27,23,1),fpp(27,23,2)/ 0.00000000d+00,-6.68390755d-10/
      data fpp(28, 1,1),fpp(28, 1,2)/ 0.00000000d+00, 1.93346221d-09/
      data fpp(28, 2,1),fpp(28, 2,2)/-2.30938982d-08, 9.33075574d-10/
      data fpp(28, 3,1),fpp(28, 3,2)/ 5.42130590d-08,-8.65764509d-10/
      data fpp(28, 4,1),fpp(28, 4,2)/-6.94854255d-08, 1.29982462d-10/
      data fpp(28, 5,1),fpp(28, 5,2)/-3.19451194d-07, 3.45834662d-10/
      data fpp(28, 6,1),fpp(28, 6,2)/-4.17675480d-07, 8.86678888d-10/
      data fpp(28, 7,1),fpp(28, 7,2)/-5.73992761d-07,-1.49255022d-09/
      data fpp(28, 8,1),fpp(28, 8,2)/-4.74688814d-07, 2.83521977d-10/
      data fpp(28, 9,1),fpp(28, 9,2)/-4.63199524d-07, 3.58462308d-10/
      data fpp(28,10,1),fpp(28,10,2)/-2.44159606d-07,-6.17147914d-10/
      data fpp(28,11,1),fpp(28,11,2)/-2.30574265d-07, 3.10129346d-10/
      data fpp(28,12,1),fpp(28,12,2)/-1.27937371d-07,-2.33694698d-11/
      data fpp(28,13,1),fpp(28,13,2)/ 1.09099292d-08,-2.16651467d-10/
      data fpp(28,14,1),fpp(28,14,2)/-6.63718990d-07, 2.89975336d-10/
      data fpp(28,15,1),fpp(28,15,2)/-3.48236759d-07, 2.56750122d-10/
      data fpp(28,16,1),fpp(28,16,2)/-4.15126115d-08,-1.16975826d-10/
      data fpp(28,17,1),fpp(28,17,2)/-1.27047758d-08,-3.88846819d-10/
      data fpp(28,18,1),fpp(28,18,2)/ 1.73350972d-08, 4.72363100d-10/
      data fpp(28,19,1),fpp(28,19,2)/ 7.26309767d-08,-9.00605582d-10/
      data fpp(28,20,1),fpp(28,20,2)/-1.12373457d-07, 1.33005923d-09/
      data fpp(28,21,1),fpp(28,21,2)/-5.81521085d-08,-8.19631331d-10/
      data fpp(28,22,1),fpp(28,22,2)/-7.79303647d-08, 1.48466094d-10/
      data fpp(28,23,1),fpp(28,23,2)/ 0.00000000d+00, 2.25766953d-10/
 
      data fpppp( 1, 1),fpppp( 1, 2)/-7.10943030d-03,-1.27634389d-02/
      data fpppp( 1, 3),fpppp( 1, 4)/ 5.10740782d-02,-1.28308745d-01/
      data fpppp( 1, 5),fpppp( 1, 6)/ 1.40258311d-01,-3.46560155d-02/
      data fpppp( 1, 7),fpppp( 1, 8)/-3.15736657d-02, 2.16079167d-02/
      data fpppp( 1, 9),fpppp( 1,10)/-3.57119921d-03,-1.31929887d-03/
      data fpppp( 1,11),fpppp( 1,12)/ 4.35644104d-04, 3.11639962d-04/
      data fpppp( 1,13),fpppp( 1,14)/ 9.61043644d-05,-1.44950494d-04/
      data fpppp( 1,15),fpppp( 1,16)/ 3.49485561d-05,-9.97702228d-06/
      data fpppp( 1,17),fpppp( 1,18)/ 3.37990590d-05,-4.48827171d-05/
      data fpppp( 1,19),fpppp( 1,20)/ 1.69734741d-05, 1.55602071d-06/
      data fpppp( 1,21),fpppp( 1,22)/-2.11774965d-06,-5.07772083d-08/
      data fpppp( 1,23) /             3.75983002d-07 /
      data fpppp( 2, 1),fpppp( 2, 2)/ 9.12260301d-05,-5.31849300d-03/
      data fpppp( 2, 3),fpppp( 2, 4)/ 1.44305617d-02,-5.38760917d-02/
      data fpppp( 2, 5),fpppp( 2, 6)/ 6.89141052d-02,-8.52289609d-03/
      data fpppp( 2, 7),fpppp( 2, 8)/-2.40515276d-02, 1.10931696d-02/
      data fpppp( 2, 9),fpppp( 2,10)/-2.04875441d-03,-7.26705254d-04/
      data fpppp( 2,11),fpppp( 2,12)/ 3.98696566d-04, 1.24123969d-04/
      data fpppp( 2,13),fpppp( 2,14)/ 4.90309301d-05,-1.01621540d-04/
      data fpppp( 2,15),fpppp( 2,16)/ 2.74733385d-05,-3.62523126d-06/
      data fpppp( 2,17),fpppp( 2,18)/ 1.29285344d-05,-2.30618998d-05/
      data fpppp( 2,19),fpppp( 2,20)/ 1.09157352d-05,-1.54410984d-08/
      data fpppp( 2,21),fpppp( 2,22)/-1.29358541d-06,-1.98707097d-07/
      data fpppp( 2,23) /             2.18164752d-07 /
      data fpppp( 3, 1),fpppp( 3, 2)/ 1.53216651d-02,-1.11542701d-03/
      data fpppp( 3, 3),fpppp( 3, 4)/-1.74104323d-02,-3.42027416d-02/
      data fpppp( 3, 5),fpppp( 3, 6)/ 1.21851268d-01,-9.69351058d-02/
      data fpppp( 3, 7),fpppp( 3, 8)/ 5.02229989d-02,-2.92088605d-02/
      data fpppp( 3, 9),fpppp( 3,10)/-2.17562464d-03, 6.32965701d-03/
      data fpppp( 3,11),fpppp( 3,12)/-3.06013739d-03, 6.10275138d-04/
      data fpppp( 3,13),fpppp( 3,14)/-2.19444957d-04, 6.85316831d-06/
      data fpppp( 3,15),fpppp( 3,16)/ 8.06889796d-06, 7.45819843d-06/
      data fpppp( 3,17),fpppp( 3,18)/-2.09450091d-05, 6.39731582d-06/
      data fpppp( 3,19),fpppp( 3,20)/ 7.48740010d-06,-5.73651603d-06/
      data fpppp( 3,21),fpppp( 3,22)/ 2.21731506d-06,-1.25302977d-06/
      data fpppp( 3,23) /            -1.45932433d-06 /
      data fpppp( 4, 1),fpppp( 4, 2)/ 2.44786451d-03, 1.44342188d-02/
      data fpppp( 4, 3),fpppp( 4, 4)/-6.60602548d-02, 1.77128169d-01/
      data fpppp( 4, 5),fpppp( 4, 6)/-2.60196359d-01, 2.15561336d-01/
      data fpppp( 4, 7),fpppp( 4, 8)/-1.09135834d-01, 3.47446004d-02/
      data fpppp( 4, 9),fpppp( 4,10)/ 3.47010774d-03,-9.23717102d-03/
      data fpppp( 4,11),fpppp( 4,12)/ 5.45763112d-03,-1.26140876d-03/
      data fpppp( 4,13),fpppp( 4,14)/ 2.86987741d-04,-1.12682261d-04/
      data fpppp( 4,15),fpppp( 4,16)/ 3.04167377d-05, 1.98089274d-06/
      data fpppp( 4,17),fpppp( 4,18)/-9.30798667d-06, 9.12213690d-06/
      data fpppp( 4,19),fpppp( 4,20)/-5.14384815d-06, 3.06605497d-06/
      data fpppp( 4,21),fpppp( 4,22)/-3.67536128d-06, 8.65022297d-07/
      data fpppp( 4,23) /             2.18203450d-06 /
      data fpppp( 5, 1),fpppp( 5, 2)/ 1.67264021d-03, 1.62740650d-02/
      data fpppp( 5, 3),fpppp( 5, 4)/-6.15362049d-02, 1.84094456d-01/
      data fpppp( 5, 5),fpppp( 5, 6)/-2.57305184d-01, 1.50877336d-01/
      data fpppp( 5, 7),fpppp( 5, 8)/-3.87886907d-02, 1.06015580d-02/
      data fpppp( 5, 9),fpppp( 5,10)/-4.40337328d-03, 3.87773850d-03/
      data fpppp( 5,11),fpppp( 5,12)/-1.86454593d-03, 5.42563775d-04/
      data fpppp( 5,13),fpppp( 5,14)/-1.97842668d-04, 3.05386457d-05/
      data fpppp( 5,15),fpppp( 5,16)/-8.05026673d-06, 7.33313284d-06/
      data fpppp( 5,17),fpppp( 5,18)/-1.00823517d-06, 1.39998244d-07/
      data fpppp( 5,19),fpppp( 5,20)/ 2.40973675d-06,-3.60054250d-06/
      data fpppp( 5,21),fpppp( 5,22)/ 2.93740490d-07,-6.52662396d-07/
      data fpppp( 5,23) /            -2.16012174d-07 /
      data fpppp( 6, 1),fpppp( 6, 2)/-1.99341787d-02,-1.37002519d-02/
      data fpppp( 6, 3),fpppp( 6, 4)/ 8.70370409d-02,-1.42987447d-01/
      data fpppp( 6, 5),fpppp( 6, 6)/ 1.50304216d-01,-1.60241717d-01/
      data fpppp( 6, 7),fpppp( 6, 8)/ 9.45090648d-02,-1.72767066d-02/
      data fpppp( 6, 9),fpppp( 6,10)/ 3.81545496d-03,-1.51797453d-03/
      data fpppp( 6,11),fpppp( 6,12)/ 4.98409192d-04,-1.04641242d-04/
      data fpppp( 6,13),fpppp( 6,14)/-8.61407485d-06,-1.30494004d-05/
      data fpppp( 6,15),fpppp( 6,16)/ 2.49648445d-07, 1.80237760d-06/
      data fpppp( 6,17),fpppp( 6,18)/ 6.25240135d-06,-1.12382758d-06/
      data fpppp( 6,19),fpppp( 6,20)/-6.79782045d-07,-9.63454416d-07/
      data fpppp( 6,21),fpppp( 6,22)/-1.07663967d-06,-8.66472876d-08/
      data fpppp( 6,23) /             5.88151484d-07 /
      data fpppp( 7, 1),fpppp( 7, 2)/-2.06222240d-03,-6.84481988d-03/
      data fpppp( 7, 3),fpppp( 7, 4)/ 4.58956310d-02,-1.02694587d-01/
      data fpppp( 7, 5),fpppp( 7, 6)/ 1.12408859d-01,-7.09674308d-02/
      data fpppp( 7, 7),fpppp( 7, 8)/ 2.49862154d-02,-8.10192277d-03/
      data fpppp( 7, 9),fpppp( 7,10)/ 3.08263117d-03,-1.68942169d-04/
      data fpppp( 7,11),fpppp( 7,12)/ 6.66020233d-05,-2.66581959d-05/
      data fpppp( 7,13),fpppp( 7,14)/-1.43829381d-05,-2.64510019d-06/
      data fpppp( 7,15),fpppp( 7,16)/-4.20140173d-06, 4.34063822d-06/
      data fpppp( 7,17),fpppp( 7,18)/ 1.62715355d-06, 1.53618614d-06/
      data fpppp( 7,19),fpppp( 7,20)/-9.14572363d-07,-1.03786753d-06/
      data fpppp( 7,21),fpppp( 7,22)/-6.03892999d-07,-8.74578647d-08/
      data fpppp( 7,23) /             4.05417098d-07 /
      data fpppp( 8, 1),fpppp( 8, 2)/-2.01559306d-02,-4.10731073d-03/
      data fpppp( 8, 3),fpppp( 8, 4)/ 4.35938427d-02,-1.94888713d-02/
      data fpppp( 8, 5),fpppp( 8, 6)/-3.00984261d-02,-1.85580717d-02/
      data fpppp( 8, 7),fpppp( 8, 8)/ 2.56288573d-02, 8.50969531d-03/
      data fpppp( 8, 9),fpppp( 8,10)/-2.66339395d-03, 7.83337278d-04/
      data fpppp( 8,11),fpppp( 8,12)/-1.67379271d-04, 2.86978965d-05/
      data fpppp( 8,13),fpppp( 8,14)/-1.86076697d-05, 8.99918760d-07/
      data fpppp( 8,15),fpppp( 8,16)/-2.26101509d-06,-9.71539734d-08/
      data fpppp( 8,17),fpppp( 8,18)/ 2.86485194d-06, 4.37836524d-07/
      data fpppp( 8,19),fpppp( 8,20)/ 1.77190035d-07,-1.25030311d-06/
      data fpppp( 8,21),fpppp( 8,22)/ 8.40037241d-08,-2.65461842d-07/
      data fpppp( 8,23) /            -1.33849580d-07 /
      data fpppp( 9, 1),fpppp( 9, 2)/ 8.06430752d-03, 1.35255576d-02/
      data fpppp( 9, 3),fpppp( 9, 4)/-6.57841836d-02, 1.51604544d-01/
      data fpppp( 9, 5),fpppp( 9, 6)/-1.89804540d-01, 1.28884826d-01/
      data fpppp( 9, 7),fpppp( 9, 8)/-3.95358146d-02, 1.78027242d-03/
      data fpppp( 9, 9),fpppp( 9,10)/ 2.49390946d-04,-8.94713170d-05/
      data fpppp( 9,11),fpppp( 9,12)/ 3.62462449d-05,-2.49937546d-05/
      data fpppp( 9,13),fpppp( 9,14)/-2.76108923d-07,-9.55307289d-07/
      data fpppp( 9,15),fpppp( 9,16)/-2.42188248d-06, 9.38088274d-07/
      data fpppp( 9,17),fpppp( 9,18)/ 4.80340826d-07, 1.27474862d-06/
      data fpppp( 9,19),fpppp( 9,20)/-6.50213310d-07, 2.20901244d-07/
      data fpppp( 9,21),fpppp( 9,22)/-8.03381472d-07, 2.72522255d-07/
      data fpppp( 9,23) /             7.48372712d-07 /
      data fpppp(10, 1),fpppp(10, 2)/ 8.80291167d-03,-3.28042175d-03/
      data fpppp(10, 3),fpppp(10, 4)/ 8.71694994d-05,-5.06234756d-02/
      data fpppp(10, 5),fpppp(10, 6)/ 1.00926225d-01,-4.49031839d-02/
      data fpppp(10, 7),fpppp(10, 8)/-4.28307868d-03, 5.94643492d-04/
      data fpppp(10, 9),fpppp(10,10)/-4.76004185d-04, 1.46876810d-04/
      data fpppp(10,11),fpppp(10,12)/-4.04866323d-05,-1.48800272d-06/
      data fpppp(10,13),fpppp(10,14)/-2.90647213d-06,-2.49254982d-07/
      data fpppp(10,15),fpppp(10,16)/-1.80616026d-07,-1.82798969d-06/
      data fpppp(10,17),fpppp(10,18)/ 1.56410805d-06,-9.53336010d-08/
      data fpppp(10,19),fpppp(10,20)/ 4.97350371d-07,-6.99547911d-07/
      data fpppp(10,21),fpppp(10,22)/ 5.90819176d-07,-4.03569180d-07/
      data fpppp(10,23) /            -7.45170267d-07 /
      data fpppp(11, 1),fpppp(11, 2)/-5.15954505d-04,-2.28890997d-03/
      data fpppp(11, 3),fpppp(11, 4)/ 4.36694348d-03,-1.84780343d-02/
      data fpppp(11, 5),fpppp(11, 6)/ 2.62018923d-02,-6.26138230d-03/
      data fpppp(11, 7),fpppp(11, 8)/-2.47099582d-03,-1.37245452d-03/
      data fpppp(11, 9),fpppp(11,10)/ 6.79034219d-05,-2.68147340d-05/
      data fpppp(11,11),fpppp(11,12)/-1.64209184d-06,-8.75591733d-06/
      data fpppp(11,13),fpppp(11,14)/ 3.31104845d-07,-5.32419632d-07/
      data fpppp(11,15),fpppp(11,16)/-5.45773440d-07, 2.19097423d-07/
      data fpppp(11,17),fpppp(11,18)/-7.47560731d-07, 8.34509658d-07/
      data fpppp(11,19),fpppp(11,20)/-2.90095951d-07, 2.52997640d-07/
      data fpppp(11,21),fpppp(11,22)/-3.31816410d-07, 2.83731947d-07/
      data fpppp(11,23) /             5.56319616d-07 /
      data fpppp(12, 1),fpppp(12, 2)/ 3.51208955d-03, 1.22787520d-03/
      data fpppp(12, 3),fpppp(12, 4)/-1.04964610d-02, 1.08196293d-02/
      data fpppp(12, 5),fpppp(12, 6)/ 6.32977022d-04,-3.12267403d-04/
      data fpppp(12, 7),fpppp(12, 8)/-1.67850700d-03,-3.86649072d-04/
      data fpppp(12, 9),fpppp(12,10)/-1.03265909d-04, 1.34531767d-05/
      data fpppp(12,11),fpppp(12,12)/-1.48927950d-05,-2.40819957d-06/
      data fpppp(12,13),fpppp(12,14)/-4.80666066d-07, 5.89680384d-07/
      data fpppp(12,15),fpppp(12,16)/-7.46558904d-07,-5.68072121d-07/
      data fpppp(12,17),fpppp(12,18)/ 2.65092041d-07,-1.38861578d-07/
      data fpppp(12,19),fpppp(12,20)/ 1.18702454d-07, 1.11037819d-07/
      data fpppp(12,21),fpppp(12,22)/ 1.26855571d-07,-6.64754929d-08/
      data fpppp(12,23) /            -2.00049752d-07 /
      data fpppp(13, 1),fpppp(13, 2)/ 3.71593043d-04, 9.52721909d-05/
      data fpppp(13, 3),fpppp(13, 4)/-4.34919159d-04,-7.65637656d-05/
      data fpppp(13, 5),fpppp(13, 6)/-4.65135316d-04, 1.71394331d-03/
      data fpppp(13, 7),fpppp(13, 8)/-6.72030820d-04,-1.02258330d-04/
      data fpppp(13, 9),fpppp(13,10)/-5.89915374d-05,-2.03144823d-06/
      data fpppp(13,11),fpppp(13,12)/-8.74427487d-06,-6.44763276d-07/
      data fpppp(13,13),fpppp(13,14)/-9.93699037d-08,-7.78672285d-08/
      data fpppp(13,15),fpppp(13,16)/ 6.20816705d-08,-1.84090972d-07/
      data fpppp(13,17),fpppp(13,18)/-3.48570306d-07,-2.86521212d-08/
      data fpppp(13,19),fpppp(13,20)/ 1.41763545d-07, 1.00228757d-07/
      data fpppp(13,21),fpppp(13,22)/-4.17617083d-08, 9.38934156d-08/
      data fpppp(13,23) /             1.50221228d-07 /
      data fpppp(14, 1),fpppp(14, 2)/-1.10625181d-03,-5.88610474d-04/
      data fpppp(14, 3),fpppp(14, 4)/ 2.10715373d-03,-2.82051212d-03/
      data fpppp(14, 5),fpppp(14, 6)/ 1.64189981d-03,-1.93230186d-04/
      data fpppp(14, 7),fpppp(14, 8)/ 8.55921188d-05,-8.54805967d-05/
      data fpppp(14, 9),fpppp(14,10)/-2.19578220d-05,-6.21624747d-06/
      data fpppp(14,11),fpppp(14,12)/-3.42477011d-06,-6.25225160d-07/
      data fpppp(14,13),fpppp(14,14)/ 3.02721630d-07, 7.59625607d-08/
      data fpppp(14,15),fpppp(14,16)/-1.03039853d-07,-3.24649722d-07/
      data fpppp(14,17),fpppp(14,18)/ 6.80418359d-09, 1.20957992d-08/
      data fpppp(14,19),fpppp(14,20)/ 2.12541998d-09,-1.02106798d-07/
      data fpppp(14,21),fpppp(14,22)/ 3.92925019d-07,-1.69879243d-07/
      data fpppp(14,23) /            -4.30444625d-07 /
      data fpppp(15, 1),fpppp(15, 2)/ 2.72118778d-04, 1.09025457d-04/
      data fpppp(15, 3),fpppp(15, 4)/-2.99684711d-04, 1.51264082d-04/
      data fpppp(15, 5),fpppp(15, 6)/-1.64172553d-04, 2.76604044d-04/
      data fpppp(15, 7),fpppp(15, 8)/-4.02502015d-05,-2.34342497d-05/
      data fpppp(15, 9),fpppp(15,10)/-1.63688352d-05,-3.34347255d-06/
      data fpppp(15,11),fpppp(15,12)/-2.57695687d-06, 4.84031959d-07/
      data fpppp(15,13),fpppp(15,14)/-3.40378529d-07, 5.95277217d-08/
      data fpppp(15,15),fpppp(15,16)/ 2.67743264d-07,-2.35820623d-07/
      data fpppp(15,17),fpppp(15,18)/-1.76009193d-07,-1.12920184d-07/
      data fpppp(15,19),fpppp(15,20)/-1.67512052d-08, 5.89525375d-07/
      data fpppp(15,21),fpppp(15,22)/-6.55841827d-07, 2.64658745d-07/
      data fpppp(15,23) /             5.66339953d-07 /
      data fpppp(16, 1),fpppp(16, 2)/-2.87482588d-05,-2.46214499d-05/
      data fpppp(16, 3),fpppp(16, 4)/ 1.07630454d-04,-2.08555474d-04/
      data fpppp(16, 5),fpppp(16, 6)/ 1.00950131d-04, 4.33063597d-05/
      data fpppp(16, 7),fpppp(16, 8)/ 1.39195567d-05,-1.50782335d-05/
      data fpppp(16, 9),fpppp(16,10)/-7.01439141d-06,-2.48928575d-06/
      data fpppp(16,11),fpppp(16,12)/-6.92154672d-07,-3.72470129d-07/
      data fpppp(16,13),fpppp(16,14)/ 1.19814579d-07, 5.23405624d-07/
      data fpppp(16,15),fpppp(16,16)/-5.88871582d-07, 2.64206664d-07/
      data fpppp(16,17),fpppp(16,18)/-2.56926829d-07, 3.99481546d-08/
      data fpppp(16,19),fpppp(16,20)/ 1.87585942d-07,-4.57184083d-07/
      data fpppp(16,21),fpppp(16,22)/ 5.82493275d-07,-1.45770306d-07/
      data fpppp(16,23) /            -3.68907904d-07 /
      data fpppp(17, 1),fpppp(17, 2)/ 2.12267256d-05, 8.69776516d-06/
      data fpppp(17, 3),fpppp(17, 4)/-2.07897000d-05, 9.07760145d-06/
      data fpppp(17, 5),fpppp(17, 6)/-1.80223768d-05, 2.43085987d-05/
      data fpppp(17, 7),fpppp(17, 8)/ 1.14194580d-06,-2.41021780d-06/
      data fpppp(17, 9),fpppp(17,10)/-1.63782153d-06,-6.71435480d-07/
      data fpppp(17,11),fpppp(17,12)/-5.31018145d-07, 4.01602001d-07/
      data fpppp(17,13),fpppp(17,14)/ 2.52817209d-07,-6.28213921d-07/
      data fpppp(17,15),fpppp(17,16)/ 5.54503090d-07,-2.80005070d-07/
      data fpppp(17,17),fpppp(17,18)/ 8.97886602d-08,-1.05456190d-07/
      data fpppp(17,19),fpppp(17,20)/-3.98422459d-08, 1.81398801d-07/
      data fpppp(17,21),fpppp(17,22)/-1.60568216d-07, 4.36004788d-08/
      data fpppp(17,23) /             9.17303988d-08 /
      data fpppp(18, 1),fpppp(18, 2)/-3.89443327d-06,-1.84469787d-06/
      data fpppp(18, 3),fpppp(18, 4)/ 9.64448463d-06,-1.19043977d-05/
      data fpppp(18, 5),fpppp(18, 6)/ 4.66110212d-06,-8.78192137d-07/
      data fpppp(18, 7),fpppp(18, 8)/ 8.60684086d-07,-4.95553788d-07/
      data fpppp(18, 9),fpppp(18,10)/ 3.62876070d-08,-6.94733116d-08/
      data fpppp(18,11),fpppp(18,12)/ 8.36210918d-08, 2.09877484d-08/
      data fpppp(18,13),fpppp(18,14)/-9.81797554d-08, 4.02909794d-07/
      data fpppp(18,15),fpppp(18,16)/-1.95883367d-07,-1.70675756d-07/
      data fpppp(18,17),fpppp(18,18)/ 5.04722695d-08, 3.75656552d-08/
      data fpppp(18,19),fpppp(18,20)/-2.03673232d-07, 4.17724926d-07/
      data fpppp(18,21),fpppp(18,22)/-2.29308323d-07, 4.15839836d-08/
      data fpppp(18,23) /             5.02118454d-08 /
      data fpppp(19, 1),fpppp(19, 2)/ 1.27638419d-06, 8.88229217d-07/
      data fpppp(19, 3),fpppp(19, 4)/ 8.72270291d-07,-4.46374801d-07/
      data fpppp(19, 5),fpppp(19, 6)/-1.93424381d-06, 3.29217389d-07/
      data fpppp(19, 7),fpppp(19, 8)/ 1.21339964d-07,-9.87755448d-08/
      data fpppp(19, 9),fpppp(19,10)/-4.54900113d-07, 3.41038489d-07/
      data fpppp(19,11),fpppp(19,12)/-2.17458714d-07, 4.09661436d-07/
      data fpppp(19,13),fpppp(19,14)/-1.60459283d-07, 2.19297718d-07/
      data fpppp(19,15),fpppp(19,16)/-4.26308782d-07, 5.97744500d-07/
      data fpppp(19,17),fpppp(19,18)/-4.70505824d-07, 7.98438398d-08/
      data fpppp(19,19),fpppp(19,20)/ 4.23639694d-07,-7.22251332d-07/
      data fpppp(19,21),fpppp(19,22)/ 4.67997763d-07,-9.42074438d-08/
      data fpppp(19,23) /            -1.55711422d-07 /
      data fpppp(20, 1),fpppp(20, 2)/-4.98898948d-07, 2.27371928d-07/
      data fpppp(20, 3),fpppp(20, 4)/ 7.31865982d-07, 2.01257892d-06/
      data fpppp(20, 5),fpppp(20, 6)/-2.24028660d-06,-6.16720553d-07/
      data fpppp(20, 7),fpppp(20, 8)/-1.43771170d-06, 3.55370139d-07/
      data fpppp(20, 9),fpppp(20,10)/ 7.76123920d-07,-5.25470951d-07/
      data fpppp(20,11),fpppp(20,12)/ 6.06563913d-07,-2.70243783d-07/
      data fpppp(20,13),fpppp(20,14)/ 3.12107900d-07,-3.27854420d-07/
      data fpppp(20,15),fpppp(20,16)/ 4.10042502d-07,-4.48244522d-07/
      data fpppp(20,17),fpppp(20,18)/ 2.84396133d-07,-8.03791547d-08/
      data fpppp(20,19),fpppp(20,20)/-2.39978086d-07, 4.31088711d-07/
      data fpppp(20,21),fpppp(20,22)/-3.12823427d-07, 1.16000277d-07/
      data fpppp(20,23) /             2.09756598d-07 /
      data fpppp(21, 1),fpppp(21, 2)/ 2.82522217d-07, 3.22377062d-07/
      data fpppp(21, 3),fpppp(21, 4)/ 9.87394802d-08, 7.97325391d-07/
      data fpppp(21, 5),fpppp(21, 6)/-3.96042724d-07,-8.39439296d-07/
      data fpppp(21, 7),fpppp(21, 8)/ 7.42447241d-09,-4.26802314d-07/
      data fpppp(21, 9),fpppp(21,10)/ 5.25837622d-08,-3.09366425d-08/
      data fpppp(21,11),fpppp(21,12)/ 1.07285957d-07, 1.66079708d-07/
      data fpppp(21,13),fpppp(21,14)/-1.31078894d-07, 1.79043199d-07/
      data fpppp(21,15),fpppp(21,16)/-1.54484845d-07, 1.10787900d-07/
      data fpppp(21,17),fpppp(21,18)/-8.29775074d-08,-5.79074376d-09/
      data fpppp(21,19),fpppp(21,20)/ 1.08129571d-07,-1.57485772d-07/
      data fpppp(21,21),fpppp(21,22)/ 1.48214327d-07,-7.17106501d-08/
      data fpppp(21,23) /            -1.41457034d-07 /
      data fpppp(22, 1),fpppp(22, 2)/-6.38389597d-07,-2.68714010d-07/
      data fpppp(22, 3),fpppp(22, 4)/ 1.05730897d-06,-9.63883924d-07/
      data fpppp(22, 5),fpppp(22, 6)/ 7.93095076d-07,-2.60412194d-07/
      data fpppp(22, 7),fpppp(22, 8)/-3.00116596d-07, 7.79368165d-08/
      data fpppp(22, 9),fpppp(22,10)/-4.76523070d-07, 2.68126114d-07/
      data fpppp(22,11),fpppp(22,12)/ 3.14211946d-09, 7.26280392d-09/
      data fpppp(22,13),fpppp(22,14)/ 6.51057956d-08,-5.56694816d-08/
      data fpppp(22,15),fpppp(22,16)/ 4.51835158d-08,-3.51607290d-08/
      data fpppp(22,17),fpppp(22,18)/ 9.97747287d-09, 7.95518602d-10/
      data fpppp(22,19),fpppp(22,20)/-3.56654871d-08, 5.86144436d-08/
      data fpppp(22,21),fpppp(22,22)/-4.70068835d-08, 2.66210832d-08/
      data fpppp(22,23) /             4.90349660d-08 /
      data fpppp(23, 1),fpppp(23, 2)/ 6.10122788d-07, 3.11105741d-07/
      data fpppp(23, 3),fpppp(23, 4)/-9.01569028d-07, 1.08355823d-06/
      data fpppp(23, 5),fpppp(23, 6)/-4.35335606d-07, 7.89322592d-08/
      data fpppp(23, 7),fpppp(23, 8)/ 1.26631885d-08,-4.46074250d-07/
      data fpppp(23, 9),fpppp(23,10)/ 1.52004429d-07,-6.28909015d-08/
      data fpppp(23,11),fpppp(23,12)/ 7.17420048d-08, 3.80640765d-09/
      data fpppp(23,13),fpppp(23,14)/-7.89005202d-09, 2.12804512d-08/
      data fpppp(23,15),fpppp(23,16)/-1.50863501d-08, 7.55781725d-09/
      data fpppp(23,17),fpppp(23,18)/-8.50645883d-09, 8.02166803d-10/
      data fpppp(23,19),fpppp(23,20)/ 6.93246261d-09,-7.96583996d-09/
      data fpppp(23,21),fpppp(23,22)/ 7.38847073d-09,-2.88090111d-09/
      data fpppp(23,23) /            -5.82922080d-09 /
      data fpppp(24, 1),fpppp(24, 2)/-5.07894872d-07,-2.13722324d-07/
      data fpppp(24, 3),fpppp(24, 4)/ 6.83613938d-07,-5.30122800d-07/
      data fpppp(24, 5),fpppp(24, 6)/ 2.07895783d-07, 8.26322854d-09/
      data fpppp(24, 7),fpppp(24, 8)/-2.43704878d-07, 2.17054990d-07/
      data fpppp(24, 9),fpppp(24,10)/-1.32305157d-07, 5.37216238d-08/
      data fpppp(24,11),fpppp(24,12)/-8.83615355d-09, 6.13149387d-09/
      data fpppp(24,13),fpppp(24,14)/ 1.71007139d-08,-1.58574571d-08/
      data fpppp(24,15),fpppp(24,16)/ 1.09361194d-08,-6.16234479d-09/
      data fpppp(24,17),fpppp(24,18)/ 6.41347050d-10,-8.43193622d-11/
      data fpppp(24,19),fpppp(24,20)/ 1.26318632d-09,-3.98114860d-09/
      data fpppp(24,21),fpppp(24,22)/ 5.04571038d-09,-2.63825302d-09/
      data fpppp(24,23) /            -5.54769573d-09 /
      data fpppp(25, 1),fpppp(25, 2)/ 2.62886885d-07, 1.15323185d-07/
      data fpppp(25, 3),fpppp(25, 4)/-3.42875428d-07, 2.86148154d-07/
      data fpppp(25, 5),fpppp(25, 6)/-3.51195584d-08,-5.69122328d-08/
      data fpppp(25, 7),fpppp(25, 8)/ 1.50336592d-07,-2.25139728d-07/
      data fpppp(25, 9),fpppp(25,10)/ 5.54119942d-08,-1.94859713d-08/
      data fpppp(25,11),fpppp(25,12)/ 1.45683253d-08, 9.69513111d-09/
      data fpppp(25,13),fpppp(25,14)/-1.87885764d-08, 2.44249545d-08/
      data fpppp(25,15),fpppp(25,16)/-1.38846636d-08, 4.52212979d-09/
      data fpppp(25,17),fpppp(25,18)/-1.75466464d-09,-3.12516174d-10/
      data fpppp(25,19),fpppp(25,20)/-4.89896532d-09, 9.79309100d-09/
      data fpppp(25,21),fpppp(25,22)/-7.06818135d-09, 3.11873291d-09/
      data fpppp(25,23) /             5.57759386d-09 /
      data fpppp(26, 1),fpppp(26, 2)/-7.24918249d-08,-2.82921053d-08/
      data fpppp(26, 3),fpppp(26, 4)/ 8.84136833d-08,-4.86517699d-08/
      data fpppp(26, 5),fpppp(26, 6)/-3.21564063d-09, 3.03600216d-08/
      data fpppp(26, 7),fpppp(26, 8)/-6.89406753d-08, 6.33263412d-08/
      data fpppp(26, 9),fpppp(26,10)/-2.85333136d-08, 7.88253247d-09/
      data fpppp(26,11),fpppp(26,12)/-1.68773844d-09,-3.56992681d-09/
      data fpppp(26,13),fpppp(26,14)/ 1.77358164d-08,-1.95133508d-08/
      data fpppp(26,15),fpppp(26,16)/ 8.40426971d-09,-1.46212305d-09/
      data fpppp(26,17),fpppp(26,18)/ 7.19371517d-10,-8.97907378d-10/
      data fpppp(26,19),fpppp(26,20)/ 4.11978069d-09,-4.90734683d-09/
      data fpppp(26,21),fpppp(26,22)/ 2.70443502d-09,-1.23022720d-09/
      data fpppp(26,23) /            -1.86590540d-09 /
      data fpppp(27, 1),fpppp(27, 2)/ 1.76813999d-08, 7.91598726d-09/
      data fpppp(27, 3),fpppp(27, 4)/-2.02577596d-08, 1.59976631d-08/
      data fpppp(27, 5),fpppp(27, 6)/ 1.99540326d-09,-3.69518738d-09/
      data fpppp(27, 7),fpppp(27, 8)/ 7.54998322d-09,-1.43229346d-08/
      data fpppp(27, 9),fpppp(27,10)/ 1.65279049d-09,-2.72426487d-09/
      data fpppp(27,11),fpppp(27,12)/ 2.09881816d-09, 2.60280598d-09/
      data fpppp(27,13),fpppp(27,14)/-6.29529084d-09, 7.51550371d-09/
      data fpppp(27,15),fpppp(27,16)/-1.34006200d-09,-1.58428570d-09/
      data fpppp(27,17),fpppp(27,18)/ 2.27162237d-10, 5.27792286d-10/
      data fpppp(27,19),fpppp(27,20)/-2.12905215d-09, 2.62445387d-09/
      data fpppp(27,21),fpppp(27,22)/-1.55585717d-09, 8.38927370d-10/
      data fpppp(27,23) /             1.35511317d-09 /
      data fpppp(28, 1),fpppp(28, 2)/ 1.56206071d-08, 4.91939214d-09/
      data fpppp(28, 3),fpppp(28, 4)/-1.12019704d-08,-8.35281657d-09/
      data fpppp(28, 5),fpppp(28, 6)/ 1.43090886d-08,-1.24655821d-08/
      data fpppp(28, 7),fpppp(28, 8)/ 2.16109213d-08,-1.26290086d-08/
      data fpppp(28, 9),fpppp(28,10)/ 7.82959521d-09,-5.41060101d-09/
      data fpppp(28,11),fpppp(28,12)/ 1.48553426d-09, 4.81155711d-09/
      data fpppp(28,13),fpppp(28,14)/-1.85591383d-08, 2.06164230d-08/
      data fpppp(28,15),fpppp(28,16)/-4.49988483d-09,-3.14236873d-09/
      data fpppp(28,17),fpppp(28,18)/ 3.94381028d-10, 1.63876685d-09/
      data fpppp(28,19),fpppp(28,20)/-5.43408804d-09, 5.67956654d-09/
      data fpppp(28,21),fpppp(28,22)/-2.93063120d-09, 1.60298197d-09/
      data fpppp(28,23) /             2.38122059d-09 /
 
      c(1,1)=fpppp(ix+1,iy+1)
      c(1,2)=fpppp(ix+1,iy  )
      c(2,1)=fpppp(ix  ,iy+1)
      c(2,2)=fpppp(ix,  iy  )
      c(1,3)=fpp(ix+1,iy+1,1)
      c(1,4)=fpp(ix+1,iy  ,1)
      c(2,3)=fpp(ix,  iy+1,1)
      c(2,4)=fpp(ix,  iy,  1)
      c(3,1)=fpp(ix+1,iy+1,2)
      c(3,2)=fpp(ix+1,iy  ,2)
      c(4,1)=fpp(ix,  iy+1,2)
      c(4,2)=fpp(ix,  iy,  2)
      c(3,3)=f(ix+1,iy+1)
      c(3,4)=f(ix+1,iy  )
      c(4,3)=f(ix,  iy+1)
      c(4,4)=f(ix,  iy  )
      px(1)=((xi-xix)**3/(6.0*delxi))-(xi-xix)*delxi/6.0
      px(2)=(xi-xixp1)*delxi/6.0-((xi-xixp1)**3/(6.0*delxi))
      px(3)=(xi-xix)/delxi
      px(4)=(xixp1-xi)/delxi
      py(1)=((yi-yiy)**3/(6.0*delyi))-(yi-yiy)*delyi/6.0
      py(2)=(yi-yiyp1)*delyi/6.0-((yi-yiyp1)**3/(6.0*delyi))
      py(3)=(yi-yiy)/delyi
      py(4)=(yiyp1-yi)/delyi

      fi=0.0d 00
      do l=1,4
        sum=0.0d 00
        do i=1,4
          sum=sum + c(i,l) * px(i)
        enddo
        fi = fi + sum * py(l)
      enddo
      return
      end  
      subroutine c6_spl(xi,yi,ix,iy,delxi,delyi,xix,xixp1,
     x                    yiy,yiyp1,fi)
      implicit real*8 (a-h,o-z)
      dimension fpp(28,23,2),f(28,23),fpppp(28,23)
      dimension c(4,4),px(4),py(4)
 
      data f( 2,17),f( 2,18) /  1.15592000d-03 ,  7.78000000d-04 /
      data f( 2,19),f( 2,20) /  2.18900000d-04 ,  1.82400000d-05 /
      data f( 2,21),f( 2,22) / -1.03000000d-06 , -2.00000000d-08 /
      data f( 2,23) /           0.00000000d+00 /
      data f( 3, 1),f( 3, 2) /  0.00000000d+00 ,  2.31300000d-05 /
      data f( 3, 3),f( 3, 4) /  1.45258000d-03 ,  1.45842100d-02 /
      data f( 3, 5),f( 3, 6) /  3.46053000d-02 ,  2.61530800d-02 /
      data f( 3, 7),f( 3, 8) /  1.31180500d-02 ,  6.94801000d-03 /
      data f( 3, 9),f( 3,10) /  4.08981000d-03 ,  1.28707000d-03 /
      data f( 3,11),f( 3,12) /  1.05030000d-04 , -1.23610000d-04 /
      data f( 3,13),f( 3,14) /  1.70000000d-07 , -8.34800000d-05 /
      data f( 3,15),f( 3,16) / -9.49400000d-05 ,  3.09750000d-04 /
      data f( 3,17),f( 3,18) /  6.50470000d-04 ,  4.36510000d-04 /
      data f( 3,19),f( 3,20) /  1.07860000d-04 ,  1.94000000d-06 /
      data f( 3,21),f( 3,22) / -1.86000000d-06 , -5.00000000d-08 /
      data f( 3,23) /           0.00000000d+00 /
      data f( 4, 1),f( 4, 2) /  0.00000000d+00 ,  3.24800000d-05 /
      data f( 4, 3),f( 4, 4) /  2.14654000d-03 ,  2.29095600d-02 /
      data f( 4, 5),f( 4, 6) /  5.41268000d-02 ,  3.67541100d-02 /
      data f( 4, 7),f( 4, 8) /  1.56584500d-02 ,  6.70312000d-03 /
      data f( 4, 9),f( 4,10) /  3.30493000d-03 ,  1.35197000d-03 /
      data f( 4,11),f( 4,12) /  6.96500000d-05 , -9.21900000d-05 /
      data f( 4,13),f( 4,14) /  1.41700000d-05 , -7.80800000d-05 /
      data f( 4,15),f( 4,16) / -1.53780000d-04 ,  7.76000000d-05 /
      data f( 4,17),f( 4,18) /  3.11030000d-04 ,  2.08360000d-04 /
      data f( 4,19),f( 4,20) /  3.52300000d-05 , -8.37000000d-06 /
      data f( 4,21),f( 4,22) / -2.31000000d-06 , -7.00000000d-08 /
      data f( 4,23) /           0.00000000d+00 /
      data f( 5, 1),f( 5, 2) /  0.00000000d+00 ,  4.20500000d-05 /
      data f( 5, 3),f( 5, 4) /  2.95383000d-03 ,  3.39889900d-02 /
      data f( 5, 5),f( 5, 6) /  6.73036900d-02 ,  4.93049900d-02 /
      data f( 5, 7),f( 5, 8) /  1.76343600d-02 ,  7.21628000d-03 /
      data f( 5, 9),f( 5,10) /  3.37408000d-03 ,  1.17570000d-03 /
      data f( 5,11),f( 5,12) /  4.51500000d-05 , -6.32500000d-05 /
      data f( 5,13),f( 5,14) /  2.38000000d-05 , -6.80000000d-05 /
      data f( 5,15),f( 5,16) / -1.78250000d-04 , -6.59600000d-05 /
      data f( 5,17),f( 5,18) /  9.14600000d-05 ,  6.17900000d-05 /
      data f( 5,19),f( 5,20) / -1.02500000d-05 , -1.42800000d-05 /
      data f( 5,21),f( 5,22) / -2.50000000d-06 , -1.10000000d-07 /
      data f( 5,23) /           0.00000000d+00 /
      data f( 6, 1),f( 6, 2) /  0.00000000d+00 ,  5.03000000d-05 /
      data f( 6, 3),f( 6, 4) /  3.67393000d-03 ,  4.58161200d-02 /
      data f( 6, 5),f( 6, 6) /  7.07110300d-02 ,  6.15370400d-02 /
      data f( 6, 7),f( 6, 8) /  1.97397400d-02 ,  7.55911000d-03 /
      data f( 6, 9),f( 6,10) /  3.35463000d-03 ,  9.94650000d-04 /
      data f( 6,11),f( 6,12) /  2.85900000d-05 , -4.01100000d-05 /
      data f( 6,13),f( 6,14) /  3.00900000d-05 , -5.63100000d-05 /
      data f( 6,15),f( 6,16) / -1.81200000d-04 , -1.46420000d-04 /
      data f( 6,17),f( 6,18) / -4.24200000d-05 , -2.75800000d-05 /
      data f( 6,19),f( 6,20) / -3.68600000d-05 , -1.71600000d-05 /
      data f( 6,21),f( 6,22) / -2.50000000d-06 , -1.10000000d-07 /
      data f( 6,23) /           0.00000000d+00 /
      data f( 7, 1),f( 7, 2) /  0.00000000d+00 ,  1.01780000d-04 /
      data f( 7, 3),f( 7, 4) /  4.27574000d-03 ,  5.30561700d-02 /
      data f( 7, 5),f( 7, 6) /  7.33807700d-02 ,  6.79513500d-02 /
      data f( 7, 7),f( 7, 8) /  2.16679800d-02 ,  7.66161000d-03 /
      data f( 7, 9),f( 7,10) /  3.07961000d-03 ,  6.92340000d-04 /
      data f( 7,11),f( 7,12) /  1.06700000d-05 , -1.11700000d-05 /
      data f( 7,13),f( 7,14) /  3.38900000d-05 , -3.38900000d-05 /
      data f( 7,15),f( 7,16) / -1.54770000d-04 , -1.94340000d-04 /
      data f( 7,17),f( 7,18) / -1.52660000d-04 , -1.02690000d-04 /
      data f( 7,19),f( 7,20) / -5.56600000d-05 , -1.75600000d-05 /
      data f( 7,21),f( 7,22) / -2.23000000d-06 , -1.10000000d-07 /
      data f( 7,23) /           0.00000000d+00 /
      data f( 8, 1),f( 8, 2) /  0.00000000d+00 ,  5.33500000d-05 /
      data f( 8, 3),f( 8, 4) /  3.59103000d-03 ,  4.55866800d-02 /
      data f( 8, 5),f( 8, 6) /  7.79865000d-02 ,  6.11157300d-02 /
      data f( 8, 7),f( 8, 8) /  1.99504500d-02 ,  6.33151000d-03 /
      data f( 8, 9),f( 8,10) /  2.70303000d-03 ,  4.64700000d-04 /
      data f( 8,11),f( 8,12) /  2.27000000d-06 ,  1.74000000d-06 /
      data f( 8,13),f( 8,14) /  3.07600000d-05 , -1.85300000d-05 /
      data f( 8,15),f( 8,16) / -1.15580000d-04 , -1.72880000d-04 /
      data f( 8,17),f( 8,18) / -1.60240000d-04 , -1.09080000d-04 /
      data f( 8,19),f( 8,20) / -5.23800000d-05 , -1.47900000d-05 /
      data f( 8,21),f( 8,22) / -1.83000000d-06 , -1.00000000d-07 /
      data f( 8,23) /           0.00000000d+00 /
      data f( 9, 1),f( 9, 2) /  0.00000000d+00 ,  3.27200000d-05 /
      data f( 9, 3),f( 9, 4) /  2.27813000d-03 ,  2.48151500d-02 /
      data f( 9, 5),f( 9, 6) /  5.97097300d-02 ,  3.82910200d-02 /
      data f( 9, 7),f( 9, 8) /  1.38420700d-02 ,  4.89384000d-03 /
      data f( 9, 9),f( 9,10) /  1.95391000d-03 ,  2.93340000d-04 /
      data f( 9,11),f( 9,12) / -2.28000000d-06 ,  6.20000000d-06 /
      data f( 9,13),f( 9,14) /  2.50600000d-05 , -9.16000000d-06 /
      data f( 9,15),f( 9,16) / -8.12900000d-05 , -1.34010000d-04 /
      data f( 9,17),f( 9,18) / -1.33490000d-04 , -9.17200000d-05 /
      data f( 9,19),f( 9,20) / -4.22400000d-05 , -1.13500000d-05 /
      data f( 9,21),f( 9,22) / -1.30000000d-06 , -7.00000000d-08 /
      data f( 9,23) /           0.00000000d+00 /
      data f(10, 1),f(10, 2) /  0.00000000d+00 ,  2.01900000d-05 /
      data f(10, 3),f(10, 4) /  1.20736000d-03 ,  1.12249200d-02 /
      data f(10, 5),f(10, 6) /  2.65661400d-02 ,  2.06518700d-02 /
      data f(10, 7),f(10, 8) /  8.98229000d-03 ,  3.41853000d-03 /
      data f(10, 9),f(10,10) /  1.33553000d-03 ,  1.70010000d-04 /
      data f(10,11),f(10,12) / -5.05000000d-06 ,  7.17000000d-06 /
      data f(10,13),f(10,14) /  1.93200000d-05 , -4.76000000d-06 /
      data f(10,15),f(10,16) / -5.57400000d-05 , -9.77300000d-05 /
      data f(10,17),f(10,18) / -1.01490000d-04 , -7.01600000d-05 /
      data f(10,19),f(10,20) / -3.15000000d-05 , -8.10000000d-06 /
      data f(10,21),f(10,22) / -9.10000000d-07 , -5.00000000d-08 /
      data f(10,23) /           0.00000000d+00 /
      data f(11, 1),f(11, 2) /  0.00000000d+00 ,  9.27000000d-06 /
      data f(11, 3),f(11, 4) /  5.51170000d-04 ,  4.92974000d-03 /
      data f(11, 5),f(11, 6) /  1.15524800d-02 ,  1.07772500d-02 /
      data f(11, 7),f(11, 8) /  5.36188000d-03 ,  2.18610000d-03 /
      data f(11, 9),f(11,10) /  8.41920000d-04 ,  8.67100000d-05 /
      data f(11,11),f(11,12) / -7.13000000d-06 ,  6.79000000d-06 /
      data f(11,13),f(11,14) /  1.47900000d-05 , -2.59000000d-06 /
      data f(11,15),f(11,16) / -3.84200000d-05 , -6.99000000d-05 /
      data f(11,17),f(11,18) / -7.42500000d-05 , -5.14600000d-05 /
      data f(11,19),f(11,20) / -2.27100000d-05 , -5.64000000d-06 /
      data f(11,21),f(11,22) / -6.40000000d-07 , -6.00000000d-08 /
      data f(11,23) /           0.00000000d+00 /
      data f(12, 1),f(12, 2) /  0.00000000d+00 ,  2.85000000d-06 /
      data f(12, 3),f(12, 4) /  2.96480000d-04 ,  1.00318000d-03 /
      data f(12, 5),f(12, 6) /  5.22877000d-03 ,  5.36088000d-03 /
      data f(12, 7),f(12, 8) /  2.98662000d-03 ,  1.28863000d-03 /
      data f(12, 9),f(12,10) /  4.83610000d-04 ,  3.40800000d-05 /
      data f(12,11),f(12,12) / -8.23000000d-06 ,  6.01000000d-06 /
      data f(12,13),f(12,14) /  1.15500000d-05 , -1.37000000d-06 /
      data f(12,15),f(12,16) / -2.72900000d-05 , -4.98300000d-05 /
      data f(12,17),f(12,18) / -5.36700000d-05 , -3.72300000d-05 /
      data f(12,19),f(12,20) / -1.61900000d-05 , -3.91000000d-06 /
      data f(12,21),f(12,22) / -4.50000000d-07 , -5.00000000d-08 /
      data f(12,23) /           0.00000000d+00 /
      data f(13, 1),f(13, 2) /  0.00000000d+00 ,  1.24000000d-06 /
      data f(13, 3),f(13, 4) /  4.74400000d-05 , -2.13620000d-04 /
      data f(13, 5),f(13, 6) /  1.42993000d-03 ,  1.75126000d-03 /
      data f(13, 7),f(13, 8) /  1.10965000d-03 ,  4.93190000d-04 /
      data f(13, 9),f(13,10) /  1.65550000d-04 , -6.04000000d-06 /
      data f(13,11),f(13,12) / -8.90000000d-06 ,  4.33000000d-06 /
      data f(13,13),f(13,14) /  8.36000000d-06 , -2.90000000d-07 /
      data f(13,15),f(13,16) / -1.61300000d-05 , -3.05200000d-05 /
      data f(13,17),f(13,18) / -3.32200000d-05 , -2.32000000d-05 /
      data f(13,19),f(13,20) / -1.01200000d-05 , -2.50000000d-06 /
      data f(13,21),f(13,22) / -2.40000000d-07 , -3.00000000d-08 /
      data f(13,23) /           0.00000000d+00 /
      data f(14, 1),f(14, 2) /  0.00000000d+00 , -1.80000000d-07 /
      data f(14, 3),f(14, 4) / -1.89900000d-05 ,  4.11600000d-05 /
      data f(14, 5),f(14, 6) /  3.97530000d-04 ,  5.18240000d-04 /
      data f(14, 7),f(14, 8) /  3.41490000d-04 ,  1.37240000d-04 /
      data f(14, 9),f(14,10) /  2.61300000d-05 , -1.91200000d-05 /
      data f(14,11),f(14,12) / -8.33000000d-06 ,  3.15000000d-06 /
      data f(14,13),f(14,14) /  5.96000000d-06 ,  6.80000000d-07 /
      data f(14,15),f(14,16) / -9.51000000d-06 , -1.87400000d-05 /
      data f(14,17),f(14,18) / -2.08100000d-05 , -1.47400000d-05 /
      data f(14,19),f(14,20) / -6.54000000d-06 , -1.66000000d-06 /
      data f(14,21),f(14,22) / -1.70000000d-07 ,  3.00000000d-08 /
      data f(14,23) /           0.00000000d+00 /
      data f(15, 1),f(15, 2) /  0.00000000d+00 , -1.70000000d-07 /
      data f(15, 3),f(15, 4) / -5.82000000d-06 ,  2.67400000d-05 /
      data f(15, 5),f(15, 6) /  1.54740000d-04 ,  2.02710000d-04 /
      data f(15, 7),f(15, 8) /  1.26510000d-04 ,  3.56900000d-05 /
      data f(15, 9),f(15,10) / -1.10200000d-05 , -2.04900000d-05 /
      data f(15,11),f(15,12) / -7.42000000d-06 ,  2.29000000d-06 /
      data f(15,13),f(15,14) /  4.70000000d-06 ,  1.04000000d-06 /
      data f(15,15),f(15,16) / -6.45000000d-06 , -1.33700000d-05 /
      data f(15,17),f(15,18) / -1.50300000d-05 , -1.07100000d-05 /
      data f(15,19),f(15,20) / -4.81000000d-06 , -1.25000000d-06 /
      data f(15,21),f(15,22) / -5.00000000d-08 ,  2.00000000d-08 /
      data f(15,23) /           0.00000000d+00 /
      data f(16, 1),f(16, 2) /  0.00000000d+00 , -7.00000000d-08 /
      data f(16, 3),f(16, 4) / -1.65000000d-06 ,  9.48000000d-06 /
      data f(16, 5),f(16, 6) /  4.96300000d-05 ,  6.23100000d-05 /
      data f(16, 7),f(16, 8) /  2.83300000d-05 , -9.07000000d-06 /
      data f(16, 9),f(16,10) / -2.50000000d-05 , -1.91900000d-05 /
      data f(16,11),f(16,12) / -6.52000000d-06 ,  1.66000000d-06 /
      data f(16,13),f(16,14) /  3.49000000d-06 ,  1.00000000d-06 /
      data f(16,15),f(16,16) / -4.43000000d-06 , -9.48000000d-06 /
      data f(16,17),f(16,18) / -1.07900000d-05 , -7.74000000d-06 /
      data f(16,19),f(16,20) / -3.49000000d-06 , -8.80000000d-07 /
      data f(16,21),f(16,22) / -6.00000000d-08 , -3.00000000d-08 /
      data f(16,23) /           0.00000000d+00 /
      data f(17, 1),f(17, 2) /  0.00000000d+00 ,  1.00000000d-08 /
      data f(17, 3),f(17, 4) / -6.10000000d-07 , -1.21000000d-06 /
      data f(17, 5),f(17, 6) / -3.70000000d-07 , -5.48000000d-06 /
      data f(17, 7),f(17, 8) / -1.76100000d-05 , -2.60700000d-05 /
      data f(17, 9),f(17,10) / -2.61800000d-05 , -1.53500000d-05 /
      data f(17,11),f(17,12) / -4.70000000d-06 ,  9.10000000d-07 /
      data f(17,13),f(17,14) /  2.16000000d-06 ,  4.10000000d-07 /
      data f(17,15),f(17,16) / -2.48000000d-06 , -5.66000000d-06 /
      data f(17,17),f(17,18) / -6.54000000d-06 , -4.64000000d-06 /
      data f(17,19),f(17,20) / -2.06000000d-06 , -5.40000000d-07 /
      data f(17,21),f(17,22) / -3.00000000d-08 , -2.00000000d-08 /
      data f(17,23) /           0.00000000d+00 /
      data f(18, 1),f(18, 2) /  0.00000000d+00 , -5.00000000d-08 /
      data f(18, 3),f(18, 4) / -4.60000000d-07 , -2.62000000d-06 /
      data f(18, 5),f(18, 6) / -7.45000000d-06 , -1.43300000d-05 /
      data f(18, 7),f(18, 8) / -2.03300000d-05 , -2.22500000d-05 /
      data f(18, 9),f(18,10) / -2.00800000d-05 , -1.11700000d-05 /
      data f(18,11),f(18,12) / -3.33000000d-06 ,  4.60000000d-07 /
      data f(18,13),f(18,14) /  1.24000000d-06 ,  2.50000000d-07 /
      data f(18,15),f(18,16) / -1.72000000d-06 , -3.52000000d-06 /
      data f(18,17),f(18,18) / -4.02000000d-06 , -2.89000000d-06 /
      data f(18,19),f(18,20) / -1.33000000d-06 , -3.80000000d-07 /
      data f(18,21),f(18,22) / -8.00000000d-08 , -1.00000000d-08 /
      data f(18,23) /           0.00000000d+00 /
      data f(19, 1),f(19, 2) /  0.00000000d+00 , -4.00000000d-08 /
      data f(19, 3),f(19, 4) / -3.50000000d-07 , -2.25000000d-06 /
      data f(19, 5),f(19, 6) / -6.50000000d-06 , -1.21600000d-05 /
      data f(19, 7),f(19, 8) / -1.64400000d-05 , -1.75400000d-05 /
      data f(19, 9),f(19,10) / -1.57800000d-05 , -8.86000000d-06 /
      data f(19,11),f(19,12) / -2.67000000d-06 ,  2.70000000d-07 /
      data f(19,13),f(19,14) /  8.60000000d-07 ,  8.00000000d-08 /
      data f(19,15),f(19,16) / -1.36000000d-06 , -2.72000000d-06 /
      data f(19,17),f(19,18) / -2.97000000d-06 , -2.13000000d-06 /
      data f(19,19),f(19,20) / -9.90000000d-07 , -1.50000000d-07 /
      data f(19,21),f(19,22) / -5.00000000d-08 , -1.00000000d-08 /
      data f(19,23) /           0.00000000d+00 /
      data f(20, 1),f(20, 2) /  0.00000000d+00 , -4.00000000d-08 /
      data f(20, 3),f(20, 4) / -2.50000000d-07 , -1.58000000d-06 /
      data f(20, 5),f(20, 6) / -4.89000000d-06 , -9.05000000d-06 /
      data f(20, 7),f(20, 8) / -1.23000000d-05 , -1.33400000d-05 /
      data f(20, 9),f(20,10) / -1.22000000d-05 , -6.81000000d-06 /
      data f(20,11),f(20,12) / -2.03000000d-06 ,  1.60000000d-07 /
      data f(20,13),f(20,14) /  5.80000000d-07 , -1.10000000d-07 /
      data f(20,15),f(20,16) / -1.10000000d-06 , -2.00000000d-06 /
      data f(20,17),f(20,18) / -2.18000000d-06 , -1.50000000d-06 /
      data f(20,19),f(20,20) / -6.50000000d-07 , -2.00000000d-07 /
      data f(20,21),f(20,22) /  1.00000000d-08 ,  0.00000000d+00 /
      data f(20,23) /           0.00000000d+00 /
      data f(21, 1),f(21, 2) /  0.00000000d+00 , -3.00000000d-08 /
      data f(21, 3),f(21, 4) / -1.40000000d-07 , -8.60000000d-07 /
      data f(21, 5),f(21, 6) / -2.69000000d-06 , -5.24000000d-06 /
      data f(21, 7),f(21, 8) / -7.54000000d-06 , -8.54000000d-06 /
      data f(21, 9),f(21,10) / -8.14000000d-06 , -4.51000000d-06 /
      data f(21,11),f(21,12) / -1.37000000d-06 ,  1.00000000d-08 /
      data f(21,13),f(21,14) /  3.20000000d-07 ,  3.00000000d-08 /
      data f(21,15),f(21,16) / -8.40000000d-07 , -1.42000000d-06 /
      data f(21,17),f(21,18) / -1.43000000d-06 , -9.80000000d-07 /
      data f(21,19),f(21,20) / -4.40000000d-07 , -9.00000000d-08 /
      data f(21,21),f(21,22) / -1.00000000d-08 ,  5.00000000d-08 /
      data f(21,23) /           0.00000000d+00 /
      data f(22, 1),f(22, 2) /  0.00000000d+00 ,  0.00000000d+00 /
      data f(22, 3),f(22, 4) /  3.00000000d-08 , -3.30000000d-07 /
      data f(22, 5),f(22, 6) / -9.90000000d-07 , -2.23000000d-06 /
      data f(22, 7),f(22, 8) / -3.43000000d-06 , -4.07000000d-06 /
      data f(22, 9),f(22,10) / -3.87000000d-06 , -2.30000000d-06 /
      data f(22,11),f(22,12) / -6.60000000d-07 , -4.00000000d-08 /
      data f(22,13),f(22,14) /  7.00000000d-08 , -1.70000000d-07 /
      data f(22,15),f(22,16) / -5.20000000d-07 , -7.90000000d-07 /
      data f(22,17),f(22,18) / -7.70000000d-07 , -5.20000000d-07 /
      data f(22,19),f(22,20) / -2.30000000d-07 , -6.00000000d-08 /
      data f(22,21),f(22,22) / -1.00000000d-08 , -1.00000000d-08 /
      data f(22,23) /           0.00000000d+00 /
      data f(23, 1),f(23, 2) /  0.00000000d+00 ,  0.00000000d+00 /
      data f(23, 3),f(23, 4) /  1.00000000d-08 , -1.50000000d-07 /
      data f(23, 5),f(23, 6) / -4.50000000d-07 , -9.80000000d-07 /
      data f(23, 7),f(23, 8) / -1.45000000d-06 , -1.73000000d-06 /
      data f(23, 9),f(23,10) / -1.72000000d-06 , -1.04000000d-06 /
      data f(23,11),f(23,12) / -3.70000000d-07 , -4.00000000d-08 /
      data f(23,13),f(23,14) /  0.00000000d+00 , -1.30000000d-07 /
      data f(23,15),f(23,16) / -3.10000000d-07 , -4.30000000d-07 /
      data f(23,17),f(23,18) / -4.10000000d-07 , -2.70000000d-07 /
      data f(23,19),f(23,20) / -1.20000000d-07 , -3.00000000d-08 /
      data f(23,21),f(23,22) /  0.00000000d+00 , -1.00000000d-08 /
      data f(23,23) /           0.00000000d+00 /
      data f(24, 1),f(24, 2) /  0.00000000d+00 ,  0.00000000d+00 /
      data f(24, 3),f(24, 4) /  4.00000000d-08 , -7.00000000d-08 /
      data f(24, 5),f(24, 6) / -1.40000000d-07 , -3.60000000d-07 /
      data f(24, 7),f(24, 8) / -5.90000000d-07 , -7.80000000d-07 /
      data f(24, 9),f(24,10) / -8.00000000d-07 , -5.00000000d-07 /
      data f(24,11),f(24,12) / -2.00000000d-07 , -4.00000000d-08 /
      data f(24,13),f(24,14) / -1.00000000d-08 , -7.00000000d-08 /
      data f(24,15),f(24,16) / -1.60000000d-07 , -2.20000000d-07 /
      data f(24,17),f(24,18) / -2.10000000d-07 , -1.40000000d-07 /
      data f(24,19),f(24,20) / -6.00000000d-08 , -2.00000000d-08 /
      data f(24,21),f(24,22) /  0.00000000d+00 , -1.00000000d-08 /
      data f(24,23) /           0.00000000d+00 /
      data f(25, 1),f(25, 2) /  0.00000000d+00 ,  0.00000000d+00 /
      data f(25, 3),f(25, 4) /  2.00000000d-08 , -4.00000000d-08 /
      data f(25, 5),f(25, 6) / -9.00000000d-08 , -2.00000000d-07 /
      data f(25, 7),f(25, 8) / -3.00000000d-07 , -3.10000000d-07 /
      data f(25, 9),f(25,10) / -3.60000000d-07 , -2.40000000d-07 /
      data f(25,11),f(25,12) / -1.20000000d-07 , -3.00000000d-08 /
      data f(25,13),f(25,14) / -3.00000000d-08 ,  0.00000000d+00 /
      data f(25,15),f(25,16) / -8.00000000d-08 , -1.10000000d-07 /
      data f(25,17),f(25,18) / -1.00000000d-07 , -7.00000000d-08 /
      data f(25,19),f(25,20) / -2.00000000d-08 , -1.00000000d-08 /
      data f(25,21),f(25,22) /  0.00000000d+00 ,  1.00000000d-08 /
      data f(25,23) /           0.00000000d+00 /
      data f(26, 1),f(26, 2) /  0.00000000d+00 ,  0.00000000d+00 /
      data f(26, 3),f(26, 4) /  0.00000000d+00 , -1.00000000d-08 /
      data f(26, 5),f(26, 6) / -4.00000000d-08 , -8.00000000d-08 /
      data f(26, 7),f(26, 8) / -1.20000000d-07 , -1.50000000d-07 /
      data f(26, 9),f(26,10) / -1.70000000d-07 , -1.30000000d-07 /
      data f(26,11),f(26,12) / -5.00000000d-08 , -2.00000000d-08 /
      data f(26,13),f(26,14) / -2.00000000d-08 , -7.00000000d-08 /
      data f(26,15),f(26,16) / -6.00000000d-08 , -7.00000000d-08 /
      data f(26,17),f(26,18) / -5.00000000d-08 , -4.00000000d-08 /
      data f(26,19),f(26,20) / -1.00000000d-08 ,  0.00000000d+00 /
      data f(26,21),f(26,22) /  0.00000000d+00 ,  0.00000000d+00 /
      data f(26,23) /           0.00000000d+00 /
      data f(27, 1),f(27, 2) /  0.00000000d+00 ,  0.00000000d+00 /
      data f(27, 3),f(27, 4) /  0.00000000d+00 ,  0.00000000d+00 /
      data f(27, 5),f(27, 6) / -1.00000000d-08 , -1.00000000d-08 /
      data f(27, 7),f(27, 8) / -2.00000000d-08 , -3.00000000d-08 /
      data f(27, 9),f(27,10) / -4.00000000d-08 , -3.00000000d-08 /
      data f(27,11),f(27,12) / -1.00000000d-08 , -1.00000000d-08 /
      data f(27,13),f(27,14) / -1.00000000d-08 , -1.00000000d-08 /
      data f(27,15),f(27,16) /  0.00000000d+00 , -3.00000000d-08 /
      data f(27,17),f(27,18) / -2.00000000d-08 , -2.00000000d-08 /
      data f(27,19),f(27,20) / -1.00000000d-08 , -1.00000000d-08 /
      data f(27,21),f(27,22) /  0.00000000d+00 ,  0.00000000d+00 /
      data f(27,23) /           0.00000000d+00 /
      data f(28, 1),f(28, 2) /  0.00000000d+00 ,  0.00000000d+00 /
      data f(28, 3),f(28, 4) /  0.00000000d+00 ,  1.00000000d-08 /
      data f(28, 5),f(28, 6) /  0.00000000d+00 ,  0.00000000d+00 /
      data f(28, 7),f(28, 8) / -1.00000000d-08 ,  0.00000000d+00 /
      data f(28, 9),f(28,10) / -1.00000000d-08 , -1.00000000d-08 /
      data f(28,11),f(28,12) / -1.00000000d-08 , -1.00000000d-08 /
      data f(28,13),f(28,14) /  2.00000000d-08 ,  4.00000000d-08 /
      data f(28,15),f(28,16) / -2.00000000d-08 ,  0.00000000d+00 /
      data f(28,17),f(28,18) /  1.00000000d-08 ,  1.00000000d-08 /
      data f(28,19),f(28,20) /  0.00000000d+00 ,  0.00000000d+00 /
      data f(28,21),f(28,22) /  6.00000000d-08 , -1.00000000d-08 /
      data f(28,23) /           0.00000000d+00 /
 
      data fpp( 1, 1,1),fpp( 1, 1,2)/ 0.00000000d+00,-1.00003443d-04/
      data fpp( 1, 2,1),fpp( 1, 2,2)/ 3.16125585d-04, 2.13168863d-05/
      data fpp( 1, 3,1),fpp( 1, 3,2)/ 1.62965965d-02, 1.61450298d-04/
      data fpp( 1, 4,1),fpp( 1, 4,2)/ 2.58601734d-01, 2.35737922d-04/
      data fpp( 1, 5,1),fpp( 1, 5,2)/ 5.14116596d-01,-3.99135586d-04/
      data fpp( 1, 6,1),fpp( 1, 6,2)/ 2.30244726d-01,-2.16141977d-04/
      data fpp( 1, 7,1),fpp( 1, 7,2)/ 3.39676987d-02, 8.22746955d-05/
      data fpp( 1, 8,1),fpp( 1, 8,2)/ 3.62152377d-02, 7.38591955d-05/
      data fpp( 1, 9,1),fpp( 1, 9,2)/ 6.92434981d-02, 3.77092263d-06/
      data fpp( 1,10,1),fpp( 1,10,2)/-1.67728470d-02, 1.96776344d-05/
      data fpp( 1,11,1),fpp( 1,11,2)/-2.74372633d-03, 3.72293984d-06/
      data fpp( 1,12,1),fpp( 1,12,2)/ 5.88867474d-03, 6.95660626d-06/
      data fpp( 1,13,1),fpp( 1,13,2)/ 1.04848611d-03,-4.51216487d-06/
      data fpp( 1,14,1),fpp( 1,14,2)/ 1.90979413d-03, 2.73765323d-06/
      data fpp( 1,15,1),fpp( 1,15,2)/ 9.35821800d-03, 1.12135520d-05/
      data fpp( 1,16,1),fpp( 1,16,2)/ 2.46832656d-02,-2.58346108d-06/
      data fpp( 1,17,1),fpp( 1,17,2)/ 3.35710796d-02,-1.91821076d-05/
      data fpp( 1,18,1),fpp( 1,18,2)/ 2.03330388d-02,-1.10250839d-06/
      data fpp( 1,19,1),fpp( 1,19,2)/ 6.76950444d-03, 7.98614120d-06/
      data fpp( 1,20,1),fpp( 1,20,2)/ 1.11497398d-03, 2.46394360d-06/
      data fpp( 1,21,1),fpp( 1,21,2)/ 7.77294824d-05,-1.17155836d-08/
      data fpp( 1,22,1),fpp( 1,22,2)/ 5.17261024d-06, 1.27518738d-07/
      data fpp( 1,23,1),fpp( 1,23,2)/ 0.00000000d+00,-4.80359369d-07/
      data fpp( 2, 1,1),fpp( 2, 1,2)/ 0.00000000d+00,-1.91735055d-04/
      data fpp( 2, 2,1),fpp( 2, 2,2)/ 2.64748830d-04, 3.38789102d-05/
      data fpp( 2, 3,1),fpp( 2, 3,2)/ 1.72038070d-02, 2.77624214d-04/
      data fpp( 2, 4,1),fpp( 2, 4,2)/ 2.53185531d-01, 4.57909833d-04/
      data fpp( 2, 5,1),fpp( 2, 5,2)/ 3.99094808d-01,-9.80737945d-04/
      data fpp( 2, 6,1),fpp( 2, 6,2)/ 2.43219547d-01,-9.75060525d-05/
      data fpp( 2, 7,1),fpp( 2, 7,2)/ 1.72216026d-02, 1.81499755d-04/
      data fpp( 2, 8,1),fpp( 2, 8,2)/ 6.57952464d-03, 7.69510325d-05/
      data fpp( 2, 9,1),fpp( 2, 9,2)/ 2.36030038d-02, 2.56473149d-05/
      data fpp( 2,10,1),fpp( 2,10,2)/-1.09783060d-02, 1.42017391d-05/
      data fpp( 2,11,1),fpp( 2,11,2)/-7.38547350d-04, 7.44372880d-06/
      data fpp( 2,12,1),fpp( 2,12,2)/ 3.51665052d-03, 5.86294570d-06/
      data fpp( 2,13,1),fpp( 2,13,2)/ 4.37027785d-04,-4.73911162d-06/
      data fpp( 2,14,1),fpp( 2,14,2)/ 1.40141174d-03, 1.49190078d-06/
      data fpp( 2,15,1),fpp( 2,15,2)/ 7.27256400d-03, 8.30550849d-06/
      data fpp( 2,16,1),fpp( 2,16,2)/ 1.87874689d-02,-1.37433473d-06/
      data fpp( 2,17,1),fpp( 2,17,2)/ 2.54658408d-02,-1.24477696d-05/
      data fpp( 2,18,1),fpp( 2,18,2)/ 1.59559224d-02,-9.18187063d-07/
      data fpp( 2,19,1),fpp( 2,19,2)/ 5.33399112d-03, 5.24971780d-06/
      data fpp( 2,20,1),fpp( 2,20,2)/ 8.67052032d-04, 1.42571585d-06/
      data fpp( 2,21,1),fpp( 2,21,2)/ 5.85410352d-05,-6.91811894d-08/
      data fpp( 2,22,1),fpp( 2,22,2)/ 2.65477951d-06, 6.78089113d-08/
      data fpp( 2,23,1),fpp( 2,23,2)/ 0.00000000d+00,-2.61454456d-07/
      data fpp( 3, 1,1),fpp( 3, 1,2)/ 0.00000000d+00,-3.51423466d-04/
      data fpp( 3, 2,1),fpp( 3, 2,2)/ 1.18879095d-04, 4.79365311d-05/
      data fpp( 3, 3,1),fpp( 3, 3,2)/ 2.14301756d-02, 4.97194141d-04/
      data fpp( 3, 4,1),fpp( 3, 4,2)/ 2.07266141d-01, 7.71810104d-04/
      data fpp( 3, 5,1),fpp( 3, 5,2)/ 9.94396172d-01,-1.93096416d-03/
      data fpp( 3, 6,1),fpp( 3, 6,2)/ 3.14439085d-01, 1.18452132d-04/
      data fpp( 3, 7,1),fpp( 3, 7,2)/ 7.04318908d-02, 3.57281232d-04/
      data fpp( 3, 8,1),fpp( 3, 8,2)/-1.74709336d-01, 1.00020541d-04/
      data fpp( 3, 9,1),fpp( 3, 9,2)/-1.95239513d-01, 3.74782043d-05/
      data fpp( 3,10,1),fpp( 3,10,2)/ 2.52980711d-02, 1.23747166d-05/
      data fpp( 3,11,1),fpp( 3,11,2)/ 3.00991572d-03, 1.02649292d-05/
      data fpp( 3,12,1),fpp( 3,12,2)/ 5.64723168d-04, 3.76956657d-06/
      data fpp( 3,13,1),fpp( 3,13,2)/-3.72597248d-04,-4.19799549d-06/
      data fpp( 3,14,1),fpp( 3,14,2)/ 8.42558901d-04, 5.76615382d-07/
      data fpp( 3,15,1),fpp( 3,15,2)/ 4.99752601d-03, 6.22293396d-06/
      data fpp( 3,16,1),fpp( 3,16,2)/ 1.16828589d-02,-4.99351227d-07/
      data fpp( 3,17,1),fpp( 3,17,2)/ 1.55375573d-02,-8.06372905d-06/
      data fpp( 3,18,1),fpp( 3,18,2)/ 1.09912716d-02,-5.26532555d-07/
      data fpp( 3,19,1),fpp( 3,19,2)/ 3.76053109d-03, 3.28845928d-06/
      data fpp( 3,20,1),fpp( 3,20,2)/ 5.70817887d-04, 7.36495452d-07/
      data fpp( 3,21,1),fpp( 3,21,2)/ 3.61063769d-05,-1.07241083d-07/
      data fpp( 3,22,1),fpp( 3,22,2)/ 2.20827171d-06, 2.90688809d-08/
      data fpp( 3,23,1),fpp( 3,23,2)/ 0.00000000d+00,-1.14634440d-07/
      data fpp( 4, 1,1),fpp( 4, 1,2)/ 0.00000000d+00,-5.74063517d-04/
      data fpp( 4, 2,1),fpp( 4, 2,2)/ 3.03734788d-04, 7.25262334d-05/
      data fpp( 4, 3,1),fpp( 4, 3,2)/ 1.40394905d-02, 7.83537783d-04/
      data fpp( 4, 4,1),fpp( 4, 4,2)/ 3.03107906d-01, 1.26907303d-03/
      data fpp( 4, 5,1),fpp( 4, 5,2)/-8.96433497d-01,-3.35081712d-03/
      data fpp( 4, 6,1),fpp( 4, 6,2)/ 1.81802113d-01, 4.72612245d-04/
      data fpp( 4, 7,1),fpp( 4, 7,2)/-1.21205166d-01, 5.66855338d-04/
      data fpp( 4, 8,1),fpp( 4, 8,2)/ 1.74787820d-01, 1.73645602d-04/
      data fpp( 4, 9,1),fpp( 4, 9,2)/ 1.92125049d-01, 7.22758528d-05/
      data fpp( 4,10,1),fpp( 4,10,2)/-4.51119785d-02,-1.30451595d-05/
      data fpp( 4,11,1),fpp( 4,11,2)/ 6.56884456d-04, 2.01431853d-05/
      data fpp( 4,12,1),fpp( 4,12,2)/-3.57543196d-04,-2.98781858d-07/
      data fpp( 4,13,1),fpp( 4,13,2)/-4.88638793d-04,-2.85605792d-06/
      data fpp( 4,14,1),fpp( 4,14,2)/ 4.60352655d-04,-1.93586475d-07/
      data fpp( 4,15,1),fpp( 4,15,2)/ 3.38533195d-03, 4.62340382d-06/
      data fpp( 4,16,1),fpp( 4,16,2)/ 8.80909553d-03, 1.24771210d-07/
      data fpp( 4,17,1),fpp( 4,17,2)/ 1.19899302d-02,-4.99948866d-06/
      data fpp( 4,18,1),fpp( 4,18,2)/ 8.08299118d-03,-2.92816585d-07/
      data fpp( 4,19,1),fpp( 4,19,2)/ 2.66988453d-03, 1.94315500d-06/
      data fpp( 4,20,1),fpp( 4,20,2)/ 4.43676419d-04, 2.91996599d-07/
      data fpp( 4,21,1),fpp( 4,21,2)/ 2.50334571d-05,-1.31541392d-07/
      data fpp( 4,22,1),fpp( 4,22,2)/-5.48786636d-06, 4.96896914d-09/
      data fpp( 4,23,1),fpp( 4,23,2)/ 0.00000000d+00,-1.85344846d-08/
      data fpp( 5, 1,1),fpp( 5, 1,2)/ 0.00000000d+00,-8.33464088d-04/
      data fpp( 5, 2,1),fpp( 5, 2,2)/-1.20181825d-03,-8.99622396d-06/
      data fpp( 5, 3,1),fpp( 5, 3,2)/-9.59013745d-03, 1.55818418d-03/
      data fpp( 5, 4,1),fpp( 5, 4,2)/ 2.32750234d-01, 5.25870689d-04/
      data fpp( 5, 5,1),fpp( 5, 5,2)/-1.21542819d+00,-3.11457734d-03/
      data fpp( 5, 6,1),fpp( 5, 6,2)/ 1.28262464d-01,-3.82777336d-04/
      data fpp( 5, 7,1),fpp( 5, 7,2)/ 7.56947730d-02, 1.36442348d-03/
      data fpp( 5, 8,1),fpp( 5, 8,2)/-6.96119452d-02, 2.56954067d-05/
      data fpp( 5, 9,1),fpp( 5, 9,2)/-6.08426822d-02, 1.11006091d-04/
      data fpp( 5,10,1),fpp( 5,10,2)/ 1.04478428d-02,-1.67047759d-05/
      data fpp( 5,11,1),fpp( 5,11,2)/ 8.90546453d-04, 1.98828129d-05/
      data fpp( 5,12,1),fpp( 5,12,2)/-6.22550386d-04,-1.49747556d-06/
      data fpp( 5,13,1),fpp( 5,13,2)/-2.94847579d-04,-2.16591063d-06/
      data fpp( 5,14,1),fpp( 5,14,2)/ 1.24030479d-04,-5.69881927d-07/
      data fpp( 5,15,1),fpp( 5,15,2)/ 2.08314619d-03, 3.33843834d-06/
      data fpp( 5,16,1),fpp( 5,16,2)/ 6.23475899d-03, 5.68528581d-07/
      data fpp( 5,17,1),fpp( 5,17,2)/ 8.42472195d-03,-2.90475266d-06/
      data fpp( 5,18,1),fpp( 5,18,2)/ 5.62476367d-03,-1.74917940d-07/
      data fpp( 5,19,1),fpp( 5,19,2)/ 1.84993078d-03, 1.06222442d-06/
      data fpp( 5,20,1),fpp( 5,20,2)/ 2.94476435d-04, 6.62025845d-09/
      data fpp( 5,21,1),fpp( 5,21,2)/ 1.97597947d-05,-1.40105454d-07/
      data fpp( 5,22,1),fpp( 5,22,2)/ 7.74319374d-06,-9.59844166d-09/
      data fpp( 5,23,1),fpp( 5,23,2)/ 0.00000000d+00, 4.16992208d-08/
      data fpp( 6, 1,1),fpp( 6, 1,2)/ 0.00000000d+00,-1.08665369d-03/
      data fpp( 6, 2,1),fpp( 6, 2,2)/ 3.71153821d-03,-1.93511417d-04/
      data fpp( 6, 3,1),fpp( 6, 3,2)/-2.79929406d-02, 2.71829856d-03/
      data fpp( 6, 4,1),fpp( 6, 4,2)/-7.85488841d-01,-1.43522842d-03/
      data fpp( 6, 5,1),fpp( 6, 5,2)/-1.03583760d-01,-1.11673208d-03/
      data fpp( 6, 6,1),fpp( 6, 6,2)/-8.86149968d-01,-2.27437926d-03/
      data fpp( 6, 7,1),fpp( 6, 7,2)/-1.03891926d-01, 2.38465473d-03/
      data fpp( 6, 8,1),fpp( 6, 8,2)/ 1.46196053d-03,-1.56238850d-04/
      data fpp( 6, 9,1),fpp( 6, 9,2)/-1.91432016d-03, 1.54576674d-04/
      data fpp( 6,10,1),fpp( 6,10,2)/ 4.52607343d-04,-2.26717958d-05/
      data fpp( 6,11,1),fpp( 6,11,2)/ 5.44929732d-04, 1.97457094d-05/
      data fpp( 6,12,1),fpp( 6,12,2)/-6.32255261d-04,-2.46944186d-06/
      data fpp( 6,13,1),fpp( 6,13,2)/-3.35970890d-04,-1.53394196d-06/
      data fpp( 6,14,1),fpp( 6,14,2)/ 9.52542931d-06,-7.90790310d-07/
      data fpp( 6,15,1),fpp( 6,15,2)/ 1.19408328d-03, 2.38770320d-06/
      data fpp( 6,16,1),fpp( 6,16,2)/ 4.11186849d-03, 8.20177525d-07/
      data fpp( 6,17,1),fpp( 6,17,2)/ 5.72518200d-03,-1.51521330d-06/
      data fpp( 6,18,1),fpp( 6,18,2)/ 3.73795416d-03,-1.08924343d-07/
      data fpp( 6,19,1),fpp( 6,19,2)/ 1.25239236d-03, 5.03710666d-07/
      data fpp( 6,20,1),fpp( 6,20,2)/ 1.96417840d-04,-1.67118323d-07/
      data fpp( 6,21,1),fpp( 6,21,2)/ 9.92736402d-06,-1.37637375d-07/
      data fpp( 6,22,1),fpp( 6,22,2)/-1.48490861d-06,-1.85321787d-08/
      data fpp( 6,23,1),fpp( 6,23,2)/ 0.00000000d+00, 7.49660893d-08/
      data fpp( 7, 1,1),fpp( 7, 1,2)/ 0.00000000d+00,-1.23068610d-03/
      data fpp( 7, 2,1),fpp( 7, 2,2)/-5.28670550d-03,-2.92709399d-04/
      data fpp( 7, 3,1),fpp( 7, 3,2)/-3.69846094d-02, 3.37884690d-03/
      data fpp( 7, 4,1),fpp( 7, 4,2)/-2.22040094d-01,-2.51712538d-03/
      data fpp( 7, 5,1),fpp( 7, 5,2)/ 2.96724374d-01,-1.39744559d-04/
      data fpp( 7, 6,1),fpp( 7, 6,2)/-1.13149829d-01,-3.10486118d-03/
      data fpp( 7, 7,1),fpp( 7, 7,2)/-6.85496086d-02, 2.75424128d-03/
      data fpp( 7, 8,1),fpp( 7, 8,2)/-5.70539090d-02,-1.65623956d-04/
      data fpp( 7, 9,1),fpp( 7, 9,2)/ 7.46301560d-04, 1.70103339d-04/
      data fpp( 7,10,1),fpp( 7,10,2)/ 2.38675658d-03,-2.08942395d-05/
      data fpp( 7,11,1),fpp( 7,11,2)/ 1.99937579d-04, 1.58096189d-05/
      data fpp( 7,12,1),fpp( 7,12,2)/-3.92959025d-04,-2.75443592d-06/
      data fpp( 7,13,1),fpp( 7,13,2)/-1.61663541d-04,-7.77875180d-07/
      data fpp( 7,14,1),fpp( 7,14,2)/-2.34591527d-04,-9.04463363d-07/
      data fpp( 7,15,1),fpp( 7,15,2)/ 2.25677055d-04, 1.20972863d-06/
      data fpp( 7,16,1),fpp( 7,16,2)/ 1.49701502d-03, 9.44148841d-07/
      data fpp( 7,17,1),fpp( 7,17,2)/ 2.24009303d-03,-1.11323995d-07/
      data fpp( 7,18,1),fpp( 7,18,2)/ 1.51825570d-03,-1.45285987d-09/
      data fpp( 7,19,1),fpp( 7,19,2)/ 4.80857537d-04,-5.92645652d-08/
      data fpp( 7,20,1),fpp( 7,20,2)/ 6.75082627d-05,-2.97288879d-07/
      data fpp( 7,21,1),fpp( 7,21,2)/ 8.38010581d-07,-1.17779917d-07/
      data fpp( 7,22,1),fpp( 7,22,2)/ 5.83128968d-07,-2.41914523d-08/
      data fpp( 7,23,1),fpp( 7,23,2)/ 0.00000000d+00, 9.39457261d-08/
      data fpp( 8, 1,1),fpp( 8, 1,2)/ 0.00000000d+00,-1.12441289d-03/
      data fpp( 8, 2,1),fpp( 8, 2,2)/ 2.44878378d-03,-1.30945812d-04/
      data fpp( 8, 3,1),fpp( 8, 3,2)/-1.70466219d-02, 2.48443534d-03/
      data fpp( 8, 4,1),fpp( 8, 4,2)/-5.32781782d-01,-5.76882758d-04/
      data fpp( 8, 5,1),fpp( 8, 5,2)/-7.92915234d-01,-2.47990351d-03/
      data fpp( 8, 6,1),fpp( 8, 6,2)/-6.48740217d-01,-1.32844480d-03/
      data fpp( 8, 7,1),fpp( 8, 7,2)/-1.68775140d-01, 1.96300031d-03/
      data fpp( 8, 8,1),fpp( 8, 8,2)/ 1.18636754d-02, 8.75651701d-05/
      data fpp( 8, 9,1),fpp( 8, 9,2)/-1.63048861d-02, 8.44494124d-05/
      data fpp( 8,10,1),fpp( 8,10,2)/ 1.20086634d-03, 3.98697763d-06/
      data fpp( 8,11,1),fpp( 8,11,2)/ 8.33199533d-05, 6.15667703d-06/
      data fpp( 8,12,1),fpp( 8,12,2)/-2.00408640d-04,-8.99685766d-07/
      data fpp( 8,13,1),fpp( 8,13,2)/-5.68749445d-05,-7.84933971d-07/
      data fpp( 8,14,1),fpp( 8,14,2)/-1.30159320d-04,-6.59178348d-07/
      data fpp( 8,15,1),fpp( 8,15,2)/-1.82791505d-04, 5.56047365d-07/
      data fpp( 8,16,1),fpp( 8,16,2)/ 3.07071434d-04, 8.19988887d-07/
      data fpp( 8,17,1),fpp( 8,17,2)/ 7.13445869d-04, 3.60397087d-07/
      data fpp( 8,18,1),fpp( 8,18,2)/ 4.97023049d-04, 4.96227642d-08/
      data fpp( 8,19,1),fpp( 8,19,2)/ 1.36177494d-04,-2.26488144d-07/
      data fpp( 8,20,1),fpp( 8,20,2)/ 9.04910928d-06,-2.90270188d-07/
      data fpp( 8,21,1),fpp( 8,21,2)/ 6.22059366d-06,-9.02311032d-08/
      data fpp( 8,22,1),fpp( 8,22,2)/ 6.52392742d-07,-2.26053991d-08/
      data fpp( 8,23,1),fpp( 8,23,2)/ 0.00000000d+00, 8.28526995d-08/
      data fpp( 9, 1,1),fpp( 9, 1,2)/ 0.00000000d+00,-6.33878860d-04/
      data fpp( 9, 2,1),fpp( 9, 2,2)/-3.38429625d-04, 8.69669202d-05/
      data fpp( 9, 3,1),fpp( 9, 3,2)/ 1.09425968d-02, 8.17056779d-04/
      data fpp( 9, 4,1),fpp( 9, 4,2)/ 3.57861223d-01, 1.51479236d-03/
      data fpp( 9, 5,1),fpp( 9, 5,2)/-5.57438437d-01,-3.91041183d-03/
      data fpp( 9, 6,1),fpp( 9, 6,2)/ 3.09747196d-01, 6.11665362d-04/
      data fpp( 9, 7,1),fpp( 9, 7,2)/ 8.50226675d-02, 7.36492783d-04/
      data fpp( 9, 8,1),fpp( 9, 8,2)/-6.53629253d-03, 1.62536305d-04/
      data fpp( 9, 9,1),fpp( 9, 9,2)/ 8.59224277d-03, 5.53539981d-05/
      data fpp( 9,10,1),fpp( 9,10,2)/ 1.25177806d-03, 5.82725349d-06/
      data fpp( 9,11,1),fpp( 9,11,2)/ 4.42826079d-05, 3.23398797d-06/
      data fpp( 9,12,1),fpp( 9,12,2)/-7.29064148d-05,-5.17205378d-07/
      data fpp( 9,13,1),fpp( 9,13,2)/ 3.66331930d-06,-5.42366458d-07/
      data fpp( 9,14,1),fpp( 9,14,2)/-1.43271193d-04,-4.98128788d-07/
      data fpp( 9,15,1),fpp( 9,15,2)/-2.29511037d-04, 2.60281611d-07/
      data fpp( 9,16,1),fpp( 9,16,2)/-1.13800753d-04, 6.21602345d-07/
      data fpp( 9,17,1),fpp( 9,17,2)/ 5.56234911d-05, 4.47709011d-07/
      data fpp( 9,18,1),fpp( 9,18,2)/ 5.61521039d-05, 6.25616122d-08/
      data fpp( 9,19,1),fpp( 9,19,2)/ 3.43248845d-06,-2.35355460d-07/
      data fpp( 9,20,1),fpp( 9,20,2)/-3.20469982d-06,-2.36539774d-07/
      data fpp( 9,21,1),fpp( 9,21,2)/-6.22038520d-06,-6.88854455d-08/
      data fpp( 9,22,1),fpp( 9,22,2)/-1.92699937d-07,-1.71184441d-08/
      data fpp( 9,23,1),fpp( 9,23,2)/ 0.00000000d+00, 6.77592221d-08/
      data fpp(10, 1,1),fpp(10, 1,2)/ 0.00000000d+00,-2.56588567d-04/
      data fpp(10, 2,1),fpp(10, 2,2)/ 1.19934718d-04, 4.01419342d-05/
      data fpp(10, 3,1),fpp(10, 3,2)/ 9.59573458d-03, 3.76096030d-04/
      data fpp(10, 4,1),fpp(10, 4,2)/ 1.78531888d-01, 5.74767544d-04/
      data fpp(10, 5,1),fpp(10, 5,2)/ 7.92645982d-01,-1.39748781d-03/
      data fpp(10, 6,1),fpp(10, 6,2)/ 1.87585433d-01,-8.61339150d-05/
      data fpp(10, 7,1),fpp(10, 7,2)/ 1.59744699d-02, 3.60749067d-04/
      data fpp(10, 8,1),fpp(10, 8,2)/ 8.63549475d-03, 1.08534446d-04/
      data fpp(10, 9,1),fpp(10, 9,2)/ 1.54691500d-03, 4.04955477d-05/
      data fpp(10,10,1),fpp(10,10,2)/ 9.96521410d-04, 4.27493389d-06/
      data fpp(10,11,1),fpp(10,11,2)/ 6.54961518d-06, 1.83231680d-06/
      data fpp(10,12,1),fpp(10,12,2)/-3.14657006d-05,-3.67401078d-07/
      data fpp(10,13,1),fpp(10,13,2)/ 3.62216673d-05,-3.66912484d-07/
      data fpp(10,14,1),fpp(10,14,2)/-4.22559067d-05,-3.38748984d-07/
      data fpp(10,15,1),fpp(10,15,2)/-2.10164349d-04, 1.07908420d-07/
      data fpp(10,16,1),fpp(10,16,2)/-2.40368422d-04, 4.46515302d-07/
      data fpp(10,17,1),fpp(10,17,2)/-1.48439833d-04, 3.99830370d-07/
      data fpp(10,18,1),fpp(10,18,2)/-9.16314649d-05, 5.95632169d-08/
      data fpp(10,19,1),fpp(10,19,2)/-5.99074474d-05,-1.98283238d-07/
      data fpp(10,20,1),fpp(10,20,2)/-2.47303100d-05,-1.82030266d-07/
      data fpp(10,21,1),fpp(10,21,2)/-2.33905284d-06,-4.61956976d-08/
      data fpp(10,22,1),fpp(10,22,2)/-1.38159299d-06,-1.29869436d-08/
      data fpp(10,23,1),fpp(10,23,2)/ 0.00000000d+00, 4.95434718d-08/
      data fpp(11, 1,1),fpp(11, 1,2)/ 0.00000000d+00,-1.07598116d-04/
      data fpp(11, 2,1),fpp(11, 2,2)/ 1.00190751d-04, 1.47886326d-05/
      data fpp(11, 3,1),fpp(11, 3,2)/ 1.28614649d-02, 1.76274786d-04/
      data fpp(11, 4,1),fpp(11, 4,2)/ 2.22687230d-02, 2.00913023d-04/
      data fpp(11, 5,1),fpp(11, 5,2)/ 1.06344011d-01,-4.41326080d-04/
      data fpp(11, 6,1),fpp(11, 6,2)/ 1.04590573d-01,-2.11121504d-04/
      data fpp(11, 7,1),fpp(11, 7,2)/ 3.69849531d-02, 1.72178494d-04/
      data fpp(11, 8,1),fpp(11, 8,2)/ 8.42631354d-03, 5.99091263d-05/
      data fpp(11, 9,1),fpp(11, 9,2)/ 3.93559724d-03, 2.77690004d-05/
      data fpp(11,10,1),fpp(11,10,2)/ 7.66636297d-04, 2.72743550d-06/
      data fpp(11,11,1),fpp(11,11,2)/ 3.30189314d-05, 1.00345756d-06/
      data fpp(11,12,1),fpp(11,12,2)/-3.73078295d-06,-2.75665729d-07/
      data fpp(11,13,1),fpp(11,13,2)/ 3.29500116d-05,-2.55994642d-07/
      data fpp(11,14,1),fpp(11,14,2)/-2.22051800d-05,-2.23155704d-07/
      data fpp(11,15,1),fpp(11,15,2)/-1.64331567d-04, 4.16174561d-08/
      data fpp(11,16,1),fpp(11,16,2)/-1.92225559d-04, 3.17685879d-07/
      data fpp(11,17,1),fpp(11,17,2)/-1.75864159d-04, 3.15439028d-07/
      data fpp(11,18,1),fpp(11,18,2)/-1.18626244d-04, 4.89580104d-08/
      data fpp(11,19,1),fpp(11,19,2)/-5.63026988d-05,-1.53671069d-07/
      data fpp(11,20,1),fpp(11,20,2)/-1.63740602d-05,-1.35073734d-07/
      data fpp(11,21,1),fpp(11,21,2)/-2.42340343d-06,-3.02339947d-08/
      data fpp(11,22,1),fpp(11,22,2)/ 1.21907192d-06,-9.19028724d-09/
      data fpp(11,23,1),fpp(11,23,2)/ 0.00000000d+00, 3.57951436d-08/
      data fpp(12, 1,1),fpp(12, 1,2)/ 0.00000000d+00,-3.98968502d-06/
      data fpp(12, 2,1),fpp(12, 2,2)/ 1.54302278d-04, 3.30897700d-05/
      data fpp(12, 3,1),fpp(12, 3,2)/-8.16594088d-04,-5.85821952d-05/
      data fpp(12, 4,1),fpp(12, 4,2)/ 8.76862195d-02, 3.00375811d-04/
      data fpp(12, 5,1),fpp(12, 5,2)/ 8.54704758d-02,-2.98387447d-04/
      data fpp(12, 6,1),fpp(12, 6,2)/ 6.27897767d-02,-8.92612221d-05/
      data fpp(12, 7,1),fpp(12, 7,2)/ 2.28582177d-02, 5.39035356d-05/
      data fpp(12, 8,1),fpp(12, 8,2)/ 7.90325110d-03, 3.59518796d-05/
      data fpp(12, 9,1),fpp(12, 9,2)/ 3.00569606d-03, 1.66017461d-05/
      data fpp(12,10,1),fpp(12,10,2)/ 5.37433402d-04, 1.84942180d-06/
      data fpp(12,11,1),fpp(12,11,2)/ 8.37465922d-06, 4.33766664d-07/
      data fpp(12,12,1),fpp(12,12,2)/-1.36111676d-05,-1.91488454d-07/
      data fpp(12,13,1),fpp(12,13,2)/ 2.54782863d-05,-1.89812847d-07/
      data fpp(12,14,1),fpp(12,14,2)/-1.14233734d-05,-1.56860157d-07/
      data fpp(12,15,1),fpp(12,15,2)/-6.10093816d-05, 3.72534740d-08/
      data fpp(12,16,1),fpp(12,16,2)/-1.54729341d-04, 2.10646261d-07/
      data fpp(12,17,1),fpp(12,17,2)/-1.47103533d-04, 2.42161484d-07/
      data fpp(12,18,1),fpp(12,18,2)/-1.04363557d-04, 3.75078037d-08/
      data fpp(12,19,1),fpp(12,19,2)/-5.53817573d-05,-1.16192699d-07/
      data fpp(12,20,1),fpp(12,20,2)/-1.92734491d-05,-9.83370086d-08/
      data fpp(12,21,1),fpp(12,21,2)/ 3.26665768d-08,-1.96592669d-08/
      data fpp(12,22,1),fpp(12,22,2)/-4.94694671d-07,-6.62592374d-09/
      data fpp(12,23,1),fpp(12,23,2)/ 0.00000000d+00, 2.51629619d-08/
      data fpp(13, 1,1),fpp(13, 1,2)/ 0.00000000d+00, 8.81796186d-06/
      data fpp(13, 2,1),fpp(13, 2,2)/-4.64680940d-05, 1.59368763d-05/
      data fpp(13, 3,1),fpp(13, 3,2)/ 3.01400371d-03,-6.17750670d-05/
      data fpp(13, 4,1),fpp(13, 4,2)/ 4.40278628d-03, 1.57420992d-04/
      data fpp(13, 5,1),fpp(13, 5,2)/ 2.33174067d-02,-1.10802499d-04/
      data fpp(13, 6,1),fpp(13, 6,2)/ 2.19693626d-02,-3.15437944d-05/
      data fpp(13, 7,1),fpp(13, 7,2)/ 1.15439723d-02, 5.87207702d-06/
      data fpp(13, 8,1),fpp(13, 8,2)/ 4.75595397d-03, 1.40914864d-05/
      data fpp(13, 9,1),fpp(13, 9,2)/ 1.98428165d-03, 7.07877756d-06/
      data fpp(13,10,1),fpp(13,10,2)/ 2.85797796d-04, 7.39324147d-07/
      data fpp(13,11,1),fpp(13,11,2)/ 1.54051817d-05, 8.77258536d-08/
      data fpp(13,12,1),fpp(13,12,2)/ 1.38577474d-05,-1.24827562d-07/
      data fpp(13,13,1),fpp(13,13,2)/ 4.43903802d-06,-1.40415608d-07/
      data fpp(13,14,1),fpp(13,14,2)/ 2.88136464d-06,-7.43100083d-08/
      data fpp(13,15,1),fpp(13,15,2)/-5.60810163d-05, 6.25564073d-09/
      data fpp(13,16,1),fpp(13,16,2)/-7.57518226d-05, 1.36287445d-07/
      data fpp(13,17,1),fpp(13,17,2)/-8.70787848d-05, 1.49994578d-07/
      data fpp(13,18,1),fpp(13,18,2)/-6.07039793d-05, 2.69342434d-08/
      data fpp(13,19,1),fpp(13,19,2)/-2.51923430d-05,-7.41315514d-08/
      data fpp(13,20,1),fpp(13,20,2)/-3.83912942d-06,-5.80080378d-08/
      data fpp(13,21,1),fpp(13,21,2)/-3.49328630d-06,-1.54362975d-08/
      data fpp(13,22,1),fpp(13,22,2)/ 1.16960096d-06,-3.24677214d-09/
      data fpp(13,23,1),fpp(13,23,2)/ 0.00000000d+00, 1.76233861d-08/
      data fpp(14, 1,1),fpp(14, 1,2)/ 0.00000000d+00,-5.22447128d-06/
      data fpp(14, 2,1),fpp(14, 2,2)/ 4.42367646d-05, 4.06142563d-07/
      data fpp(14, 3,1),fpp(14, 3,2)/ 9.34579261d-04,-8.71298969d-07/
      data fpp(14, 4,1),fpp(14, 4,2)/-7.19203131d-03, 2.20294533d-05/
      data fpp(14, 5,1),fpp(14, 5,2)/ 5.68923053d-03,-1.61537143d-05/
      data fpp(14, 6,1),fpp(14, 6,2)/ 7.77277293d-03,-1.39729962d-05/
      data fpp(14, 7,1),fpp(14, 7,2)/ 4.88655970d-03, 6.55299001d-07/
      data fpp(14, 8,1),fpp(14, 8,2)/ 2.37226636d-03, 4.75180017d-06/
      data fpp(14, 9,1),fpp(14, 9,2)/ 9.66510683d-04, 2.69110030d-06/
      data fpp(14,10,1),fpp(14,10,2)/ 1.22042082d-04, 1.68999001d-07/
      data fpp(14,11,1),fpp(14,11,2)/ 1.26712808d-05,-4.69630738d-09/
      data fpp(14,12,1),fpp(14,12,2)/-8.48648876d-06,-1.08813771d-07/
      data fpp(14,13,1),fpp(14,13,2)/ 9.43222831d-06,-8.02486075d-08/
      data fpp(14,14,1),fpp(14,14,2)/-7.43541849d-06,-5.55917989d-08/
      data fpp(14,15,1),fpp(14,15,2)/-1.73332197d-05, 8.01580297d-09/
      data fpp(14,16,1),fpp(14,16,2)/-4.42633680d-05, 8.11285870d-08/
      data fpp(14,17,1),fpp(14,17,2)/-4.05813279d-05, 9.70698491d-08/
      data fpp(14,18,1),fpp(14,18,2)/-2.41538589d-05, 1.89920168d-08/
      data fpp(14,19,1),fpp(14,19,2)/-9.84887064d-06,-4.52379161d-08/
      data fpp(14,20,1),fpp(14,20,2)/-3.37003319d-06,-3.72403524d-08/
      data fpp(14,21,1),fpp(14,21,2)/ 4.60714529d-06,-9.20067436d-09/
      data fpp(14,22,1),fpp(14,22,2)/-1.51704250d-06,-3.35695018d-09/
      data fpp(14,23,1),fpp(14,23,2)/ 0.00000000d+00, 8.82847509d-09/
      data fpp(15, 1,1),fpp(15, 1,2)/ 0.00000000d+00,-2.10308526d-06/
      data fpp(15, 2,1),fpp(15, 2,2)/-7.98168211d-06, 5.33705298d-08/
      data fpp(15, 3,1),fpp(15, 3,2)/-5.75401867d-04, 5.74403146d-07/
      data fpp(15, 4,1),fpp(15, 4,2)/ 1.71497713d-03, 6.81941689d-06/
      data fpp(15, 5,1),fpp(15, 5,2)/ 3.39923724d-03,-4.94647069d-06/
      data fpp(15, 6,1),fpp(15, 6,2)/ 4.15459146d-03,-6.24073411d-06/
      data fpp(15, 7,1),fpp(15, 7,2)/ 2.82024301d-03, 1.08607137d-07/
      data fpp(15, 8,1),fpp(15, 8,2)/ 1.36723726d-03, 2.29750556d-06/
      data fpp(15, 9,1),fpp(15, 9,2)/ 5.60524113d-04, 1.28777061d-06/
      data fpp(15,10,1),fpp(15,10,2)/ 6.35928985d-05, 2.49353769d-08/
      data fpp(15,11,1),fpp(15,11,2)/-6.96417646d-06,-3.51121216d-08/
      data fpp(15,12,1),fpp(15,12,2)/ 1.06458226d-05,-8.60868905d-08/
      data fpp(15,13,1),fpp(15,13,2)/-2.81969860d-06,-5.85403163d-08/
      data fpp(15,14,1),fpp(15,14,2)/-1.01449545d-05,-4.39518444d-08/
      data fpp(15,15,1),fpp(15,15,2)/-3.22123772d-05, 4.54769397d-09/
      data fpp(15,16,1),fpp(15,16,2)/-3.75554259d-05, 5.99610686d-08/
      data fpp(15,17,1),fpp(15,17,2)/-4.04751833d-05, 7.12080318d-08/
      data fpp(15,18,1),fpp(15,18,2)/-2.96747366d-05, 1.40068042d-08/
      data fpp(15,19,1),fpp(15,19,2)/-1.14671323d-05,-3.24352486d-08/
      data fpp(15,20,1),fpp(15,20,2)/ 1.08860073d-07,-2.46658096d-08/
      data fpp(15,21,1),fpp(15,21,2)/-6.79579700d-06,-1.05015128d-08/
      data fpp(15,22,1),fpp(15,22,2)/-1.66918893d-06,-1.12813920d-09/
      data fpp(15,23,1),fpp(15,23,2)/ 0.00000000d+00, 9.61406960d-09/
      data fpp(16, 1,1),fpp(16, 1,2)/ 0.00000000d+00,-6.67370257d-07/
      data fpp(16, 2,1),fpp(16, 2,2)/ 1.18996382d-06, 1.59405134d-08/
      data fpp(16, 3,1),fpp(16, 3,2)/ 1.70282062d-05, 2.41208203d-07/
      data fpp(16, 4,1),fpp(16, 4,2)/-9.38772212d-05, 2.06962667d-06/
      data fpp(16, 5,1),fpp(16, 5,2)/ 1.36582050d-03,-1.55491490d-06/
      data fpp(16, 6,1),fpp(16, 6,2)/ 1.87836125d-03,-2.44276708d-06/
      data fpp(16, 7,1),fpp(16, 7,2)/ 1.35246827d-03, 1.27583206d-07/
      data fpp(16, 8,1),fpp(16, 8,2)/ 6.77284592d-04, 1.11163425d-06/
      data fpp(16, 9,1),fpp(16, 9,2)/ 2.66892866d-04, 5.78679789d-07/
      data fpp(16,10,1),fpp(16,10,2)/ 2.40863246d-05,-3.16564931d-08/
      data fpp(16,11,1),fpp(16,11,2)/ 1.36854251d-05,-4.04538168d-08/
      data fpp(16,12,1),fpp(16,12,2)/ 4.03198178d-07,-7.59282396d-08/
      data fpp(16,13,1),fpp(16,13,2)/ 9.34656608d-06,-3.68332248d-08/
      data fpp(16,14,1),fpp(16,14,2)/-1.19847634d-05,-3.59388614d-08/
      data fpp(16,15,1),fpp(16,15,2)/-9.81727167d-06, 4.18867021d-09/
      data fpp(16,16,1),fpp(16,16,2)/-2.75149285d-05, 4.19841805d-08/
      data fpp(16,17,1),fpp(16,17,2)/-2.85179388d-05, 5.22746077d-08/
      data fpp(16,18,1),fpp(16,18,2)/-1.61471949d-05, 1.05173886d-08/
      data fpp(16,19,1),fpp(16,19,2)/-5.78260021d-06,-2.23441621d-08/
      data fpp(16,20,1),fpp(16,20,2)/-3.06540710d-06,-1.95407400d-08/
      data fpp(16,21,1),fpp(16,21,2)/ 3.07604270d-06,-6.89287768d-09/
      data fpp(16,22,1),fpp(16,22,2)/ 2.19379824d-06,-2.87749234d-10/
      data fpp(16,23,1),fpp(16,23,2)/ 0.00000000d+00, 8.04387462d-09/
      data fpp(17, 1,1),fpp(17, 1,2)/ 0.00000000d+00,-5.67361047d-08/
      data fpp(17, 2,1),fpp(17, 2,2)/-3.31209131d-06,-1.41277906d-08/
      data fpp(17, 3,1),fpp(17, 3,2)/-2.08261095d-05,-3.79527330d-08/
      data fpp(17, 4,1),fpp(17, 4,2)/ 1.82939315d-04, 1.70738722d-07/
      data fpp(17, 5,1),fpp(17, 5,2)/ 3.58773517d-04,-2.99402157d-07/
      data fpp(17, 6,1),fpp(17, 6,2)/ 4.89734869d-04,-4.01130095d-07/
      data fpp(17, 7,1),fpp(17, 7,2)/ 3.66943750d-04, 2.19122535d-07/
      data fpp(17, 8,1),fpp(17, 8,2)/ 1.73559853d-04, 4.05439954d-07/
      data fpp(17, 9,1),fpp(17, 9,2)/ 5.60077064d-05, 1.63117647d-07/
      data fpp(17,10,1),fpp(17,10,2)/ 3.31698563d-06,-2.90729194d-08/
      data fpp(17,11,1),fpp(17,11,2)/-9.64196588d-06,-5.76259699d-08/
      data fpp(17,12,1),fpp(17,12,2)/ 4.55879098d-06,-4.28232010d-08/
      data fpp(17,13,1),fpp(17,13,2)/ 3.05791213d-06,-3.26812261d-08/
      data fpp(17,14,1),fpp(17,14,2)/ 1.13791810d-05,-6.45189467d-09/
      data fpp(17,15,1),fpp(17,15,2)/-1.78008430d-05,-9.91119526d-09/
      data fpp(17,16,1),fpp(17,16,2)/-1.75799543d-05, 2.86966757d-08/
      data fpp(17,17,1),fpp(17,17,2)/-1.86234150d-05, 3.31244925d-08/
      data fpp(17,18,1),fpp(17,18,2)/-1.67261928d-05, 5.60535434d-09/
      data fpp(17,19,1),fpp(17,19,2)/-9.74657777d-06,-1.47459099d-08/
      data fpp(17,20,1),fpp(17,20,2)/-4.18788303d-06,-1.02217149d-08/
      data fpp(17,21,1),fpp(17,21,2)/-2.72294432d-06,-4.96723061d-09/
      data fpp(17,22,1),fpp(17,22,2)/-5.33201501d-07, 9.06373168d-11/
      data fpp(17,23,1),fpp(17,23,2)/ 0.00000000d+00, 5.20468134d-09/
      data fpp(18, 1,1),fpp(18, 1,2)/ 0.00000000d+00, 4.08605616d-08/
      data fpp(18, 2,1),fpp(18, 2,2)/ 2.72506810d-06,-1.37211232d-08/
      data fpp(18, 3,1),fpp(18, 3,2)/ 6.94289844d-06,-7.23760689d-08/
      data fpp(18, 4,1),fpp(18, 4,2)/-1.92133723d-05,-1.16774601d-07/
      data fpp(18, 5,1),fpp(18, 5,2)/ 6.04187675d-05,-1.01325526d-07/
      data fpp(18, 6,1),fpp(18, 6,2)/ 9.20326091d-05, 3.00767038d-08/
      data fpp(18, 7,1),fpp(18, 7,2)/ 6.10900609d-05, 1.92218710d-07/
      data fpp(18, 8,1),fpp(18, 8,2)/ 1.64759976d-05, 1.80248455d-07/
      data fpp(18, 9,1),fpp(18, 9,2)/-5.59035764d-06, 6.83874689d-08/
      data fpp(18,10,1),fpp(18,10,2)/-1.46876005d-05,-2.10866342d-08/
      data fpp(18,11,1),fpp(18,11,2)/-5.11756153d-06,-4.82409320d-08/
      data fpp(18,12,1),fpp(18,12,2)/ 1.36163791d-06,-2.89496380d-08/
      data fpp(18,13,1),fpp(18,13,2)/ 5.75511872d-06,-1.65605162d-08/
      data fpp(18,14,1),fpp(18,14,2)/-4.86529412d-06,-1.10082972d-08/
      data fpp(18,15,1),fpp(18,15,2)/ 1.68731034d-06, 1.79370502d-09/
      data fpp(18,16,1),fpp(18,16,2)/-1.41652543d-05, 1.40334771d-08/
      data fpp(18,17,1),fpp(18,17,2)/-1.23217344d-05, 2.00723864d-08/
      data fpp(18,18,1),fpp(18,18,2)/-6.94803412d-06, 3.47697714d-09/
      data fpp(18,19,1),fpp(18,19,2)/-1.89775539d-06,-8.18029498d-09/
      data fpp(18,20,1),fpp(18,20,2)/ 7.81693924d-06,-7.35579722d-09/
      data fpp(18,21,1),fpp(18,21,2)/ 2.48240127d-06,-1.39651613d-09/
      data fpp(18,22,1),fpp(18,22,2)/-6.09922327d-08,-8.58138248d-10/
      data fpp(18,23,1),fpp(18,23,2)/ 0.00000000d+00, 1.22906912d-09/
      data fpp(19, 1,1),fpp(19, 1,2)/ 0.00000000d+00, 4.15903631d-08/
      data fpp(19, 2,1),fpp(19, 2,2)/-1.15720353d-06,-9.98072611d-09/
      data fpp(19, 3,1),fpp(19, 3,2)/-1.97532797d-06,-6.64674586d-08/
      data fpp(19, 4,1),fpp(19, 4,2)/ 1.81578890d-05,-1.05749439d-07/
      data fpp(19, 5,1),fpp(19, 5,2)/ 1.02458865d-05,-7.45347837d-08/
      data fpp(19, 6,1),fpp(19, 6,2)/ 1.57346508d-05, 6.54885742d-08/
      data fpp(19, 7,1),fpp(19, 7,2)/-3.65928842d-07, 1.43780487d-07/
      data fpp(19, 8,1),fpp(19, 8,2)/-1.82197671d-05, 1.22589478d-07/
      data fpp(19, 9,1),fpp(19, 9,2)/-2.10597714d-05, 5.22616016d-08/
      data fpp(19,10,1),fpp(19,10,2)/-3.03747606d-06,-1.40795436d-08/
      data fpp(19,11,1),fpp(19,11,2)/ 2.05075645d-06,-3.97434272d-08/
      data fpp(19,12,1),fpp(19,12,2)/ 2.85362397d-06,-2.19467478d-08/
      data fpp(19,13,1),fpp(19,13,2)/ 1.63753821d-06,-1.34695817d-08/
      data fpp(19,14,1),fpp(19,14,2)/-2.24230096d-06,-6.37492533d-09/
      data fpp(19,15,1),fpp(19,15,2)/-3.73528722d-06,-6.30716973d-10/
      data fpp(19,16,1),fpp(19,16,2)/ 3.19620288d-06, 1.36977932d-08/
      data fpp(19,17,1),fpp(19,17,2)/-4.95620531d-06, 1.24395441d-08/
      data fpp(19,18,1),fpp(19,18,2)/-1.17054026d-06, 1.94403037d-09/
      data fpp(19,19,1),fpp(19,19,2)/ 2.10864361d-06,-2.21566560d-09/
      data fpp(19,20,1),fpp(19,20,2)/-1.43028716d-05,-1.10813680d-08/
      data fpp(19,21,1),fpp(19,21,2)/ 1.17241016d-06, 2.14113753d-09/
      data fpp(19,22,1),fpp(19,22,2)/ 1.04763415d-07,-1.08318215d-09/
      data fpp(19,23,1),fpp(19,23,2)/ 0.00000000d+00, 3.91591076d-10/
      data fpp(20, 1,1),fpp(20, 1,2)/ 0.00000000d+00, 3.18546959d-08/
      data fpp(20, 2,1),fpp(20, 2,2)/ 4.03746025d-07,-8.10939178d-09/
      data fpp(20, 3,1),fpp(20, 3,2)/-5.41586570d-07,-4.02171288d-08/
      data fpp(20, 4,1),fpp(20, 4,2)/-8.41818374d-06,-9.98220931d-08/
      data fpp(20, 5,1),fpp(20, 5,2)/-2.40231362d-06,-3.56944988d-08/
      data fpp(20, 6,1),fpp(20, 6,2)/-1.39712125d-05, 3.86000884d-08/
      data fpp(20, 7,1),fpp(20, 7,2)/-2.21263455d-05, 9.96941452d-08/
      data fpp(20, 8,1),fpp(20, 8,2)/-2.00969294d-05, 9.30233309d-08/
      data fpp(20, 9,1),fpp(20, 9,2)/-1.81705570d-05, 5.14125311d-08/
      data fpp(20,10,1),fpp(20,10,2)/-1.21624953d-05,-1.41492588d-08/
      data fpp(20,11,1),fpp(20,11,2)/-6.08546428d-06,-3.14154959d-08/
      data fpp(20,12,1),fpp(20,12,2)/-7.76133794d-07,-1.55887577d-08/
      data fpp(20,13,1),fpp(20,13,2)/ 2.69472843d-06,-1.24294732d-08/
      data fpp(20,14,1),fpp(20,14,2)/ 1.08344980d-05,-1.29334960d-09/
      data fpp(20,15,1),fpp(20,15,2)/-1.74616147d-06,-3.97128421d-10/
      data fpp(20,16,1),fpp(20,16,2)/-1.06195572d-05, 8.28186329d-09/
      data fpp(20,17,1),fpp(20,17,2)/-6.85344433d-06, 1.04696753d-08/
      data fpp(20,18,1),fpp(20,18,2)/-7.86980483d-06, 1.43943564d-09/
      data fpp(20,19,1),fpp(20,19,2)/-6.53681903d-06,-6.02741784d-09/
      data fpp(20,20,1),fpp(20,20,2)/ 7.39454732d-06,-1.32976429d-09/
      data fpp(20,21,1),fpp(20,21,2)/-2.67204189d-06,-3.05352500d-09/
      data fpp(20,22,1),fpp(20,22,2)/ 1.14193857d-06, 3.43864285d-10/
      data fpp(20,23,1),fpp(20,23,2)/ 0.00000000d+00, 2.27806786d-09/
      data fpp(21, 1,1),fpp(21, 1,2)/ 0.00000000d+00, 1.82868548d-08/
      data fpp(21, 2,1),fpp(21, 2,2)/ 9.23156031d-08,-3.77370951d-09/
      data fpp(21, 3,1),fpp(21, 3,2)/ 4.55507212d-07,-2.23920167d-08/
      data fpp(21, 4,1),fpp(21, 4,2)/-3.04464686d-06,-5.30582236d-08/
      data fpp(21, 5,1),fpp(21, 5,2)/-1.31562123d-05,-3.17750888d-08/
      data fpp(21, 6,1),fpp(21, 6,2)/-2.09190589d-05, 7.35857895d-09/
      data fpp(21, 7,1),fpp(21, 7,2)/-2.26682291d-05, 6.23407730d-08/
      data fpp(21, 8,1),fpp(21, 8,2)/-2.08637240d-05, 5.52783289d-08/
      data fpp(21, 9,1),fpp(21, 9,2)/-1.27249626d-05, 5.25459113d-08/
      data fpp(21,10,1),fpp(21,10,2)/-9.10003163d-06,-1.54768982d-08/
      data fpp(21,11,1),fpp(21,11,2)/-1.08229005d-06,-2.00383183d-08/
      data fpp(21,12,1),fpp(21,12,2)/ 1.68469667d-06,-9.96982867d-09/
      data fpp(21,13,1),fpp(21,13,2)/ 5.92546425d-07,-4.28236704d-09/
      data fpp(21,14,1),fpp(21,14,2)/-6.28679260d-06,-8.90070317d-09/
      data fpp(21,15,1),fpp(21,15,2)/-3.55936963d-07, 5.08517973d-09/
      data fpp(21,16,1),fpp(21,16,2)/-6.56111363d-08, 5.95998426d-09/
      data fpp(21,17,1),fpp(21,17,2)/-2.85104871d-06, 5.27488323d-09/
      data fpp(21,18,1),fpp(21,18,2)/-1.32029038d-06, 5.40482805d-10/
      data fpp(21,19,1),fpp(21,19,2)/ 3.83634378d-07,-2.03681445d-09/
      data fpp(21,20,1),fpp(21,20,2)/-2.77990999d-06,-3.79322499d-09/
      data fpp(21,21,1),fpp(21,21,2)/ 7.91866185d-07, 1.00971442d-09/
      data fpp(21,22,1),fpp(21,22,2)/-1.54297085d-06,-1.44563269d-09/
      data fpp(21,23,1),fpp(21,23,2)/ 0.00000000d+00,-1.82718365d-09/
      data fpp(22, 1,1),fpp(22, 1,2)/ 0.00000000d+00, 1.68802032d-08/
      data fpp(22, 2,1),fpp(22, 2,2)/-2.17657545d-07, 3.43959352d-09/
      data fpp(22, 3,1),fpp(22, 3,2)/-1.45267114d-06,-2.34385773d-08/
      data fpp(22, 4,1),fpp(22, 4,2)/-1.28621979d-06,-3.28528426d-09/
      data fpp(22, 5,1),fpp(22, 5,2)/-3.65873252d-06,-3.54202857d-08/
      data fpp(22, 6,1),fpp(22, 6,2)/-4.83628395d-06, 5.76642689d-09/
      data fpp(22, 7,1),fpp(22, 7,2)/-5.94585968d-06, 2.19545781d-08/
      data fpp(22, 8,1),fpp(22, 8,2)/-5.89792561d-06, 4.08152607d-08/
      data fpp(22, 9,1),fpp(22, 9,2)/-8.29778552d-06, 1.63843790d-08/
      data fpp(22,10,1),fpp(22,10,2)/-2.54240159d-06, 6.39232630d-10/
      data fpp(22,11,1),fpp(22,11,2)/-2.24539328d-06,-1.47413095d-08/
      data fpp(22,12,1),fpp(22,12,2)/-1.25349054d-07,-2.87399454d-09/
      data fpp(22,13,1),fpp(22,13,2)/ 8.87014382d-07,-4.36271231d-09/
      data fpp(22,14,1),fpp(22,14,2)/ 3.21703754d-06,-6.75156208d-10/
      data fpp(22,15,1),fpp(22,15,2)/-5.33304838d-07, 4.63337145d-10/
      data fpp(22,16,1),fpp(22,16,2)/-1.49831002d-06, 3.62180763d-09/
      data fpp(22,17,1),fpp(22,17,2)/-9.24577545d-07, 2.44943235d-09/
      data fpp(22,18,1),fpp(22,18,2)/-8.13187889d-07, 3.80462983d-10/
      data fpp(22,19,1),fpp(22,19,2)/-6.65538589d-07,-1.57128428d-09/
      data fpp(22,20,1),fpp(22,20,2)/ 7.78983563d-07,-1.29532586d-09/
      data fpp(22,21,1),fpp(22,21,2)/-1.30746661d-07,-4.47412268d-10/
      data fpp(22,22,1),fpp(22,22,2)/ 8.12343580d-07, 8.49749336d-11/
      data fpp(22,23,1),fpp(22,23,2)/ 0.00000000d+00, 7.07512533d-10/
      data fpp(23, 1,1),fpp(23, 1,2)/ 0.00000000d+00, 7.14820586d-09/
      data fpp(23, 2,1),fpp(23, 2,2)/ 5.83145771d-08, 1.30358828d-09/
      data fpp(23, 3,1),fpp(23, 3,2)/ 7.95177339d-07,-9.96255897d-09/
      data fpp(23, 4,1),fpp(23, 4,2)/-2.10473987d-07,-2.25335241d-09/
      data fpp(23, 5,1),fpp(23, 5,2)/-4.88576234d-08,-1.46240314d-08/
      data fpp(23, 6,1),fpp(23, 6,2)/-1.97580529d-06, 5.54947792d-09/
      data fpp(23, 7,1),fpp(23, 7,2)/-4.66833221d-06, 6.82611970d-09/
      data fpp(23, 8,1),fpp(23, 8,2)/-6.66457356d-06, 1.27460433d-08/
      data fpp(23, 9,1),fpp(23, 9,2)/-4.96389533d-06, 1.17897072d-08/
      data fpp(23,10,1),fpp(23,10,2)/-3.53036201d-06,-2.14214310d-09/
      data fpp(23,11,1),fpp(23,11,2)/-1.61368486d-08,-3.82113473d-09/
      data fpp(23,12,1),fpp(23,12,2)/ 1.66995487d-08,-2.97331796d-09/
      data fpp(23,13,1),fpp(23,13,2)/ 1.79396048d-07,-1.68559343d-09/
      data fpp(23,14,1),fpp(23,14,2)/-8.21357562d-07,-4.84308325d-10/
      data fpp(23,15,1),fpp(23,15,2)/-1.50843687d-07, 6.22826727d-10/
      data fpp(23,16,1),fpp(23,16,2)/-4.21148773d-07, 1.59300142d-09/
      data fpp(23,17,1),fpp(23,17,2)/-6.50641112d-07, 1.40516761d-09/
      data fpp(23,18,1),fpp(23,18,2)/-4.66958064d-07,-1.36718539d-11/
      data fpp(23,19,1),fpp(23,19,2)/-1.21480022d-07,-7.50480194d-10/
      data fpp(23,20,1),fpp(23,20,2)/-3.36024267d-07,-5.84407371d-10/
      data fpp(23,21,1),fpp(23,21,2)/-2.88795401d-08,-5.11890323d-10/
      data fpp(23,22,1),fpp(23,22,2)/-2.66403470d-07, 2.31968664d-10/
      data fpp(23,23,1),fpp(23,23,2)/ 0.00000000d+00, 7.84015668d-10/
      data fpp(24, 1,1),fpp(24, 1,2)/ 0.00000000d+00, 8.35793510d-09/
      data fpp(24, 2,1),fpp(24, 2,2)/-1.56007632d-08, 3.28412980d-09/
      data fpp(24, 3,1),fpp(24, 3,2)/-5.28038218d-07,-1.18944543d-08/
      data fpp(24, 4,1),fpp(24, 4,2)/-2.71884266d-07, 8.29368746d-09/
      data fpp(24, 5,1),fpp(24, 5,2)/-1.66583698d-06,-1.16802955d-08/
      data fpp(24, 6,1),fpp(24, 6,2)/-2.38049489d-06, 2.42749469d-09/
      data fpp(24, 7,1),fpp(24, 7,2)/-2.26081149d-06,-4.29683238d-10/
      data fpp(24, 8,1),fpp(24, 8,2)/-8.03780135d-07, 8.89123826d-09/
      data fpp(24, 9,1),fpp(24, 9,2)/-1.36663317d-06, 5.66473021d-09/
      data fpp(24,10,1),fpp(24,10,2)/-6.16150386d-07,-1.03980977d-09/
      data fpp(24,11,1),fpp(24,11,2)/-5.70059330d-07,-1.50549115d-09/
      data fpp(24,12,1),fpp(24,12,2)/ 5.85508587d-08,-1.33822563d-09/
      data fpp(24,13,1),fpp(24,13,2)/-1.64598574d-07,-9.41606322d-10/
      data fpp(24,14,1),fpp(24,14,2)/ 5.48392706d-07,-2.95349080d-10/
      data fpp(24,15,1),fpp(24,15,2)/-3.03320416d-07, 3.23002644d-10/
      data fpp(24,16,1),fpp(24,16,2)/-4.17094885d-07, 8.03338506d-10/
      data fpp(24,17,1),fpp(24,17,2)/-3.12858005d-07, 6.63643332d-10/
      data fpp(24,18,1),fpp(24,18,2)/-1.98979854d-07, 1.42088167d-10/
      data fpp(24,19,1),fpp(24,19,2)/-4.85413225d-08,-6.31996001d-10/
      data fpp(24,20,1),fpp(24,20,2)/ 8.51135031d-08,-1.41041648d-11/
      data fpp(24,21,1),fpp(24,21,2)/ 6.26482160d-09,-5.11587340d-10/
      data fpp(24,22,1),fpp(24,22,2)/ 2.53270301d-07, 2.60453526d-10/
      data fpp(24,23,1),fpp(24,23,2)/ 0.00000000d+00, 6.69773237d-10/
      data fpp(25, 1,1),fpp(25, 1,2)/ 0.00000000d+00, 4.39999185d-09/
      data fpp(25, 2,1),fpp(25, 2,2)/ 4.08847588d-09, 1.60001630d-09/
      data fpp(25, 3,1),fpp(25, 3,2)/ 1.16975533d-07,-6.00005704d-09/
      data fpp(25, 4,1),fpp(25, 4,2)/ 9.80110489d-08, 3.20021186d-09/
      data fpp(25, 5,1),fpp(25, 5,2)/ 4.72205554d-07,-4.40079041d-09/
      data fpp(25, 6,1),fpp(25, 6,2)/ 4.57784869d-07, 2.94979299d-12/
      data fpp(25, 7,1),fpp(25, 7,2)/ 3.15781848d-08, 6.78899124d-09/
      data fpp(25, 8,1),fpp(25, 8,2)/-1.64030590d-06,-5.55891476d-09/
      data fpp(25, 9,1),fpp(25, 9,2)/-1.08957200d-06, 5.84666780d-09/
      data fpp(25,10,1),fpp(25,10,2)/-7.25036451d-07,-1.56054603d-09/
      data fpp(25,11,1),fpp(25,11,2)/ 1.36374169d-07, 3.95516330d-10/
      data fpp(25,12,1),fpp(25,12,2)/-1.09029837d-08,-1.82151929d-09/
      data fpp(25,13,1),fpp(25,13,2)/ 2.38998247d-07, 1.49056081d-09/
      data fpp(25,14,1),fpp(25,14,2)/-1.13221326d-06,-2.34072397d-09/
      data fpp(25,15,1),fpp(25,15,2)/-3.15874650d-07, 1.27233508d-09/
      data fpp(25,16,1),fpp(25,16,2)/-3.10471685d-07, 2.51383672d-10/
      data fpp(25,17,1),fpp(25,17,2)/-2.57926868d-07, 1.22130238d-10/
      data fpp(25,18,1),fpp(25,18,2)/-1.77122521d-07, 4.60095377d-10/
      data fpp(25,19,1),fpp(25,19,2)/-1.64354688d-07,-7.62511745d-10/
      data fpp(25,20,1),fpp(25,20,2)/-4.42974563d-09, 1.89951602d-10/
      data fpp(25,21,1),fpp(25,21,2)/ 3.82025365d-09, 2.70533802d-12/
      data fpp(25,22,1),fpp(25,22,2)/-2.66677734d-07,-2.00772954d-10/
      data fpp(25,23,1),fpp(25,23,2)/ 0.00000000d+00,-3.99613523d-10/
      data fpp(26, 1,1),fpp(26, 1,2)/ 0.00000000d+00, 4.09025373d-10/
      data fpp(26, 2,1),fpp(26, 2,2)/-7.53140294d-10,-1.80507458d-11/
      data fpp(26, 3,1),fpp(26, 3,2)/ 6.01360860d-08,-3.36822390d-10/
      data fpp(26, 4,1),fpp(26, 4,2)/-1.20159930d-07,-1.03465970d-09/
      data fpp(26, 5,1),fpp(26, 5,2)/-2.22985234d-07,-3.24538830d-10/
      data fpp(26, 6,1),fpp(26, 6,2)/-4.10644581d-07,-6.71849844d-11/
      data fpp(26, 7,1),fpp(26, 7,2)/-5.05501245d-07, 5.93278768d-10/
      data fpp(26, 8,1),fpp(26, 8,2)/-7.49962824d-08, 9.40699135d-11/
      data fpp(26, 9,1),fpp(26, 9,2)/-2.75078843d-07, 1.43044158d-09/
      data fpp(26,10,1),fpp(26,10,2)/-8.37038117d-08, 4.61640309d-10/
      data fpp(26,11,1),fpp(26,11,2)/-2.15437347d-07,-8.77002814d-10/
      data fpp(26,12,1),fpp(26,12,2)/-1.49389241d-08, 4.63709456d-11/
      data fpp(26,13,1),fpp(26,13,2)/-7.13944139d-08,-1.10848097d-09/
      data fpp(26,14,1),fpp(26,14,2)/ 6.20460338d-07, 1.38755293d-09/
      data fpp(26,15,1),fpp(26,15,2)/ 1.26819014d-07,-8.41730747d-10/
      data fpp(26,16,1),fpp(26,16,2)/-2.10183738d-08, 7.79370060d-10/
      data fpp(26,17,1),fpp(26,17,2)/-9.54345244d-08,-4.75749495d-10/
      data fpp(26,18,1),fpp(26,18,2)/-5.25300619d-08, 5.23627918d-10/
      data fpp(26,19,1),fpp(26,19,2)/-1.40399259d-08,-4.18762177d-10/
      data fpp(26,20,1),fpp(26,20,2)/-6.73945205d-08,-4.85792103d-11/
      data fpp(26,21,1),fpp(26,21,2)/-2.15458362d-08, 1.30790182d-11/
      data fpp(26,22,1),fpp(26,22,2)/ 9.34406352d-08,-3.73686233d-12/
      data fpp(26,23,1),fpp(26,23,2)/ 0.00000000d+00, 1.86843117d-12/
      data fpp(27, 1,1),fpp(27, 1,2)/ 0.00000000d+00, 3.57447480d-11/
      data fpp(27, 2,1),fpp(27, 2,2)/ 2.15182941d-10,-7.14894959d-11/
      data fpp(27, 3,1),fpp(27, 3,2)/ 1.10397542d-09, 2.50213236d-10/
      data fpp(27, 4,1),fpp(27, 4,2)/ 1.14742657d-08,-9.29363447d-10/
      data fpp(27, 5,1),fpp(27, 5,2)/ 1.28529239d-08, 1.06724055d-09/
      data fpp(27, 6,1),fpp(27, 6,2)/-1.69586911d-08,-9.39598765d-10/
      data fpp(27, 7,1),fpp(27, 7,2)/-5.92853587d-08, 2.91154506d-10/
      data fpp(27, 8,1),fpp(27, 8,2)/-1.54858205d-07,-2.25019258d-10/
      data fpp(27, 9,1),fpp(27, 9,2)/-1.29977474d-07, 6.08922527d-10/
      data fpp(27,10,1),fpp(27,10,2)/-1.06370340d-07, 8.57420476d-11/
      data fpp(27,11,1),fpp(27,11,2)/-2.18750437d-08,-3.51890718d-10/
      data fpp(27,12,1),fpp(27,12,2)/-9.73173598d-09, 1.21820823d-10/
      data fpp(27,13,1),fpp(27,13,2)/ 3.46841183d-08,-1.35392573d-10/
      data fpp(27,14,1),fpp(27,14,2)/-9.52743821d-08, 4.19749468d-10/
      data fpp(27,15,1),fpp(27,15,2)/-1.02519718d-07,-9.43605299d-10/
      data fpp(27,16,1),fpp(27,16,2)/-2.17090361d-08, 9.54671729d-10/
      data fpp(27,17,1),fpp(27,17,2)/-4.73299303d-09,-4.75081616d-10/
      data fpp(27,18,1),fpp(27,18,2)/ 6.15144626d-09, 3.45654733d-10/
      data fpp(27,19,1),fpp(27,19,2)/ 4.29712169d-09,-3.07537318d-10/
      data fpp(27,20,1),fpp(27,20,2)/ 2.43984344d-08, 2.84494539d-10/
      data fpp(27,21,1),fpp(27,21,2)/ 6.27273818d-08,-2.30440837d-10/
      data fpp(27,22,1),fpp(27,22,2)/-2.69830386d-08, 3.72688107d-11/
      data fpp(27,23,1),fpp(27,23,2)/ 0.00000000d+00, 8.13655947d-11/
      data fpp(28, 1,1),fpp(28, 1,2)/ 0.00000000d+00,-2.98709828d-10/
      data fpp(28, 2,1),fpp(28, 2,2)/-1.07591471d-10,-2.02580344d-10/
      data fpp(28, 3,1),fpp(28, 3,2)/-6.45519877d-08, 1.10903120d-09/
      data fpp(28, 4,1),fpp(28, 4,2)/ 7.42628671d-08,-1.83354447d-09/
      data fpp(28, 5,1),fpp(28, 5,2)/ 5.15735381d-08, 1.42514668d-09/
      data fpp(28, 6,1),fpp(28, 6,2)/ 1.18479346d-07,-1.46704224d-09/
      data fpp(28, 7,1),fpp(28, 7,2)/ 2.02642679d-07, 2.04302227d-09/
      data fpp(28, 8,1),fpp(28, 8,2)/ 1.54429103d-07,-1.90504686d-09/
      data fpp(28, 9,1),fpp(28, 9,2)/ 1.94988737d-07, 7.77165150d-10/
      data fpp(28,10,1),fpp(28,10,2)/ 2.91851698d-08,-1.78972022d-10/
      data fpp(28,11,1),fpp(28,11,2)/ 6.29375219d-08,-6.12770621d-11/
      data fpp(28,12,1),fpp(28,12,2)/-6.13413201d-09, 4.24080270d-10/
      data fpp(28,13,1),fpp(28,13,2)/ 5.26579409d-08, 1.64955981d-10/
      data fpp(28,14,1),fpp(28,14,2)/-2.99362809d-07,-1.68390419d-09/
      data fpp(28,15,1),fpp(28,15,2)/-1.96740141d-07, 1.77066080d-09/
      data fpp(28,16,1),fpp(28,16,2)/ 4.78545180d-08,-5.98738999d-10/
      data fpp(28,17,1),fpp(28,17,2)/ 1.14366497d-07, 2.42951979d-11/
      data fpp(28,18,1),fpp(28,18,2)/ 8.79242769d-08,-9.84417925d-11/
      data fpp(28,19,1),fpp(28,19,2)/ 5.68514392d-08,-2.30528028d-10/
      data fpp(28,20,1),fpp(28,20,2)/ 8.98007828d-08, 1.62055390d-09/
      data fpp(28,21,1),fpp(28,21,2)/ 1.30636309d-07,-2.65168759d-09/
      data fpp(28,22,1),fpp(28,22,2)/-4.55084807d-08, 1.18619645d-09/
      data fpp(28,23,1),fpp(28,23,2)/ 0.00000000d+00, 2.70690177d-09/
 
      data fpppp( 1, 1),fpppp( 1, 2)/-7.40244075d-03,-1.68222773d-04/
      data fpppp( 1, 3),fpppp( 1, 4)/ 1.18347747d-02, 7.14704390d-03/
      data fpppp( 1, 5),fpppp( 1, 6)/-3.72526166d-02, 1.24106071d-02/
      data fpppp( 1, 7),fpppp( 1, 8)/ 8.63295014d-03, 7.03488310d-04/
      data fpppp( 1, 9),fpppp( 1,10)/-4.05953023d-03, 2.70247458d-03/
      data fpppp( 1,11),fpppp( 1,12)/-7.47640146d-04,-3.57171728d-05/
      data fpppp( 1,13),fpppp( 1,14)/ 8.21534553d-05, 4.91931505d-05/
      data fpppp( 1,15),fpppp( 1,16)/ 1.16300894d-04,-4.17993041d-05/
      data fpppp( 1,17),fpppp( 1,18)/-3.35337687d-04, 5.55987625d-05/
      data fpppp( 1,19),fpppp( 1,20)/ 9.34130243d-05, 4.52893743d-05/
      data fpppp( 1,21),fpppp( 1,22)/ 2.46663590d-06, 2.72533987d-06/
      data fpppp( 1,23) /            -9.32493968d-06 /
      data fpppp( 2, 1),fpppp( 2, 2)/-6.58318961d-03,-1.02217222d-03/
      data fpppp( 2, 3),fpppp( 2, 4)/ 1.46737127d-02,-5.10243880d-03/
      data fpppp( 2, 5),fpppp( 2, 6)/-1.58813449d-02,-3.80047040d-03/
      data fpppp( 2, 7),fpppp( 2, 8)/ 1.42537825d-02,-1.52925150d-03/
      data fpppp( 2, 9),fpppp( 2,10)/-1.49704278d-03, 1.13805801d-03/
      data fpppp( 2,11),fpppp( 2,12)/-3.65925143d-04,-3.34310844d-05/
      data fpppp( 2,13),fpppp( 2,14)/ 5.95602439d-05, 3.78305106d-05/
      data fpppp( 2,15),fpppp( 2,16)/ 8.35238115d-05,-3.33005983d-05/
      data fpppp( 2,17),fpppp( 2,18)/-2.40513398d-04, 2.40567724d-05/
      data fpppp( 2,19),fpppp( 2,20)/ 7.75655346d-05, 3.49806209d-05/
      data fpppp( 2,21),fpppp( 2,22)/ 2.01766720d-06, 2.10619482d-06/
      data fpppp( 2,23) /            -7.24855792d-06 /
      data fpppp( 3, 1),fpppp( 3, 2)/-7.03887992d-03, 5.15426987d-03/
      data fpppp( 3, 3),fpppp( 3, 4)/-8.49201937d-03, 6.82997280d-02/
      data fpppp( 3, 5),fpppp( 3, 6)/-1.20396317d-01, 6.11846302d-02/
      data fpppp( 3, 7),fpppp( 3, 8)/-1.97142296d-02, 1.74001205d-02/
      data fpppp( 3, 9),fpppp( 3,10)/ 4.02039964d-03,-5.06538290d-03/
      data fpppp( 3,11),fpppp( 3,12)/ 1.67158758d-03,-4.30389637d-04/
      data fpppp( 3,13),fpppp( 3,14)/ 1.40443300d-04,-2.23496807d-06/
      data fpppp( 3,15),fpppp( 3,16)/ 4.48852304d-05,-2.54840074d-05/
      data fpppp( 3,17),fpppp( 3,18)/-1.12787272d-04,-2.74259442d-05/
      data fpppp( 3,19),fpppp( 3,20)/ 6.14237569d-05, 2.41925555d-05/
      data fpppp( 3,21),fpppp( 3,22)/ 1.10612251d-06, 1.43175878d-06/
      data fpppp( 3,23) /            -4.93176760d-06 /
      data fpppp( 4, 1),fpppp( 4, 2)/-3.03227511d-03,-1.32756584d-02/
      data fpppp( 4, 3),fpppp( 4, 4)/ 5.93585939d-02,-1.58078878d-01/
      data fpppp( 4, 5),fpppp( 4, 6)/ 2.15690564d-01,-1.58016893d-01/
      data fpppp( 4, 7),fpppp( 4, 8)/ 8.48787138d-02,-3.77378988d-02/
      data fpppp( 4, 9),fpppp( 4,10)/-8.04500335d-04, 4.96776137d-03/
      data fpppp( 4,11),fpppp( 4,12)/-2.08619171d-03, 5.70008054d-04/
      data fpppp( 4,13),fpppp( 4,14)/-1.40840580d-04, 5.81594888d-05/
      data fpppp( 4,15),fpppp( 4,16)/ 2.67618957d-05,-1.52800145d-05/
      data fpppp( 4,17),fpppp( 4,18)/-1.00217572d-04,-9.11611821d-06/
      data fpppp( 4,19),fpppp( 4,20)/ 4.63119870d-05, 1.50820821d-05/
      data fpppp( 4,21),fpppp( 4,22)/ 1.81359376d-06, 9.50841221d-07/
      data fpppp( 4,23) /            -3.45640725d-06 /
      data fpppp( 5, 1),fpppp( 5, 2)/-2.88833174d-03,-1.57189319d-02/
      data fpppp( 5, 3),fpppp( 5, 4)/ 6.40392992d-02,-1.80263379d-01/
      data fpppp( 5, 5),fpppp( 5, 6)/ 2.51289708d-01,-1.54846877d-01/
      data fpppp( 5, 7),fpppp( 5, 8)/ 3.29957974d-02, 6.06320672d-04/
      data fpppp( 5, 9),fpppp( 5,10)/ 1.55715543d-03,-1.74950670d-03/
      data fpppp( 5,11),fpppp( 5,12)/ 5.90002104d-04,-1.27849744d-04/
      data fpppp( 5,13),fpppp( 5,14)/ 3.18448509d-05, 5.94085562d-06/
      data fpppp( 5,15),fpppp( 5,16)/ 3.68059859d-05,-2.16149740d-05/
      data fpppp( 5,17),fpppp( 5,18)/-6.80450806d-05,-5.59997808d-06/
      data fpppp( 5,19),fpppp( 5,20)/ 3.19525168d-05, 1.09526237d-05/
      data fpppp( 5,21),fpppp( 5,22)/ 1.08125043d-06, 4.84376918d-07/
      data fpppp( 5,23) /            -2.76235367d-06 /
      data fpppp( 6, 1),fpppp( 6, 2)/ 1.83121828d-02, 1.43557448d-02/
      data fpppp( 6, 3),fpppp( 6, 4)/-8.42350059d-02, 1.48394338d-01/
      data fpppp( 6, 5),fpppp( 6, 6)/-1.63886110d-01, 1.55676993d-01/
      data fpppp( 6, 7),fpppp( 6, 8)/-8.32640424d-02, 1.49221792d-02/
      data fpppp( 6, 9),fpppp( 6,10)/-2.51991455d-03, 6.45823385d-04/
      data fpppp( 6,11),fpppp( 6,12)/-1.99855298d-04, 7.74273635d-05/
      data fpppp( 6,13),fpppp( 6,14)/-2.14459943d-05, 1.13093306d-05/
      data fpppp( 6,15),fpppp( 6,16)/ 2.65523642d-05,-1.35251456d-05/
      data fpppp( 6,17),fpppp( 6,18)/-5.07200842d-05, 3.73001916d-07/
      data fpppp( 6,19),fpppp( 6,20)/ 1.93280391d-05, 8.09007846d-06/
      data fpppp( 6,21),fpppp( 6,22)/ 4.80689592d-07, 4.91855367d-07/
      data fpppp( 6,23) /            -1.67428018d-06 /
      data fpppp( 7, 1),fpppp( 7, 2)/ 8.59637269d-04, 5.26709226d-03/
      data fpppp( 7, 3),fpppp( 7, 4)/-2.82666939d-02, 7.09938640d-02/
      data fpppp( 7, 5),fpppp( 7, 6)/-8.67919735d-02, 5.33007492d-02/
      data fpppp( 7, 7),fpppp( 7, 8)/-1.73371619d-02, 8.10281340d-03/
      data fpppp( 7, 9),fpppp( 7,10)/-3.96100908d-03, 9.94022586d-04/
      data fpppp( 7,11),fpppp( 7,12)/-2.44717701d-04, 8.04835635d-05/
      data fpppp( 7,13),fpppp( 7,14)/-2.77650273d-05, 1.23231374d-05/
      data fpppp( 7,15),fpppp( 7,16)/ 1.04642718d-05,-5.51606178d-06/
      data fpppp( 7,17),fpppp( 7,18)/-2.00956214d-05,-1.99637347d-06/
      data fpppp( 7,19),fpppp( 7,20)/ 9.14746575d-06, 2.84944371d-06/
      data fpppp( 7,21),fpppp( 7,22)/ 2.55500752d-07, 1.13475513d-07/
      data fpppp( 7,23) /            -7.29097645d-07 /
      data fpppp( 8, 1),fpppp( 8, 2)/ 1.57951105d-02, 3.72012146d-03/
      data fpppp( 8, 3),fpppp( 8, 4)/-3.59422018d-02, 2.09511447d-02/
      data fpppp( 8, 5),fpppp( 8, 6)/ 1.34820332d-02, 2.21547553d-02/
      data fpppp( 8, 7),fpppp( 8, 8)/-2.15114400d-02,-7.94729810d-03/
      data fpppp( 8, 9),fpppp( 8,10)/ 3.18686206d-03,-1.15636460d-03/
      data fpppp( 8,11),fpppp( 8,12)/ 3.21198413d-04,-7.83999860d-05/
      data fpppp( 8,13),fpppp( 8,14)/ 1.80372680d-05,-6.75817009d-06/
      data fpppp( 8,15),fpppp( 8,16)/ 1.02345438d-05,-1.63029785d-06/
      data fpppp( 8,17),fpppp( 8,18)/-8.72266265d-06,-8.46886837d-07/
      data fpppp( 8,19),fpppp( 8,20)/ 3.44484581d-06, 1.09053386d-06/
      data fpppp( 8,21),fpppp( 8,22)/-3.48989143d-07, 1.41041593d-07/
      data fpppp( 8,23) /             7.97712605d-08 /
      data fpppp( 9, 1),fpppp( 9, 2)/-6.40095528d-03,-1.17252062d-02/
      data fpppp( 9, 3),fpppp( 9, 4)/ 5.60904497d-02,-1.32083569d-01/
      data fpppp( 9, 5),fpppp( 9, 6)/ 1.69311436d-01,-1.17365704d-01/
      data fpppp( 9, 7),fpppp( 9, 8)/ 3.80929399d-02,-3.04631969d-03/
      data fpppp( 9, 9),fpppp( 9,10)/-3.02662299d-04, 1.75294623d-04/
      data fpppp( 9,11),fpppp( 9,12)/-3.05380382d-05, 1.22759156d-05/
      data fpppp( 9,13),fpppp( 9,14)/-6.94009883d-06, 2.07422489d-06/
      data fpppp( 9,15),fpppp( 9,16)/ 2.28487943d-06, 9.03265005d-07/
      data fpppp( 9,17),fpppp( 9,18)/-2.67510182d-06,-3.36595585d-07/
      data fpppp( 9,19),fpppp( 9,20)/ 8.26590471d-07,-2.04820670d-07/
      data fpppp( 9,21),fpppp( 9,22)/ 2.09982382d-07,-9.25066176d-08/
      data fpppp( 9,23) /            -1.90055031d-07 /
      data fpppp(10, 1),fpppp(10, 2)/-7.17785052d-03, 3.47004575d-03/
      data fpppp(10, 3),fpppp(10, 4)/-4.45692484d-03, 5.26281386d-02/
      data fpppp(10, 5),fpppp(10, 6)/-9.92129240d-02, 5.16216433d-02/
      data fpppp(10, 7),fpppp(10, 8)/-3.24574852d-03, 7.86627918d-04/
      data fpppp(10, 9),fpppp(10,10)/ 1.59331736d-04,-5.37032129d-05/
      data fpppp(10,11),fpppp(10,12)/ 2.91064228d-05,-5.60508957d-06/
      data fpppp(10,13),fpppp(10,14)/-3.43903505d-07,-1.78919292d-06/
      data fpppp(10,15),fpppp(10,16)/ 2.13482306d-06, 1.51216283d-06/
      data fpppp(10,17),fpppp(10,18)/-8.55514685d-07,-1.97317326d-07/
      data fpppp(10,19),fpppp(10,20)/ 1.39722939d-07,-1.54387231d-07/
      data fpppp(10,21),fpppp(10,22)/-2.89326832d-07, 2.56667197d-08/
      data fpppp(10,23) /             2.12107942d-07 /
      data fpppp(11, 1),fpppp(11, 2)/ 8.67381016d-04, 1.06577592d-03/
      data fpppp(11, 3),fpppp(11, 4)/-2.09182469d-03, 6.49655900d-03/
      data fpppp(11, 5),fpppp(11, 6)/-5.97408423d-03,-3.19911625d-03/
      data fpppp(11, 7),fpppp(11, 8)/ 2.96602566d-03, 7.06288772d-04/
      data fpppp(11, 9),fpppp(11,10)/-1.48791657d-05, 4.02414107d-05/
      data fpppp(11,11),fpppp(11,12)/ 3.41370608d-08, 1.43410009d-06/
      data fpppp(11,13),fpppp(11,14)/-1.36470687d-06,-1.48543178d-06/
      data fpppp(11,15),fpppp(11,16)/ 2.08816225d-06,-1.32734931d-08/
      data fpppp(11,17),fpppp(11,18)/ 6.20255271d-07,-1.51567861d-08/
      data fpppp(11,19),fpppp(11,20)/-2.54490230d-07,-3.10576715d-07/
      data fpppp(11,21),fpppp(11,22)/-6.18818177d-08,-6.03869003d-08/
      data fpppp(11,23) /             1.17365828d-08 /
      data fpppp(12, 1),fpppp(12, 2)/-3.09897648d-03,-1.18498357d-03/
      data fpppp(12, 3),fpppp(12, 4)/ 7.56886309d-03,-7.61677838d-03/
      data fpppp(12, 5),fpppp(12, 6)/ 1.12579671d-03,-1.79799777d-03/
      data fpppp(12, 7),fpppp(12, 8)/ 1.92598799d-03, 8.84279784d-05/
      data fpppp(12, 9),fpppp(12,10)/ 1.34078861d-04,-6.83972681d-06/
      data fpppp(12,11),fpppp(12,12)/ 9.63228093d-06,-1.26502197d-06/
      data fpppp(12,13),fpppp(12,14)/-9.07676214d-07, 3.36260009d-07/
      data fpppp(12,15),fpppp(12,16)/-1.19842474d-06, 1.80940185d-06/
      data fpppp(12,17),fpppp(12,18)/ 4.15634299d-08, 1.31194450d-07/
      data fpppp(12,19),fpppp(12,20)/-1.91831763d-07,-1.36276905d-07/
      data fpppp(12,21),fpppp(12,22)/-2.71192168d-07, 3.10369587d-08/
      data fpppp(12,23) /             2.08367688d-07 /
      data fpppp(13, 1),fpppp(13, 2)/ 2.44667579d-04, 2.65787958d-04/
      data fpppp(13, 3),fpppp(13, 4)/-5.62153837d-04, 1.58162198d-03/
      data fpppp(13, 5),fpppp(13, 6)/-1.55813298d-03,-2.12129574d-04/
      data fpppp(13, 7),fpppp(13, 8)/ 2.28088204d-04, 1.72746020d-04/
      data fpppp(13, 9),fpppp(13,10)/ 4.48507652d-05, 9.76634206d-06/
      data fpppp(13,11),fpppp(13,12)/ 1.76934088d-06,-7.12994803d-07/
      data fpppp(13,13),fpppp(13,14)/ 6.10361817d-07,-1.25679030d-06/
      data fpppp(13,15),fpppp(13,16)/ 9.72516945d-07,-2.75782994d-07/
      data fpppp(13,17),fpppp(13,18)/ 6.31245681d-07, 1.29063341d-08/
      data fpppp(13,19),fpppp(13,20)/-1.34661173d-07,-3.23767003d-07/
      data fpppp(13,21),fpppp(13,22)/ 1.69286956d-07,-9.43581720d-08/
      data fpppp(13,23) /            -1.41803561d-07 /
      data fpppp(14, 1),fpppp(14, 2)/ 3.30300825d-04, 2.29975743d-04/
      data fpppp(14, 3),fpppp(14, 4)/-1.04713842d-03, 1.79450920d-03/
      data fpppp(14, 5),fpppp(14, 6)/-1.08900899d-03,-2.99258979d-05/
      data fpppp(14, 7),fpppp(14, 8)/ 1.59712314d-05, 5.53017441d-05/
      data fpppp(14, 9),fpppp(14,10)/ 2.88708335d-05, 3.75919227d-06/
      data fpppp(14,11),fpppp(14,12)/ 1.98265479d-07, 7.40527688d-07/
      data fpppp(14,13),fpppp(14,14)/-8.15787033d-07, 4.35438610d-07/
      data fpppp(14,15),fpppp(14,16)/-5.07776671d-07, 5.73727244d-07/
      data fpppp(14,17),fpppp(14,18)/ 4.95990073d-08,-7.39754223d-09/
      data fpppp(14,19),fpppp(14,20)/-1.47357682d-07, 1.27259220d-07/
      data fpppp(14,21),fpppp(14,22)/-2.71778737d-07, 1.13773753d-07/
      data fpppp(14,23) /             2.75157544d-07 /
      data fpppp(15, 1),fpppp(15, 2)/-1.46054276d-04,-4.84030836d-05/
      data fpppp(15, 3),fpppp(15, 4)/ 2.05401370d-04,-8.73305908d-05/
      data fpppp(15, 5),fpppp(15, 6)/-1.54754012d-06,-1.29416664d-04/
      data fpppp(15, 7),fpppp(15, 8)/ 1.76855593d-05, 3.01966766d-05/
      data fpppp(15, 9),fpppp(15,10)/ 1.66379568d-05, 1.97749659d-06/
      data fpppp(15,11),fpppp(15,12)/ 1.03450525d-06,-8.25493145d-07/
      data fpppp(15,13),fpppp(15,14)/ 4.02936108d-07,-4.17835369d-07/
      data fpppp(15,15),fpppp(15,16)/ 3.83875365d-07,-1.14203655d-07/
      data fpppp(15,17),fpppp(15,18)/ 2.18336729d-07, 6.40689918d-08/
      data fpppp(15,19),fpppp(15,20)/-3.01832459d-08,-3.41232723d-07/
      data fpppp(15,21),fpppp(15,22)/ 2.86275171d-07,-8.19920541d-08/
      data fpppp(15,23) /            -1.65752102d-07 /
      data fpppp(16, 1),fpppp(16, 2)/ 1.06562745d-06, 1.09378944d-05/
      data fpppp(16, 3),fpppp(16, 4)/-4.13016182d-05, 1.23850098d-04/
      data fpppp(16, 5),fpppp(16, 6)/-7.71540174d-05,-4.25516996d-05/
      data fpppp(16, 7),fpppp(16, 8)/-1.86327878d-06, 1.41750447d-05/
      data fpppp(16, 9),fpppp(16,10)/ 8.71316928d-06, 1.45158446d-06/
      data fpppp(16,11),fpppp(16,12)/-5.75168628d-07, 6.76210417d-07/
      data fpppp(16,13),fpppp(16,14)/-7.96137355d-07, 6.91857158d-07/
      data fpppp(16,15),fpppp(16,16)/-5.61362003d-07, 3.61681937d-07/
      data fpppp(16,17),fpppp(16,18)/ 1.16313050d-07,-2.45088831d-08/
      data fpppp(16,19),fpppp(16,20)/-1.38646477d-07, 1.20250699d-07/
      data fpppp(16,21),fpppp(16,22)/-1.36900917d-07, 5.93131193d-09/
      data fpppp(16,23) /             3.44824422d-08 /
      data fpppp(17, 1),fpppp(17, 2)/-9.04513163d-06,-2.45247754d-06/
      data fpppp(17, 3),fpppp(17, 4)/ 1.54465793d-05,-6.22677352d-06/
      data fpppp(17, 5),fpppp(17, 6)/ 2.75702144d-06,-1.55707964d-05/
      data fpppp(17, 7),fpppp(17, 8)/-1.37442866d-06, 4.12624447d-06/
      data fpppp(17, 9),fpppp(17,10)/ 3.06907092d-06,-3.25520669d-07/
      data fpppp(17,11),fpppp(17,12)/ 6.16917913d-07,-5.12568482d-07/
      data fpppp(17,13),fpppp(17,14)/ 4.91257872d-07,-8.63134140d-07/
      data fpppp(17,15),fpppp(17,16)/ 7.11201111d-07,-2.17615537d-07/
      data fpppp(17,17),fpppp(17,18)/ 8.34000728d-08, 6.04562255d-08/
      data fpppp(17,19),fpppp(17,20)/-2.02814111d-08,-6.45857963d-08/
      data fpppp(17,21),fpppp(17,22)/ 3.29992351d-08,-2.39228972d-08/
      data fpppp(17,23) /            -3.67001256d-08 /
      data fpppp(18, 1),fpppp(18, 2)/ 9.12400014d-07, 9.03680509d-07/
      data fpppp(18, 3),fpppp(18, 4)/-4.16885911d-06, 8.48197168d-06/
      data fpppp(18, 5),fpppp(18, 6)/-4.36980907d-06,-2.52712693d-06/
      data fpppp(18, 7),fpppp(18, 8)/-5.35216802d-07, 1.38683053d-06/
      data fpppp(18, 9),fpppp(18,10)/ 3.99344604d-07, 2.10678982d-07/
      data fpppp(18,11),fpppp(18,12)/-1.22023623d-07, 9.19651395d-08/
      data fpppp(18,13),fpppp(18,14)/-3.70980053d-07, 4.91121454d-07/
      data fpppp(18,15),fpppp(18,16)/-5.63124724d-07, 4.17067298d-07/
      data fpppp(18,17),fpppp(18,18)/-4.33793972d-08,-3.17388817d-08/
      data fpppp(18,19),fpppp(18,20)/ 1.50929629d-07,-2.92114680d-07/
      data fpppp(18,21),fpppp(18,22)/ 1.14575137d-07, 1.28280250d-09/
      data fpppp(18,23) /             3.65567973d-08 /
      data fpppp(19, 1),fpppp(19, 2)/-6.44499038d-07,-3.19293419d-07/
      data fpppp(19, 3),fpppp(19, 4)/ 2.00305170d-06,-2.66459143d-06/
      data fpppp(19, 5),fpppp(19, 6)/ 1.92446136d-06,-1.81706998d-06/
      data fpppp(19, 7),fpppp(19, 8)/ 1.62375996d-07, 7.46783945d-07/
      data fpppp(19, 9),fpppp(19,10)/ 4.53808362d-07,-3.12678825d-07/
      data fpppp(19,11),fpppp(19,12)/ 2.08631695d-08,-2.78957523d-08/
      data fpppp(19,13),fpppp(19,14)/-3.04173571d-08,-1.02600245d-08/
      data fpppp(19,15),fpppp(19,16)/ 2.14668630d-07,-3.42945915d-07/
      data fpppp(19,17),fpppp(19,18)/ 2.52081133d-07, 5.09057764d-08/
      data fpppp(19,19),fpppp(19,20)/-4.86093110d-07, 7.12024716d-07/
      data fpppp(19,21),fpppp(19,22)/-4.48797933d-07, 9.05913040d-08/
      data fpppp(19,23) /             1.44205716d-07 /
      data fpppp(20, 1),fpppp(20, 2)/ 9.57758425d-08, 9.31337570d-08/
      data fpppp(20, 3),fpppp(20, 4)/-7.92089740d-07, 1.41172170d-06/
      data fpppp(20, 5),fpppp(20, 6)/-1.52060492d-06, 4.50353423d-07/
      data fpppp(20, 7),fpppp(20, 8)/ 5.38495029d-07,-1.60041748d-07/
      data fpppp(20, 9),fpppp(20,10)/ 7.69414796d-08,-2.14845593d-08/
      data fpppp(20,11),fpppp(20,12)/ 1.31349197d-08,-7.71171519d-08/
      data fpppp(20,13),fpppp(20,14)/ 1.85025593d-07,-3.82850779d-07/
      data fpppp(20,15),fpppp(20,16)/ 1.03151784d-07, 1.92679462d-07/
      data fpppp(20,17),fpppp(20,18)/-1.15499112d-07,-1.76314192d-08/
      data fpppp(20,19),fpppp(20,20)/ 3.26985567d-07,-5.34408017d-07/
      data fpppp(20,21),fpppp(20,22)/ 3.70769166d-07,-1.15834467d-07/
      data fpppp(20,23) /            -2.04786439d-07 /
      data fpppp(21, 1),fpppp(21, 2)/ 1.79457191d-07, 4.32847412d-09/
      data fpppp(21, 3),fpppp(21, 4)/-1.31760846d-07,-4.04488055d-07/
      data fpppp(21, 5),fpppp(21, 6)/ 1.62974344d-07, 3.16283185d-07/
      data fpppp(21, 7),fpppp(21, 8)/ 1.51752784d-08, 4.75897755d-07/
      data fpppp(21, 9),fpppp(21,10)/-3.98544787d-07, 1.98529973d-07/
      data fpppp(21,11),fpppp(21,12)/-1.32006469d-07, 1.44506090d-08/
      data fpppp(21,13),fpppp(21,14)/-1.57344185d-07, 2.67694803d-07/
      data fpppp(21,15),fpppp(21,16)/-1.44823346d-07,-2.68332057d-08/
      data fpppp(21,17),fpppp(21,18)/ 6.76103656d-08, 1.53634971d-08/
      data fpppp(21,19),fpppp(21,20)/-1.18674368d-07, 1.67285829d-07/
      data fpppp(21,21),fpppp(21,22)/-1.46349717d-07, 6.37162460d-08/
      data fpppp(21,23) /             1.24153206d-07 /
      data fpppp(22, 1),fpppp(22, 2)/-1.22774508d-07,-7.00393895d-08/
      data fpppp(22, 3),fpppp(22, 4)/ 1.58766614d-07,-2.28675481d-07/
      data fpppp(22, 5),fpppp(22, 6)/ 1.46583928d-07,-7.08695154d-08/
      data fpppp(22, 7),fpppp(22, 8)/ 1.53208298d-07,-2.64161325d-07/
      data fpppp(22, 9),fpppp(22,10)/ 3.15966449d-07,-1.82512460d-07/
      data fpppp(22,11),fpppp(22,12)/ 8.65808539d-08,-5.44288013d-08/
      data fpppp(22,13),fpppp(22,14)/ 6.46735041d-08,-1.25205632d-07/
      data fpppp(22,15),fpppp(22,16)/ 7.13270900d-08, 7.01750311d-09/
      data fpppp(22,17),fpppp(22,18)/-7.07284272d-09,-6.46670149d-09/
      data fpppp(22,19),fpppp(22,20)/ 3.51152274d-08,-5.61818368d-08/
      data fpppp(22,21),fpppp(22,22)/ 4.83569774d-08,-2.60768447d-08/
      data fpppp(22,23) /            -4.93756279d-08 /
      data fpppp(23, 1),fpppp(23, 2)/ 1.11832539d-07, 5.14456852d-08/
      data fpppp(23, 3),fpppp(23, 4)/-1.54763716d-07, 1.49405798d-07/
      data fpppp(23, 5),fpppp(23, 6)/-1.62715229d-07, 1.99751071d-10/
      data fpppp(23, 7),fpppp(23, 8)/-2.18227953d-08, 2.54199964d-07/
      data fpppp(23, 9),fpppp(23,10)/-1.07716360d-07, 7.79797080d-08/
      data fpppp(23,11),fpppp(23,12)/-7.93609622d-08, 3.05808150d-08/
      data fpppp(23,13),fpppp(23,14)/-3.51706918d-08, 4.02949456d-08/
      data fpppp(23,15),fpppp(23,16)/-2.57330417d-08, 6.18808341d-09/
      data fpppp(23,17),fpppp(23,18)/ 3.42947284d-09, 4.88454847d-09/
      data fpppp(23,19),fpppp(23,20)/-1.32599671d-08, 1.45539827d-08/
      data fpppp(23,21),fpppp(23,22)/-1.36546254d-08, 7.38439938d-09/
      data fpppp(23,23) /             1.43526719d-08 /
      data fpppp(24, 1),fpppp(24, 2)/-6.19542110d-08,-3.69462290d-08/
      data fpppp(24, 3),fpppp(24, 4)/ 9.04983208d-08,-1.40585117d-07/
      data fpppp(24, 5),fpppp(24, 6)/ 7.58165452d-08, 3.49688982d-10/
      data fpppp(24, 7),fpppp(24, 8)/ 1.23026614d-07,-1.71492634d-07/
      data fpppp(24, 9),fpppp(24,10)/ 7.81716674d-08,-3.61973542d-08/
      data fpppp(24,11),fpppp(24,12)/ 2.43542458d-08,-2.62684809d-08/
      data fpppp(24,13),fpppp(24,14)/ 2.96141005d-08,-3.60194783d-08/
      data fpppp(24,15),fpppp(24,16)/ 2.05815487d-08,-2.03039753d-09/
      data fpppp(24,17),fpppp(24,18)/ 6.20722393d-10, 1.25984212d-10/
      data fpppp(24,19),fpppp(24,20)/ 1.06896355d-09,-5.40886074d-09/
      data fpppp(24,21),fpppp(24,22)/ 7.81626901d-09,-6.30496563d-09/
      data fpppp(24,23) /            -1.26129533d-08 /
      data fpppp(25, 1),fpppp(25, 2)/ 1.19601649d-08, 8.38750973d-09/
      data fpppp(25, 3),fpppp(25, 4)/-1.93985443d-08, 3.75622977d-08/
      data fpppp(25, 5),fpppp(25, 6)/-3.64924890d-08, 1.51400128d-08/
      data fpppp(25, 7),fpppp(25, 8)/-1.22896202d-07, 1.77482219d-07/
      data fpppp(25, 9),fpppp(25,10)/-5.36043610d-08, 2.78560382d-08/
      data fpppp(25,11),fpppp(25,12)/-2.80072874d-08, 2.36518449d-08/
      data fpppp(25,13),fpppp(25,14)/-4.27693894d-08, 5.01589484d-08/
      data fpppp(25,15),fpppp(25,16)/-2.66133969d-08, 7.63850053d-09/
      data fpppp(25,17),fpppp(25,18)/-1.11209400d-09,-1.49455280d-09/
      data fpppp(25,19),fpppp(25,20)/ 3.00811440d-09,-1.70847825d-09/
      data fpppp(25,21),fpppp(25,22)/-5.27469798d-09, 6.08239097d-09/
      data fpppp(25,23) /             1.31756774d-08 /
      data fpppp(26, 1),fpppp(26, 2)/ 1.33209938d-08, 4.98130520d-09/
      data fpppp(26, 3),fpppp(26, 4)/-1.84520466d-08, 1.09424229d-08/
      data fpppp(26, 5),fpppp(26, 6)/-6.72467409d-09,-4.40389709d-09/
      data fpppp(26, 7),fpppp(26, 8)/ 4.66129066d-08,-5.59609392d-08/
      data fpppp(26, 9),fpppp(26,10)/ 2.58898449d-08,-1.41966559d-08/
      data fpppp(26,11),fpppp(26,12)/ 1.15102648d-08,-1.19104856d-08/
      data fpppp(26,13),fpppp(26,14)/ 2.07144431d-08,-2.60486721d-08/
      data fpppp(26,15),fpppp(26,16)/ 1.23504809d-08,-2.60501521d-09/
      data fpppp(26,17),fpppp(26,18)/ 2.47485426d-09,-2.55165047d-10/
      data fpppp(26,19),fpppp(26,20)/-1.71905366d-09, 1.62069586d-09/
      data fpppp(26,21),fpppp(26,22)/ 1.18846697d-09,-2.22629652d-09/
      data fpppp(26,23) /            -4.78890727d-09 /
      data fpppp(27, 1),fpppp(27, 2)/-2.91149733d-10,-4.14984533d-11/
      data fpppp(27, 3),fpppp(27, 4)/ 6.18809835d-10,-1.58181407d-10/
      data fpppp(27, 5),fpppp(27, 6)/-2.14407592d-09, 1.24881953d-09/
      data fpppp(27, 7),fpppp(27, 8)/-5.85481480d-09, 9.39135679d-09/
      data fpppp(27, 9),fpppp(27,10)/-2.80175368d-09, 2.14032292d-09/
      data fpppp(27,11),fpppp(27,12)/-2.10624829d-09, 1.94355094d-09/
      data fpppp(27,13),fpppp(27,14)/-3.73160268d-09, 2.52039852d-09/
      data fpppp(27,15),fpppp(27,16)/ 1.01279847d-09,-1.28823128d-09/
      data fpppp(27,17),fpppp(27,18)/ 3.10048278d-10,-3.17458059d-10/
      data fpppp(27,19),fpppp(27,20)/ 1.95458126d-10, 8.52963793d-10/
      data fpppp(27,21),fpppp(27,22)/-2.51365522d-09, 1.51929503d-09/
      data fpppp(27,23) /             3.43808264d-09 /
      data fpppp(28, 1),fpppp(28, 2)/-1.19234385d-08,-5.28122397d-09/
      data fpppp(28, 3),fpppp(28, 4)/ 1.76075013d-08,-1.63665609d-08/
      data fpppp(28, 5),fpppp(28, 6)/ 9.09773822d-09, 1.47844083d-09/
      data fpppp(28, 7),fpppp(28, 8)/-1.08696952d-08, 1.02298815d-08/
      data fpppp(28, 9),fpppp(28,10)/-8.74426008d-09, 6.30246937d-09/
      data fpppp(28,11),fpppp(28,12)/-4.49226226d-09, 5.49713931d-09/
      data fpppp(28,13),fpppp(28,14)/-9.82447137d-09, 9.15197682d-09/
      data fpppp(28,15),fpppp(28,16)/ 4.95169170d-10,-2.61433406d-09/
      data fpppp(28,17),fpppp(28,18)/-7.22793767d-10,-7.17427653d-11/
      data fpppp(28,19),fpppp(28,20)/ 7.31927744d-10, 9.85362671d-10/
      data fpppp(28,21),fpppp(28,22)/-4.20020746d-09, 2.79664822d-09/
      data fpppp(28,23) /             6.31281081d-09 /
 
      c(1,1)=fpppp(ix+1,iy+1)
      c(1,2)=fpppp(ix+1,iy  )
      c(2,1)=fpppp(ix  ,iy+1)
      c(2,2)=fpppp(ix,  iy  )
      c(1,3)=fpp(ix+1,iy+1,1)
      c(1,4)=fpp(ix+1,iy  ,1)
      c(2,3)=fpp(ix,  iy+1,1)
      c(2,4)=fpp(ix,  iy,  1)
      c(3,1)=fpp(ix+1,iy+1,2)
      c(3,2)=fpp(ix+1,iy  ,2)
      c(4,1)=fpp(ix,  iy+1,2)
      c(4,2)=fpp(ix,  iy,  2)
      c(3,3)=f(ix+1,iy+1)
      c(3,4)=f(ix+1,iy  )
      c(4,3)=f(ix,  iy+1)
      c(4,4)=f(ix,  iy  )
      px(1)=((xi-xix)**3/(6.0*delxi))-(xi-xix)*delxi/6.0
      px(2)=(xi-xixp1)*delxi/6.0-((xi-xixp1)**3/(6.0*delxi))
      px(3)=(xi-xix)/delxi
      px(4)=(xixp1-xi)/delxi
      py(1)=((yi-yiy)**3/(6.0*delyi))-(yi-yiy)*delyi/6.0
      py(2)=(yi-yiyp1)*delyi/6.0-((yi-yiyp1)**3/(6.0*delyi))
      py(3)=(yi-yiy)/delyi
      py(4)=(yiyp1-yi)/delyi

      fi=0.0d 00
      do l=1,4
        sum=0.0d 00
        do i=1,4
          sum=sum + c(i,l) * px(i)
        enddo
        fi = fi + sum * py(l)
      enddo
      return
      end  
      subroutine c7_spl(xi,yi,ix,iy,delxi,delyi,xix,xixp1,
     x                    yiy,yiyp1,fi)
      implicit real*8 (a-h,o-z)
      dimension fpp(28,23,2),f(28,23),fpppp(28,23)
      dimension c(4,4),px(4),py(4)
 
      data f( 3, 1),f( 3, 2) /  0.00000000d+00 , -4.35000000d-06 /
      data f( 3, 3),f( 3, 4) / -5.56720000d-04 , -7.91182000d-03 /
      data f( 3, 5),f( 3, 6) / -2.14794300d-02 , -1.54249200d-02 /
      data f( 3, 7),f( 3, 8) / -6.58557000d-03 , -2.25966000d-03 /
      data f( 3, 9),f( 3,10) / -4.24280000d-04 ,  1.00516000d-03 /
      data f( 3,11),f( 3,12) /  1.07369000d-03 ,  3.96080000d-04 /
      data f( 3,13),f( 3,14) /  5.15300000d-05 ,  1.46600000d-05 /
      data f( 3,15),f( 3,16) /  8.49000000d-06 , -3.51400000d-05 /
      data f( 3,17),f( 3,18) / -5.73900000d-05 , -3.56600000d-05 /
      data f( 3,19),f( 3,20) / -1.32900000d-05 , -2.88000000d-06 /
      data f( 3,21),f( 3,22) / -2.40000000d-07 , -1.00000000d-08 /
      data f( 3,23) /           0.00000000d+00 /
      data f( 4, 1),f( 4, 2) /  0.00000000d+00 , -6.68000000d-06 /
      data f( 4, 3),f( 4, 4) / -9.04210000d-04 , -1.32317800d-02 /
      data f( 4, 5),f( 4, 6) / -3.55896500d-02 , -2.35017600d-02 /
      data f( 4, 7),f( 4, 8) / -8.00622000d-03 , -2.61112000d-03 /
      data f( 4, 9),f( 4,10) / -6.06130000d-04 ,  1.27339000d-03 /
      data f( 4,11),f( 4,12) /  8.15360000d-04 ,  2.62260000d-04 /
      data f( 4,13),f( 4,14) /  3.14800000d-05 ,  1.35500000d-05 /
      data f( 4,15),f( 4,16) /  1.09700000d-05 , -2.74200000d-05 /
      data f( 4,17),f( 4,18) / -4.57200000d-05 , -2.83400000d-05 /
      data f( 4,19),f( 4,20) / -1.06600000d-05 , -2.21000000d-06 /
      data f( 4,21),f( 4,22) / -1.10000000d-07 ,  1.00000000d-08 /
      data f( 4,23) /           0.00000000d+00 /
      data f( 5, 1),f( 5, 2) /  0.00000000d+00 , -9.15000000d-06 /
      data f( 5, 3),f( 5, 4) / -1.35934000d-03 , -2.06411000d-02 /
      data f( 5, 5),f( 5, 6) / -4.37789000d-02 , -3.27174400d-02 /
      data f( 5, 7),f( 5, 8) / -9.62904000d-03 , -2.92309000d-03 /
      data f( 5, 9),f( 5,10) / -7.12790000d-04 ,  9.40590000d-04 /
      data f( 5,11),f( 5,12) /  6.12310000d-04 ,  1.72840000d-04 /
      data f( 5,13),f( 5,14) /  1.94900000d-05 ,  1.22900000d-05 /
      data f( 5,15),f( 5,16) /  1.25900000d-05 , -1.69300000d-05 /
      data f( 5,17),f( 5,18) / -3.23000000d-05 , -2.14500000d-05 /
      data f( 5,19),f( 5,20) / -8.27000000d-06 , -1.60000000d-06 /
      data f( 5,21),f( 5,22) / -7.00000000d-08 , -2.00000000d-08 /
      data f( 5,23) /           0.00000000d+00 /
      data f( 6, 1),f( 6, 2) /  0.00000000d+00 , -1.13900000d-05 /
      data f( 6, 3),f( 6, 4) / -1.70213000d-03 , -2.93188100d-02 /
      data f( 6, 5),f( 6, 6) / -4.48229900d-02 , -4.16989200d-02 /
      data f( 6, 7),f( 6, 8) / -1.10453500d-02 , -3.16243000d-03 /
      data f( 6, 9),f( 6,10) / -7.79290000d-04 ,  7.01610000d-04 /
      data f( 6,11),f( 6,12) /  4.54190000d-04 ,  1.14170000d-04 /
      data f( 6,13),f( 6,14) /  1.24300000d-05 ,  1.09000000d-05 /
      data f( 6,15),f( 6,16) /  1.39300000d-05 , -7.68000000d-06 /
      data f( 6,17),f( 6,18) / -2.10300000d-05 , -1.54900000d-05 /
      data f( 6,19),f( 6,20) / -6.05000000d-06 , -1.18000000d-06 /
      data f( 6,21),f( 6,22) / -9.00000000d-08 , -2.00000000d-08 /
      data f( 6,23) /           0.00000000d+00 /
      data f( 7, 1),f( 7, 2) /  0.00000000d+00 , -4.64000000d-05 /
      data f( 7, 3),f( 7, 4) / -1.97030000d-03 , -3.40857400d-02 /
      data f( 7, 5),f( 7, 6) / -4.51451400d-02 , -4.56985100d-02 /
      data f( 7, 7),f( 7, 8) / -1.18756700d-02 , -2.85324000d-03 /
      data f( 7, 9),f( 7,10) / -3.93800000d-04 ,  4.31100000d-04 /
      data f( 7,11),f( 7,12) /  2.42510000d-04 ,  5.03000000d-05 /
      data f( 7,13),f( 7,14) /  5.02000000d-06 ,  8.29000000d-06 /
      data f( 7,15),f( 7,16) /  1.47600000d-05 ,  4.68000000d-06 /
      data f( 7,17),f( 7,18) / -5.81000000d-06 , -6.37000000d-06 /
      data f( 7,19),f( 7,20) / -2.62000000d-06 , -4.70000000d-07 /
      data f( 7,21),f( 7,22) / -1.00000000d-08 , -2.00000000d-08 /
      data f( 7,23) /           0.00000000d+00 /
      data f( 8, 1),f( 8, 2) /  0.00000000d+00 , -1.39800000d-05 /
      data f( 8, 3),f( 8, 4) / -1.66869000d-03 , -2.92586500d-02 /
      data f( 8, 5),f( 8, 6) / -5.05135600d-02 , -4.13301700d-02 /
      data f( 8, 7),f( 8, 8) / -1.06195300d-02 , -2.65336000d-03 /
      data f( 8, 9),f( 8,10) / -4.79010000d-04 ,  2.65330000d-04 /
      data f( 8,11),f( 8,12) /  1.25000000d-04 ,  2.23300000d-05 /
      data f( 8,13),f( 8,14) /  1.80000000d-06 ,  5.99000000d-06 /
      data f( 8,15),f( 8,16) /  1.31100000d-05 ,  9.70000000d-06 /
      data f( 8,17),f( 8,18) /  2.53000000d-06 , -5.30000000d-07 /
      data f( 8,19),f( 8,20) / -4.60000000d-07 , -5.00000000d-08 /
      data f( 8,21),f( 8,22) /  1.20000000d-07 , -2.00000000d-08 /
      data f( 8,23) /           0.00000000d+00 /
      data f( 9, 1),f( 9, 2) /  0.00000000d+00 , -7.28000000d-06 /
      data f( 9, 3),f( 9, 4) / -1.00635000d-03 , -1.49328700d-02 /
      data f( 9, 5),f( 9, 6) / -3.95852400d-02 , -2.48015500d-02 /
      data f( 9, 7),f( 9, 8) / -7.83849000d-03 , -2.10995000d-03 /
      data f( 9, 9),f( 9,10) / -3.89060000d-04 ,  1.57530000d-04 /
      data f( 9,11),f( 9,12) /  6.28300000d-05 ,  9.98000000d-06 /
      data f( 9,13),f( 9,14) /  4.40000000d-07 ,  4.20000000d-06 /
      data f( 9,15),f( 9,16) /  1.07300000d-05 ,  1.06500000d-05 /
      data f( 9,17),f( 9,18) /  6.31000000d-06 ,  2.58000000d-06 /
      data f( 9,19),f( 9,20) /  8.10000000d-07 ,  2.90000000d-07 /
      data f( 9,21),f( 9,22) /  1.00000000d-07 , -3.00000000d-08 /
      data f( 9,23) /           0.00000000d+00 /
      data f(10, 1),f(10, 2) /  0.00000000d+00 , -4.53000000d-06 /
      data f(10, 3),f(10, 4) / -5.02180000d-04 , -6.53495000d-03 /
      data f(10, 5),f(10, 6) / -1.67989300d-02 , -1.32965700d-02 /
      data f(10, 7),f(10, 8) / -5.09243000d-03 , -1.45613000d-03 /
      data f(10, 9),f(10,10) / -2.68920000d-04 ,  8.92300000d-05 /
      data f(10,11),f(10,12) /  3.12800000d-05 ,  4.51000000d-06 /
      data f(10,13),f(10,14) / -1.90000000d-07 ,  2.83000000d-06 /
      data f(10,15),f(10,16) /  8.09000000d-06 ,  9.54000000d-06 /
      data f(10,17),f(10,18) /  7.04000000d-06 ,  3.60000000d-06 /
      data f(10,19),f(10,20) /  1.43000000d-06 ,  3.90000000d-07 /
      data f(10,21),f(10,22) /  1.00000000d-07 ,  9.00000000d-08 /
      data f(10,23) /           0.00000000d+00 /
      data f(11, 1),f(11, 2) /  0.00000000d+00 , -2.04000000d-06 /
      data f(11, 3),f(11, 4) / -2.37180000d-04 , -3.06511000d-03 /
      data f(11, 5),f(11, 6) / -8.51038000d-03 , -7.05743000d-03 /
      data f(11, 7),f(11, 8) / -2.95036000d-03 , -8.97440000d-04 /
      data f(11, 9),f(11,10) / -1.66750000d-04 ,  4.85800000d-05 /
      data f(11,11),f(11,12) /  1.56500000d-05 ,  2.13000000d-06 /
      data f(11,13),f(11,14) / -3.40000000d-07 ,  1.95000000d-06 /
      data f(11,15),f(11,16) /  5.83000000d-06 ,  7.92000000d-06 /
      data f(11,17),f(11,18) /  6.45000000d-06 ,  3.71000000d-06 /
      data f(11,19),f(11,20) /  1.50000000d-06 ,  3.90000000d-07 /
      data f(11,21),f(11,22) /  9.00000000d-08 , -5.00000000d-08 /
      data f(11,23) /           0.00000000d+00 /
      data f(12, 1),f(12, 2) /  0.00000000d+00 , -5.60000000d-07 /
      data f(12, 3),f(12, 4) / -1.99860000d-04 , -1.07101000d-03 /
      data f(12, 5),f(12, 6) / -4.45656000d-03 , -3.40678000d-03 /
      data f(12, 7),f(12, 8) / -1.58057000d-03 , -5.09420000d-04 /
      data f(12, 9),f(12,10) / -9.49600000d-05 ,  2.62600000d-05 /
      data f(12,11),f(12,12) /  8.33000000d-06 ,  1.09000000d-06 /
      data f(12,13),f(12,14) / -4.30000000d-07 ,  1.25000000d-06 /
      data f(12,15),f(12,16) /  4.38000000d-06 ,  6.03000000d-06 /
      data f(12,17),f(12,18) /  5.34000000d-06 ,  3.16000000d-06 /
      data f(12,19),f(12,20) /  1.25000000d-06 ,  3.30000000d-07 /
      data f(12,21),f(12,22) /  8.00000000d-08 ,  1.00000000d-08 /
      data f(12,23) /           0.00000000d+00 /
      data f(13, 1),f(13, 2) /  0.00000000d+00 , -2.30000000d-07 /
      data f(13, 3),f(13, 4) / -1.14000000d-05 , -8.44300000d-05 /
      data f(13, 5),f(13, 6) / -1.11130000d-03 , -1.04348000d-03 /
      data f(13, 7),f(13, 8) / -5.58980000d-04 , -1.92630000d-04 /
      data f(13, 9),f(13,10) / -3.42100000d-05 ,  1.20700000d-05 /
      data f(13,11),f(13,12) /  4.11000000d-06 ,  4.30000000d-07 /
      data f(13,13),f(13,14) / -4.10000000d-07 ,  7.10000000d-07 /
      data f(13,15),f(13,16) /  2.46000000d-06 ,  3.66000000d-06 /
      data f(13,17),f(13,18) /  3.48000000d-06 ,  2.19000000d-06 /
      data f(13,19),f(13,20) /  8.70000000d-07 ,  1.60000000d-07 /
      data f(13,21),f(13,22) /  4.00000000d-08 ,  2.00000000d-08 /
      data f(13,23) /           0.00000000d+00 /
      data f(14, 1),f(14, 2) /  0.00000000d+00 ,  1.00000000d-07 /
      data f(14, 3),f(14, 4) /  4.26000000d-06 , -7.40900000d-05 /
      data f(14, 5),f(14, 6) / -2.75410000d-04 , -2.99060000d-04 /
      data f(14, 7),f(14, 8) / -1.76830000d-04 , -6.10800000d-05 /
      data f(14, 9),f(14,10) / -6.51000000d-06 ,  7.64000000d-06 /
      data f(14,11),f(14,12) /  2.80000000d-06 ,  2.70000000d-07 /
      data f(14,13),f(14,14) / -3.20000000d-07 ,  2.60000000d-07 /
      data f(14,15),f(14,16) /  1.43000000d-06 ,  2.18000000d-06 /
      data f(14,17),f(14,18) /  2.09000000d-06 ,  1.28000000d-06 /
      data f(14,19),f(14,20) /  4.30000000d-07 ,  1.10000000d-07 /
      data f(14,21),f(14,22) / -2.00000000d-08 ,  3.00000000d-08 /
      data f(14,23) /           0.00000000d+00 /
      data f(15, 1),f(15, 2) /  0.00000000d+00 , -3.00000000d-08 /
      data f(15, 3),f(15, 4) / -3.30000000d-07 , -3.26400000d-05 /
      data f(15, 5),f(15, 6) / -1.06150000d-04 , -1.22940000d-04 /
      data f(15, 7),f(15, 8) / -7.45100000d-05 , -2.28600000d-05 /
      data f(15, 9),f(15,10) /  2.10000000d-06 ,  6.31000000d-06 /
      data f(15,11),f(15,12) /  2.32000000d-06 ,  2.40000000d-07 /
      data f(15,13),f(15,14) / -1.60000000d-07 ,  3.10000000d-07 /
      data f(15,15),f(15,16) /  8.60000000d-07 ,  1.54000000d-06 /
      data f(15,17),f(15,18) /  1.43000000d-06 ,  8.50000000d-07 /
      data f(15,19),f(15,20) /  3.20000000d-07 ,  7.00000000d-08 /
      data f(15,21),f(15,22) /  5.00000000d-08 , -4.00000000d-08 /
      data f(15,23) /           0.00000000d+00 /
      data f(16, 1),f(16, 2) /  0.00000000d+00 ,  5.00000000d-08 /
      data f(16, 3),f(16, 4) / -5.70000000d-07 , -1.19800000d-05 /
      data f(16, 5),f(16, 6) / -3.82800000d-05 , -4.60800000d-05 /
      data f(16, 7),f(16, 8) / -2.66500000d-05 , -4.40000000d-06 /
      data f(16, 9),f(16,10) /  6.03000000d-06 ,  5.31000000d-06 /
      data f(16,11),f(16,12) /  1.89000000d-06 ,  2.90000000d-07 /
      data f(16,13),f(16,14) / -1.40000000d-07 ,  2.20000000d-07 /
      data f(16,15),f(16,16) /  6.30000000d-07 ,  1.05000000d-06 /
      data f(16,17),f(16,18) /  1.07000000d-06 ,  6.60000000d-07 /
      data f(16,19),f(16,20) /  2.40000000d-07 ,  3.00000000d-08 /
      data f(16,21),f(16,22) / -1.00000000d-08 , -3.00000000d-08 /
      data f(16,23) /           0.00000000d+00 /
      data f(17, 1),f(17, 2) /  0.00000000d+00 , -1.00000000d-08 /
      data f(17, 3),f(17, 4) /  1.00000000d-08 , -1.74000000d-06 /
      data f(17, 5),f(17, 6) / -6.16000000d-06 , -6.70000000d-06 /
      data f(17, 7),f(17, 8) / -8.40000000d-07 ,  5.17000000d-06 /
      data f(17, 9),f(17,10) /  7.11000000d-06 ,  4.07000000d-06 /
      data f(17,11),f(17,12) /  1.53000000d-06 ,  1.30000000d-07 /
      data f(17,13),f(17,14) / -1.30000000d-07 ,  4.00000000d-08 /
      data f(17,15),f(17,16) /  3.40000000d-07 ,  6.70000000d-07 /
      data f(17,17),f(17,18) /  6.60000000d-07 ,  3.90000000d-07 /
      data f(17,19),f(17,20) /  1.20000000d-07 , -3.00000000d-08 /
      data f(17,21),f(17,22) / -1.00000000d-08 ,  2.00000000d-08 /
      data f(17,23) /           0.00000000d+00 /
      data f(18, 1),f(18, 2) /  0.00000000d+00 ,  0.00000000d+00 /
      data f(18, 3),f(18, 4) /  7.00000000d-08 ,  1.60000000d-07 /
      data f(18, 5),f(18, 6) /  2.60000000d-07 ,  1.79000000d-06 /
      data f(18, 7),f(18, 8) /  4.40000000d-06 ,  6.01000000d-06 /
      data f(18, 9),f(18,10) /  5.69000000d-06 ,  3.01000000d-06 /
      data f(18,11),f(18,12) /  1.09000000d-06 ,  1.00000000d-07 /
      data f(18,13),f(18,14) / -8.00000000d-08 ,  6.00000000d-08 /
      data f(18,15),f(18,16) /  2.70000000d-07 ,  4.30000000d-07 /
      data f(18,17),f(18,18) /  3.80000000d-07 ,  1.80000000d-07 /
      data f(18,19),f(18,20) /  3.00000000d-08 ,  9.00000000d-08 /
      data f(18,21),f(18,22) /  3.00000000d-08 , -2.00000000d-08 /
      data f(18,23) /           0.00000000d+00 /
      data f(19, 1),f(19, 2) /  0.00000000d+00 , -4.00000000d-08 /
      data f(19, 3),f(19, 4) /  7.00000000d-08 ,  4.80000000d-07 /
      data f(19, 5),f(19, 6) /  1.15000000d-06 ,  2.56000000d-06 /
      data f(19, 7),f(19, 8) /  4.28000000d-06 ,  5.00000000d-06 /
      data f(19, 9),f(19,10) /  4.55000000d-06 ,  2.54000000d-06 /
      data f(19,11),f(19,12) /  8.10000000d-07 ,  5.00000000d-08 /
      data f(19,13),f(19,14) / -8.00000000d-08 ,  4.00000000d-08 /
      data f(19,15),f(19,16) /  1.70000000d-07 ,  4.00000000d-07 /
      data f(19,17),f(19,18) /  2.50000000d-07 ,  1.00000000d-07 /
      data f(19,19),f(19,20) /  1.00000000d-08 , -4.00000000d-08 /
      data f(19,21),f(19,22) /  3.00000000d-08 , -2.00000000d-08 /
      data f(19,23) /           0.00000000d+00 /
      data f(20, 1),f(20, 2) /  0.00000000d+00 , -6.00000000d-08 /
      data f(20, 3),f(20, 4) /  1.00000000d-08 ,  2.60000000d-07 /
      data f(20, 5),f(20, 6) /  1.22000000d-06 ,  2.37000000d-06 /
      data f(20, 7),f(20, 8) /  3.60000000d-06 ,  3.75000000d-06 /
      data f(20, 9),f(20,10) /  3.35000000d-06 ,  2.00000000d-06 /
      data f(20,11),f(20,12) /  5.90000000d-07 ,  8.00000000d-08 /
      data f(20,13),f(20,14) / -6.00000000d-08 ,  5.00000000d-08 /
      data f(20,15),f(20,16) /  1.10000000d-07 ,  1.80000000d-07 /
      data f(20,17),f(20,18) /  2.50000000d-07 ,  1.30000000d-07 /
      data f(20,19),f(20,20) /  5.00000000d-08 ,  4.00000000d-08 /
      data f(20,21),f(20,22) / -3.00000000d-08 , -1.00000000d-08 /
      data f(20,23) /           0.00000000d+00 /
      data f(21, 1),f(21, 2) /  0.00000000d+00 , -8.00000000d-08 /
      data f(21, 3),f(21, 4) /  1.00000000d-08 ,  1.60000000d-07 /
      data f(21, 5),f(21, 6) /  6.70000000d-07 ,  1.46000000d-06 /
      data f(21, 7),f(21, 8) /  2.23000000d-06 ,  2.53000000d-06 /
      data f(21, 9),f(21,10) /  2.35000000d-06 ,  1.32000000d-06 /
      data f(21,11),f(21,12) /  4.80000000d-07 ,  7.00000000d-08 /
      data f(21,13),f(21,14) / -5.00000000d-08 , -7.00000000d-08 /
      data f(21,15),f(21,16) /  8.00000000d-08 ,  1.00000000d-07 /
      data f(21,17),f(21,18) /  1.80000000d-07 ,  1.40000000d-07 /
      data f(21,19),f(21,20) /  1.10000000d-07 , -1.00000000d-08 /
      data f(21,21),f(21,22) /  0.00000000d+00 ,  9.00000000d-08 /
      data f(21,23) /           0.00000000d+00 /
      data f(22, 1),f(22, 2) /  0.00000000d+00 , -2.00000000d-08 /
      data f(22, 3),f(22, 4) / -5.00000000d-08 ,  4.70000000d-07 /
      data f(22, 5),f(22, 6) /  1.00000000d-08 ,  6.10000000d-07 /
      data f(22, 7),f(22, 8) /  1.05000000d-06 ,  1.19000000d-06 /
      data f(22, 9),f(22,10) /  1.15000000d-06 ,  6.30000000d-07 /
      data f(22,11),f(22,12) /  2.30000000d-07 ,  4.00000000d-08 /
      data f(22,13),f(22,14) / -1.00000000d-08 , -1.00000000d-08 /
      data f(22,15),f(22,16) /  3.00000000d-08 ,  5.00000000d-08 /
      data f(22,17),f(22,18) /  6.00000000d-08 ,  4.00000000d-08 /
      data f(22,19),f(22,20) /  2.00000000d-08 ,  1.00000000d-08 /
      data f(22,21),f(22,22) /  0.00000000d+00 ,  0.00000000d+00 /
      data f(22,23) /           0.00000000d+00 /
      data f(23, 1),f(23, 2) /  0.00000000d+00 , -2.00000000d-08 /
      data f(23, 3),f(23, 4) /  1.70000000d-07 , -1.00000000d-08 /
      data f(23, 5),f(23, 6) /  6.00000000d-08 ,  2.60000000d-07 /
      data f(23, 7),f(23, 8) /  3.90000000d-07 ,  4.90000000d-07 /
      data f(23, 9),f(23,10) /  4.80000000d-07 ,  3.40000000d-07 /
      data f(23,11),f(23,12) /  1.10000000d-07 ,  2.00000000d-08 /
      data f(23,13),f(23,14) / -1.00000000d-08 ,  0.00000000d+00 /
      data f(23,15),f(23,16) /  1.00000000d-08 ,  2.00000000d-08 /
      data f(23,17),f(23,18) /  3.00000000d-08 ,  2.00000000d-08 /
      data f(23,19),f(23,20) /  0.00000000d+00 ,  0.00000000d+00 /
      data f(23,21),f(23,22) /  0.00000000d+00 ,  0.00000000d+00 /
      data f(23,23) /           0.00000000d+00 /
      data f(24, 1),f(24, 2) /  0.00000000d+00 , -1.00000000d-08 /
      data f(24, 3),f(24, 4) / -3.00000000d-08 ,  4.00000000d-08 /
      data f(24, 5),f(24, 6) /  3.00000000d-08 ,  8.00000000d-08 /
      data f(24, 7),f(24, 8) /  1.40000000d-07 ,  1.90000000d-07 /
      data f(24, 9),f(24,10) /  2.40000000d-07 ,  1.40000000d-07 /
      data f(24,11),f(24,12) /  6.00000000d-08 ,  1.00000000d-08 /
      data f(24,13),f(24,14) /  0.00000000d+00 ,  0.00000000d+00 /
      data f(24,15),f(24,16) /  1.00000000d-08 ,  2.00000000d-08 /
      data f(24,17),f(24,18) /  1.00000000d-08 ,  0.00000000d+00 /
      data f(24,19),f(24,20) /  0.00000000d+00 ,  0.00000000d+00 /
      data f(24,21),f(24,22) /  1.00000000d-08 ,  0.00000000d+00 /
      data f(24,23) /           0.00000000d+00 /
      data f(25, 1),f(25, 2) /  0.00000000d+00 ,  0.00000000d+00 /
      data f(25, 3),f(25, 4) /  0.00000000d+00 ,  3.00000000d-08 /
      data f(25, 5),f(25, 6) /  1.00000000d-08 ,  6.00000000d-08 /
      data f(25, 7),f(25, 8) /  9.00000000d-08 ,  7.00000000d-08 /
      data f(25, 9),f(25,10) /  9.00000000d-08 ,  7.00000000d-08 /
      data f(25,11),f(25,12) /  3.00000000d-08 ,  1.00000000d-08 /
      data f(25,13),f(25,14) /  1.00000000d-08 , -6.00000000d-08 /
      data f(25,15),f(25,16) /  0.00000000d+00 ,  0.00000000d+00 /
      data f(25,17),f(25,18) /  0.00000000d+00 ,  1.00000000d-08 /
      data f(25,19),f(25,20) /  0.00000000d+00 , -1.00000000d-08 /
      data f(25,21),f(25,22) /  0.00000000d+00 ,  1.00000000d-08 /
      data f(25,23) /           0.00000000d+00 /
      data f(26, 1),f(26, 2) /  0.00000000d+00 , -1.00000000d-08 /
      data f(26, 3),f(26, 4) /  0.00000000d+00 ,  0.00000000d+00 /
      data f(26, 5),f(26, 6) /  1.00000000d-08 ,  1.00000000d-08 /
      data f(26, 7),f(26, 8) /  2.00000000d-08 ,  3.00000000d-08 /
      data f(26, 9),f(26,10) /  4.00000000d-08 ,  3.00000000d-08 /
      data f(26,11),f(26,12) /  1.00000000d-08 ,  1.00000000d-08 /
      data f(26,13),f(26,14) / -1.00000000d-08 ,  9.00000000d-08 /
      data f(26,15),f(26,16) /  0.00000000d+00 ,  1.00000000d-08 /
      data f(26,17),f(26,18) / -1.00000000d-08 , -1.00000000d-08 /
      data f(26,19),f(26,20) / -2.00000000d-08 , -1.00000000d-08 /
      data f(26,21),f(26,22) /  0.00000000d+00 , -1.00000000d-08 /
      data f(26,23) /           0.00000000d+00 /
      data f(27, 1),f(27, 2) /  0.00000000d+00 ,  0.00000000d+00 /
      data f(27, 3),f(27, 4) /  0.00000000d+00 ,  0.00000000d+00 /
      data f(27, 5),f(27, 6) /  0.00000000d+00 ,  0.00000000d+00 /
      data f(27, 7),f(27, 8) /  1.00000000d-08 ,  1.00000000d-08 /
      data f(27, 9),f(27,10) /  1.00000000d-08 ,  1.00000000d-08 /
      data f(27,11),f(27,12) /  0.00000000d+00 ,  0.00000000d+00 /
      data f(27,13),f(27,14) /  0.00000000d+00 , -1.00000000d-07 /
      data f(27,15),f(27,16) / -4.00000000d-08 ,  0.00000000d+00 /
      data f(27,17),f(27,18) / -1.00000000d-08 , -1.00000000d-08 /
      data f(27,19),f(27,20) /  1.00000000d-08 , -1.00000000d-08 /
      data f(27,21),f(27,22) /  0.00000000d+00 , -2.00000000d-08 /
      data f(27,23) /           0.00000000d+00 /
      data f(28, 1),f(28, 2) /  0.00000000d+00 ,  1.00000000d-08 /
      data f(28, 3),f(28, 4) /  0.00000000d+00 ,  0.00000000d+00 /
      data f(28, 5),f(28, 6) /  0.00000000d+00 ,  0.00000000d+00 /
      data f(28, 7),f(28, 8) /  0.00000000d+00 ,  0.00000000d+00 /
      data f(28, 9),f(28,10) /  0.00000000d+00 ,  1.00000000d-08 /
      data f(28,11),f(28,12) /  0.00000000d+00 ,  0.00000000d+00 /
      data f(28,13),f(28,14) /  3.00000000d-08 ,  3.00000000d-08 /
      data f(28,15),f(28,16) /  1.00000000d-08 ,  0.00000000d+00 /
      data f(28,17),f(28,18) /  1.00000000d-08 ,  1.00000000d-08 /
      data f(28,19),f(28,20) /  0.00000000d+00 ,  2.00000000d-08 /
      data f(28,21),f(28,22) / -6.00000000d-08 ,  2.00000000d-08 /
      data f(28,23) /           0.00000000d+00 /
 
      data fpp( 1, 1,1),fpp( 1, 1,2)/ 0.00000000d+00, 5.32671105d-05/
      data fpp( 1, 2,1),fpp( 1, 2,2)/-8.06202256d-05,-2.31014209d-05/
      data fpp( 1, 3,1),fpp( 1, 3,2)/-7.26725950d-03,-1.36374267d-05/
      data fpp( 1, 4,1),fpp( 1, 4,2)/ 1.39103121d-01,-3.04587272d-04/
      data fpp( 1, 5,1),fpp( 1, 5,2)/-4.37903972d-01, 4.09338515d-04/
      data fpp( 1, 6,1),fpp( 1, 6,2)/-9.96722451d-02, 1.12366812d-04/
      data fpp( 1, 7,1),fpp( 1, 7,2)/-1.56606516d-01,-1.43706561d-04/
      data fpp( 1, 8,1),fpp( 1, 8,2)/ 8.85691520d-02,-1.50421664d-05/
      data fpp( 1, 9,1),fpp( 1, 9,2)/ 4.01017619d-03,-5.42637306d-06/
      data fpp( 1,10,1),fpp( 1,10,2)/-4.18907308d-02,-2.14799761d-06/
      data fpp( 1,11,1),fpp( 1,11,2)/-1.04426957d-02,-2.89974365d-05/
      data fpp( 1,12,1),fpp( 1,12,2)/ 4.42859130d-03, 1.28095436d-05/
      data fpp( 1,13,1),fpp( 1,13,2)/ 5.50220738d-03, 4.39566191d-06/
      data fpp( 1,14,1),fpp( 1,14,2)/ 1.31096506d-04, 9.29008691d-07/
      data fpp( 1,15,1),fpp( 1,15,2)/-6.76346027d-05,-4.45496680d-07/
      data fpp( 1,16,1),fpp( 1,16,2)/-2.16011322d-04, 1.29780284d-08/
      data fpp( 1,17,1),fpp( 1,17,2)/-6.04742434d-04, 7.04984566d-07/
      data fpp( 1,18,1),fpp( 1,18,2)/ 1.52044285d-03,-2.23516294d-07/
      data fpp( 1,19,1),fpp( 1,19,2)/ 6.68075092d-05, 4.56806091d-08/
      data fpp( 1,20,1),fpp( 1,20,2)/-5.74521442d-06,-1.36206143d-07/
      data fpp( 1,21,1),fpp( 1,21,2)/-2.10920517d-05,-2.88560385d-08/
      data fpp( 1,22,1),fpp( 1,22,2)/ 1.01784646d-05,-6.96970328d-09/
      data fpp( 1,23,1),fpp( 1,23,2)/ 0.00000000d+00, 3.93348516d-08/
      data fpp( 2, 1,1),fpp( 2, 1,2)/ 0.00000000d+00, 1.37029238d-04/
      data fpp( 2, 2,1),fpp( 2, 2,2)/-8.47595489d-05,-1.13092759d-05/
      data fpp( 2, 3,1),fpp( 2, 3,2)/-1.02874810d-02,-1.71925734d-04/
      data fpp( 2, 4,1),fpp( 2, 4,2)/-1.74752419d-02,-2.89569387d-04/
      data fpp( 2, 5,1),fpp( 2, 5,2)/-3.23277055d-01, 6.19467282d-04/
      data fpp( 2, 6,1),fpp( 2, 6,2)/-1.55337510d-01, 1.07146659d-04/
      data fpp( 2, 7,1),fpp( 2, 7,2)/-6.72819685d-02,-2.11087519d-04/
      data fpp( 2, 8,1),fpp( 2, 8,2)/ 5.13546961d-02, 2.88261528d-06/
      data fpp( 2, 9,1),fpp( 2, 9,2)/ 3.14064761d-03,-3.50789425d-05/
      data fpp( 2,10,1),fpp( 2,10,2)/-2.02805385d-02,-2.54308012d-06/
      data fpp( 2,11,1),fpp( 2,11,2)/ 5.43913290d-05,-2.04601370d-05/
      data fpp( 2,12,1),fpp( 2,12,2)/ 4.85181740d-03, 1.03058281d-05/
      data fpp( 2,13,1),fpp( 2,13,2)/ 3.68058525d-03, 3.77802444d-06/
      data fpp( 2,14,1),fpp( 2,14,2)/ 6.68069887d-05, 1.16274090d-07/
      data fpp( 2,15,1),fpp( 2,15,2)/-7.47307947d-05,-5.11720801d-07/
      data fpp( 2,16,1),fpp( 2,16,2)/ 2.23022644d-04, 2.26009113d-07/
      data fpp( 2,17,1),fpp( 2,17,2)/ 8.84848679d-05, 5.44284349d-07/
      data fpp( 2,18,1),fpp( 2,18,2)/ 9.37114306d-04, 5.85349045d-09/
      data fpp( 2,19,1),fpp( 2,19,2)/ 3.23849816d-05,-1.56098311d-07/
      data fpp( 2,20,1),fpp( 2,20,2)/-1.15095712d-05,-8.22602465d-08/
      data fpp( 2,21,1),fpp( 2,21,2)/-8.81589652d-06,-2.90607029d-08/
      data fpp( 2,22,1),fpp( 2,22,2)/ 4.64307073d-06,-3.09694204d-09/
      data fpp( 2,23,1),fpp( 2,23,2)/ 0.00000000d+00, 3.06484710d-08/
      data fpp( 3, 1,1),fpp( 3, 1,2)/ 0.00000000d+00, 2.33437972d-04/
      data fpp( 3, 2,1),fpp( 3, 2,2)/-3.41578851d-07,-3.22615445d-05/
      data fpp( 3, 3,1),fpp( 3, 3,2)/-1.25068165d-02,-2.35916594d-04/
      data fpp( 3, 4,1),fpp( 3, 4,2)/-2.84956153d-01,-6.56727279d-04/
      data fpp( 3, 5,1),fpp( 3, 5,2)/-8.70017807d-01, 1.37182331d-03/
      data fpp( 3, 6,1),fpp( 3, 6,2)/-3.56409716d-01,-1.21257155d-04/
      data fpp( 3, 7,1),fpp( 3, 7,2)/ 1.45720390d-01,-2.18433087d-04/
      data fpp( 3, 8,1),fpp( 3, 8,2)/-6.79793626d-03,-8.82360948d-05/
      data fpp( 3, 9,1),fpp( 3, 9,2)/-6.57076665d-03,-2.63497334d-05/
      data fpp( 3,10,1),fpp( 3,10,2)/ 1.01136885d-01,-1.13119523d-05/
      data fpp( 3,11,1),fpp( 3,11,2)/ 2.39951303d-02,-1.00570572d-05/
      data fpp( 3,12,1),fpp( 3,12,2)/ 6.17013910d-03, 6.77178112d-06/
      data fpp( 3,13,1),fpp( 3,13,2)/ 1.39345163d-03, 2.95353270d-06/
      data fpp( 3,14,1),fpp( 3,14,2)/-3.23244604d-05,-1.25111937d-07/
      data fpp( 3,15,1),fpp( 3,15,2)/-6.54422187d-05,-6.11084955d-07/
      data fpp( 3,16,1),fpp( 3,16,2)/ 1.30992075d-03, 3.21851759d-07/
      data fpp( 3,17,1),fpp( 3,17,2)/ 1.86480296d-03, 6.06477920d-07/
      data fpp( 3,18,1),fpp( 3,18,2)/ 2.75099929d-04,-1.08963440d-07/
      data fpp( 3,19,1),fpp( 3,19,2)/-4.34743558d-06,-1.32224161d-07/
      data fpp( 3,20,1),fpp( 3,20,2)/-3.82165009d-05,-7.97399156d-08/
      data fpp( 3,21,1),fpp( 3,21,2)/ 2.63556378d-05,-1.50161766d-08/
      data fpp( 3,22,1),fpp( 3,22,2)/ 1.24925245d-06,-4.79537812d-09/
      data fpp( 3,23,1),fpp( 3,23,2)/ 0.00000000d+00, 2.09976891d-08/
      data fpp( 4, 1,1),fpp( 4, 1,2)/ 0.00000000d+00, 3.94644048d-04/
      data fpp( 4, 2,1),fpp( 4, 2,2)/-2.25874136d-04,-5.30548954d-05/
      data fpp( 4, 3,1),fpp( 4, 3,2)/-1.75292529d-02,-3.96228466d-04/
      data fpp( 4, 4,1),fpp( 4, 4,2)/-1.64278145d-01,-1.10524084d-03/
      data fpp( 4, 5,1),fpp( 4, 5,2)/ 8.98028282d-01, 2.40991983d-03/
      data fpp( 4, 6,1),fpp( 4, 6,2)/-4.85576262d-02,-2.67456066d-04/
      data fpp( 4, 7,1),fpp( 4, 7,2)/-7.41495907d-02,-5.22259563d-04/
      data fpp( 4, 8,1),fpp( 4, 8,2)/ 8.33304895d-03,-6.76112823d-05/
      data fpp( 4, 9,1),fpp( 4, 9,2)/ 1.46644190d-02,-2.09217077d-05/
      data fpp( 4,10,1),fpp( 4,10,2)/-1.26771000d-01,-3.12568356d-05/
      data fpp( 4,11,1),fpp( 4,11,2)/ 8.83087276d-04, 5.69605024d-06/
      data fpp( 4,12,1),fpp( 4,12,2)/ 4.35562621d-03, 2.76843468d-06/
      data fpp( 4,13,1),fpp( 4,13,2)/ 7.35608234d-04, 2.56941104d-06/
      data fpp( 4,14,1),fpp( 4,14,2)/-9.50914727d-06,-2.75078848d-07/
      data fpp( 4,15,1),fpp( 4,15,2)/-1.13500331d-04,-5.48095648d-07/
      data fpp( 4,16,1),fpp( 4,16,2)/ 1.29294374d-04, 3.18861442d-07/
      data fpp( 4,17,1),fpp( 4,17,2)/-1.49696717d-04, 4.78049879d-07/
      data fpp( 4,18,1),fpp( 4,18,2)/-1.11514021d-04,-9.02609595d-08/
      data fpp( 4,19,1),fpp( 4,19,2)/-3.29952393d-05,-9.90060412d-08/
      data fpp( 4,20,1),fpp( 4,20,2)/ 8.37557488d-06,-6.75148755d-08/
      data fpp( 4,21,1),fpp( 4,21,2)/-1.86066547d-05,-1.19344566d-08/
      data fpp( 4,22,1),fpp( 4,22,2)/-9.64008054d-06,-3.54729812d-09/
      data fpp( 4,23,1),fpp( 4,23,2)/ 0.00000000d+00, 1.83236491d-08/
      data fpp( 5, 1,1),fpp( 5, 1,2)/ 0.00000000d+00, 5.76396201d-04/
      data fpp( 5, 2,1),fpp( 5, 2,2)/ 8.19838122d-04, 1.35251979d-05/
      data fpp( 5, 3,1),fpp( 5, 3,2)/ 1.80398281d-02,-9.52346593d-04/
      data fpp( 5, 4,1),fpp( 5, 4,2)/-3.11547267d-01,-5.07715627d-04/
      data fpp( 5, 5,1),fpp( 5, 5,2)/ 8.30486677d-01, 2.05775950d-03/
      data fpp( 5, 6,1),fpp( 5, 6,2)/-1.32663779d-01, 4.84500028d-04/
      data fpp( 5, 7,1),fpp( 5, 7,2)/ 2.95759728d-02,-1.10929401d-03/
      data fpp( 5, 8,1),fpp( 5, 8,2)/-2.84025956d-03, 2.08880192d-05/
      data fpp( 5, 9,1),fpp( 5, 9,2)/-6.97290927d-03,-5.32140649d-05/
      data fpp( 5,10,1),fpp( 5,10,2)/ 4.53291149d-02,-1.68350150d-05/
      data fpp( 5,11,1),fpp( 5,11,2)/ 5.64052055d-03, 1.65452488d-06/
      data fpp( 5,12,1),fpp( 5,12,2)/ 3.04735608d-03, 3.54551550d-06/
      data fpp( 5,13,1),fpp( 5,13,2)/ 5.00115434d-04, 1.33061313d-06/
      data fpp( 5,14,1),fpp( 5,14,2)/-1.96389506d-05,-9.89680107d-08/
      data fpp( 5,15,1),fpp( 5,15,2)/ 3.44354131d-06,-4.84741085d-07/
      data fpp( 5,16,1),fpp( 5,16,2)/-1.65098240d-04, 2.48732351d-07/
      data fpp( 5,17,1),fpp( 5,17,2)/-2.16016093d-04, 3.38811681d-07/
      data fpp( 5,18,1),fpp( 5,18,2)/-8.70438434d-05,-3.07790736d-08/
      data fpp( 5,19,1),fpp( 5,19,2)/-7.67160726d-06,-7.58953864d-08/
      data fpp( 5,20,1),fpp( 5,20,2)/-3.12857986d-05,-5.62393810d-08/
      data fpp( 5,21,1),fpp( 5,21,2)/-5.92901901d-06,-7.54708974d-09/
      data fpp( 5,22,1),fpp( 5,22,2)/ 7.31106971d-06,-2.37226007d-09/
      data fpp( 5,23,1),fpp( 5,23,2)/ 0.00000000d+00, 1.52361300d-08/
      data fpp( 6, 1,1),fpp( 6, 1,2)/ 0.00000000d+00, 7.82635219d-04/
      data fpp( 6, 2,1),fpp( 6, 2,2)/-2.91547835d-03, 1.72934761d-04/
      data fpp( 6, 3,1),fpp( 6, 3,2)/ 1.27739404d-02,-1.87741826d-03/
      data fpp( 6, 4,1),fpp( 6, 4,2)/ 6.49433214d-01, 1.11451270d-03/
      data fpp( 6, 5,1),fpp( 6, 5,2)/ 6.71210080d-02, 3.26367476d-04/
      data fpp( 6, 6,1),fpp( 6, 6,2)/ 7.19732742d-01, 2.05079740d-03/
      data fpp( 6, 7,1),fpp( 6, 7,2)/ 7.97516993d-02,-1.92247708d-03/
      data fpp( 6, 8,1),fpp( 6, 8,2)/ 4.66059893d-02, 1.74154912d-04/
      data fpp( 6, 9,1),fpp( 6, 9,2)/ 3.73232181d-02,-9.40897710d-05/
      data fpp( 6,10,1),fpp( 6,10,2)/ 1.74654031d-03,-1.93094311d-06/
      data fpp( 6,11,1),fpp( 6,11,2)/ 3.51283054d-03,-1.88565654d-06/
      data fpp( 6,12,1),fpp( 6,12,2)/ 1.90494948d-03, 3.91756926d-06/
      data fpp( 6,13,1),fpp( 6,13,2)/ 2.21930029d-04, 5.12179493d-07/
      data fpp( 6,14,1),fpp( 6,14,2)/ 1.00649496d-05, 4.63127673d-08/
      data fpp( 6,15,1),fpp( 6,15,2)/-6.82738346d-05,-4.23830562d-07/
      data fpp( 6,16,1),fpp( 6,16,2)/-2.12901415d-04, 1.70609480d-07/
      data fpp( 6,17,1),fpp( 6,17,2)/-2.76238911d-04, 2.36992640d-07/
      data fpp( 6,18,1),fpp( 6,18,2)/-9.83106052d-05, 1.48199587d-08/
      data fpp( 6,19,1),fpp( 6,19,2)/-3.83183317d-05,-6.22724751d-08/
      data fpp( 6,20,1),fpp( 6,20,2)/ 2.76761942d-06,-3.99300582d-08/
      data fpp( 6,21,1),fpp( 6,21,2)/ 6.32273075d-06,-4.80729202d-09/
      data fpp( 6,22,1),fpp( 6,22,2)/-1.60419831d-06,-2.04077371d-09/
      data fpp( 6,23,1),fpp( 6,23,2)/ 0.00000000d+00, 9.97038685d-09/
      data fpp( 7, 1,1),fpp( 7, 1,2)/ 0.00000000d+00, 8.90652217d-04/
      data fpp( 7, 2,1),fpp( 7, 2,2)/ 3.75701599d-03, 2.58518766d-04/
      data fpp( 7, 3,1),fpp( 7, 3,2)/ 1.52697648d-02,-2.37532728d-03/
      data fpp( 7, 4,1),fpp( 7, 4,2)/ 9.57474916d-02, 1.99682076d-03/
      data fpp( 7, 5,1),fpp( 7, 5,2)/-3.51701863d-01,-5.58506155d-04/
      data fpp( 7, 6,1),fpp( 7, 6,2)/ 1.63916246d-03, 2.75865106d-03/
      data fpp( 7, 7,1),fpp( 7, 7,2)/ 4.63019156d-02,-2.22580769d-03/
      data fpp( 7, 8,1),fpp( 7, 8,2)/-2.02173381d-02, 1.92481304d-04/
      data fpp( 7, 9,1),fpp( 7, 9,2)/-3.07096996d-02,-1.19235123d-04/
      data fpp( 7,10,1),fpp( 7,10,2)/ 3.21332164d-03, 1.58259175d-05/
      data fpp( 7,11,1),fpp( 7,11,2)/ 2.32524810d-03,-4.87794683d-06/
      data fpp( 7,12,1),fpp( 7,12,2)/ 7.81973533d-04, 3.46866982d-06/
      data fpp( 7,13,1),fpp( 7,13,2)/ 9.06521973d-05,-1.80932471d-07/
      data fpp( 7,14,1),fpp( 7,14,2)/ 5.12462654d-06, 1.68060059d-07/
      data fpp( 7,15,1),fpp( 7,15,2)/-7.44002669d-05,-2.99307764d-07/
      data fpp( 7,16,1),fpp( 7,16,2)/-1.99746637d-04, 3.61709967d-08/
      data fpp( 7,17,1),fpp( 7,17,2)/-1.61275219d-04, 1.30023777d-07/
      data fpp( 7,18,1),fpp( 7,18,2)/-8.15462627d-05, 3.95338954d-08/
      data fpp( 7,19,1),fpp( 7,19,2)/-3.27092013d-05,-2.95593587d-08/
      data fpp( 7,20,1),fpp( 7,20,2)/-1.21599590d-05,-1.72964605d-08/
      data fpp( 7,21,1),fpp( 7,21,2)/ 1.99631726d-06,-2.65479908d-09/
      data fpp( 7,22,1),fpp( 7,22,2)/ 1.15706008d-06,-2.84343119d-10/
      data fpp( 7,23,1),fpp( 7,23,2)/ 0.00000000d+00, 5.59217156d-09/
      data fpp( 8, 1,1),fpp( 8, 1,2)/ 0.00000000d+00, 8.10987663d-04/
      data fpp( 8, 2,1),fpp( 8, 2,2)/-1.99808562d-03, 1.24698675d-04/
      data fpp( 8, 3,1),fpp( 8, 3,2)/ 1.16140003d-02,-1.70355756d-03/
      data fpp( 8, 4,1),fpp( 8, 4,2)/ 4.06679820d-01, 4.65071572d-04/
      data fpp( 8, 5,1),fpp( 8, 5,2)/ 5.82745943d-01, 1.36368327d-03/
      data fpp( 8, 6,1),fpp( 8, 6,2)/ 5.28900108d-01, 1.38538733d-03/
      data fpp( 8, 7,1),fpp( 8, 7,2)/ 4.80096383d-02,-1.73869261d-03/
      data fpp( 8, 8,1),fpp( 8, 8,2)/ 1.78668630d-02, 1.10710306d-04/
      data fpp( 8, 9,1),fpp( 8, 9,2)/ 1.49105805d-02,-9.41854153d-05/
      data fpp( 8,10,1),fpp( 8,10,2)/ 1.11117314d-03, 1.09394927d-05/
      data fpp( 8,11,1),fpp( 8,11,2)/ 1.31167704d-03,-2.65275555d-06/
      data fpp( 8,12,1),fpp( 8,12,2)/ 3.52156394d-04, 1.93112949d-06/
      data fpp( 8,13,1),fpp( 8,13,2)/ 4.39611823d-05,-1.43362426d-07/
      data fpp( 8,14,1),fpp( 8,14,2)/ 1.59365443d-05, 1.25520209d-07/
      data fpp( 8,15,1),fpp( 8,15,2)/-6.12509778d-06,-1.82918409d-07/
      data fpp( 8,16,1),fpp( 8,16,2)/-8.91120390d-05,-2.56465740d-08/
      data fpp( 8,17,1),fpp( 8,17,2)/-1.10660212d-04, 5.99047048d-08/
      data fpp( 8,18,1),fpp( 8,18,2)/-6.75043440d-05, 3.26277549d-08/
      data fpp( 8,19,1),fpp( 8,19,2)/-2.13448630d-05,-2.61572438d-09/
      data fpp( 8,20,1),fpp( 8,20,2)/ 2.37221646d-06,-1.76485738d-09/
      data fpp( 8,21,1),fpp( 8,21,2)/-6.80799980d-06,-4.72484609d-09/
      data fpp( 8,22,1),fpp( 8,22,2)/-3.02404200d-06, 2.06424174d-09/
      data fpp( 8,23,1),fpp( 8,23,2)/ 0.00000000d+00, 6.06787913d-09/
      data fpp( 9, 1,1),fpp( 9, 1,2)/ 0.00000000d+00, 4.46603988d-04/
      data fpp( 9, 2,1),fpp( 9, 2,2)/ 3.77326473d-04,-5.73699753d-05/
      data fpp( 9, 3,1),fpp( 9, 3,2)/-7.61626612d-03,-4.55153686d-04/
      data fpp( 9, 4,1),fpp( 9, 4,2)/-2.97663270d-01,-1.22460328d-03/
      data fpp( 9, 5,1),fpp( 9, 5,2)/ 4.65229091d-01, 2.77936280d-03/
      data fpp( 9, 6,1),fpp( 9, 6,2)/-2.93197594d-01,-4.28193527d-04/
      data fpp( 9, 7,1),fpp( 9, 7,2)/-9.60546884d-03,-5.43539893d-04/
      data fpp( 9, 8,1),fpp( 9, 8,2)/ 2.79386227d-04,-9.39317000d-05/
      data fpp( 9, 9,1),fpp( 9, 9,2)/-2.65862232d-03,-4.25693067d-05/
      data fpp( 9,10,1),fpp( 9,10,2)/ 1.03748579d-03, 9.62370199d-07/
      data fpp( 9,11,1),fpp( 9,11,2)/ 7.29043717d-04, 2.42425936d-07/
      data fpp( 9,12,1),fpp( 9,12,2)/ 1.52400892d-04, 5.78926058d-07/
      data fpp( 9,13,1),fpp( 9,13,2)/ 1.25030737d-05, 4.04698313d-08/
      data fpp( 9,14,1),fpp( 9,14,2)/ 7.62919642d-06, 5.71946164d-08/
      data fpp( 9,15,1),fpp( 9,15,2)/-1.05993420d-05,-1.03048297d-07/
      data fpp( 9,16,1),fpp( 9,16,2)/-5.43052072d-05,-4.16014289d-08/
      data fpp( 9,17,1),fpp( 9,17,2)/-8.00839341d-05, 1.38540124d-08/
      data fpp( 9,18,1),fpp( 9,18,2)/-5.79363612d-05, 2.27853794d-08/
      data fpp( 9,19,1),fpp( 9,19,2)/-1.54113467d-05, 1.26044702d-08/
      data fpp( 9,20,1),fpp( 9,20,2)/-9.32890687d-06, 1.79673995d-09/
      data fpp( 9,21,1),fpp( 9,21,2)/ 2.73568195d-06, 8.57001232d-12/
      data fpp( 9,22,1),fpp( 9,22,2)/ 9.43910791d-06, 1.76898000d-09/
      data fpp( 9,23,1),fpp( 9,23,2)/ 0.00000000d+00, 2.51551000d-09/
      data fpp(10, 1,1),fpp(10, 1,2)/ 0.00000000d+00, 1.81967109d-04/
      data fpp(10, 2,1),fpp(10, 2,2)/-1.03720277d-04,-1.97486189d-05/
      data fpp(10, 3,1),fpp(10, 3,2)/-4.87443584d-03,-2.21321434d-04/
      data fpp(10, 4,1),fpp(10, 4,2)/-1.05205739d-01,-4.23394446d-04/
      data fpp(10, 5,1),fpp(10, 5,2)/-6.64963807d-01, 8.99408817d-04/
      data fpp(10, 6,1),fpp(10, 6,2)/-1.09655733d-01, 1.29680779d-04/
      data fpp(10, 7,1),fpp(10, 7,2)/-1.48347630d-02,-2.89704732d-04/
      data fpp(10, 8,1),fpp(10, 8,2)/-2.42290787d-03,-6.71434507d-05/
      data fpp(10, 9,1),fpp(10, 9,2)/ 2.52408803d-04,-2.95030654d-05/
      data fpp(10,10,1),fpp(10,10,2)/ 6.63883698d-04, 1.10472139d-06/
      data fpp(10,11,1),fpp(10,11,2)/ 3.65148088d-04, 1.18179804d-07/
      data fpp(10,12,1),fpp(10,12,2)/ 7.02400369d-05, 2.93359396d-07/
      data fpp(10,13,1),fpp(10,13,2)/ 1.55265231d-05, 3.25826137d-08/
      data fpp(10,14,1),fpp(10,14,2)/ 1.65466700d-05, 3.95101496d-08/
      data fpp(10,15,1),fpp(10,15,2)/ 9.52246573d-06,-5.62232120d-08/
      data fpp(10,16,1),fpp(10,16,2)/-2.66713208d-06,-4.32173017d-08/
      data fpp(10,17,1),fpp(10,17,2)/-2.65040521d-05,-7.90758141d-09/
      data fpp(10,18,1),fpp(10,18,2)/-1.42502114d-05, 1.84476273d-08/
      data fpp(10,19,1),fpp(10,19,2)/-1.45097502d-05, 1.03170722d-08/
      data fpp(10,20,1),fpp(10,20,2)/-1.05658898d-06, 8.08408373d-09/
      data fpp(10,21,1),fpp(10,21,2)/-1.13472801d-06, 2.34659284d-09/
      data fpp(10,22,1),fpp(10,22,2)/-1.52323897d-05,-6.70455098d-10/
      data fpp(10,23,1),fpp(10,23,2)/ 0.00000000d+00,-4.46477245d-09/
      data fpp(11, 1,1),fpp(11, 1,2)/ 0.00000000d+00, 8.70074284d-05/
      data fpp(11, 2,1),fpp(11, 2,2)/-1.44536627d-06,-1.32116568d-05/
      data fpp(11, 3,1),fpp(11, 3,2)/-8.76149053d-03,-9.01048011d-05/
      data fpp(11, 4,1),fpp(11, 4,2)/-2.07257744d-02,-2.48638739d-04/
      data fpp(11, 5,1),fpp(11, 5,2)/ 1.99621388d-02, 4.56498156d-04/
      data fpp(11, 6,1),fpp(11, 6,2)/-5.80554748d-02, 7.82189156d-05/
      data fpp(11, 7,1),fpp(11, 7,2)/-2.16539793d-02,-1.32385018d-04/
      data fpp(11, 8,1),fpp(11, 8,2)/-4.85725476d-03,-4.16748435d-05/
      data fpp(11, 9,1),fpp(11, 9,2)/-1.04651289d-03,-1.82508080d-05/
      data fpp(11,10,1),fpp(11,10,2)/ 4.54479420d-04, 8.26845755d-07/
      data fpp(11,11,1),fpp(11,11,2)/ 1.98363930d-04, 4.78249827d-08/
      data fpp(11,12,1),fpp(11,12,2)/ 3.01389601d-05, 1.46454314d-07/
      data fpp(11,13,1),fpp(11,13,2)/-2.60916595d-06, 2.93577608d-08/
      data fpp(11,14,1),fpp(11,14,2)/-3.15876604d-07, 2.17146428d-08/
      data fpp(11,15,1),fpp(11,15,2)/ 2.95094791d-05,-2.08163320d-08/
      data fpp(11,16,1),fpp(11,16,2)/-1.15262645d-05,-4.58493147d-08/
      data fpp(11,17,1),fpp(11,17,2)/-1.18998577d-05,-9.38640934d-09/
      data fpp(11,18,1),fpp(11,18,2)/-2.15627934d-05, 7.19495202d-09/
      data fpp(11,19,1),fpp(11,19,2)/-9.04965259d-06, 1.24066013d-08/
      data fpp(11,20,1),fpp(11,20,2)/-1.44473721d-06, 9.17864296d-09/
      data fpp(11,21,1),fpp(11,21,2)/ 3.03230069d-07,-5.21173105d-10/
      data fpp(11,22,1),fpp(11,22,2)/ 1.24904507d-05, 2.50604946d-09/
      data fpp(11,23,1),fpp(11,23,2)/ 0.00000000d+00, 1.89697527d-09/
      data fpp(12, 1,1),fpp(12, 1,2)/ 0.00000000d+00, 1.84691930d-05/
      data fpp(12, 2,1),fpp(12, 2,2)/-4.19982582d-05,-2.29383861d-05/
      data fpp(12, 3,1),fpp(12, 3,2)/ 5.76839796d-03, 2.55867512d-05/
      data fpp(12, 4,1),fpp(12, 4,2)/-3.32521636d-02,-2.40652619d-04/
      data fpp(12, 5,1),fpp(12, 5,2)/-5.00942478d-02, 3.33567724d-04/
      data fpp(12, 6,1),fpp(12, 6,2)/-4.63958679d-02,-2.91390768d-05/
      data fpp(12, 7,1),fpp(12, 7,2)/-1.43913199d-02,-3.06682169d-05/
      data fpp(12, 8,1),fpp(12, 8,2)/-3.74857308d-03,-2.94024558d-05/
      data fpp(12, 9,1),fpp(12, 9,2)/-6.23357247d-04,-9.32756010d-06/
      data fpp(12,10,1),fpp(12,10,2)/ 2.67698622d-04, 2.21908169d-07/
      data fpp(12,11,1),fpp(12,11,2)/ 8.78961904d-05, 9.09274191d-08/
      data fpp(12,12,1),fpp(12,12,2)/ 1.02041226d-05, 5.57821542d-08/
      data fpp(12,13,1),fpp(12,13,2)/ 3.91014075d-06, 2.91439640d-08/
      data fpp(12,14,1),fpp(12,14,2)/ 1.17168364d-05, 1.96419898d-08/
      data fpp(12,15,1),fpp(12,15,2)/-6.06038203d-06,-2.07119233d-08/
      data fpp(12,16,1),fpp(12,16,2)/ 8.27218993d-06,-2.55942968d-08/
      data fpp(12,17,1),fpp(12,17,2)/-3.89651711d-06,-1.73108895d-08/
      data fpp(12,18,1),fpp(12,18,2)/ 1.50138503d-06, 5.43785493d-09/
      data fpp(12,19,1),fpp(12,19,2)/ 2.70836055d-06, 1.17594698d-08/
      data fpp(12,20,1),fpp(12,20,2)/-2.16446220d-06, 6.92426582d-09/
      data fpp(12,21,1),fpp(12,21,2)/-7.81922722d-08, 7.43466894d-10/
      data fpp(12,22,1),fpp(12,22,2)/-4.72941315d-06, 9.01866602d-10/
      data fpp(12,23,1),fpp(12,23,2)/ 0.00000000d+00,-7.50933301d-10/
      data fpp(13, 1,1),fpp(13, 1,2)/ 0.00000000d+00, 4.62593215d-06/
      data fpp(13, 2,1),fpp(13, 2,2)/ 1.49577714d-05,-6.49106429d-06/
      data fpp(13, 3,1),fpp(13, 3,2)/-4.55499950d-03, 1.87127250d-05/
      data fpp(13, 4,1),fpp(13, 4,2)/-8.98027178d-03,-8.32062358d-05/
      data fpp(13, 5,1),fpp(13, 5,2)/-2.86919333d-02, 8.51906182d-05/
      data fpp(13, 6,1),fpp(13, 6,2)/-1.41551238d-02, 5.16936292d-06/
      data fpp(13, 7,1),fpp(13, 7,2)/-6.46594745d-03,-5.86486991d-06/
      data fpp(13, 8,1),fpp(13, 8,2)/-1.94925323d-03,-1.00658833d-05/
      data fpp(13, 9,1),fpp(13, 9,2)/-3.53467251d-04,-3.77479691d-06/
      data fpp(13,10,1),fpp(13,10,2)/ 9.06849802d-05, 1.23732371d-07/
      data fpp(13,11,1),fpp(13,11,2)/ 2.54367450d-05, 2.54674220d-08/
      data fpp(13,12,1),fpp(13,12,2)/ 5.89361782d-06, 3.11979405d-08/
      data fpp(13,13,1),fpp(13,13,2)/-9.61025189d-07, 2.01408159d-08/
      data fpp(13,14,1),fpp(13,14,2)/-4.84553684d-06, 5.83879574d-09/
      data fpp(13,15,1),fpp(13,15,2)/ 1.75282874d-05,-5.69599891d-09/
      data fpp(13,16,1),fpp(13,16,2)/ 1.11102099d-05,-1.60548001d-08/
      data fpp(13,17,1),fpp(13,17,2)/ 7.92162884d-06,-1.28848007d-08/
      data fpp(13,18,1),fpp(13,18,2)/-2.96087827d-07, 9.94002849d-10/
      data fpp(13,19,1),fpp(13,19,2)/-3.32810009d-06, 7.10878929d-09/
      data fpp(13,20,1),fpp(13,20,2)/ 2.84469880d-06, 7.17083998d-09/
      data fpp(13,21,1),fpp(13,21,2)/-1.60817914d-06,-3.92149226d-10/
      data fpp(13,22,1),fpp(13,22,2)/ 2.10441004d-06, 3.97756922d-10/
      data fpp(13,23,1),fpp(13,23,2)/ 0.00000000d+00,-1.19887846d-09/
      data fpp(14, 1,1),fpp(14, 1,2)/ 0.00000000d+00, 3.73535871d-06/
      data fpp(14, 2,1),fpp(14, 2,2)/-1.78328274d-05,-5.79174300d-08/
      data fpp(14, 3,1),fpp(14, 3,2)/ 9.31600040d-04,-2.52928900d-06/
      data fpp(14, 4,1),fpp(14, 4,2)/ 4.09058404d-03,-9.62732659d-06/
      data fpp(14, 5,1),fpp(14, 5,2)/-2.42935253d-03, 1.15257954d-05/
      data fpp(14, 6,1),fpp(14, 6,2)/-4.90897035d-03, 6.16494518d-06/
      data fpp(14, 7,1),fpp(14, 7,2)/-2.37422362d-03,-1.17437606d-06/
      data fpp(14, 8,1),fpp(14, 8,2)/-8.03747344d-04,-3.02264094d-06/
      data fpp(14, 9,1),fpp(14, 9,2)/-1.66107081d-04,-1.41826020d-06/
      data fpp(14,10,1),fpp(14,10,2)/ 2.02281241d-05, 6.67010546d-08/
      data fpp(14,11,1),fpp(14,11,2)/ 4.35682954d-06, 1.20559772d-08/
      data fpp(14,12,1),fpp(14,12,2)/-4.45260571d-07, 2.36750367d-08/
      data fpp(14,13,1),fpp(14,13,2)/ 4.60062667d-06, 9.64387619d-09/
      data fpp(14,14,1),fpp(14,14,2)/ 1.36653110d-05, 7.94945858d-09/
      data fpp(14,15,1),fpp(14,15,2)/-4.71943412d-06,-6.04171051d-09/
      data fpp(14,16,1),fpp(14,16,2)/ 6.62030395d-06,-8.98261655d-09/
      data fpp(14,17,1),fpp(14,17,2)/ 3.54333510d-06,-8.42782329d-09/
      data fpp(14,18,1),fpp(14,18,2)/ 3.68296627d-06,-5.06090280d-10/
      data fpp(14,19,1),fpp(14,19,2)/ 6.60403982d-06, 8.05218441d-09/
      data fpp(14,20,1),fpp(14,20,2)/-1.21433298d-06, 9.73526318d-11/
      data fpp(14,21,1),fpp(14,21,2)/ 5.17757550d-06, 2.95840506d-09/
      data fpp(14,22,1),fpp(14,22,2)/-3.68822701d-06,-1.13097287d-09/
      data fpp(14,23,1),fpp(14,23,2)/ 0.00000000d+00,-3.23451356d-09/
      data fpp(15, 1,1),fpp(15, 1,2)/ 0.00000000d+00, 1.27720391d-06/
      data fpp(15, 2,1),fpp(15, 2,2)/ 1.42274800d-05,-4.76078113d-08/
      data fpp(15, 3,1),fpp(15, 3,2)/-8.00009497d-05,-1.15157266d-06/
      data fpp(15, 4,1),fpp(15, 4,2)/-1.79901252d-03,-3.02850155d-06/
      data fpp(15, 5,1),fpp(15, 5,2)/-3.01533747d-03, 3.37757885d-06/
      data fpp(15, 6,1),fpp(15, 6,2)/-2.24646261d-03, 3.13098616d-06/
      data fpp(15, 7,1),fpp(15, 7,2)/-1.29696070d-03,-2.48723481d-07/
      data fpp(15, 8,1),fpp(15, 8,2)/-4.79383441d-04,-1.36329224d-06/
      data fpp(15, 9,1),fpp(15, 9,2)/-1.17763716d-04,-7.03707579d-07/
      data fpp(15,10,1),fpp(15,10,2)/ 6.33190913d-06, 5.01688536d-08/
      data fpp(15,11,1),fpp(15,11,2)/-9.39265219d-07, 1.10321644d-08/
      data fpp(15,12,1),fpp(15,12,2)/ 4.88587613d-06, 2.03024888d-08/
      data fpp(15,13,1),fpp(15,13,2)/-6.56159559d-06, 8.55788043d-09/
      data fpp(15,14,1),fpp(15,14,2)/-8.55824960d-06,-2.33401050d-09/
      data fpp(15,15,1),fpp(15,15,2)/ 1.48047396d-05, 5.57816159d-09/
      data fpp(15,16,1),fpp(15,16,2)/ 2.23316547d-06,-1.21786358d-08/
      data fpp(15,17,1),fpp(15,17,2)/ 1.04008812d-05,-4.26361820d-09/
      data fpp(15,18,1),fpp(15,18,2)/ 8.52930037d-06, 1.03310865d-09/
      data fpp(15,19,1),fpp(15,19,2)/-5.28048984d-07, 3.13118359d-09/
      data fpp(15,20,1),fpp(15,20,2)/ 8.04616729d-07, 3.24215698d-09/
      data fpp(15,21,1),fpp(15,21,2)/-6.97560877d-06,-2.29981149d-09/
      data fpp(15,22,1),fpp(15,22,2)/ 3.78451997d-06, 1.75708900d-09/
      data fpp(15,23,1),fpp(15,23,2)/ 0.00000000d+00, 3.07145550d-09/
      data fpp(16, 1,1),fpp(16, 1,2)/ 0.00000000d+00, 3.86508240d-07/
      data fpp(16, 2,1),fpp(16, 2,2)/-7.57709263d-06,-4.38164799d-08/
      data fpp(16, 3,1),fpp(16, 3,2)/ 4.09037592d-05,-3.72042320d-07/
      data fpp(16, 4,1),fpp(16, 4,2)/-1.30339520d-05,-1.05761424d-06/
      data fpp(16, 5,1),fpp(16, 5,2)/-7.17797572d-04, 1.02889928d-06/
      data fpp(16, 6,1),fpp(16, 6,2)/-9.94179203d-04, 1.38201714d-06/
      data fpp(16, 7,1),fpp(16, 7,2)/-6.06933570d-04,-2.17678217d-08/
      data fpp(16, 8,1),fpp(16, 8,2)/-2.42718894d-04,-6.18145850d-07/
      data fpp(16, 9,1),fpp(16, 9,2)/-6.48380532d-05,-3.42448780d-07/
      data fpp(16,10,1),fpp(16,10,2)/ 3.94423937d-06, 4.16192648d-08/
      data fpp(16,11,1),fpp(16,11,2)/ 6.90023133d-06, 1.39717207d-08/
      data fpp(16,12,1),fpp(16,12,2)/-7.09824394d-06, 1.16938523d-08/
      data fpp(16,13,1),fpp(16,13,2)/ 6.45755675d-07, 9.45287013d-09/
      data fpp(16,14,1),fpp(16,14,2)/-4.32312588d-07,-2.10533280d-09/
      data fpp(16,15,1),fpp(16,15,2)/-3.49952410d-06, 1.96846107d-09/
      data fpp(16,16,1),fpp(16,16,2)/ 6.94703416d-06,-5.16851149d-09/
      data fpp(16,17,1),fpp(16,17,2)/-1.46860064d-07,-5.29441511d-09/
      data fpp(16,18,1),fpp(16,18,2)/-1.80016774d-06, 5.46171924d-10/
      data fpp(16,19,1),fpp(16,19,2)/ 8.15611093d-09, 2.50972741d-09/
      data fpp(16,20,1),fpp(16,20,2)/-2.00413393d-06, 2.01491843d-09/
      data fpp(16,21,1),fpp(16,21,2)/ 3.22485957d-06,-3.69401115d-10/
      data fpp(16,22,1),fpp(16,22,2)/ 5.50147128d-07, 6.62686033d-10/
      data fpp(16,23,1),fpp(16,23,2)/ 0.00000000d+00, 7.18656984d-10/
      data fpp(17, 1,1),fpp(17, 1,2)/ 0.00000000d+00, 7.52119452d-08/
      data fpp(17, 2,1),fpp(17, 2,2)/ 3.77198877d-06,-2.82389046d-09/
      data fpp(17, 3,1),fpp(17, 3,2)/-2.03452308d-05,-5.67163834d-08/
      data fpp(17, 4,1),fpp(17, 4,2)/-1.40545146d-04,-1.95110576d-07/
      data fpp(17, 5,1),fpp(17, 5,2)/-2.42783110d-04, 1.96358687d-07/
      data fpp(17, 6,1),fpp(17, 6,2)/-2.49094249d-04, 3.40875827d-07/
      data fpp(17, 7,1),fpp(17, 7,2)/-1.77580965d-04,-2.38619964d-08/
      data fpp(17, 8,1),fpp(17, 8,2)/-7.93480602d-05,-2.09427842d-07/
      data fpp(17, 9,1),fpp(17, 9,2)/-2.63640118d-05,-1.15226636d-07/
      data fpp(17,10,1),fpp(17,10,2)/-3.54039726d-08, 3.51938292d-08/
      data fpp(17,11,1),fpp(17,11,2)/-3.37459430d-06, 4.45131932d-09/
      data fpp(17,12,1),fpp(17,12,2)/ 4.73689573d-06, 1.54008935d-08/
      data fpp(17,13,1),fpp(17,13,2)/ 8.88544809d-07, 2.34510656d-09/
      data fpp(17,14,1),fpp(17,14,2)/ 4.14654169d-06, 1.01868024d-09/
      data fpp(17,15,1),fpp(17,15,2)/ 5.46192064d-06, 1.38017250d-09/
      data fpp(17,16,1),fpp(17,16,2)/-9.78890840d-07,-4.73937024d-09/
      data fpp(17,17,1),fpp(17,17,2)/ 2.22227939d-06,-2.82269155d-09/
      data fpp(17,18,1),fpp(17,18,2)/ 1.31435890d-06, 4.30136449d-10/
      data fpp(17,19,1),fpp(17,19,2)/ 3.24845619d-07, 1.10214576d-09/
      data fpp(17,20,1),fpp(17,20,2)/ 6.14403528d-06, 2.36128052d-09/
      data fpp(17,21,1),fpp(17,21,2)/-9.91260693d-08,-3.47267832d-10/
      data fpp(17,22,1),fpp(17,22,2)/-2.02350374d-06,-3.72209191d-10/
      data fpp(17,23,1),fpp(17,23,2)/ 0.00000000d+00,-1.16389540d-09/
      data fpp(18, 1,1),fpp(18, 1,2)/ 0.00000000d+00, 5.51920887d-09/
      data fpp(18, 2,1),fpp(18, 2,2)/-2.84419576d-06, 1.36158227d-09/
      data fpp(18, 3,1),fpp(18, 3,2)/ 5.81049747d-06, 5.83446206d-09/
      data fpp(18, 4,1),fpp(18, 4,2)/ 1.92145350d-05,-1.98994305d-08/
      data fpp(18, 5,1),fpp(18, 5,2)/-2.44033220d-05, 7.61632599d-08/
      data fpp(18, 6,1),fpp(18, 6,2)/-6.87771363d-05, 5.84463907d-08/
      data fpp(18, 7,1),fpp(18, 7,2)/-5.40759039d-05,-5.07488228d-08/
      data fpp(18, 8,1),fpp(18, 8,2)/-2.18888653d-05,-9.54510995d-08/
      data fpp(18, 9,1),fpp(18, 9,2)/ 3.62743381d-06,-3.06467792d-08/
      data fpp(18,10,1),fpp(18,10,2)/ 8.19737652d-06, 1.72658875d-08/
      data fpp(18,11,1),fpp(18,11,2)/ 1.26481253d-06, 7.18322942d-09/
      data fpp(18,12,1),fpp(18,12,2)/-3.18267230d-06, 9.80119488d-09/
      data fpp(18,13,1),fpp(18,13,2)/-1.53326824d-06, 2.21199108d-09/
      data fpp(18,14,1),fpp(18,14,2)/-2.82052084d-06, 5.50840807d-10/
      data fpp(18,15,1),fpp(18,15,2)/-3.68149178d-06,-2.15354305d-10/
      data fpp(18,16,1),fpp(18,16,2)/ 6.30186254d-06,-2.68942358d-09/
      data fpp(18,17,1),fpp(18,17,2)/-7.55908187d-08,-1.62695136d-09/
      data fpp(18,18,1),fpp(18,18,2)/ 5.42732149d-07, 1.97229009d-10/
      data fpp(18,19,1),fpp(18,19,2)/ 6.92461411d-07, 3.83803532d-09/
      data fpp(18,20,1),fpp(18,20,2)/-1.05720072d-05,-2.94937029d-09/
      data fpp(18,21,1),fpp(18,21,2)/-1.61688631d-07, 7.59445848d-10/
      data fpp(18,22,1),fpp(18,22,2)/ 1.54386783d-06, 5.11586901d-10/
      data fpp(18,23,1),fpp(18,23,2)/ 0.00000000d+00, 1.39420655d-09/
      data fpp(19, 1,1),fpp(19, 1,2)/ 0.00000000d+00, 6.18687625d-10/
      data fpp(19, 2,1),fpp(19, 2,2)/ 1.56299567d-06, 4.76262475d-09/
      data fpp(19, 3,1),fpp(19, 3,2)/-4.53464109d-06, 1.63308134d-08/
      data fpp(19, 4,1),fpp(19, 4,2)/-2.72549564d-05, 1.91412175d-09/
      data fpp(19, 5,1),fpp(19, 5,2)/-2.23087255d-05, 3.84126996d-08/
      data fpp(19, 6,1),fpp(19, 6,2)/-1.59729459d-05, 2.20350798d-08/
      data fpp(19, 7,1),fpp(19, 7,2)/-5.24903343d-06,-5.21530187d-08/
      data fpp(19, 8,1),fpp(19, 8,2)/-7.03358306d-06,-5.34230049d-08/
      data fpp(19, 9,1),fpp(19, 9,2)/-7.59115133d-06,-1.49549618d-08/
      data fpp(19,10,1),fpp(19,10,2)/-5.43377666d-06, 4.97638775d-09/
      data fpp(19,11,1),fpp(19,11,2)/ 7.37828779d-07, 1.18494108d-08/
      data fpp(19,12,1),fpp(19,12,2)/ 4.30801790d-06, 5.82596919d-09/
      data fpp(19,13,1),fpp(19,13,2)/ 1.33352400d-06, 2.64671249d-09/
      data fpp(19,14,1),fpp(19,14,2)/ 2.88279166d-06,-1.41281915d-09/
      data fpp(19,15,1),fpp(19,15,2)/ 2.21457795d-06, 3.60456409d-09/
      data fpp(19,16,1),fpp(19,16,2)/-1.05409764d-05,-7.00543722d-09/
      data fpp(19,17,1),fpp(19,17,2)/ 5.54453501d-06, 1.61718478d-09/
      data fpp(19,18,1),fpp(19,18,2)/ 4.31480091d-06, 5.36698081d-10/
      data fpp(19,19,1),fpp(19,19,2)/ 2.05042452d-06,-1.63977110d-10/
      data fpp(19,20,1),fpp(19,20,2)/ 1.21439831d-05, 2.51921036d-09/
      data fpp(19,21,1),fpp(19,21,2)/-3.04286774d-06,-2.71286433d-09/
      data fpp(19,22,1),fpp(19,22,2)/-6.84083519d-07, 1.13224695d-09/
      data fpp(19,23,1),fpp(19,23,2)/ 0.00000000d+00, 2.38387652d-09/
      data fpp(20, 1,1),fpp(20, 1,2)/ 0.00000000d+00, 1.84060082d-09/
      data fpp(20, 2,1),fpp(20, 2,2)/-4.07786921d-07, 7.91879837d-09/
      data fpp(20, 3,1),fpp(20, 3,2)/ 3.32806690d-06,-2.31579428d-09/
      data fpp(20, 4,1),fpp(20, 4,2)/ 8.80529053d-06, 4.45443788d-08/
      data fpp(20, 5,1),fpp(20, 5,2)/-9.36177617d-06,-5.46172073d-09/
      data fpp(20, 6,1),fpp(20, 6,2)/-1.13310802d-05, 2.29025042d-08/
      data fpp(20, 7,1),fpp(20, 7,2)/-8.92796241d-06,-6.69482960d-08/
      data fpp(20, 8,1),fpp(20, 8,2)/ 1.40231976d-05,-1.43093203d-08/
      data fpp(20, 9,1),fpp(20, 9,2)/ 1.77371715d-05,-7.81442289d-09/
      data fpp(20,10,1),fpp(20,10,2)/ 3.03773012d-06,-2.40207120d-09/
      data fpp(20,11,1),fpp(20,11,2)/ 4.78387235d-06, 1.38227077d-08/
      data fpp(20,12,1),fpp(20,12,2)/-2.04939931d-06, 1.11124044d-09/
      data fpp(20,13,1),fpp(20,13,2)/-8.00827768d-07, 3.93233056d-09/
      data fpp(20,14,1),fpp(20,14,2)/-4.21064579d-06,-1.84056266d-09/
      data fpp(20,15,1),fpp(20,15,2)/ 8.23179998d-07, 4.29920080d-10/
      data fpp(20,16,1),fpp(20,16,2)/ 7.36204317d-06, 7.20882338d-10/
      data fpp(20,17,1),fpp(20,17,2)/-2.60254923d-06,-3.31344943d-09/
      data fpp(20,18,1),fpp(20,18,2)/-1.30193578d-06, 1.13291539d-09/
      data fpp(20,19,1),fpp(20,19,2)/ 1.05840529d-07, 1.18178786d-09/
      data fpp(20,20,1),fpp(20,20,2)/-6.50392519d-06,-1.66006685d-09/
      data fpp(20,21,1),fpp(20,21,2)/ 3.33315960d-06, 1.85847954d-09/
      data fpp(20,22,1),fpp(20,22,2)/ 2.69246625d-06,-3.73851296d-10/
      data fpp(20,23,1),fpp(20,23,2)/ 0.00000000d+00,-9.63074352d-10/
      data fpp(21, 1,1),fpp(21, 1,2)/ 0.00000000d+00, 1.03694523d-08/
      data fpp(21, 2,1),fpp(21, 2,2)/ 9.83959288d-07, 8.46109535d-09/
      data fpp(21, 3,1),fpp(21, 3,2)/-2.07046226d-06,-3.41383371d-09/
      data fpp(21, 4,1),fpp(21, 4,2)/ 4.15233581d-06, 1.95942395d-08/
      data fpp(21, 5,1),fpp(21, 5,2)/ 2.41173755d-06, 1.14368757d-08/
      data fpp(21, 6,1),fpp(21, 6,2)/ 6.75223116d-06, 1.85825756d-09/
      data fpp(21, 7,1),fpp(21, 7,2)/ 9.92589699d-06,-2.36699060d-08/
      data fpp(21, 8,1),fpp(21, 8,2)/ 1.61173018d-06,-1.99786336d-08/
      data fpp(21, 9,1),fpp(21, 9,2)/-7.29804173d-07,-1.16155596d-08/
      data fpp(21,10,1),fpp(21,10,2)/ 2.16341738d-06, 4.63599571d-09/
      data fpp(21,11,1),fpp(21,11,2)/-1.77146035d-06, 4.47157681d-09/
      data fpp(21,12,1),fpp(21,12,2)/ 2.92652431d-07, 3.27769704d-09/
      data fpp(21,13,1),fpp(21,13,2)/ 4.47076559d-07,-1.82364964d-10/
      data fpp(21,14,1),fpp(21,14,2)/ 3.11362486d-06, 3.45176282d-09/
      data fpp(21,15,1),fpp(21,15,2)/-2.20318625d-07,-3.42468631d-09/
      data fpp(21,16,1),fpp(21,16,2)/-8.46159623d-07, 2.44698243d-09/
      data fpp(21,17,1),fpp(21,17,2)/ 3.12140760d-07,-2.76324341d-09/
      data fpp(21,18,1),fpp(21,18,2)/-8.70081354d-07, 1.40599120d-09/
      data fpp(21,19,1),fpp(21,19,2)/-1.71975144d-06,-2.26072140d-09/
      data fpp(21,20,1),fpp(21,20,2)/ 2.25042856d-06, 2.23689440d-09/
      data fpp(21,21,1),fpp(21,21,2)/-1.08195352d-06, 1.11314382d-09/
      data fpp(21,22,1),fpp(21,22,2)/-2.85216516d-06,-1.88946966d-09/
      data fpp(21,23,1),fpp(21,23,2)/ 0.00000000d+00,-4.35526517d-09/
      data fpp(22, 1,1),fpp(22, 1,2)/ 0.00000000d+00,-1.73285919d-08/
      data fpp(22, 2,1),fpp(22, 2,2)/-6.63997568d-07,-1.13428161d-08/
      data fpp(22, 3,1),fpp(22, 3,2)/ 3.18863909d-06, 6.02998564d-08/
      data fpp(22, 4,1),fpp(22, 4,2)/-7.13064892d-06,-9.78566097d-08/
      data fpp(22, 5,1),fpp(22, 5,2)/ 4.05950556d-06, 9.59265822d-08/
      data fpp(22, 6,1),fpp(22, 6,2)/ 1.19150839d-06,-3.14497193d-08/
      data fpp(22, 7,1),fpp(22, 7,2)/ 7.39070707d-08,-8.52770523d-09/
      data fpp(22, 8,1),fpp(22, 8,2)/ 3.06854488d-06,-6.43945985d-09/
      data fpp(22, 9,1),fpp(22, 9,2)/ 2.89307044d-06,-8.91445538d-09/
      data fpp(22,10,1),fpp(22,10,2)/ 1.89442631d-06, 3.56309607d-09/
      data fpp(22,11,1),fpp(22,11,2)/ 1.19834971d-06, 1.86207110d-09/
      data fpp(22,12,1),fpp(22,12,2)/-2.68481945d-08, 1.58861952d-09/
      data fpp(22,13,1),fpp(22,13,2)/-3.90148328d-07, 1.83450812d-10/
      data fpp(22,14,1),fpp(22,14,2)/-1.19721206d-06, 6.77577229d-10/
      data fpp(22,15,1),fpp(22,15,2)/ 2.11111600d-07,-4.93759729d-10/
      data fpp(22,16,1),fpp(22,16,2)/ 2.90484890d-07, 9.74616864d-11/
      data fpp(22,17,1),fpp(22,17,2)/ 4.82679105d-07,-4.96087017d-10/
      data fpp(22,18,1),fpp(22,18,2)/ 7.65421799d-07, 8.68863805d-11/
      data fpp(22,19,1),fpp(22,19,2)/ 8.79700286d-07, 1.48541495d-10/
      data fpp(22,20,1),fpp(22,20,2)/-8.19016289d-07,-8.10523594d-11/
      data fpp(22,21,1),fpp(22,21,2)/ 2.62355492d-07, 1.75667943d-10/
      data fpp(22,22,1),fpp(22,22,2)/ 1.35144876d-06,-2.16194123d-11/
      data fpp(22,23,1),fpp(22,23,2)/ 0.00000000d+00,-8.91902939d-11/
      data fpp(23, 1,1),fpp(23, 1,2)/ 0.00000000d+00, 2.93001078d-08/
      data fpp(23, 2,1),fpp(23, 2,2)/ 2.32030985d-07, 1.29997844d-08/
      data fpp(23, 3,1),fpp(23, 3,2)/-3.96409411d-06,-3.08992455d-08/
      data fpp(23, 4,1),fpp(23, 4,2)/ 5.41025987d-06, 2.17971975d-08/
      data fpp(23, 5,1),fpp(23, 5,2)/-1.60975977d-06, 3.71045565d-09/
      data fpp(23, 6,1),fpp(23, 6,2)/ 4.81735270d-07,-5.43902004d-09/
      data fpp(23, 7,1),fpp(23, 7,2)/ 2.25847472d-06, 1.24562451d-09/
      data fpp(23, 8,1),fpp(23, 8,2)/ 1.47409030d-06,-6.74347800d-09/
      data fpp(23, 9,1),fpp(23, 9,2)/ 1.87752240d-06,-6.71712527d-10/
      data fpp(23,10,1),fpp(23,10,2)/-1.41122620d-07,-1.81312342d-09/
      data fpp(23,11,1),fpp(23,11,2)/ 9.80615220d-08, 2.52420622d-09/
      data fpp(23,12,1),fpp(23,12,2)/ 5.47403467d-08, 1.16298557d-10/
      data fpp(23,13,1),fpp(23,13,2)/ 1.53516754d-07, 6.10599557d-10/
      data fpp(23,14,1),fpp(23,14,2)/ 4.75223400d-07,-1.58696786d-10/
      data fpp(23,15,1),fpp(23,15,2)/ 9.58722259d-08, 2.41875861d-11/
      data fpp(23,16,1),fpp(23,16,2)/ 1.64220064d-07, 6.19464416d-11/
      data fpp(23,17,1),fpp(23,17,2)/-8.28571798d-08,-2.71973352d-10/
      data fpp(23,18,1),fpp(23,18,2)/-2.71605840d-07,-1.74053032d-10/
      data fpp(23,19,1),fpp(23,19,2)/-1.19049706d-07, 3.68185481d-10/
      data fpp(23,20,1),fpp(23,20,2)/ 3.05636594d-07,-9.86888918d-11/
      data fpp(23,21,1),fpp(23,21,2)/ 3.25315488d-08, 2.65700863d-11/
      data fpp(23,22,1),fpp(23,22,2)/-3.93629870d-07,-7.59145322d-12/
      data fpp(23,23,1),fpp(23,23,2)/ 0.00000000d+00, 3.79572661d-12/
      data fpp(24, 1,1),fpp(24, 1,2)/ 0.00000000d+00,-3.79154652d-09/
      data fpp(24, 2,1),fpp(24, 2,2)/-2.41263704d-08,-1.61690696d-09/
      data fpp(24, 3,1),fpp(24, 3,2)/ 2.58773735d-06, 7.85917437d-09/
      data fpp(24, 4,1),fpp(24, 4,2)/-1.79039056d-06,-8.21979053d-09/
      data fpp(24, 5,1),fpp(24, 5,2)/ 4.59533517d-07, 5.81998775d-09/
      data fpp(24, 6,1),fpp(24, 6,2)/ 9.61550527d-07,-6.60160458d-10/
      data fpp(24, 7,1),fpp(24, 7,2)/ 7.32194031d-07,-7.79345915d-10/
      data fpp(24, 8,1),fpp(24, 8,2)/ 6.35093924d-07, 1.37754412d-09/
      data fpp(24, 9,1),fpp(24, 9,2)/-8.31600523d-08,-4.73083056d-09/
      data fpp(24,10,1),fpp(24,10,2)/ 8.30064170d-07, 1.50371962d-09/
      data fpp(24,11,1),fpp(24,11,2)/ 8.94042054d-08,-8.40479025d-11/
      data fpp(24,12,1),fpp(24,12,2)/ 4.78868076d-08, 6.32471995d-10/
      data fpp(24,13,1),fpp(24,13,2)/ 1.60813111d-08,-4.58400769d-11/
      data fpp(24,14,1),fpp(24,14,2)/-9.43681537d-07, 1.50888313d-10/
      data fpp(24,15,1),fpp(24,15,2)/-1.14600503d-07, 4.22868256d-11/
      data fpp(24,16,1),fpp(24,16,2)/-2.27365146d-07,-3.20035615d-10/
      data fpp(24,17,1),fpp(24,17,2)/ 8.87496145d-08, 3.78556359d-11/
      data fpp(24,18,1),fpp(24,18,2)/ 3.21001562d-07, 1.68613072d-10/
      data fpp(24,19,1),fpp(24,19,2)/ 7.64985376d-08,-1.12307923d-10/
      data fpp(24,20,1),fpp(24,20,2)/-1.63530085d-07, 2.80618618d-10/
      data fpp(24,21,1),fpp(24,21,2)/-1.52481687d-07,-4.10166551d-10/
      data fpp(24,22,1),fpp(24,22,2)/ 2.23070722d-07, 1.60047586d-10/
      data fpp(24,23,1),fpp(24,23,2)/ 0.00000000d+00, 3.69976207d-10/
      data fpp(25, 1,1),fpp(25, 1,2)/ 0.00000000d+00,-9.03240331d-10/
      data fpp(25, 2,1),fpp(25, 2,2)/-1.35525503d-07,-5.93519337d-10/
      data fpp(25, 3,1),fpp(25, 3,2)/-8.66855307d-07, 3.27731768d-09/
      data fpp(25, 4,1),fpp(25, 4,2)/ 3.11302352d-07,-5.31575138d-09/
      data fpp(25, 5,1),fpp(25, 5,2)/ 1.16256989d-08, 5.98568785d-09/
      data fpp(25, 6,1),fpp(25, 6,2)/-4.87937380d-07,-1.82700001d-09/
      data fpp(25, 7,1),fpp(25, 7,2)/-3.87250850d-07,-3.47768782d-09/
      data fpp(25, 8,1),fpp(25, 8,2)/ 3.05534006d-07, 3.73775127d-09/
      data fpp(25, 9,1),fpp(25, 9,2)/ 6.15117807d-07,-1.87331727d-09/
      data fpp(25,10,1),fpp(25,10,2)/-5.91340582d-08, 1.51076165d-10/
      data fpp(25,11,1),fpp(25,11,2)/ 2.43216565d-08, 6.90126076d-11/
      data fpp(25,12,1),fpp(25,12,2)/-6.28757717d-09, 7.72873405d-10/
      data fpp(25,13,1),fpp(25,13,2)/-2.17841999d-07,-1.96050623d-09/
      data fpp(25,14,1),fpp(25,14,2)/ 1.85950275d-06, 2.86915150d-09/
      data fpp(25,15,1),fpp(25,15,2)/ 1.22529787d-07,-1.71609979d-09/
      data fpp(25,16,1),fpp(25,16,2)/ 2.65240521d-07, 3.95247656d-10/
      data fpp(25,17,1),fpp(25,17,2)/-3.21412783d-08, 1.35109166d-10/
      data fpp(25,18,1),fpp(25,18,2)/-2.92400409d-07,-3.35684321d-10/
      data fpp(25,19,1),fpp(25,19,2)/-1.86944444d-07, 7.62811927d-12/
      data fpp(25,20,1),fpp(25,20,2)/ 1.08483746d-07, 3.05171844d-10/
      data fpp(25,21,1),fpp(25,21,2)/ 9.73952008d-08,-2.83154965d-11/
      data fpp(25,22,1),fpp(25,22,2)/-2.58653017d-07,-1.91909858d-10/
      data fpp(25,23,1),fpp(25,23,2)/ 0.00000000d+00,-4.04045071d-10/
      data fpp(26, 1,1),fpp(26, 1,2)/ 0.00000000d+00, 1.89349101d-09/
      data fpp(26, 2,1),fpp(26, 2,2)/ 8.62283821d-08, 1.01301799d-09/
      data fpp(26, 3,1),fpp(26, 3,2)/ 1.59683872d-07,-1.14556296d-09/
      data fpp(26, 4,1),fpp(26, 4,2)/ 6.51811456d-08, 1.16923384d-09/
      data fpp(26, 5,1),fpp(26, 5,2)/-2.60363130d-08,-1.13137239d-09/
      data fpp(26, 6,1),fpp(26, 6,2)/ 2.70198991d-07, 9.56255723d-10/
      data fpp(26, 7,1),fpp(26, 7,2)/ 3.36809367d-07,-2.93650500d-10/
      data fpp(26, 8,1),fpp(26, 8,2)/ 6.27700515d-08, 2.18346279d-10/
      data fpp(26, 9,1),fpp(26, 9,2)/ 2.26888251d-08,-5.79734614d-10/
      data fpp(26,10,1),fpp(26,10,2)/ 1.26472063d-07,-1.69969297d-10/
      data fpp(26,11,1),fpp(26,11,2)/ 5.33091685d-08, 6.59611800d-10/
      data fpp(26,12,1),fpp(26,12,2)/-2.27364989d-08,-1.26847791d-09/
      data fpp(26,13,1),fpp(26,13,2)/ 1.35286684d-07, 3.21429982d-09/
      data fpp(26,14,1),fpp(26,14,2)/-1.45432945d-06,-4.38872138d-09/
      data fpp(26,15,1),fpp(26,15,2)/-1.35518645d-07, 2.94058568d-09/
      data fpp(26,16,1),fpp(26,16,2)/-1.13596938d-07,-1.37362135d-09/
      data fpp(26,17,1),fpp(26,17,2)/ 3.98154986d-08, 7.53899732d-10/
      data fpp(26,18,1),fpp(26,18,2)/ 1.28600075d-07,-4.41977574d-10/
      data fpp(26,19,1),fpp(26,19,2)/ 1.91279240d-07, 4.14010566d-10/
      data fpp(26,20,1),fpp(26,20,2)/-3.04049007d-08,-1.40646877d-11/
      data fpp(26,21,1),fpp(26,21,2)/ 2.90088406d-09,-3.57751815d-10/
      data fpp(26,22,1),fpp(26,22,2)/ 9.15413452d-08, 2.45071947d-10/
      data fpp(26,23,1),fpp(26,23,2)/ 0.00000000d+00, 5.77464026d-10/
      data fpp(27, 1,1),fpp(27, 1,2)/ 0.00000000d+00,-2.42231227d-12/
      data fpp(27, 2,1),fpp(27, 2,2)/-1.09223949d-08, 4.84462455d-12/
      data fpp(27, 3,1),fpp(27, 3,2)/-4.56239635d-08,-1.69561859d-11/
      data fpp(27, 4,1),fpp(27, 4,2)/ 8.80538697d-09, 6.29801191d-11/
      data fpp(27, 5,1),fpp(27, 5,2)/ 1.22960894d-08,-2.34964291d-10/
      data fpp(27, 6,1),fpp(27, 6,2)/-2.66282831d-08, 8.76877043d-10/
      data fpp(27, 7,1),fpp(27, 7,2)/-3.68026763d-08,-8.72543883d-10/
      data fpp(27, 8,1),fpp(27, 8,2)/ 1.89228424d-08, 2.13298490d-10/
      data fpp(27, 9,1),fpp(27, 9,2)/ 4.43746214d-08, 1.93499242d-11/
      data fpp(27,10,1),fpp(27,10,2)/ 1.01508390d-08,-1.64699018d-10/
      data fpp(27,11,1),fpp(27,11,2)/ 7.91166613d-09, 3.94461459d-11/
      data fpp(27,12,1),fpp(27,12,2)/ 1.13532854d-08, 6.06914434d-10/
      data fpp(27,13,1),fpp(27,13,2)/ 3.06094743d-09,-2.46710388d-09/
      data fpp(27,14,1),fpp(27,14,2)/ 4.93236987d-07, 3.26150109d-09/
      data fpp(27,15,1),fpp(27,15,2)/ 1.05291041d-07,-9.78900494d-10/
      data fpp(27,16,1),fpp(27,16,2)/ 2.81705537d-08,-5.45899118d-10/
      data fpp(27,17,1),fpp(27,17,2)/ 1.66241432d-08, 1.62496967d-10/
      data fpp(27,18,1),fpp(27,18,2)/ 3.99978449d-10, 4.95911249d-10/
      data fpp(27,19,1),fpp(27,19,2)/-6.03654971d-08,-9.46141965d-10/
      data fpp(27,20,1),fpp(27,20,2)/ 3.69728288d-08, 8.88656609d-10/
      data fpp(27,21,1),fpp(27,21,2)/-5.74002526d-08,-8.08484472d-10/
      data fpp(27,22,1),fpp(27,22,2)/ 3.47024728d-08, 5.45281278d-10/
      data fpp(27,23,1),fpp(27,23,2)/ 0.00000000d+00, 1.02735936d-09/
      data fpp(28, 1,1),fpp(28, 1,2)/ 0.00000000d+00,-1.92921532d-09/
      data fpp(28, 2,1),fpp(28, 2,2)/-4.25388026d-08,-9.41569355d-10/
      data fpp(28, 3,1),fpp(28, 3,2)/ 2.28119818d-08, 8.95492743d-10/
      data fpp(28, 4,1),fpp(28, 4,2)/-1.00402693d-07,-2.40401618d-10/
      data fpp(28, 5,1),fpp(28, 5,2)/ 3.68519553d-08, 6.61137285d-11/
      data fpp(28, 6,1),fpp(28, 6,2)/-1.03685858d-07,-2.40532959d-11/
      data fpp(28, 7,1),fpp(28, 7,2)/-1.89598662d-07, 3.00994553d-11/
      data fpp(28, 8,1),fpp(28, 8,2)/-7.84614212d-08,-9.63445251d-11/
      data fpp(28, 9,1),fpp(28, 9,2)/-8.01873107d-08, 3.55278645d-10/
      data fpp(28,10,1),fpp(28,10,2)/-4.70754195d-08,-4.17663673d-10/
      data fpp(28,11,1),fpp(28,11,2)/-2.49558331d-08, 1.15376046d-10/
      data fpp(28,12,1),fpp(28,12,2)/ 3.73233573d-08, 5.56159488d-10/
      data fpp(28,13,1),fpp(28,13,2)/-2.75304737d-08,-5.40013998d-10/
      data fpp(28,14,1),fpp(28,14,2)/ 1.40138151d-06,-1.96103496d-10/
      data fpp(28,15,1),fpp(28,15,2)/ 2.54354479d-07, 1.24427982d-10/
      data fpp(28,16,1),fpp(28,16,2)/ 6.09147231d-08, 2.98391567d-10/
      data fpp(28,17,1),fpp(28,17,2)/ 1.36879284d-08,-1.17994250d-10/
      data fpp(28,18,1),fpp(28,18,2)/-1.01999892d-08,-4.26414568d-10/
      data fpp(28,19,1),fpp(28,19,2)/-1.89817251d-07, 1.22365252d-09/
      data fpp(28,20,1),fpp(28,20,2)/ 6.25135856d-08,-2.66819552d-09/
      data fpp(28,21,1),fpp(28,21,2)/-1.33299874d-07, 3.44912956d-09/
      data fpp(28,22,1),fpp(28,22,2)/ 6.96487636d-08,-1.52832273d-09/
      data fpp(28,23,1),fpp(28,23,2)/ 0.00000000d+00,-3.33583863d-09/
 
      data fpppp( 1, 1),fpppp( 1, 2)/-3.44389561d-03,-6.81797418d-03/
      data fpppp( 1, 3),fpppp( 1, 4)/ 2.90103477d-02,-7.23697321d-02/
      data fpppp( 1, 5),fpppp( 1, 6)/ 8.68579868d-02,-5.54048982d-02/
      data fpppp( 1, 7),fpppp( 1, 8)/ 3.99217664d-02,-3.17757824d-02/
      data fpppp( 1, 9),fpppp( 1,10)/ 8.04504873d-03,-8.54232302d-04/
      data fpppp( 1,11),fpppp( 1,12)/ 1.28170065d-05,-1.91640613d-04/
      data fpppp( 1,13),fpppp( 1,14)/-7.41148087d-05, 1.01416231d-04/
      data fpppp( 1,15),fpppp( 1,16)/-2.12073283d-05,-1.35656543d-05/
      data fpppp( 1,17),fpppp( 1,18)/ 6.10486818d-05,-7.97940893d-05/
      data fpppp( 1,19),fpppp( 1,20)/ 4.33984383d-05,-1.09347070d-05/
      data fpppp( 1,21),fpppp( 1,22)/ 3.77274306d-06,-1.35922396d-06/
      data fpppp( 1,23) /            -8.22786083d-07 /
      data fpppp( 2, 1),fpppp( 2, 2)/ 2.51626382d-04,-2.76804199d-03/
      data fpppp( 2, 3),fpppp( 2, 4)/ 8.39223070d-03,-3.00772903d-02/
      data fpppp( 2, 5),fpppp( 2, 6)/ 4.02495580d-02,-1.72230154d-02/
      data fpppp( 2, 7),fpppp( 2, 8)/ 9.47034265d-03,-1.33188856d-02/
      data fpppp( 2, 9),fpppp( 2,10)/ 3.76102849d-03,-2.43228039d-04/
      data fpppp( 2,11),fpppp( 2,12)/-1.62749385d-04,-3.80246443d-05/
      data fpppp( 2,13),fpppp( 2,14)/-4.32715314d-05, 6.45580032d-05/
      data fpppp( 2,15),fpppp( 2,16)/-6.62605291d-06,-1.16963182d-05/
      data fpppp( 2,17),fpppp( 2,18)/ 2.74738530d-05,-3.92090608d-05/
      data fpppp( 2,19),fpppp( 2,20)/ 2.41608643d-05,-5.78431029d-06/
      data fpppp( 2,21),fpppp( 2,22)/ 1.77167045d-06,-6.56453958d-07/
      data fpppp( 2,23) /            -2.31976896d-07 /
      data fpppp( 3, 1),fpppp( 3, 2)/ 1.00253542d-02,-1.75650604d-03/
      data fpppp( 3, 3),fpppp( 3, 4)/-6.00080200d-03,-3.66265728d-02/
      data fpppp( 3, 5),fpppp( 3, 6)/ 7.74801372d-02,-9.61323741d-03/
      data fpppp( 3, 7),fpppp( 3, 8)/-4.17819040d-02, 1.96252296d-02/
      data fpppp( 3, 9),fpppp( 3,10)/-6.00955748d-05,-3.19712937d-03/
      data fpppp( 3,11),fpppp( 3,12)/ 1.75764872d-03,-2.74459716d-04/
      data fpppp( 3,13),fpppp( 3,14)/ 1.23088374d-04,-1.68390984d-05/
      data fpppp( 3,15),fpppp( 3,16)/ 2.78275194d-05,-9.96213590d-06/
      data fpppp( 3,17),fpppp( 3,18)/-3.72078207d-05, 3.01183036d-05/
      data fpppp( 3,19),fpppp( 3,20)/-4.65005370d-06, 3.21660911d-06/
      data fpppp( 3,21),fpppp( 3,22)/-2.30991049d-06, 6.42321400d-07/
      data fpppp( 3,23) /             1.17205286d-06 /
      data fpppp( 4, 1),fpppp( 4, 2)/-1.47463832d-03, 9.88941677d-03/
      data fpppp( 4, 3),fpppp( 4, 4)/-4.21816299d-02, 1.27770180d-01/
      data fpppp( 4, 5),fpppp( 4, 6)/-1.78725812d-01, 1.04998907d-01/
      data fpppp( 4, 7),fpppp( 4, 8)/-2.02312707d-02, 1.86408056d-03/
      data fpppp( 4, 9),fpppp( 4,10)/-5.50135623d-03, 6.32613887d-03/
      data fpppp( 4,11),fpppp( 4,12)/-3.65782890d-03, 8.54283852d-04/
      data fpppp( 4,13),fpppp( 4,14)/-1.84859919d-04, 5.76498597d-05/
      data fpppp( 4,15),fpppp( 4,16)/-7.27194770d-06,-7.75491565d-06/
      data fpppp( 4,17),fpppp( 4,18)/ 6.98446259d-06,-1.15250749d-06/
      data fpppp( 4,19),fpppp( 4,20)/ 4.57325349d-08,-1.25930072d-06/
      data fpppp( 4,21),fpppp( 4,22)/ 8.90287735d-07,-1.44921993d-07/
      data fpppp( 4,23) /            -2.70189381d-07 /
      data fpppp( 5, 1),fpppp( 5, 2)/ 8.20084586d-03, 1.46229055d-02/
      data fpppp( 5, 3),fpppp( 5, 4)/-6.27564314d-02, 1.53169119d-01/
      data fpppp( 5, 5),fpppp( 5, 6)/-1.96730997d-01, 1.28510611d-01/
      data fpppp( 5, 7),fpppp( 5, 8)/-4.72177972d-02, 1.36431416d-02/
      data fpppp( 5, 9),fpppp( 5,10)/-5.66709192d-04,-1.48740379d-03/
      data fpppp( 5,11),fpppp( 5,12)/ 9.96887229d-04,-2.74419338d-04/
      data fpppp( 5,13),fpppp( 5,14)/ 1.03545551d-04,-1.81136909d-05/
      data fpppp( 5,15),fpppp( 5,16)/ 1.47942521d-06, 6.98533699d-07/
      data fpppp( 5,17),fpppp( 5,18)/ 2.78387567d-06,-1.04063025d-06/
      data fpppp( 5,19),fpppp( 5,20)/-1.59735548d-06, 1.25086652d-06/
      data fpppp( 5,21),fpppp( 5,22)/-4.67852341d-07,-1.06458604d-07/
      data fpppp( 5,23) /            -3.39382751d-07 /
      data fpppp( 6, 1),fpppp( 6, 2)/-1.66366261d-02,-1.26833567d-02/
      data fpppp( 6, 3),fpppp( 6, 4)/ 7.18352282d-02,-1.25624791d-01/
      data fpppp( 6, 5),fpppp( 6, 6)/ 1.38110780d-01,-1.30436584d-01/
      data fpppp( 6, 7),fpppp( 6, 8)/ 7.34132889d-02,-1.75760918d-02/
      data fpppp( 6, 9),fpppp( 6,10)/ 2.61818358d-03,-8.71729626d-05/
      data fpppp( 6,11),fpppp( 6,12)/-2.89136451d-05, 3.77264988d-07/
      data fpppp( 6,13),fpppp( 6,14)/ 2.28962822d-05,-3.69313182d-06/
      data fpppp( 6,15),fpppp( 6,16)/-1.12177266d-07, 1.64513138d-07/
      data fpppp( 6,17),fpppp( 6,18)/ 4.33152969d-06,-3.01468371d-06/
      data fpppp( 6,19),fpppp( 6,20)/ 6.51043201d-07,-7.23868435d-07/
      data fpppp( 6,21),fpppp( 6,22)/-7.41984716d-09, 6.46254004d-08/
      data fpppp( 6,23) /             3.20785888d-07 /
      data fpppp( 7, 1),fpppp( 7, 2)/ 1.40299664d-04,-4.24665099d-03/
      data fpppp( 7, 3),fpppp( 7, 4)/ 1.87076802d-02,-5.40324751d-02/
      data fpppp( 7, 5),fpppp( 7, 6)/ 7.07197207d-02,-3.66567165d-02/
      data fpppp( 7, 7),fpppp( 7, 8)/ 1.82435987d-03, 2.67559533d-03/
      data fpppp( 7, 9),fpppp( 7,10)/ 9.19712900d-04,-8.02471698d-04/
      data fpppp( 7,11),fpppp( 7,12)/ 2.01508201d-04,-4.28731703d-05/
      data fpppp( 7,13),fpppp( 7,14)/ 2.11016737d-05,-5.18589876d-06/
      data fpppp( 7,15),fpppp( 7,16)/ 2.08194800d-09, 2.42828239d-06/
      data fpppp( 7,17),fpppp( 7,18)/ 1.13855718d-07,-4.08252914d-07/
      data fpppp( 7,19),fpppp( 7,20)/-3.34357773d-07, 4.84148671d-08/
      data fpppp( 7,21),fpppp( 7,22)/-2.42879663d-07, 2.33717793d-08/
      data fpppp( 7,23) /             1.30324372d-07 /
      data fpppp( 8, 1),fpppp( 8, 2)/-1.20768053d-02,-3.24065375d-03/
      data fpppp( 8, 3),fpppp( 8, 4)/ 2.87858615d-02,-2.03538962d-02/
      data fpppp( 8, 5),fpppp( 8, 6)/ 6.97961839d-05,-3.51041585d-02/
      data fpppp( 8, 7),fpppp( 8, 8)/ 3.78561257d-02,-8.14089781d-03/
      data fpppp( 8, 9),fpppp( 8,10)/ 1.23222380d-03,-9.94330507d-05/
      data fpppp( 8,11),fpppp( 8,12)/ 5.50307385d-06, 7.81928209d-06/
      data fpppp( 8,13),fpppp( 8,14)/ 2.29932417d-06,-2.06344364d-07/
      data fpppp( 8,15),fpppp( 8,16)/-1.11616696d-06, 1.01549424d-06/
      data fpppp( 8,17),fpppp( 8,18)/ 7.40516098d-07,-9.53162190d-08/
      data fpppp( 8,19),fpppp( 8,20)/-1.79034417d-07,-5.35090208d-07/
      data fpppp( 8,21),fpppp( 8,22)/ 3.45557507d-07,-6.92893771d-08/
      data fpppp( 8,23) /            -1.13994947d-07 /
      data fpppp( 9, 1),fpppp( 9, 2)/ 5.45905346d-03, 9.97198219d-03/
      data fpppp( 9, 3),fpppp( 9, 4)/-4.73560028d-02, 1.11759210d-01/
      data fpppp( 9, 5),fpppp( 9, 6)/-1.46975390d-01, 1.11025781d-01/
      data fpppp( 9, 7),fpppp( 9, 8)/-4.70432175d-02, 1.14573446d-02/
      data fpppp( 9, 9),fpppp( 9,10)/-1.86364800d-03, 4.36599239d-04/
      data fpppp( 9,11),fpppp( 9,12)/-1.23021965d-04, 3.93965760d-05/
      data fpppp( 9,13),fpppp( 9,14)/-8.35963859d-06, 2.14341489d-06/
      data fpppp( 9,15),fpppp( 9,16)/-1.01530063d-06, 3.89148019d-07/
      data fpppp( 9,17),fpppp( 9,18)/ 5.34336857d-07, 3.49082541d-07/
      data fpppp( 9,19),fpppp( 9,20)/-7.08020527d-07, 2.96445092d-07/
      data fpppp( 9,21),fpppp( 9,22)/-1.18830901d-07,-1.42791261d-07/
      data fpppp( 9,23) /            -2.78556088d-07 /
      data fpppp(10, 1),fpppp(10, 2)/ 5.20261099d-03,-3.69377405d-03/
      data fpppp(10, 3),fpppp(10, 4)/ 8.45240632d-03,-5.30503922d-02/
      data fpppp(10, 5),fpppp(10, 6)/ 9.34867388d-02,-5.32806887d-02/
      data fpppp(10, 7),fpppp(10, 8)/ 9.11911079d-03,-2.97394203d-03/
      data fpppp(10, 9),fpppp(10,10)/ 4.39888120d-04,-1.29042848d-04/
      data fpppp(10,11),fpppp(10,12)/ 3.36706429d-05,-5.41006990d-06/
      data fpppp(10,13),fpppp(10,14)/ 2.38130898d-06,-7.71146376d-07/
      data fpppp(10,15),fpppp(10,16)/ 2.20615444d-07,-4.21239011d-07/
      data fpppp(10,17),fpppp(10,18)/ 7.65501269d-07,-4.75320423d-07/
      data fpppp(10,19),fpppp(10,20)/ 3.84977654d-07,-2.41828193d-07/
      data fpppp(10,21),fpppp(10,22)/-2.29542896d-07, 3.18828419d-07/
      data fpppp(10,23) /             7.14032299d-07 /
      data fpppp(11, 1),fpppp(11, 2)/-8.17917854d-04, 1.40454843d-04/
      data fpppp(11, 3),fpppp(11, 4)/-1.84596547d-03, 6.47438975d-03/
      data fpppp(11, 5),fpppp(11, 6)/-1.14150663d-02, 1.06965488d-02/
      data fpppp(11, 7),fpppp(11, 8)/-3.91054278d-03, 2.40477256d-04/
      data fpppp(11, 9),fpppp(11,10)/-1.68002082d-04, 1.65381310d-05/
      data fpppp(11,11),fpppp(11,12)/-3.57691017d-06, 3.04294087d-06/
      data fpppp(11,13),fpppp(11,14)/-4.66242642d-07, 9.24514629d-07/
      data fpppp(11,15),fpppp(11,16)/-1.57989189d-06, 1.14338699d-06/
      data fpppp(11,17),fpppp(11,18)/-5.53927053d-07, 5.14960674d-07/
      data fpppp(11,19),fpppp(11,20)/-1.75351050d-07,-1.08050001d-07/
      data fpppp(11,21),fpppp(11,22)/ 2.56134167d-07,-2.90131466d-07/
      data fpppp(11,23) /            -5.76268584d-07 /
      data fpppp(12, 1),fpppp(12, 2)/ 2.03227727d-03, 6.92400973d-04/
      data fpppp(12, 3),fpppp(12, 4)/-3.39730649d-03, 2.13739513d-03/
      data fpppp(12, 5),fpppp(12, 6)/ 1.70560535d-04, 2.11007411d-03/
      data fpppp(12, 7),fpppp(12, 8)/-1.81737662d-03, 3.26000979d-05/
      data fpppp(12, 9),fpppp(12,10)/-1.17231209d-04, 1.38310312d-05/
      data fpppp(12,11),fpppp(12,12)/-2.34441351d-06, 1.67324466d-06/
      data fpppp(12,13),fpppp(12,14)/-6.46799832d-08,-5.68484079d-07/
      data fpppp(12,15),fpppp(12,16)/ 8.03581456d-07,-7.19254325d-07/
      data fpppp(12,17),fpppp(12,18)/ 4.83359105d-07,-1.60185545d-07/
      data fpppp(12,19),fpppp(12,20)/-9.40725228d-08, 1.71687741d-07/
      data fpppp(12,21),fpppp(12,22)/-1.75132880d-07, 1.24594332d-07/
      data fpppp(12,23) /             2.39593593d-07 /
      data fpppp(13, 1),fpppp(13, 2)/-2.98039521d-04,-3.32478765d-04/
      data fpppp(13, 3),fpppp(13, 4)/ 5.27574972d-04,-1.74309673d-03/
      data fpppp(13, 5),fpppp(13, 6)/ 2.77607853d-03,-1.14158436d-03/
      data fpppp(13, 7),fpppp(13, 8)/ 1.46826940d-04,-2.07119107d-04/
      data fpppp(13, 9),fpppp(13,10)/-1.93684924d-05,-3.18015265d-06/
      data fpppp(13,11),fpppp(13,12)/ 1.52507504d-06,-1.77841043d-07/
      data fpppp(13,13),fpppp(13,14)/-5.24018201d-08, 5.65656205d-07/
      data fpppp(13,15),fpppp(13,16)/-6.34722848d-07, 2.45721086d-07/
      data fpppp(13,17),fpppp(13,18)/-1.54391707d-07, 7.00976047d-08/
      data fpppp(13,19),fpppp(13,20)/ 1.85143552d-07,-2.58383144d-07/
      data fpppp(13,21),fpppp(13,22)/ 2.10848415d-07,-9.50824905d-08/
      data fpppp(13,23) /            -1.79538406d-07 /
      data fpppp(14, 1),fpppp(14, 2)/ 2.33933103d-05,-3.00975723d-05/
      data fpppp(14, 3),fpppp(14, 4)/ 3.29140745d-04,-7.56173138d-04/
      data fpppp(14, 5),fpppp(14, 6)/ 3.72610870d-04, 2.35406158d-04/
      data fpppp(14, 7),fpppp(14, 8)/-1.10788013d-04,-2.36790113d-05/
      data fpppp(14, 9),fpppp(14,10)/-1.83765861d-05, 1.63254482d-06/
      data fpppp(14,11),fpppp(14,12)/-2.85983179d-07, 1.75540168d-07/
      data fpppp(14,13),fpppp(14,14)/ 1.74701151d-07,-6.33216947d-07/
      data fpppp(14,15),fpppp(14,16)/ 7.11200875d-07,-4.28117562d-07/
      data fpppp(14,17),fpppp(14,18)/ 1.36266960d-07, 7.60457231d-08/
      data fpppp(14,19),fpppp(14,20)/-2.73563310d-07, 3.73840735d-07/
      data fpppp(14,21),fpppp(14,22)/-3.69182754d-07, 1.87427622d-07/
      data fpppp(14,23) /             3.72714036d-07 /
      data fpppp(15, 1),fpppp(15, 2)/ 5.04268518d-05, 7.43776578d-06/
      data fpppp(15, 3),fpppp(15, 4)/-1.06207333d-04, 2.74436132d-05/
      data fpppp(15, 5),fpppp(15, 6)/ 1.17077669d-04,-1.93063338d-05/
      data fpppp(15, 7),fpppp(15, 8)/ 3.49815797d-06,-2.63482143d-05/
      data fpppp(15, 9),fpppp(15,10)/-7.53510955d-06,-1.69193584d-07/
      data fpppp(15,11),fpppp(15,12)/ 3.29875898d-07,-3.64531067d-07/
      data fpppp(15,13),fpppp(15,14)/ 9.18915868d-08, 5.64013783d-07/
      data fpppp(15,15),fpppp(15,16)/-8.26368128d-07, 5.85384933d-07/
      data fpppp(15,17),fpppp(15,18)/-2.70814215d-07,-1.04485870d-07/
      data fpppp(15,19),fpppp(15,20)/ 2.57611587d-07,-3.02559574d-07/
      data fpppp(15,21),fpppp(15,22)/ 4.05853235d-07,-2.08432114d-07/
      data fpppp(15,23) /            -4.44803703d-07 /
      data fpppp(16, 1),fpppp(16, 2)/ 1.00181539d-05,-6.31233941d-07/
      data fpppp(16, 3),fpppp(16, 4)/ 5.96068850d-06,-4.77919752d-05/
      data fpppp(16, 5),fpppp(16, 6)/ 2.90089940d-05, 3.45676765d-05/
      data fpppp(16, 7),fpppp(16, 8)/-8.00915677d-06,-8.05847886d-06/
      data fpppp(16, 9),fpppp(16,10)/-4.47704842d-06, 2.41621358d-07/
      data fpppp(16,11),fpppp(16,12)/-4.39015050d-07, 4.97170805d-07/
      data fpppp(16,13),fpppp(16,14)/-2.45119678d-07,-4.60161652d-08/
      data fpppp(16,15),fpppp(16,16)/ 3.09835744d-07,-3.82500624d-07/
      data fpppp(16,17),fpppp(16,18)/ 1.67739602d-07, 3.79774079d-08/
      data fpppp(16,19),fpppp(16,20)/-1.11951342d-07, 1.80591125d-07/
      data fpppp(16,21),fpppp(16,22)/-1.75936147d-07, 4.89311069d-08/
      data fpppp(16,23) /             1.07685639d-07 /
      data fpppp(17, 1),fpppp(17, 2)/ 1.30473259d-06,-5.00691219d-07/
      data fpppp(17, 3),fpppp(17, 4)/-5.99537772d-06, 1.42235521d-06/
      data fpppp(17, 5),fpppp(17, 6)/ 4.61682510d-06, 3.13278248d-06/
      data fpppp(17, 7),fpppp(17, 8)/ 1.52990638d-06,-2.83969900d-06/
      data fpppp(17, 9),fpppp(17,10)/-1.03083584d-06,-2.66012306d-07/
      data fpppp(17,11),fpppp(17,12)/ 3.14817175d-07,-3.06215573d-07/
      data fpppp(17,13),fpppp(17,14)/ 1.92454662d-07,-3.72222058d-08/
      data fpppp(17,15),fpppp(17,16)/-1.60122914d-07, 2.12342438d-07/
      data fpppp(17,17),fpppp(17,18)/-1.10727936d-07,-1.59761386d-08/
      data fpppp(17,19),fpppp(17,20)/ 1.69736922d-07,-2.54449375d-07/
      data fpppp(17,21),fpppp(17,22)/ 1.24319515d-07, 1.62983345d-08/
      data fpppp(17,23) /             4.73600311d-08 /
      data fpppp(18, 1),fpppp(18, 2)/ 8.69819609d-07, 1.80191037d-07/
      data fpppp(18, 3),fpppp(18, 4)/ 1.16914960d-06,-3.71694682d-06/
      data fpppp(18, 5),fpppp(18, 6)/ 1.33829886d-08, 3.48198510d-06/
      data fpppp(18, 7),fpppp(18, 8)/ 2.36687797d-07,-2.32142810d-07/
      data fpppp(18, 9),fpppp(18,10)/-9.09094018d-07, 5.55941251d-08/
      data fpppp(18,11),fpppp(18,12)/-3.43288438d-09, 1.07242162d-07/
      data fpppp(18,13),fpppp(18,14)/-5.97224296d-08,-4.45518424d-08/
      data fpppp(18,15),fpppp(18,16)/ 2.63506698d-07,-3.58815436d-07/
      data fpppp(18,17),fpppp(18,18)/ 1.90106583d-07, 1.81356820d-08/
      data fpppp(18,19),fpppp(18,20)/-2.90764934d-07, 4.60072180d-07/
      data fpppp(18,21),fpppp(18,22)/-2.49036554d-07, 1.37883094d-08/
      data fpppp(18,23) /            -1.08214057d-09 /
      data fpppp(19, 1),fpppp(19, 2)/-7.20014749d-08,-5.83092542d-08/
      data fpppp(19, 3),fpppp(19, 4)/-1.53331329d-06, 2.20211958d-06/
      data fpppp(19, 5),fpppp(19, 6)/-6.35193919d-07, 6.72147778d-07/
      data fpppp(19, 7),fpppp(19, 8)/-1.00024530d-06, 3.26802508d-07/
      data fpppp(19, 9),fpppp(19,10)/-1.24892107d-08, 7.04170513d-08/
      data fpppp(19,11),fpppp(19,12)/-2.83251483d-08,-1.13201437d-07/
      data fpppp(19,13),fpppp(19,14)/ 8.84499148d-08, 3.08274709d-08/
      data fpppp(19,15),fpppp(19,16)/-3.44808680d-07, 6.23166810d-07/
      data fpppp(19,17),fpppp(19,18)/-4.17394611d-07, 7.49690270d-09/
      data fpppp(19,19),fpppp(19,20)/ 3.25328463d-07,-5.67334658d-07/
      data fpppp(19,21),fpppp(19,22)/ 4.27185603d-07,-8.86696506d-08/
      data fpppp(19,23) /            -1.72989043d-07 /
      data fpppp(20, 1),fpppp(20, 2)/ 3.36551456d-07, 1.63156505d-08/
      data fpppp(20, 3),fpppp(20, 4)/ 5.92659719d-07,-1.96902577d-06/
      data fpppp(20, 5),fpppp(20, 6)/ 1.60881368d-06,-5.78765914d-07/
      data fpppp(20, 7),fpppp(20, 8)/ 1.75563119d-06,-1.51222873d-06/
      data fpppp(20, 9),fpppp(20,10)/-3.23640926d-07, 3.99393782d-07/
      data fpppp(20,11),fpppp(20,12)/-2.87199186d-07, 2.34638127d-07/
      data fpppp(20,13),fpppp(20,14)/-1.66442731d-07, 1.51629425d-07/
      data fpppp(20,15),fpppp(20,16)/ 6.65436612d-08,-3.27501826d-07/
      data fpppp(20,17),fpppp(20,18)/ 2.53256309d-07,-9.61105713d-09/
      data fpppp(20,19),fpppp(20,20)/-2.08382309d-07, 3.62087773d-07/
      data fpppp(20,21),fpppp(20,22)/-2.53157753d-07, 2.18765485d-08/
      data fpppp(20,23) /             4.25451847d-08 /
      data fpppp(21, 1),fpppp(21, 2)/-6.27438421d-07,-2.94976895d-07/
      data fpppp(21, 3),fpppp(21, 4)/ 8.38134600d-07,-8.31028797d-07/
      data fpppp(21, 5),fpppp(21, 6)/ 5.74765467d-07,-8.57101977d-09/
      data fpppp(21, 7),fpppp(21, 8)/-8.20520055d-07, 5.33571405d-07/
      data fpppp(21, 9),fpppp(21,10)/ 1.19666222d-07,-1.71206953d-07/
      data fpppp(21,11),fpppp(21,12)/ 1.55475634d-07,-9.07561517d-08/
      data fpppp(21,13),fpppp(21,14)/ 9.29676536d-08,-1.30387013d-07/
      data fpppp(21,15),fpppp(21,16)/ 6.85508911d-08, 1.86695975d-08/
      data fpppp(21,17),fpppp(21,18)/-3.61807981d-08,-1.43777551d-08/
      data fpppp(21,19),fpppp(21,20)/ 1.13644940d-07,-1.51011001d-07/
      data fpppp(21,21),fpppp(21,22)/ 5.22453387d-08, 3.57598725d-08/
      data fpppp(21,23) /             8.20577794d-08 /
      data fpppp(22, 1),fpppp(22, 2)/ 7.99964950d-07, 4.37150919d-07/
      data fpppp(22, 3),fpppp(22, 4)/-1.46457641d-06, 2.01989280d-06/
      data fpppp(22, 5),fpppp(22, 6)/-1.45272861d-06, 4.17065232d-07/
      data fpppp(22, 7),fpppp(22, 8)/ 2.04562679d-07,-2.48378559d-07/
      data fpppp(22, 9),fpppp(22,10)/ 2.81246168d-08, 9.53713510d-10/
      data fpppp(22,11),fpppp(22,12)/-1.37854190d-08, 2.24406846d-08/
      data fpppp(22,13),fpppp(22,14)/-2.42634534d-08, 4.79873129d-08/
      data fpppp(22,15),fpppp(22,16)/-3.47625544d-08, 1.13258822d-08/
      data fpppp(22,17),fpppp(22,18)/-3.77171900d-09, 9.19390251d-09/
      data fpppp(22,19),fpppp(22,20)/-4.31117434d-08, 5.44733673d-08/
      data fpppp(22,21),fpppp(22,22)/-7.97642447d-09,-2.21043804d-08/
      data fpppp(22,23) /            -5.00385752d-08 /
      data fpppp(23, 1),fpppp(23, 2)/-7.88579525d-07,-3.94110492d-07/
      data fpppp(23, 3),fpppp(23, 4)/ 1.30226403d-06,-1.55803067d-06/
      data fpppp(23, 5),fpppp(23, 6)/ 9.95208969d-07,-2.36041685d-07/
      data fpppp(23, 7),fpppp(23, 8)/-1.26583568d-07, 1.27706224d-07/
      data fpppp(23, 9),fpppp(23,10)/-9.91653628d-08, 6.41124227d-08/
      data fpppp(23,11),fpppp(23,12)/-2.18145780d-08, 6.19557044d-09/
      data fpppp(23,13),fpppp(23,14)/ 5.55815125d-09,-1.50523611d-08/
      data fpppp(23,15),fpppp(23,16)/ 1.25878241d-08,-8.43699441d-09/
      data fpppp(23,17),fpppp(23,18)/ 2.23464863d-09, 2.99811489d-09/
      data fpppp(23,19),fpppp(23,20)/ 6.25117949d-09,-1.16750229d-08/
      data fpppp(23,21),fpppp(23,22)/-1.41856843d-09, 8.16591422d-09/
      data fpppp(23,23) /             1.79423888d-08 /
      data fpppp(24, 1),fpppp(24, 2)/ 4.41064653d-07, 2.04268044d-07/
      data fpppp(24, 3),fpppp(24, 4)/-6.25499205d-07, 6.20130785d-07/
      data fpppp(24, 5),fpppp(24, 6)/-2.64291459d-07, 1.75373578d-08/
      data fpppp(24, 7),fpppp(24, 8)/ 1.86123869d-08,-6.02453722d-08/
      data fpppp(24, 9),fpppp(24,10)/ 7.32921733d-08,-4.87699035d-08/
      data fpppp(24,11),fpppp(24,12)/ 2.25543895d-08, 5.00899302d-10/
      data fpppp(24,13),fpppp(24,14)/-2.39752727d-08, 3.97227503d-08/
      data fpppp(24,15),fpppp(24,16)/-2.75850957d-08, 1.41068919d-08/
      data fpppp(24,17),fpppp(24,18)/-3.10970776d-09,-6.69982968d-09/
      data fpppp(24,19),fpppp(24,20)/ 1.30372810d-09, 1.75338141d-09/
      data fpppp(24,21),fpppp(24,22)/ 6.74736746d-09,-6.87261055d-09/
      data fpppp(24,23) /            -1.51743131d-08 /
      data fpppp(25, 1),fpppp(25, 2)/-1.12160035d-07,-4.75997867d-08/
      data fpppp(25, 3),fpppp(25, 4)/ 1.59566150d-07,-1.32387821d-07/
      data fpppp(25, 5),fpppp(25, 6)/ 1.53049011d-08, 2.31954751d-08/
      data fpppp(25, 7),fpppp(25, 8)/ 3.59731044d-08,-2.49842947d-08/
      data fpppp(25, 9),fpppp(25,10)/-2.80041788d-08, 1.88995156d-08/
      data fpppp(25,11),fpppp(25,12)/-2.13142906d-09,-1.72176963d-08/
      data fpppp(25,13),fpppp(25,14)/ 6.01455031d-08,-8.60303659d-08/
      data fpppp(25,15),fpppp(25,16)/ 5.51168983d-08,-2.16562054d-08/
      data fpppp(25,17),fpppp(25,18)/ 5.10237140d-09, 3.47407989d-09/
      data fpppp(25,19),fpppp(25,20)/ 2.94421480d-09,-3.85260555d-09/
      data fpppp(25,21),fpppp(25,22)/-5.92479678d-09, 6.85421236d-09/
      data fpppp(25,23) /             1.53900214d-08 /
      data fpppp(26, 1),fpppp(26, 2)/ 5.37769162d-09, 1.26695718d-10/
      data fpppp(26, 3),fpppp(26, 4)/-8.94996856d-09,-4.63679353d-09/
      data fpppp(26, 5),fpppp(26, 6)/ 2.82856070d-08,-1.55169715d-08/
      data fpppp(26, 7),fpppp(26, 8)/-2.13277035d-08, 1.90718596d-08/
      data fpppp(26, 9),fpppp(26,10)/ 1.19020633d-09,-2.06980735d-09/
      data fpppp(26,11),fpppp(26,12)/-3.52774493d-09, 1.60078207d-08/
      data fpppp(26,13),fpppp(26,14)/-4.64594069d-08, 6.49714477d-08/
      data fpppp(26,15),fpppp(26,16)/-3.89207672d-08, 1.28982750d-08/
      data fpppp(26,17),fpppp(26,18)/-4.78288902d-09, 2.35560946d-09/
      data fpppp(26,19),fpppp(26,20)/-6.20587358d-09, 5.40608659d-09/
      data fpppp(26,21),fpppp(26,22)/-1.19077274d-10,-1.60969691d-09/
      data fpppp(26,23) /            -4.25304347d-09 /
      data fpppp(27, 1),fpppp(27, 2)/-4.98931320d-09,-1.90768188d-09/
      data fpppp(27, 3),fpppp(27, 4)/ 6.91303901d-09,-4.35305360d-09/
      data fpppp(27, 5),fpppp(27, 6)/-1.72610016d-09, 1.07783624d-09/
      data fpppp(27, 7),fpppp(27, 8)/ 4.31475025d-09,-2.52085839d-09/
      data fpppp(27, 9),fpppp(27,10)/-1.49701422d-09, 6.43831424d-10/
      data fpppp(27,11),fpppp(27,12)/ 8.40765086d-10,-3.66604424d-09/
      data fpppp(27,13),fpppp(27,14)/ 1.31193744d-08,-1.89033508d-08/
      data fpppp(27,15),fpppp(27,16)/ 9.80670976d-09,-1.67396077d-09/
      data fpppp(27,17),fpppp(27,18)/ 8.23577968d-10,-1.90101636d-09/
      data fpppp(27,19),fpppp(27,20)/ 4.10800882d-09,-5.04479084d-09/
      data fpppp(27,21),fpppp(27,22)/ 4.56847009d-09,-2.04054113d-09/
      data fpppp(27,23) /            -4.01461746d-09 /
      data fpppp(28, 1),fpppp(28, 2)/ 1.43942830d-08, 7.87458809d-09/
      data fpppp(28, 3),fpppp(28, 4)/-1.99991345d-08, 2.68662398d-08/
      data fpppp(28, 5),fpppp(28, 6)/-2.49531869d-08, 6.27631662d-09/
      data fpppp(28, 7),fpppp(28, 8)/ 1.29579228d-08,-1.08159974d-08/
      data fpppp(28, 9),fpppp(28,10)/ 3.21891563d-09,-2.05492796d-09/
      data fpppp(28,11),fpppp(28,12)/ 4.34125792d-09,-1.29005275d-08/
      data fpppp(28,13),fpppp(28,14)/ 3.96328707d-08,-5.60050068d-08/
      data fpppp(28,15),fpppp(28,16)/ 2.98308161d-08,-6.10302120d-09/
      data fpppp(28,17),fpppp(28,18)/ 3.35404643d-09,-5.91283188d-09/
      data fpppp(28,19),fpppp(28,20)/ 1.09535204d-08,-1.19843638d-08/
      data fpppp(28,21),fpppp(28,22)/ 1.00952771d-08,-4.47101861d-09/
      data fpppp(28,23) /            -8.56704669d-09 /
 
      c(1,1)=fpppp(ix+1,iy+1)
      c(1,2)=fpppp(ix+1,iy  )
      c(2,1)=fpppp(ix  ,iy+1)
      c(2,2)=fpppp(ix,  iy  )
      c(1,3)=fpp(ix+1,iy+1,1)
      c(1,4)=fpp(ix+1,iy  ,1)
      c(2,3)=fpp(ix,  iy+1,1)
      c(2,4)=fpp(ix,  iy,  1)
      c(3,1)=fpp(ix+1,iy+1,2)
      c(3,2)=fpp(ix+1,iy  ,2)
      c(4,1)=fpp(ix,  iy+1,2)
      c(4,2)=fpp(ix,  iy,  2)
      c(3,3)=f(ix+1,iy+1)
      c(3,4)=f(ix+1,iy  )
      c(4,3)=f(ix,  iy+1)
      c(4,4)=f(ix,  iy  )
      px(1)=((xi-xix)**3/(6.0*delxi))-(xi-xix)*delxi/6.0
      px(2)=(xi-xixp1)*delxi/6.0-((xi-xixp1)**3/(6.0*delxi))
      px(3)=(xi-xix)/delxi
      px(4)=(xixp1-xi)/delxi
      py(1)=((yi-yiy)**3/(6.0*delyi))-(yi-yiy)*delyi/6.0
      py(2)=(yi-yiyp1)*delyi/6.0-((yi-yiyp1)**3/(6.0*delyi))
      py(3)=(yi-yiy)/delyi
      py(4)=(yiyp1-yi)/delyi

      fi=0.0d 00
      do l=1,4
        sum=0.0d 00
        do i=1,4
          sum=sum + c(i,l) * px(i)
        enddo
        fi = fi + sum * py(l)
      enddo
      return
      end  
      subroutine c8_spl(xi,yi,ix,iy,delxi,delyi,xix,xixp1,
     x                    yiy,yiyp1,fi)
      implicit real*8 (a-h,o-z)
      dimension fpp(28,23,2),f(28,23),fpppp(28,23)
      dimension c(4,4),px(4),py(4)
 
      data f( 3, 9),f( 3,10) / -1.75195000d-03 , -8.63690000d-04 /
      data f( 3,11),f( 3,12) / -3.55880000d-04 , -2.19900000d-05 /
      data f( 3,13),f( 3,14) /  5.66000000d-06 ,  1.08000000d-06 /
      data f( 3,15),f( 3,16) /  1.22350000d-04 ,  3.46560000d-04 /
      data f( 3,17),f( 3,18) /  4.40560000d-04 ,  2.59620000d-04 /
      data f( 3,19),f( 3,20) /  6.93300000d-05 ,  7.92000000d-06 /
      data f( 3,21),f( 3,22) /  2.30000000d-07 ,  2.00000000d-08 /
      data f( 3,23) /           0.00000000d+00 /
      data f( 4, 1),f( 4, 2) /  0.00000000d+00 ,  1.24000000d-06 /
      data f( 4, 3),f( 4, 4) /  3.85120000d-04 ,  7.97653000d-03 /
      data f( 4, 5),f( 4, 6) /  2.23026600d-02 ,  1.36003500d-02 /
      data f( 4, 7),f( 4, 8) /  2.49865000d-03 ,  2.38200000d-05 /
      data f( 4, 9),f( 4,10) / -4.44590000d-04 , -1.15014000d-03 /
      data f( 4,11),f( 4,12) / -2.49080000d-04 , -4.31000000d-06 /
      data f( 4,13),f( 4,14) /  4.27000000d-06 , -7.08000000d-06 /
      data f( 4,15),f( 4,16) /  6.43800000d-05 ,  2.07420000d-04 /
      data f( 4,17),f( 4,18) /  2.79440000d-04 ,  1.65580000d-04 /
      data f( 4,19),f( 4,20) /  4.41600000d-05 ,  5.15000000d-06 /
      data f( 4,21),f( 4,22) /  1.10000000d-07 ,  1.00000000d-08 /
      data f( 4,23) /           0.00000000d+00 /
      data f( 5, 1),f( 5, 2) /  0.00000000d+00 ,  1.90000000d-06 /
      data f( 5, 3),f( 5, 4) /  6.40460000d-04 ,  1.29407800d-02 /
      data f( 5, 5),f( 5, 6) /  2.66573800d-02 ,  2.14562400d-02 /
      data f( 5, 7),f( 5, 8) /  4.75560000d-03 ,  1.43380000d-04 /
      data f( 5, 9),f( 5,10) / -4.01970000d-04 , -8.58790000d-04 /
      data f( 5,11),f( 5,12) / -1.73540000d-04 ,  2.91000000d-06 /
      data f( 5,13),f( 5,14) /  3.74000000d-06 , -1.13300000d-05 /
      data f( 5,15),f( 5,16) /  2.61900000d-05 ,  1.16220000d-04 /
      data f( 5,17),f( 5,18) /  1.69240000d-04 ,  1.02100000d-04 /
      data f( 5,19),f( 5,20) /  2.72000000d-05 ,  3.06000000d-06 /
      data f( 5,21),f( 5,22) /  4.00000000d-08 ,  2.00000000d-08 /
      data f( 5,23) /           0.00000000d+00 /
      data f( 6, 1),f( 6, 2) /  0.00000000d+00 ,  2.55000000d-06 /
      data f( 6, 3),f( 6, 4) /  7.58620000d-04 ,  1.80246400d-02 /
      data f( 6, 5),f( 6, 6) /  2.66403100d-02 ,  2.85348000d-02 /
      data f( 6, 7),f( 6, 8) /  5.67643000d-03 ,  2.55770000d-04 /
      data f( 6, 9),f( 6,10) / -3.50570000d-04 , -6.33040000d-04 /
      data f( 6,11),f( 6,12) / -1.19540000d-04 ,  5.32000000d-06 /
      data f( 6,13),f( 6,14) /  3.48000000d-06 , -1.25500000d-05 /
      data f( 6,15),f( 6,16) /  3.74000000d-06 ,  5.79100000d-05 /
      data f( 6,17),f( 6,18) /  9.65300000d-05 ,  6.02100000d-05 /
      data f( 6,19),f( 6,20) /  1.57900000d-05 ,  1.45000000d-06 /
      data f( 6,21),f( 6,22) /  3.00000000d-08 ,  2.00000000d-08 /
      data f( 6,23) /           0.00000000d+00 /
      data f( 7, 1),f( 7, 2) /  0.00000000d+00 ,  4.33000000d-06 /
      data f( 7, 3),f( 7, 4) /  9.66290000d-04 ,  2.17283200d-02 /
      data f( 7, 5),f( 7, 6) /  2.53364700d-02 ,  3.06679500d-02 /
      data f( 7, 7),f( 7, 8) /  5.83346000d-03 , -3.89800000d-05 /
      data f( 7, 9),f( 7,10) / -5.68680000d-04 , -3.65920000d-04 /
      data f( 7,11),f( 7,12) / -5.65100000d-05 ,  5.43000000d-06 /
      data f( 7,13),f( 7,14) /  3.72000000d-06 , -1.12400000d-05 /
      data f( 7,15),f( 7,16) / -1.42800000d-05 ,  5.90000000d-07 /
      data f( 7,17),f( 7,18) /  2.15000000d-05 ,  1.54800000d-05 /
      data f( 7,19),f( 7,20) /  3.58000000d-06 ,  1.10000000d-07 /
      data f( 7,21),f( 7,22) /  7.00000000d-08 ,  2.00000000d-08 /
      data f( 7,23) /           0.00000000d+00 /
      data f( 8, 1),f( 8, 2) /  0.00000000d+00 ,  1.14000000d-06 /
      data f( 8, 3),f( 8, 4) /  7.67390000d-04 ,  1.89554000d-02 /
      data f( 8, 5),f( 8, 6) /  3.10406900d-02 ,  2.80992900d-02 /
      data f( 8, 7),f( 8, 8) /  4.68139000d-03 ,  3.84320000d-04 /
      data f( 8, 9),f( 8,10) / -4.32230000d-04 , -2.11030000d-04 /
      data f( 8,11),f( 8,12) / -2.59300000d-05 ,  4.03000000d-06 /
      data f( 8,13),f( 8,14) /  3.75000000d-06 , -6.83000000d-06 /
      data f( 8,15),f( 8,16) / -1.67600000d-05 , -1.64000000d-05 /
      data f( 8,17),f( 8,18) / -5.66000000d-06 , -1.56000000d-06 /
      data f( 8,19),f( 8,20) / -1.03000000d-06 , -3.20000000d-07 /
      data f( 8,21),f( 8,22) / -4.00000000d-08 ,  1.00000000d-08 /
      data f( 8,23) /           0.00000000d+00 /
      data f( 9, 1),f( 9, 2) /  0.00000000d+00 ,  1.89000000d-06 /
      data f( 9, 3),f( 9, 4) /  4.39280000d-04 ,  9.03243000d-03 /
      data f( 9, 5),f( 9, 6) /  2.61102600d-02 ,  1.53720700d-02 /
      data f( 9, 7),f( 9, 8) /  3.35072000d-03 ,  3.86030000d-04 /
      data f( 9, 9),f( 9,10) / -2.11270000d-04 , -1.16910000d-04 /
      data f( 9,11),f( 9,12) / -1.15200000d-05 ,  2.98000000d-06 /
      data f( 9,13),f( 9,14) /  3.47000000d-06 , -4.12000000d-06 /
      data f( 9,15),f( 9,16) / -1.33500000d-05 , -1.79700000d-05 /
      data f( 9,17),f( 9,18) / -1.28900000d-05 , -6.76000000d-06 /
      data f( 9,19),f( 9,20) / -2.48000000d-06 , -4.60000000d-07 /
      data f( 9,21),f( 9,22) /  0.00000000d+00 ,  0.00000000d+00 /
      data f( 9,23) /           0.00000000d+00 /
      data f(10, 1),f(10, 2) /  0.00000000d+00 ,  9.20000000d-07 /
      data f(10, 3),f(10, 4) /  1.99950000d-04 ,  3.48506000d-03 /
      data f(10, 5),f(10, 6) /  9.90912000d-03 ,  6.94114000d-03 /
      data f(10, 7),f(10, 8) /  2.06148000d-03 ,  2.83600000d-04 /
      data f(10, 9),f(10,10) / -1.11440000d-04 , -6.05900000d-05 /
      data f(10,11),f(10,12) / -5.52000000d-06 ,  1.78000000d-06 /
      data f(10,13),f(10,14) /  2.78000000d-06 , -1.56000000d-06 /
      data f(10,15),f(10,16) / -9.57000000d-06 , -1.43100000d-05 /
      data f(10,17),f(10,18) / -1.25200000d-05 , -7.13000000d-06 /
      data f(10,19),f(10,20) / -2.56000000d-06 , -4.60000000d-07 /
      data f(10,21),f(10,22) / -2.00000000d-08 ,  9.00000000d-08 /
      data f(10,23) /           0.00000000d+00 /
      data f(11, 1),f(11, 2) /  0.00000000d+00 ,  4.20000000d-07 /
      data f(11, 3),f(11, 4) /  9.41800000d-05 ,  1.63159000d-03 /
      data f(11, 5),f(11, 6) /  4.65329000d-03 ,  3.38784000d-03 /
      data f(11, 7),f(11, 8) /  1.11547000d-03 ,  1.75130000d-04 /
      data f(11, 9),f(11,10) / -5.48100000d-05 , -2.91200000d-05 /
      data f(11,11),f(11,12) / -2.12000000d-06 ,  1.01000000d-06 /
      data f(11,13),f(11,14) /  2.07000000d-06 , -4.10000000d-07 /
      data f(11,15),f(11,16) / -6.44000000d-06 , -1.04800000d-05 /
      data f(11,17),f(11,18) / -1.00300000d-05 , -6.05000000d-06 /
      data f(11,19),f(11,20) / -2.14000000d-06 , -3.60000000d-07 /
      data f(11,21),f(11,22) /  3.00000000d-08 ,  0.00000000d+00 /
      data f(11,23) /           0.00000000d+00 /
      data f(12, 1),f(12, 2) /  0.00000000d+00 ,  1.30000000d-07 /
      data f(12, 3),f(12, 4) /  1.48890000d-04 ,  1.00046000d-03 /
      data f(12, 5),f(12, 6) /  2.69354000d-03 ,  1.55857000d-03 /
      data f(12, 7),f(12, 8) /  5.60220000d-04 ,  1.00990000d-04 /
      data f(12, 9),f(12,10) / -2.20200000d-05 , -1.31200000d-05 /
      data f(12,11),f(12,12) / -1.17000000d-06 ,  4.80000000d-07 /
      data f(12,13),f(12,14) /  1.35000000d-06 , -2.40000000d-07 /
      data f(12,15),f(12,16) / -3.05000000d-06 , -7.02000000d-06 /
      data f(12,17),f(12,18) / -7.26000000d-06 , -4.44000000d-06 /
      data f(12,19),f(12,20) / -1.59000000d-06 , -3.00000000d-07 /
      data f(12,21),f(12,22) /  3.00000000d-08 ,  3.00000000d-08 /
      data f(12,23) /           0.00000000d+00 /
      data f(13, 1),f(13, 2) /  0.00000000d+00 ,  0.00000000d+00 /
      data f(13, 3),f(13, 4) /  9.00000000d-07 ,  2.06060000d-04 /
      data f(13, 5),f(13, 6) /  6.08430000d-04 ,  4.30980000d-04 /
      data f(13, 7),f(13, 8) /  1.88710000d-04 ,  4.53700000d-05 /
      data f(13, 9),f(13,10) / -1.15000000d-06 , -3.95000000d-06 /
      data f(13,11),f(13,12) / -4.60000000d-07 ,  8.80000000d-07 /
      data f(13,13),f(13,14) /  5.50000000d-07 ,  5.00000000d-08 /
      data f(13,15),f(13,16) / -2.05000000d-06 , -4.02000000d-06 /
      data f(13,17),f(13,18) / -4.12000000d-06 , -2.54000000d-06 /
      data f(13,19),f(13,20) / -8.60000000d-07 , -1.20000000d-07 /
      data f(13,21),f(13,22) / -3.00000000d-08 ,  3.00000000d-08 /
      data f(13,23) /           0.00000000d+00 /
      data f(14, 1),f(14, 2) /  0.00000000d+00 ,  5.00000000d-08 /
      data f(14, 3),f(14, 4) / -3.00000000d-07 ,  4.96900000d-05 /
      data f(14, 5),f(14, 6) /  1.26230000d-04 ,  1.17530000d-04 /
      data f(14, 7),f(14, 8) /  6.40800000d-05 ,  2.05500000d-05 /
      data f(14, 9),f(14,10) /  2.19000000d-06 , -2.07000000d-06 /
      data f(14,11),f(14,12) / -2.90000000d-07 ,  3.10000000d-07 /
      data f(14,13),f(14,14) /  1.70000000d-07 , -3.90000000d-07 /
      data f(14,15),f(14,16) / -1.39000000d-06 , -2.36000000d-06 /
      data f(14,17),f(14,18) / -2.56000000d-06 , -1.50000000d-06 /
      data f(14,19),f(14,20) / -4.10000000d-07 , -8.00000000d-08 /
      data f(14,21),f(14,22) / -1.50000000d-07 , -5.00000000d-08 /
      data f(14,23) /           0.00000000d+00 /
      data f(15, 1),f(15, 2) /  0.00000000d+00 , -2.00000000d-08 /
      data f(15, 3),f(15, 4) /  8.70000000d-07 ,  1.70200000d-05 /
      data f(15, 5),f(15, 6) /  4.57800000d-05 ,  4.98900000d-05 /
      data f(15, 7),f(15, 8) /  3.08000000d-05 ,  1.09400000d-05 /
      data f(15, 9),f(15,10) /  1.12000000d-06 , -1.64000000d-06 /
      data f(15,11),f(15,12) / -6.40000000d-07 ,  2.30000000d-07 /
      data f(15,13),f(15,14) /  3.80000000d-07 , -2.90000000d-07 /
      data f(15,15),f(15,16) / -1.41000000d-06 , -1.89000000d-06 /
      data f(15,17),f(15,18) / -1.83000000d-06 , -1.04000000d-06 /
      data f(15,19),f(15,20) / -3.20000000d-07 , -6.00000000d-08 /
      data f(15,21),f(15,22) /  1.00000000d-07 , -2.00000000d-08 /
      data f(15,23) /           0.00000000d+00 /
      data f(16, 1),f(16, 2) /  0.00000000d+00 ,  2.00000000d-08 /
      data f(16, 3),f(16, 4) /  4.20000000d-07 ,  5.58000000d-06 /
      data f(16, 5),f(16, 6) /  1.65800000d-05 ,  2.06400000d-05 /
      data f(16, 7),f(16, 8) /  1.38500000d-05 ,  4.80000000d-06 /
      data f(16, 9),f(16,10) / -2.90000000d-07 , -1.27000000d-06 /
      data f(16,11),f(16,12) /  4.00000000d-08 ,  9.00000000d-08 /
      data f(16,13),f(16,14) /  1.60000000d-07 , -2.20000000d-07 /
      data f(16,15),f(16,16) / -1.11000000d-06 , -1.57000000d-06 /
      data f(16,17),f(16,18) / -1.44000000d-06 , -8.30000000d-07 /
      data f(16,19),f(16,20) / -2.60000000d-07 , -4.00000000d-08 /
      data f(16,21),f(16,22) / -1.50000000d-07 ,  4.00000000d-08 /
      data f(16,23) /           0.00000000d+00 /
      data f(17, 1),f(17, 2) /  0.00000000d+00 , -3.00000000d-08 /
      data f(17, 3),f(17, 4) /  1.80000000d-07 ,  1.09000000d-06 /
      data f(17, 5),f(17, 6) /  3.36000000d-06 ,  4.73000000d-06 /
      data f(17, 7),f(17, 8) /  3.01000000d-06 ,  1.40000000d-07 /
      data f(17, 9),f(17,10) / -1.50000000d-06 , -8.70000000d-07 /
      data f(17,11),f(17,12) / -3.10000000d-07 , -2.70000000d-07 /
      data f(17,13),f(17,14) /  1.40000000d-07 ,  3.00000000d-08 /
      data f(17,15),f(17,16) / -9.20000000d-07 , -7.40000000d-07 /
      data f(17,17),f(17,18) / -8.60000000d-07 , -5.10000000d-07 /
      data f(17,19),f(17,20) / -1.50000000d-07 , -1.40000000d-07 /
      data f(17,21),f(17,22) /  0.00000000d+00 , -4.00000000d-08 /
      data f(17,23) /           0.00000000d+00 /
      data f(18, 1),f(18, 2) /  0.00000000d+00 ,  7.00000000d-08 /
      data f(18, 3),f(18, 4) /  7.00000000d-08 ,  2.30000000d-07 /
      data f(18, 5),f(18, 6) /  5.20000000d-07 ,  5.40000000d-07 /
      data f(18, 7),f(18, 8) / -3.10000000d-07 , -1.29000000d-06 /
      data f(18, 9),f(18,10) / -1.60000000d-06 , -1.32000000d-06 /
      data f(18,11),f(18,12) / -2.00000000d-07 ,  0.00000000d+00 /
      data f(18,13),f(18,14) /  6.00000000d-08 , -1.40000000d-07 /
      data f(18,15),f(18,16) / -3.70000000d-07 , -4.30000000d-07 /
      data f(18,17),f(18,18) / -5.80000000d-07 , -3.60000000d-07 /
      data f(18,19),f(18,20) / -1.60000000d-07 , -1.10000000d-07 /
      data f(18,21),f(18,22) /  0.00000000d+00 , -2.00000000d-08 /
      data f(18,23) /           0.00000000d+00 /
      data f(19, 1),f(19, 2) /  0.00000000d+00 ,  5.00000000d-08 /
      data f(19, 3),f(19, 4) /  8.00000000d-08 ,  5.00000000d-08 /
      data f(19, 5),f(19, 6) /  1.00000000d-07 , -2.10000000d-07 /
      data f(19, 7),f(19, 8) / -8.50000000d-07 , -1.40000000d-06 /
      data f(19, 9),f(19,10) / -1.37000000d-06 , -6.90000000d-07 /
      data f(19,11),f(19,12) / -7.00000000d-08 ,  6.00000000d-08 /
      data f(19,13),f(19,14) /  6.00000000d-08 , -1.50000000d-07 /
      data f(19,15),f(19,16) / -2.60000000d-07 , -5.00000000d-07 /
      data f(19,17),f(19,18) / -4.00000000d-07 , -2.70000000d-07 /
      data f(19,19),f(19,20) / -1.20000000d-07 ,  2.00000000d-07 /
      data f(19,21),f(19,22) / -6.00000000d-08 , -3.00000000d-08 /
      data f(19,23) /           0.00000000d+00 /
      data f(20, 1),f(20, 2) /  0.00000000d+00 ,  4.00000000d-08 /
      data f(20, 3),f(20, 4) /  6.00000000d-08 ,  4.00000000d-08 /
      data f(20, 5),f(20, 6) / -1.20000000d-07 , -3.90000000d-07 /
      data f(20, 7),f(20, 8) / -8.80000000d-07 , -1.14000000d-06 /
      data f(20, 9),f(20,10) / -1.29000000d-06 , -5.10000000d-07 /
      data f(20,11),f(20,12) / -3.90000000d-07 , -3.00000000d-08 /
      data f(20,13),f(20,14) /  6.00000000d-08 ,  1.60000000d-07 /
      data f(20,15),f(20,16) / -2.20000000d-07 , -1.90000000d-07 /
      data f(20,17),f(20,18) / -2.80000000d-07 , -1.00000000d-07 /
      data f(20,19),f(20,20) /  2.00000000d-08 , -6.00000000d-08 /
      data f(20,21),f(20,22) /  2.00000000d-08 , -1.00000000d-08 /
      data f(20,23) /           0.00000000d+00 /
      data f(21, 1),f(21, 2) /  0.00000000d+00 ,  3.00000000d-08 /
      data f(21, 3),f(21, 4) /  5.00000000d-08 ,  2.00000000d-08 /
      data f(21, 5),f(21, 6) / -1.10000000d-07 , -4.00000000d-07 /
      data f(21, 7),f(21, 8) / -6.10000000d-07 , -8.10000000d-07 /
      data f(21, 9),f(21,10) / -6.90000000d-07 , -3.00000000d-07 /
      data f(21,11),f(21,12) / -1.60000000d-07 , -2.00000000d-08 /
      data f(21,13),f(21,14) /  4.00000000d-08 , -3.50000000d-07 /
      data f(21,15),f(21,16) / -1.40000000d-07 , -1.90000000d-07 /
      data f(21,17),f(21,18) / -1.40000000d-07 , -9.00000000d-08 /
      data f(21,19),f(21,20) / -5.00000000d-08 ,  1.00000000d-08 /
      data f(21,21),f(21,22) /  0.00000000d+00 ,  1.20000000d-07 /
      data f(21,23) /           0.00000000d+00 /
      data f(22, 1),f(22, 2) /  0.00000000d+00 , -1.00000000d-08 /
      data f(22, 3),f(22, 4) / -6.00000000d-08 ,  7.00000000d-08 /
      data f(22, 5),f(22, 6) / -1.20000000d-07 , -4.00000000d-08 /
      data f(22, 7),f(22, 8) / -3.10000000d-07 , -3.10000000d-07 /
      data f(22, 9),f(22,10) / -2.90000000d-07 ,  6.40000000d-07 /
      data f(22,11),f(22,12) / -1.00000000d-07 , -3.00000000d-08 /
      data f(22,13),f(22,14) / -1.00000000d-08 ,  0.00000000d+00 /
      data f(22,15),f(22,16) / -6.00000000d-08 , -8.00000000d-08 /
      data f(22,17),f(22,18) / -7.00000000d-08 , -4.00000000d-08 /
      data f(22,19),f(22,20) / -1.00000000d-08 ,  0.00000000d+00 /
      data f(22,21),f(22,22) /  0.00000000d+00 , -1.00000000d-08 /
      data f(22,23) /           0.00000000d+00 /
      data f(23, 1),f(23, 2) /  0.00000000d+00 , -1.00000000d-08 /
      data f(23, 3),f(23, 4) /  9.00000000d-08 , -1.00000000d-08 /
      data f(23, 5),f(23, 6) / -2.00000000d-08 ,  1.00000000d-08 /
      data f(23, 7),f(23, 8) / -1.20000000d-07 , -1.60000000d-07 /
      data f(23, 9),f(23,10) / -1.20000000d-07 , -1.20000000d-07 /
      data f(23,11),f(23,12) / -4.00000000d-08 , -2.00000000d-08 /
      data f(23,13),f(23,14) /  0.00000000d+00 , -1.00000000d-08 /
      data f(23,15),f(23,16) / -3.00000000d-08 , -5.00000000d-08 /
      data f(23,17),f(23,18) / -3.00000000d-08 , -2.00000000d-08 /
      data f(23,19),f(23,20) / -1.00000000d-08 ,  0.00000000d+00 /
      data f(23,21),f(23,22) /  0.00000000d+00 , -2.00000000d-08 /
      data f(23,23) /           0.00000000d+00 /
      data f(24, 1),f(24, 2) /  0.00000000d+00 , -1.00000000d-08 /
      data f(24, 3),f(24, 4) / -3.00000000d-08 ,  6.00000000d-08 /
      data f(24, 5),f(24, 6) / -2.00000000d-08 , -3.00000000d-08 /
      data f(24, 7),f(24, 8) / -4.00000000d-08 , -2.00000000d-08 /
      data f(24, 9),f(24,10) / -6.00000000d-08 , -5.00000000d-08 /
      data f(24,11),f(24,12) / -2.00000000d-08 ,  2.00000000d-08 /
      data f(24,13),f(24,14) /  0.00000000d+00 ,  0.00000000d+00 /
      data f(24,15),f(24,16) / -1.00000000d-08 , -1.00000000d-08 /
      data f(24,17),f(24,18) / -2.00000000d-08 , -2.00000000d-08 /
      data f(24,19),f(24,20) /  0.00000000d+00 ,  0.00000000d+00 /
      data f(24,21),f(24,22) /  0.00000000d+00 , -1.00000000d-08 /
      data f(24,23) /           0.00000000d+00 /
      data f(25, 1),f(25, 2) /  0.00000000d+00 ,  0.00000000d+00 /
      data f(25, 3),f(25, 4) /  0.00000000d+00 , -1.00000000d-08 /
      data f(25, 5),f(25, 6) /  2.00000000d-08 , -1.00000000d-08 /
      data f(25, 7),f(25, 8) / -1.00000000d-08 , -4.00000000d-08 /
      data f(25, 9),f(25,10) /  0.00000000d+00 , -4.00000000d-08 /
      data f(25,11),f(25,12) /  2.00000000d-08 , -1.00000000d-08 /
      data f(25,13),f(25,14) /  2.00000000d-08 , -1.10000000d-07 /
      data f(25,15),f(25,16) /  0.00000000d+00 , -1.00000000d-08 /
      data f(25,17),f(25,18) / -1.00000000d-08 ,  1.00000000d-08 /
      data f(25,19),f(25,20) /  0.00000000d+00 ,  0.00000000d+00 /
      data f(25,21),f(25,22) /  1.00000000d-08 , -1.00000000d-08 /
      data f(25,23) /           0.00000000d+00 /
      data f(26, 1),f(26, 2) /  0.00000000d+00 ,  0.00000000d+00 /
      data f(26, 3),f(26, 4) /  0.00000000d+00 , -1.00000000d-08 /
      data f(26, 5),f(26, 6) /  0.00000000d+00 ,  0.00000000d+00 /
      data f(26, 7),f(26, 8) / -1.00000000d-08 , -1.00000000d-08 /
      data f(26, 9),f(26,10) / -1.00000000d-08 , -1.00000000d-08 /
      data f(26,11),f(26,12) / -2.00000000d-08 ,  0.00000000d+00 /
      data f(26,13),f(26,14) / -1.00000000d-08 ,  1.20000000d-07 /
      data f(26,15),f(26,16) /  2.00000000d-08 ,  2.00000000d-08 /
      data f(26,17),f(26,18) /  2.00000000d-08 ,  1.00000000d-08 /
      data f(26,19),f(26,20) /  0.00000000d+00 ,  0.00000000d+00 /
      data f(26,21),f(26,22) /  0.00000000d+00 , -2.00000000d-08 /
      data f(26,23) /           0.00000000d+00 /
      data f(27, 1),f(27, 2) /  0.00000000d+00 ,  0.00000000d+00 /
      data f(27, 3),f(27, 4) /  0.00000000d+00 ,  0.00000000d+00 /
      data f(27, 5),f(27, 6) /  0.00000000d+00 ,  0.00000000d+00 /
      data f(27, 7),f(27, 8) / -2.00000000d-08 , -2.00000000d-08 /
      data f(27, 9),f(27,10) /  1.00000000d-08 ,  1.00000000d-08 /
      data f(27,11),f(27,12) / -1.00000000d-08 ,  0.00000000d+00 /
      data f(27,13),f(27,14) /  0.00000000d+00 , -9.00000000d-08 /
      data f(27,15),f(27,16) / -1.00000000d-08 ,  2.00000000d-08 /
      data f(27,17),f(27,18) /  0.00000000d+00 ,  2.00000000d-08 /
      data f(27,19),f(27,20) /  2.00000000d-08 ,  1.00000000d-08 /
      data f(27,21),f(27,22) /  1.00000000d-08 , -1.00000000d-08 /
      data f(27,23) /           0.00000000d+00 /
      data f(28, 1),f(28, 2) /  0.00000000d+00 ,  2.00000000d-08 /
      data f(28, 3),f(28, 4) /  1.00000000d-08 , -1.00000000d-08 /
      data f(28, 5),f(28, 6) /  0.00000000d+00 ,  0.00000000d+00 /
      data f(28, 7),f(28, 8) / -1.00000000d-08 ,  0.00000000d+00 /
      data f(28, 9),f(28,10) /  0.00000000d+00 , -1.00000000d-08 /
      data f(28,11),f(28,12) /  0.00000000d+00 ,  2.00000000d-08 /
      data f(28,13),f(28,14) / -1.50000000d-07 , -1.20000000d-07 /
      data f(28,15),f(28,16) /  7.00000000d-08 ,  0.00000000d+00 /
      data f(28,17),f(28,18) /  1.00000000d-08 ,  1.00000000d-08 /
      data f(28,19),f(28,20) /  0.00000000d+00 ,  3.00000000d-08 /
      data f(28,21),f(28,22) / -9.00000000d-08 ,  1.00000000d-08 /
      data f(28,23) /           0.00000000d+00 /
 
      data fpp( 1, 1,1),fpp( 1, 1,2)/ 0.00000000d+00,-2.09408199d-05/
      data fpp( 1, 2,1),fpp( 1, 2,2)/ 3.79087070d-05, 2.05548398d-05/
      data fpp( 1, 3,1),fpp( 1, 3,2)/ 3.11726426d-03,-4.46249392d-05/
      data fpp( 1, 4,1),fpp( 1, 4,2)/-2.20155195d-01, 2.63559317d-04/
      data fpp( 1, 5,1),fpp( 1, 5,2)/ 4.18979050d-01,-3.30887529d-04/
      data fpp( 1, 6,1),fpp( 1, 6,2)/ 1.32990856d-01,-5.15404029d-05/
      data fpp( 1, 7,1),fpp( 1, 7,2)/-1.59256948d-01, 1.58331540d-04/
      data fpp( 1, 8,1),fpp( 1, 8,2)/ 2.98922983d-02,-7.03601570d-05/
      data fpp( 1, 9,1),fpp( 1, 9,2)/-9.76271105d-02, 8.00578881d-05/
      data fpp( 1,10,1),fpp( 1,10,2)/ 3.87142072d-02,-3.78137859d-05/
      data fpp( 1,11,1),fpp( 1,11,2)/ 7.74553064d-04, 2.16258554d-05/
      data fpp( 1,12,1),fpp( 1,12,2)/-6.26227453d-03,-1.38824357d-05/
      data fpp( 1,13,1),fpp( 1,13,2)/-3.53068195d-04, 1.01728733d-06/
      data fpp( 1,14,1),fpp( 1,14,2)/ 1.19260534d-03, 2.77108636d-06/
      data fpp( 1,15,1),fpp( 1,15,2)/ 5.01812199d-03, 3.37776723d-06/
      data fpp( 1,16,1),fpp( 1,16,2)/ 1.11190402d-02,-4.09915528d-06/
      data fpp( 1,17,1),fpp( 1,17,2)/ 1.40475260d-02,-7.43814612d-06/
      data fpp( 1,18,1),fpp( 1,18,2)/ 6.17703242d-03, 5.48139744d-07/
      data fpp( 1,19,1),fpp( 1,19,2)/ 2.07710202d-03, 3.89378714d-06/
      data fpp( 1,20,1),fpp( 1,20,2)/ 2.80062835d-04, 8.68711694d-07/
      data fpp( 1,21,1),fpp( 1,21,2)/ 8.25992893d-05, 8.96608230d-09/
      data fpp( 1,22,1),fpp( 1,22,2)/-2.06419816d-05, 5.48239765d-08/
      data fpp( 1,23,1),fpp( 1,23,2)/ 0.00000000d+00,-1.58061988d-07/
      data fpp( 2, 1,1),fpp( 2, 1,2)/ 0.00000000d+00,-9.27691082d-05/
      data fpp( 2, 2,1),fpp( 2, 2,2)/ 2.71825861d-05, 2.60661642d-06/
      data fpp( 2, 3,1),fpp( 2, 3,2)/ 6.42047149d-03, 1.06676243d-04/
      data fpp( 2, 4,1),fpp( 2, 4,2)/-4.83306092d-02, 1.80317213d-04/
      data fpp( 2, 5,1),fpp( 2, 5,2)/ 2.50910900d-01,-4.13683496d-04/
      data fpp( 2, 6,1),fpp( 2, 6,2)/ 1.57539289d-01,-6.11296277d-05/
      data fpp( 2, 7,1),fpp( 2, 7,2)/-4.55301042d-02, 1.19320407d-04/
      data fpp( 2, 8,1),fpp( 2, 8,2)/ 3.09814034d-02, 7.28695987d-05/
      data fpp( 2, 9,1),fpp( 2, 9,2)/-3.75587791d-02, 2.80555979d-05/
      data fpp( 2,10,1),fpp( 2,10,2)/ 2.01155856d-02,-1.73139932d-05/
      data fpp( 2,11,1),fpp( 2,11,2)/-3.56210613d-03, 8.85497480d-06/
      data fpp( 2,12,1),fpp( 2,12,2)/-4.32745094d-03,-9.10230602d-06/
      data fpp( 2,13,1),fpp( 2,13,2)/-1.85863610d-04, 8.92649274d-07/
      data fpp( 2,14,1),fpp( 2,14,2)/ 9.28789320d-04, 1.93410892d-06/
      data fpp( 2,15,1),fpp( 2,15,2)/ 3.91775601d-03, 2.33411504d-06/
      data fpp( 2,16,1),fpp( 2,16,2)/ 8.67891955d-03,-2.59396907d-06/
      data fpp( 2,17,1),fpp( 2,17,2)/ 1.03489481d-02,-5.15943877d-06/
      data fpp( 2,18,1),fpp( 2,18,2)/ 5.14093516d-03, 2.65524157d-07/
      data fpp( 2,19,1),fpp( 2,19,2)/ 1.61979596d-03, 2.72754215d-06/
      data fpp( 2,20,1),fpp( 2,20,2)/ 2.06874331d-04, 5.44107260d-07/
      data fpp( 2,21,1),fpp( 2,21,2)/ 4.88014213d-05, 2.50288146d-08/
      data fpp( 2,22,1),fpp( 2,22,2)/-1.07160369d-05, 2.83774815d-08/
      data fpp( 2,23,1),fpp( 2,23,2)/ 0.00000000d+00,-1.17538741d-07/
      data fpp( 3, 1,1),fpp( 3, 1,2)/ 0.00000000d+00,-1.56944348d-04/
      data fpp( 3, 2,1),fpp( 3, 2,2)/ 3.36094882d-06, 1.91422960d-05/
      data fpp( 3, 3,1),fpp( 3, 3,2)/ 8.76684980d-03, 1.27295164d-04/
      data fpp( 3, 4,1),fpp( 3, 4,2)/ 2.08199632d-01, 4.73216247d-04/
      data fpp( 3, 5,1),fpp( 3, 5,2)/ 4.76791349d-01,-9.31347354d-04/
      data fpp( 3, 6,1),fpp( 3, 6,2)/-5.30011199d-04,-3.98363126d-06/
      data fpp( 3, 7,1),fpp( 3, 7,2)/ 4.31413648d-02, 2.78613079d-04/
      data fpp( 3, 8,1),fpp( 3, 8,2)/ 2.18806088d-01, 4.88345148d-05/
      data fpp( 3, 9,1),fpp( 3, 9,2)/ 2.60684227d-01, 3.45440616d-05/
      data fpp( 3,10,1),fpp( 3,10,2)/-8.90085496d-02,-1.49590421d-05/
      data fpp( 3,11,1),fpp( 3,11,2)/-1.60881286d-02, 2.46510698d-06/
      data fpp( 3,12,1),fpp( 3,12,2)/-2.07192172d-03,-5.33658577d-06/
      data fpp( 3,13,1),fpp( 3,13,2)/-7.47736571d-06, 5.06836099d-07/
      data fpp( 3,14,1),fpp( 3,14,2)/ 7.20237380d-04, 1.37544137d-06/
      data fpp( 3,15,1),fpp( 3,15,2)/ 2.71085396d-03, 1.54239840d-06/
      data fpp( 3,16,1),fpp( 3,16,2)/ 5.39928157d-03,-1.36863499d-06/
      data fpp( 3,17,1),fpp( 3,17,2)/ 4.95268171d-03,-3.88045843d-06/
      data fpp( 3,18,1),fpp( 3,18,2)/ 4.14122693d-03, 3.94068729d-07/
      data fpp( 3,19,1),fpp( 3,19,2)/ 1.07971414d-03, 1.74318352d-06/
      data fpp( 3,20,1),fpp( 3,20,2)/ 1.34439843d-04, 3.65997202d-07/
      data fpp( 3,21,1),fpp( 3,21,2)/-1.80497472d-06, 1.60276765d-08/
      data fpp( 3,22,1),fpp( 3,22,2)/ 3.50612910d-06, 1.86920924d-08/
      data fpp( 3,23,1),fpp( 3,23,2)/ 0.00000000d+00,-7.93960462d-08/
      data fpp( 4, 1,1),fpp( 4, 1,2)/ 0.00000000d+00,-2.64748338d-04/
      data fpp( 4, 2,1),fpp( 4, 2,2)/ 2.53736187d-05, 2.94222766d-05/
      data fpp( 4, 3,1),fpp( 4, 3,2)/ 1.44621293d-02, 2.38892832d-04/
      data fpp( 4, 4,1),fpp( 4, 4,2)/ 1.68260081d-01, 7.44813595d-04/
      data fpp( 4, 5,1),fpp( 4, 5,2)/-6.76148296d-01,-1.60181441d-03/
      data fpp( 4, 6,1),fpp( 4, 6,2)/ 4.80562756d-01, 1.35618458d-04/
      data fpp( 4, 7,1),fpp( 4, 7,2)/ 2.19506645d-01, 4.83486983d-04/
      data fpp( 4, 8,1),fpp( 4, 8,2)/-2.46943756d-01, 8.82411126d-07/
      data fpp( 4, 9,1),fpp( 4, 9,2)/-2.74684128d-01,-5.47582732d-06/
      data fpp( 4,10,1),fpp( 4,10,2)/ 1.18706613d-01, 2.98624764d-05/
      data fpp( 4,11,1),fpp( 4,11,2)/ 4.86203481d-05,-1.75774783d-05/
      data fpp( 4,12,1),fpp( 4,12,2)/-9.38862197d-04, 1.07003670d-06/
      data fpp( 4,13,1),fpp( 4,13,2)/ 1.31773073d-04,-8.74068523d-07/
      data fpp( 4,14,1),fpp( 4,14,2)/ 3.18261159d-04, 1.23043739d-06/
      data fpp( 4,15,1),fpp( 4,15,2)/ 1.87682815d-03, 9.20918957d-07/
      data fpp( 4,16,1),fpp( 4,16,2)/ 5.05795416d-03,-6.19313221d-07/
      data fpp( 4,17,1),fpp( 4,17,2)/ 5.49832508d-03,-2.70486607d-06/
      data fpp( 4,18,1),fpp( 4,18,2)/ 3.01415713d-03, 2.85977512d-07/
      data fpp( 4,19,1),fpp( 4,19,2)/ 8.29347462d-04, 1.10735603d-06/
      data fpp( 4,20,1),fpp( 4,20,2)/ 5.93662987d-05, 2.29198385d-07/
      data fpp( 4,21,1),fpp( 4,21,2)/ 6.41847753d-06, 1.40504349d-08/
      data fpp( 4,22,1),fpp( 4,22,2)/ 2.69152047d-06, 1.09998758d-08/
      data fpp( 4,23,1),fpp( 4,23,2)/ 0.00000000d+00,-5.26499379d-08/
      data fpp( 5, 1,1),fpp( 5, 1,2)/ 0.00000000d+00,-3.87262279d-04/
      data fpp( 5, 2,1),fpp( 5, 2,2)/-3.88554235d-05,-3.10842425d-05/
      data fpp( 5, 3,1),fpp( 5, 3,2)/-2.63553671d-02, 6.64397649d-04/
      data fpp( 5, 4,1),fpp( 5, 4,2)/ 5.10820450d-02, 1.72316047d-04/
      data fpp( 5, 5,1),fpp( 5, 5,2)/-4.57678164d-01,-1.01375464d-03/
      data fpp( 5, 6,1),fpp( 5, 6,2)/-8.19110123d-02,-6.57555098d-04/
      data fpp( 5, 7,1),fpp( 5, 7,2)/-2.48171945d-01, 8.84095029d-04/
      data fpp( 5, 8,1),fpp( 5, 8,2)/ 7.42169352d-02, 2.23957803d-05/
      data fpp( 5, 9,1),fpp( 5, 9,2)/ 7.92082862d-02, 2.37064943d-06/
      data fpp( 5,10,1),fpp( 5,10,2)/-3.91379022d-02, 1.97229616d-05/
      data fpp( 5,11,1),fpp( 5,11,2)/-2.86235284d-03,-1.27382957d-05/
      data fpp( 5,12,1),fpp( 5,12,2)/-4.48629494d-04, 7.02221232d-07/
      data fpp( 5,13,1),fpp( 5,13,2)/-3.61492485d-06,-6.07789228d-07/
      data fpp( 5,14,1),fpp( 5,14,2)/ 3.52717982d-04, 7.74935681d-07/
      data fpp( 5,15,1),fpp( 5,15,2)/ 1.64983346d-03, 6.63446506d-07/
      data fpp( 5,16,1),fpp( 5,16,2)/ 3.13290179d-03,-2.78121703d-07/
      data fpp( 5,17,1),fpp( 5,17,2)/ 3.60601797d-03,-1.77155969d-06/
      data fpp( 5,18,1),fpp( 5,18,2)/ 2.13814457d-03, 1.54760481d-07/
      data fpp( 5,19,1),fpp( 5,19,2)/ 5.28896009d-04, 6.86917772d-07/
      data fpp( 5,20,1),fpp( 5,20,2)/ 3.60949627d-05, 1.43168432d-07/
      data fpp( 5,21,1),fpp( 5,21,2)/ 6.13106459d-06, 7.60849899d-09/
      data fpp( 5,22,1),fpp( 5,22,2)/-2.27221099d-06, 6.39757172d-09/
      data fpp( 5,23,1),fpp( 5,23,2)/ 0.00000000d+00,-3.31987859d-08/
      data fpp( 6, 1,1),fpp( 6, 1,2)/ 0.00000000d+00,-5.15457123d-04/
      data fpp( 6, 2,1),fpp( 6, 2,2)/ 1.24048075d-04,-1.39177754d-04/
      data fpp( 6, 3,1),fpp( 6, 3,2)/ 8.65133906d-03, 1.25301294d-03/
      data fpp( 6, 4,1),fpp( 6, 4,2)/-3.00822261d-01,-9.10486008d-04/
      data fpp( 6, 5,1),fpp( 6, 5,2)/-1.16213048d-01, 3.12847093d-04/
      data fpp( 6, 6,1),fpp( 6, 6,2)/-6.19316707d-01,-1.95398556d-03/
      data fpp( 6, 7,1),fpp( 6, 7,2)/-2.84908640d-02, 1.56240876d-03/
      data fpp( 6, 8,1),fpp( 6, 8,2)/-5.42259850d-02,-1.10599084d-04/
      data fpp( 6, 9,1),fpp( 6, 9,2)/-3.68810165d-02, 3.54243722d-05/
      data fpp( 6,10,1),fpp( 6,10,2)/-1.51500414d-03, 4.83902509d-06/
      data fpp( 6,11,1),fpp( 6,11,2)/-1.52320900d-03,-7.02227259d-06/
      data fpp( 6,12,1),fpp( 6,12,2)/-1.52619825d-04,-6.83347506d-08/
      data fpp( 6,13,1),fpp( 6,13,2)/ 4.46866267d-05,-3.06388413d-07/
      data fpp( 6,14,1),fpp( 6,14,2)/ 8.88669112d-05, 4.42488401d-07/
      data fpp( 6,15,1),fpp( 6,15,2)/ 9.67838021d-04, 4.75634808d-07/
      data fpp( 6,16,1),fpp( 6,16,2)/ 2.14443867d-03,-7.22276348d-08/
      data fpp( 6,17,1),fpp( 6,17,2)/ 2.57160304d-03,-1.11972427d-06/
      data fpp( 6,18,1),fpp( 6,18,2)/ 1.38726460d-03, 5.47247117d-08/
      data fpp( 6,19,1),fpp( 6,19,2)/ 3.85068504d-04, 4.14825423d-07/
      data fpp( 6,20,1),fpp( 6,20,2)/ 8.42538507d-05, 9.07735981d-08/
      data fpp( 6,21,1),fpp( 6,21,2)/ 5.05726411d-06,-2.71981487d-09/
      data fpp( 6,22,1),fpp( 6,22,2)/ 3.97323500d-07, 4.70566139d-09/
      data fpp( 6,23,1),fpp( 6,23,2)/ 0.00000000d+00,-1.67028307d-08/
      data fpp( 7, 1,1),fpp( 7, 1,2)/ 0.00000000d+00,-5.88892566d-04/
      data fpp( 7, 2,1),fpp( 7, 2,2)/-2.80716514d-04,-2.14694467d-04/
      data fpp( 7, 3,1),fpp( 7, 3,2)/-1.70738336d-02, 1.67750164d-03/
      data fpp( 7, 4,1),fpp( 7, 4,2)/-9.26802407d-02,-1.74329527d-03/
      data fpp( 7, 5,1),fpp( 7, 5,2)/ 3.87023226d-01, 1.17874826d-03/
      data fpp( 7, 6,1),fpp( 7, 6,2)/ 9.53101258d-02,-2.55809858d-03/
      data fpp( 7, 7,1),fpp( 7, 7,2)/-4.31359354d-02, 1.81381326d-03/
      data fpp( 7, 8,1),fpp( 7, 8,2)/ 4.76399873d-02,-1.46262466d-04/
      data fpp( 7, 9,1),fpp( 7, 9,2)/ 2.29024064d-02, 5.34942025d-05/
      data fpp( 7,10,1),fpp( 7,10,2)/-3.54303647d-03,-1.16217745d-05/
      data fpp( 7,11,1),fpp( 7,11,2)/-7.44696581d-04,-6.08104581d-07/
      data fpp( 7,12,1),fpp( 7,12,2)/-2.43257770d-05,-7.94007192d-07/
      data fpp( 7,13,1),fpp( 7,13,2)/-1.82524178d-05,-3.48666488d-08/
      data fpp( 7,14,1),fpp( 7,14,2)/ 1.19540275d-04, 1.38473788d-07/
      data fpp( 7,15,1),fpp( 7,15,2)/ 3.03569207d-04, 1.96171498d-07/
      data fpp( 7,16,1),fpp( 7,16,2)/ 8.95233097d-04, 1.51440219d-07/
      data fpp( 7,17,1),fpp( 7,17,2)/ 1.04068189d-03,-4.39532375d-07/
      data fpp( 7,18,1),fpp( 7,18,2)/ 6.26633912d-04,-9.11071809d-09/
      data fpp( 7,19,1),fpp( 7,19,2)/ 1.71846483d-04, 1.23175248d-07/
      data fpp( 7,20,1),fpp( 7,20,2)/ 1.11909665d-05, 2.22097274d-08/
      data fpp( 7,21,1),fpp( 7,21,2)/-9.23732462d-06,-6.21415738d-09/
      data fpp( 7,22,1),fpp( 7,22,2)/-5.58650020d-08, 2.04690211d-09/
      data fpp( 7,23,1),fpp( 7,23,2)/ 0.00000000d+00,-1.73451055d-10/
      data fpp( 8, 1,1),fpp( 8, 1,2)/ 0.00000000d+00,-5.61029059d-04/
      data fpp( 8, 2,1),fpp( 8, 2,2)/ 2.53317982d-04,-1.18660682d-04/
      data fpp( 8, 3,1),fpp( 8, 3,2)/-1.34150452d-03, 1.21929819d-03/
      data fpp( 8, 4,1),fpp( 8, 4,2)/-2.99946777d-01,-5.77309664d-04/
      data fpp( 8, 5,1),fpp( 8, 5,2)/-3.80670855d-01,-3.74712331d-04/
      data fpp( 8, 6,1),fpp( 8, 6,2)/-4.67195297d-01,-1.53024661d-03/
      data fpp( 8, 7,1),fpp( 8, 7,2)/ 4.66960576d-03, 1.58133879d-03/
      data fpp( 8, 8,1),fpp( 8, 8,2)/-2.86264641d-02,-2.06109332d-04/
      data fpp( 8, 9,1),fpp( 8, 9,2)/-1.54460911d-03, 7.84233418d-05/
      data fpp( 8,10,1),fpp( 8,10,2)/-1.14734999d-03,-2.09573594d-05/
      data fpp( 8,11,1),fpp( 8,11,2)/-3.65504675d-04, 3.24009585d-06/
      data fpp( 8,12,1),fpp( 8,12,2)/ 2.34229331d-05,-1.31142398d-06/
      data fpp( 8,13,1),fpp( 8,13,2)/-3.17695554d-06, 1.91200062d-07/
      data fpp( 8,14,1),fpp( 8,14,2)/-1.02028012d-04,-7.13762695d-08/
      data fpp( 8,15,1),fpp( 8,15,2)/ 1.48885152d-04, 1.33305016d-07/
      data fpp( 8,16,1),fpp( 8,16,2)/ 3.24128942d-04, 1.55556205d-07/
      data fpp( 8,17,1),fpp( 8,17,2)/ 4.46169389d-04,-1.32729836d-07/
      data fpp( 8,18,1),fpp( 8,18,2)/ 2.59699749d-04,-2.30368611d-08/
      data fpp( 8,19,1),fpp( 8,19,2)/ 6.75455642d-05, 1.06772805d-08/
      data fpp( 8,20,1),fpp( 8,20,2)/ 7.48228326d-06,-8.87226074d-09/
      data fpp( 8,21,1),fpp( 8,21,2)/ 9.39203436d-06,-9.88237492d-10/
      data fpp( 8,22,1),fpp( 8,22,2)/-1.67386349d-06,-9.74789288d-10/
      data fpp( 8,23,1),fpp( 8,23,2)/ 0.00000000d+00, 1.28739464d-09/
      data fpp( 9, 1,1),fpp( 9, 1,2)/ 0.00000000d+00,-3.03249617d-04/
      data fpp( 9, 2,1),fpp( 9, 2,2)/-1.41555412d-04, 4.11384342d-05/
      data fpp( 9, 3,1),fpp( 9, 3,2)/ 3.05835171d-03, 2.43215880d-04/
      data fpp( 9, 4,1),fpp( 9, 4,2)/ 2.19959848d-01, 9.43380444d-04/
      data fpp( 9, 5,1),fpp( 9, 5,2)/-4.59537306d-01,-1.98041446d-03/
      data fpp( 9, 6,1),fpp( 9, 6,2)/ 2.49687061d-01, 3.02432587d-04/
      data fpp( 9, 7,1),fpp( 9, 7,2)/-2.33248760d-03, 4.62725710d-04/
      data fpp( 9, 8,1),fpp( 9, 8,2)/ 3.62736905d-03, 2.02629733d-05/
      data fpp( 9, 9,1),fpp( 9, 9,2)/-4.04746996d-03, 2.43959970d-05/
      data fpp( 9,10,1),fpp( 9,10,2)/-9.83063566d-04,-5.98187755d-06/
      data fpp( 9,11,1),fpp( 9,11,2)/-2.18784720d-04, 1.93313247d-07/
      data fpp( 9,12,1),fpp( 9,12,2)/-1.68659555d-05,-2.44775432d-07/
      data fpp( 9,13,1),fpp( 9,13,2)/-1.55397601d-05,-5.48115172d-08/
      data fpp( 9,14,1),fpp( 9,14,2)/ 3.35717733d-05,-2.07784987d-08/
      data fpp( 9,15,1),fpp( 9,15,2)/-1.56098133d-05, 3.95255121d-08/
      data fpp( 9,16,1),fpp( 9,16,2)/ 1.21251136d-04, 1.39276450d-07/
      data fpp( 9,17,1),fpp( 9,17,2)/ 1.64140553d-04,-1.46313139d-08/
      data fpp( 9,18,1),fpp( 9,18,2)/ 1.10567091d-04,-1.77511949d-08/
      data fpp( 9,19,1),fpp( 9,19,2)/ 3.19712603d-05,-2.53639063d-08/
      data fpp( 9,20,1),fpp( 9,20,2)/ 2.37990044d-06,-1.63931797d-08/
      data fpp( 9,21,1),fpp( 9,21,2)/-5.83081283d-06,-2.66337468d-09/
      data fpp( 9,22,1),fpp( 9,22,2)/ 6.75131897d-06,-5.53321519d-10/
      data fpp( 9,23,1),fpp( 9,23,2)/ 0.00000000d+00, 4.87666076d-09/
      data fpp(10, 1,1),fpp(10, 1,2)/ 0.00000000d+00,-1.10886587d-04/
      data fpp(10, 2,1),fpp(10, 2,2)/ 5.49036662d-05, 1.45087742d-05/
      data fpp(10, 3,1),fpp(10, 3,2)/ 2.42509767d-03, 1.00397890d-04/
      data fpp(10, 4,1),fpp(10, 4,2)/ 7.64473864d-02, 3.24558864d-04/
      data fpp(10, 5,1),fpp(10, 5,2)/ 5.28213580d-01,-6.45285347d-04/
      data fpp(10, 6,1),fpp(10, 6,2)/ 1.12890551d-01, 2.49292212d-06/
      data fpp(10, 7,1),fpp(10, 7,2)/ 1.08748446d-02, 1.76510458d-04/
      data fpp(10, 8,1),fpp(10, 8,2)/-1.50401213d-03, 3.58924457d-05/
      data fpp(10, 9,1),fpp(10, 9,2)/-4.35011055d-04, 1.18013591d-05/
      data fpp(10,10,1),fpp(10,10,2)/-5.90395742d-04,-2.89450009d-06/
      data fpp(10,11,1),fpp(10,11,2)/-2.08564447d-05, 2.98412722d-08/
      data fpp(10,12,1),fpp(10,12,2)/ 2.15408888d-05,-9.10650018d-08/
      data fpp(10,13,1),fpp(10,13,2)/ 3.83599574d-06,-4.35812650d-08/
      data fpp(10,14,1),fpp(10,14,2)/-5.47590811d-05,-5.50099382d-08/
      data fpp(10,15,1),fpp(10,15,2)/-3.09458985d-05, 4.34210180d-08/
      data fpp(10,16,1),fpp(10,16,2)/-2.46334848d-05, 7.75258664d-08/
      data fpp(10,17,1),fpp(10,17,2)/ 3.72683983d-05, 3.82755166d-08/
      data fpp(10,18,1),fpp(10,18,2)/ 2.25318878d-05,-1.46279326d-08/
      data fpp(10,19,1),fpp(10,19,2)/ 1.00693946d-05,-2.89637860d-08/
      data fpp(10,20,1),fpp(10,20,2)/ 3.99811496d-06,-1.77169233d-08/
      data fpp(10,21,1),fpp(10,21,2)/ 4.93121695d-06, 2.31479360d-10/
      data fpp(10,22,1),fpp(10,22,2)/-1.03314124d-05,-3.00899410d-09/
      data fpp(10,23,1),fpp(10,23,2)/ 0.00000000d+00,-1.95502949d-10/
      data fpp(11, 1,1),fpp(11, 1,2)/ 0.00000000d+00,-5.17716552d-05/
      data fpp(11, 2,1),fpp(11, 2,2)/-7.55925270d-06, 6.71931048d-06/
      data fpp(11, 3,1),fpp(11, 3,2)/ 7.27525761d-03, 4.72960133d-05/
      data fpp(11, 4,1),fpp(11, 4,2)/ 2.83356067d-02, 1.50572636d-04/
      data fpp(11, 5,1),fpp(11, 5,2)/-1.15205146d-02,-2.93356958d-04/
      data fpp(11, 6,1),fpp(11, 6,2)/ 3.03952330d-02,-6.06080327d-06/
      data fpp(11, 7,1),fpp(11, 7,2)/ 1.03176091d-02, 7.59393713d-05/
      data fpp(11, 8,1),fpp(11, 8,2)/ 1.48267947d-03, 2.19905179d-05/
      data fpp(11, 9,1),fpp(11, 9,2)/-6.92485823d-04, 6.59455689d-06/
      data fpp(11,10,1),fpp(11,10,2)/-3.82853464d-04,-1.64472965d-06/
      data fpp(11,11,1),fpp(11,11,2)/-8.77895012d-05, 6.29617129d-08/
      data fpp(11,12,1),fpp(11,12,2)/-4.79759971d-06,-3.93172002d-08/
      data fpp(11,13,1),fpp(11,13,2)/-2.80422291d-06,-2.98929120d-08/
      data fpp(11,14,1),fpp(11,14,2)/-2.60354491d-05,-5.35111519d-08/
      data fpp(11,15,1),fpp(11,15,2)/ 4.18934072d-05, 3.09375195d-08/
      data fpp(11,16,1),fpp(11,16,2)/ 2.78280325d-06, 4.91610739d-08/
      data fpp(11,17,1),fpp(11,17,2)/ 4.78585348d-06, 4.18181851d-08/
      data fpp(11,18,1),fpp(11,18,2)/ 1.68053580d-05,-4.63381421d-09/
      data fpp(11,19,1),fpp(11,19,2)/ 2.75116125d-06,-2.74829282d-08/
      data fpp(11,20,1),fpp(11,20,2)/-3.37236028d-06,-1.32344728d-08/
      data fpp(11,21,1),fpp(11,21,2)/-3.39405497d-06,-2.97918039d-09/
      data fpp(11,22,1),fpp(11,22,2)/ 7.57433054d-06,-4.88056034d-11/
      data fpp(11,23,1),fpp(11,23,2)/ 0.00000000d+00, 4.97440280d-09/
      data fpp(12, 1,1),fpp(12, 1,2)/ 0.00000000d+00,-1.80914735d-05/
      data fpp(12, 2,1),fpp(12, 2,2)/ 6.83334463d-06, 9.68414701d-06/
      data fpp(12, 3,1),fpp(12, 3,2)/-7.45412810d-03, 1.50260854d-05/
      data fpp(12, 4,1),fpp(12, 4,2)/-6.43881330d-03, 9.88859112d-05/
      data fpp(12, 5,1),fpp(12, 5,2)/ 1.22804782d-02,-2.08607330d-04/
      data fpp(12, 6,1),fpp(12, 6,2)/ 2.41330166d-02, 5.68114097d-05/
      data fpp(12, 7,1),fpp(12, 7,2)/ 6.46871896d-03, 1.41504914d-05/
      data fpp(12, 8,1),fpp(12, 8,2)/ 7.22794244d-04, 1.59754247d-05/
      data fpp(12, 9,1),fpp(12, 9,2)/-3.71045652d-04, 2.64060971d-06/
      data fpp(12,10,1),fpp(12,10,2)/-1.98690402d-04,-6.14341488d-07/
      data fpp(12,11,1),fpp(12,11,2)/ 4.51444944d-06,-2.43756046d-10/
      data fpp(12,12,1),fpp(12,12,2)/ 3.36495100d-05,-2.68348769d-09/
      data fpp(12,13,1),fpp(12,13,2)/ 5.88089589d-06,-3.58222932d-08/
      data fpp(12,14,1),fpp(12,14,2)/ 1.19008773d-05,-1.62733954d-09/
      data fpp(12,15,1),fpp(12,15,2)/-9.76277305d-05,-3.08683486d-08/
      data fpp(12,16,1),fpp(12,16,2)/-4.19977282d-05, 5.55007341d-08/
      data fpp(12,17,1),fpp(12,17,2)/-1.44118122d-05, 3.26654122d-08/
      data fpp(12,18,1),fpp(12,18,2)/-1.02533199d-05,-2.56238283d-09/
      data fpp(12,19,1),fpp(12,19,2)/-1.57403962d-06,-2.06158808d-08/
      data fpp(12,20,1),fpp(12,20,2)/ 3.49132615d-06,-8.57409379d-09/
      data fpp(12,21,1),fpp(12,21,2)/ 1.14500293d-06,-2.68774398d-09/
      data fpp(12,22,1),fpp(12,22,2)/-1.96590980d-06,-4.74930292d-10/
      data fpp(12,23,1),fpp(12,23,2)/ 0.00000000d+00, 2.78746515d-09/
      data fpp(13, 1,1),fpp(13, 1,2)/ 0.00000000d+00,-8.25534884d-06/
      data fpp(13, 2,1),fpp(13, 2,2)/ 2.59501969d-06, 3.49897688d-07/
      data fpp(13, 3,1),fpp(13, 3,2)/ 4.65992191d-03, 7.07175809d-06/
      data fpp(13, 4,1),fpp(13, 4,2)/ 1.27253065d-02, 2.03854699d-05/
      data fpp(13, 5,1),fpp(13, 5,2)/ 2.37130824d-02,-4.12832379d-05/
      data fpp(13, 6,1),fpp(13, 6,2)/ 7.04745610d-03, 5.59068151d-06/
      data fpp(13, 7,1),fpp(13, 7,2)/ 2.31686407d-03, 3.36371181d-06/
      data fpp(13, 8,1),fpp(13, 8,2)/ 3.08232871d-04, 4.69767125d-06/
      data fpp(13, 9,1),fpp(13, 9,2)/-1.89190610d-04, 1.08240320d-06/
      data fpp(13,10,1),fpp(13,10,2)/-7.11296856d-05,-1.81645217d-07/
      data fpp(13,11,1),fpp(13,11,2)/-4.18849734d-06, 2.15776695d-08/
      data fpp(13,12,1),fpp(13,12,2)/-2.92999670d-05,-3.36654611d-08/
      data fpp(13,13,1),fpp(13,13,2)/ 9.33162294d-07, 1.28841748d-08/
      data fpp(13,14,1),fpp(13,14,2)/-1.99792915d-05,-2.80712380d-08/
      data fpp(13,15,1),fpp(13,15,2)/ 2.51634967d-05, 3.40077729d-09/
      data fpp(13,16,1),fpp(13,16,2)/-7.86277471d-06, 2.22681289d-08/
      data fpp(13,17,1),fpp(13,17,2)/-2.28178616d-05, 1.97267072d-08/
      data fpp(13,18,1),fpp(13,18,2)/-1.13591725d-05,-3.74957824d-10/
      data fpp(13,19,1),fpp(13,19,2)/-2.92064210d-06,-1.22268759d-08/
      data fpp(13,20,1),fpp(13,20,2)/-3.38951364d-06,-7.11753841d-09/
      data fpp(13,21,1),fpp(13,21,2)/-5.55397311d-06, 1.69702957d-09/
      data fpp(13,22,1),fpp(13,22,2)/-1.49652103d-06,-1.47057988d-09/
      data fpp(13,23,1),fpp(13,23,2)/ 0.00000000d+00,-1.21471006d-09/
      data fpp(14, 1,1),fpp(14, 1,2)/ 0.00000000d+00,-1.97852248d-06/
      data fpp(14, 2,1),fpp(14, 2,2)/-5.21342339d-06,-1.50155049d-07/
      data fpp(14, 3,1),fpp(14, 3,2)/-1.39955956d-03, 2.48314267d-06/
      data fpp(14, 4,1),fpp(14, 4,2)/-1.92707943d-03, 2.29918436d-06/
      data fpp(14, 5,1),fpp(14, 5,2)/-2.72141158d-04,-5.30788011d-06/
      data fpp(14, 6,1),fpp(14, 6,2)/ 1.95315902d-03,-1.52526392d-06/
      data fpp(14, 7,1),fpp(14, 7,2)/ 7.22491433d-04, 6.68935782d-07/
      data fpp(14, 8,1),fpp(14, 8,2)/ 9.76076041d-05, 1.23032079d-06/
      data fpp(14, 9,1),fpp(14, 9,2)/-4.08585735d-05, 4.50581057d-07/
      data fpp(14,10,1),fpp(14,10,2)/-2.79085623d-06,-1.93035649d-08/
      data fpp(14,11,1),fpp(14,11,2)/-2.37604601d-05,-1.09667970d-08/
      data fpp(14,12,1),fpp(14,12,2)/ 1.88836912d-05,-7.62924729d-09/
      data fpp(14,13,1),fpp(14,13,2)/ 1.83864549d-05,-2.91621389d-09/
      data fpp(14,14,1),fpp(14,14,2)/ 1.93496221d-05,-5.90589714d-09/
      data fpp(14,15,1),fpp(14,15,2)/-2.56929231d-05, 1.39802444d-10/
      data fpp(14,16,1),fpp(14,16,2)/-1.58845062d-05, 7.14668736d-09/
      data fpp(14,17,1),fpp(14,17,2)/ 3.49925291d-07, 1.74734481d-08/
      data fpp(14,18,1),fpp(14,18,2)/-1.64332356d-06,-1.44047980d-09/
      data fpp(14,19,1),fpp(14,19,2)/-5.41005863d-06,-9.91152889d-09/
      data fpp(14,20,1),fpp(14,20,2)/ 7.33395090d-07,-4.51340463d-09/
      data fpp(14,21,1),fpp(14,21,2)/ 1.70708895d-05, 3.96514740d-09/
      data fpp(14,22,1),fpp(14,22,2)/ 2.61866057d-06,-1.14718497d-09/
      data fpp(14,23,1),fpp(14,23,2)/ 0.00000000d+00,-2.37640751d-09/
      data fpp(15, 1,1),fpp(15, 1,2)/ 0.00000000d+00,-5.28660362d-07/
      data fpp(15, 2,1),fpp(15, 2,2)/ 6.67458741d-06, 1.85207244d-08/
      data fpp(15, 3,1),fpp(15, 3,2)/ 3.03414911d-04, 6.72977465d-07/
      data fpp(15, 4,1),fpp(15, 4,2)/ 1.28393736d-03, 9.51969417d-07/
      data fpp(15, 5,1),fpp(15, 5,2)/ 1.94358218d-03,-1.45445513d-06/
      data fpp(15, 6,1),fpp(15, 6,2)/ 8.62020764d-04,-1.05014889d-06/
      data fpp(15, 7,1),fpp(15, 7,2)/ 3.83246731d-04, 8.70506835d-08/
      data fpp(15, 8,1),fpp(15, 8,2)/ 9.01126725d-05, 5.17146154d-07/
      data fpp(15, 9,1),fpp(15, 9,2)/-6.42121729d-06, 2.53964701d-07/
      data fpp(15,10,1),fpp(15,10,2)/-2.85119051d-06,-7.66717887d-09/
      data fpp(15,11,1),fpp(15,11,2)/ 5.55850465d-05, 2.30401485d-09/
      data fpp(15,12,1),fpp(15,12,2)/-5.46850557d-06,-9.34888052d-09/
      data fpp(15,13,1),fpp(15,13,2)/-2.38320181d-05,-8.10849275d-09/
      data fpp(15,14,1),fpp(15,14,2)/-7.77917337d-06,-7.41714846d-09/
      data fpp(15,15,1),fpp(15,15,2)/ 2.17193706d-05, 1.07770866d-08/
      data fpp(15,16,1),fpp(15,16,2)/-4.28330673d-06, 2.70880212d-09/
      data fpp(15,17,1),fpp(15,17,2)/-1.40228341d-05, 1.07877049d-08/
      data fpp(15,18,1),fpp(15,18,2)/-9.74462348d-06,-2.05962190d-09/
      data fpp(15,19,1),fpp(15,19,2)/-6.87436967d-08,-6.74921734d-09/
      data fpp(15,20,1),fpp(15,20,2)/ 4.17295016d-07, 1.45649124d-09/
      data fpp(15,21,1),fpp(15,21,2)/-2.75234880d-05,-5.07674764d-09/
      data fpp(15,22,1),fpp(15,22,2)/ 1.65147868d-06, 2.05049933d-09/
      data fpp(15,23,1),fpp(15,23,2)/ 0.00000000d+00, 5.27475034d-09/
      data fpp(16, 1,1),fpp(16, 1,2)/ 0.00000000d+00,-1.61337038d-07/
      data fpp(16, 2,1),fpp(16, 2,2)/-4.98492626d-06, 1.78740766d-08/
      data fpp(16, 3,1),fpp(16, 3,2)/-5.71000868d-05, 1.81040732d-07/
      data fpp(16, 4,1),fpp(16, 4,2)/-2.41700019d-05, 4.00362995d-07/
      data fpp(16, 5,1),fpp(16, 5,2)/ 1.85312426d-04,-3.80892714d-07/
      data fpp(16, 6,1),fpp(16, 6,2)/ 3.57257927d-04,-5.42392140d-07/
      data fpp(16, 7,1),fpp(16, 7,2)/ 1.94021643d-04,-5.35387252d-08/
      data fpp(16, 8,1),fpp(16, 8,2)/ 6.24417058d-05, 2.14147041d-07/
      data fpp(16, 9,1),fpp(16, 9,2)/ 1.55434426d-05, 1.47350561d-07/
      data fpp(16,10,1),fpp(16,10,2)/ 5.19561827d-06, 2.87479715d-09/
      data fpp(16,11,1),fpp(16,11,2)/-4.40797258d-05,-2.14497494d-08/
      data fpp(16,12,1),fpp(16,12,2)/-6.00966895d-06, 7.32420034d-09/
      data fpp(16,13,1),fpp(16,13,2)/ 1.24416174d-05,-6.64705200d-09/
      data fpp(16,14,1),fpp(16,14,2)/ 7.26707134d-06,-7.73599235d-09/
      data fpp(16,15,1),fpp(16,15,2)/-1.31845592d-05, 6.99102139d-09/
      data fpp(16,16,1),fpp(16,16,2)/ 1.05177331d-05, 5.57190679d-09/
      data fpp(16,17,1),fpp(16,17,2)/ 4.74141092d-06, 6.12135143d-09/
      data fpp(16,18,1),fpp(16,18,2)/ 3.12181748d-06,-1.25731252d-09/
      data fpp(16,19,1),fpp(16,19,2)/ 1.18503342d-06,-3.49210134d-09/
      data fpp(16,20,1),fpp(16,20,2)/-2.40257515d-06,-5.77428211d-09/
      data fpp(16,21,1),fpp(16,21,2)/ 1.80230624d-05, 6.78922980d-09/
      data fpp(16,22,1),fpp(16,22,2)/-4.72457527d-06,-3.38263709d-09/
      data fpp(16,23,1),fpp(16,23,2)/ 0.00000000d+00,-7.05868146d-09/
      data fpp(17, 1,1),fpp(17, 1,2)/ 0.00000000d+00,-1.03130840d-08/
      data fpp(17, 2,1),fpp(17, 2,2)/ 4.83336260d-06, 1.26261679d-08/
      data fpp(17, 3,1),fpp(17, 3,2)/ 1.70570155d-05, 1.74084122d-08/
      data fpp(17, 4,1),fpp(17, 4,2)/ 6.92751017d-05, 8.57401833d-08/
      data fpp(17, 5,1),fpp(17, 5,2)/ 1.25237123d-04,-3.39691453d-08/
      data fpp(17, 6,1),fpp(17, 6,2)/ 9.87930677d-05,-1.65863602d-07/
      data fpp(17, 7,1),fpp(17, 7,2)/ 7.00967033d-05,-4.41764459d-08/
      data fpp(17, 8,1),fpp(17, 8,2)/ 3.51191990d-05, 6.65693859d-08/
      data fpp(17, 9,1),fpp(17, 9,2)/ 1.28026694d-05, 7.30989022d-08/
      data fpp(17,10,1),fpp(17,10,2)/-2.57512672d-05,-1.79813995d-08/
      data fpp(17,11,1),fpp(17,11,2)/ 1.85423883d-05,-5.37330417d-09/
      data fpp(17,12,1),fpp(17,12,2)/ 1.36779002d-05, 8.27461619d-09/
      data fpp(17,13,1),fpp(17,13,2)/-4.91737938d-06,-5.52516060d-09/
      data fpp(17,14,1),fpp(17,14,2)/-9.37078887d-06,-1.73739738d-08/
      data fpp(17,15,1),fpp(17,15,2)/ 1.21356169d-05, 2.46210558d-08/
      data fpp(17,16,1),fpp(17,16,2)/-8.87023935d-06,-1.33102494d-08/
      data fpp(17,17,1),fpp(17,17,2)/-6.78948037d-06, 1.06199419d-08/
      data fpp(17,18,1),fpp(17,18,2)/-3.57630928d-06,-9.69518106d-10/
      data fpp(17,19,1),fpp(17,19,2)/-2.57094892d-06,-6.14186946d-09/
      data fpp(17,20,1),fpp(17,20,2)/-9.36279501d-07, 4.53699594d-09/
      data fpp(17,21,1),fpp(17,21,2)/-6.72788260d-06,-4.20611429d-09/
      data fpp(17,22,1),fpp(17,22,2)/ 3.31426513d-06, 1.48746123d-09/
      data fpp(17,23,1),fpp(17,23,2)/ 0.00000000d+00, 3.05626939d-09/
      data fpp(18, 1,1),fpp(18, 1,2)/ 0.00000000d+00,-1.16700603d-08/
      data fpp(18, 2,1),fpp(18, 2,2)/-4.34852416d-06,-3.45987942d-09/
      data fpp(18, 3,1),fpp(18, 3,2)/-2.46130845d-06, 8.70957799d-09/
      data fpp(18, 4,1),fpp(18, 4,2)/-1.09304048d-05, 7.02156748d-09/
      data fpp(18, 5,1),fpp(18, 5,2)/ 5.73908134d-06,-5.59584791d-09/
      data fpp(18, 6,1),fpp(18, 6,2)/ 2.89031356d-05,-4.94381758d-08/
      data fpp(18, 7,1),fpp(18, 7,2)/ 2.69248772d-05,-5.45144878d-09/
      data fpp(18, 8,1),fpp(18, 8,2)/ 1.24148316d-05, 4.00439709d-08/
      data fpp(18, 9,1),fpp(18, 9,2)/ 7.24587986d-06, 6.07556501d-09/
      data fpp(18,10,1),fpp(18,10,2)/ 4.11427840d-05, 1.57513195d-08/
      data fpp(18,11,1),fpp(18,11,2)/ 5.76839212d-07,-1.86808430d-08/
      data fpp(18,12,1),fpp(18,12,2)/-6.70193183d-06, 3.77205235d-09/
      data fpp(18,13,1),fpp(18,13,2)/ 3.22790009d-06,-4.80736645d-09/
      data fpp(18,14,1),fpp(18,14,2)/ 2.21608416d-06,-1.42586560d-10/
      data fpp(18,15,1),fpp(18,15,2)/-1.13579086d-05, 3.57771269d-09/
      data fpp(18,16,1),fpp(18,16,2)/-9.70344243d-06,-3.96826420d-09/
      data fpp(18,17,1),fpp(18,17,2)/ 2.41651054d-06, 6.89534410d-09/
      data fpp(18,18,1),fpp(18,18,2)/-1.49913676d-07,-1.41311219d-09/
      data fpp(18,19,1),fpp(18,19,2)/ 1.09876227d-06,-2.44289535d-09/
      data fpp(18,20,1),fpp(18,20,2)/ 1.48143598d-05, 2.18469360d-09/
      data fpp(18,21,1),fpp(18,21,2)/-1.11153196d-06,-2.69587905d-09/
      data fpp(18,22,1),fpp(18,22,2)/-1.86581857d-06, 7.98822585d-10/
      data fpp(18,23,1),fpp(18,23,2)/ 0.00000000d+00, 1.90058871d-09/
      data fpp(19, 1,1),fpp(19, 1,2)/ 0.00000000d+00, 1.97865050d-10/
      data fpp(19, 2,1),fpp(19, 2,2)/ 1.49257687d-06, 4.04269900d-10/
      data fpp(19, 3,1),fpp(19, 3,2)/-7.78980962d-07,-6.61494465d-09/
      data fpp(19, 4,1),fpp(19, 4,2)/ 9.73937134d-06, 1.16555087d-08/
      data fpp(19, 5,1),fpp(19, 5,2)/ 4.44890874d-06,-2.08070901d-08/
      data fpp(19, 6,1),fpp(19, 6,2)/ 1.37947204d-05,-1.48271481d-08/
      data fpp(19, 7,1),fpp(19, 7,2)/ 1.12305592d-05, 9.15682732d-10/
      data fpp(19, 8,1),fpp(19, 8,2)/ 1.17470437d-05, 3.27644172d-08/
      data fpp(19, 9,1),fpp(19, 9,2)/-1.09334034d-05, 7.22664838d-09/
      data fpp(19,10,1),fpp(19,10,2)/-2.75870192d-05,-8.62153751d-10/
      data fpp(19,11,1),fpp(19,11,2)/-2.21977785d-05,-7.37803338d-09/
      data fpp(19,12,1),fpp(19,12,2)/-5.00719114d-06, 9.74287253d-10/
      data fpp(19,13,1),fpp(19,13,2)/-7.63431360d-07,-4.31911564d-09/
      data fpp(19,14,1),fpp(19,14,2)/ 1.84757625d-05, 3.70217529d-09/
      data fpp(19,15,1),fpp(19,15,2)/ 8.61175096d-08,-4.48958552d-09/
      data fpp(19,16,1),fpp(19,16,2)/ 2.03225712d-05, 6.45616677d-09/
      data fpp(19,17,1),fpp(19,17,2)/-2.89833216d-06,-9.35081577d-10/
      data fpp(19,18,1),fpp(19,18,2)/ 4.61403231d-06,-9.15840466d-10/
      data fpp(19,19,1),fpp(19,19,2)/ 5.36261202d-06, 5.79844344d-09/
      data fpp(19,20,1),fpp(19,20,2)/-2.91673799d-05,-1.20779333d-08/
      data fpp(19,21,1),fpp(19,21,2)/ 6.64948370d-06, 7.71328973d-09/
      data fpp(19,22,1),fpp(19,22,2)/ 8.57695145d-07,-1.37522564d-09/
      data fpp(19,23,1),fpp(19,23,2)/ 0.00000000d+00,-2.21238718d-09/
      data fpp(20, 1,1),fpp(20, 1,2)/ 0.00000000d+00, 2.31340965d-10/
      data fpp(20, 2,1),fpp(20, 2,2)/-1.21783331d-07,-1.26268193d-09/
      data fpp(20, 3,1),fpp(20, 3,2)/ 1.07723230d-06, 1.93867575d-11/
      data fpp(20, 4,1),fpp(20, 4,2)/-2.52708060d-06,-8.41486510d-09/
      data fpp(20, 5,1),fpp(20, 5,2)/ 6.46528370d-06, 4.00736394d-11/
      data fpp(20, 6,1),fpp(20, 6,2)/ 1.41798273d-06,-1.81454295d-08/
      data fpp(20, 7,1),fpp(20, 7,2)/ 4.65288604d-06, 1.97416442d-08/
      data fpp(20, 8,1),fpp(20, 8,2)/-3.90300634d-06,-5.62114732d-09/
      data fpp(20, 9,1),fpp(20, 9,2)/ 1.39877336d-05, 2.91429451d-08/
      data fpp(20,10,1),fpp(20,10,2)/ 1.70529271d-06,-1.98182615d-08/
      data fpp(20,11,1),fpp(20,11,2)/ 2.07142749d-05, 1.05301011d-08/
      data fpp(20,12,1),fpp(20,12,2)/ 4.23069637d-06,-7.90214296d-09/
      data fpp(20,13,1),fpp(20,13,2)/-1.74174646d-07, 4.87847073d-09/
      data fpp(20,14,1),fpp(20,14,2)/-2.81191341d-05,-1.10117399d-08/
      data fpp(20,15,1),fpp(20,15,2)/ 5.13438547d-07, 1.03684890d-08/
      data fpp(20,16,1),fpp(20,16,2)/-1.45868423d-05,-5.86221617d-09/
      data fpp(20,17,1),fpp(20,17,2)/ 1.76818106d-07, 5.88037565d-09/
      data fpp(20,18,1),fpp(20,18,2)/-6.30621555d-06,-1.45928644d-09/
      data fpp(20,19,1),fpp(20,19,2)/-7.54921034d-06,-3.64322988d-09/
      data fpp(20,20,1),fpp(20,20,2)/ 1.63551596d-05, 4.03220595d-09/
      data fpp(20,21,1),fpp(20,21,2)/-4.48640284d-06,-2.88559391d-09/
      data fpp(20,22,1),fpp(20,22,2)/ 2.93503799d-06, 9.10169688d-10/
      data fpp(20,23,1),fpp(20,23,2)/ 0.00000000d+00, 1.64491516d-09/
      data fpp(21, 1,1),fpp(21, 1,2)/ 0.00000000d+00, 1.16202055d-09/
      data fpp(21, 2,1),fpp(21, 2,2)/-2.55773479d-07,-3.24041105d-10/
      data fpp(21, 3,1),fpp(21, 3,2)/-1.73812036d-06,-2.26585613d-09/
      data fpp(21, 4,1),fpp(21, 4,2)/ 1.59735443d-06,-2.61253436d-09/
      data fpp(21, 5,1),fpp(21, 5,2)/-1.85021815d-06,-1.12840064d-08/
      data fpp(21, 6,1),fpp(21, 6,2)/ 3.41024395d-06, 9.34856006d-09/
      data fpp(21, 7,1),fpp(21, 7,2)/-1.99665961d-06,-6.91023380d-09/
      data fpp(21, 8,1),fpp(21, 8,2)/ 1.17865866d-06, 2.06923751d-08/
      data fpp(21, 9,1),fpp(21, 9,2)/-7.33684298d-06, 9.40733207d-10/
      data fpp(21,10,1),fpp(21,10,2)/ 8.70703709d-06,-4.16838720d-09/
      data fpp(21,11,1),fpp(21,11,2)/-6.91573065d-06, 7.32815574d-10/
      data fpp(21,12,1),fpp(21,12,2)/-1.09752715d-06, 1.23712490d-09/
      data fpp(21,13,1),fpp(21,13,2)/-2.43796940d-07,-1.04813152d-08/
      data fpp(21,14,1),fpp(21,14,2)/ 1.64132722d-05, 1.36881358d-08/
      data fpp(21,15,1),fpp(21,15,2)/-4.35540164d-07,-8.27122790d-09/
      data fpp(21,16,1),fpp(21,16,2)/ 4.07442687d-06, 3.79677585d-09/
      data fpp(21,17,1),fpp(21,17,2)/-1.32383891d-06,-9.15875479d-10/
      data fpp(21,18,1),fpp(21,18,2)/ 1.61136362d-06,-1.33273928d-10/
      data fpp(21,19,1),fpp(21,19,2)/ 2.92229312d-06, 8.48971191d-10/
      data fpp(21,20,1),fpp(21,20,2)/-4.40561219d-06,-2.06261083d-09/
      data fpp(21,21,1),fpp(21,21,2)/ 1.18835365d-06, 3.20147215d-09/
      data fpp(21,22,1),fpp(21,22,2)/-3.68859006d-06,-2.94327776d-09/
      data fpp(21,23,1),fpp(21,23,2)/ 0.00000000d+00,-5.82836112d-09/
      data fpp(22, 1,1),fpp(22, 1,2)/ 0.00000000d+00,-8.52868678d-09/
      data fpp(22, 2,1),fpp(22, 2,2)/ 3.31545132d-07,-5.34262644d-09/
      data fpp(22, 3,1),fpp(22, 3,2)/ 2.67564576d-06, 2.02991925d-08/
      data fpp(22, 4,1),fpp(22, 4,2)/-1.59528583d-06,-3.26541437d-08/
      data fpp(22, 5,1),fpp(22, 5,2)/ 1.40152786d-06, 3.35173823d-08/
      data fpp(22, 6,1),fpp(22, 6,2)/-2.72357027d-06,-3.66153855d-08/
      data fpp(22, 7,1),fpp(22, 7,2)/-2.42087552d-09, 2.89441596d-08/
      data fpp(22, 8,1),fpp(22, 8,2)/-2.62990390d-06,-1.43612529d-08/
      data fpp(22, 9,1),fpp(22, 9,2)/ 6.85257397d-07, 3.33008521d-08/
      data fpp(22,10,1),fpp(22,10,2)/-1.47256943d-05,-3.93219300d-08/
      data fpp(22,11,1),fpp(22,11,2)/ 1.94177313d-06, 2.37868677d-08/
      data fpp(22,12,1),fpp(22,12,2)/ 3.33669063d-07,-7.22554093d-09/
      data fpp(22,13,1),fpp(22,13,2)/ 4.84654995d-07, 2.11529599d-09/
      data fpp(22,14,1),fpp(22,14,2)/-6.85099041d-06,-1.83564304d-09/
      data fpp(22,15,1),fpp(22,15,2)/-1.94334602d-07, 1.02727615d-09/
      data fpp(22,16,1),fpp(22,16,2)/-1.64606060d-06, 1.26538430d-10/
      data fpp(22,17,1),fpp(22,17,2)/ 2.10193658d-07, 2.66570127d-10/
      data fpp(22,18,1),fpp(22,18,2)/-5.72634252d-07, 7.18106145d-12/
      data fpp(22,19,1),fpp(22,19,2)/-1.06181179d-06,-2.95294373d-10/
      data fpp(22,20,1),fpp(22,20,2)/ 1.24486324d-06,-2.60035702d-11/
      data fpp(22,21,1),fpp(22,21,2)/-3.10889992d-07,-2.00691346d-10/
      data fpp(22,22,1),fpp(22,22,2)/ 1.72246539d-06, 2.28768956d-10/
      data fpp(22,23,1),fpp(22,23,2)/ 0.00000000d+00, 4.85615522d-10/
      data fpp(23, 1,1),fpp(23, 1,2)/ 0.00000000d+00, 1.56882078d-08/
      data fpp(23, 2,1),fpp(23, 2,2)/-1.10407050d-07, 6.62358449d-09/
      data fpp(23, 3,1),fpp(23, 3,2)/-2.72446268d-06,-1.57825457d-08/
      data fpp(23, 4,1),fpp(23, 4,2)/ 1.66378889d-06, 8.50659836d-09/
      data fpp(23, 5,1),fpp(23, 5,2)/-1.11589328d-06, 3.35615228d-09/
      data fpp(23, 6,1),fpp(23, 6,2)/ 4.40371150d-08,-1.23312075d-08/
      data fpp(23, 7,1),fpp(23, 7,2)/-6.33656889d-07, 7.56867767d-09/
      data fpp(23, 8,1),fpp(23, 8,2)/ 9.40956953d-07, 3.65649680d-09/
      data fpp(23, 9,1),fpp(23, 9,2)/-9.24186609d-07,-2.99466488d-09/
      data fpp(23,10,1),fpp(23,10,2)/ 9.39574015d-06, 2.35574625d-09/
      data fpp(23,11,1),fpp(23,11,2)/-8.51361856d-07,-1.62832011d-09/
      data fpp(23,12,1),fpp(23,12,2)/ 2.42850898d-07, 5.57534177d-10/
      data fpp(23,13,1),fpp(23,13,2)/-2.54823039d-07,-6.01816604d-10/
      data fpp(23,14,1),fpp(23,14,2)/ 2.35068947d-06, 4.97322370d-11/
      data fpp(23,15,1),fpp(23,15,2)/ 1.28785736d-08,-1.97112344d-10/
      data fpp(23,16,1),fpp(23,16,2)/ 5.89815545d-07, 7.38717141d-10/
      data fpp(23,17,1),fpp(23,17,2)/-2.36935721d-07,-3.57756219d-10/
      data fpp(23,18,1),fpp(23,18,2)/-4.08266117d-08, 9.23077360d-11/
      data fpp(23,19,1),fpp(23,19,2)/ 3.64954023d-07,-1.14747248d-11/
      data fpp(23,20,1),fpp(23,20,2)/-3.33840769d-07,-4.64088366d-11/
      data fpp(23,21,1),fpp(23,21,2)/ 5.52063153d-08,-4.02889929d-10/
      data fpp(23,22,1),fpp(23,22,2)/-3.21271498d-07, 4.57968551d-10/
      data fpp(23,23,1),fpp(23,23,2)/ 0.00000000d+00, 9.71015724d-10/
      data fpp(24, 1,1),fpp(24, 1,2)/ 0.00000000d+00,-4.26416155d-09/
      data fpp(24, 2,1),fpp(24, 2,2)/ 1.10083067d-07,-2.27167690d-09/
      data fpp(24, 3,1),fpp(24, 3,2)/ 1.74220496d-06, 1.09508692d-08/
      data fpp(24, 4,1),fpp(24, 4,2)/-1.45986972d-06,-1.51317997d-08/
      data fpp(24, 5,1),fpp(24, 5,2)/ 6.62045249d-07, 8.77632979d-09/
      data fpp(24, 6,1),fpp(24, 6,2)/ 3.87421805d-07,-3.17351941d-09/
      data fpp(24, 7,1),fpp(24, 7,2)/-1.02951570d-07, 3.91774784d-09/
      data fpp(24, 8,1),fpp(24, 8,2)/-1.37392391d-06,-5.29747196d-09/
      data fpp(24, 9,1),fpp(24, 9,2)/ 3.71489037d-07, 2.87214001d-09/
      data fpp(24,10,1),fpp(24,10,2)/-2.93726628d-06,-5.67684042d-10/
      data fpp(24,11,1),fpp(24,11,2)/ 5.03674297d-07, 5.98596159d-10/
      data fpp(24,12,1),fpp(24,12,2)/-5.85072657d-07,-1.22670059d-09/
      data fpp(24,13,1),fpp(24,13,2)/ 2.94637160d-07, 7.08206214d-10/
      data fpp(24,14,1),fpp(24,14,2)/-2.07176748d-06,-4.06124262d-10/
      data fpp(24,15,1),fpp(24,15,2)/-9.71796922d-08, 3.16290836d-10/
      data fpp(24,16,1),fpp(24,16,2)/-4.73201576d-07,-2.59039081d-10/
      data fpp(24,17,1),fpp(24,17,2)/ 1.75492242d-08, 1.19865490d-10/
      data fpp(24,18,1),fpp(24,18,2)/ 2.55940699d-07, 3.79577123d-10/
      data fpp(24,19,1),fpp(24,19,2)/-1.58004305d-07,-4.38173980d-10/
      data fpp(24,20,1),fpp(24,20,2)/ 9.04998368d-08, 1.73118799d-10/
      data fpp(24,21,1),fpp(24,21,2)/ 9.00647311d-08,-2.54301215d-10/
      data fpp(24,22,1),fpp(24,22,2)/ 4.26206037d-08, 2.44086061d-10/
      data fpp(24,23,1),fpp(24,23,2)/ 0.00000000d+00, 4.77956969d-10/
      data fpp(25, 1,1),fpp(25, 1,2)/ 0.00000000d+00, 2.04506395d-10/
      data fpp(25, 2,1),fpp(25, 2,2)/-8.99252175d-08, 3.90987210d-10/
      data fpp(25, 3,1),fpp(25, 3,2)/-6.44357162d-07,-1.76845524d-09/
      data fpp(25, 4,1),fpp(25, 4,2)/ 8.15689996d-07, 4.28283373d-09/
      data fpp(25, 5,1),fpp(25, 5,2)/-5.72287720d-07,-5.76287970d-09/
      data fpp(25, 6,1),fpp(25, 6,2)/-1.53724335d-07, 4.36868505d-09/
      data fpp(25, 7,1),fpp(25, 7,2)/-1.54536830d-07,-4.51186050d-09/
      data fpp(25, 8,1),fpp(25, 8,2)/ 7.14738679d-07, 6.47875695d-09/
      data fpp(25, 9,1),fpp(25, 9,2)/-5.61769541d-07,-4.60316728d-09/
      data fpp(25,10,1),fpp(25,10,2)/ 9.13324955d-07, 3.37012338d-09/
      data fpp(25,11,1),fpp(25,11,2)/-6.83335333d-07,-2.87732624d-09/
      data fpp(25,12,1),fpp(25,12,2)/ 4.17439731d-07, 2.73918159d-09/
      data fpp(25,13,1),fpp(25,13,2)/-4.43725600d-07,-4.47940010d-09/
      data fpp(25,14,1),fpp(25,14,2)/ 3.05638044d-06, 5.57841881d-09/
      data fpp(25,15,1),fpp(25,15,2)/ 1.35840195d-07,-3.43427515d-09/
      data fpp(25,16,1),fpp(25,16,2)/ 3.42990758d-07, 9.58681794d-10/
      data fpp(25,17,1),fpp(25,17,2)/ 1.66738824d-07, 1.99547976d-10/
      data fpp(25,18,1),fpp(25,18,2)/-2.62936183d-07,-5.56873699d-10/
      data fpp(25,19,1),fpp(25,19,2)/ 2.70631972d-08, 2.27946820d-10/
      data fpp(25,20,1),fpp(25,20,2)/-2.81585779d-08, 2.45086419d-10/
      data fpp(25,21,1),fpp(25,21,2)/-1.75465240d-07,-6.08292498d-10/
      data fpp(25,22,1),fpp(25,22,2)/-8.92109168d-08, 3.88083571d-10/
      data fpp(25,23,1),fpp(25,23,2)/ 0.00000000d+00, 8.55958215d-10/
      data fpp(26, 1,1),fpp(26, 1,2)/ 0.00000000d+00, 3.04373068d-10/
      data fpp(26, 2,1),fpp(26, 2,2)/ 9.61780323d-09, 1.91253863d-10/
      data fpp(26, 3,1),fpp(26, 3,2)/ 1.15223688d-07,-1.06938852d-09/
      data fpp(26, 4,1),fpp(26, 4,2)/-1.22890262d-07, 1.68630022d-09/
      data fpp(26, 5,1),fpp(26, 5,2)/ 1.87105633d-07,-8.75812362d-10/
      data fpp(26, 6,1),fpp(26, 6,2)/-1.25244646d-08,-5.83050772d-10/
      data fpp(26, 7,1),fpp(26, 7,2)/ 1.09888970d-09, 8.08015451d-10/
      data fpp(26, 8,1),fpp(26, 8,2)/-2.85030809d-07,-2.49011033d-10/
      data fpp(26, 9,1),fpp(26, 9,2)/ 1.95589126d-07, 1.88028681d-10/
      data fpp(26,10,1),fpp(26,10,2)/-2.36033544d-07,-4.39580526d-10/
      data fpp(26,11,1),fpp(26,11,2)/ 3.09667035d-07, 9.70293424d-10/
      data fpp(26,12,1),fpp(26,12,2)/-1.24686266d-07,-1.64159317d-09/
      data fpp(26,13,1),fpp(26,13,2)/ 2.80265242d-07, 3.79607925d-09/
      data fpp(26,14,1),fpp(26,14,2)/-1.99375429d-06,-5.14272383d-09/
      data fpp(26,15,1),fpp(26,15,2)/-2.06181089d-07, 2.97481608d-09/
      data fpp(26,16,1),fpp(26,16,2)/-1.78761455d-07,-7.56540506d-10/
      data fpp(26,17,1),fpp(26,17,2)/-2.04504520d-07, 5.13459388d-11/
      data fpp(26,18,1),fpp(26,18,2)/ 7.58040337d-08,-4.88432493d-11/
      data fpp(26,19,1),fpp(26,19,2)/ 4.97515163d-08, 1.44027059d-10/
      data fpp(26,20,1),fpp(26,20,2)/ 2.21344749d-08, 7.27350152d-11/
      data fpp(26,21,1),fpp(26,21,2)/ 1.31796228d-07,-4.34967119d-10/
      data fpp(26,22,1),fpp(26,22,2)/ 7.42230636d-08, 4.67133463d-10/
      data fpp(26,23,1),fpp(26,23,2)/ 0.00000000d+00, 9.66433269d-10/
      data fpp(27, 1,1),fpp(27, 1,2)/ 0.00000000d+00, 4.38373256d-12/
      data fpp(27, 2,1),fpp(27, 2,2)/ 1.61091991d-08,-8.76746511d-12/
      data fpp(27, 3,1),fpp(27, 3,2)/-2.34924822d-08, 3.06861279d-11/
      data fpp(27, 4,1),fpp(27, 4,2)/ 2.08257893d-08,-1.13977046d-10/
      data fpp(27, 5,1),fpp(27, 5,2)/-3.51730379d-08, 4.25222058d-10/
      data fpp(27, 6,1),fpp(27, 6,2)/-5.56443869d-09,-1.58691119d-09/
      data fpp(27, 7,1),fpp(27, 7,2)/ 1.39717458d-08, 1.12242268d-09/
      data fpp(27, 8,1),fpp(27, 8,2)/ 7.77230884d-08, 1.89722045d-09/
      data fpp(27, 9,1),fpp(27, 9,2)/-6.58826074d-08,-1.51130448d-09/
      data fpp(27,10,1),fpp(27,10,2)/ 1.14381555d-08,-1.46967967d-11/
      data fpp(27,11,1),fpp(27,11,2)/-4.73334386d-08, 3.70091662d-10/
      data fpp(27,12,1),fpp(27,12,2)/ 4.53389332d-08, 3.34330147d-10/
      data fpp(27,13,1),fpp(27,13,2)/-1.98932926d-07,-2.30741225d-09/
      data fpp(27,14,1),fpp(27,14,2)/ 4.33072655d-07, 3.49531885d-09/
      data fpp(27,15,1),fpp(27,15,2)/ 1.30623168d-07,-1.47386317d-09/
      data fpp(27,16,1),fpp(27,16,2)/ 4.78898725d-09,-5.99866180d-10/
      data fpp(27,17,1),fpp(27,17,2)/ 5.01441486d-08, 8.73327887d-10/
      data fpp(27,18,1),fpp(27,18,2)/-3.59440096d-08,-4.93445370d-10/
      data fpp(27,19,1),fpp(27,19,2)/-4.27861475d-08,-9.95464063d-11/
      data fpp(27,20,1),fpp(27,20,2)/ 7.67586432d-09, 2.91630996d-10/
      data fpp(27,21,1),fpp(27,21,2)/-1.27656065d-07,-4.66977576d-10/
      data fpp(27,22,1),fpp(27,22,2)/ 1.93626753d-09, 3.76279307d-10/
      data fpp(27,23,1),fpp(27,23,2)/ 0.00000000d+00, 7.61860346d-10/
      data fpp(28, 1,1),fpp(28, 1,2)/ 0.00000000d+00,-2.07191597d-09/
      data fpp(28, 2,1),fpp(28, 2,2)/ 4.59454005d-08,-1.05616806d-09/
      data fpp(28, 3,1),fpp(28, 3,2)/ 3.87462411d-08,-9.03411791d-10/
      data fpp(28, 4,1),fpp(28, 4,2)/-8.04128946d-08, 2.26981523d-09/
      data fpp(28, 5,1),fpp(28, 5,2)/-4.64134810d-08,-9.75849109d-10/
      data fpp(28, 6,1),fpp(28, 6,2)/ 3.47822193d-08,-7.66418788d-10/
      data fpp(28, 7,1),fpp(28, 7,2)/ 6.30141271d-08, 1.64152426d-09/
      data fpp(28, 8,1),fpp(28, 8,2)/ 1.54138456d-07,-9.99678261d-10/
      data fpp(28, 9,1),fpp(28, 9,2)/-1.12058696d-07,-4.28112186d-11/
      data fpp(28,10,1),fpp(28,10,2)/-4.97190778d-08, 2.82727861d-11/
      data fpp(28,11,1),fpp(28,11,2)/-1.20333281d-07, 1.12972007d-09/
      data fpp(28,12,1),fpp(28,12,2)/ 6.33305334d-08,-3.94715308d-09/
      data fpp(28,13,1),fpp(28,13,2)/-4.44533537d-07, 3.25889225d-09/
      data fpp(28,14,1),fpp(28,14,2)/ 1.34146367d-06, 2.91158406d-09/
      data fpp(28,15,1),fpp(28,15,2)/ 3.43688416d-07,-5.30522851d-09/
      data fpp(28,16,1),fpp(28,16,2)/ 3.96055064d-08, 2.70932998d-09/
      data fpp(28,17,1),fpp(28,17,2)/ 1.83927926d-07,-7.32091392d-10/
      data fpp(28,18,1),fpp(28,18,2)/-5.20279952d-08,-3.80964409d-10/
      data fpp(28,19,1),fpp(28,19,2)/-1.18606926d-07, 1.65594903d-09/
      data fpp(28,20,1),fpp(28,20,2)/ 7.16206784d-09,-3.84283170d-09/
      data fpp(28,21,1),fpp(28,21,2)/-2.81171967d-07, 4.71537776d-09/
      data fpp(28,22,1),fpp(28,22,2)/-2.19681338d-08,-1.81867936d-09/
      data fpp(28,23,1),fpp(28,23,2)/ 0.00000000d+00,-4.04066032d-09/
 
      data fpppp( 1, 1),fpppp( 1, 2)/ 5.51211795d-03, 7.69219869d-03/
      data fpppp( 1, 3),fpppp( 1, 4)/-3.55509655d-02, 8.01872276d-02/
      data fpppp( 1, 5),fpppp( 1, 6)/-7.82203357d-02, 1.06647296d-02/
      data fpppp( 1, 7),fpppp( 1, 8)/ 3.40591111d-02,-3.13658822d-02/
      data fpppp( 1, 9),fpppp( 1,10)/ 1.54039406d-02,-7.04607258d-03/
      data fpppp( 1,11),fpppp( 1,12)/ 2.32349142d-03,-3.93723495d-04/
      data fpppp( 1,13),fpppp( 1,14)/ 2.81645984d-05, 1.92531331d-05/
      data fpppp( 1,15),fpppp( 1,16)/ 3.16134562d-05,-9.18286334d-06/
      data fpppp( 1,17),fpppp( 1,18)/-1.85227953d-04, 1.02155917d-04/
      data fpppp( 1,19),fpppp( 1,20)/ 2.83807168d-06, 2.46652686d-05/
      data fpppp( 1,21),fpppp( 1,22)/-5.52460762d-06, 3.08649834d-06/
      data fpppp( 1,23) /             6.11609395d-07 /
      data fpppp( 2, 1),fpppp( 2, 2)/ 1.52803850d-03, 3.10869384d-03/
      data fpppp( 2, 3),fpppp( 2, 4)/-1.24349483d-02, 3.19564508d-02/
      data fpppp( 2, 5),fpppp( 2, 6)/-3.04326332d-02,-4.45306702d-03/
      data fpppp( 2, 7),fpppp( 2, 8)/ 2.19174336d-02,-1.61172514d-02/
      data fpppp( 2, 9),fpppp( 2,10)/ 7.73916621d-03,-3.47358916d-03/
      data fpppp( 2,11),fpppp( 2,12)/ 1.27406703d-03,-2.47938159d-04/
      data fpppp( 2,13),fpppp( 2,14)/ 1.21015325d-05, 1.79159653d-05/
      data fpppp( 2,15),fpppp( 2,16)/ 2.86934321d-05,-2.63578826d-05/
      data fpppp( 2,17),fpppp( 2,18)/-1.08730002d-04, 4.85954031d-05/
      data fpppp( 2,19),fpppp( 2,20)/ 1.55608122d-05, 1.56544025d-05/
      data fpppp( 2,21),fpppp( 2,22)/-2.88749931d-06, 1.80892176d-06/
      data fpppp( 2,23) /            -1.34178011d-07 /
      data fpppp( 3, 1),fpppp( 3, 2)/-7.03244279d-03, 5.63367683d-04/
      data fpppp( 3, 3),fpppp( 3, 4)/ 6.88140276d-03, 1.76716517d-02/
      data fpppp( 3, 5),fpppp( 3, 6)/-6.09698654d-02, 4.71886713d-02/
      data fpppp( 3, 7),fpppp( 3, 8)/-2.74656296d-03,-4.52401605d-03/
      data fpppp( 3, 9),fpppp( 3,10)/-1.12661531d-02, 1.00535242d-02/
      data fpppp( 3,11),fpppp( 3,12)/-3.59115189d-03, 7.76830485d-04/
      data fpppp( 3,13),fpppp( 3,14)/-2.33275800d-04, 7.60689393d-05/
      data fpppp( 3,15),fpppp( 3,16)/ 4.77415306d-06,-5.32968897d-05/
      data fpppp( 3,17),fpppp( 3,18)/ 2.03117572d-05,-4.98414341d-05/
      data fpppp( 3,19),fpppp( 3,20)/ 4.40504990d-05, 6.13746883d-07/
      data fpppp( 3,21),fpppp( 3,22)/ 2.03628256d-06,-2.65521858d-07/
      data fpppp( 3,23) /            -1.50322911d-06 /
      data fpppp( 4, 1),fpppp( 4, 2)/ 4.24482346d-04,-9.11558393d-03/
      data fpppp( 4, 3),fpppp( 4, 4)/ 3.94965851d-02,-1.15424069d-01/
      data fpppp( 4, 5),fpppp( 4, 6)/ 1.82630174d-01,-1.34827963d-01/
      data fpppp( 4, 7),fpppp( 4, 8)/ 1.64175573d-02, 1.98631037d-02/
      data fpppp( 4, 9),fpppp( 4,10)/ 9.42043486d-03,-1.12605672d-02/
      data fpppp( 4,11),fpppp( 4,12)/ 4.89891007d-03,-1.27484245d-03/
      data fpppp( 4,13),fpppp( 4,14)/ 3.23946801d-04,-7.39935833d-05/
      data fpppp( 4,15),fpppp( 4,16)/ 5.43522662d-05,-4.60619397d-05/
      data fpppp( 4,17),fpppp( 4,18)/-3.45498130d-05, 8.78885909d-06/
      data fpppp( 4,19),fpppp( 4,20)/ 1.73558740d-05, 6.67735488d-06/
      data fpppp( 4,21),fpppp( 4,22)/-1.04329304d-06, 4.49069132d-07/
      data fpppp( 4,23) /            -6.90857292d-07 /
      data fpppp( 5, 1),fpppp( 5, 2)/-3.49145669d-03,-6.57293178d-03/
      data fpppp( 5, 3),fpppp( 5, 4)/ 2.34765463d-02,-6.24323117d-02/
      data fpppp( 5, 5),fpppp( 5, 6)/ 8.55652715d-02,-6.75422078d-02/
      data fpppp( 5, 7),fpppp( 5, 8)/ 5.45168195d-02,-3.32491149d-02/
      data fpppp( 5, 9),fpppp( 5,10)/ 2.30423311d-03, 2.01212472d-03/
      data fpppp( 5,11),fpppp( 5,12)/-1.07542771d-03, 2.57876559d-04/
      data fpppp( 5,13),fpppp( 5,14)/-7.42010541d-05, 3.36067572d-05/
      data fpppp( 5,15),fpppp( 5,16)/-3.77902056d-06,-7.33350343d-06/
      data fpppp( 5,17),fpppp( 5,18)/-2.74840952d-05, 8.10509614d-07/
      data fpppp( 5,19),fpppp( 5,20)/ 1.57595473d-05, 3.13815213d-06/
      data fpppp( 5,21),fpppp( 5,22)/-5.41926922d-07, 3.23192908d-07/
      data fpppp( 5,23) /            -1.10315514d-07 /
      data fpppp( 6, 1),fpppp( 6, 2)/ 1.01328023d-02, 6.85511532d-03/
      data fpppp( 6, 3),fpppp( 6, 4)/-3.55364852d-02, 5.89706119d-02/
      data fpppp( 6, 5),fpppp( 6, 6)/-8.17660872d-02, 1.03042648d-01/
      data fpppp( 6, 7),fpppp( 6, 8)/-6.78614238d-02, 2.04284162d-02/
      data fpppp( 6, 9),fpppp( 6,10)/-3.51301966d-03, 3.65415385d-04/
      data fpppp( 6,11),fpppp( 6,12)/-7.10949120d-05, 1.69190518d-06/
      data fpppp( 6,13),fpppp( 6,14)/-6.06967210d-06, 1.33992132d-05/
      data fpppp( 6,15),fpppp( 6,16)/ 2.56026899d-06,-5.78251691d-06/
      data fpppp( 6,17),fpppp( 6,18)/-2.43963779d-05, 6.67785964d-06/
      data fpppp( 6,19),fpppp( 6,20)/ 8.61347985d-06, 9.51107558d-07/
      data fpppp( 6,21),fpppp( 6,22)/ 8.79173935d-07, 4.39546410d-09/
      data fpppp( 6,23) /            -6.40998764d-07 /
      data fpppp( 7, 1),fpppp( 7, 2)/-1.20954177d-03, 3.82166660d-03/
      data fpppp( 7, 3),fpppp( 7, 4)/-1.80401008d-02, 5.42235470d-02/
      data fpppp( 7, 5),fpppp( 7, 6)/-6.55797176d-02, 2.29553474d-02/
      data fpppp( 7, 7),fpppp( 7, 8)/ 1.05424171d-02,-1.01117395d-02/
      data fpppp( 7, 9),fpppp( 7,10)/ 2.18130013d-03,-1.06247505d-04/
      data fpppp( 7,11),fpppp( 7,12)/-1.68314316d-06,-1.16980667d-05/
      data fpppp( 7,13),fpppp( 7,14)/ 5.61756323d-06,-2.86902621d-06/
      data fpppp( 7,15),fpppp( 7,16)/ 8.63271590d-06,-7.20373983d-06/
      data fpppp( 7,17),fpppp( 7,18)/-6.59066230d-06,-3.41749837d-09/
      data fpppp( 7,19),fpppp( 7,20)/ 4.15996534d-06, 1.01147093d-06/
      data fpppp( 7,21),fpppp( 7,22)/ 2.07784437d-07,-6.60236404d-08/
      data fpppp( 7,23) /            -4.91225552d-07 /
      data fpppp( 8, 1),fpppp( 8, 2)/ 9.90020744d-03, 3.59079301d-03/
      data fpppp( 8, 3),fpppp( 8, 4)/-2.47069332d-02, 2.39544318d-02/
      data fpppp( 8, 5),fpppp( 8, 6)/-1.88193073d-02, 4.99307102d-02/
      data fpppp( 8, 7),fpppp( 8, 8)/-4.68900907d-02, 1.63910193d-02/
      data fpppp( 8, 9),fpppp( 8,10)/-4.18328451d-03, 1.12835683d-03/
      data fpppp( 8,11),fpppp( 8,12)/-3.07067651d-04, 7.63387101d-05/
      data fpppp( 8,13),fpppp( 8,14)/-2.32188388d-05, 1.22015751d-05/
      data fpppp( 8,15),fpppp( 8,16)/-4.60160838d-06, 1.66469598d-06/
      data fpppp( 8,17),fpppp( 8,18)/-5.24937612d-06, 8.22203357d-07/
      data fpppp( 8,19),fpppp( 8,20)/ 1.61948995d-06, 6.25291073d-07/
      data fpppp( 8,21),fpppp( 8,22)/-4.02272322d-07, 2.05259280d-07/
      data fpppp( 8,23) /             3.45620883d-07 /
      data fpppp( 9, 1),fpppp( 9, 2)/-3.90389778d-03,-8.62003904d-03/
      data fpppp( 9, 3),fpppp( 9, 4)/ 3.91860050d-02,-9.68355995d-02/
      data fpppp( 9, 5),fpppp( 9, 6)/ 1.33020717d-01,-1.01954103d-01/
      data fpppp( 9, 7),fpppp( 9, 8)/ 4.40971556d-02,-1.25194620d-02/
      data fpppp( 9, 9),fpppp( 9,10)/ 2.70836528d-03,-7.60519808d-04/
      data fpppp( 9,11),fpppp( 9,12)/ 1.95706294d-04,-5.60469743d-05/
      data fpppp( 9,13),fpppp( 9,14)/ 1.64460487d-05,-6.87010004d-06/
      data fpppp( 9,15),fpppp( 9,16)/ 5.13676432d-06,-2.51440511d-06/
      data fpppp( 9,17),fpppp( 9,18)/-7.17435788d-07,-4.03624549d-07/
      data fpppp( 9,19),fpppp( 9,20)/ 8.30591909d-07, 2.15251489d-08/
      data fpppp( 9,21),fpppp( 9,22)/ 3.66146290d-07,-2.38539605d-07/
      data fpppp( 9,23) /            -5.71994917d-07 /
      data fpppp(10, 1),fpppp(10, 2)/-4.09707813d-03, 2.92504675d-03/
      data fpppp(10, 3),fpppp(10, 4)/-7.04743920d-03, 4.24612128d-02/
      data fpppp(10, 5),fpppp(10, 6)/-7.21388747d-02, 3.79928725d-02/
      data fpppp(10, 7),fpppp(10, 8)/-4.63885803d-03, 2.07540362d-03/
      data fpppp(10, 9),fpppp(10,10)/-4.35270587d-04, 1.30506740d-04/
      data fpppp(10,11),fpppp(10,12)/-4.32609318d-05, 1.09084698d-05/
      data fpppp(10,13),fpppp(10,14)/-3.97908109d-06, 2.55444352d-06/
      data fpppp(10,15),fpppp(10,16)/-1.29419741d-06, 1.57230001d-06/
      data fpppp(10,17),fpppp(10,18)/-1.65963447d-06, 4.67934258d-07/
      data fpppp(10,19),fpppp(10,20)/-7.56615221d-08, 2.18184643d-07/
      data fpppp(10,21),fpppp(10,22)/-3.76814152d-07, 3.17328085d-07/
      data fpppp(10,23) /             6.43144313d-07 /
      data fpppp(11, 1),fpppp(11, 2)/ 3.04995579d-04,-2.54118515d-04/
      data fpppp(11, 3),fpppp(11, 4)/ 2.46116875d-03,-6.28394874d-03/
      data fpppp(11, 5),fpppp(11, 6)/ 8.05467331d-03,-6.30949594d-03/
      data fpppp(11, 7),fpppp(11, 8)/ 2.30490128d-03,-2.11862566d-04/
      data fpppp(11, 9),fpppp(11,10)/ 1.40892422d-04,-3.71482052d-05/
      data fpppp(11,11),fpppp(11,12)/ 6.82629522d-06,-2.88129938d-06/
      data fpppp(11,13),fpppp(11,14)/-1.61009162d-07, 2.01185986d-06/
      data fpppp(11,15),fpppp(11,16)/-2.41682532d-06, 1.23307380d-06/
      data fpppp(11,17),fpppp(11,18)/-4.86506188d-08,-4.37484064d-07/
      data fpppp(11,19),fpppp(11,20)/ 2.34164797d-07,-2.33346088d-08/
      data fpppp(11,21),fpppp(11,22)/ 2.25283249d-07,-2.18393574d-07/
      data fpppp(11,23) /            -4.64271917d-07 /
      data fpppp(12, 1),fpppp(12, 2)/-9.38116698d-04,-2.95427660d-04/
      data fpppp(12, 3),fpppp(12, 4)/ 3.27556588d-04, 1.01950760d-03/
      data fpppp(12, 5),fpppp(12, 6)/-1.56632591d-04,-2.04099799d-03/
      data fpppp(12, 7),fpppp(12, 8)/ 1.23658392d-03,-4.49281774d-05/
      data fpppp(12, 9),fpppp(12,10)/ 5.96291503d-05,-1.48212597d-05/
      data fpppp(12,11),fpppp(12,12)/ 1.50686448d-06,-1.65038564d-06/
      data fpppp(12,13),fpppp(12,14)/ 1.68045760d-06,-3.04412905d-06/
      data fpppp(12,15),fpppp(12,16)/ 3.56314323d-06,-1.29892728d-06/
      data fpppp(12,17),fpppp(12,18)/-5.00792692d-08, 9.35989409d-08/
      data fpppp(12,19),fpppp(12,20)/-5.30692212d-08,-9.81569246d-08/
      data fpppp(12,21),fpppp(12,22)/ 9.95580443d-10, 4.82992323d-08/
      data fpppp(12,23) /             1.10416842d-07 /
      data fpppp(13, 1),fpppp(13, 2)/ 2.11448746d-04, 2.35404267d-04/
      data fpppp(13, 3),fpppp(13, 4)/-3.59301637d-05, 7.26250238d-04/
      data fpppp(13, 5),fpppp(13, 6)/-2.16769688d-03, 1.30772075d-03/
      data fpppp(13, 7),fpppp(13, 8)/-1.98777884d-04, 1.40661392d-04/
      data fpppp(13, 9),fpppp(13,10)/-1.17783118d-06,-2.27291320d-08/
      data fpppp(13,11),fpppp(13,12)/-1.79843648d-06, 1.69331558d-06/
      data fpppp(13,13),fpppp(13,14)/-1.65414992d-06, 1.85454912d-06/
      data fpppp(13,15),fpppp(13,16)/-1.80073202d-06, 6.58235371d-07/
      data fpppp(13,17),fpppp(13,18)/ 2.52061605d-07,-8.16552309d-08/
      data fpppp(13,19),fpppp(13,20)/-1.06650207d-07,-2.61880578d-08/
      data fpppp(13,21),fpppp(13,22)/ 1.09667162d-07,-3.91658952d-08/
      data fpppp(13,23) /            -1.06659445d-07 /
      data fpppp(14, 1),fpppp(14, 2)/-1.44964837d-04,-5.72429688d-05/
      data fpppp(14, 3),fpppp(14, 4)/ 4.05448620d-05, 1.03101824d-04/
      data fpppp(14, 5),fpppp(14, 6)/ 7.08377948d-05,-2.49566145d-04/
      data fpppp(14, 7),fpppp(14, 8)/ 9.79945254d-05, 2.97614464d-06/
      data fpppp(14, 9),fpppp(14,10)/ 6.84113237d-06,-3.11146507d-06/
      data fpppp(14,11),fpppp(14,12)/ 2.06248865d-06,-1.32166422d-06/
      data fpppp(14,13),fpppp(14,14)/ 6.35684972d-07,-1.13345146d-06/
      data fpppp(14,15),fpppp(14,16)/ 1.13777812d-06,-1.26603286d-07/
      data fpppp(14,17),fpppp(14,18)/-2.45804097d-07, 1.61588500d-08/
      data fpppp(14,19),fpppp(14,20)/ 7.47595238d-08, 2.79414382d-07/
      data fpppp(14,21),fpppp(14,22)/-5.80774608d-07, 1.96300648d-07/
      data fpppp(14,23) /             5.05586120d-07 /
      data fpppp(15, 1),fpppp(15, 2)/-2.55225296d-06, 8.41508326d-06/
      data fpppp(15, 3),fpppp(15, 4)/ 3.85076965d-05, 1.66184018d-06/
      data fpppp(15, 5),fpppp(15, 6)/-1.22165686d-04, 6.91114053d-05/
      data fpppp(15, 7),fpppp(15, 8)/-9.61096268d-06, 1.38860394d-05/
      data fpppp(15, 9),fpppp(15,10)/ 1.25084564d-06, 1.10271177d-06/
      data fpppp(15,11),fpppp(15,12)/-2.36972012d-06, 1.20678136d-06/
      data fpppp(15,13),fpppp(15,14)/ 1.03997060d-07, 4.42211839d-07/
      data fpppp(15,15),fpppp(15,16)/-1.06610246d-06, 4.92124737d-07/
      data fpppp(15,17),fpppp(15,18)/ 7.33925143d-08, 5.53694798d-08/
      data fpppp(15,19),fpppp(15,20)/ 2.89897191d-08,-7.22718820d-07/
      data fpppp(15,21),fpppp(15,22)/ 1.15627626d-06,-4.75441243d-07/
      data fpppp(15,23) /            -1.10409801d-06 /
      data fpppp(16, 1),fpppp(16, 2)/-7.20696950d-06,-1.81572749d-06/
      data fpppp(16, 3),fpppp(16, 4)/ 3.15862324d-06, 9.59209342d-06/
      data fpppp(16, 5),fpppp(16, 6)/ 8.45565493d-07,-2.19832181d-05/
      data fpppp(16, 7),fpppp(16, 8)/ 6.64367876d-06, 3.00602637d-06/
      data fpppp(16, 9),fpppp(16,10)/ 1.65581748d-06,-1.46354352d-06/
      data fpppp(16,11),fpppp(16,12)/ 1.86270542d-06,-7.46554094d-07/
      data fpppp(16,13),fpppp(16,14)/-5.36152678d-08,-4.56534783d-07/
      data fpppp(16,15),fpppp(16,16)/ 9.63129332d-07,-7.46747174d-07/
      data fpppp(16,17),fpppp(16,18)/ 2.55142487d-07,-2.44190476d-08/
      data fpppp(16,19),fpppp(16,20)/-1.76497734d-07, 6.31360515d-07/
      data fpppp(16,21),fpppp(16,22)/-9.08149561d-07, 4.10841218d-07/
      data fpppp(16,23) /             9.13117466d-07 /
      data fpppp(17, 1),fpppp(17, 2)/-9.39335140d-07, 1.57173668d-07/
      data fpppp(17, 3),fpppp(17, 4)/ 2.08431013d-06, 1.10424980d-06/
      data fpppp(17, 5),fpppp(17, 6)/-5.60276488d-06, 1.52935132d-06/
      data fpppp(17, 7),fpppp(17, 8)/-1.05519459d-06, 1.18395346d-06/
      data fpppp(17, 9),fpppp(17,10)/-6.41985293d-07, 1.69872651d-06/
      data fpppp(17,11),fpppp(17,12)/-1.18206521d-06, 8.00457130d-08/
      data fpppp(17,13),fpppp(17,14)/ 3.80348709d-08, 6.16327008d-07/
      data fpppp(17,15),fpppp(17,16)/-9.45753985d-07, 6.15953205d-07/
      data fpppp(17,17),fpppp(17,18)/-1.32861919d-07,-1.65608049d-08/
      data fpppp(17,19),fpppp(17,20)/ 6.66364949d-08,-2.12226631d-07/
      data fpppp(17,21),fpppp(17,22)/ 3.36693679d-07,-1.84523034d-07/
      data fpppp(17,23) /            -3.99986313d-07 /
      data fpppp(18, 1),fpppp(18, 2)/ 8.05581348d-07, 4.64490238d-07/
      data fpppp(18, 3),fpppp(18, 4)/-1.16696473d-06, 1.71785381d-06/
      data fpppp(18, 5),fpppp(18, 6)/ 3.28809293d-07,-1.47439462d-06/
      data fpppp(18, 7),fpppp(18, 8)/-4.65385863d-07, 3.28309153d-07/
      data fpppp(18, 9),fpppp(18,10)/ 1.39401178d-06,-1.69210147d-06/
      data fpppp(18,11),fpppp(18,12)/ 9.06623158d-07, 6.28392631d-08/
      data fpppp(18,13),fpppp(18,14)/-1.25464032d-07,-2.17482004d-07/
      data fpppp(18,15),fpppp(18,16)/ 2.41661439d-07, 1.64543783d-07/
      data fpppp(18,17),fpppp(18,18)/-2.71907362d-07, 4.19030340d-08/
      data fpppp(18,19),fpppp(18,20)/ 3.33201236d-07,-6.26692682d-07/
      data fpppp(18,21),fpppp(18,22)/ 3.95080134d-07,-4.33315432d-08/
      data fpppp(18,23) /            -6.45476507d-08 /
      data fpppp(19, 1),fpppp(19, 2)/-7.03017599d-07,-3.69984555d-07/
      data fpppp(19, 3),fpppp(19, 4)/ 1.27956349d-06,-1.67869096d-06/
      data fpppp(19, 5),fpppp(19, 6)/ 1.64108479d-06,-1.37294237d-06/
      data fpppp(19, 7),fpppp(19, 8)/ 9.92291213d-07,-1.85686751d-06/
      data fpppp(19, 9),fpppp(19,10)/ 8.67915251d-07, 4.71246987d-08/
      data fpppp(19,11),fpppp(19,12)/ 2.66157343d-07,-4.03673266d-07/
      data fpppp(19,13),fpppp(19,14)/ 5.71726062d-07,-9.83504939d-07/
      data fpppp(19,15),fpppp(19,16)/ 1.10456336d-06,-1.11718260d-06/
      data fpppp(19,17),fpppp(19,18)/ 7.56725617d-07,-6.57237969d-08/
      data fpppp(19,19),fpppp(19,20)/-8.99657514d-07, 1.54763956d-06/
      data fpppp(19,21),fpppp(19,22)/-1.07008940d-06, 2.36198898d-07/
      data fpppp(19,23) /             4.21339407d-07 /
      data fpppp(20, 1),fpppp(20, 2)/ 2.31321633d-07, 1.85782808d-07/
      data fpppp(20, 3),fpppp(20, 4)/-6.57461113d-07, 1.29126280d-06/
      data fpppp(20, 5),fpppp(20, 6)/-1.48438756d-06, 1.27676777d-06/
      data fpppp(20, 7),fpppp(20, 8)/-1.63495450d-06, 2.43325926d-06/
      data fpppp(20, 9),fpppp(20,10)/-1.75089079d-06, 1.15220749d-06/
      data fpppp(20,11),fpppp(20,12)/-9.80453791d-07, 6.40054032d-07/
      data fpppp(20,13),fpppp(20,14)/-8.55039885d-07, 1.36770020d-06/
      data fpppp(20,15),fpppp(20,16)/-1.22110899d-06, 8.92764532d-07/
      data fpppp(20,17),fpppp(20,18)/-5.58112669d-07, 6.48844987d-08/
      data fpppp(20,19),fpppp(20,20)/ 6.12977005d-07,-1.00795063d-06/
      data fpppp(20,21),fpppp(20,22)/ 7.34069588d-07,-2.32547518d-07/
      data fpppp(20,23) /            -4.25268244d-07 /
      data fpppp(21, 1),fpppp(21, 2)/-2.43695998d-07,-1.43348418d-07/
      data fpppp(21, 3),fpppp(21, 4)/ 5.22712053d-07,-7.91222593d-07/
      data fpppp(21, 5),fpppp(21, 6)/ 1.01424695d-06,-1.17583689d-06/
      data fpppp(21, 7),fpppp(21, 8)/ 1.12893284d-06,-1.28016124d-06/
      data fpppp(21, 9),fpppp(21,10)/ 1.18591533d-06,-9.33172362d-07/
      data fpppp(21,11),fpppp(21,12)/ 6.46775255d-07,-3.67470383d-07/
      data fpppp(21,13),fpppp(21,14)/ 5.25237881d-07,-7.85280807d-07/
      data fpppp(21,15),fpppp(21,16)/ 6.05532462d-07,-3.55322279d-07/
      data fpppp(21,17),fpppp(21,18)/ 2.21262686d-07,-2.97203654d-08/
      data fpppp(21,19),fpppp(21,20)/-1.99837606d-07, 3.10740701d-07/
      data fpppp(21,21),fpppp(21,22)/-2.67812927d-07, 1.32256432d-07/
      data fpppp(21,23) /             2.52719224d-07 /
      data fpppp(22, 1),fpppp(22, 2)/ 3.71230053d-07, 1.89253571d-07/
      data fpppp(22, 3),fpppp(22, 4)/-6.45231017d-07, 8.04062764d-07/
      data fpppp(22, 5),fpppp(22, 6)/-8.26761175d-07, 7.93723101d-07/
      data fpppp(22, 7),fpppp(22, 8)/-7.05031827d-07, 7.42732428d-07/
      data fpppp(22, 9),fpppp(22,10)/-8.39663246d-07, 8.25147065d-07/
      data fpppp(22,11),fpppp(22,12)/-5.36219867d-07, 2.23198113d-07/
      data fpppp(22,13),fpppp(22,14)/-2.51027184d-07, 3.31712742d-07/
      data fpppp(22,15),fpppp(22,16)/-2.36285711d-07, 1.26927195d-07/
      data fpppp(22,17),fpppp(22,18)/-7.29442536d-08, 6.50488904d-09/
      data fpppp(22,19),fpppp(22,20)/ 6.45437200d-08,-9.69286155d-08/
      data fpppp(22,21),fpppp(22,22)/ 9.14250465d-08,-5.34250535d-08/
      data fpppp(22,23) /            -1.03074079d-07 /
      data fpppp(23, 1),fpppp(23, 2)/-4.27441769d-07,-2.06030755d-07/
      data fpppp(23, 3),fpppp(23, 4)/ 6.50689128d-07,-7.16172031d-07/
      data fpppp(23, 5),fpppp(23, 6)/ 4.93694900d-07,-3.13100554d-07/
      data fpppp(23, 7),fpppp(23, 8)/ 3.17677461d-07,-4.17055408d-07/
      data fpppp(23, 9),fpppp(23,10)/ 5.25002393d-07,-5.23466643d-07/
      data fpppp(23,11),fpppp(23,12)/ 3.34842453d-07,-1.35424285d-07/
      data fpppp(23,13),fpppp(23,14)/ 1.11341483d-07,-1.23750463d-07/
      data fpppp(23,15),fpppp(23,16)/ 8.70609623d-08,-4.96085146d-08/
      data fpppp(23,17),fpppp(23,18)/ 2.71518018d-08, 2.37292968d-09/
      data fpppp(23,19),fpppp(23,20)/-2.40632290d-08, 2.76054608d-08/
      data fpppp(23,21),fpppp(23,22)/-2.10881014d-08, 1.08154509d-08/
      data fpppp(23,23) /             1.96912563d-08 /
      data fpppp(24, 1),fpppp(24, 2)/ 2.78474689d-07, 1.34194113d-07/
      data fpppp(24, 3),fpppp(24, 4)/-4.49961821d-07, 5.05445995d-07/
      data fpppp(24, 5),fpppp(24, 6)/-2.94064643d-07, 9.56433564d-08/
      data fpppp(24, 7),fpppp(24, 8)/-1.40288767d-07, 2.78167959d-07/
      data fpppp(24, 9),fpppp(24,10)/-2.48450601d-07, 1.98292950d-07/
      data fpppp(24,11),fpppp(24,12)/-1.39739448d-07, 8.88835886d-08/
      data fpppp(24,13),fpppp(24,14)/-9.76875005d-08, 1.07099546d-07/
      data fpppp(24,15),fpppp(24,16)/-7.02511377d-08, 3.28684248d-08/
      data fpppp(24,17),fpppp(24,18)/-9.21620041d-09,-1.11451826d-08/
      data fpppp(24,19),fpppp(24,20)/ 1.46567423d-08,-7.73483784d-09/
      data fpppp(24,21),fpppp(24,22)/ 1.34625421d-09,-4.70720315d-10/
      data fpppp(24,23) /             8.26038466d-10 /
      data fpppp(25, 1),fpppp(25, 2)/-1.00352095d-07,-5.33554837d-08/
      data fpppp(25, 3),fpppp(25, 4)/ 2.02292415d-07,-2.72339192d-07/
      data fpppp(25, 5),fpppp(25, 6)/ 2.03538384d-07,-1.08244479d-07/
      data fpppp(25, 7),fpppp(25, 8)/ 1.28789321d-07,-1.98091683d-07/
      data fpppp(25, 9),fpppp(25,10)/ 1.48589317d-07,-1.05035453d-07/
      data fpppp(25,11),fpppp(25,12)/ 8.72472094d-08,-8.21072631d-08/
      data fpppp(25,13),fpppp(25,14)/ 1.23465419d-07,-1.50078131d-07/
      data fpppp(25,15),fpppp(25,16)/ 9.16083285d-08,-2.86937342d-08/
      data fpppp(25,17),fpppp(25,18)/ 1.62458469d-10, 1.28385159d-08/
      data fpppp(25,19),fpppp(25,20)/-8.33605887d-09,-2.07549745d-10/
      data fpppp(25,21),fpppp(25,22)/ 3.64116464d-09,-3.43449716d-10/
      data fpppp(25,23) /            -2.08997015d-09 /
      data fpppp(26, 1),fpppp(26, 2)/ 1.80824600d-08, 1.05302830d-08/
      data fpppp(26, 3),fpppp(26, 4)/-3.71664523d-08, 5.56427661d-08/
      data fpppp(26, 5),fpppp(26, 6)/-5.38582493d-08, 3.74799928d-08/
      data fpppp(26, 7),fpppp(26, 8)/-4.48808936d-08, 7.01028488d-08/
      data fpppp(26, 9),fpppp(26,10)/-5.15105893d-08, 3.59085912d-08/
      data fpppp(26,11),fpppp(26,12)/-3.34843803d-08, 3.92256973d-08/
      data fpppp(26,13),fpppp(26,14)/-7.30601205d-08, 9.22765219d-08/
      data fpppp(26,15),fpppp(26,16)/-5.23504030d-08, 1.15158758d-08/
      data fpppp(26,17),fpppp(26,18)/ 3.09713796d-09,-5.54133049d-09/
      data fpppp(26,19),fpppp(26,20)/ 6.86519704d-10, 2.70138023d-09/
      data fpppp(26,21),fpppp(26,22)/-3.25531292d-09, 2.85776366d-10/
      data fpppp(26,23) /             1.11321353d-09 /
      data fpppp(27, 1),fpppp(27, 2)/-7.06966873d-09,-3.71643484d-09/
      data fpppp(27, 3),fpppp(27, 4)/ 8.56479681d-09,-1.04019637d-08/
      data fpppp(27, 5),fpppp(27, 6)/ 8.96695441d-09,-4.92007159d-09/
      data fpppp(27, 7),fpppp(27, 8)/ 8.29595242d-09,-1.76521001d-08/
      data fpppp(27, 9),fpppp(27,10)/ 1.25467590d-08,-6.94229754d-09/
      data fpppp(27,11),fpppp(27,12)/ 7.05688976d-09,-1.21986235d-08/
      data fpppp(27,13),fpppp(27,14)/ 2.15209506d-08,-2.13085322d-08/
      data fpppp(27,15),fpppp(27,16)/ 7.64587432d-09, 1.32195329d-09/
      data fpppp(27,17),fpppp(27,18)/-2.66232696d-09, 1.44075538d-09/
      data fpppp(27,19),fpppp(27,20)/ 1.65406667d-09,-4.61877308d-09/
      data fpppp(27,21),fpppp(27,22)/ 5.67338918d-09,-2.17932788d-09/
      data fpppp(27,23) /            -4.84779369d-09 /
      data fpppp(28, 1),fpppp(28, 2)/-4.61647335d-10,-7.48819183d-10/
      data fpppp(28, 3),fpppp(28, 4)/-9.29777029d-09, 1.10695060d-08/
      data fpppp(28, 5),fpppp(28, 6)/ 1.77779810d-09,-6.85358958d-09/
      data fpppp(28, 7),fpppp(28, 8)/ 1.29252500d-08,-2.97532293d-08/
      data fpppp(28, 9),fpppp(28,10)/ 2.03305120d-08,-1.04308859d-08/
      data fpppp(28,11),fpppp(28,12)/ 1.34158023d-08,-2.79756424d-08/
      data fpppp(28,13),fpppp(28,14)/ 5.69950943d-08,-6.23730578d-08/
      data fpppp(28,15),fpppp(28,16)/ 2.54707892d-08, 2.11144201d-09/
      data fpppp(28,17),fpppp(28,18)/-7.01223747d-09, 3.12080747d-09/
      data fpppp(28,19),fpppp(28,20)/ 4.69162700d-09,-1.03464399d-08/
      data fpppp(28,21),fpppp(28,22)/ 1.18479510d-08,-4.19309195d-09/
      data fpppp(28,23) /            -9.30972521d-09 /
 
      c(1,1)=fpppp(ix+1,iy+1)
      c(1,2)=fpppp(ix+1,iy  )
      c(2,1)=fpppp(ix  ,iy+1)
      c(2,2)=fpppp(ix,  iy  )
      c(1,3)=fpp(ix+1,iy+1,1)
      c(1,4)=fpp(ix+1,iy  ,1)
      c(2,3)=fpp(ix,  iy+1,1)
      c(2,4)=fpp(ix,  iy,  1)
      c(3,1)=fpp(ix+1,iy+1,2)
      c(3,2)=fpp(ix+1,iy  ,2)
      c(4,1)=fpp(ix,  iy+1,2)
      c(4,2)=fpp(ix,  iy,  2)
      c(3,3)=f(ix+1,iy+1)
      c(3,4)=f(ix+1,iy  )
      c(4,3)=f(ix,  iy+1)
      c(4,4)=f(ix,  iy  )
      px(1)=((xi-xix)**3/(6.0*delxi))-(xi-xix)*delxi/6.0
      px(2)=(xi-xixp1)*delxi/6.0-((xi-xixp1)**3/(6.0*delxi))
      px(3)=(xi-xix)/delxi
      px(4)=(xixp1-xi)/delxi
      py(1)=((yi-yiy)**3/(6.0*delyi))-(yi-yiy)*delyi/6.0
      py(2)=(yi-yiyp1)*delyi/6.0-((yi-yiyp1)**3/(6.0*delyi))
      py(3)=(yi-yiy)/delyi
      py(4)=(yiyp1-yi)/delyi

      fi=0.0d 00
      do l=1,4
        sum=0.0d 00
        do i=1,4
          sum=sum + c(i,l) * px(i)
        enddo
        fi = fi + sum * py(l)
      enddo
      return
      end  
      subroutine c9_spl(xi,yi,ix,iy,delxi,delyi,xix,xixp1,
     x                    yiy,yiyp1,fi)
      implicit real*8 (a-h,o-z)
      dimension fpp(28,23,2),f(28,23),fpppp(28,23)
      dimension c(4,4),px(4),py(4)
 
      data f( 3,17),f( 3,18) / -3.45200000d-05 , -1.44800000d-05 /
      data f( 3,19),f( 3,20) / -2.35000000d-06 , -3.80000000d-07 /
      data f( 3,21),f( 3,22) / -8.00000000d-08 ,  2.00000000d-08 /
      data f( 3,23) /           0.00000000d+00 /
      data f( 4, 1),f( 4, 2) /  0.00000000d+00 , -2.00000000d-07 /
      data f( 4, 3),f( 4, 4) / -1.69740000d-04 , -4.71726000d-03 /
      data f( 4, 5),f( 4, 6) / -1.37568400d-02 , -7.98243000d-03 /
      data f( 4, 7),f( 4, 8) / -9.74800000d-04 ,  1.13509000d-03 /
      data f( 4, 9),f( 4,10) /  5.54040000d-04 , -1.64400000d-05 /
      data f( 4,11),f( 4,12) / -1.97770000d-04 , -7.40700000d-05 /
      data f( 4,13),f( 4,14) / -7.27000000d-06 , -4.90000000d-07 /
      data f( 4,15),f( 4,16) / -7.86000000d-06 , -2.02400000d-05 /
      data f( 4,17),f( 4,18) / -2.27800000d-05 , -9.16000000d-06 /
      data f( 4,19),f( 4,20) / -1.87000000d-06 , -3.90000000d-07 /
      data f( 4,21),f( 4,22) / -3.00000000d-08 , -1.00000000d-08 /
      data f( 4,23) /           0.00000000d+00 /
      data f( 5, 1),f( 5, 2) /  0.00000000d+00 , -3.50000000d-07 /
      data f( 5, 3),f( 5, 4) / -2.89460000d-04 , -7.85356000d-03 /
      data f( 5, 5),f( 5, 6) / -1.56564800d-02 , -1.26583700d-02 /
      data f( 5, 7),f( 5, 8) / -1.77495000d-03 ,  1.10639000d-03 /
      data f( 5, 9),f( 5,10) /  5.47270000d-04 ,  3.18000000d-05 /
      data f( 5,11),f( 5,12) / -1.39660000d-04 , -4.42200000d-05 /
      data f( 5,13),f( 5,14) / -3.91000000d-06 ,  1.70000000d-07 /
      data f( 5,15),f( 5,16) / -5.06000000d-06 , -1.34800000d-05 /
      data f( 5,17),f( 5,18) / -1.41100000d-05 , -6.09000000d-06 /
      data f( 5,19),f( 5,20) / -1.59000000d-06 , -2.80000000d-07 /
      data f( 5,21),f( 5,22) / -1.00000000d-08 ,  3.00000000d-08 /
      data f( 5,23) /           0.00000000d+00 /
      data f( 6, 1),f( 6, 2) /  0.00000000d+00 , -5.80000000d-07 /
      data f( 6, 3),f( 6, 4) / -2.84320000d-04 , -1.10546800d-02 /
      data f( 6, 5),f( 6, 6) / -1.39172400d-02 , -1.79021600d-02 /
      data f( 6, 7),f( 6, 8) / -2.35196000d-03 ,  1.05295000d-03 /
      data f( 6, 9),f( 6,10) /  5.12680000d-04 ,  4.20300000d-05 /
      data f( 6,11),f( 6,12) / -9.66000000d-05 , -2.63200000d-05 /
      data f( 6,13),f( 6,14) / -2.34000000d-06 ,  5.50000000d-07 /
      data f( 6,15),f( 6,16) / -2.97000000d-06 , -8.69000000d-06 /
      data f( 6,17),f( 6,18) / -8.78000000d-06 , -4.46000000d-06 /
      data f( 6,19),f( 6,20) / -1.23000000d-06 , -6.00000000d-08 /
      data f( 6,21),f( 6,22) /  2.00000000d-08 ,  4.00000000d-08 /
      data f( 6,23) /           0.00000000d+00 /
      data f( 7, 1),f( 7, 2) /  0.00000000d+00 ,  1.51900000d-05 /
      data f( 7, 3),f( 7, 4) / -4.67980000d-04 , -1.25758000d-02 /
      data f( 7, 5),f( 7, 6) / -1.27502600d-02 , -1.95396400d-02 /
      data f( 7, 7),f( 7, 8) / -2.96507000d-03 ,  5.48450000d-04 /
      data f( 7, 9),f( 7,10) /  2.24480000d-04 ,  2.13100000d-05 /
      data f( 7,11),f( 7,12) / -4.40300000d-05 , -9.38000000d-06 /
      data f( 7,13),f( 7,14) / -9.20000000d-07 ,  5.10000000d-07 /
      data f( 7,15),f( 7,16) / -8.50000000d-07 , -3.25000000d-06 /
      data f( 7,17),f( 7,18) / -4.22000000d-06 , -2.56000000d-06 /
      data f( 7,19),f( 7,20) / -7.30000000d-07 , -8.00000000d-08 /
      data f( 7,21),f( 7,22) / -5.00000000d-08 ,  4.00000000d-08 /
      data f( 7,23) /           0.00000000d+00 /
      data f( 8, 1),f( 8, 2) /  0.00000000d+00 , -1.10000000d-07 /
      data f( 8, 3),f( 8, 4) / -3.40920000d-04 , -1.17387700d-02 /
      data f( 8, 5),f( 8, 6) / -1.76439700d-02 , -1.81160000d-02 /
      data f( 8, 7),f( 8, 8) / -1.94849000d-03 ,  1.57640000d-04 /
      data f( 8, 9),f( 8,10) /  2.68980000d-04 ,  9.81000000d-06 /
      data f( 8,11),f( 8,12) / -1.85500000d-05 , -3.39000000d-06 /
      data f( 8,13),f( 8,14) / -4.10000000d-07 ,  7.10000000d-07 /
      data f( 8,15),f( 8,16) /  3.00000000d-07 , -1.03000000d-06 /
      data f( 8,17),f( 8,18) / -1.96000000d-06 , -1.35000000d-06 /
      data f( 8,19),f( 8,20) / -3.60000000d-07 , -3.00000000d-08 /
      data f( 8,21),f( 8,22) /  2.00000000d-08 ,  4.00000000d-08 /
      data f( 8,23) /           0.00000000d+00 /
      data f( 9, 1),f( 9, 2) /  0.00000000d+00 , -6.20000000d-07 /
      data f( 9, 3),f( 9, 4) / -1.89270000d-04 , -5.33000000d-03 /
      data f( 9, 5),f( 9, 6) / -1.62648800d-02 , -8.95173000d-03 /
      data f( 9, 7),f( 9, 8) / -1.03063000d-03 ,  6.44100000d-05 /
      data f( 9, 9),f( 9,10) /  1.25890000d-04 ,  3.81000000d-06 /
      data f( 9,11),f( 9,12) / -7.20000000d-06 , -1.19000000d-06 /
      data f( 9,13),f( 9,14) / -2.20000000d-07 ,  3.30000000d-07 /
      data f( 9,15),f( 9,16) /  6.40000000d-07 , -3.00000000d-08 /
      data f( 9,17),f( 9,18) / -7.40000000d-07 , -5.70000000d-07 /
      data f( 9,19),f( 9,20) / -2.20000000d-07 , -8.00000000d-08 /
      data f( 9,21),f( 9,22) / -2.00000000d-08 ,  7.00000000d-08 /
      data f( 9,23) /           0.00000000d+00 /
      data f(10, 1),f(10, 2) /  0.00000000d+00 , -1.20000000d-07 /
      data f(10, 3),f(10, 4) / -7.78200000d-05 , -1.64019000d-03 /
      data f(10, 5),f(10, 6) / -5.33786000d-03 , -2.71073000d-03 /
      data f(10, 7),f(10, 8) / -5.21160000d-04 ,  1.15500000d-05 /
      data f(10, 9),f(10,10) /  5.90100000d-05 ,  1.23000000d-06 /
      data f(10,11),f(10,12) / -2.67000000d-06 , -5.10000000d-07 /
      data f(10,13),f(10,14) / -1.90000000d-07 ,  3.20000000d-07 /
      data f(10,15),f(10,16) /  7.50000000d-07 ,  2.30000000d-07 /
      data f(10,17),f(10,18) / -1.70000000d-07 , -2.80000000d-07 /
      data f(10,19),f(10,20) / -1.20000000d-07 , -3.00000000d-08 /
      data f(10,21),f(10,22) /  2.00000000d-08 , -2.50000000d-07 /
      data f(10,23) /           0.00000000d+00 /
      data f(11, 1),f(11, 2) /  0.00000000d+00 , -9.00000000d-08 /
      data f(11, 3),f(11, 4) / -3.28200000d-05 , -6.84050000d-04 /
      data f(11, 5),f(11, 6) / -1.55500000d-03 , -9.51840000d-04 /
      data f(11, 7),f(11, 8) / -2.57240000d-04 , -1.04300000d-05 /
      data f(11, 9),f(11,10) /  2.30100000d-05 ,  2.20000000d-07 /
      data f(11,11),f(11,12) / -6.70000000d-07 , -2.60000000d-07 /
      data f(11,13),f(11,14) / -1.20000000d-07 ,  1.30000000d-07 /
      data f(11,15),f(11,16) /  6.90000000d-07 ,  5.70000000d-07 /
      data f(11,17),f(11,18) /  1.30000000d-07 ,  1.00000000d-08 /
      data f(11,19),f(11,20) / -1.00000000d-08 , -2.00000000d-08 /
      data f(11,21),f(11,22) /  0.00000000d+00 ,  6.00000000d-08 /
      data f(11,23) /           0.00000000d+00 /
      data f(12, 1),f(12, 2) /  0.00000000d+00 , -3.00000000d-08 /
      data f(12, 3),f(12, 4) / -1.05620000d-04 , -7.57640000d-04 /
      data f(12, 5),f(12, 6) / -1.03646000d-03 , -4.33510000d-04 /
      data f(12, 7),f(12, 8) / -1.28520000d-04 , -1.62500000d-05 /
      data f(12, 9),f(12,10) /  5.51000000d-06 , -9.00000000d-08 /
      data f(12,11),f(12,12) / -1.20000000d-07 , -1.60000000d-07 /
      data f(12,13),f(12,14) / -1.10000000d-07 ,  1.60000000d-07 /
      data f(12,15),f(12,16) /  3.80000000d-07 ,  5.10000000d-07 /
      data f(12,17),f(12,18) /  3.40000000d-07 ,  1.00000000d-07 /
      data f(12,19),f(12,20) / -1.00000000d-08 , -4.00000000d-08 /
      data f(12,21),f(12,22) /  2.00000000d-08 ,  1.00000000d-08 /
      data f(12,23) /           0.00000000d+00 /
      data f(13, 1),f(13, 2) /  0.00000000d+00 ,  1.00000000d-08 /
      data f(13, 3),f(13, 4) /  1.30000000d-06 , -2.00140000d-04 /
      data f(13, 5),f(13, 6) / -2.28440000d-04 , -1.14840000d-04 /
      data f(13, 7),f(13, 8) / -5.02900000d-05 , -1.43600000d-05 /
      data f(13, 9),f(13,10) / -2.57000000d-06 ,  9.00000000d-08 /
      data f(13,11),f(13,12) /  1.50000000d-07 ,  8.00000000d-08 /
      data f(13,13),f(13,14) / -7.00000000d-08 ,  1.60000000d-07 /
      data f(13,15),f(13,16) /  3.00000000d-07 ,  4.70000000d-07 /
      data f(13,17),f(13,18) /  3.20000000d-07 ,  1.30000000d-07 /
      data f(13,19),f(13,20) /  1.00000000d-08 , -7.00000000d-08 /
      data f(13,21),f(13,22) / -4.00000000d-08 ,  2.00000000d-08 /
      data f(13,23) /           0.00000000d+00 /
      data f(14, 1),f(14, 2) /  0.00000000d+00 , -8.00000000d-08 /
      data f(14, 3),f(14, 4) / -4.00000000d-07 , -2.37700000d-05 /
      data f(14, 5),f(14, 6) / -3.98600000d-05 , -3.41700000d-05 /
      data f(14, 7),f(14, 8) / -2.16300000d-05 , -9.20000000d-06 /
      data f(14, 9),f(14,10) / -2.79000000d-06 ,  2.60000000d-07 /
      data f(14,11),f(14,12) /  2.10000000d-07 ,  3.00000000d-08 /
      data f(14,13),f(14,14) / -3.00000000d-08 ,  6.00000000d-08 /
      data f(14,15),f(14,16) /  1.60000000d-07 ,  1.90000000d-07 /
      data f(14,17),f(14,18) /  3.00000000d-07 ,  1.90000000d-07 /
      data f(14,19),f(14,20) /  2.00000000d-08 , -3.00000000d-08 /
      data f(14,21),f(14,22) /  2.00000000d-08 , -3.00000000d-08 /
      data f(14,23) /           0.00000000d+00 /
      data f(15, 1),f(15, 2) /  0.00000000d+00 ,  4.00000000d-08 /
      data f(15, 3),f(15, 4) / -5.90000000d-07 , -6.39000000d-06 /
      data f(15, 5),f(15, 6) / -1.42300000d-05 , -1.63000000d-05 /
      data f(15, 7),f(15, 8) / -1.20700000d-05 , -5.71000000d-06 /
      data f(15, 9),f(15,10) / -1.75000000d-06 ,  3.90000000d-07 /
      data f(15,11),f(15,12) /  8.00000000d-08 ,  3.00000000d-08 /
      data f(15,13),f(15,14) /  0.00000000d+00 , -1.70000000d-07 /
      data f(15,15),f(15,16) /  1.10000000d-07 ,  1.70000000d-07 /
      data f(15,17),f(15,18) /  1.10000000d-07 ,  4.00000000d-08 /
      data f(15,19),f(15,20) /  4.00000000d-08 ,  4.00000000d-08 /
      data f(15,21),f(15,22) / -1.40000000d-07 ,  5.00000000d-08 /
      data f(15,23) /           0.00000000d+00 /
      data f(16, 1),f(16, 2) /  0.00000000d+00 , -5.00000000d-08 /
      data f(16, 3),f(16, 4) / -1.70000000d-07 , -1.89000000d-06 /
      data f(16, 5),f(16, 6) / -5.43000000d-06 , -7.61000000d-06 /
      data f(16, 7),f(16, 8) / -6.24000000d-06 , -3.08000000d-06 /
      data f(16, 9),f(16,10) / -8.20000000d-07 ,  4.60000000d-07 /
      data f(16,11),f(16,12) /  3.00000000d-07 ,  1.00000000d-08 /
      data f(16,13),f(16,14) /  1.00000000d-08 , -1.70000000d-07 /
      data f(16,15),f(16,16) /  6.00000000d-08 ,  1.20000000d-07 /
      data f(16,17),f(16,18) /  1.40000000d-07 ,  1.00000000d-07 /
      data f(16,19),f(16,20) /  5.00000000d-08 ,  4.00000000d-08 /
      data f(16,21),f(16,22) /  3.10000000d-07 , -2.00000000d-08 /
      data f(16,23) /           0.00000000d+00 /
      data f(17, 1),f(17, 2) /  0.00000000d+00 , -2.00000000d-08 /
      data f(17, 3),f(17, 4) / -6.00000000d-08 , -3.50000000d-07 /
      data f(17, 5),f(17, 6) / -1.22000000d-06 , -2.10000000d-06 /
      data f(17, 7),f(17, 8) / -1.83000000d-06 , -8.20000000d-07 /
      data f(17, 9),f(17,10) /  1.30000000d-07 ,  4.20000000d-07 /
      data f(17,11),f(17,12) /  9.00000000d-08 , -7.00000000d-08 /
      data f(17,13),f(17,14) /  1.00000000d-08 ,  5.20000000d-07 /
      data f(17,15),f(17,16) /  9.00000000d-08 , -3.00000000d-08 /
      data f(17,17),f(17,18) /  8.00000000d-08 ,  7.00000000d-08 /
      data f(17,19),f(17,20) /  3.00000000d-08 ,  6.00000000d-08 /
      data f(17,21),f(17,22) /  2.00000000d-08 ,  3.00000000d-08 /
      data f(17,23) /           0.00000000d+00 /
      data f(18, 1),f(18, 2) /  0.00000000d+00 ,  0.00000000d+00 /
      data f(18, 3),f(18, 4) / -4.00000000d-08 , -7.00000000d-08 /
      data f(18, 5),f(18, 6) / -2.80000000d-07 , -4.50000000d-07 /
      data f(18, 7),f(18, 8) / -2.80000000d-07 ,  1.30000000d-07 /
      data f(18, 9),f(18,10) /  4.60000000d-07 , -4.00000000d-08 /
      data f(18,11),f(18,12) /  3.00000000d-08 ,  2.00000000d-08 /
      data f(18,13),f(18,14) /  1.00000000d-08 ,  3.00000000d-08 /
      data f(18,15),f(18,16) /  5.00000000d-08 , -7.00000000d-08 /
      data f(18,17),f(18,18) / -2.00000000d-08 ,  1.00000000d-08 /
      data f(18,19),f(18,20) /  1.00000000d-08 ,  1.90000000d-07 /
      data f(18,21),f(18,22) / -3.00000000d-08 ,  3.00000000d-08 /
      data f(18,23) /           0.00000000d+00 /
      data f(19, 1),f(19, 2) /  0.00000000d+00 ,  3.00000000d-08 /
      data f(19, 3),f(19, 4) / -2.00000000d-08 , -1.20000000d-07 /
      data f(19, 5),f(19, 6) / -5.00000000d-08 , -8.00000000d-08 /
      data f(19, 7),f(19, 8) /  4.00000000d-08 ,  3.20000000d-07 /
      data f(19, 9),f(19,10) /  5.20000000d-07 ,  1.90000000d-07 /
      data f(19,11),f(19,12) /  9.00000000d-08 , -4.00000000d-08 /
      data f(19,13),f(19,14) / -4.00000000d-08 ,  3.00000000d-08 /
      data f(19,15),f(19,16) /  3.00000000d-08 ,  1.60000000d-07 /
      data f(19,17),f(19,18) / -3.00000000d-08 ,  1.00000000d-08 /
      data f(19,19),f(19,20) /  0.00000000d+00 , -2.40000000d-07 /
      data f(19,21),f(19,22) /  6.00000000d-08 ,  4.00000000d-08 /
      data f(19,23) /           0.00000000d+00 /
      data f(20, 1),f(20, 2) /  0.00000000d+00 ,  5.00000000d-08 /
      data f(20, 3),f(20, 4) /  2.00000000d-08 ,  0.00000000d+00 /
      data f(20, 5),f(20, 6) / -3.00000000d-08 ,  6.00000000d-08 /
      data f(20, 7),f(20, 8) /  2.70000000d-07 ,  1.50000000d-07 /
      data f(20, 9),f(20,10) / -6.00000000d-08 ,  1.70000000d-07 /
      data f(20,11),f(20,12) / -6.00000000d-08 , -3.00000000d-08 /
      data f(20,13),f(20,14) / -3.00000000d-08 ,  5.00000000d-08 /
      data f(20,15),f(20,16) /  1.00000000d-08 , -2.00000000d-08 /
      data f(20,17),f(20,18) /  2.00000000d-08 , -8.00000000d-08 /
      data f(20,19),f(20,20) / -1.00000000d-07 ,  4.00000000d-08 /
      data f(20,21),f(20,22) / -2.00000000d-08 ,  1.00000000d-08 /
      data f(20,23) /           0.00000000d+00 /
      data f(21, 1),f(21, 2) /  0.00000000d+00 ,  5.00000000d-08 /
      data f(21, 3),f(21, 4) /  1.00000000d-08 ,  1.00000000d-08 /
      data f(21, 5),f(21, 6) /  0.00000000d+00 ,  1.20000000d-07 /
      data f(21, 7),f(21, 8) /  1.60000000d-07 ,  2.40000000d-07 /
      data f(21, 9),f(21,10) /  1.90000000d-07 ,  1.80000000d-07 /
      data f(21,11),f(21,12) /  5.00000000d-08 , -1.00000000d-08 /
      data f(21,13),f(21,14) / -2.00000000d-08 , -5.00000000d-08 /
      data f(21,15),f(21,16) /  1.00000000d-08 ,  2.00000000d-08 /
      data f(21,17),f(21,18) /  4.00000000d-08 ,  6.00000000d-08 /
      data f(21,19),f(21,20) /  8.00000000d-08 , -1.00000000d-08 /
      data f(21,21),f(21,22) /  0.00000000d+00 , -1.60000000d-07 /
      data f(21,23) /           0.00000000d+00 /
      data f(22, 1),f(22, 2) /  0.00000000d+00 ,  2.00000000d-08 /
      data f(22, 3),f(22, 4) /  3.00000000d-08 , -1.20000000d-07 /
      data f(22, 5),f(22, 6) /  3.00000000d-08 ,  4.00000000d-08 /
      data f(22, 7),f(22, 8) /  1.20000000d-07 ,  2.00000000d-07 /
      data f(22, 9),f(22,10) /  1.80000000d-07 ,  4.60000000d-07 /
      data f(22,11),f(22,12) /  0.00000000d+00 ,  0.00000000d+00 /
      data f(22,13),f(22,14) /  0.00000000d+00 ,  3.00000000d-08 /
      data f(22,15),f(22,16) /  0.00000000d+00 ,  1.00000000d-08 /
      data f(22,17),f(22,18) /  0.00000000d+00 ,  0.00000000d+00 /
      data f(22,19),f(22,20) /  0.00000000d+00 ,  0.00000000d+00 /
      data f(22,21),f(22,22) /  0.00000000d+00 ,  1.00000000d-08 /
      data f(22,23) /           0.00000000d+00 /
      data f(23, 1),f(23, 2) /  0.00000000d+00 ,  1.00000000d-08 /
      data f(23, 3),f(23, 4) / -2.00000000d-08 ,  2.00000000d-08 /
      data f(23, 5),f(23, 6) /  3.00000000d-08 , -1.00000000d-08 /
      data f(23, 7),f(23, 8) /  4.00000000d-08 ,  5.00000000d-08 /
      data f(23, 9),f(23,10) /  1.00000000d-08 ,  5.00000000d-08 /
      data f(23,11),f(23,12) /  1.00000000d-08 ,  0.00000000d+00 /
      data f(23,13),f(23,14) /  0.00000000d+00 ,  0.00000000d+00 /
      data f(23,15),f(23,16) /  0.00000000d+00 ,  0.00000000d+00 /
      data f(23,17),f(23,18) /  0.00000000d+00 ,  0.00000000d+00 /
      data f(23,19),f(23,20) /  0.00000000d+00 ,  0.00000000d+00 /
      data f(23,21),f(23,22) /  0.00000000d+00 ,  2.00000000d-08 /
      data f(23,23) /           0.00000000d+00 /
      data f(24, 1),f(24, 2) /  0.00000000d+00 ,  1.00000000d-08 /
      data f(24, 3),f(24, 4) / -1.00000000d-08 , -2.00000000d-08 /
      data f(24, 5),f(24, 6) /  1.00000000d-08 ,  2.00000000d-08 /
      data f(24, 7),f(24, 8) /  1.00000000d-08 , -1.00000000d-08 /
      data f(24, 9),f(24,10) / -1.00000000d-08 ,  1.00000000d-08 /
      data f(24,11),f(24,12) /  1.00000000d-08 ,  0.00000000d+00 /
      data f(24,13),f(24,14) /  0.00000000d+00 ,  0.00000000d+00 /
      data f(24,15),f(24,16) / -1.00000000d-08 , -1.00000000d-08 /
      data f(24,17),f(24,18) / -1.00000000d-08 ,  0.00000000d+00 /
      data f(24,19),f(24,20) / -1.00000000d-08 ,  0.00000000d+00 /
      data f(24,21),f(24,22) /  0.00000000d+00 ,  1.00000000d-08 /
      data f(24,23) /           0.00000000d+00 /
      data f(25, 1),f(25, 2) /  0.00000000d+00 ,  0.00000000d+00 /
      data f(25, 3),f(25, 4) /  1.00000000d-08 , -1.00000000d-08 /
      data f(25, 5),f(25, 6) / -2.00000000d-08 , -2.00000000d-08 /
      data f(25, 7),f(25, 8) / -1.00000000d-08 ,  2.00000000d-08 /
      data f(25, 9),f(25,10) /  2.00000000d-08 ,  0.00000000d+00 /
      data f(25,11),f(25,12) /  0.00000000d+00 , -1.00000000d-08 /
      data f(25,13),f(25,14) / -2.00000000d-08 ,  1.10000000d-07 /
      data f(25,15),f(25,16) /  0.00000000d+00 ,  0.00000000d+00 /
      data f(25,17),f(25,18) /  0.00000000d+00 ,  0.00000000d+00 /
      data f(25,19),f(25,20) /  0.00000000d+00 ,  1.00000000d-08 /
      data f(25,21),f(25,22) /  0.00000000d+00 ,  0.00000000d+00 /
      data f(25,23) /           0.00000000d+00 /
      data f(26, 1),f(26, 2) /  0.00000000d+00 ,  0.00000000d+00 /
      data f(26, 3),f(26, 4) /  0.00000000d+00 ,  0.00000000d+00 /
      data f(26, 5),f(26, 6) /  0.00000000d+00 , -1.00000000d-08 /
      data f(26, 7),f(26, 8) /  0.00000000d+00 ,  0.00000000d+00 /
      data f(26, 9),f(26,10) /  0.00000000d+00 ,  0.00000000d+00 /
      data f(26,11),f(26,12) /  1.00000000d-08 , -1.00000000d-08 /
      data f(26,13),f(26,14) /  1.00000000d-08 , -1.40000000d-07 /
      data f(26,15),f(26,16) / -1.00000000d-08 , -1.00000000d-08 /
      data f(26,17),f(26,18) /  1.00000000d-08 ,  1.00000000d-08 /
      data f(26,19),f(26,20) /  2.00000000d-08 ,  1.00000000d-08 /
      data f(26,21),f(26,22) /  0.00000000d+00 ,  0.00000000d+00 /
      data f(26,23) /           0.00000000d+00 /
      data f(27, 1),f(27, 2) /  0.00000000d+00 ,  0.00000000d+00 /
      data f(27, 3),f(27, 4) /  0.00000000d+00 ,  0.00000000d+00 /
      data f(27, 5),f(27, 6) /  0.00000000d+00 ,  0.00000000d+00 /
      data f(27, 7),f(27, 8) / -1.00000000d-08 ,  0.00000000d+00 /
      data f(27, 9),f(27,10) /  0.00000000d+00 ,  0.00000000d+00 /
      data f(27,11),f(27,12) /  0.00000000d+00 ,  0.00000000d+00 /
      data f(27,13),f(27,14) /  0.00000000d+00 ,  2.00000000d-08 /
      data f(27,15),f(27,16) /  1.00000000d-08 ,  0.00000000d+00 /
      data f(27,17),f(27,18) /  1.00000000d-08 ,  1.00000000d-08 /
      data f(27,19),f(27,20) /  0.00000000d+00 ,  1.00000000d-08 /
      data f(27,21),f(27,22) /  0.00000000d+00 ,  2.00000000d-08 /
      data f(27,23) /           0.00000000d+00 /
      data f(28, 1),f(28, 2) /  0.00000000d+00 , -1.00000000d-08 /
      data f(28, 3),f(28, 4) /  0.00000000d+00 ,  0.00000000d+00 /
      data f(28, 5),f(28, 6) /  0.00000000d+00 ,  0.00000000d+00 /
      data f(28, 7),f(28, 8) /  0.00000000d+00 ,  0.00000000d+00 /
      data f(28, 9),f(28,10) /  0.00000000d+00 ,  0.00000000d+00 /
      data f(28,11),f(28,12) /  0.00000000d+00 ,  0.00000000d+00 /
      data f(28,13),f(28,14) / -5.00000000d-08 , -6.00000000d-08 /
      data f(28,15),f(28,16) /  2.00000000d-08 ,  2.00000000d-08 /
      data f(28,17),f(28,18) / -1.00000000d-08 , -1.00000000d-08 /
      data f(28,19),f(28,20) /  1.00000000d-08 ,  0.00000000d+00 /
      data f(28,21),f(28,22) /  6.00000000d-08 ,  0.00000000d+00 /
      data f(28,23) /           0.00000000d+00 /
 
      data fpp( 1, 1,1),fpp( 1, 1,2)/ 0.00000000d+00,-1.93821685d-05/
      data fpp( 1, 2,1),fpp( 1, 2,2)/-2.09560085d-05,-2.59476629d-05/
      data fpp( 1, 3,1),fpp( 1, 3,2)/-1.52136362d-03, 1.18603220d-04/
      data fpp( 1, 4,1),fpp( 1, 4,2)/ 1.34329753d-01,-2.65753218d-04/
      data fpp( 1, 5,1),fpp( 1, 5,2)/-2.04559109d-01, 2.34316853d-04/
      data fpp( 1, 6,1),fpp( 1, 6,2)/-9.37893378d-02, 1.79218063d-05/
      data fpp( 1, 7,1),fpp( 1, 7,2)/ 7.69080650d-02,-1.02323278d-04/
      data fpp( 1, 8,1),fpp( 1, 8,2)/-8.93999646d-02, 4.27617070d-05/
      data fpp( 1, 9,1),fpp( 1, 9,2)/ 3.16747126d-02,-3.63259498d-05/
      data fpp( 1,10,1),fpp( 1,10,2)/ 1.06445430d-02, 1.00871958d-05/
      data fpp( 1,11,1),fpp( 1,11,2)/-2.12819742d-03, 1.33843667d-05/
      data fpp( 1,12,1),fpp( 1,12,2)/-1.60166005d-03,-4.92186259d-06/
      data fpp( 1,13,1),fpp( 1,13,2)/-2.79345600d-03,-1.17051635d-06/
      data fpp( 1,14,1),fpp( 1,14,2)/-2.77620384d-04,-8.41471995d-07/
      data fpp( 1,15,1),fpp( 1,15,2)/-3.26951137d-05, 5.59004334d-07/
      data fpp( 1,16,1),fpp( 1,16,2)/ 1.12790623d-03,-3.67945339d-07/
      data fpp( 1,17,1),fpp( 1,17,2)/ 6.86471597d-04, 2.31177024d-07/
      data fpp( 1,18,1),fpp( 1,18,2)/ 1.72212288d-03, 1.59637245d-07/
      data fpp( 1,19,1),fpp( 1,19,2)/-5.82532942d-05,-2.04326002d-07/
      data fpp( 1,20,1),fpp( 1,20,2)/ 5.05385580d-06,-2.27332366d-08/
      data fpp( 1,21,1),fpp( 1,21,2)/-1.42875607d-04, 3.24589483d-08/
      data fpp( 1,22,1),fpp( 1,22,2)/ 2.05877307d-05,-1.53025567d-08/
      data fpp( 1,23,1),fpp( 1,23,2)/ 0.00000000d+00,-3.36487217d-08/
      data fpp( 2, 1,1),fpp( 2, 1,2)/ 0.00000000d+00, 4.56101196d-05/
      data fpp( 2, 2,1),fpp( 2, 2,2)/-2.08798294d-06,-7.40783924d-06/
      data fpp( 2, 3,1),fpp( 2, 3,2)/-3.78027275d-03,-2.09203627d-05/
      data fpp( 2, 4,1),fpp( 2, 4,2)/ 3.98444935d-02,-1.72701910d-04/
      data fpp( 2, 5,1),fpp( 2, 5,2)/-1.13258782d-01, 3.00216803d-04/
      data fpp( 2, 6,1),fpp( 2, 6,2)/-9.40113244d-02, 2.45298974d-05/
      data fpp( 2, 7,1),fpp( 2, 7,2)/ 2.20508699d-02,-1.09090793d-04/
      data fpp( 2, 8,1),fpp( 2, 8,2)/-5.09910708d-02,-4.02067269d-05/
      data fpp( 2, 9,1),fpp( 2, 9,2)/ 1.09815748d-02,-2.37429971d-06/
      data fpp( 2,10,1),fpp( 2,10,2)/ 3.96391405d-03, 4.36326259d-06/
      data fpp( 2,11,1),fpp( 2,11,2)/-3.90560515d-03, 1.04914493d-05/
      data fpp( 2,12,1),fpp( 2,12,2)/-1.88767990d-03,-3.39545996d-06/
      data fpp( 2,13,1),fpp( 2,13,2)/-1.81708801d-03,-1.22660950d-06/
      data fpp( 2,14,1),fpp( 2,14,2)/-1.66759232d-04,-2.57702033d-07/
      data fpp( 2,15,1),fpp( 2,15,2)/-4.06097726d-05, 7.70176323d-08/
      data fpp( 2,16,1),fpp( 2,16,2)/ 8.90187536d-04,-1.97684967d-08/
      data fpp( 2,17,1),fpp( 2,17,2)/ 7.34056805d-04, 2.81056354d-07/
      data fpp( 2,18,1),fpp( 2,18,2)/ 8.80754233d-04, 7.33430790d-08/
      data fpp( 2,19,1),fpp( 2,19,2)/-4.44934116d-05,-2.54628670d-07/
      data fpp( 2,20,1),fpp( 2,20,2)/ 2.89228840d-06, 2.95716024d-08/
      data fpp( 2,21,1),fpp( 2,21,2)/-8.02487858d-05,-9.45773910d-09/
      data fpp( 2,22,1),fpp( 2,22,2)/ 1.08245386d-05, 1.05935403d-09/
      data fpp( 2,23,1),fpp( 2,23,2)/ 0.00000000d+00,-2.57967701d-09/
      data fpp( 3, 1,1),fpp( 3, 1,2)/ 0.00000000d+00, 9.93850320d-05/
      data fpp( 3, 2,1),fpp( 3, 2,2)/-3.06920597d-05,-1.08928640d-05/
      data fpp( 3, 3,1),fpp( 3, 3,2)/-7.38754536d-03,-7.06911760d-05/
      data fpp( 3, 4,1),fpp( 3, 4,2)/-6.80357271d-02,-3.07168032d-04/
      data fpp( 3, 5,1),fpp( 3, 5,2)/-3.33251761d-01, 5.99945704d-04/
      data fpp( 3, 6,1),fpp( 3, 6,2)/-3.63373645d-02, 3.81641641d-06/
      data fpp( 3, 7,1),fpp( 3, 7,2)/-1.33497545d-01,-2.19156170d-04/
      data fpp( 3, 8,1),fpp( 3, 8,2)/ 3.78247658d-04,-2.76165383d-05/
      data fpp( 3, 9,1),fpp( 3, 9,2)/-8.89750117d-02,-5.67447723d-06/
      data fpp( 3,10,1),fpp( 3,10,2)/-3.20501992d-02, 7.47550084d-06/
      data fpp( 3,11,1),fpp( 3,11,2)/-1.07493820d-02, 6.42827387d-06/
      data fpp( 3,12,1),fpp( 3,12,2)/-2.62562035d-03,-2.05699632d-06/
      data fpp( 3,13,1),fpp( 3,13,2)/-6.06191970d-04,-9.21888606d-07/
      data fpp( 3,14,1),fpp( 3,14,2)/ 2.06573126d-05,-6.58492606d-08/
      data fpp( 3,15,1),fpp( 3,15,2)/-5.68657959d-05,-1.05314352d-07/
      data fpp( 3,16,1),fpp( 3,16,2)/ 1.17934362d-03, 6.65066674d-08/
      data fpp( 3,17,1),fpp( 3,17,2)/ 1.92730118d-03, 4.35087682d-07/
      data fpp( 3,18,1),fpp( 3,18,2)/-3.55139817d-04,-2.01857395d-07/
      data fpp( 3,19,1),fpp( 3,19,2)/-2.17730594d-05,-1.02258101d-07/
      data fpp( 3,20,1),fpp( 3,20,2)/-1.06230094d-05, 1.28980035d-09/
      data fpp( 3,21,1),fpp( 3,21,2)/ 1.98707502d-05,-3.10110009d-09/
      data fpp( 3,22,1),fpp( 3,22,2)/-1.58858852d-05,-8.85399973d-10/
      data fpp( 3,23,1),fpp( 3,23,2)/ 0.00000000d+00,-5.57300013d-10/
      data fpp( 4, 1,1),fpp( 4, 1,2)/ 0.00000000d+00, 1.67495112d-04/
      data fpp( 4, 2,1),fpp( 4, 2,2)/ 1.06856222d-04,-1.86198230d-05/
      data fpp( 4, 3,1),fpp( 4, 3,2)/-6.27554579d-03,-1.33657419d-04/
      data fpp( 4, 4,1),fpp( 4, 4,2)/-1.29033585d-01,-4.97465699d-04/
      data fpp( 4, 5,1),fpp( 4, 5,2)/ 5.36281828d-01, 1.04542582d-03/
      data fpp( 4, 6,1),fpp( 4, 6,2)/-1.81299218d-01,-1.28879963d-04/
      data fpp( 4, 7,1),fpp( 4, 7,2)/ 6.33733092d-02,-2.33933162d-04/
      data fpp( 4, 8,1),fpp( 4, 8,2)/ 6.38608013d-03,-1.10844990d-04/
      data fpp( 4, 9,1),fpp( 4, 9,2)/ 8.84904719d-02, 3.14875201d-05/
      data fpp( 4,10,1),fpp( 4,10,2)/ 3.46028827d-02,-3.54286546d-06/
      data fpp( 4,11,1),fpp( 4,11,2)/ 1.39132990d-04, 6.03294175d-06/
      data fpp( 4,12,1),fpp( 4,12,2)/-1.78183872d-03,-2.28710154d-06/
      data fpp( 4,13,1),fpp( 4,13,2)/-2.16144110d-04,-2.98535582d-07/
      data fpp( 4,14,1),fpp( 4,14,2)/-5.98700184d-05,-1.19956129d-07/
      data fpp( 4,15,1),fpp( 4,15,2)/-4.39270438d-05,-7.06398999d-08/
      data fpp( 4,16,1),fpp( 4,16,2)/-3.75562032d-04, 1.01915729d-07/
      data fpp( 4,17,1),fpp( 4,17,2)/-8.89261530d-04, 2.53376983d-07/
      data fpp( 4,18,1),fpp( 4,18,2)/-2.10194967d-04,-1.45823662d-07/
      data fpp( 4,19,1),fpp( 4,19,2)/-3.04143506d-05,-4.98823335d-08/
      data fpp( 4,20,1),fpp( 4,20,2)/ 1.55997492d-05,-3.24700338d-09/
      data fpp( 4,21,1),fpp( 4,21,2)/-1.12342152d-05,-4.32965294d-09/
      data fpp( 4,22,1),fpp( 4,22,2)/ 1.67190022d-05, 1.65615125d-10/
      data fpp( 4,23,1),fpp( 4,23,2)/ 0.00000000d+00, 3.06719244d-09/
      data fpp( 5, 1,1),fpp( 5, 1,2)/ 0.00000000d+00, 2.47500035d-04/
      data fpp( 5, 2,1),fpp( 5, 2,2)/-4.08732827d-04, 2.92471308d-05/
      data fpp( 5, 3,1),fpp( 5, 3,2)/ 2.52237285d-02,-4.33790958d-04/
      data fpp( 5, 4,1),fpp( 5, 4,2)/-4.38319327d-02,-4.00808996d-05/
      data fpp( 5, 5,1),fpp( 5, 5,2)/ 4.38022449d-01, 5.36797756d-04/
      data fpp( 5, 6,1),fpp( 5, 6,2)/-1.65759765d-01, 4.85137074d-04/
      data fpp( 5, 7,1),fpp( 5, 7,2)/ 1.69783079d-02,-5.84871653d-04/
      data fpp( 5, 8,1),fpp( 5, 8,2)/ 2.97431833d-04,-6.61496614d-05/
      data fpp( 5, 9,1),fpp( 5, 9,2)/-2.29108758d-02, 2.37598989d-05/
      data fpp( 5,10,1),fpp( 5,10,2)/-1.44173316d-02,-2.03866605d-06/
      data fpp( 5,11,1),fpp( 5,11,2)/-2.01115000d-03, 5.03536527d-06/
      data fpp( 5,12,1),fpp( 5,12,2)/-1.17902479d-03,-2.08879501d-06/
      data fpp( 5,13,1),fpp( 5,13,2)/-2.03231588d-04, 1.20147896d-08/
      data fpp( 5,14,1),fpp( 5,14,2)/-1.51772390d-05,-1.33064145d-07/
      data fpp( 5,15,1),fpp( 5,15,2)/-7.34260288d-05,-3.83582105d-08/
      data fpp( 5,16,1),fpp( 5,16,2)/-1.63095498d-04, 9.50969866d-08/
      data fpp( 5,17,1),fpp( 5,17,2)/-2.12255060d-04, 1.25370264d-07/
      data fpp( 5,18,1),fpp( 5,18,2)/-1.54080316d-04,-7.75780426d-08/
      data fpp( 5,19,1),fpp( 5,19,2)/ 2.34304620d-05,-2.62580936d-08/
      data fpp( 5,20,1),fpp( 5,20,2)/ 2.02240126d-05,-8.78958317d-09/
      data fpp( 5,21,1),fpp( 5,21,2)/ 7.06611058d-06,-9.83573762d-10/
      data fpp( 5,22,1),fpp( 5,22,2)/-8.99012357d-06,-1.07612178d-09/
      data fpp( 5,23,1),fpp( 5,23,2)/ 0.00000000d+00, 1.08806089d-09/
      data fpp( 6, 1,1),fpp( 6, 1,2)/ 0.00000000d+00, 3.31659487d-04/
      data fpp( 6, 2,1),fpp( 6, 2,2)/ 1.48007509d-03, 1.18978625d-04/
      data fpp( 6, 3,1),fpp( 6, 3,2)/-1.97033683d-02,-8.75532388d-04/
      data fpp( 6, 4,1),fpp( 6, 4,2)/ 2.65469316d-01, 8.66362126d-04/
      data fpp( 6, 5,1),fpp( 6, 5,2)/-1.05043623d-01,-6.92044117d-04/
      data fpp( 6, 6,1),fpp( 6, 6,2)/ 5.03628276d-01, 1.63244794d-03/
      data fpp( 6, 7,1),fpp( 6, 7,2)/ 2.59745928d-03,-1.14931886d-03/
      data fpp( 6, 8,1),fpp( 6, 8,2)/-2.24198075d-02, 4.99578803d-05/
      data fpp( 6, 9,1),fpp( 6, 9,2)/-1.35389688d-02, 2.64413470d-06/
      data fpp( 6,10,1),fpp( 6,10,2)/ 2.60443526d-04, 3.68205575d-06/
      data fpp( 6,11,1),fpp( 6,11,2)/-1.12453298d-03, 2.54884230d-06/
      data fpp( 6,12,1),fpp( 6,12,2)/-6.72062120d-04,-1.34282493d-06/
      data fpp( 6,13,1),fpp( 6,13,2)/-4.49295380d-05, 4.44574371d-08/
      data fpp( 6,14,1),fpp( 6,14,2)/-4.74210254d-05,-1.00404815d-07/
      data fpp( 6,15,1),fpp( 6,15,2)/-8.83688410d-05,-2.74381767d-08/
      data fpp( 6,16,1),fpp( 6,16,2)/-1.54055978d-04, 7.81575217d-08/
      data fpp( 6,17,1),fpp( 6,17,2)/-2.65718230d-04, 5.26080897d-08/
      data fpp( 6,18,1),fpp( 6,18,2)/-3.74837673d-05,-2.39898804d-08/
      data fpp( 6,19,1),fpp( 6,19,2)/-1.53074972d-05,-2.20485680d-08/
      data fpp( 6,20,1),fpp( 6,20,2)/-3.04957997d-05,-1.14158478d-08/
      data fpp( 6,21,1),fpp( 6,21,2)/-1.10302271d-05, 2.31195901d-09/
      data fpp( 6,22,1),fpp( 6,22,2)/ 1.24149209d-06,-1.43198829d-09/
      data fpp( 6,23,1),fpp( 6,23,2)/ 0.00000000d+00,-1.84005855d-10/
      data fpp( 7, 1,1),fpp( 7, 1,2)/ 0.00000000d+00, 3.40606885d-04/
      data fpp( 7, 2,1),fpp( 7, 2,2)/-1.80135885d-03, 1.49086231d-04/
      data fpp( 7, 3,1),fpp( 7, 3,2)/ 1.74072407d-02,-1.05655821d-03/
      data fpp( 7, 4,1),fpp( 7, 4,2)/-4.23239814d-02, 1.28723060d-03/
      data fpp( 7, 5,1),fpp( 7, 5,2)/-2.50605356d-01,-1.22835779d-03/
      data fpp( 7, 6,1),fpp( 7, 6,2)/-1.00489945d-01, 2.03861977d-03/
      data fpp( 7, 7,1),fpp( 7, 7,2)/ 6.48549682d-02,-1.31877329d-03/
      data fpp( 7, 8,1),fpp( 7, 8,2)/ 7.46770647d-03, 1.01821383d-04/
      data fpp( 7, 9,1),fpp( 7, 9,2)/ 1.92193444d-02,-9.50984535d-06/
      data fpp( 7,10,1),fpp( 7,10,2)/ 2.50335199d-04, 4.30504432d-06/
      data fpp( 7,11,1),fpp( 7,11,2)/-6.53326062d-04, 5.59468053d-07/
      data fpp( 7,12,1),fpp( 7,12,2)/-2.23301245d-04,-5.43516534d-07/
      data fpp( 7,13,1),fpp( 7,13,2)/-2.15955920d-05, 4.31980852d-08/
      data fpp( 7,14,1),fpp( 7,14,2)/ 2.98516958d-05,-5.10758062d-08/
      data fpp( 7,15,1),fpp( 7,15,2)/-7.18046272d-06,-6.29486022d-09/
      data fpp( 7,16,1),fpp( 7,16,2)/-7.72843186d-05, 1.38552471d-08/
      data fpp( 7,17,1),fpp( 7,17,2)/-1.17177814d-05, 3.66738717d-08/
      data fpp( 7,18,1),fpp( 7,18,2)/-1.45085398d-05,-2.75073394d-09/
      data fpp( 7,19,1),fpp( 7,19,2)/ 1.20726055d-06,-1.54709359d-08/
      data fpp( 7,20,1),fpp( 7,20,2)/ 1.23753928d-05,-6.16552233d-09/
      data fpp( 7,21,1),fpp( 7,21,2)/ 1.00576261d-05, 2.93302524d-09/
      data fpp( 7,22,1),fpp( 7,22,2)/-2.22941449d-06,-1.96657864d-09/
      data fpp( 7,23,1),fpp( 7,23,2)/ 0.00000000d+00,-2.86671068d-09/
      data fpp( 8, 1,1),fpp( 8, 1,2)/ 0.00000000d+00, 3.59372372d-04/
      data fpp( 8, 2,1),fpp( 8, 2,2)/ 1.06486031d-03, 9.76784560d-05/
      data fpp( 8, 3,1),fpp( 8, 3,2)/-3.31759457d-03,-8.31854196d-04/
      data fpp( 8, 4,1),fpp( 8, 4,2)/ 2.57549110d-01, 5.76048729d-04/
      data fpp( 8, 5,1),fpp( 8, 5,2)/ 1.98361546d-01,-1.54104718d-04/
      data fpp( 8, 6,1),fpp( 8, 6,2)/ 3.57499506d-01, 1.34433094d-03/
      data fpp( 8, 7,1),fpp( 8, 7,2)/-1.75638322d-02,-1.22972946d-03/
      data fpp( 8, 8,1),fpp( 8, 8,2)/ 9.60248160d-03, 1.99855693d-04/
      data fpp( 8, 9,1),fpp( 8, 9,2)/-1.34334088d-02,-4.84429139d-05/
      data fpp( 8,10,1),fpp( 8,10,2)/ 1.21215676d-04, 1.64898951d-05/
      data fpp( 8,11,1),fpp( 8,11,2)/-3.25662774d-04,-3.66806663d-06/
      data fpp( 8,12,1),fpp( 8,12,2)/-7.72328990d-05, 7.93571396d-07/
      data fpp( 8,13,1),fpp( 8,13,2)/-5.18809380d-06,-2.37018949d-07/
      data fpp( 8,14,1),fpp( 8,14,2)/-3.59857579d-05, 4.29044009d-08/
      data fpp( 8,15,1),fpp( 8,15,2)/-2.84093082d-05,-2.63986545d-08/
      data fpp( 8,16,1),fpp( 8,16,2)/-1.98067482d-05, 7.49021715d-09/
      data fpp( 8,17,1),fpp( 8,17,2)/-3.24106447d-05, 2.04377859d-08/
      data fpp( 8,18,1),fpp( 8,18,2)/-7.98207351d-06, 3.15863915d-09/
      data fpp( 8,19,1),fpp( 8,19,2)/-9.02154503d-06,-1.02723425d-08/
      data fpp( 8,20,1),fpp( 8,20,2)/-8.50577137d-06,-1.66926901d-09/
      data fpp( 8,21,1),fpp( 8,21,2)/-8.20027711d-06, 1.49418580d-10/
      data fpp( 8,22,1),fpp( 8,22,2)/ 7.67616589d-06,-7.28405309d-10/
      data fpp( 8,23,1),fpp( 8,23,2)/ 0.00000000d+00,-8.35797346d-10/
      data fpp( 9, 1,1),fpp( 9, 1,2)/ 0.00000000d+00, 1.92757534d-04/
      data fpp( 9, 2,1),fpp( 9, 2,2)/-2.39582407d-04,-2.69546689d-05/
      data fpp( 9, 3,1),fpp( 9, 3,2)/-4.48362427d-04,-1.30066059d-04/
      data fpp( 9, 4,1),fpp( 9, 4,2)/-1.52111458d-01,-6.41280296d-04/
      data fpp( 9, 5,1),fpp( 9, 5,2)/ 3.98079172d-01, 1.30459124d-03/
      data fpp( 9, 6,1),fpp( 9, 6,2)/-1.68413577d-01,-1.97557475d-04/
      data fpp( 9, 7,1),fpp( 9, 7,2)/-9.40763939d-03,-3.68453344d-04/
      data fpp( 9, 8,1),fpp( 9, 8,2)/-1.24063286d-03, 3.31164522d-05/
      data fpp( 9, 9,1),fpp( 9, 9,2)/ 6.37579078d-03,-1.20668645d-05/
      data fpp( 9,10,1),fpp( 9,10,2)/ 8.98020947d-05, 4.93996744d-06/
      data fpp( 9,11,1),fpp( 9,11,2)/-1.63522841d-04,-1.02880525d-06/
      data fpp( 9,12,1),fpp( 9,12,2)/-3.62671588d-05, 1.96453564d-07/
      data fpp( 9,13,1),fpp( 9,13,2)/-5.65203276d-06,-5.94090031d-08/
      data fpp( 9,14,1),fpp( 9,14,2)/ 2.70913358d-05, 1.59824488d-08/
      data fpp( 9,15,1),fpp( 9,15,2)/-6.82304635d-07,-1.89207920d-08/
      data fpp( 9,16,1),fpp( 9,16,2)/-2.64886887d-05, 9.00719203d-10/
      data fpp( 9,17,1),fpp( 9,17,2)/-1.46396398d-05, 1.29179152d-08/
      data fpp( 9,18,1),fpp( 9,18,2)/-1.80631662d-05, 2.27620062d-10/
      data fpp( 9,19,1),fpp( 9,19,2)/ 3.78919584d-07,-3.02839543d-09/
      data fpp( 9,20,1),fpp( 9,20,2)/ 6.64769271d-06,-7.14038338d-10/
      data fpp( 9,21,1),fpp( 9,21,2)/ 6.24348237d-06, 1.08454878d-09/
      data fpp( 9,22,1),fpp( 9,22,2)/-2.39752490d-05,-1.82415680d-09/
      data fpp( 9,23,1),fpp( 9,23,2)/ 0.00000000d+00,-3.38792160d-09/
      data fpp(10, 1,1),fpp(10, 1,2)/ 0.00000000d+00, 5.79408276d-05/
      data fpp(10, 2,1),fpp(10, 2,2)/ 4.49693131d-05,-1.26240552d-05/
      data fpp(10, 3,1),fpp(10, 3,2)/-9.18955718d-04,-2.60638068d-05/
      data fpp(10, 4,1),fpp(10, 4,2)/-5.69472794d-02,-2.39441518d-04/
      data fpp(10, 5,1),fpp(10, 5,2)/-3.58488732d-01, 4.71357877d-04/
      data fpp(10, 6,1),fpp(10, 6,2)/-1.22335698d-01,-1.28037992d-04/
      data fpp(10, 7,1),fpp(10, 7,2)/-6.06411024d-03,-6.42203089d-05/
      data fpp(10, 8,1),fpp(10, 8,2)/ 1.41554982d-03,-1.27271721d-05/
      data fpp(10, 9,1),fpp(10, 9,2)/-6.38254317d-04,-1.33100271d-06/
      data fpp(10,10,1),fpp(10,10,2)/ 3.25759449d-05, 1.19459416d-06/
      data fpp(10,11,1),fpp(10,11,2)/-4.32458601d-05,-2.14573932d-07/
      data fpp(10,12,1),fpp(10,12,2)/-5.69846575d-06, 2.73015694d-08/
      data fpp(10,13,1),fpp(10,13,2)/ 3.79622482d-06,-5.03234526d-09/
      data fpp(10,14,1),fpp(10,14,2)/-1.68795851d-05, 4.22781167d-09/
      data fpp(10,15,1),fpp(10,15,2)/-3.36147330d-06,-1.66789014d-08/
      data fpp(10,16,1),fpp(10,16,2)/ 1.47615031d-05, 5.48779407d-09/
      data fpp(10,17,1),fpp(10,17,2)/-6.53079628d-06, 1.92772515d-09/
      data fpp(10,18,1),fpp(10,18,2)/ 6.73473813d-06, 4.20130533d-09/
      data fpp(10,19,1),fpp(10,19,2)/ 1.50586670d-06,-2.53294645d-09/
      data fpp(10,20,1),fpp(10,20,2)/-3.08499948d-06, 1.73048049d-09/
      data fpp(10,21,1),fpp(10,21,2)/-4.77365238d-06,-6.78897552d-09/
      data fpp(10,22,1),fpp(10,22,2)/ 3.57248303d-05, 6.22542158d-09/
      data fpp(10,23,1),fpp(10,23,2)/ 0.00000000d+00, 1.30872892d-08/
      data fpp(11, 1,1),fpp(11, 1,2)/ 0.00000000d+00, 2.14580168d-05/
      data fpp(11, 2,1),fpp(11, 2,2)/-1.07948457d-05, 3.59663096d-08/
      data fpp(11, 3,1),fpp(11, 3,2)/-5.84331470d-03,-2.94354821d-05/
      data fpp(11, 4,1),fpp(11, 4,2)/-3.01499247d-02,-3.07340380d-05/
      data fpp(11, 5,1),fpp(11, 5,2)/-3.57482421d-02, 9.96388340d-05/
      data fpp(11, 6,1),fpp(11, 6,2)/-1.45601312d-02,-1.40348980d-05/
      data fpp(11, 7,1),fpp(11, 7,2)/-3.16841966d-03,-2.15536421d-05/
      data fpp(11, 8,1),fpp(11, 8,2)/ 2.10433563d-04,-7.22013357d-06/
      data fpp(11, 9,1),fpp(11, 9,2)/ 8.09226489d-04,-7.74623606d-07/
      data fpp(11,10,1),fpp(11,10,2)/ 1.53941257d-05, 5.53737604d-07/
      data fpp(11,11,1),fpp(11,11,2)/-4.29937182d-05,-1.26326808d-07/
      data fpp(11,12,1),fpp(11,12,2)/-5.43897818d-06, 2.95696302d-08/
      data fpp(11,13,1),fpp(11,13,2)/-3.53286652d-06,-8.15171244d-09/
      data fpp(11,14,1),fpp(11,14,2)/ 1.34270047d-05, 9.63721954d-09/
      data fpp(11,15,1),fpp(11,15,2)/-1.13718022d-05,-1.17971657d-08/
      data fpp(11,16,1),fpp(11,16,2)/-2.05573236d-05,-3.24855665d-09/
      data fpp(11,17,1),fpp(11,17,2)/ 2.62824861d-07, 5.59139231d-09/
      data fpp(11,18,1),fpp(11,18,2)/-8.87578637d-06, 8.29874046d-11/
      data fpp(11,19,1),fpp(11,19,2)/-4.90238638d-06, 7.66580711d-11/
      data fpp(11,20,1),fpp(11,20,2)/-3.07694792d-07, 2.10380311d-10/
      data fpp(11,21,1),fpp(11,21,2)/ 3.85112714d-06, 8.81820686d-10/
      data fpp(11,22,1),fpp(11,22,2)/-2.44240722d-05,-1.33766305d-09/
      data fpp(11,23,1),fpp(11,23,2)/ 0.00000000d+00,-2.73116847d-09/
      data fpp(12, 1,1),fpp(12, 1,2)/ 0.00000000d+00, 1.12159013d-05/
      data fpp(12, 2,1),fpp(12, 2,2)/ 2.71006949d-06, 1.70597435d-07/
      data fpp(12, 3,1),fpp(12, 3,2)/ 6.62221453d-03,-3.72326910d-05/
      data fpp(12, 4,1),fpp(12, 4,2)/ 2.30874780d-02, 1.76169666d-05/
      data fpp(12, 5,1),fpp(12, 5,2)/ 1.18337009d-02, 5.63328244d-05/
      data fpp(12, 6,1),fpp(12, 6,2)/-5.50777734d-03,-3.13234643d-05/
      data fpp(12, 7,1),fpp(12, 7,2)/-1.54221114d-03,-2.54936703d-06/
      data fpp(12, 8,1),fpp(12, 8,2)/ 1.66715925d-04,-4.73186755d-06/
      data fpp(12, 9,1),fpp(12, 9,2)/ 1.76348361d-04,-2.45562782d-07/
      data fpp(12,10,1),fpp(12,10,2)/ 1.08475524d-05, 1.55422120d-07/
      data fpp(12,11,1),fpp(12,11,2)/-2.27926705d-06,-4.19256980d-08/
      data fpp(12,12,1),fpp(12,12,2)/ 4.95437846d-06, 1.16806719d-08/
      data fpp(12,13,1),fpp(12,13,2)/ 1.33524127d-06, 6.03010408d-10/
      data fpp(12,14,1),fpp(12,14,2)/-3.82843374d-06,-8.92713522d-10/
      data fpp(12,15,1),fpp(12,15,2)/ 1.13486820d-05,-3.21563189d-11/
      data fpp(12,16,1),fpp(12,16,2)/ 7.46779130d-06,-4.37866120d-09/
      data fpp(12,17,1),fpp(12,17,2)/-8.02050317d-06,-4.53198873d-10/
      data fpp(12,18,1),fpp(12,18,2)/-1.23159267d-06, 1.99145669d-09/
      data fpp(12,19,1),fpp(12,19,2)/ 1.60367882d-06, 2.87372102d-10/
      data fpp(12,20,1),fpp(12,20,2)/-1.84221352d-07, 1.65905490d-09/
      data fpp(12,21,1),fpp(12,21,2)/-4.63085617d-06,-1.52359170d-09/
      data fpp(12,22,1),fpp(12,22,2)/ 7.97145847d-06, 2.35311915d-10/
      data fpp(12,23,1),fpp(12,23,2)/ 0.00000000d+00, 5.82344042d-10/
      data fpp(13, 1,1),fpp(13, 1,2)/ 0.00000000d+00, 7.09516385d-06/
      data fpp(13, 2,1),fpp(13, 2,2)/-5.17033451d-06, 2.28407231d-06/
      data fpp(13, 3,1),fpp(13, 3,2)/-3.77050529d-03,-1.59242531d-05/
      data fpp(13, 4,1),fpp(13, 4,2)/-1.23326437d-02, 1.27577400d-05/
      data fpp(13, 5,1),fpp(13, 5,2)/-1.35995083d-02, 6.44689301d-06/
      data fpp(13, 6,1),fpp(13, 6,2)/-2.52232142d-03,-4.48931205d-06/
      data fpp(13, 7,1),fpp(13, 7,2)/-4.03683106d-04,-2.61644821d-07/
      data fpp(13, 8,1),fpp(13, 8,2)/ 1.19912072d-05,-1.33290867d-06/
      data fpp(13, 9,1),fpp(13, 9,2)/ 8.40211376d-05,-2.00320506d-07/
      data fpp(13,10,1),fpp(13,10,2)/-3.42125854d-06, 1.22158511d-08/
      data fpp(13,11,1),fpp(13,11,2)/-7.39964369d-07,-4.54289882d-09/
      data fpp(13,12,1),fpp(13,12,2)/-6.88860941d-06,-1.84425583d-09/
      data fpp(13,13,1),fpp(13,13,2)/-4.28893226d-07, 7.11992213d-09/
      data fpp(13,14,1),fpp(13,14,2)/ 8.10109337d-07,-3.83543271d-09/
      data fpp(13,15,1),fpp(13,15,2)/-4.58107188d-06, 2.82180869d-09/
      data fpp(13,16,1),fpp(13,16,2)/-7.85442194d-06,-5.65180206d-09/
      data fpp(13,17,1),fpp(13,17,2)/ 4.22646065d-06, 5.85399561d-10/
      data fpp(13,18,1),fpp(13,18,2)/ 3.02249980d-06, 9.10203819d-10/
      data fpp(13,19,1),fpp(13,19,2)/-7.44005144d-07,-2.62148354d-11/
      data fpp(13,20,1),fpp(13,20,2)/ 8.19201036d-07, 1.59465552d-09/
      data fpp(13,21,1),fpp(13,21,2)/ 6.86876913d-06, 2.47592744d-10/
      data fpp(13,22,1),fpp(13,22,2)/-4.62214678d-06,-7.85026498d-10/
      data fpp(13,23,1),fpp(13,23,2)/ 0.00000000d+00,-1.90748675d-09/
      data fpp(14, 1,1),fpp(14, 1,2)/ 0.00000000d+00, 8.11423760d-07/
      data fpp(14, 2,1),fpp(14, 2,2)/ 9.30460191d-06, 1.73152479d-07/
      data fpp(14, 3,1),fpp(14, 3,2)/ 1.21847329d-03,-1.56163368d-06/
      data fpp(14, 4,1),fpp(14, 4,2)/ 8.34430160d-04, 5.41382230d-07/
      data fpp(14, 5,1),fpp(14, 5,2)/ 1.26833213d-03, 1.14330476d-06/
      data fpp(14, 6,1),fpp(14, 6,2)/-2.69603648d-04, 1.12598742d-07/
      data fpp(14, 7,1),fpp(14, 7,2)/-1.47723104d-04, 5.03002767d-08/
      data fpp(14, 8,1),fpp(14, 8,2)/ 3.31924607d-06,-3.40199849d-07/
      data fpp(14, 9,1),fpp(14, 9,2)/ 1.15670887d-05,-1.34300883d-07/
      data fpp(14,10,1),fpp(14,10,2)/ 2.17081507d-06,-1.31974276d-08/
      data fpp(14,11,1),fpp(14,11,2)/-8.76087548d-06, 1.09059329d-09/
      data fpp(14,12,1),fpp(14,12,2)/ 3.26672586d-06, 1.03505448d-09/
      data fpp(14,13,1),fpp(14,13,2)/ 3.80331633d-07, 1.96918879d-09/
      data fpp(14,14,1),fpp(14,14,2)/-6.07867027d-06, 8.81903647d-11/
      data fpp(14,15,1),fpp(14,15,2)/ 2.97560551d-06,-1.72195025d-09/
      data fpp(14,16,1),fpp(14,16,2)/ 7.94989646d-06, 2.59961063d-09/
      data fpp(14,17,1),fpp(14,17,2)/-8.88533943d-06,-3.87649226d-09/
      data fpp(14,18,1),fpp(14,18,2)/-8.85840652d-06,-2.93641601d-10/
      data fpp(14,19,1),fpp(14,19,2)/ 7.05675092d-07, 1.45105866d-09/
      data fpp(14,20,1),fpp(14,20,2)/ 1.57408387d-06, 1.68940696d-09/
      data fpp(14,21,1),fpp(14,21,2)/-1.48442204d-05,-2.20868649d-09/
      data fpp(14,22,1),fpp(14,22,2)/ 6.51712864d-06, 1.14533900d-09/
      data fpp(14,23,1),fpp(14,23,2)/ 0.00000000d+00, 2.42733050d-09/
      data fpp(15, 1,1),fpp(15, 1,2)/ 0.00000000d+00, 1.43358126d-07/
      data fpp(15, 2,1),fpp(15, 2,2)/-1.17675078d-05,-7.11625191d-09/
      data fpp(15, 3,1),fpp(15, 3,2)/-2.95108535d-04,-2.75693118d-07/
      data fpp(15, 4,1),fpp(15, 4,2)/-7.03185225d-04,-1.30911275d-07/
      data fpp(15, 5,1),fpp(15, 5,2)/-9.55898280d-04, 3.09738218d-07/
      data fpp(15, 6,1),fpp(15, 6,2)/-2.54999630d-04, 2.76758404d-07/
      data fpp(15, 7,1),fpp(15, 7,2)/-8.78598185d-05, 9.52281677d-08/
      data fpp(15, 8,1),fpp(15, 8,2)/-2.70830411d-05,-1.46471074d-07/
      data fpp(15, 9,1),fpp(15, 9,2)/-5.86715011d-06,-8.53438699d-08/
      data fpp(15,10,1),fpp(15,10,2)/-3.22218752d-06,-1.75328531d-08/
      data fpp(15,11,1),fpp(15,11,2)/ 1.94143239d-05, 8.47528211d-09/
      data fpp(15,12,1),fpp(15,12,2)/-1.00071520d-06,-7.68275401d-10/
      data fpp(15,13,1),fpp(15,13,2)/-7.58318326d-07,-4.20218051d-09/
      data fpp(15,14,1),fpp(15,14,2)/ 4.67818734d-06, 9.17699744d-09/
      data fpp(15,15,1),fpp(15,15,2)/-1.50641975d-06,-5.50580926d-09/
      data fpp(15,16,1),fpp(15,16,2)/-2.96784939d-06,-3.53760415d-10/
      data fpp(15,17,1),fpp(15,17,2)/ 1.15870062d-05,-2.79149084d-10/
      data fpp(15,18,1),fpp(15,18,2)/ 1.12582829d-05, 8.70356749d-10/
      data fpp(15,19,1),fpp(15,19,2)/-4.12367743d-07, 9.97722087d-10/
      data fpp(15,20,1),fpp(15,20,2)/-2.59922093d-06,-4.86124510d-09/
      data fpp(15,21,1),fpp(15,21,2)/ 3.39179481d-05, 7.64725829d-09/
      data fpp(15,22,1),fpp(15,22,2)/-8.65242301d-06,-3.52778808d-09/
      data fpp(15,23,1),fpp(15,23,2)/ 0.00000000d+00,-7.93610596d-09/
      data fpp(16, 1,1),fpp(16, 1,2)/ 0.00000000d+00, 5.77431493d-08/
      data fpp(16, 2,1),fpp(16, 2,2)/ 6.26542916d-06,-1.48629854d-09/
      data fpp(16, 3,1),fpp(16, 3,2)/ 5.34608461d-05,-6.85979551d-08/
      data fpp(16, 4,1),fpp(16, 4,2)/ 4.63107388d-05,-1.08121881d-07/
      data fpp(16, 5,1),fpp(16, 5,2)/ 3.07609857d-05, 6.42854791d-08/
      data fpp(16, 6,1),fpp(16, 6,2)/-8.73978309d-05, 1.77379965d-07/
      data fpp(16, 7,1),fpp(16, 7,2)/-6.03376216d-05, 7.81946623d-08/
      data fpp(16, 8,1),fpp(16, 8,2)/-2.39870817d-05,-6.05586140d-08/
      data fpp(16, 9,1),fpp(16, 9,2)/-4.59848832d-06,-5.19602064d-08/
      data fpp(16,10,1),fpp(16,10,2)/ 1.71793502d-06,-8.24007372d-09/
      data fpp(16,11,1),fpp(16,11,2)/-1.63964203d-05,-1.47949870d-09/
      data fpp(16,12,1),fpp(16,12,2)/-2.26386508d-06, 6.35806853d-09/
      data fpp(16,13,1),fpp(16,13,2)/-3.47058328d-07,-6.55277543d-09/
      data fpp(16,14,1),fpp(16,14,2)/ 2.18659209d-05, 9.05303318d-09/
      data fpp(16,15,1),fpp(16,15,2)/ 3.05007350d-06,-5.05935729d-09/
      data fpp(16,16,1),fpp(16,16,2)/-5.78498899d-07, 9.84395997d-10/
      data fpp(16,17,1),fpp(16,17,2)/-4.46268525d-06,-1.27822669d-09/
      data fpp(16,18,1),fpp(16,18,2)/-4.67472507d-06, 5.28510780d-10/
      data fpp(16,19,1),fpp(16,19,2)/-5.56204121d-07,-1.43581642d-09/
      data fpp(16,20,1),fpp(16,20,2)/-1.67720017d-06, 7.61475492d-09/
      data fpp(16,21,1),fpp(16,21,2)/-2.93275720d-05,-1.22232032d-08/
      data fpp(16,22,1),fpp(16,22,2)/ 5.59256341d-06, 5.27805807d-09/
      data fpp(16,23,1),fpp(16,23,2)/ 0.00000000d+00, 1.21109710d-08/
      data fpp(17, 1,1),fpp(17, 1,2)/ 0.00000000d+00, 8.84886640d-09/
      data fpp(17, 2,1),fpp(17, 2,2)/-2.03975868d-06,-1.69773279d-09/
      data fpp(17, 3,1),fpp(17, 3,2)/-1.61304637d-05,-6.85793523d-09/
      data fpp(17, 4,1),fpp(17, 4,2)/-3.29123127d-05,-3.08705263d-08/
      data fpp(17, 5,1),fpp(17, 5,2)/-6.46044325d-05,-8.85995965d-09/
      data fpp(17, 6,1),fpp(17, 6,2)/-4.03408103d-05, 6.39103649d-08/
      data fpp(17, 7,1),fpp(17, 7,2)/-2.93013824d-05, 2.92185002d-08/
      data fpp(17, 8,1),fpp(17, 8,2)/-1.43210335d-05,-3.18436558d-09/
      data fpp(17, 9,1),fpp(17, 9,2)/-1.04269389d-05,-3.08810379d-08/
      data fpp(17,10,1),fpp(17,10,2)/-1.32449917d-05,-2.36470361d-09/
      data fpp(17,11,1),fpp(17,11,2)/ 5.71185176d-06, 3.13985229d-09/
      data fpp(17,12,1),fpp(17,12,2)/ 4.88002705d-06, 5.29443053d-12/
      data fpp(17,13,1),fpp(17,13,2)/ 6.62406645d-07, 1.12389700d-08/
      data fpp(17,14,1),fpp(17,14,2)/-3.00051946d-05,-1.91611744d-08/
      data fpp(17,15,1),fpp(17,15,2)/-2.16263185d-06, 9.00572748d-09/
      data fpp(17,16,1),fpp(17,16,2)/-1.09310408d-06, 1.73826444d-09/
      data fpp(17,17,1),fpp(17,17,2)/ 1.50946732d-07,-2.15878526d-09/
      data fpp(17,18,1),fpp(17,18,2)/ 7.68949547d-08,-3.03123418d-10/
      data fpp(17,19,1),fpp(17,19,2)/-2.04407768d-07, 1.57127893d-09/
      data fpp(17,20,1),fpp(17,20,2)/ 8.65681451d-06,-1.78199229d-09/
      data fpp(17,21,1),fpp(17,21,2)/ 1.08132746d-05, 1.35669023d-09/
      data fpp(17,22,1),fpp(17,22,2)/-2.54026269d-06,-6.44768638d-10/
      data fpp(17,23,1),fpp(17,23,2)/ 0.00000000d+00,-1.17761568d-09/
      data fpp(18, 1,1),fpp(18, 1,2)/ 0.00000000d+00,-3.04100238d-09/
      data fpp(18, 2,1),fpp(18, 2,2)/ 1.22693890d-06,-2.71799524d-09/
      data fpp(18, 3,1),fpp(18, 3,2)/ 5.06100875d-06, 4.31298336d-09/
      data fpp(18, 4,1),fpp(18, 4,2)/ 1.33851204d-06,-1.21339382d-08/
      data fpp(18, 5,1),fpp(18, 5,2)/ 9.65674414d-06, 1.02276936d-09/
      data fpp(18, 6,1),fpp(18, 6,2)/-8.57226125d-06, 1.76428607d-08/
      data fpp(18, 7,1),fpp(18, 7,2)/-1.31235156d-05, 1.00057877d-08/
      data fpp(18, 8,1),fpp(18, 8,2)/-6.06211777d-06,-6.60117116d-11/
      data fpp(18, 9,1),fpp(18, 9,2)/ 4.97291048d-06,-2.89417409d-08/
      data fpp(18,10,1),fpp(18,10,2)/ 2.32620318d-05, 1.72582286d-08/
      data fpp(18,11,1),fpp(18,11,2)/ 3.54901328d-06,-5.89117334d-09/
      data fpp(18,12,1),fpp(18,12,2)/-5.92290981d-06, 1.50646478d-09/
      data fpp(18,13,1),fpp(18,13,2)/-2.30256825d-06,-1.34685791d-10/
      data fpp(18,14,1),fpp(18,14,2)/ 1.94881908d-05, 8.32278382d-10/
      data fpp(18,15,1),fpp(18,15,2)/ 9.33787211d-07,-3.19442774d-09/
      data fpp(18,16,1),fpp(18,16,2)/ 1.22842485d-05, 3.54543257d-09/
      data fpp(18,17,1),fpp(18,17,2)/ 1.19223166d-06,-7.87302539d-10/
      data fpp(18,18,1),fpp(18,18,2)/ 2.36714525d-06,-1.59622241d-09/
      data fpp(18,19,1),fpp(18,19,2)/ 1.37383519d-06, 5.37219219d-09/
      data fpp(18,20,1),fpp(18,20,2)/-2.56167246d-05,-9.09254636d-09/
      data fpp(18,21,1),fpp(18,21,2)/ 2.07447351d-06, 6.99799325d-09/
      data fpp(18,22,1),fpp(18,22,2)/ 1.23515402d-06,-2.09942664d-09/
      data fpp(18,23,1),fpp(18,23,2)/ 0.00000000d+00,-4.00028668d-09/
      data fpp(19, 1,1),fpp(19, 1,2)/ 0.00000000d+00,-5.00038395d-09/
      data fpp(19, 2,1),fpp(19, 2,2)/-5.75056466d-07,-1.99923211d-09/
      data fpp(19, 3,1),fpp(19, 3,2)/-1.09348174d-07,-6.20268762d-09/
      data fpp(19, 4,1),fpp(19, 4,2)/ 7.17590886d-06, 1.48099826d-08/
      data fpp(19, 5,1),fpp(19, 5,2)/-1.08770720d-05,-1.22372427d-08/
      data fpp(19, 6,1),fpp(19, 6,2)/-6.12747829d-06, 1.01389881d-08/
      data fpp(19, 7,1),fpp(19, 7,2)/ 2.56965145d-06, 7.68129023d-09/
      data fpp(19, 8,1),fpp(19, 8,2)/-1.47078610d-05,-2.46414901d-09/
      data fpp(19, 9,1),fpp(19, 9,2)/-3.32241441d-05,-1.70246942d-08/
      data fpp(19,10,1),fpp(19,10,2)/-1.59426715d-05, 8.50615701d-09/
      data fpp(19,11,1),fpp(19,11,2)/-1.13128440d-05,-3.19993388d-09/
      data fpp(19,12,1),fpp(19,12,2)/ 4.29450845d-06, 2.49357852d-09/
      data fpp(19,13,1),fpp(19,13,2)/ 3.01923129d-06, 1.02561980d-09/
      data fpp(19,14,1),fpp(19,14,2)/-3.43316217d-06,-2.39605771d-09/
      data fpp(19,15,1),fpp(19,15,2)/-4.24988288d-07, 4.35861102d-09/
      data fpp(19,16,1),fpp(19,16,2)/-2.12815866d-05,-7.23838639d-09/
      data fpp(19,17,1),fpp(19,17,2)/ 2.31242160d-06, 5.39493455d-09/
      data fpp(19,18,1),fpp(19,18,2)/-5.95106867d-06,-5.41351820d-10/
      data fpp(19,19,1),fpp(19,19,2)/-6.06256431d-06,-6.22952727d-09/
      data fpp(19,20,1),fpp(19,20,2)/ 3.75984010d-05, 1.16594609d-08/
      data fpp(19,21,1),fpp(19,21,2)/-8.09227947d-06,-8.00831640d-09/
      data fpp(19,22,1),fpp(19,22,2)/-8.65376075d-07, 1.17380469d-09/
      data fpp(19,23,1),fpp(19,23,2)/ 0.00000000d+00, 2.11309766d-09/
      data fpp(20, 1,1),fpp(20, 1,2)/ 0.00000000d+00,-6.55505885d-09/
      data fpp(20, 2,1),fpp(20, 2,2)/-4.26713033d-07,-3.68988231d-09/
      data fpp(20, 3,1),fpp(20, 3,2)/-1.62361605d-06, 2.11458808d-09/
      data fpp(20, 4,1),fpp(20, 4,2)/-4.54214749d-06,-2.36847001d-09/
      data fpp(20, 5,1),fpp(20, 5,2)/ 2.35154381d-06, 4.95929197d-09/
      data fpp(20, 6,1),fpp(20, 6,2)/-1.41782558d-06, 1.13313021d-08/
      data fpp(20, 7,1),fpp(20, 7,2)/-1.06550902d-05,-2.14845005d-08/
      data fpp(20, 8,1),fpp(20, 8,2)/ 1.08935616d-05,-4.59330011d-09/
      data fpp(20, 9,1),fpp(20, 9,2)/ 3.19236659d-05, 1.82577010d-08/
      data fpp(20,10,1),fpp(20,10,2)/ 3.00865414d-06,-1.34764528d-08/
      data fpp(20,11,1),fpp(20,11,2)/ 1.02023629d-05, 8.04811037d-09/
      data fpp(20,12,1),fpp(20,12,2)/-7.55123992d-07,-3.11598863d-09/
      data fpp(20,13,1),fpp(20,13,2)/-7.74356907d-07, 2.61584415d-09/
      data fpp(20,14,1),fpp(20,14,2)/-2.75554214d-06,-2.54738797d-09/
      data fpp(20,15,1),fpp(20,15,2)/ 7.66165942d-07, 3.73707736d-10/
      data fpp(20,16,1),fpp(20,16,2)/ 1.13420978d-05, 1.65255703d-09/
      data fpp(20,17,1),fpp(20,17,2)/-1.44191808d-06,-2.78393585d-09/
      data fpp(20,18,1),fpp(20,18,2)/ 7.93712942d-06, 1.08318636d-09/
      data fpp(20,19,1),fpp(20,19,2)/ 9.37642206d-06, 3.25119039d-09/
      data fpp(20,20,1),fpp(20,20,2)/-1.82768794d-05,-4.48794794d-09/
      data fpp(20,21,1),fpp(20,21,2)/ 4.79464436d-06, 2.70060137d-09/
      data fpp(20,22,1),fpp(20,22,2)/-3.77364972d-06,-9.14457534d-10/
      data fpp(20,23,1),fpp(20,23,2)/ 0.00000000d+00,-1.44277123d-09/
      data fpp(21, 1,1),fpp(21, 1,2)/ 0.00000000d+00,-8.36159036d-09/
      data fpp(21, 2,1),fpp(21, 2,2)/-1.94252246d-07,-4.47681929d-09/
      data fpp(21, 3,1),fpp(21, 3,2)/ 8.18285617d-07, 4.66886751d-09/
      data fpp(21, 4,1),fpp(21, 4,2)/-9.76780950d-07,-4.59865076d-09/
      data fpp(21, 5,1),fpp(21, 5,2)/-5.87098047d-07, 1.13257355d-08/
      data fpp(21, 6,1),fpp(21, 6,2)/-1.18892922d-06,-9.50429141d-09/
      data fpp(21, 7,1),fpp(21, 7,2)/ 3.47053307d-06, 7.49143008d-09/
      data fpp(21, 8,1),fpp(21, 8,2)/-3.50663134d-06,-1.08614289d-08/
      data fpp(21, 9,1),fpp(21, 9,2)/-9.59612372d-06, 4.75428563d-09/
      data fpp(21,10,1),fpp(21,10,2)/ 3.26626719d-06,-3.43214242d-09/
      data fpp(21,11,1),fpp(21,11,2)/-4.13264687d-06, 1.77428404d-09/
      data fpp(21,12,1),fpp(21,12,2)/-1.25923258d-08, 5.35006248d-10/
      data fpp(21,13,1),fpp(21,13,2)/ 2.35035497d-07,-9.14309036d-10/
      data fpp(21,14,1),fpp(21,14,2)/ 2.80724858d-06, 1.92222989d-09/
      data fpp(21,15,1),fpp(21,15,2)/-2.70560949d-07,-1.37461054d-09/
      data fpp(21,16,1),fpp(21,16,2)/-2.95260147d-06, 5.76212274d-10/
      data fpp(21,17,1),fpp(21,17,2)/-4.01887478d-07,-3.30238552d-10/
      data fpp(21,18,1),fpp(21,18,2)/-4.15638561d-06, 7.44741936d-10/
      data fpp(21,19,1),fpp(21,19,2)/-5.21303067d-06,-2.64872919d-09/
      data fpp(21,20,1),fpp(21,20,2)/ 4.52399746d-06, 3.25017484d-09/
      data fpp(21,21,1),fpp(21,21,2)/-1.25396156d-06,-4.35197015d-09/
      data fpp(21,22,1),fpp(21,22,2)/ 4.82241646d-06, 3.95770576d-09/
      data fpp(21,23,1),fpp(21,23,2)/ 0.00000000d+00, 7.72114712d-09/
      data fpp(22, 1,1),fpp(22, 1,2)/ 0.00000000d+00, 4.10383473d-09/
      data fpp(22, 2,1),fpp(22, 2,2)/ 1.57635006d-07, 2.59233054d-09/
      data fpp(22, 3,1),fpp(22, 3,2)/-7.64344345d-07,-1.68731569d-08/
      data fpp(22, 4,1),fpp(22, 4,2)/ 2.33098753d-06, 2.65002970d-08/
      data fpp(22, 5,1),fpp(22, 5,2)/-1.22125365d-08,-1.71280310d-08/
      data fpp(22, 6,1),fpp(22, 6,2)/ 3.35268849d-07, 8.41182707d-09/
      data fpp(22, 7,1),fpp(22, 7,2)/-1.27265171d-06, 2.80722742d-10/
      data fpp(22, 8,1),fpp(22, 8,2)/ 1.25083338d-07,-9.53471804d-09/
      data fpp(22, 9,1),fpp(22, 9,2)/ 1.31339633d-06, 1.38581494d-08/
      data fpp(22,10,1),fpp(22,10,2)/-5.93724749d-06,-1.76070892d-08/
      data fpp(22,11,1),fpp(22,11,2)/ 1.50305227d-06, 1.21702074d-08/
      data fpp(22,12,1),fpp(22,12,2)/-6.66301622d-08,-3.47374027d-09/
      data fpp(22,13,1),fpp(22,13,2)/-2.07499445d-07, 1.72475373d-09/
      data fpp(22,14,1),fpp(22,14,2)/-1.40987018d-06,-1.62527464d-09/
      data fpp(22,15,1),fpp(22,15,2)/ 1.66095470d-07, 1.17634484d-09/
      data fpp(22,16,1),fpp(22,16,2)/ 8.03066064d-07,-6.80104730d-10/
      data fpp(22,17,1),fpp(22,17,2)/ 3.91190777d-07, 3.44074076d-10/
      data fpp(22,18,1),fpp(22,18,2)/ 1.49815630d-06,-9.61915732d-11/
      data fpp(22,19,1),fpp(22,19,2)/ 1.93584491d-06, 4.06922171d-11/
      data fpp(22,20,1),fpp(22,20,2)/-1.27066422d-06,-6.65772953d-11/
      data fpp(22,21,1),fpp(22,21,2)/ 3.35890361d-07, 2.25616964d-10/
      data fpp(22,22,1),fpp(22,22,2)/-2.28754285d-06,-2.35890561d-10/
      data fpp(22,23,1),fpp(22,23,2)/ 0.00000000d+00,-4.82054719d-10/
      data fpp(23, 1,1),fpp(23, 1,2)/ 0.00000000d+00,-5.64461343d-09/
      data fpp(23, 2,1),fpp(23, 2,2)/ 4.37122229d-08,-2.31077314d-09/
      data fpp(23, 3,1),fpp(23, 3,2)/ 5.59091762d-07, 5.28770599d-09/
      data fpp(23, 4,1),fpp(23, 4,2)/-1.86716918d-06,-2.04005081d-09/
      data fpp(23, 5,1),fpp(23, 5,2)/-8.40518068d-08,-4.32750276d-09/
      data fpp(23, 6,1),fpp(23, 6,2)/ 5.67853823d-07, 7.35006185d-09/
      data fpp(23, 7,1),fpp(23, 7,2)/ 6.60073765d-07,-3.47274463d-09/
      data fpp(23, 8,1),fpp(23, 8,2)/ 3.66297988d-07,-3.05908333d-09/
      data fpp(23, 9,1),fpp(23, 9,2)/ 5.02538403d-07, 3.70907797d-09/
      data fpp(23,10,1),fpp(23,10,2)/ 3.92272276d-06,-2.39769224d-09/
      data fpp(23,11,1),fpp(23,11,2)/-4.39562199d-07, 1.08169098d-09/
      data fpp(23,12,1),fpp(23,12,2)/ 3.91129748d-08,-1.29071666d-10/
      data fpp(23,13,1),fpp(23,13,2)/ 1.14962283d-07, 3.45956904d-11/
      data fpp(23,14,1),fpp(23,14,2)/ 1.92232150d-07,-9.31109499d-12/
      data fpp(23,15,1),fpp(23,15,2)/-1.53820932d-07, 2.64868958d-12/
      data fpp(23,16,1),fpp(23,16,2)/-2.59662781d-07,-1.28366333d-12/
      data fpp(23,17,1),fpp(23,17,2)/-2.02875631d-07, 2.48596374d-12/
      data fpp(23,18,1),fpp(23,18,2)/-3.96239603d-07,-8.66019162d-12/
      data fpp(23,19,1),fpp(23,19,2)/-6.10348957d-07, 3.21548027d-11/
      data fpp(23,20,1),fpp(23,20,2)/ 3.18659421d-07,-1.19959019d-10/
      data fpp(23,21,1),fpp(23,21,2)/-8.95998891d-08, 4.47681274d-10/
      data fpp(23,22,1),fpp(23,22,2)/ 4.87754930d-07,-4.70766078d-10/
      data fpp(23,23,1),fpp(23,23,2)/ 0.00000000d+00,-9.64616961d-10/
      data fpp(24, 1,1),fpp(24, 1,2)/ 0.00000000d+00,-2.83048865d-09/
      data fpp(24, 2,1),fpp(24, 2,2)/-9.24838973d-08,-1.13902270d-09/
      data fpp(24, 3,1),fpp(24, 3,2)/-3.20227039d-08, 1.86579444d-10/
      data fpp(24, 4,1),fpp(24, 4,2)/ 8.17689171d-07, 2.79270492d-09/
      data fpp(24, 5,1),fpp(24, 5,2)/-1.31580236d-07,-1.75739914d-09/
      data fpp(24, 6,1),fpp(24, 6,2)/-6.86684141d-07,-5.63108369d-10/
      data fpp(24, 7,1),fpp(24, 7,2)/-1.67643350d-07,-7.90167386d-10/
      data fpp(24, 8,1),fpp(24, 8,2)/ 5.69724708d-07, 1.32377791d-09/
      data fpp(24, 9,1),fpp(24, 9,2)/ 2.76450058d-07, 2.95055735d-10/
      data fpp(24,10,1),fpp(24,10,2)/-8.73643542d-07,-3.47056161d-10/
      data fpp(24,11,1),fpp(24,11,2)/ 1.51965293d-08,-1.06831091d-10/
      data fpp(24,12,1),fpp(24,12,2)/-8.98217368d-08, 1.74380524d-10/
      data fpp(24,13,1),fpp(24,13,2)/-2.52349688d-07, 9.30899370d-12/
      data fpp(24,14,1),fpp(24,14,2)/ 1.36094158d-06,-2.11616499d-10/
      data fpp(24,15,1),fpp(24,15,2)/ 2.09188257d-07, 2.37157003d-10/
      data fpp(24,16,1),fpp(24,16,2)/ 2.35585061d-07,-1.37011511d-10/
      data fpp(24,17,1),fpp(24,17,2)/ 1.80311746d-07, 3.10889042d-10/
      data fpp(24,18,1),fpp(24,18,2)/ 8.68021077d-08,-5.06544658d-10/
      data fpp(24,19,1),fpp(24,19,2)/ 2.65550920d-07, 5.15289591d-10/
      data fpp(24,20,1),fpp(24,20,2)/-3.97346123d-09,-3.54613705d-10/
      data fpp(24,21,1),fpp(24,21,2)/ 2.25091954d-08, 3.03165228d-10/
      data fpp(24,22,1),fpp(24,22,2)/-1.43476872d-07,-2.58047208d-10/
      data fpp(24,23,1),fpp(24,23,2)/ 0.00000000d+00,-4.70976396d-10/
      data fpp(25, 1,1),fpp(25, 1,2)/ 0.00000000d+00, 1.85057411d-09/
      data fpp(25, 2,1),fpp(25, 2,2)/ 8.62233662d-08, 6.98851785d-10/
      data fpp(25, 3,1),fpp(25, 3,2)/-1.91000947d-07,-2.24598125d-09/
      data fpp(25, 4,1),fpp(25, 4,2)/-2.03587507d-07, 1.08507320d-09/
      data fpp(25, 5,1),fpp(25, 5,2)/ 3.70372752d-07, 3.05688439d-10/
      data fpp(25, 6,1),fpp(25, 6,2)/ 4.98882740d-07, 9.21730413d-11/
      data fpp(25, 7,1),fpp(25, 7,2)/ 2.50499637d-07, 1.72561940d-09/
      data fpp(25, 8,1),fpp(25, 8,2)/-4.85196820d-07,-2.19465062d-09/
      data fpp(25, 9,1),fpp(25, 9,2)/-4.08338636d-07,-1.47016903d-10/
      data fpp(25,10,1),fpp(25,10,2)/ 2.91851411d-07, 3.38376020d-10/
      data fpp(25,11,1),fpp(25,11,2)/ 1.38776082d-07,-6.48717878d-12/
      data fpp(25,12,1),fpp(25,12,2)/ 8.01739724d-08,-9.12427305d-10/
      data fpp(25,13,1),fpp(25,13,2)/ 4.14436470d-07, 3.65619640d-09/
      data fpp(25,14,1),fpp(25,14,2)/-2.99599848d-06,-5.31235829d-09/
      data fpp(25,15,1),fpp(25,15,2)/-2.02932095d-07, 3.19323678d-09/
      data fpp(25,16,1),fpp(25,16,2)/-2.02677464d-07,-8.60588821d-10/
      data fpp(25,17,1),fpp(25,17,2)/-3.83713542d-08, 2.49118504d-10/
      data fpp(25,18,1),fpp(25,18,2)/ 4.90311718d-08,-1.35885195d-10/
      data fpp(25,19,1),fpp(25,19,2)/ 2.81452761d-08, 2.94422276d-10/
      data fpp(25,20,1),fpp(25,20,2)/-6.27655757d-08,-4.41803909d-10/
      data fpp(25,21,1),fpp(25,21,2)/-4.36892596d-10, 2.72793360d-10/
      data fpp(25,22,1),fpp(25,22,2)/ 8.61525597d-08,-4.93695315d-11/
      data fpp(25,23,1),fpp(25,23,2)/ 0.00000000d+00,-7.53152343d-11/
      data fpp(26, 1,1),fpp(26, 1,2)/ 0.00000000d+00,-1.14903039d-11/
      data fpp(26, 2,1),fpp(26, 2,2)/-1.24095675d-08, 2.29806077d-11/
      data fpp(26, 3,1),fpp(26, 3,2)/ 7.60264902d-08,-8.04321271d-11/
      data fpp(26, 4,1),fpp(26, 4,2)/-3.33914349d-09, 2.98747901d-10/
      data fpp(26, 5,1),fpp(26, 5,2)/-1.49910770d-07,-1.11455948d-09/
      data fpp(26, 6,1),fpp(26, 6,2)/-1.08846821d-07, 1.75949000d-09/
      data fpp(26, 7,1),fpp(26, 7,2)/-1.14355196d-07,-1.12340053d-09/
      data fpp(26, 8,1),fpp(26, 8,2)/ 1.71062572d-07, 3.34112137d-10/
      data fpp(26, 9,1),fpp(26, 9,2)/ 1.56904486d-07,-2.13048014d-10/
      data fpp(26,10,1),fpp(26,10,2)/-5.37621020d-08, 4.72087973d-10/
      data fpp(26,11,1),fpp(26,11,2)/-9.03008572d-08,-1.07530388d-09/
      data fpp(26,12,1),fpp(26,12,2)/ 9.12584719d-09, 2.02912753d-09/
      data fpp(26,13,1),fpp(26,13,2)/-2.05396192d-07,-4.64120626d-09/
      data fpp(26,14,1),fpp(26,14,2)/ 1.98305235d-06, 6.33569750d-09/
      data fpp(26,15,1),fpp(26,15,2)/ 1.22540123d-07,-3.90158374d-09/
      data fpp(26,16,1),fpp(26,16,2)/ 9.51247961d-08, 1.47063747d-09/
      data fpp(26,17,1),fpp(26,17,2)/-2.68263295d-08,-7.80966128d-10/
      data fpp(26,18,1),fpp(26,18,2)/-4.29267948d-08, 4.53227045d-10/
      data fpp(26,19,1),fpp(26,19,2)/-1.38132025d-07,-4.31942054d-10/
      data fpp(26,20,1),fpp(26,20,2)/ 1.50357639d-08, 7.45411690d-11/
      data fpp(26,21,1),fpp(26,21,2)/-2.07616250d-08, 1.33777378d-10/
      data fpp(26,22,1),fpp(26,22,2)/ 3.88666337d-08,-9.65067931d-12/
      data fpp(26,23,1),fpp(26,23,2)/ 0.00000000d+00,-9.51746603d-11/
      data fpp(27, 1,1),fpp(27, 1,2)/ 0.00000000d+00, 3.07181048d-12/
      data fpp(27, 2,1),fpp(27, 2,2)/-5.88298073d-09,-6.14362096d-12/
      data fpp(27, 3,1),fpp(27, 3,2)/-1.25789972d-08, 2.15026734d-11/
      data fpp(27, 4,1),fpp(27, 4,2)/-8.18881615d-09,-7.98670725d-11/
      data fpp(27, 5,1),fpp(27, 5,2)/ 2.45459343d-08, 2.97965617d-10/
      data fpp(27, 6,1),fpp(27, 6,2)/ 1.70990916d-08,-1.11199539d-09/
      data fpp(27, 7,1),fpp(27, 7,2)/ 3.78157704d-08, 1.75001596d-09/
      data fpp(27, 8,1),fpp(27, 8,2)/-3.05893063d-08,-1.08806845d-09/
      data fpp(27, 9,1),fpp(27, 9,2)/-2.65441387d-08, 2.02257831d-10/
      data fpp(27,10,1),fpp(27,10,2)/ 1.53606006d-08,-6.27392691d-11/
      data fpp(27,11,1),fpp(27,11,2)/ 2.15145306d-08, 4.86992452d-11/
      data fpp(27,12,1),fpp(27,12,2)/-7.46452777d-09,-1.32057712d-10/
      data fpp(27,13,1),fpp(27,13,2)/-1.10296595d-08, 4.79531602d-10/
      data fpp(27,14,1),fpp(27,14,2)/-4.91157815d-07,-5.86068696d-10/
      data fpp(27,15,1),fpp(27,15,2)/-2.61543208d-08, 6.47431813d-11/
      data fpp(27,16,1),fpp(27,16,2)/-4.03565602d-09, 3.27095971d-10/
      data fpp(27,17,1),fpp(27,17,2)/-2.03353344d-08,-1.73127064d-10/
      data fpp(27,18,1),fpp(27,18,2)/-1.57352015d-08,-2.34587715d-10/
      data fpp(27,19,1),fpp(27,19,2)/ 4.03234356d-08, 5.11477924d-10/
      data fpp(27,20,1),fpp(27,20,2)/-1.37245040d-08,-6.11323980d-10/
      data fpp(27,21,1),fpp(27,21,2)/ 6.25033214d-08, 7.33817994d-10/
      data fpp(27,22,1),fpp(27,22,2)/-3.96761811d-08,-5.23947998d-10/
      data fpp(27,23,1),fpp(27,23,2)/ 0.00000000d+00,-1.03802600d-09/
      data fpp(28, 1,1),fpp(28, 1,2)/ 0.00000000d+00, 1.92923544d-09/
      data fpp(28, 2,1),fpp(28, 2,2)/-2.40585096d-08, 9.41529119d-10/
      data fpp(28, 3,1),fpp(28, 3,2)/-2.57105014d-08,-8.95351917d-10/
      data fpp(28, 4,1),fpp(28, 4,2)/ 3.60944081d-08, 2.39878550d-10/
      data fpp(28, 5,1),fpp(28, 5,2)/ 5.17270329d-08,-6.41622834d-11/
      data fpp(28, 6,1),fpp(28, 6,2)/-1.95495458d-08, 1.67705835d-11/
      data fpp(28, 7,1),fpp(28, 7,2)/ 8.30921148d-08,-2.92005048d-12/
      data fpp(28, 8,1),fpp(28, 8,2)/-4.87053468d-08,-5.09038155d-12/
      data fpp(28, 9,1),fpp(28, 9,2)/-5.07279306d-08, 2.32815767d-11/
      data fpp(28,10,1),fpp(28,10,2)/-7.68030029d-09,-6.72995392d-11/
      data fpp(28,11,1),fpp(28,11,2)/ 6.42427347d-08, 2.45916580d-10/
      data fpp(28,12,1),fpp(28,12,2)/-3.92677361d-08,-9.16366782d-10/
      data fpp(28,13,1),fpp(28,13,2)/ 9.51482974d-09, 4.19550548d-10/
      data fpp(28,14,1),fpp(28,14,2)/-1.45842109d-06, 1.63816459d-09/
      data fpp(28,15,1),fpp(28,15,2)/-7.79228396d-08,-1.57220891d-09/
      data fpp(28,16,1),fpp(28,16,2)/-1.89821720d-08,-1.49328940d-10/
      data fpp(28,17,1),fpp(28,17,2)/-1.18323328d-08, 3.69524672d-10/
      data fpp(28,18,1),fpp(28,18,2)/-1.41323993d-08, 4.71230251d-10/
      data fpp(28,19,1),fpp(28,19,2)/ 1.56838282d-07,-1.05444567d-09/
      data fpp(28,20,1),fpp(28,20,2)/-2.01377480d-08, 1.94655245d-09/
      data fpp(28,21,1),fpp(28,21,2)/ 1.30748339d-07,-2.53176412d-09/
      data fpp(28,22,1),fpp(28,22,2)/-1.20161909d-07, 9.80504035d-10/
      data fpp(28,23,1),fpp(28,23,2)/ 0.00000000d+00, 2.20974798d-09/
 
      data fpppp( 1, 1),fpppp( 1, 2)/-3.53968542d-03,-4.20464143d-03/
      data fpppp( 1, 3),fpppp( 1, 4)/ 2.00031828d-02,-4.28437238d-02/
      data fpppp( 1, 5),fpppp( 1, 6)/ 3.74341174d-02, 1.02532616d-03/
      data fpppp( 1, 7),fpppp( 1, 8)/-2.71527904d-02, 2.67045317d-02/
      data fpppp( 1, 9),fpppp( 1,10)/-1.06934867d-02, 2.93742271d-03/
      data fpppp( 1,11),fpppp( 1,12)/-5.60758410d-04, 1.03567598d-04/
      data fpppp( 1,13),fpppp( 1,14)/ 4.33880194d-05,-5.46617820d-05/
      data fpppp( 1,15),fpppp( 1,16)/ 3.90044882d-05,-4.64156062d-05/
      data fpppp( 1,17),fpppp( 1,18)/ 5.05357779d-05,-6.71023500d-05/
      data fpppp( 1,19),fpppp( 1,20)/ 4.89119744d-05,-1.79245479d-05/
      data fpppp( 1,21),fpppp( 1,22)/ 1.01120204d-05,-3.83996565d-06/
      data fpppp( 1,23) /            -5.79522189d-06 /
      data fpppp( 2, 1),fpppp( 2, 2)/-1.39635046d-03,-1.75475452d-03/
      data fpppp( 2, 3),fpppp( 2, 4)/ 7.50910529d-03,-1.69049584d-02/
      data fpppp( 2, 5),fpppp( 2, 6)/ 1.28959983d-02, 6.68514148d-03/
      data fpppp( 2, 7),fpppp( 2, 8)/-1.64010274d-02, 1.35339759d-02/
      data fpppp( 2, 9),fpppp( 2,10)/-5.33137542d-03, 1.36936120d-03/
      data fpppp( 2,11),fpppp( 2,12)/-1.97180906d-04, 1.26090867d-05/
      data fpppp( 2,13),fpppp( 2,14)/ 2.99045573d-05,-3.74431028d-05/
      data fpppp( 2,15),fpppp( 2,16)/ 2.84170950d-05,-2.79464063d-05/
      data fpppp( 2,17),fpppp( 2,18)/ 1.81528479d-05,-2.64952956d-05/
      data fpppp( 2,19),fpppp( 2,20)/ 2.35116302d-05,-9.19322435d-06/
      data fpppp( 2,21),fpppp( 2,22)/ 5.42966078d-06,-2.07255486d-06/
      data fpppp( 2,23) /            -3.25331313d-06 /
      data fpppp( 3, 1),fpppp( 3, 2)/ 2.39466181d-03,-1.99124958d-03/
      data fpppp( 3, 3),fpppp( 3, 4)/ 3.81205783d-03,-2.60469006d-02/
      data fpppp( 3, 5),fpppp( 3, 6)/ 5.12792598d-02,-4.41588353d-02/
      data fpppp( 3, 7),fpppp( 3, 8)/ 3.07781826d-02,-2.35052617d-02/
      data fpppp( 3, 9),fpppp( 3,10)/ 9.66789180d-03,-3.11316467d-03/
      data fpppp( 3,11),fpppp( 3,12)/ 6.47327167d-04,-2.66767335d-04/
      data fpppp( 3,13),fpppp( 3,14)/ 5.34821775d-05,-3.07161207d-05/
      data fpppp( 3,15),fpppp( 3,16)/ 2.71199620d-05, 1.06022437d-06/
      data fpppp( 3,17),fpppp( 3,18)/-6.06559712d-05, 5.97397473d-05/
      data fpppp( 3,19),fpppp( 3,20)/-2.13545526d-05, 6.34546071d-06/
      data fpppp( 3,21),fpppp( 3,22)/-2.86666767d-06, 1.14618627d-06/
      data fpppp( 3,23) /             1.38047383d-06 /
      data fpppp( 4, 1),fpppp( 4, 2)/ 4.18803515d-04, 7.17459230d-03/
      data fpppp( 4, 3),fpppp( 4, 4)/-3.06745947d-02, 8.75936336d-02/
      data fpppp( 4, 5),fpppp( 4, 6)/-1.30562311d-01, 1.02760460d-01/
      data fpppp( 4, 7),fpppp( 4, 8)/-4.95386722d-02, 2.29958870d-02/
      data fpppp( 4, 9),fpppp( 4,10)/-9.06288687d-03, 2.60493475d-03/
      data fpppp( 4,11),fpppp( 4,12)/-1.91421749d-04, 1.13318930d-04/
      data fpppp( 4,13),fpppp( 4,14)/-5.26539904d-05, 1.27318012d-05/
      data fpppp( 4,15),fpppp( 4,16)/-6.69308158d-06,-6.81415263d-06/
      data fpppp( 4,17),fpppp( 4,18)/ 2.30258215d-05,-1.37231695d-05/
      data fpppp( 4,19),fpppp( 4,20)/ 1.90969950d-06,-1.94161954d-06/
      data fpppp( 4,21),fpppp( 4,22)/ 1.48589480d-06,-7.14728763d-07/
      data fpppp( 4,23) /            -1.30731293d-06 /
      data fpppp( 5, 1),fpppp( 5, 2)/ 3.06703030d-03, 6.64922805d-03/
      data fpppp( 5, 3),fpppp( 5, 4)/-2.34140559d-02, 6.42818462d-02/
      data fpppp( 5, 5),fpppp( 5, 6)/-1.01494919d-01, 8.11450451d-02/
      data fpppp( 5, 7),fpppp( 5, 8)/-3.43203935d-02, 8.27598134d-03/
      data fpppp( 5, 9),fpppp( 5,10)/-3.50115406d-04, 2.06965109d-04/
      data fpppp( 5,11),fpppp( 5,12)/-2.42986790d-04, 7.05386690d-05/
      data fpppp( 5,13),fpppp( 5,14)/-3.05478071d-05, 4.38822796d-06/
      data fpppp( 5,15),fpppp( 5,16)/-1.78329308d-06, 8.59703624d-07/
      data fpppp( 5,17),fpppp( 5,18)/ 7.75072983d-07, 2.48006279d-06/
      data fpppp( 5,19),fpppp( 5,20)/-3.53516207d-06, 8.17551808d-07/
      data fpppp( 5,21),fpppp( 5,22)/-3.32132328d-07, 3.37077579d-07/
      data fpppp( 5,23) /             4.86603475d-07 /
      data fpppp( 6, 1),fpppp( 6, 2)/-1.01942068d-02,-8.65278022d-03/
      data fpppp( 6, 3),fpppp( 6, 4)/ 3.93660833d-02,-7.52860823d-02/
      data fpppp( 6, 5),fpppp( 6, 6)/ 1.04413696d-01,-1.07364342d-01/
      data fpppp( 6, 7),fpppp( 6, 8)/ 5.87150195d-02,-1.32524842d-02/
      data fpppp( 6, 9),fpppp( 6,10)/ 2.43046266d-03,-9.02881752d-04/
      data fpppp( 6,11),fpppp( 6,12)/ 2.70001017d-04,-6.68754744d-05/
      data fpppp( 6,13),fpppp( 6,14)/ 7.98058409d-06,-2.82430607d-06/
      data fpppp( 6,15),fpppp( 6,16)/ 1.00926052d-06,-2.69709526d-06/
      data fpppp( 6,17),fpppp( 6,18)/ 7.02061361d-06,-4.99155632d-06/
      data fpppp( 6,19),fpppp( 6,20)/ 5.82120133d-07, 4.21201425d-07/
      data fpppp( 6,21),fpppp( 6,22)/-1.87693328d-07,-1.02059315d-07/
      data fpppp( 6,23) /            -2.14862092d-07 /
      data fpppp( 7, 1),fpppp( 7, 2)/ 5.14337912d-03, 2.30419190d-04/
      data fpppp( 7, 3),fpppp( 7, 4)/-1.02266586d-03,-1.50853130d-02/
      data fpppp( 7, 5),fpppp( 7, 6)/ 2.57118813d-02,-1.74698366d-03/
      data fpppp( 7, 7),fpppp( 7, 8)/-1.50688658d-02, 8.56672495d-03/
      data fpppp( 7, 9),fpppp( 7,10)/-2.60469801d-03, 9.82394447d-04/
      data fpppp( 7,11),fpppp( 7,12)/-2.40958902d-04, 6.14623244d-05/
      data fpppp( 7,13),fpppp( 7,14)/-1.85895457d-05, 3.88035666d-06/
      data fpppp( 7,15),fpppp( 7,16)/-2.24064769d-06, 3.09793224d-06/
      data fpppp( 7,17),fpppp( 7,18)/-2.01085771d-06, 8.44060869d-07/
      data fpppp( 7,19),fpppp( 7,20)/-2.54992243d-07,-9.69519858d-08/
      data fpppp( 7,21),fpppp( 7,22)/-1.66353750d-07, 1.64210554d-07/
      data fpppp( 7,23) /             3.80498838d-07 /
      data fpppp( 8, 1),fpppp( 8, 2)/-8.90659609d-03,-4.49620360d-03/
      data fpppp( 8, 3),fpppp( 8, 4)/ 2.55840548d-02,-3.41802176d-02/
      data fpppp( 8, 5),fpppp( 8, 6)/ 3.43237911d-02,-5.07168214d-02/
      data fpppp( 8, 7),fpppp( 8, 8)/ 4.03351831d-02,-1.40887945d-02/
      data fpppp( 8, 9),fpppp( 8,10)/ 3.97146610d-03,-1.29241670d-03/
      data fpppp( 8,11),fpppp( 8,12)/ 3.58110523d-04,-9.83068934d-05/
      data fpppp( 8,13),fpppp( 8,14)/ 2.45339465d-05,-5.99944083d-06/
      data fpppp( 8,15),fpppp( 8,16)/ 1.76626361d-06,-1.00404702d-06/
      data fpppp( 8,17),fpppp( 8,18)/ 9.77537062d-07,-6.84153167d-07/
      data fpppp( 8,19),fpppp( 8,20)/ 2.30993045d-07,-1.46504300d-07/
      data fpppp( 8,21),fpppp( 8,22)/ 3.42407393d-07,-2.88868348d-07/
      data fpppp( 8,23) /            -6.00090535d-07 /
      data fpppp( 9, 1),fpppp( 9, 2)/ 2.67595650d-03, 6.77059268d-03/
      data fpppp( 9, 3),fpppp( 9, 4)/-2.97509347d-02, 7.58841103d-02/
      data fpppp( 9, 5),fpppp( 9, 6)/-1.05340613d-01, 7.74743303d-02/
      data fpppp( 9, 7),fpppp( 9, 8)/-3.04370236d-02, 8.07242059d-03/
      data fpppp( 9, 9),fpppp( 9,10)/-1.98479867d-03, 6.27055569d-04/
      data fpppp( 9,11),fpppp( 9,12)/-1.61463779d-04, 4.16343848d-05/
      data fpppp( 9,13),fpppp( 9,14)/-1.08721932d-05, 1.98208274d-06/
      data fpppp( 9,15),fpppp( 9,16)/-6.87158247d-07, 8.84585628d-07/
      data fpppp( 9,17),fpppp( 9,18)/-5.91858281d-07, 5.66492972d-07/
      data fpppp( 9,19),fpppp( 9,20)/-3.62176880d-07, 1.51815791d-07/
      data fpppp( 9,21),fpppp( 9,22)/-6.45465292d-07, 6.41174114d-07/
      data fpppp( 9,23) /             1.33240767d-06 /
      data fpppp(10, 1),fpppp(10, 2)/ 2.97248968d-03,-1.74160632d-03/
      data fpppp(10, 3),fpppp(10, 4)/ 3.75180098d-03,-2.64810533d-02/
      data fpppp(10, 5),fpppp(10, 6)/ 4.32492612d-02,-1.74693144d-02/
      data fpppp(10, 7),fpppp(10, 8)/-2.14355074d-03,-6.65452813d-05/
      data fpppp(10, 9),fpppp(10,10)/ 1.21700456d-04,-4.51224163d-05/
      data fpppp(10,11),fpppp(10,12)/ 1.39900846d-05,-4.03577000d-06/
      data fpppp(10,13),fpppp(10,14)/ 4.69833209d-07, 3.46207129d-07/
      data fpppp(10,15),fpppp(10,16)/ 1.96973579d-07,-8.57809572d-07/
      data fpppp(10,17),fpppp(10,18)/ 8.69348167d-07,-5.46113068d-07/
      data fpppp(10,19),fpppp(10,20)/ 2.05439756d-07,-2.37365640d-07/
      data fpppp(10,21),fpppp(10,22)/ 9.18155601d-07,-9.04028629d-07/
      data fpppp(10,23) /            -1.87543987d-06 /
      data fpppp(11, 1),fpppp(11, 2)/ 1.84169209d-04,-5.47562127d-05/
      data fpppp(11, 3),fpppp(11, 4)/-1.36235836d-03, 1.07040803d-03/
      data fpppp(11, 5),fpppp(11, 6)/ 1.57071642d-03,-9.24530880d-04/
      data fpppp(11, 7),fpppp(11, 8)/-2.23728769d-04,-1.03640035d-04/
      data fpppp(11, 9),fpppp(11,10)/-2.89255600d-05, 1.91116049d-05/
      data fpppp(11,11),fpppp(11,12)/-3.39418834d-06, 2.21703497d-07/
      data fpppp(11,13),fpppp(11,14)/ 3.68456647d-07,-7.92304510d-07/
      data fpppp(11,15),fpppp(11,16)/ 2.95240703d-07, 5.48138824d-07/
      data fpppp(11,17),fpppp(11,18)/-6.87455807d-07, 4.04158823d-07/
      data fpppp(11,19),fpppp(11,20)/-1.42458811d-07, 2.02953917d-07/
      data fpppp(11,21),fpppp(11,22)/-6.95509036d-07, 6.33040950d-07/
      data fpppp(11,23) /             1.32530153d-06 /
      data fpppp(12, 1),fpppp(12, 2)/ 2.26937768d-04, 8.18226174d-05/
      data fpppp(12, 3),fpppp(12, 4)/ 1.03380242d-03,-1.85405011d-03/
      data fpppp(12, 5),fpppp(12, 6)/-2.70171750d-04, 1.47368884d-03/
      data fpppp(12, 7),fpppp(12, 8)/-5.10892946d-04, 2.82895482d-05/
      data fpppp(12, 9),fpppp(12,10)/-1.00959575d-05, 5.05715750d-06/
      data fpppp(12,11),fpppp(12,12)/-9.90233181d-07, 1.25403128d-07/
      data fpppp(12,13),fpppp(12,14)/-1.62546292d-07, 4.32109769d-07/
      data fpppp(12,15),fpppp(12,16)/-3.45445339d-07,-1.93808799d-07/
      data fpppp(12,17),fpppp(12,18)/ 4.24236310d-07,-1.66504141d-07/
      data fpppp(12,19),fpppp(12,20)/ 4.56191318d-09,-1.29133811d-07/
      data fpppp(12,21),fpppp(12,22)/ 3.52449253d-07,-2.57726234d-07/
      data fpppp(12,23) /            -5.55970706d-07 /
      data fpppp(13, 1),fpppp(13, 2)/-1.29742971d-04,-1.08802704d-04/
      data fpppp(13, 3),fpppp(13, 4)/-3.37485723d-04, 3.07512760d-04/
      data fpppp(13, 5),fpppp(13, 6)/ 8.58300416d-04,-7.78142091d-04/
      data fpppp(13, 7),fpppp(13, 8)/ 1.04216303d-04,-4.74344806d-05/
      data fpppp(13, 9),fpppp(13,10)/ 3.04696757d-06, 6.86202199d-07/
      data fpppp(13,11),fpppp(13,12)/-3.84354945d-07, 3.21421229d-07/
      data fpppp(13,13),fpppp(13,14)/-1.44828296d-07,-5.53508631d-08/
      data fpppp(13,15),fpppp(13,16)/-3.15792784d-08, 3.08737846d-07/
      data fpppp(13,17),fpppp(13,18)/-2.82118147d-07, 2.26441343d-08/
      data fpppp(13,19),fpppp(13,20)/ 3.77889644d-08, 1.45982675d-07/
      data fpppp(13,21),fpppp(13,22)/-3.52537951d-07, 2.11740087d-07/
      data fpppp(13,23) /             4.72361364d-07 /
      data fpppp(14, 1),fpppp(14, 2)/ 1.47833940d-04, 7.17618840d-05/
      data fpppp(14, 3),fpppp(14, 4)/-1.46914094d-04, 1.33523655d-04/
      data fpppp(14, 5),fpppp(14, 6)/-1.90873702d-04, 1.56730090d-04/
      data fpppp(14, 7),fpppp(14, 8)/-3.76907400d-05, 1.03170362d-06/
      data fpppp(14, 9),fpppp(14,10)/-7.06756355d-07, 5.08997122d-08/
      data fpppp(14,11),fpppp(14,12)/ 4.11032494d-07,-3.17472175d-07/
      data fpppp(14,13),fpppp(14,14)/-3.59835298d-08, 2.47049834d-07/
      data fpppp(14,15),fpppp(14,16)/-2.14191439d-08,-4.06172348d-07/
      data fpppp(14,17),fpppp(14,18)/ 3.37536927d-07, 6.77547675d-08/
      data fpppp(14,19),fpppp(14,20)/-3.63270754d-08,-4.44186836d-07/
      data fpppp(14,21),fpppp(14,22)/ 7.75871637d-07,-3.92520521d-07/
      data fpppp(14,23) /            -8.78498213d-07 /
      data fpppp(15, 1),fpppp(15, 2)/-1.63910800d-05,-1.15536909d-05/
      data fpppp(15, 3),fpppp(15, 4)/-2.57180108d-06,-8.09566385d-06/
      data fpppp(15, 5),fpppp(15, 6)/ 7.22417288d-05,-5.20044423d-05/
      data fpppp(15, 7),fpppp(15, 8)/ 7.67391927d-06,-4.21836302d-06/
      data fpppp(15, 9),fpppp(15,10)/-2.95079953d-07, 6.07212207d-07/
      data fpppp(15,11),fpppp(15,12)/-9.34275940d-07, 5.46798517d-07/
      data fpppp(15,13),fpppp(15,14)/-1.34719675d-08,-1.81264119d-07/
      data fpppp(15,15),fpppp(15,16)/ 4.12616799d-08, 2.99608048d-07/
      data fpppp(15,17),fpppp(15,18)/-2.78716758d-07,-7.77557445d-08/
      data fpppp(15,19),fpppp(15,20)/-9.07759057d-08, 1.00988721d-06/
      data fpppp(15,21),fpppp(15,22)/-1.62653162d-06, 7.50986861d-07/
      data fpppp(15,23) /             1.69595182d-06 /
      data fpppp(16, 1),fpppp(16, 2)/ 5.09797860d-06, 2.33768230d-06/
      data fpppp(16, 3),fpppp(16, 4)/-4.62551074d-06, 3.12143482d-06/
      data fpppp(16, 5),fpppp(16, 6)/-9.87614353d-06, 1.17569641d-05/
      data fpppp(16, 7),fpppp(16, 8)/-2.29914653d-06,-3.30698593d-07/
      data fpppp(16, 9),fpppp(16,10)/-4.48926229d-07,-4.35517828d-07/
      data fpppp(16,11),fpppp(16,12)/ 7.25150821d-07,-5.30270822d-07/
      data fpppp(16,13),fpppp(16,14)/ 6.62987557d-07,-9.03909056d-07/
      data fpppp(16,15),fpppp(16,16)/ 4.90919070d-07,-1.48530724d-07/
      data fpppp(16,17),fpppp(16,18)/ 8.78669886d-08, 1.73915623d-08/
      data fpppp(16,19),fpppp(16,20)/ 1.02400408d-07,-7.41364213d-07/
      data fpppp(16,21),fpppp(16,22)/ 1.27129390d-06,-5.89580938d-07/
      data fpppp(16,23) /            -1.34373207d-06 /
      data fpppp(17, 1),fpppp(17, 2)/-7.63996529d-07,-6.66904695d-07/
      data fpppp(17, 3),fpppp(17, 4)/ 5.39388184d-07,-2.13652259d-06/
      data fpppp(17, 5),fpppp(17, 6)/ 4.42823719d-06,-2.14704812d-06/
      data fpppp(17, 7),fpppp(17, 8)/ 9.86148664d-07,-8.51725499d-07/
      data fpppp(17, 9),fpppp(17,10)/-2.39947711d-07, 5.09331363d-07/
      data fpppp(17,11),fpppp(17,12)/-4.90883962d-07, 2.66884395d-07/
      data fpppp(17,13),fpppp(17,14)/-7.79801359d-07, 1.26532219d-06/
      data fpppp(17,15),fpppp(17,16)/-7.70877565d-07, 2.11805970d-07/
      data fpppp(17,17),fpppp(17,18)/-6.58749328d-08,-2.73923941d-08/
      data fpppp(17,19),fpppp(17,20)/ 1.63009452d-07,-7.60939152d-08/
      data fpppp(17,21),fpppp(17,22)/-2.60919522d-07, 1.89172156d-07/
      data fpppp(17,23) /             4.57858896d-07 /
      data fpppp(18, 1),fpppp(18, 2)/ 4.24968460d-07, 2.76014596d-07/
      data fpppp(18, 3),fpppp(18, 4)/-9.03315417d-07, 1.52367110d-06/
      data fpppp(18, 5),fpppp(18, 6)/-2.30159405d-06, 1.31136811d-06/
      data fpppp(18, 7),fpppp(18, 8)/ 3.38781862d-07, 1.20540954d-07/
      data fpppp(18, 9),fpppp(18,10)/ 1.32725632d-07,-6.85303485d-07/
      data fpppp(18,11),fpppp(18,12)/ 3.28359918d-07,-1.36704597d-08/
      data fpppp(18,13),fpppp(18,14)/ 5.11857799d-07,-9.43535687d-07/
      data fpppp(18,15),fpppp(18,16)/ 8.41575190d-07,-6.28473178d-07/
      data fpppp(18,17),fpppp(18,18)/ 3.25768828d-07, 6.14136942d-08/
      data fpppp(18,19),fpppp(18,20)/-7.01517023d-07, 1.18481942d-06/
      data fpppp(18,21),fpppp(18,22)/-7.56855174d-07, 1.30770226d-07/
      data fpppp(18,23) /             2.10024199d-07 /
      data fpppp(19, 1),fpppp(19, 2)/-8.37678616d-08,-1.69875225d-07/
      data fpppp(19, 3),fpppp(19, 4)/ 1.01305230d-06,-2.24564229d-06/
      data fpppp(19, 5),fpppp(19, 6)/ 1.88833976d-06, 1.64901146d-07/
      data fpppp(19, 7),fpppp(19, 8)/-1.60053569d-06, 3.32749830d-09/
      data fpppp(19, 9),fpppp(19,10)/ 1.28992072d-06,-6.12583565d-07/
      data fpppp(19,11),fpppp(19,12)/ 4.01314834d-07,-3.34024267d-07/
      data fpppp(19,13),fpppp(19,14)/-7.81755433d-08, 3.36099463d-07/
      data fpppp(19,15),fpppp(19,16)/-6.98588267d-07, 1.02636728d-06/
      data fpppp(19,17),fpppp(19,18)/-7.39844448d-07, 2.15606089d-08/
      data fpppp(19,19),fpppp(19,20)/ 1.14272169d-06,-1.96609971d-06/
      data fpppp(19,21),fpppp(19,22)/ 1.36057840d-06,-3.01158862d-07/
      data fpppp(19,23) /            -5.37634590d-07 /
      data fpppp(20, 1),fpppp(20, 2)/-2.91910132d-08, 4.20743031d-08/
      data fpppp(20, 3),fpppp(20, 4)/-3.23951796d-07, 8.40542058d-07/
      data fpppp(20, 5),fpppp(20, 6)/-6.83282981d-07,-6.66544699d-07/
      data fpppp(20, 7),fpppp(20, 8)/ 2.03716692d-06,-9.35030165d-08/
      data fpppp(20, 9),fpppp(20,10)/-1.78760624d-06, 1.15105700d-06/
      data fpppp(20,11),fpppp(20,12)/-6.50098533d-07, 3.60265395d-07/
      data fpppp(20,13),fpppp(20,14)/-1.34667811d-07, 6.06887100d-08/
      data fpppp(20,15),fpppp(20,16)/ 2.22086570d-07,-5.25781567d-07/
      data fpppp(20,17),fpppp(20,18)/ 4.79442840d-07,-6.22059915d-08/
      data fpppp(20,19),fpppp(20,20)/-7.07004164d-07, 1.14466700d-06/
      data fpppp(20,21),fpppp(20,22)/-8.28174316d-07, 2.69641192d-07/
      data fpppp(20,23) /             4.90126178d-07 /
      data fpppp(21, 1),fpppp(21, 2)/ 1.88180674d-07, 8.96050273d-08/
      data fpppp(21, 3),fpppp(21, 4)/-2.56971157d-07, 2.64454539d-07/
      data fpppp(21, 5),fpppp(21, 6)/-2.76507128d-07, 6.03610593d-07/
      data fpppp(21, 7),fpppp(21, 8)/-8.75224812d-07, 1.04498245d-07/
      data fpppp(21, 9),fpppp(21,10)/ 6.70273122d-07,-5.60585948d-07/
      data fpppp(21,11),fpppp(21,12)/ 3.56392374d-07,-1.73845432d-07/
      data fpppp(21,13),fpppp(21,14)/ 1.06643751d-07,-1.13254457d-07/
      data fpppp(21,15),fpppp(21,16)/ 7.37272085d-09, 1.07509714d-07/
      data fpppp(21,17),fpppp(21,18)/-1.23446307d-07, 7.96278568d-09/
      data fpppp(21,19),fpppp(21,20)/ 2.53466349d-07,-3.74207788d-07/
      data fpppp(21,21),fpppp(21,22)/ 3.12465575d-07,-1.64394289d-07/
      data fpppp(21,23) /            -3.08816088d-07 /
      data fpppp(22, 1),fpppp(22, 2)/-2.13232088d-07,-1.10843594d-07/
      data fpppp(22, 3),fpppp(22, 4)/ 3.97499018d-07,-5.14997785d-07/
      data fpppp(22, 5),fpppp(22, 6)/ 3.57244457d-07,-2.68216493d-07/
      data fpppp(22, 7),fpppp(22, 8)/ 2.46325050d-07, 4.27363917d-09/
      data fpppp(22, 9),fpppp(22,10)/-3.13680901d-07, 3.61269695d-07/
      data fpppp(22,11),fpppp(22,12)/-2.49941265d-07, 9.78964345d-08/
      data fpppp(22,13),fpppp(22,14)/-5.59156840d-08, 6.20762140d-08/
      data fpppp(22,15),fpppp(22,16)/-2.56889885d-08,-1.56599635d-08/
      data fpppp(22,17),fpppp(22,18)/ 2.53980897d-08, 5.19805360d-09/
      data fpppp(22,19),fpppp(22,20)/-8.63469194d-08, 1.21537760d-07/
      data fpppp(22,21),fpppp(22,22)/-1.11020299d-07, 6.87441665d-08/
      data fpppp(22,23) /             1.30702196d-07 /
      data fpppp(23, 1),fpppp(23, 2)/ 1.31614718d-07, 6.64352650d-08/
      data fpppp(23, 3),fpppp(23, 4)/-2.84155622d-07, 3.64193510d-07/
      data fpppp(23, 5),fpppp(23, 6)/-1.62367625d-07, 1.37861721d-08/
      data fpppp(23, 7),fpppp(23, 8)/-2.71016286d-08, 1.98136959d-09/
      data fpppp(23, 9),fpppp(23,10)/ 1.22380036d-07,-1.79268582d-07/
      data fpppp(23,11),fpppp(23,12)/ 1.27746133d-07,-4.12583425d-08/
      data fpppp(23,13),fpppp(23,14)/ 1.31176852d-08,-1.11271646d-08/
      data fpppp(23,15),fpppp(23,16)/ 5.99159630d-09, 1.57345330d-09/
      data fpppp(23,17),fpppp(23,18)/-2.52766949d-09,-6.47184268d-09/
      data fpppp(23,19),fpppp(23,20)/ 2.71703173d-08,-3.36223626d-08/
      data fpppp(23,21),fpppp(23,22)/ 2.70830720d-08,-1.55730777d-08/
      data fpppp(23,23) /            -2.86973462d-08 /
      data fpppp(24, 1),fpppp(24, 2)/-1.17250345d-08,-9.10096730d-09/
      data fpppp(24, 3),fpppp(24, 4)/ 8.48357255d-08,-1.40821771d-07/
      data fpppp(24, 5),fpppp(24, 6)/ 4.66958517d-08, 4.86380851d-08/
      data fpppp(24, 7),fpppp(24, 8)/ 1.65465349d-08,-6.24256804d-08/
      data fpppp(24, 9),fpppp(24,10)/-1.41980632d-08, 3.99943717d-08/
      data fpppp(24,11),fpppp(24,12)/-2.34434034d-08,-5.85225832d-09/
      data fpppp(24,13),fpppp(24,14)/ 4.34018556d-08,-6.12060105d-08/
      data fpppp(24,15),fpppp(24,16)/ 3.55195105d-08,-1.01830236d-08/
      data fpppp(24,17),fpppp(24,18)/ 3.12376865d-10, 6.63933678d-09/
      data fpppp(24,19),fpppp(24,20)/-1.05342169d-08, 8.60113933d-09/
      data fpppp(24,21),fpppp(24,22)/-6.10991811d-09, 4.29040965d-09/
      data fpppp(24,23) /             7.51605593d-09 /
      data fpppp(25, 1),fpppp(25, 2)/-3.99080686d-08,-1.40444188d-08/
      data fpppp(25, 3),fpppp(25, 4)/ 8.85830097d-09, 4.21242755d-08/
      data fpppp(25, 5),fpppp(25, 6)/-3.65841667d-08,-2.69567333d-09/
      data fpppp(25, 7),fpppp(25, 8)/-4.30874822d-08, 5.80903973d-08/
      data fpppp(25, 9),fpppp(25,10)/ 5.73900681d-09,-1.34737984d-08/
      data fpppp(25,11),fpppp(25,12)/-3.03973595d-09, 3.13011353d-08/
      data fpppp(25,13),fpppp(25,14)/-9.85929289d-08, 1.38388733d-07/
      data fpppp(25,15),fpppp(25,16)/-8.27519232d-08, 2.50502542d-08/
      data fpppp(25,17),fpppp(25,18)/-7.60600478d-09, 7.59549877d-10/
      data fpppp(25,19),fpppp(25,20)/-1.92950002d-09, 2.75695285d-09/
      data fpppp(25,21),fpppp(25,22)/ 9.60607140d-11,-1.68554955d-09/
      data fpppp(25,23) /            -3.71838321d-09 /
      data fpppp(26, 1),fpppp(26, 2)/ 1.43222568d-08, 4.94874680d-09/
      data fpppp(26, 3),fpppp(26, 4)/-9.91429394d-09,-5.56397694d-09/
      data fpppp(26, 5),fpppp(26, 6)/ 1.60407634d-08,-1.35665385d-08/
      data fpppp(26, 7),fpppp(26, 8)/ 2.70480327d-08,-2.48033176d-08/
      data fpppp(26, 9),fpppp(26,10)/ 2.67032578d-10, 6.59536199d-10/
      data fpppp(26,11),fpppp(26,12)/ 7.54249257d-09,-2.26715789d-08/
      data fpppp(26,13),fpppp(26,14)/ 6.43068985d-08,-9.03777800d-08/
      data fpppp(26,15),fpppp(26,16)/ 5.42665753d-08,-1.67027068d-08/
      data fpppp(26,17),fpppp(26,18)/ 6.87210401d-09,-4.43466964d-09/
      data fpppp(26,19),fpppp(26,20)/ 6.12028867d-09,-5.14410396d-09/
      data fpppp(26,21),fpppp(26,22)/ 3.11821651d-09,-1.60322322d-09/
      data fpppp(26,23) /            -2.61501718d-09 /
      data fpppp(27, 1),fpppp(27, 2)/-5.80590359d-10, 1.11677771d-10/
      data fpppp(27, 3),fpppp(27, 4)/-6.12493011d-11, 2.79400683d-09/
      data fpppp(27, 5),fpppp(27, 6)/-4.31208138d-09, 4.81073633d-09/
      data fpppp(27, 7),fpppp(27, 8)/-8.17161879d-09, 6.48651754d-09/
      data fpppp(27, 9),fpppp(27,10)/-3.86392742d-10,-5.52162932d-11/
      data fpppp(27,11),fpppp(27,12)/-1.53779064d-09, 4.09839955d-09/
      data fpppp(27,13),fpppp(27,14)/-1.33309719d-08, 2.06317068d-08/
      data fpppp(27,15),fpppp(27,16)/-1.24879564d-08, 2.74702886d-09/
      data fpppp(27,17),fpppp(27,18)/-8.05259677d-10, 1.72799853d-09/
      data fpppp(27,19),fpppp(27,20)/-3.01922419d-09, 3.74250362d-09/
      data fpppp(27,21),fpppp(27,22)/-4.13424440d-09, 2.09003430d-09/
      data fpppp(27,23) /             4.28544822d-09 /
      data fpppp(28, 1),fpppp(28, 2)/-5.30286228d-10, 4.65323930d-10/
      data fpppp(28, 3),fpppp(28, 4)/ 4.04655480d-09,-1.42188681d-09/
      data fpppp(28, 5),fpppp(28, 6)/-9.44035587d-09, 1.83251015d-08/
      data fpppp(28, 7),fpppp(28, 8)/-2.21196725d-08, 1.38881994d-08/
      data fpppp(28, 9),fpppp(28,10)/-2.28715420d-09, 2.74293080d-09/
      data fpppp(28,11),fpppp(28,12)/-6.95204473d-09, 1.45392378d-08/
      data fpppp(28,13),fpppp(28,14)/-4.20673242d-08, 6.27269496d-08/
      data fpppp(28,15),fpppp(28,16)/-3.79344239d-08, 9.71729087d-09/
      data fpppp(28,17),fpppp(28,18)/-4.04218927d-09, 5.88447188d-09/
      data fpppp(28,19),fpppp(28,20)/-9.09945338d-09, 9.63653893d-09/
      data fpppp(28,21),fpppp(28,22)/-9.77497531d-09, 5.35558214d-09/
      data fpppp(28,23) /             1.06169762d-08 /
 
      c(1,1)=fpppp(ix+1,iy+1)
      c(1,2)=fpppp(ix+1,iy  )
      c(2,1)=fpppp(ix  ,iy+1)
      c(2,2)=fpppp(ix,  iy  )
      c(1,3)=fpp(ix+1,iy+1,1)
      c(1,4)=fpp(ix+1,iy  ,1)
      c(2,3)=fpp(ix,  iy+1,1)
      c(2,4)=fpp(ix,  iy,  1)
      c(3,1)=fpp(ix+1,iy+1,2)
      c(3,2)=fpp(ix+1,iy  ,2)
      c(4,1)=fpp(ix,  iy+1,2)
      c(4,2)=fpp(ix,  iy,  2)
      c(3,3)=f(ix+1,iy+1)
      c(3,4)=f(ix+1,iy  )
      c(4,3)=f(ix,  iy+1)
      c(4,4)=f(ix,  iy  )
      px(1)=((xi-xix)**3/(6.0*delxi))-(xi-xix)*delxi/6.0
      px(2)=(xi-xixp1)*delxi/6.0-((xi-xixp1)**3/(6.0*delxi))
      px(3)=(xi-xix)/delxi
      px(4)=(xixp1-xi)/delxi
      py(1)=((yi-yiy)**3/(6.0*delyi))-(yi-yiy)*delyi/6.0
      py(2)=(yi-yiyp1)*delyi/6.0-((yi-yiyp1)**3/(6.0*delyi))
      py(3)=(yi-yiy)/delyi
      py(4)=(yiyp1-yi)/delyi

      fi=0.0d 00
      do l=1,4
        sum=0.0d 00
        do i=1,4
          sum=sum + c(i,l) * px(i)
        enddo
        fi = fi + sum * py(l)
      enddo
      return
      end  
      subroutine c10_spl(xi,yi,ix,iy,delxi,delyi,xix,xixp1,
     x                    yiy,yiyp1,fi)
      implicit real*8 (a-h,o-z)
      dimension fpp(28,23,2),f(28,23),fpppp(28,23)
      dimension c(4,4),px(4),py(4)
 
      data f( 4, 1),f( 4, 2) /  0.00000000d+00 ,  3.00000000d-08 /
      data f( 4, 3),f( 4, 4) /  7.92200000d-05 ,  2.36181000d-03 /
      data f( 4, 5),f( 4, 6) /  8.57952000d-03 ,  5.37128000d-03 /
      data f( 4, 7),f( 4, 8) /  2.01077000d-03 , -7.42880000d-04 /
      data f( 4, 9),f( 4,10) / -3.03410000d-04 ,  4.67860000d-04 /
      data f( 4,11),f( 4,12) /  1.27680000d-04 ,  1.74800000d-05 /
      data f( 4,13),f( 4,14) /  1.90000000d-07 ,  6.90000000d-07 /
      data f( 4,15),f( 4,16) /  6.90000000d-06 ,  9.22300000d-05 /
      data f( 4,17),f( 4,18) /  1.21530000d-04 ,  5.91100000d-05 /
      data f( 4,19),f( 4,20) /  1.22300000d-05 ,  1.05000000d-06 /
      data f( 4,21),f( 4,22) /  3.00000000d-08 ,  1.00000000d-08 /
      data f( 4,23) /           0.00000000d+00 /
      data f( 5, 1),f( 5, 2) /  0.00000000d+00 ,  1.00000000d-08 /
      data f( 5, 3),f( 5, 4) /  1.45110000d-04 ,  4.22465000d-03 /
      data f( 5, 5),f( 5, 6) /  9.02530000d-03 ,  7.35591000d-03 /
      data f( 5, 7),f( 5, 8) /  1.49017000d-03 , -6.87950000d-04 /
      data f( 5, 9),f( 5,10) / -2.91580000d-04 ,  2.93080000d-04 /
      data f( 5,11),f( 5,12) /  8.37600000d-05 ,  8.74000000d-06 /
      data f( 5,13),f( 5,14) /  3.10000000d-07 , -5.60000000d-07 /
      data f( 5,15),f( 5,16) /  3.77000000d-06 ,  6.12000000d-05 /
      data f( 5,17),f( 5,18) /  7.75400000d-05 ,  3.82100000d-05 /
      data f( 5,19),f( 5,20) /  8.05000000d-06 ,  6.70000000d-07 /
      data f( 5,21),f( 5,22) /  0.00000000d+00 ,  1.00000000d-08 /
      data f( 5,23) /           0.00000000d+00 /
      data f( 6, 1),f( 6, 2) /  0.00000000d+00 ,  1.50000000d-07 /
      data f( 6, 3),f( 6, 4) /  9.28400000d-05 ,  6.87313000d-03 /
      data f( 6, 5),f( 6, 6) /  6.28089000d-03 ,  1.10361400d-02 /
      data f( 6, 7),f( 6, 8) /  1.89156000d-03 , -6.31060000d-04 /
      data f( 6, 9),f( 6,10) / -2.65380000d-04 ,  1.83120000d-04 /
      data f( 6,11),f( 6,12) /  5.40000000d-05 ,  4.57000000d-06 /
      data f( 6,13),f( 6,14) / -2.00000000d-08 , -1.33000000d-06 /
      data f( 6,15),f( 6,16) /  7.50000000d-07 ,  3.95100000d-05 /
      data f( 6,17),f( 6,18) /  4.94300000d-05 ,  2.47500000d-05 /
      data f( 6,19),f( 6,20) /  5.23000000d-06 ,  3.70000000d-07 /
      data f( 6,21),f( 6,22) / -5.00000000d-08 ,  0.00000000d+00 /
      data f( 6,23) /           0.00000000d+00 /
      data f( 7, 1),f( 7, 2) /  0.00000000d+00 , -2.87900000d-05 /
      data f( 7, 3),f( 7, 4) /  1.74970000d-04 ,  6.72720000d-03 /
      data f( 7, 5),f( 7, 6) /  5.29054000d-03 ,  1.20795100d-02 /
      data f( 7, 7),f( 7, 8) /  2.69374000d-03 ,  1.19690000d-04 /
      data f( 7, 9),f( 7,10) /  1.80260000d-04 ,  9.23300000d-05 /
      data f( 7,11),f( 7,12) /  2.25800000d-05 ,  1.46000000d-06 /
      data f( 7,13),f( 7,14) / -1.80000000d-07 , -1.25000000d-06 /
      data f( 7,15),f( 7,16) / -3.22000000d-06 ,  1.51400000d-05 /
      data f( 7,17),f( 7,18) /  1.98100000d-05 ,  1.01000000d-05 /
      data f( 7,19),f( 7,20) /  2.20000000d-06 ,  1.80000000d-07 /
      data f( 7,21),f( 7,22) / -8.00000000d-08 ,  0.00000000d+00 /
      data f( 7,23) /           0.00000000d+00 /
      data f( 8, 1),f( 8, 2) /  0.00000000d+00 ,  1.38000000d-06 /
      data f( 8, 3),f( 8, 4) /  1.46720000d-04 ,  6.80816000d-03 /
      data f( 8, 5),f( 8, 6) /  8.99834000d-03 ,  1.15266500d-02 /
      data f( 8, 7),f( 8, 8) /  2.13468000d-03 ,  8.44300000d-05 /
      data f( 8, 9),f( 8,10) /  7.64100000d-05 ,  4.79900000d-05 /
      data f( 8,11),f( 8,12) /  8.93000000d-06 ,  8.80000000d-07 /
      data f( 8,13),f( 8,14) / -7.00000000d-08 , -1.76000000d-06 /
      data f( 8,15),f( 8,16) / -3.41000000d-06 ,  4.65000000d-06 /
      data f( 8,17),f( 8,18) /  7.18000000d-06 ,  3.77000000d-06 /
      data f( 8,19),f( 8,20) /  7.10000000d-07 , -9.00000000d-08 /
      data f( 8,21),f( 8,22) / -1.50000000d-07 ,  0.00000000d+00 /
      data f( 8,23) /           0.00000000d+00 /
      data f( 9, 1),f( 9, 2) /  0.00000000d+00 ,  1.10000000d-07 /
      data f( 9, 3),f( 9, 4) /  7.85700000d-05 ,  3.15457000d-03 /
      data f( 9, 5),f( 9, 6) /  9.82100000d-03 ,  5.59844000d-03 /
      data f( 9, 7),f( 9, 8) /  5.63830000d-04 ,  4.85000000d-05 /
      data f( 9, 9),f( 9,10) /  5.15200000d-05 ,  2.49200000d-05 /
      data f( 9,11),f( 9,12) /  3.13000000d-06 ,  4.60000000d-07 /
      data f( 9,13),f( 9,14) /  5.00000000d-08 , -7.70000000d-07 /
      data f( 9,15),f( 9,16) / -2.92000000d-06 ,  7.20000000d-07 /
      data f( 9,17),f( 9,18) /  1.91000000d-06 ,  9.60000000d-07 /
      data f( 9,19),f( 9,20) /  2.30000000d-07 , -3.00000000d-08 /
      data f( 9,21),f( 9,22) / -1.00000000d-07 , -4.00000000d-08 /
      data f( 9,23) /           0.00000000d+00 /
      data f(10, 1),f(10, 2) /  0.00000000d+00 , -7.00000000d-08 /
      data f(10, 3),f(10, 4) /  3.07700000d-05 ,  6.29840000d-04 /
      data f(10, 5),f(10, 6) /  2.82047000d-03 ,  8.45760000d-04 /
      data f(10, 7),f(10, 8) /  1.55030000d-04 ,  4.48300000d-05 /
      data f(10, 9),f(10,10) /  3.81000000d-05 ,  1.21700000d-05 /
      data f(10,11),f(10,12) /  1.51000000d-06 ,  6.00000000d-07 /
      data f(10,13),f(10,14) /  1.60000000d-07 , -6.90000000d-07 /
      data f(10,15),f(10,16) / -1.64000000d-06 , -7.70000000d-07 /
      data f(10,17),f(10,18) /  5.00000000d-08 ,  1.30000000d-07 /
      data f(10,19),f(10,20) / -2.00000000d-08 , -9.00000000d-08 /
      data f(10,21),f(10,22) / -1.40000000d-07 ,  3.60000000d-07 /
      data f(10,23) /           0.00000000d+00 /
      data f(11, 1),f(11, 2) /  0.00000000d+00 ,  2.00000000d-08 /
      data f(11, 3),f(11, 4) /  8.64000000d-06 ,  1.52460000d-04 /
      data f(11, 5),f(11, 6) / -4.26200000d-04 , -9.55100000d-05 /
      data f(11, 7),f(11, 8) /  6.93500000d-05 ,  4.15100000d-05 /
      data f(11, 9),f(11,10) /  2.63200000d-05 ,  5.29000000d-06 /
      data f(11,11),f(11,12) /  3.00000000d-08 ,  5.10000000d-07 /
      data f(11,13),f(11,14) /  1.60000000d-07 , -4.50000000d-07 /
      data f(11,15),f(11,16) / -7.30000000d-07 , -1.11000000d-06 /
      data f(11,17),f(11,18) / -6.60000000d-07 , -2.80000000d-07 /
      data f(11,19),f(11,20) / -1.50000000d-07 , -1.00000000d-07 /
      data f(11,21),f(11,22) / -7.00000000d-08 , -1.70000000d-07 /
      data f(11,23) /           0.00000000d+00 /
      data f(12, 1),f(12, 2) /  0.00000000d+00 ,  2.00000000d-08 /
      data f(12, 3),f(12, 4) /  6.80400000d-05 ,  4.55120000d-04 /
      data f(12, 5),f(12, 6) / -1.02470000d-04 ,  9.64000000d-06 /
      data f(12, 7),f(12, 8) /  3.97500000d-05 ,  3.05200000d-05 /
      data f(12, 9),f(12,10) /  1.60400000d-05 ,  2.11000000d-06 /
      data f(12,11),f(12,12) / -1.00000000d-08 ,  5.20000000d-07 /
      data f(12,13),f(12,14) /  1.90000000d-07 ,  1.00000000d-08 /
      data f(12,15),f(12,16) / -1.49000000d-06 , -1.00000000d-06 /
      data f(12,17),f(12,18) / -8.50000000d-07 , -4.10000000d-07 /
      data f(12,19),f(12,20) / -7.00000000d-08 ,  4.00000000d-08 /
      data f(12,21),f(12,22) / -8.00000000d-08 , -1.10000000d-07 /
      data f(12,23) /           0.00000000d+00 /
      data f(13, 1),f(13, 2) /  0.00000000d+00 , -1.00000000d-08 /
      data f(13, 3),f(13, 4) / -1.16000000d-06 ,  1.38230000d-04 /
      data f(13, 5),f(13, 6) /  3.36900000d-05 ,  1.41100000d-05 /
      data f(13, 7),f(13, 8) /  2.16100000d-05 ,  1.45900000d-05 /
      data f(13, 9),f(13,10) /  6.38000000d-06 ,  2.50000000d-07 /
      data f(13,11),f(13,12) / -1.90000000d-07 , -5.40000000d-07 /
      data f(13,13),f(13,14) /  2.10000000d-07 , -2.70000000d-07 /
      data f(13,15),f(13,16) / -2.90000000d-07 , -5.60000000d-07 /
      data f(13,17),f(13,18) / -6.60000000d-07 , -3.10000000d-07 /
      data f(13,19),f(13,20) / -3.00000000d-08 ,  1.20000000d-07 /
      data f(13,21),f(13,22) /  9.00000000d-08 , -1.20000000d-07 /
      data f(13,23) /           0.00000000d+00 /
      data f(14, 1),f(14, 2) /  0.00000000d+00 ,  1.50000000d-07 /
      data f(14, 3),f(14, 4) /  3.50000000d-07 ,  8.38000000d-06 /
      data f(14, 5),f(14, 6) /  6.87000000d-06 ,  9.09000000d-06 /
      data f(14, 7),f(14, 8) /  1.02600000d-05 ,  6.17000000d-06 /
      data f(14, 9),f(14,10) /  2.42000000d-06 ,  9.00000000d-08 /
      data f(14,11),f(14,12) / -1.80000000d-07 , -5.00000000d-08 /
      data f(14,13),f(14,14) /  6.00000000d-08 ,  1.20000000d-07 /
      data f(14,15),f(14,16) / -1.50000000d-07 , -3.70000000d-07 /
      data f(14,17),f(14,18) / -3.90000000d-07 , -2.20000000d-07 /
      data f(14,19),f(14,20) /  0.00000000d+00 ,  8.00000000d-08 /
      data f(14,21),f(14,22) / -2.00000000d-08 ,  6.00000000d-08 /
      data f(14,23) /           0.00000000d+00 /
      data f(15, 1),f(15, 2) /  0.00000000d+00 , -8.00000000d-08 /
      data f(15, 3),f(15, 4) /  4.70000000d-07 ,  1.69000000d-06 /
      data f(15, 5),f(15, 6) /  3.22000000d-06 ,  5.41000000d-06 /
      data f(15, 7),f(15, 8) /  5.64000000d-06 ,  3.25000000d-06 /
      data f(15, 9),f(15,10) /  1.19000000d-06 , -9.00000000d-08 /
      data f(15,11),f(15,12) /  3.10000000d-07 , -4.00000000d-08 /
      data f(15,13),f(15,14) / -9.00000000d-08 , -8.00000000d-08 /
      data f(15,15),f(15,16) /  1.90000000d-07 , -2.20000000d-07 /
      data f(15,17),f(15,18) / -2.10000000d-07 , -7.00000000d-08 /
      data f(15,19),f(15,20) / -1.00000000d-08 , -1.00000000d-08 /
      data f(15,21),f(15,22) /  1.50000000d-07 , -5.00000000d-08 /
      data f(15,23) /           0.00000000d+00 /
      data f(16, 1),f(16, 2) /  0.00000000d+00 ,  1.00000000d-07 /
      data f(16, 3),f(16, 4) /  6.00000000d-08 ,  6.10000000d-07 /
      data f(16, 5),f(16, 6) /  1.59000000d-06 ,  2.83000000d-06 /
      data f(16, 7),f(16, 8) /  2.85000000d-06 ,  1.65000000d-06 /
      data f(16, 9),f(16,10) /  6.10000000d-07 , -2.80000000d-07 /
      data f(16,11),f(16,12) / -6.90000000d-07 , -1.00000000d-08 /
      data f(16,13),f(16,14) /  1.00000000d-08 , -9.00000000d-08 /
      data f(16,15),f(16,16) /  1.40000000d-07 , -1.40000000d-07 /
      data f(16,17),f(16,18) / -1.80000000d-07 , -9.00000000d-08 /
      data f(16,19),f(16,20) / -1.00000000d-08 , -1.00000000d-08 /
      data f(16,21),f(16,22) / -3.70000000d-07 , -2.00000000d-08 /
      data f(16,23) /           0.00000000d+00 /
      data f(17, 1),f(17, 2) /  0.00000000d+00 ,  1.30000000d-07 /
      data f(17, 3),f(17, 4) /  1.20000000d-07 ,  2.70000000d-07 /
      data f(17, 5),f(17, 6) /  5.40000000d-07 ,  8.60000000d-07 /
      data f(17, 7),f(17, 8) /  8.60000000d-07 ,  5.20000000d-07 /
      data f(17, 9),f(17,10) /  5.00000000d-08 , -3.10000000d-07 /
      data f(17,11),f(17,12) / -7.00000000d-08 ,  3.20000000d-07 /
      data f(17,13),f(17,14) / -3.00000000d-08 ,  1.70000000d-07 /
      data f(17,15),f(17,16) /  4.50000000d-07 , -1.90000000d-07 /
      data f(17,17),f(17,18) / -1.40000000d-07 , -6.00000000d-08 /
      data f(17,19),f(17,20) /  1.00000000d-08 , -6.00000000d-08 /
      data f(17,21),f(17,22) / -2.00000000d-08 , -2.00000000d-08 /
      data f(17,23) /           0.00000000d+00 /
      data f(18, 1),f(18, 2) /  0.00000000d+00 , -1.00000000d-08 /
      data f(18, 3),f(18, 4) /  1.00000000d-07 ,  1.20000000d-07 /
      data f(18, 5),f(18, 6) /  1.10000000d-07 ,  2.00000000d-07 /
      data f(18, 7),f(18, 8) /  1.70000000d-07 ,  3.00000000d-08 /
      data f(18, 9),f(18,10) / -1.30000000d-07 ,  7.00000000d-07 /
      data f(18,11),f(18,12) / -6.00000000d-08 ,  0.00000000d+00 /
      data f(18,13),f(18,14) / -2.00000000d-08 ,  5.00000000d-08 /
      data f(18,15),f(18,16) /  0.00000000d+00 , -4.00000000d-08 /
      data f(18,17),f(18,18) / -1.00000000d-08 , -5.00000000d-08 /
      data f(18,19),f(18,20) / -4.00000000d-08 , -2.00000000d-07 /
      data f(18,21),f(18,22) /  4.00000000d-08 , -4.00000000d-08 /
      data f(18,23) /           0.00000000d+00 /
      data f(19, 1),f(19, 2) /  0.00000000d+00 , -8.00000000d-08 /
      data f(19, 3),f(19, 4) /  4.00000000d-08 ,  2.80000000d-07 /
      data f(19, 5),f(19, 6) /  9.00000000d-08 ,  3.00000000d-08 /
      data f(19, 7),f(19, 8) /  4.00000000d-08 , -5.00000000d-08 /
      data f(19, 9),f(19,10) / -1.50000000d-07 , -7.00000000d-08 /
      data f(19,11),f(19,12) / -1.20000000d-07 ,  1.00000000d-08 /
      data f(19,13),f(19,14) /  3.00000000d-08 ,  7.00000000d-08 /
      data f(19,15),f(19,16) / -2.00000000d-08 , -1.10000000d-07 /
      data f(19,17),f(19,18) /  1.00000000d-08 , -2.00000000d-08 /
      data f(19,19),f(19,20) / -4.00000000d-08 ,  3.20000000d-07 /
      data f(19,21),f(19,22) / -7.00000000d-08 , -5.00000000d-08 /
      data f(19,23) /           0.00000000d+00 /
      data f(20, 1),f(20, 2) /  0.00000000d+00 , -1.20000000d-07 /
      data f(20, 3),f(20, 4) / -3.00000000d-08 ,  2.00000000d-08 /
      data f(20, 5),f(20, 6) /  1.80000000d-07 ,  2.00000000d-08 /
      data f(20, 7),f(20, 8) / -8.00000000d-08 ,  5.00000000d-08 /
      data f(20, 9),f(20,10) /  4.40000000d-07 , -1.20000000d-07 /
      data f(20,11),f(20,12) /  2.60000000d-07 ,  1.00000000d-07 /
      data f(20,13),f(20,14) /  1.00000000d-08 , -2.40000000d-07 /
      data f(20,15),f(20,16) /  3.00000000d-08 ,  4.00000000d-08 /
      data f(20,17),f(20,18) / -7.00000000d-08 ,  3.00000000d-08 /
      data f(20,19),f(20,20) /  6.00000000d-08 , -4.00000000d-08 /
      data f(20,21),f(20,22) /  1.00000000d-08 , -1.00000000d-08 /
      data f(20,23) /           0.00000000d+00 /
      data f(21, 1),f(21, 2) /  0.00000000d+00 , -1.40000000d-07 /
      data f(21, 3),f(21, 4) / -2.00000000d-08 , -1.00000000d-08 /
      data f(21, 5),f(21, 6) /  3.00000000d-08 , -2.00000000d-08 /
      data f(21, 7),f(21, 8) / -1.30000000d-07 , -8.00000000d-08 /
      data f(21, 9),f(21,10) / -6.00000000d-08 , -1.20000000d-07 /
      data f(21,11),f(21,12) /  1.00000000d-08 ,  2.00000000d-08 /
      data f(21,13),f(21,14) /  2.00000000d-08 ,  3.50000000d-07 /
      data f(21,15),f(21,16) /  1.00000000d-08 ,  0.00000000d+00 /
      data f(21,17),f(21,18) / -3.00000000d-08 , -3.00000000d-08 /
      data f(21,19),f(21,20) / -6.00000000d-08 ,  0.00000000d+00 /
      data f(21,21),f(21,22) /  0.00000000d+00 ,  1.90000000d-07 /
      data f(21,23) /           0.00000000d+00 /
      data f(22, 1),f(22, 2) /  0.00000000d+00 , -4.00000000d-08 /
      data f(22, 3),f(22, 4) / -1.00000000d-07 ,  5.40000000d-07 /
      data f(22, 5),f(22, 6) / -3.00000000d-08 , -7.00000000d-08 /
      data f(22, 7),f(22, 8) /  4.00000000d-08 , -8.00000000d-08 /
      data f(22, 9),f(22,10) / -1.00000000d-07 , -1.17000000d-06 /
      data f(22,11),f(22,12) /  9.00000000d-08 ,  2.00000000d-08 /
      data f(22,13),f(22,14) / -1.00000000d-08 , -2.00000000d-08 /
      data f(22,15),f(22,16) / -1.00000000d-08 , -1.00000000d-08 /
      data f(22,17),f(22,18) / -1.00000000d-08 ,  0.00000000d+00 /
      data f(22,19),f(22,20) /  0.00000000d+00 ,  0.00000000d+00 /
      data f(22,21),f(22,22) /  0.00000000d+00 , -2.00000000d-08 /
      data f(22,23) /           0.00000000d+00 /
      data f(23, 1),f(23, 2) /  0.00000000d+00 , -3.00000000d-08 /
      data f(23, 3),f(23, 4) /  8.00000000d-08 ,  3.00000000d-08 /
      data f(23, 5),f(23, 6) /  2.00000000d-08 , -8.00000000d-08 /
      data f(23, 7),f(23, 8) / -1.00000000d-08 , -2.00000000d-08 /
      data f(23, 9),f(23,10) / -1.00000000d-08 , -2.00000000d-08 /
      data f(23,11),f(23,12) /  1.00000000d-08 ,  2.00000000d-08 /
      data f(23,13),f(23,14) / -1.00000000d-08 , -1.00000000d-08 /
      data f(23,15),f(23,16) /  0.00000000d+00 ,  0.00000000d+00 /
      data f(23,17),f(23,18) / -1.00000000d-08 ,  0.00000000d+00 /
      data f(23,19),f(23,20) /  0.00000000d+00 ,  0.00000000d+00 /
      data f(23,21),f(23,22) / -1.00000000d-08 , -3.00000000d-08 /
      data f(23,23) /           0.00000000d+00 /
      data f(24, 1),f(24, 2) /  0.00000000d+00 , -1.00000000d-08 /
      data f(24, 3),f(24, 4) / -3.00000000d-08 , -8.00000000d-08 /
      data f(24, 5),f(24, 6) /  0.00000000d+00 ,  0.00000000d+00 /
      data f(24, 7),f(24, 8) /  0.00000000d+00 , -1.00000000d-08 /
      data f(24, 9),f(24,10) /  2.00000000d-08 ,  1.00000000d-08 /
      data f(24,11),f(24,12) /  0.00000000d+00 , -2.00000000d-08 /
      data f(24,13),f(24,14) / -1.00000000d-08 ,  0.00000000d+00 /
      data f(24,15),f(24,16) / -1.00000000d-08 , -2.00000000d-08 /
      data f(24,17),f(24,18) /  0.00000000d+00 ,  1.00000000d-08 /
      data f(24,19),f(24,20) /  0.00000000d+00 ,  0.00000000d+00 /
      data f(24,21),f(24,22) /  0.00000000d+00 , -1.00000000d-08 /
      data f(24,23) /           0.00000000d+00 /
      data f(25, 1),f(25, 2) /  0.00000000d+00 ,  0.00000000d+00 /
      data f(25, 3),f(25, 4) / -1.00000000d-08 ,  2.00000000d-08 /
      data f(25, 5),f(25, 6) /  0.00000000d+00 ,  2.00000000d-08 /
      data f(25, 7),f(25, 8) /  2.00000000d-08 , -1.00000000d-08 /
      data f(25, 9),f(25,10) / -3.00000000d-08 ,  2.00000000d-08 /
      data f(25,11),f(25,12) / -3.00000000d-08 ,  1.00000000d-08 /
      data f(25,13),f(25,14) / -1.00000000d-08 ,  1.40000000d-07 /
      data f(25,15),f(25,16) / -1.00000000d-08 ,  0.00000000d+00 /
      data f(25,17),f(25,18) /  0.00000000d+00 , -2.00000000d-08 /
      data f(25,19),f(25,20) /  0.00000000d+00 ,  0.00000000d+00 /
      data f(25,21),f(25,22) / -1.00000000d-08 , -1.00000000d-08 /
      data f(25,23) /           0.00000000d+00 /
      data f(26, 1),f(26, 2) /  0.00000000d+00 , -1.00000000d-08 /
      data f(26, 3),f(26, 4) /  0.00000000d+00 ,  0.00000000d+00 /
      data f(26, 5),f(26, 6) /  0.00000000d+00 ,  1.00000000d-08 /
      data f(26, 7),f(26, 8) /  1.00000000d-08 ,  0.00000000d+00 /
      data f(26, 9),f(26,10) /  0.00000000d+00 ,  1.00000000d-08 /
      data f(26,11),f(26,12) /  1.00000000d-08 ,  0.00000000d+00 /
      data f(26,13),f(26,14) /  1.00000000d-08 , -1.70000000d-07 /
      data f(26,15),f(26,16) / -3.00000000d-08 , -3.00000000d-08 /
      data f(26,17),f(26,18) / -2.00000000d-08 , -1.00000000d-08 /
      data f(26,19),f(26,20) /  1.00000000d-08 ,  0.00000000d+00 /
      data f(26,21),f(26,22) /  0.00000000d+00 ,  1.00000000d-08 /
      data f(26,23) /           0.00000000d+00 /
      data f(27, 1),f(27, 2) /  0.00000000d+00 ,  0.00000000d+00 /
      data f(27, 3),f(27, 4) /  0.00000000d+00 ,  0.00000000d+00 /
      data f(27, 5),f(27, 6) / -1.00000000d-08 ,  0.00000000d+00 /
      data f(27, 7),f(27, 8) /  2.00000000d-08 ,  1.00000000d-08 /
      data f(27, 9),f(27,10) / -1.00000000d-08 , -1.00000000d-08 /
      data f(27,11),f(27,12) /  0.00000000d+00 ,  0.00000000d+00 /
      data f(27,13),f(27,14) /  0.00000000d+00 ,  5.00000000d-08 /
      data f(27,15),f(27,16) / -1.00000000d-08 , -2.00000000d-08 /
      data f(27,17),f(27,18) /  1.00000000d-08 , -1.00000000d-08 /
      data f(27,19),f(27,20) / -2.00000000d-08 ,  0.00000000d+00 /
      data f(27,21),f(27,22) / -1.00000000d-08 ,  1.00000000d-08 /
      data f(27,23) /           0.00000000d+00 /
      data f(28, 1),f(28, 2) /  0.00000000d+00 , -2.00000000d-08 /
      data f(28, 3),f(28, 4) / -1.00000000d-08 ,  1.00000000d-08 /
      data f(28, 5),f(28, 6) /  0.00000000d+00 ,  0.00000000d+00 /
      data f(28, 7),f(28, 8) /  0.00000000d+00 ,  0.00000000d+00 /
      data f(28, 9),f(28,10) /  0.00000000d+00 ,  0.00000000d+00 /
      data f(28,11),f(28,12) /  0.00000000d+00 , -1.00000000d-08 /
      data f(28,13),f(28,14) /  1.70000000d-07 ,  1.30000000d-07 /
      data f(28,15),f(28,16) / -5.00000000d-08 , -2.00000000d-08 /
      data f(28,17),f(28,18) / -2.00000000d-08 , -2.00000000d-08 /
      data f(28,19),f(28,20) /  0.00000000d+00 , -2.00000000d-08 /
      data f(28,21),f(28,22) /  7.00000000d-08 , -2.00000000d-08 /
      data f(28,23) /           0.00000000d+00 /
 
      data fpp( 1, 1,1),fpp( 1, 1,2)/ 0.00000000d+00, 2.52010068d-05/
      data fpp( 1, 2,1),fpp( 1, 2,2)/ 2.80260690d-05, 2.42147863d-05/
      data fpp( 1, 3,1),fpp( 1, 3,2)/ 8.26832417d-04,-1.20951352d-04/
      data fpp( 1, 4,1),fpp( 1, 4,2)/-2.90441329d-01, 2.38512222d-04/
      data fpp( 1, 5,1),fpp( 1, 5,2)/ 1.44015576d-01,-2.10124737d-04/
      data fpp( 1, 6,1),fpp( 1, 6,2)/ 1.48865170d-04, 8.64931270d-05/
      data fpp( 1, 7,1),fpp( 1, 7,2)/ 2.47966660d-01,-6.05525705d-05/
      data fpp( 1, 8,1),fpp( 1, 8,2)/-4.84962872d-02, 1.12325155d-04/
      data fpp( 1, 9,1),fpp( 1, 9,2)/ 7.32337726d-02,-7.93976498d-05/
      data fpp( 1,10,1),fpp( 1,10,2)/-2.92831091d-02, 3.88277720d-05/
      data fpp( 1,11,1),fpp( 1,11,2)/ 6.32647477d-03,-2.56142381d-05/
      data fpp( 1,12,1),fpp( 1,12,2)/ 4.56230363d-03, 1.20345806d-05/
      data fpp( 1,13,1),fpp( 1,13,2)/-2.62110785d-04,-7.20684143d-07/
      data fpp( 1,14,1),fpp( 1,14,2)/ 6.44935343d-05,-1.78843998d-07/
      data fpp( 1,15,1),fpp( 1,15,2)/ 5.83695511d-04, 2.40926014d-06/
      data fpp( 1,16,1),fpp( 1,16,2)/ 1.39639584d-03, 3.12203454d-07/
      data fpp( 1,17,1),fpp( 1,17,2)/ 4.31587191d-03,-5.45147395d-06/
      data fpp( 1,18,1),fpp( 1,18,2)/ 1.57760658d-03, 1.15309235d-06/
      data fpp( 1,19,1),fpp( 1,19,2)/ 6.35058706d-04, 1.58250453d-06/
      data fpp( 1,20,1),fpp( 1,20,2)/ 9.41451135d-05, 1.69889506d-07/
      data fpp( 1,21,1),fpp( 1,21,2)/ 1.79417502d-04,-4.32625593d-08/
      data fpp( 1,22,1),fpp( 1,22,2)/-1.98038066d-05, 2.83607312d-08/
      data fpp( 1,23,1),fpp( 1,23,2)/ 0.00000000d+00, 1.86196344d-08/
      data fpp( 2, 1,1),fpp( 2, 1,2)/ 0.00000000d+00,-2.81596067d-05/
      data fpp( 2, 2,1),fpp( 2, 2,2)/-5.05213794d-06,-6.31986617d-07/
      data fpp( 2, 3,1),fpp( 2, 3,2)/ 2.52733517d-03, 2.98907532d-05/
      data fpp( 2, 4,1),fpp( 2, 4,2)/-1.32453342d-01, 4.99305740d-05/
      data fpp( 2, 5,1),fpp( 2, 5,2)/ 8.38418475d-02,-1.15293849d-04/
      data fpp( 2, 6,1),fpp( 2, 6,2)/ 1.78162697d-02,-3.64535777d-05/
      data fpp( 2, 7,1),fpp( 2, 7,2)/ 1.07063680d-01, 1.31491360d-04/
      data fpp( 2, 8,1),fpp( 2, 8,2)/-4.22844256d-02,-5.52030614d-05/
      data fpp( 2, 9,1),fpp( 2, 9,2)/ 2.93434547d-02,-1.11047140d-05/
      data fpp( 2,10,1),fpp( 2,10,2)/-1.39517818d-02, 1.43754728d-05/
      data fpp( 2,11,1),fpp( 2,11,2)/ 7.35605046d-03,-1.16997772d-05/
      data fpp( 2,12,1),fpp( 2,12,2)/ 3.20439274d-03, 6.54263588d-06/
      data fpp( 2,13,1),fpp( 2,13,2)/-1.45778430d-04,-4.22366340d-07/
      data fpp( 2,14,1),fpp( 2,14,2)/ 7.40129314d-05,-2.97970515d-07/
      data fpp( 2,15,1),fpp( 2,15,2)/ 4.89608979d-04, 2.24904840d-06/
      data fpp( 2,16,1),fpp( 2,16,2)/ 9.88208316d-04,-5.19023093d-07/
      data fpp( 2,17,1),fpp( 2,17,2)/ 3.25425619d-03,-3.49575603d-06/
      data fpp( 2,18,1),fpp( 2,18,2)/ 1.58378683d-03, 8.40047211d-07/
      data fpp( 2,19,1),fpp( 2,19,2)/ 4.82882587d-04, 1.09976718d-06/
      data fpp( 2,20,1),fpp( 2,20,2)/ 5.57097729d-05, 7.92840539d-08/
      data fpp( 2,21,1),fpp( 2,21,2)/ 1.04164996d-04, 4.49660088d-09/
      data fpp( 2,22,1),fpp( 2,22,2)/-9.39238679d-06, 5.92954260d-09/
      data fpp( 2,23,1),fpp( 2,23,2)/ 0.00000000d+00,-1.44147713d-08/
      data fpp( 3, 1,1),fpp( 3, 1,2)/ 0.00000000d+00,-4.90969052d-05/
      data fpp( 3, 2,1),fpp( 3, 2,2)/ 5.81824828d-05, 1.02046105d-05/
      data fpp( 3, 3,1),fpp( 3, 3,2)/ 5.02982692d-03, 1.19096634d-05/
      data fpp( 3, 4,1),fpp( 3, 4,2)/ 1.37730698d-01, 2.15202336d-04/
      data fpp( 3, 5,1),fpp( 3, 5,2)/ 3.67763034d-01,-3.75789408d-04/
      data fpp( 3, 6,1),fpp( 3, 6,2)/ 2.62690056d-01, 9.09672953d-05/
      data fpp( 3, 7,1),fpp( 3, 7,2)/ 4.99886199d-02, 3.94506266d-05/
      data fpp( 3, 8,1),fpp( 3, 8,2)/-2.39968010d-01, 3.28725982d-05/
      data fpp( 3, 9,1),fpp( 3, 9,2)/-1.90265592d-01,-2.44402196d-05/
      data fpp( 3,10,1),fpp( 3,10,2)/ 7.51062361d-02, 1.43851596d-05/
      data fpp( 3,11,1),fpp( 3,11,2)/ 1.52193234d-02,-6.87681891d-06/
      data fpp( 3,12,1),fpp( 3,12,2)/ 1.63412541d-03, 3.66371602d-06/
      data fpp( 3,13,1),fpp( 3,13,2)/-6.77549582d-06,-2.75645184d-07/
      data fpp( 3,14,1),fpp( 3,14,2)/ 5.34547402d-05,-3.10535289d-07/
      data fpp( 3,15,1),fpp( 3,15,2)/ 3.79868575d-04, 1.93838634d-06/
      data fpp( 3,16,1),fpp( 3,16,2)/-2.72291046d-05,-8.65810066d-07/
      data fpp( 3,17,1),fpp( 3,17,2)/ 1.08710335d-03,-2.25754607d-06/
      data fpp( 3,18,1),fpp( 3,18,2)/ 1.88524609d-03, 7.40594359d-07/
      data fpp( 3,19,1),fpp( 3,19,2)/ 3.31410945d-04, 6.52368639d-07/
      data fpp( 3,20,1),fpp( 3,20,2)/-1.69842053d-05, 6.39310865d-08/
      data fpp( 3,21,1),fpp( 3,21,2)/-2.07748762d-06, 5.10701517d-09/
      data fpp( 3,22,1),fpp( 3,22,2)/ 1.53733538d-05, 3.84085281d-09/
      data fpp( 3,23,1),fpp( 3,23,2)/ 0.00000000d+00,-1.38704264d-08/
      data fpp( 4, 1,1),fpp( 4, 1,2)/ 0.00000000d+00,-9.08534356d-05/
      data fpp( 4, 2,1),fpp( 4, 2,2)/-2.15677793d-04, 2.12668711d-05/
      data fpp( 4, 3,1),fpp( 4, 3,2)/ 4.72535717d-03, 2.47843511d-05/
      data fpp( 4, 4,1),fpp( 4, 4,2)/ 1.52285490d-02, 4.08411725d-04/
      data fpp( 4, 5,1),fpp( 4, 5,2)/-5.52647983d-01,-7.14002449d-04/
      data fpp( 4, 6,1),fpp( 4, 6,2)/-2.87658494d-01, 1.85370073d-04/
      data fpp( 4, 7,1),fpp( 4, 7,2)/-3.00484159d-01,-6.40226434d-05/
      data fpp( 4, 8,1),fpp( 4, 8,2)/ 2.75982468d-01, 2.16366900d-04/
      data fpp( 4, 9,1),fpp( 4, 9,2)/ 2.05140912d-01,-3.50961578d-05/
      data fpp( 4,10,1),fpp( 4,10,2)/-9.38791628d-02,-9.35517660d-06/
      data fpp( 4,11,1),fpp( 4,11,2)/-8.35344022d-04, 5.82986427d-06/
      data fpp( 4,12,1),fpp( 4,12,2)/ 8.07105607d-04,-1.65480467d-07/
      data fpp( 4,13,1),fpp( 4,13,2)/ 5.28804131d-05, 4.06657600d-07/
      data fpp( 4,14,1),fpp( 4,14,2)/ 1.38168108d-04,-3.93749933d-07/
      data fpp( 4,15,1),fpp( 4,15,2)/ 3.24916722d-04, 1.51094213d-06/
      data fpp( 4,16,1),fpp( 4,16,2)/ 1.08270810d-03,-9.02818597d-07/
      data fpp( 4,17,1),fpp( 4,17,2)/ 2.78933042d-03,-1.26146775d-06/
      data fpp( 4,18,1),fpp( 4,18,2)/ 1.15322881d-03, 4.45489581d-07/
      data fpp( 4,19,1),fpp( 4,19,2)/ 1.77473634d-04, 4.11909422d-07/
      data fpp( 4,20,1),fpp( 4,20,2)/ 3.02270483d-05, 4.88727323d-08/
      data fpp( 4,21,1),fpp( 4,21,2)/ 1.44954030d-07, 2.19964898d-09/
      data fpp( 4,22,1),fpp( 4,22,2)/-1.01010283d-05, 2.32867172d-09/
      data fpp( 4,23,1),fpp( 4,23,2)/ 0.00000000d+00,-1.09143359d-08/
      data fpp( 5, 1,1),fpp( 5, 1,2)/ 0.00000000d+00,-1.36802024d-04/
      data fpp( 5, 2,1),fpp( 5, 2,2)/ 7.62528690d-04,-1.21331512d-05/
      data fpp( 5, 3,1),fpp( 5, 3,2)/-2.28752556d-02, 2.20156229d-04/
      data fpp( 5, 4,1),fpp( 5, 4,2)/ 2.02707106d-01, 7.57738342d-05/
      data fpp( 5, 5,1),fpp( 5, 5,2)/-4.02677102d-01,-3.50185166d-04/
      data fpp( 5, 6,1),fpp( 5, 6,2)/ 4.32225921d-01,-2.27842770d-04/
      data fpp( 5, 7,1),fpp( 5, 7,2)/ 2.19758018d-01, 2.54432244d-04/
      data fpp( 5, 8,1),fpp( 5, 8,2)/-8.41778596d-02, 9.51425918d-05/
      data fpp( 5, 9,1),fpp( 5, 9,2)/-5.93380553d-02,-1.71250117d-05/
      data fpp( 5,10,1),fpp( 5,10,2)/ 3.30864149d-02,-8.68106087d-06/
      data fpp( 5,11,1),fpp( 5,11,2)/ 2.10205270d-03, 4.21045517d-06/
      data fpp( 5,12,1),fpp( 5,12,2)/ 4.41452158d-04,-1.02759793d-07/
      data fpp( 5,13,1),fpp( 5,13,2)/-9.07461564d-05, 1.95984007d-07/
      data fpp( 5,14,1),fpp( 5,14,2)/ 1.18728286d-05,-2.27576234d-07/
      data fpp( 5,15,1),fpp( 5,15,2)/-8.35354632d-05, 1.02632093d-06/
      data fpp( 5,16,1),fpp( 5,16,2)/ 9.58396693d-04,-6.91707484d-07/
      data fpp( 5,17,1),fpp( 5,17,2)/ 1.44157495d-03,-7.24890993d-07/
      data fpp( 5,18,1),fpp( 5,18,2)/ 7.19838652d-04, 2.51071458d-07/
      data fpp( 5,19,1),fpp( 5,19,2)/ 1.34694521d-04, 2.70805162d-07/
      data fpp( 5,20,1),fpp( 5,20,2)/-1.92398791d-06, 3.25078948d-08/
      data fpp( 5,21,1),fpp( 5,21,2)/-4.50232850d-06, 1.76325910d-09/
      data fpp( 5,22,1),fpp( 5,22,2)/ 1.03075938d-06, 1.23906883d-09/
      data fpp( 5,23,1),fpp( 5,23,2)/ 0.00000000d+00,-7.91953441d-09/
      data fpp( 6, 1,1),fpp( 6, 1,2)/ 0.00000000d+00,-2.08673657d-04/
      data fpp( 6, 2,1),fpp( 6, 2,2)/-2.73843697d-03,-9.91526858d-05/
      data fpp( 6, 3,1),fpp( 6, 3,2)/ 1.58796652d-02, 6.27494000d-04/
      data fpp( 6, 4,1),fpp( 6, 4,2)/-3.54672971d-01,-8.05799316d-04/
      data fpp( 6, 5,1),fpp( 6, 5,2)/ 2.49242391d-01, 8.26296063d-04/
      data fpp( 6, 6,1),fpp( 6, 6,2)/-4.23885191d-01,-1.21598734d-03/
      data fpp( 6, 7,1),fpp( 6, 7,2)/-2.53539127d-02, 7.01694079d-04/
      data fpp( 6, 8,1),fpp( 6, 8,2)/ 6.19049708d-02,-1.51858150d-06/
      data fpp( 6, 9,1),fpp( 6, 9,2)/ 4.08333096d-02,-2.42775325d-06/
      data fpp( 6,10,1),fpp( 6,10,2)/ 4.25503172d-04,-8.92904950d-06/
      data fpp( 6,11,1),fpp( 6,11,2)/ 9.23133230d-04, 3.48675125d-06/
      data fpp( 6,12,1),fpp( 6,12,2)/ 1.69085761d-04,-2.36555489d-07/
      data fpp( 6,13,1),fpp( 6,13,2)/ 4.01042126d-05, 1.49870708d-07/
      data fpp( 6,14,1),fpp( 6,14,2)/ 1.02340578d-04,-1.66127345d-07/
      data fpp( 6,15,1),fpp( 6,15,2)/ 7.52251306d-05, 7.18038672d-07/
      data fpp( 6,16,1),fpp( 6,16,2)/ 6.87705125d-04,-5.05227341d-07/
      data fpp( 6,17,1),fpp( 6,17,2)/ 9.72369762d-04,-4.27529306d-07/
      data fpp( 6,18,1),fpp( 6,18,2)/ 4.31416578d-04, 1.39344566d-07/
      data fpp( 6,19,1),fpp( 6,19,2)/ 9.97482832d-05, 1.79751042d-07/
      data fpp( 6,20,1),fpp( 6,20,2)/ 2.54689033d-05, 2.12512672d-08/
      data fpp( 6,21,1),fpp( 6,21,2)/ 5.86435996d-06, 1.64388961d-09/
      data fpp( 6,22,1),fpp( 6,22,2)/-2.20092375d-08, 3.73174399d-10/
      data fpp( 6,23,1),fpp( 6,23,2)/ 0.00000000d+00,-6.13658720d-09/
      data fpp( 7, 1,1),fpp( 7, 1,2)/ 0.00000000d+00,-1.81267976d-04/
      data fpp( 7, 2,1),fpp( 7, 2,2)/ 3.45104655d-03,-9.88316484d-05/
      data fpp( 7, 3,1),fpp( 7, 3,2)/-8.20086778d-03, 6.32406569d-04/
      data fpp( 7, 4,1),fpp( 7, 4,2)/ 1.46231861d-01,-9.07161829d-04/
      data fpp( 7, 5,1),fpp( 7, 5,2)/ 1.28381878d-01, 1.07890715d-03/
      data fpp( 7, 6,1),fpp( 7, 6,2)/ 1.07979114d-01,-1.43431556d-03/
      data fpp( 7, 7,1),fpp( 7, 7,2)/-3.39072709d-02, 7.76417499d-04/
      data fpp( 7, 8,1),fpp( 7, 8,2)/-4.80804827d-02,-3.65416326d-05/
      data fpp( 7, 9,1),fpp( 7, 9,2)/-3.38449012d-02, 2.05783194d-06/
      data fpp( 7,10,1),fpp( 7,10,2)/ 1.54978304d-03,-4.46879500d-07/
      data fpp( 7,11,1),fpp( 7,11,2)/ 3.94573961d-04, 8.20486065d-07/
      data fpp( 7,12,1),fpp( 7,12,2)/ 5.65166373d-05, 8.27352410d-08/
      data fpp( 7,13,1),fpp( 7,13,2)/ 6.04403085d-08, 1.73729712d-08/
      data fpp( 7,14,1),fpp( 7,14,2)/-6.99581474d-05,-1.18027126d-07/
      data fpp( 7,15,1),fpp( 7,15,2)/ 1.26592340d-04, 4.00735531d-07/
      data fpp( 7,16,1),fpp( 7,16,2)/ 3.09186279d-04,-2.65115000d-07/
      data fpp( 7,17,1),fpp( 7,17,2)/ 3.52103238d-04,-1.61675533d-07/
      data fpp( 7,18,1),fpp( 7,18,2)/ 1.86330941d-04, 4.90171301d-08/
      data fpp( 7,19,1),fpp( 7,19,2)/ 2.49078901d-05, 7.42070121d-08/
      data fpp( 7,20,1),fpp( 7,20,2)/-1.39447161d-05, 6.95482150d-09/
      data fpp( 7,21,1),fpp( 7,21,2)/-4.84191562d-06, 3.57370190d-09/
      data fpp( 7,22,1),fpp( 7,22,2)/ 2.55064802d-06,-8.49629115d-10/
      data fpp( 7,23,1),fpp( 7,23,2)/ 0.00000000d+00,-4.97518544d-09/
      data fpp( 8, 1,1),fpp( 8, 1,2)/ 0.00000000d+00,-2.10072545d-04/
      data fpp( 8, 2,1),fpp( 8, 2,2)/-2.19924925d-03,-7.23509097d-05/
      data fpp( 8, 3,1),fpp( 8, 3,2)/ 3.66805930d-04, 5.34026584d-04/
      data fpp( 8, 4,1),fpp( 8, 4,2)/-1.96220974d-01,-4.99891426d-04/
      data fpp( 8, 5,1),fpp( 8, 5,2)/-5.80474033d-02, 3.92436721d-04/
      data fpp( 8, 6,1),fpp( 8, 6,2)/-2.47465763d-01,-9.88704259d-04/
      data fpp( 8, 7,1),fpp( 8, 7,2)/-4.32030038d-02, 7.01513116d-04/
      data fpp( 8, 8,1),fpp( 8, 8,2)/ 1.25154601d-02,-5.53354063d-05/
      data fpp( 8, 9,1),fpp( 8, 9,2)/ 1.21227950d-02, 9.96370877d-06/
      data fpp( 8,10,1),fpp( 8,10,2)/ 3.42864679d-04,-2.96622317d-06/
      data fpp( 8,11,1),fpp( 8,11,2)/ 1.64070926d-04, 1.26278389d-06/
      data fpp( 8,12,1),fpp( 8,12,2)/-1.56523106d-05,-2.24312410d-07/
      data fpp( 8,13,1),fpp( 8,13,2)/ 1.54026131d-07, 6.04657457d-08/
      data fpp( 8,14,1),fpp( 8,14,2)/ 8.89920118d-05,-6.19505727d-08/
      data fpp( 8,15,1),fpp( 8,15,2)/-1.45944899d-05, 1.89736545d-07/
      data fpp( 8,16,1),fpp( 8,16,2)/ 1.57549759d-04,-1.14395608d-07/
      data fpp( 8,17,1),fpp( 8,17,2)/ 1.67717284d-04,-6.39541121d-08/
      data fpp( 8,18,1),fpp( 8,18,2)/ 7.12596575d-05, 1.38120567d-08/
      data fpp( 8,19,1),fpp( 8,19,2)/ 3.16201564d-05, 2.97058854d-08/
      data fpp( 8,20,1),fpp( 8,20,2)/ 1.83099610d-05, 2.96440186d-09/
      data fpp( 8,21,1),fpp( 8,21,2)/ 7.50330252d-06, 2.83650719d-09/
      data fpp( 8,22,1),fpp( 8,22,2)/-1.01805828d-05,-1.71043063d-09/
      data fpp( 8,23,1),fpp( 8,23,2)/ 0.00000000d+00,-4.99478469d-09/
      data fpp( 9, 1,1),fpp( 9, 1,2)/ 0.00000000d+00,-1.19460211d-04/
      data fpp( 9, 2,1),fpp( 9, 2,2)/ 6.29950450d-04, 1.47872212d-05/
      data fpp( 9, 3,1),fpp( 9, 3,2)/ 7.48644062d-04, 7.91153257d-05/
      data fpp( 9, 4,1),fpp( 9, 4,2)/ 7.84695359d-02, 3.88161076d-04/
      data fpp( 9, 5,1),fpp( 9, 5,2)/-3.28963265d-01,-7.70056429d-04/
      data fpp( 9, 6,1),fpp( 9, 6,2)/ 7.55814381d-02, 7.87070415d-05/
      data fpp( 9, 7,1),fpp( 9, 7,2)/ 5.49507862d-02, 2.60336263d-04/
      data fpp( 9, 8,1),fpp( 9, 8,2)/-2.08185763d-03,-3.54248945d-05/
      data fpp( 9, 9,1),fpp( 9, 9,2)/-2.80227890d-03, 5.76731471d-06/
      data fpp( 9,10,1),fpp( 9,10,2)/ 2.69258248d-04,-1.54789688d-06/
      data fpp( 9,11,1),fpp( 9,11,2)/ 1.26642334d-04, 7.12872829d-07/
      data fpp( 9,12,1),fpp( 9,12,2)/ 3.00926049d-05,-1.56394433d-07/
      data fpp( 9,13,1),fpp( 9,13,2)/ 8.23455166d-07, 4.83049024d-08/
      data fpp( 9,14,1),fpp( 9,14,2)/-6.10098997d-05,-6.14251767d-08/
      data fpp( 9,15,1),fpp( 9,15,2)/ 3.37856197d-05, 1.17595804d-07/
      data fpp( 9,16,1),fpp( 9,16,2)/ 4.46146844d-05,-6.15580403d-08/
      data fpp( 9,17,1),fpp( 9,17,2)/ 8.10276238d-05,-1.83636429d-08/
      data fpp( 9,18,1),fpp( 9,18,2)/ 5.66304288d-05, 6.61261194d-09/
      data fpp( 9,19,1),fpp( 9,19,2)/ 1.11484359d-07, 5.11319514d-09/
      data fpp( 9,20,1),fpp( 9,20,2)/-9.79512792d-06, 1.13460749d-09/
      data fpp( 9,21,1),fpp( 9,21,2)/-7.17129448d-06, 1.74837491d-09/
      data fpp( 9,22,1),fpp( 9,22,2)/ 3.21716834d-05,-3.28107116d-10/
      data fpp( 9,23,1),fpp( 9,23,2)/ 0.00000000d+00,-1.63594644d-09/
      data fpp(10, 1,1),fpp(10, 1,2)/ 0.00000000d+00,-2.56059805d-05/
      data fpp(10, 2,1),fpp(10, 2,2)/-1.57052549d-04, 1.19355609d-05/
      data fpp(10, 3,1),fpp(10, 3,2)/-3.08882178d-04,-1.47178632d-05/
      data fpp(10, 4,1),fpp(10, 4,2)/ 5.16718308d-02, 1.83311092d-04/
      data fpp(10, 5,1),fpp(10, 5,2)/ 2.00421963d-01,-3.36552104d-04/
      data fpp(10, 6,1),fpp(10, 6,2)/ 1.21469510d-01, 1.63215724d-04/
      data fpp(10, 7,1),fpp(10, 7,2)/-2.29264096d-03,-8.15559139d-06/
      data fpp(10, 8,1),fpp(10, 8,2)/ 6.50970429d-04, 8.73384174d-06/
      data fpp(10, 9,1),fpp(10, 9,2)/ 8.06820577d-04,-1.94697558d-06/
      data fpp(10,10,1),fpp(10,10,2)/ 1.28102329d-04, 7.25805857d-07/
      data fpp(10,11,1),fpp(10,11,2)/-4.36402633d-05,-4.00478525d-08/
      data fpp(10,12,1),fpp(10,12,2)/-2.07181092d-05, 1.93855530d-08/
      data fpp(10,13,1),fpp(10,13,2)/-4.94784680d-06,-9.29435942d-09/
      data fpp(10,14,1),fpp(10,14,2)/ 1.85475871d-05,-6.80811530d-09/
      data fpp(10,15,1),fpp(10,15,2)/-2.04798879d-06, 3.05268206d-08/
      data fpp(10,16,1),fpp(10,16,2)/ 2.99915033d-05,-6.09916722d-09/
      data fpp(10,17,1),fpp(10,17,2)/ 1.96722205d-05,-9.13015174d-09/
      data fpp(10,18,1),fpp(10,18,2)/-7.81372685d-07,-1.78022581d-09/
      data fpp(10,19,1),fpp(10,19,2)/ 2.43390618d-06, 2.45105498d-09/
      data fpp(10,20,1),fpp(10,20,2)/ 2.87055068d-06,-3.22399412d-09/
      data fpp(10,21,1),fpp(10,21,2)/ 7.68187539d-06, 1.16449215d-08/
      data fpp(10,22,1),fpp(10,22,2)/-5.25061507d-05,-1.03556919d-08/
      data fpp(10,23,1),fpp(10,23,2)/ 0.00000000d+00,-2.18221541d-08/
      data fpp(11, 1,1),fpp(11, 1,2)/ 0.00000000d+00,-1.62873160d-06/
      data fpp(11, 2,1),fpp(11, 2,2)/ 3.87597465d-05,-5.83853681d-06/
      data fpp(11, 3,1),fpp(11, 3,2)/ 4.33738465d-03, 2.70468788d-05/
      data fpp(11, 4,1),fpp(11, 4,2)/ 2.19456410d-02,-6.99009785d-05/
      data fpp(11, 5,1),fpp(11, 5,2)/ 9.03544127d-02, 7.91618352d-05/
      data fpp(11, 6,1),fpp(11, 6,2)/ 1.02520199d-02,-2.85023624d-05/
      data fpp(11, 7,1),fpp(11, 7,2)/ 2.68777763d-03,-4.95158573d-06/
      data fpp(11, 8,1),fpp(11, 8,2)/-4.69524086d-04, 2.06070530d-06/
      data fpp(11, 9,1),fpp(11, 9,2)/-1.79003409d-04,-2.55235465d-07/
      data fpp(11,10,1),fpp(11,10,2)/ 9.88324344d-05, 2.96353745d-07/
      data fpp(11,11,1),fpp(11,11,2)/ 6.89187190d-05, 1.60204857d-08/
      data fpp(11,12,1),fpp(11,12,2)/ 1.82798317d-05,-1.60356876d-08/
      data fpp(11,13,1),fpp(11,13,2)/ 2.46793202d-06,-1.67773534d-09/
      data fpp(11,14,1),fpp(11,14,2)/ 1.08195513d-05, 7.14662895d-09/
      data fpp(11,15,1),fpp(11,15,2)/-8.10936645d-05,-7.10878047d-09/
      data fpp(11,16,1),fpp(11,16,2)/ 7.91930228d-06, 1.52884929d-08/
      data fpp(11,17,1),fpp(11,17,2)/ 1.27834942d-05,-4.24519118d-09/
      data fpp(11,18,1),fpp(11,18,2)/ 9.49506194d-06,-2.50772820d-09/
      data fpp(11,19,1),fpp(11,19,2)/ 8.15289091d-06,-7.23896036d-10/
      data fpp(11,20,1),fpp(11,20,2)/ 5.81292519d-06, 6.03312339d-10/
      data fpp(11,21,1),fpp(11,21,2)/-7.05620709d-06,-2.88935332d-09/
      data fpp(11,22,1),fpp(11,22,2)/ 3.83529192d-05, 3.15410095d-09/
      data fpp(11,23,1),fpp(11,23,2)/ 0.00000000d+00, 6.47294953d-09/
      data fpp(12, 1,1),fpp(12, 1,2)/ 0.00000000d+00,-3.22505688d-06/
      data fpp(12, 2,1),fpp(12, 2,2)/-1.14864368d-05,-5.47468623d-06/
      data fpp(12, 3,1),fpp(12, 3,2)/-4.81115642d-03, 4.14438018d-05/
      data fpp(12, 4,1),fpp(12, 4,2)/-2.24483949d-02,-8.37261210d-05/
      data fpp(12, 5,1),fpp(12, 5,2)/-2.62796137d-02, 6.67398823d-05/
      data fpp(12, 6,1),fpp(12, 6,2)/-5.51459010d-03,-2.25054082d-05/
      data fpp(12, 7,1),fpp(12, 7,2)/-4.64695640d-05, 3.60175032d-06/
      data fpp(12, 8,1),fpp(12, 8,2)/ 7.66259154d-05,-1.34319313d-06/
      data fpp(12, 9,1),fpp(12, 9,2)/ 1.34193059d-04, 5.11022200d-07/
      data fpp(12,10,1),fpp(12,10,2)/ 3.15679329d-05, 4.03299665d-08/
      data fpp(12,11,1),fpp(12,11,2)/-1.60346127d-05, 3.62579346d-08/
      data fpp(12,12,1),fpp(12,12,2)/-3.74012177d-05,-2.63617047d-08/
      data fpp(12,13,1),fpp(12,13,2)/-4.23881265d-07, 1.75888843d-08/
      data fpp(12,14,1),fpp(12,14,2)/-2.88257924d-05,-3.49938325d-08/
      data fpp(12,15,1),fpp(12,15,2)/ 7.59226467d-05, 4.31864459d-08/
      data fpp(12,16,1),fpp(12,16,2)/ 5.83128753d-06,-1.83519509d-08/
      data fpp(12,17,1),fpp(12,17,2)/ 7.19380273d-06, 9.82135773d-09/
      data fpp(12,18,1),fpp(12,18,2)/ 4.80112491d-06,-3.53348001d-09/
      data fpp(12,19,1),fpp(12,19,2)/-3.54546981d-06,-1.68743768d-09/
      data fpp(12,20,1),fpp(12,20,2)/-3.62225146d-06,-3.51676928d-09/
      data fpp(12,21,1),fpp(12,21,2)/ 8.54295295d-06, 1.95451481d-09/
      data fpp(12,22,1),fpp(12,22,2)/-1.24055263d-05, 1.09871006d-09/
      data fpp(12,23,1),fpp(12,23,2)/ 0.00000000d+00, 2.05064497d-09/
      data fpp(13, 1,1),fpp(13, 1,2)/ 0.00000000d+00,-4.47739528d-06/
      data fpp(13, 2,1),fpp(13, 2,2)/ 1.04482917d-05,-2.51640943d-06/
      data fpp(13, 3,1),fpp(13, 3,2)/ 2.59226498d-03, 1.42694330d-05/
      data fpp(13, 4,1),fpp(13, 4,2)/ 8.80555560d-03,-2.08317226d-05/
      data fpp(13, 5,1),fpp(13, 5,2)/ 4.06677065d-03, 1.05142574d-05/
      data fpp(13, 6,1),fpp(13, 6,2)/ 1.33028706d-03,-8.34907145d-07/
      data fpp(13, 7,1),fpp(13, 7,2)/ 1.13713460d-04,-6.75428861d-07/
      data fpp(13, 8,1),fpp(13, 8,2)/ 9.45963393d-05, 5.18225878d-08/
      data fpp(13, 9,1),fpp(13, 9,2)/ 5.60254081d-05, 1.82538510d-07/
      data fpp(13,10,1),fpp(13,10,2)/ 2.28852674d-05, 4.38731769d-08/
      data fpp(13,11,1),fpp(13,11,2)/-4.97103693d-07,-1.66312174d-08/
      data fpp(13,12,1),fpp(13,12,2)/ 4.08175045d-05, 2.80516926d-08/
      data fpp(13,13,1),fpp(13,13,2)/-1.89901713d-06,-2.95755530d-08/
      data fpp(13,14,1),fpp(13,14,2)/ 2.42062739d-05, 1.64505194d-08/
      data fpp(13,15,1),fpp(13,15,2)/-4.30130462d-05,-8.62652471d-09/
      data fpp(13,16,1),fpp(13,16,2)/-6.38382662d-06, 3.05557940d-09/
      data fpp(13,17,1),fpp(13,17,2)/-8.35005217d-07, 6.60420711d-09/
      data fpp(13,18,1),fpp(13,18,2)/-2.66712434d-06,-2.47240783d-09/
      data fpp(13,19,1),fpp(13,19,2)/ 1.04963875d-06,-9.14575804d-10/
      data fpp(13,20,1),fpp(13,20,2)/-4.67778595d-07,-1.66928896d-09/
      data fpp(13,21,1),fpp(13,21,2)/-1.14390384d-05,-3.20826836d-09/
      data fpp(13,22,1),fpp(13,22,2)/ 9.11647489d-06, 3.70236239d-09/
      data fpp(13,23,1),fpp(13,23,2)/ 0.00000000d+00, 8.19881881d-09/
      data fpp(14, 1,1),fpp(14, 1,2)/ 0.00000000d+00,-2.51811180d-07/
      data fpp(14, 2,1),fpp(14, 2,2)/-1.76400634d-05,-1.12777641d-07/
      data fpp(14, 3,1),fpp(14, 3,2)/-8.43903501d-04, 7.14921742d-07/
      data fpp(14, 4,1),fpp(14, 4,2)/-3.04494175d-04,-8.67709329d-07/
      data fpp(14, 5,1),fpp(14, 5,2)/-8.52802203d-04, 4.66315574d-07/
      data fpp(14, 6,1),fpp(14, 6,2)/-4.39224795d-04,-1.02352968d-07/
      data fpp(14, 7,1),fpp(14, 7,2)/ 4.42823914d-05,-3.08903704d-07/
      data fpp(14, 8,1),fpp(14, 8,2)/ 4.56553940d-05, 7.55677826d-08/
      data fpp(14, 9,1),fpp(14, 9,2)/ 2.17053084d-05, 8.82325733d-08/
      data fpp(14,10,1),fpp(14,10,2)/-9.77566903d-06, 7.71838874d-09/
      data fpp(14,11,1),fpp(14,11,2)/ 3.06896941d-05, 4.49387171d-09/
      data fpp(14,12,1),fpp(14,12,2)/-2.25354670d-05,-1.69387560d-09/
      data fpp(14,13,1),fpp(14,13,2)/-3.31338357d-06, 1.08163069d-09/
      data fpp(14,14,1),fpp(14,14,2)/-2.33326364d-05,-5.63264716d-09/
      data fpp(14,15,1),fpp(14,15,2)/ 2.54628712d-05, 1.64895796d-09/
      data fpp(14,16,1),fpp(14,16,2)/ 3.03735228d-06, 2.03681532d-09/
      data fpp(14,17,1),fpp(14,17,2)/ 1.47955147d-06, 2.20378074d-09/
      data fpp(14,18,1),fpp(14,18,2)/ 5.20070578d-06, 5.48061711d-10/
      data fpp(14,19,1),fpp(14,19,2)/-1.31975185d-06,-1.39602759d-09/
      data fpp(14,20,1),fpp(14,20,2)/-2.50663416d-06,-3.36395137d-09/
      data fpp(14,21,1),fpp(14,21,2)/ 1.85465341d-05, 4.05183306d-09/
      data fpp(14,22,1),fpp(14,22,2)/-1.13937066d-05,-2.04338087d-09/
      data fpp(14,23,1),fpp(14,23,2)/ 0.00000000d+00,-4.27830956d-09/
      data fpp(15, 1,1),fpp(15, 1,2)/ 0.00000000d+00, 2.49593305d-08/
      data fpp(15, 2,1),fpp(15, 2,2)/ 2.20278796d-05, 2.24813390d-08/
      data fpp(15, 3,1),fpp(15, 3,2)/ 1.98120031d-04, 3.63153135d-08/
      data fpp(15, 4,1),fpp(15, 4,2)/ 2.95637478d-04,-6.94259315d-09/
      data fpp(15, 5,1),fpp(15, 5,2)/ 2.98355043d-04, 6.58550591d-08/
      data fpp(15, 6,1),fpp(15, 6,2)/ 1.50693390d-04,-9.80776431d-08/
      data fpp(15, 7,1),fpp(15, 7,2)/ 5.00178533d-05,-1.43944487d-07/
      data fpp(15, 8,1),fpp(15, 8,2)/ 3.38285208d-05, 4.50555904d-08/
      data fpp(15, 9,1),fpp(15, 9,2)/ 1.89353460d-05, 4.29221254d-08/
      data fpp(15,10,1),fpp(15,10,2)/ 3.55044413d-06, 1.91058286d-08/
      data fpp(15,11,1),fpp(15,11,2)/-8.02028151d-05,-1.85454399d-08/
      data fpp(15,12,1),fpp(15,12,2)/ 3.95107839d-06, 1.00759308d-08/
      data fpp(15,13,1),fpp(15,13,2)/ 1.19154435d-05,-3.75828351d-09/
      data fpp(15,14,1),fpp(15,14,2)/ 1.13537714d-05, 8.55720321d-09/
      data fpp(15,15,1),fpp(15,15,2)/-2.57947870d-05,-1.48705293d-08/
      data fpp(15,16,1),fpp(15,16,2)/-2.11102149d-06, 1.01249141d-08/
      data fpp(15,17,1),fpp(15,17,2)/-6.14524954d-06,-4.29127126d-10/
      data fpp(15,18,1),fpp(15,18,2)/-8.50284239d-06,-6.08405611d-10/
      data fpp(15,19,1),fpp(15,19,2)/ 5.24301130d-07,-1.93725043d-09/
      data fpp(15,20,1),fpp(15,20,2)/ 3.73483869d-06, 4.75740733d-09/
      data fpp(15,21,1),fpp(15,21,2)/-3.90741131d-05,-7.49237890d-09/
      data fpp(15,22,1),fpp(15,22,2)/ 8.79382058d-06, 3.61210826d-09/
      data fpp(15,23,1),fpp(15,23,2)/ 0.00000000d+00, 8.04394587d-09/
      data fpp(16, 1,1),fpp(16, 1,2)/ 0.00000000d+00,-3.31394757d-08/
      data fpp(16, 2,1),fpp(16, 2,2)/-8.97145497d-06,-8.92104854d-09/
      data fpp(16, 3,1),fpp(16, 3,2)/-2.80766240d-05, 3.52236699d-08/
      data fpp(16, 4,1),fpp(16, 4,2)/-3.65557385d-05, 9.62636896d-09/
      data fpp(16, 5,1),fpp(16, 5,2)/-3.76179679d-05, 2.94708543d-08/
      data fpp(16, 6,1),fpp(16, 6,2)/ 1.45123628d-06,-6.51097861d-08/
      data fpp(16, 7,1),fpp(16, 7,2)/ 3.01461953d-05,-6.18317100d-08/
      data fpp(16, 8,1),fpp(16, 8,2)/ 1.70305227d-05, 1.96366261d-08/
      data fpp(16, 9,1),fpp(16, 9,2)/ 5.33077653d-08, 2.16852055d-08/
      data fpp(16,10,1),fpp(16,10,2)/-5.92610747d-06,-3.47392961d-09/
      data fpp(16,11,1),fpp(16,11,2)/ 6.66215663d-05, 2.10105129d-08/
      data fpp(16,12,1),fpp(16,12,2)/ 9.73115349d-06,-1.51681221d-08/
      data fpp(16,13,1),fpp(16,13,2)/-6.84839052d-06, 6.19754105d-11/
      data fpp(16,14,1),fpp(16,14,2)/ 6.41755078d-06, 7.72022044d-09/
      data fpp(16,15,1),fpp(16,15,2)/ 1.92162767d-05,-1.11428572d-08/
      data fpp(16,16,1),fpp(16,16,2)/-5.09326632d-06, 6.25120826d-09/
      data fpp(16,17,1),fpp(16,17,2)/ 6.01446683d-07, 5.38024125d-10/
      data fpp(16,18,1),fpp(16,18,2)/ 3.31066378d-06,-6.03304762d-10/
      data fpp(16,19,1),fpp(16,19,2)/ 7.22547329d-07, 1.27519492d-09/
      data fpp(16,20,1),fpp(16,20,2)/ 1.06727941d-06,-9.29747493d-09/
      data fpp(16,21,1),fpp(16,21,2)/ 3.42499182d-05, 1.43147048d-08/
      data fpp(16,22,1),fpp(16,22,2)/-2.78157574d-06,-5.36134423d-09/
      data fpp(16,23,1),fpp(16,23,2)/ 0.00000000d+00,-1.26693279d-08/
      data fpp(17, 1,1),fpp(17, 1,2)/ 0.00000000d+00,-1.70042469d-08/
      data fpp(17, 2,1),fpp(17, 2,2)/-7.80403165d-07,-6.79150616d-09/
      data fpp(17, 3,1),fpp(17, 3,2)/ 6.50872603d-06, 1.05702716d-08/
      data fpp(17, 4,1),fpp(17, 4,2)/ 1.00941427d-05, 2.91041995d-09/
      data fpp(17, 5,1),fpp(17, 5,2)/ 1.94898646d-05, 6.58804864d-09/
      data fpp(17, 6,1),fpp(17, 6,2)/ 2.13669526d-05,-1.72626145d-08/
      data fpp(17, 7,1),fpp(17, 7,2)/ 1.25007801d-05,-1.43375906d-08/
      data fpp(17, 8,1),fpp(17, 8,2)/ 5.34591059d-06,-6.98702308d-09/
      data fpp(17, 9,1),fpp(17, 9,2)/ 7.86541014d-06, 1.10856829d-08/
      data fpp(17,10,1),fpp(17,10,2)/ 3.43867288d-05, 5.03646276d-09/
      data fpp(17,11,1),fpp(17,11,2)/-2.72700110d-05, 4.76846604d-09/
      data fpp(17,12,1),fpp(17,12,2)/-1.60712306d-05,-1.51103269d-08/
      data fpp(17,13,1),fpp(17,13,2)/ 2.21767272d-06, 1.12728417d-08/
      data fpp(17,14,1),fpp(17,14,2)/-1.06276835d-05, 3.01896019d-09/
      data fpp(17,15,1),fpp(17,15,2)/-2.11910644d-05,-1.85486825d-08/
      data fpp(17,16,1),fpp(17,16,2)/ 7.05156874d-06, 1.59757696d-08/
      data fpp(17,17,1),fpp(17,17,2)/ 1.75867741d-06,-3.95439602d-09/
      data fpp(17,18,1),fpp(17,18,2)/-1.36698433d-06, 1.64181448d-09/
      data fpp(17,19,1),fpp(17,19,2)/-1.42469185d-06,-3.21286189d-09/
      data fpp(17,20,1),fpp(17,20,2)/-9.38082382d-06, 2.80963308d-09/
      data fpp(17,21,1),fpp(17,21,2)/-1.27836518d-05,-1.42567045d-09/
      data fpp(17,22,1),fpp(17,22,2)/ 4.09372073d-07, 4.93048699d-10/
      data fpp(17,23,1),fpp(17,23,2)/ 0.00000000d+00, 6.53475651d-10/
      data fpp(18, 1,1),fpp(18, 1,2)/ 0.00000000d+00, 1.28335983d-08/
      data fpp(18, 2,1),fpp(18, 2,2)/ 7.59734298d-07, 5.53280333d-09/
      data fpp(18, 3,1),fpp(18, 3,2)/-3.29161340d-06,-6.16481164d-09/
      data fpp(18, 4,1),fpp(18, 4,2)/ 8.84583422d-06,-2.47355677d-09/
      data fpp(18, 5,1),fpp(18, 5,2)/ 9.91843061d-07, 8.85903872d-09/
      data fpp(18, 6,1),fpp(18, 6,2)/ 4.14286483d-07,-8.96259810d-09/
      data fpp(18, 7,1),fpp(18, 7,2)/ 6.51735101d-06,-1.80864633d-09/
      data fpp(18, 8,1),fpp(18, 8,2)/ 4.25250163d-06,-1.02028166d-08/
      data fpp(18, 9,1),fpp(18, 9,2)/-6.18161500d-06, 3.78199127d-08/
      data fpp(18,10,1),fpp(18,10,2)/-6.22874745d-05,-3.93583297d-08/
      data fpp(18,11,1),fpp(18,11,2)/ 1.79181106d-06, 2.42134061d-08/
      data fpp(18,12,1),fpp(18,12,2)/ 1.12204354d-05,-8.29529456d-09/
      data fpp(18,13,1),fpp(18,13,2)/ 1.31103297d-06, 4.16777219d-09/
      data fpp(18,14,1),fpp(18,14,2)/ 1.07598500d-05,-2.97579418d-09/
      data fpp(18,15,1),fpp(18,15,2)/ 1.48813141d-05, 5.35404538d-10/
      data fpp(18,16,1),fpp(18,16,2)/-9.77967531d-06, 1.43417603d-09/
      data fpp(18,17,1),fpp(18,17,2)/-1.63615634d-06,-2.07210865d-09/
      data fpp(18,18,1),fpp(18,18,2)/ 8.23940214d-07, 2.65425857d-09/
      data fpp(18,19,1),fpp(18,19,2)/ 3.09553405d-07,-5.54492564d-09/
      data fpp(18,20,1),fpp(18,20,2)/ 3.04560159d-05, 9.32544399d-09/
      data fpp(18,21,1),fpp(18,21,2)/-2.44864419d-06,-7.75685030d-09/
      data fpp(18,22,1),fpp(18,22,2)/-1.89245886d-07, 2.50195723d-09/
      data fpp(18,23,1),fpp(18,23,2)/ 0.00000000d+00, 4.94902139d-09/
      data fpp(19, 1,1),fpp(19, 1,2)/ 0.00000000d+00, 1.25407564d-08/
      data fpp(19, 2,1),fpp(19, 2,2)/ 8.71933257d-07, 5.31848713d-09/
      data fpp(19, 3,1),fpp(19, 3,2)/-3.05022061d-07, 1.41852950d-08/
      data fpp(19, 4,1),fpp(19, 4,2)/-2.03703852d-05,-3.32596673d-08/
      data fpp(19, 5,1),fpp(19, 5,2)/ 5.80598787d-06, 1.56533740d-08/
      data fpp(19, 6,1),fpp(19, 6,2)/ 6.37813862d-06, 1.84617122d-09/
      data fpp(19, 7,1),fpp(19, 7,2)/-1.83792519d-06,-6.23805888d-09/
      data fpp(19, 8,1),fpp(19, 8,2)/ 7.71862594d-06,-8.93935685d-10/
      data fpp(19, 9,1),fpp(19, 9,2)/ 3.41099598d-05, 7.41380162d-09/
      data fpp(19,10,1),fpp(19,10,2)/ 4.33572791d-05,-4.99443703d-09/
      data fpp(19,11,1),fpp(19,11,2)/ 2.19459612d-05, 4.76394649d-09/
      data fpp(19,12,1),fpp(19,12,2)/ 1.50466887d-06,-3.26134892d-09/
      data fpp(19,13,1),fpp(19,13,2)/-3.38167395d-06, 1.68144920d-09/
      data fpp(19,14,1),fpp(19,14,2)/-2.28577249d-05,-2.26444788d-09/
      data fpp(19,15,1),fpp(19,15,2)/-6.19974011d-07,-4.23657680d-10/
      data fpp(19,16,1),fpp(19,16,2)/ 1.28210234d-05, 3.95907860d-09/
      data fpp(19,17,1),fpp(19,17,2)/-4.45723441d-06,-2.81265672d-09/
      data fpp(19,18,1),fpp(19,18,2)/ 1.43077543d-06,-1.70845171d-09/
      data fpp(19,19,1),fpp(19,19,2)/ 5.58927075d-06, 1.02464636d-08/
      data fpp(19,20,1),fpp(19,20,2)/-4.62088436d-05,-1.64774026d-08/
      data fpp(19,21,1),fpp(19,21,2)/ 8.91869870d-06, 1.06631469d-08/
      data fpp(19,22,1),fpp(19,22,2)/ 8.32171320d-07,-1.57518482d-09/
      data fpp(19,23,1),fpp(19,23,2)/ 0.00000000d+00,-2.56240759d-09/
      data fpp(20, 1,1),fpp(20, 1,2)/ 0.00000000d+00, 1.73743998d-08/
      data fpp(20, 2,1),fpp(20, 2,2)/ 2.52532674d-07, 1.04512005d-08/
      data fpp(20, 3,1),fpp(20, 3,2)/ 3.01170164d-06,-8.77920158d-09/
      data fpp(20, 4,1),fpp(20, 4,2)/ 9.63570657d-06, 1.50656059d-08/
      data fpp(20, 5,1),fpp(20, 5,2)/-7.71579453d-06,-2.50832220d-08/
      data fpp(20, 6,1),fpp(20, 6,2)/-1.92684097d-06, 8.46728196d-09/
      data fpp(20, 7,1),fpp(20, 7,2)/ 2.33434975d-06, 5.61409411d-09/
      data fpp(20, 8,1),fpp(20, 8,2)/-8.12700539d-06, 2.42763416d-08/
      data fpp(20, 9,1),fpp(20, 9,2)/-3.87582241d-05,-4.03194604d-08/
      data fpp(20,10,1),fpp(20,10,2)/-3.14164194d-06, 2.84202105d-08/
      data fpp(20,11,1),fpp(20,11,2)/-2.35756560d-05,-1.69613816d-08/
      data fpp(20,12,1),fpp(20,12,2)/-5.23911087d-06, 7.02531578d-09/
      data fpp(20,13,1),fpp(20,13,2)/ 1.71566284d-06,-6.93988157d-09/
      data fpp(20,14,1),fpp(20,14,2)/ 3.11710496d-05, 1.11342105d-08/
      data fpp(20,15,1),fpp(20,15,2)/-1.90141807d-06,-6.39696037d-09/
      data fpp(20,16,1),fpp(20,16,2)/-8.50441842d-06,-1.14636902d-09/
      data fpp(20,17,1),fpp(20,17,2)/ 4.46509399d-06, 3.78243644d-09/
      data fpp(20,18,1),fpp(20,18,2)/-3.54704193d-06,-1.38337675d-09/
      data fpp(20,19,1),fpp(20,19,2)/-7.66663641d-06,-2.44892943d-09/
      data fpp(20,20,1),fpp(20,20,2)/ 2.23793586d-05, 3.37909449d-09/
      data fpp(20,21,1),fpp(20,21,2)/-4.72615061d-06,-2.06744852d-09/
      data fpp(20,22,1),fpp(20,22,2)/ 4.36056061d-06, 6.90699576d-10/
      data fpp(20,23,1),fpp(20,23,2)/ 0.00000000d+00, 1.10465021d-09/
      data fpp(21, 1,1),fpp(21, 1,2)/ 0.00000000d+00, 2.42308824d-08/
      data fpp(21, 2,1),fpp(21, 2,2)/ 1.24360225d-06, 1.23382353d-08/
      data fpp(21, 3,1),fpp(21, 3,2)/-2.16899076d-06,-1.11838235d-08/
      data fpp(21, 4,1),fpp(21, 4,2)/ 5.46123491d-06, 5.99705888d-09/
      data fpp(21, 5,1),fpp(21, 5,2)/ 2.84865651d-06,-5.60441199d-09/
      data fpp(21, 6,1),fpp(21, 6,2)/ 5.04044162d-07,-5.17941092d-09/
      data fpp(21, 7,1),fpp(21, 7,2)/ 2.11078428d-06, 1.19220557d-08/
      data fpp(21, 8,1),fpp(21, 8,2)/ 3.27760069d-06,-4.10881176d-09/
      data fpp(21, 9,1),fpp(21, 9,2)/ 1.41207739d-05,-2.68680863d-09/
      data fpp(21,10,1),fpp(21,10,2)/-1.34327129d-05, 4.11483176d-09/
      data fpp(21,11,1),fpp(21,11,2)/ 9.28821238d-06,-2.37251840d-09/
      data fpp(21,12,1),fpp(21,12,2)/ 2.12725700d-06,-1.82475814d-09/
      data fpp(21,13,1),fpp(21,13,2)/-7.97760160d-07, 9.07155098d-09/
      data fpp(21,14,1),fpp(21,14,2)/-1.83316821d-05,-1.46614458d-08/
      data fpp(21,15,1),fpp(21,15,2)/ 4.18042908d-07, 9.37423212d-09/
      data fpp(21,16,1),fpp(21,16,2)/ 2.13404578d-06,-3.03548272d-09/
      data fpp(21,17,1),fpp(21,17,2)/-1.24549034d-06, 1.56769876d-09/
      data fpp(21,18,1),fpp(21,18,2)/ 1.86962280d-06,-1.43531233d-09/
      data fpp(21,19,1),fpp(21,19,2)/ 3.82927420d-06, 2.37355054d-09/
      data fpp(21,20,1),fpp(21,20,2)/-5.12529966d-06,-2.65888984d-09/
      data fpp(21,21,1),fpp(21,21,2)/ 1.14136957d-06, 4.66200880d-09/
      data fpp(21,22,1),fpp(21,22,2)/-5.75664957d-06,-4.58914537d-09/
      data fpp(21,23,1),fpp(21,23,2)/ 0.00000000d+00,-9.10542731d-09/
      data fpp(22, 1,1),fpp(22, 1,2)/ 0.00000000d+00,-2.33744776d-08/
      data fpp(22, 2,1),fpp(22, 2,2)/-9.31046801d-07,-1.32510448d-08/
      data fpp(22, 3,1),fpp(22, 3,2)/ 2.81374944d-06, 7.15786568d-08/
      data fpp(22, 4,1),fpp(22, 4,2)/-8.85737566d-06,-1.05063582d-07/
      data fpp(22, 5,1),fpp(22, 5,2)/ 7.37758776d-08, 5.82756731d-08/
      data fpp(22, 6,1),fpp(22, 6,2)/-5.68367337d-08,-8.39109804d-10/
      data fpp(22, 7,1),fpp(22, 7,2)/-2.07511955d-06,-1.89192339d-08/
      data fpp(22, 8,1),fpp(22, 8,2)/-4.12118966d-07, 2.13160452d-08/
      data fpp(22, 9,1),fpp(22, 9,2)/-2.89154193d-06,-4.23449470d-08/
      data fpp(22,10,1),fpp(22,10,2)/ 1.96696665d-05, 5.45768184d-08/
      data fpp(22,11,1),fpp(22,11,2)/-3.65688605d-06,-3.61623266d-08/
      data fpp(22,12,1),fpp(22,12,2)/-4.63755883d-07, 1.02724879d-08/
      data fpp(22,13,1),fpp(22,13,2)/ 4.03434808d-07,-2.52762491d-09/
      data fpp(22,14,1),fpp(22,14,2)/ 7.47875297d-06, 1.03801175d-09/
      data fpp(22,15,1),fpp(22,15,2)/ 1.23113536d-07,-4.24422111d-10/
      data fpp(22,16,1),fpp(22,16,2)/-3.66295446d-07, 5.96766905d-11/
      data fpp(22,17,1),fpp(22,17,2)/ 1.86512711d-07, 1.85715349d-10/
      data fpp(22,18,1),fpp(22,18,2)/-7.34567805d-07,-2.02538088d-10/
      data fpp(22,19,1),fpp(22,19,2)/-1.41369559d-06, 2.44370014d-11/
      data fpp(22,20,1),fpp(22,20,2)/ 1.37334374d-06, 1.04790082d-10/
      data fpp(22,21,1),fpp(22,21,2)/-4.16692271d-07,-4.43597330d-10/
      data fpp(22,22,1),fpp(22,22,2)/ 2.76494226d-06, 4.69599237d-10/
      data fpp(22,23,1),fpp(22,23,2)/ 0.00000000d+00, 9.65200381d-10/
      data fpp(23, 1,1),fpp(23, 1,2)/ 0.00000000d+00, 1.65583439d-08/
      data fpp(23, 2,1),fpp(23, 2,2)/ 3.20584956d-07, 7.68331226d-09/
      data fpp(23, 3,1),fpp(23, 3,2)/-2.84600702d-06,-1.36915929d-08/
      data fpp(23, 4,1),fpp(23, 4,2)/ 4.52826772d-06, 8.68305938d-09/
      data fpp(23, 5,1),fpp(23, 5,2)/-5.03760023d-07,-1.14406446d-08/
      data fpp(23, 6,1),fpp(23, 6,2)/ 6.83302773d-07, 1.54795190d-08/
      data fpp(23, 7,1),fpp(23, 7,2)/ 9.09693918d-07,-9.67743152d-09/
      data fpp(23, 8,1),fpp(23, 8,2)/-1.89124825d-07, 4.03020704d-09/
      data fpp(23, 9,1),fpp(23, 9,2)/ 5.65393833d-07,-1.64339665d-09/
      data fpp(23,10,1),fpp(23,10,2)/-1.24459532d-05, 1.11508644d-09/
      data fpp(23,11,1),fpp(23,11,2)/ 1.49933180d-06,-4.16949099d-10/
      data fpp(23,12,1),fpp(23,12,2)/-2.72233471d-07,-6.47290041d-10/
      data fpp(23,13,1),fpp(23,13,2)/-9.59790737d-08, 6.06109263d-10/
      data fpp(23,14,1),fpp(23,14,2)/-2.46332976d-06, 2.28529872d-11/
      data fpp(23,15,1),fpp(23,15,2)/-1.90497052d-07,-9.75212124d-11/
      data fpp(23,16,1),fpp(23,16,2)/-1.88863998d-07,-2.32768138d-10/
      data fpp(23,17,1),fpp(23,17,2)/ 1.94395011d-08, 4.28593763d-10/
      data fpp(23,18,1),fpp(23,18,2)/ 3.48648418d-07,-2.81606915d-10/
      data fpp(23,19,1),fpp(23,19,2)/ 3.85508161d-07, 9.78338971d-11/
      data fpp(23,20,1),fpp(23,20,2)/-3.68075287d-07,-1.09728673d-10/
      data fpp(23,21,1),fpp(23,21,2)/ 2.85399511d-07,-2.58919203d-10/
      data fpp(23,22,1),fpp(23,22,2)/-5.03119479d-07, 5.45405487d-10/
      data fpp(23,23,1),fpp(23,23,2)/ 0.00000000d+00, 1.07729726d-09/
      data fpp(24, 1,1),fpp(24, 1,2)/ 0.00000000d+00,-1.01047028d-10/
      data fpp(24, 2,1),fpp(24, 2,2)/-1.11293023d-07, 6.02094057d-10/
      data fpp(24, 3,1),fpp(24, 3,2)/ 1.61027863d-06,-4.70732920d-09/
      data fpp(24, 4,1),fpp(24, 4,2)/ 3.44304760d-07, 1.10272227d-08/
      data fpp(24, 5,1),fpp(24, 5,2)/ 2.61264213d-07,-8.20156175d-09/
      data fpp(24, 6,1),fpp(24, 6,2)/-5.16374358d-07, 2.57902427d-09/
      data fpp(24, 7,1),fpp(24, 7,2)/-1.23656122d-07,-2.11453532d-09/
      data fpp(24, 8,1),fpp(24, 8,2)/-3.13817351d-08, 3.47911702d-09/
      data fpp(24, 9,1),fpp(24, 9,2)/-8.10033406d-07,-2.20193276d-09/
      data fpp(24,10,1),fpp(24,10,2)/ 3.23414614d-06, 6.66239761d-10/
      data fpp(24,11,1),fpp(24,11,2)/-6.60441165d-07,-4.63026287d-10/
      data fpp(24,12,1),fpp(24,12,2)/ 5.92689766d-07, 5.85865388d-10/
      data fpp(24,13,1),fpp(24,13,2)/-1.95185135d-08,-8.04352647d-11/
      data fpp(24,14,1),fpp(24,14,2)/ 2.37456608d-06,-2.64124329d-10/
      data fpp(24,15,1),fpp(24,15,2)/ 1.58874673d-07,-6.30674180d-11/
      data fpp(24,16,1),fpp(24,16,2)/ 4.01751439d-07, 5.16394001d-10/
      data fpp(24,17,1),fpp(24,17,2)/-2.42707152d-08,-2.02508587d-10/
      data fpp(24,18,1),fpp(24,18,2)/-4.20025868d-07,-3.06359653d-10/
      data fpp(24,19,1),fpp(24,19,2)/-1.28337054d-07, 2.27947200d-10/
      data fpp(24,20,1),fpp(24,20,2)/ 9.89574107d-08,-5.42914636d-12/
      data fpp(24,21,1),fpp(24,21,2)/-2.44905773d-07,-2.06230614d-10/
      data fpp(24,22,1),fpp(24,22,2)/-3.24643460d-08, 2.30351604d-10/
      data fpp(24,23,1),fpp(24,23,2)/ 0.00000000d+00, 4.84824198d-10/
      data fpp(25, 1,1),fpp(25, 1,2)/ 0.00000000d+00,-2.06883604d-09/
      data fpp(25, 2,1),fpp(25, 2,2)/-1.15412863d-07,-1.06232792d-09/
      data fpp(25, 3,1),fpp(25, 3,2)/-4.75107503d-07, 3.91814772d-09/
      data fpp(25, 4,1),fpp(25, 4,2)/-8.65486765d-07,-5.01026298d-09/
      data fpp(25, 5,1),fpp(25, 5,2)/-6.12968282d-08, 4.12290419d-09/
      data fpp(25, 6,1),fpp(25, 6,2)/-5.78053406d-08,-1.88135378d-09/
      data fpp(25, 7,1),fpp(25, 7,2)/-1.75069430d-07,-1.39748908d-09/
      data fpp(25, 8,1),fpp(25, 8,2)/ 7.46517651d-08, 2.71310097d-10/
      data fpp(25, 9,1),fpp(25, 9,2)/ 7.54739789d-07, 2.71224869d-09/
      data fpp(25,10,1),fpp(25,10,2)/-9.70631403d-07,-2.87240112d-09/
      data fpp(25,11,1),fpp(25,11,2)/ 6.62432857d-07, 2.77735581d-09/
      data fpp(25,12,1),fpp(25,12,2)/-4.18525594d-07,-2.83702210d-09/
      data fpp(25,13,1),fpp(25,13,2)/ 1.74053128d-07, 4.97073260d-09/
      data fpp(25,14,1),fpp(25,14,2)/-3.91493456d-06,-6.84590830d-09/
      data fpp(25,15,1),fpp(25,15,2)/-2.05001638d-07, 4.41290058d-09/
      data fpp(25,16,1),fpp(25,16,2)/-4.58141756d-07,-1.20569404d-09/
      data fpp(25,17,1),fpp(25,17,2)/-1.62356640d-07,-1.90124425d-10/
      data fpp(25,18,1),fpp(25,18,2)/ 3.71455055d-07, 7.66191741d-10/
      data fpp(25,19,1),fpp(25,19,2)/ 1.27840056d-07,-4.74642538d-10/
      data fpp(25,20,1),fpp(25,20,2)/-2.77543559d-08,-6.76215877d-11/
      data fpp(25,21,1),fpp(25,21,2)/ 2.14223582d-07, 1.45128889d-10/
      data fpp(25,22,1),fpp(25,22,2)/ 1.52976863d-07, 8.71060317d-11/
      data fpp(25,23,1),fpp(25,23,2)/ 0.00000000d+00, 1.06446984d-10/
      data fpp(26, 1,1),fpp(26, 1,2)/ 0.00000000d+00, 1.93765677d-09/
      data fpp(26, 2,1),fpp(26, 2,2)/ 9.29444747d-08, 9.24686461d-10/
      data fpp(26, 3,1),fpp(26, 3,2)/ 5.01513822d-08,-8.36402614d-10/
      data fpp(26, 4,1),fpp(26, 4,2)/ 2.37642299d-07, 2.09239962d-11/
      data fpp(26, 5,1),fpp(26, 5,2)/-1.60769001d-08, 7.52706630d-10/
      data fpp(26, 6,1),fpp(26, 6,2)/ 2.75957206d-08,-6.31750515d-10/
      data fpp(26, 7,1),fpp(26, 7,2)/ 1.03933842d-07,-6.25704570d-10/
      data fpp(26, 8,1),fpp(26, 8,2)/-2.72253251d-08, 7.34568794d-10/
      data fpp(26, 9,1),fpp(26, 9,2)/-2.88925751d-07, 8.74293922d-11/
      data fpp(26,10,1),fpp(26,10,2)/ 1.68379469d-07,-2.95725737d-11/
      data fpp(26,11,1),fpp(26,11,2)/-3.09290263d-07,-5.69139097d-10/
      data fpp(26,12,1),fpp(26,12,2)/ 1.21412609d-07, 1.70612896d-09/
      data fpp(26,13,1),fpp(26,13,2)/-1.96693997d-07,-5.05537675d-09/
      data fpp(26,14,1),fpp(26,14,2)/ 2.48517216d-06, 7.11537805d-09/
      data fpp(26,15,1),fpp(26,15,2)/ 1.81131881d-07,-4.20613546d-09/
      data fpp(26,16,1),fpp(26,16,2)/ 2.30815587d-07, 1.30916379d-09/
      data fpp(26,17,1),fpp(26,17,2)/ 1.93697276d-07,-4.30519690d-10/
      data fpp(26,18,1),fpp(26,18,2)/-1.05794352d-07, 4.12914972d-10/
      data fpp(26,19,1),fpp(26,19,2)/-1.43023168d-07,-6.21140200d-10/
      data fpp(26,20,1),fpp(26,20,2)/ 1.20600129d-08, 2.71645827d-10/
      data fpp(26,21,1),fpp(26,21,2)/-1.31988555d-07, 1.34556893d-10/
      data fpp(26,22,1),fpp(26,22,2)/-9.94431064d-08,-2.09873398d-10/
      data fpp(26,23,1),fpp(26,23,2)/ 0.00000000d+00,-4.95063301d-10/
      data fpp(27, 1,1),fpp(27, 1,2)/ 0.00000000d+00, 3.76720974d-11/
      data fpp(27, 2,1),fpp(27, 2,2)/-4.11269928d-08,-7.53441947d-11/
      data fpp(27, 3,1),fpp(27, 3,2)/-3.29003949d-08, 2.63704682d-10/
      data fpp(27, 4,1),fpp(27, 4,2)/-4.01835139d-08,-9.79474531d-10/
      data fpp(27, 5,1),fpp(27, 5,2)/ 1.88791143d-08, 1.25419344d-09/
      data fpp(27, 6,1),fpp(27, 6,2)/ 6.11550839d-09, 7.62700756d-10/
      data fpp(27, 7,1),fpp(27, 7,2)/-4.42668121d-08,-1.90499647d-09/
      data fpp(27, 8,1),fpp(27, 8,2)/-1.56499071d-08,-3.42714890d-10/
      data fpp(27, 9,1),fpp(27, 9,2)/ 6.94073573d-08, 8.75856028d-10/
      data fpp(27,10,1),fpp(27,10,2)/-1.98227054d-08,-5.62106388d-11/
      data fpp(27,11,1),fpp(27,11,2)/ 5.66543609d-08,-5.10134728d-11/
      data fpp(27,12,1),fpp(27,12,2)/-3.49750313d-08,-3.39735470d-10/
      data fpp(27,13,1),fpp(27,13,2)/ 2.03055428d-07, 1.40995535d-09/
      data fpp(27,14,1),fpp(27,14,2)/-4.58049187d-07,-2.30008594d-09/
      data fpp(27,15,1),fpp(27,15,2)/-8.08948231d-08, 1.19038842d-09/
      data fpp(27,16,1),fpp(27,16,2)/-4.33758819d-08, 5.38532263d-10/
      data fpp(27,17,1),fpp(27,17,2)/-7.99135074d-08,-9.44517471d-10/
      data fpp(27,18,1),fpp(27,18,2)/ 1.16555292d-08, 2.39537620d-10/
      data fpp(27,19,1),fpp(27,19,2)/ 6.51494766d-08, 5.86366991d-10/
      data fpp(27,20,1),fpp(27,20,2)/-2.23028608d-08,-7.85005585d-10/
      data fpp(27,21,1),fpp(27,21,2)/ 1.08853873d-07, 7.53655350d-10/
      data fpp(27,22,1),fpp(27,22,2)/-1.81591125d-08,-4.29615814d-10/
      data fpp(27,23,1),fpp(27,23,2)/ 0.00000000d+00,-8.35192093d-10/
      data fpp(28, 1,1),fpp(28, 1,2)/ 0.00000000d+00, 2.07496857d-09/
      data fpp(28, 2,1),fpp(28, 2,2)/-1.08436504d-07, 1.05006287d-09/
      data fpp(28, 3,1),fpp(28, 3,2)/ 2.14501975d-08, 9.24779964d-10/
      data fpp(28, 4,1),fpp(28, 4,2)/-1.69082430d-08,-2.34918272d-09/
      data fpp(28, 5,1),fpp(28, 5,2)/ 6.05604428d-08, 1.27195093d-09/
      data fpp(28, 6,1),fpp(28, 6,2)/ 7.94224581d-09,-3.38620997d-10/
      data fpp(28, 7,1),fpp(28, 7,2)/-1.06866594d-07, 8.25330564d-11/
      data fpp(28, 8,1),fpp(28, 8,2)/-3.01750464d-08, 8.48877095d-12/
      data fpp(28, 9,1),fpp(28, 9,2)/ 1.31296321d-07,-1.16488140d-10/
      data fpp(28,10,1),fpp(28,10,2)/ 9.09113527d-08, 3.45220035d-10/
      data fpp(28,11,1),fpp(28,11,2)/ 1.42672820d-07,-1.26439200d-09/
      data fpp(28,12,1),fpp(28,12,2)/-4.15124844d-08, 4.11234797d-09/
      data fpp(28,13,1),fpp(28,13,2)/ 4.64472286d-07,-3.78499987d-09/
      data fpp(28,14,1),fpp(28,14,2)/-1.49297541d-06,-2.17234849d-09/
      data fpp(28,15,1),fpp(28,15,2)/-2.17552588d-07, 4.07439384d-09/
      data fpp(28,16,1),fpp(28,16,2)/-1.17312059d-07,-1.52522685d-09/
      data fpp(28,17,1),fpp(28,17,2)/-2.34043246d-07, 2.26513582d-10/
      data fpp(28,18,1),fpp(28,18,2)/-8.27764609d-10, 6.19172526d-10/
      data fpp(28,19,1),fpp(28,19,2)/ 1.82425262d-07,-1.50320369d-09/
      data fpp(28,20,1),fpp(28,20,2)/-4.28485696d-08, 2.99364223d-09/
      data fpp(28,21,1),fpp(28,21,2)/ 2.36573064d-07,-3.87136521d-09/
      data fpp(28,22,1),fpp(28,22,2)/-7.92044377d-09, 1.69181863d-09/
      data fpp(28,23,1),fpp(28,23,2)/ 0.00000000d+00, 3.70409068d-09/
 
      data fpppp( 1, 1),fpppp( 1, 2)/ 8.18824250d-03, 7.14302846d-03/
      data fpppp( 1, 3),fpppp( 1, 4)/-3.65753691d-02, 6.90623756d-02/
      data fpppp( 1, 5),fpppp( 1, 6)/-6.55001174d-02, 5.41404263d-02/
      data fpppp( 1, 7),fpppp( 1, 8)/-5.70573063d-02, 4.34614207d-02/
      data fpppp( 1, 9),fpppp( 1,10)/-1.64220548d-02, 6.77683395d-03/
      data fpppp( 1,11),fpppp( 1,12)/-2.39769308d-03, 5.71513063d-04/
      data fpppp( 1,13),fpppp( 1,14)/-7.19737695d-05, 2.54431390d-05/
      data fpppp( 1,15),fpppp( 1,16)/-1.82429271d-05, 6.51384706d-05/
      data fpppp( 1,17),fpppp( 1,18)/-1.15904411d-04, 5.90146910d-05/
      data fpppp( 1,19),fpppp( 1,20)/-1.24113062d-05, 1.47285910d-05/
      data fpppp( 1,21),fpppp( 1,22)/-8.93189900d-06, 3.92938316d-06/
      data fpppp( 1,23) /             6.35587326d-06 /
      data fpppp( 2, 1),fpppp( 2, 2)/ 3.99901884d-03, 3.51049539d-03/
      data fpppp( 2, 3),fpppp( 2, 4)/-1.74320149d-02, 3.32144288d-02/
      data fpppp( 2, 5),fpppp( 2, 6)/-3.11194921d-02, 2.35065553d-02/
      data fpppp( 2, 7),fpppp( 2, 8)/-2.56412118d-02, 2.17953683d-02/
      data fpppp( 2, 9),fpppp( 2,10)/-8.50602456d-03, 3.42732972d-03/
      data fpppp( 2,11),fpppp( 2,12)/-1.32711018d-03, 3.53541621d-04/
      data fpppp( 2,13),fpppp( 2,14)/-3.89671095d-05, 1.65245682d-05/
      data fpppp( 2,15),fpppp( 2,16)/-1.53828820d-05, 4.99871572d-05/
      data fpppp( 2,17),fpppp( 2,18)/-7.85188346d-05, 2.78971478d-05/
      data fpppp( 2,19),fpppp( 2,20)/ 1.10415007d-06, 8.11013777d-06/
      data fpppp( 2,21),fpppp( 2,22)/-5.00701888d-06, 2.19718136d-06/
      data fpppp( 2,23) /             3.59527964d-06 /
      data fpppp( 3, 1),fpppp( 3, 2)/-4.73032889d-03, 2.25012005d-04/
      data fpppp( 3, 3),fpppp( 3, 4)/ 5.00951174d-03, 1.03919555d-02/
      data fpppp( 3, 5),fpppp( 3, 6)/-2.32177825d-02, 2.05389921d-03/
      data fpppp( 3, 7),fpppp( 3, 8)/-1.08286444d-02, 2.27194320d-02/
      data fpppp( 3, 9),fpppp( 3,10)/ 1.46908820d-03,-5.80896120d-03/
      data fpppp( 3,11),fpppp( 3,12)/ 2.25123218d-03,-4.17864645d-04/
      data fpppp( 3,13),fpppp( 3,14)/ 1.36884220d-04,-2.76043653d-05/
      data fpppp( 3,15),fpppp( 3,16)/-1.04957427d-05, 2.55766451d-05/
      data fpppp( 3,17),fpppp( 3,18)/-5.25029876d-07,-4.24479082d-05/
      data fpppp( 3,19),fpppp( 3,20)/ 2.91979898d-05,-2.01765116d-06/
      data fpppp( 3,21),fpppp( 3,22)/ 6.70726973d-07,-5.12609305d-07/
      data fpppp( 3,23) /            -5.89741464d-07 /
      data fpppp( 4, 1),fpppp( 4, 2)/ 2.43075764d-03,-4.27514527d-03/
      data fpppp( 4, 3),fpppp( 4, 4)/ 1.59074345d-02,-5.80196751d-02/
      data fpppp( 4, 5),fpppp( 4, 6)/ 7.73601323d-02,-5.15330092d-02/
      data fpppp( 4, 7),fpppp( 4, 8)/ 6.20962675d-02,-5.54219109d-02/
      data fpppp( 4, 9),fpppp( 4,10)/ 4.23741213d-03, 5.55850126d-03/
      data fpppp( 4,11),fpppp( 4,12)/-2.94758360d-03, 7.47750975d-04/
      data fpppp( 4,13),fpppp( 4,14)/-1.87220793d-04, 5.15029703d-05/
      data fpppp( 4,15),fpppp( 4,16)/-1.27034332d-05, 3.35733283d-05/
      data fpppp( 4,17),fpppp( 4,18)/-6.46600237d-05, 2.45033304d-05/
      data fpppp( 4,19),fpppp( 4,20)/ 6.26748764d-06, 1.37234777d-07/
      data fpppp( 4,21),fpppp( 4,22)/ 2.13442716d-07, 1.99161079d-07/
      data fpppp( 4,23) /             2.10733606d-07 /
      data fpppp( 5, 1),fpppp( 5, 2)/-7.50793676d-03,-9.80180071d-03/
      data fpppp( 5, 3),fpppp( 5, 4)/ 4.08590645d-02,-9.38216223d-02/
      data fpppp( 5, 5),fpppp( 5, 6)/ 1.34995448d-01,-1.00491235d-01/
      data fpppp( 5, 7),fpppp( 5, 8)/ 1.56004690d-02, 1.61370452d-02/
      data fpppp( 5, 9),fpppp( 5,10)/-1.24248607d-03,-1.77637268d-03/
      data fpppp( 5,11),fpppp( 5,12)/ 9.43446833d-04,-2.37988956d-04/
      data fpppp( 5,13),fpppp( 5,14)/ 7.62131261d-05,-2.87745100d-05/
      data fpppp( 5,15),fpppp( 5,16)/ 2.70032774d-05,-1.09981728d-05/
      data fpppp( 5,17),fpppp( 5,18)/-1.65358200d-05, 4.84657904d-06/
      data fpppp( 5,19),fpppp( 5,20)/ 5.34503407d-06, 6.84822018d-07/
      data fpppp( 5,21),fpppp( 5,22)/-4.19120552d-08,-3.04880898d-08/
      data fpppp( 5,23) /            -2.29966421d-07 /
      data fpppp( 6, 1),fpppp( 6, 2)/ 1.20471631d-02, 1.13106407d-02/
      data fpppp( 6, 3),fpppp( 6, 4)/-5.21641566d-02, 1.03945008d-01/
      data fpppp( 6, 5),fpppp( 6, 6)/-1.29743558d-01, 1.08538915d-01/
      data fpppp( 6, 7),fpppp( 6, 8)/-4.72139752d-02, 5.61161124d-03/
      data fpppp( 6, 9),fpppp( 6,10)/-1.23180050d-03, 9.93726828d-04/
      data fpppp( 6,11),fpppp( 6,12)/-2.88780627d-04, 8.62950293d-05/
      data fpppp( 6,13),fpppp( 6,14)/-1.88955346d-05, 7.60183857d-07/
      data fpppp( 6,15),fpppp( 6,16)/ 1.04936904d-05,-4.35921906d-06/
      data fpppp( 6,17),fpppp( 6,18)/-1.27257356d-05, 5.72509228d-06/
      data fpppp( 6,19),fpppp( 6,20)/ 2.38245986d-06, 1.88403146d-07/
      data fpppp( 6,21),fpppp( 6,22)/ 1.44417737d-07, 5.70163571d-08/
      data fpppp( 6,23) /            -1.79804598d-08 /
      data fpppp( 7, 1),fpppp( 7, 2)/-6.71517891d-03,-2.87700584d-03/
      data fpppp( 7, 3),fpppp( 7, 4)/ 1.45984916d-02,-1.56566463d-02/
      data fpppp( 7, 5),fpppp( 7, 6)/ 6.68024252d-03,-1.16769912d-02/
      data fpppp( 7, 7),fpppp( 7, 8)/ 1.08716537d-02,-1.15846200d-03/
      data fpppp( 7, 9),fpppp( 7,10)/ 5.80304774d-04,-7.46272059d-04/
      data fpppp( 7,11),fpppp( 7,12)/ 2.11789864d-04,-5.18582914d-05/
      data fpppp( 7,13),fpppp( 7,14)/ 1.25393696d-05, 8.87069634d-07/
      data fpppp( 7,15),fpppp( 7,16)/-9.35036386d-08,-1.35044796d-06/
      data fpppp( 7,17),fpppp( 7,18)/-2.88532330d-06, 3.70385772d-07/
      data fpppp( 7,19),fpppp( 7,20)/ 1.66473499d-06, 3.24900976d-07/
      data fpppp( 7,21),fpppp( 7,22)/-8.70144902d-08,-7.94572247d-08/
      data fpppp( 7,23) /            -1.91749311d-07 /
      data fpppp( 8, 1),fpppp( 8, 2)/ 6.38201496d-03, 4.12133781d-03/
      data fpppp( 8, 3),fpppp( 8, 4)/-2.17236931d-02, 3.49765142d-02/
      data fpppp( 8, 5),fpppp( 8, 6)/-3.78396392d-02, 3.77599793d-02/
      data fpppp( 8, 7),fpppp( 8, 8)/-1.87168096d-02, 1.45662838d-03/
      data fpppp( 8, 9),fpppp( 8,10)/-5.76374853d-04, 3.41134356d-04/
      data fpppp( 8,11),fpppp( 8,12)/-9.20943761d-05, 2.71873794d-05/
      data fpppp( 8,13),fpppp( 8,14)/-4.92336702d-06,-3.11201237d-06/
      data fpppp( 8,15),fpppp( 8,16)/ 5.82594726d-06,-3.64793164d-06/
      data fpppp( 8,17),fpppp( 8,18)/-9.52824127d-07, 1.06171901d-06/
      data fpppp( 8,19),fpppp( 8,20)/ 1.15035618d-07, 5.78968559d-08/
      data fpppp( 8,21),fpppp( 8,22)/-1.96410828d-07, 3.15112842d-07/
      data fpppp( 8,23) /             6.07827554d-07 /
      data fpppp( 9, 1),fpppp( 9, 2)/-9.00345338d-04,-4.50973655d-03/
      data fpppp( 9, 3),fpppp( 9, 4)/ 1.88165899d-02,-5.21320954d-02/
      data fpppp( 9, 5),fpppp( 9, 6)/ 7.32749057d-02,-4.60929263d-02/
      data fpppp( 9, 7),fpppp( 9, 8)/ 9.05471423d-03, 1.13759130d-03/
      data fpppp( 9, 9),fpppp( 9,10)/-9.01459981d-05,-2.76148730d-05/
      data fpppp( 9,11),fpppp( 9,12)/ 7.75630648d-06,-6.46381880d-07/
      data fpppp( 9,13),fpppp( 9,14)/-1.13394419d-06, 3.22830632d-06/
      data fpppp( 9,15),fpppp( 9,16)/-2.38154865d-06, 1.25990100d-06/
      data fpppp( 9,17),fpppp( 9,18)/-1.12302289d-06,-4.16417525d-07/
      data fpppp( 9,19),fpppp( 9,20)/ 8.61388016d-07,-2.32394610d-07/
      data fpppp( 9,21),fpppp( 9,22)/ 8.20017166d-07,-8.44525390d-07/
      data fpppp( 9,23) /            -1.73279528d-06 /
      data fpppp(10, 1),fpppp(10, 2)/-2.29434926d-03, 4.19139700d-04/
      data fpppp(10, 3),fpppp(10, 4)/ 6.19043962d-04, 9.61649467d-03/
      data fpppp(10, 5),fpppp(10, 6)/-1.58603620d-02,-8.23667063d-04/
      data fpppp(10, 7),fpppp(10, 8)/ 8.40070251d-03,-2.36975991d-03/
      data fpppp(10, 9),fpppp(10,10)/ 4.09274412d-04,-1.02368395d-04/
      data fpppp(10,11),fpppp(10,12)/ 3.06177076d-05,-8.42255052d-06/
      data fpppp(10,13),fpppp(10,14)/ 2.64338099d-06,-1.68746313d-06/
      data fpppp(10,15),fpppp(10,16)/ 1.46101095d-06,-9.98476603d-07/
      data fpppp(10,17),fpppp(10,18)/-8.63103830d-09, 4.24942134d-07/
      data fpppp(10,19),fpppp(10,20)/-2.71005174d-07, 4.92360498d-07/
      data fpppp(10,21),fpppp(10,22)/-1.43595601d-06, 1.35150248d-06/
      data fpppp(10,23) /             2.79159668d-06 /
      data fpppp(11, 1),fpppp(11, 2)/-4.03804813d-04, 5.94812140d-04/
      data fpppp(11, 3),fpppp(11, 4)/-9.53076110d-04, 6.41180385d-03/
      data fpppp(11, 5),fpppp(11, 6)/-1.25020156d-02, 7.95357925d-03/
      data fpppp(11, 7),fpppp(11, 8)/-1.90314524d-03, 7.16667425d-04/
      data fpppp(11, 9),fpppp(11,10)/-1.36047089d-04, 3.16152249d-05/
      data fpppp(11,11),fpppp(11,12)/-8.87878380d-06, 2.65639998d-06/
      data fpppp(11,13),fpppp(11,14)/ 3.42803131d-07,-2.57780136d-06/
      data fpppp(11,15),fpppp(11,16)/ 3.95251221d-06,-2.37667654d-06/
      data fpppp(11,17),fpppp(11,18)/ 5.05267449d-07,-1.33550707d-07/
      data fpppp(11,19),fpppp(11,20)/ 1.45711050d-07,-5.09161173d-07/
      data fpppp(11,21),fpppp(11,22)/ 1.25918365d-06,-1.03087790d-06/
      data fpppp(11,23) /            -2.16139477d-06 /
      data fpppp(12, 1),fpppp(12, 2)/ 7.35323925d-05,-7.76960174d-05/
      data fpppp(12, 3),fpppp(12, 4)/-9.11912375d-04, 6.44329085d-04/
      data fpppp(12, 5),fpppp(12, 6)/ 1.64804074d-03,-1.33339387d-03/
      data fpppp(12, 7),fpppp(12, 8)/ 1.42779868d-05,-6.52409145d-06/
      data fpppp(12, 9),fpppp(12,10)/-3.90842157d-06, 1.92174556d-06/
      data fpppp(12,11),fpppp(12,12)/-4.77205810d-07, 1.56123412d-06/
      data fpppp(12,13),fpppp(12,14)/-2.26709417d-06, 3.58438772d-06/
      data fpppp(12,15),fpppp(12,16)/-4.08143570d-06, 2.25096717d-06/
      data fpppp(12,17),fpppp(12,18)/-6.35200506d-07, 6.45232778d-08/
      data fpppp(12,19),fpppp(12,20)/ 1.98723811d-08, 3.52175982d-07/
      data fpppp(12,21),fpppp(12,22)/-6.94057144d-07, 4.37231572d-07/
      data fpppp(12,23) /             9.46371190d-07 /
      data fpppp(13, 1),fpppp(13, 2)/ 1.00238536d-04, 2.32786936d-05/
      data fpppp(13, 3),fpppp(13, 4)/ 4.23775105d-04,-8.46825372d-04/
      data fpppp(13, 5),fpppp(13, 6)/ 3.35028247d-04,-1.27352911d-05/
      data fpppp(13, 7),fpppp(13, 8)/ 8.06913165d-05,-2.26404209d-05/
      data fpppp(13, 9),fpppp(13,10)/ 5.20145233d-06,-1.64404326d-06/
      data fpppp(13,11),fpppp(13,12)/ 1.96018688d-06,-2.31488551d-06/
      data fpppp(13,13),fpppp(13,14)/ 2.25748737d-06,-2.58575522d-06/
      data fpppp(13,15),fpppp(13,16)/ 2.48605685d-06,-1.12755980d-06/
      data fpppp(13,17),fpppp(13,18)/ 1.59358457d-07, 4.72695393d-08/
      data fpppp(13,19),fpppp(13,20)/-1.55036814d-08,-2.99305640d-07/
      data fpppp(13,21),fpppp(13,22)/ 6.45495689d-07,-3.91070727d-07/
      data fpppp(13,23) /            -8.61532074d-07 /
      data fpppp(14, 1),fpppp(14, 2)/-1.09291702d-04,-5.23950909d-05/
      data fpppp(14, 3),fpppp(14, 4)/ 1.24802456d-04,-1.19053272d-04/
      data fpppp(14, 5),fpppp(14, 6)/ 9.03584664d-05,-1.15280890d-05/
      data fpppp(14, 7),fpppp(14, 8)/-2.74629638d-05, 5.66774003d-06/
      data fpppp(14, 9),fpppp(14,10)/-1.28553754d-06, 2.00789424d-06/
      data fpppp(14,11),fpppp(14,12)/-2.42925898d-06, 2.08771023d-06/
      data fpppp(14,13),fpppp(14,14)/-1.57474725d-06, 1.85679859d-06/
      data fpppp(14,15),fpppp(14,16)/-1.72356148d-06, 7.64185735d-07/
      data fpppp(14,17),fpppp(14,18)/-8.11183709d-08,-1.22974945d-07/
      data fpppp(14,19),fpppp(14,20)/-4.14785659d-08, 6.08903728d-07/
      data fpppp(14,21),fpppp(14,22)/-1.05973331d-06, 5.70424964d-07/
      data fpppp(14,23) /             1.25807029d-06 /
      data fpppp(15, 1),fpppp(15, 2)/ 1.50578743d-05, 6.98308220d-06/
      data fpppp(15, 3),fpppp(15, 4)/-6.01477778d-06,-1.78190010d-06/
      data fpppp(15, 5),fpppp(15, 6)/-9.60959372d-06, 4.12926273d-06/
      data fpppp(15, 7),fpppp(15, 8)/ 4.36921084d-06,-1.32941716d-06/
      data fpppp(15, 9),fpppp(15,10)/ 1.25953566d-06,-2.24981151d-06/
      data fpppp(15,11),fpppp(15,12)/ 3.63760894d-06,-2.22619508d-06/
      data fpppp(15,13),fpppp(15,14)/ 6.95799690d-07,-1.06856591d-06/
      data fpppp(15,15),fpppp(15,16)/ 1.38325077d-06,-8.14497753d-07/
      data fpppp(15,17),fpppp(15,18)/ 2.11660625d-07, 6.84533634d-08/
      data fpppp(15,19),fpppp(15,20)/ 1.97610103d-07,-1.20789013d-06/
      data fpppp(15,21),fpppp(15,22)/ 1.87278107d-06,-8.42621034d-07/
      data fpppp(15,23) /            -1.90200219d-06 /
      data fpppp(16, 1),fpppp(16, 2)/-1.17019213d-06,-5.36442924d-07/
      data fpppp(16, 3),fpppp(16, 4)/ 8.83872445d-07,-4.48793751d-07/
      data fpppp(16, 5),fpppp(16, 6)/ 2.69135497d-06,-6.85082055d-07/
      data fpppp(16, 7),fpppp(16, 8)/-2.44084560d-06, 4.13912834d-07/
      data fpppp(16, 9),fpppp(16,10)/-1.41575876d-07, 1.89627208d-06/
      data fpppp(16,11),fpppp(16,12)/-2.73188712d-06, 1.26499120d-06/
      data fpppp(16,13),fpppp(16,14)/ 9.05744605d-08, 1.63440079d-07/
      data fpppp(16,15),fpppp(16,16)/-7.72367700d-07, 6.99534581d-07/
      data fpppp(16,17),fpppp(16,18)/-2.25515263d-07, 2.33967170d-08/
      data fpppp(16,19),fpppp(16,20)/-1.85911617d-07, 8.96220664d-07/
      data fpppp(16,21),fpppp(16,22)/-1.42869664d-06, 6.05717928d-07/
      data fpppp(16,23) /             1.39460910d-06 /
      data fpppp(17, 1),fpppp(17, 2)/ 7.47620137d-07, 4.14963196d-07/
      data fpppp(17, 3),fpppp(17, 4)/-4.70785154d-07, 5.79286424d-07/
      data fpppp(17, 5),fpppp(17, 6)/-4.51887320d-07,-5.76209236d-07/
      data fpppp(17, 7),fpppp(17, 8)/ 1.78341708d-07, 2.73555141d-07/
      data fpppp(17, 9),fpppp(17,10)/ 1.04928630d-06,-1.99569729d-06/
      data fpppp(17,11),fpppp(17,12)/ 1.64281937d-06,-2.04248966d-07/
      data fpppp(17,13),fpppp(17,14)/-4.00416136d-07,-6.21420635d-08/
      data fpppp(17,15),fpppp(17,16)/ 7.85902915d-07,-7.53108760d-07/
      data fpppp(17,17),fpppp(17,18)/ 2.14400659d-07, 2.55398988d-08/
      data fpppp(17,19),fpppp(17,20)/-1.32483001d-07, 3.04866362d-08/
      data fpppp(17,21),fpppp(17,22)/ 2.83734693d-07,-1.69674295d-07/
      data fpppp(17,23) /            -4.21181271d-07 /
      data fpppp(18, 1),fpppp(18, 2)/-9.06780652d-07,-4.43758718d-07/
      data fpppp(18, 3),fpppp(18, 4)/ 1.52715585d-06,-1.77955379d-06/
      data fpppp(18, 5),fpppp(18, 6)/ 7.93114026d-07, 3.53441988d-07/
      data fpppp(18, 7),fpppp(18, 8)/-6.03532911d-07, 5.23903181d-08/
      data fpppp(18, 9),fpppp(18,10)/-1.56665250d-06, 2.55950478d-06/
      data fpppp(18,11),fpppp(18,12)/-1.46025790d-06, 2.48714933d-09/
      data fpppp(18,13),fpppp(18,14)/ 2.90027697d-07,-1.10476674d-09/
      data fpppp(18,15),fpppp(18,16)/-6.05249810d-07, 6.95156796d-07/
      data fpppp(18,17),fpppp(18,18)/-2.07106871d-07,-2.07734655d-07/
      data fpppp(18,19),fpppp(18,20)/ 8.59576490d-07,-1.39092035d-06/
      data fpppp(18,21),fpppp(18,22)/ 9.21037556d-07,-1.83386374d-07/
      data fpppp(18,23) /            -3.11701207d-07 /
      data fpppp(19, 1),fpppp(19, 2)/ 3.84762245d-07, 3.31770420d-07/
      data fpppp(19, 3),fpppp(19, 4)/-2.20357718d-06, 3.94932043d-06/
      data fpppp(19, 5),fpppp(19, 6)/-2.49568786d-06,-1.11582329d-07/
      data fpppp(19, 7),fpppp(19, 8)/ 8.32845683d-07, 1.04562718d-06/
      data fpppp(19, 9),fpppp(19,10)/-9.75006567d-07,-2.09914792d-07/
      data fpppp(19,11),fpppp(19,12)/-2.48524971d-08, 3.67526312d-07/
      data fpppp(19,13),fpppp(19,14)/-5.11955778d-07, 8.04914311d-07/
      data fpppp(19,15),fpppp(19,16)/-2.04873356d-07,-5.13226095d-07/
      data fpppp(19,17),fpppp(19,18)/ 4.14622420d-07, 2.44712475d-07/
      data fpppp(19,19),fpppp(19,20)/-1.49724319d-06, 2.38686371d-06/
      data fpppp(19,21),fpppp(19,22)/-1.63467226d-06, 3.58981151d-07/
      data fpppp(19,23) /             6.34009023d-07 /
      data fpppp(20, 1),fpppp(20, 2)/ 1.36704458d-07,-8.12685344d-08/
      data fpppp(20, 3),fpppp(20, 4)/ 7.89962390d-07,-2.15102039d-06/
      data fpppp(20, 5),fpppp(20, 6)/ 2.05999774d-06,-5.35261458d-07/
      data fpppp(20, 7),fpppp(20, 8)/-2.85614989d-07,-1.85568960d-06/
      data fpppp(20, 9),fpppp(20,10)/ 2.86760612d-06,-1.86223238d-06/
      data fpppp(20,11),fpppp(20,12)/ 1.21828761d-06,-6.84684536d-07/
      data fpppp(20,13),fpppp(20,14)/ 8.37544247d-07,-1.31545567d-06/
      data fpppp(20,15),fpppp(20,16)/ 6.72607163d-07, 2.13195057d-07/
      data fpppp(20,17),fpppp(20,18)/-3.51036624d-07,-6.79474590d-08/
      data fpppp(20,19),fpppp(20,20)/ 8.56378946d-07,-1.30763295d-06/
      data fpppp(20,21),fpppp(20,22)/ 9.45062611d-07,-3.01084263d-07/
      data fpppp(20,23) /            -5.47561869d-07 /
      data fpppp(21, 1),fpppp(21, 2)/-7.38455186d-07,-3.37754174d-07/
      data fpppp(21, 3),fpppp(21, 4)/ 9.71985020d-07,-8.99909424d-07/
      data fpppp(21, 5),fpppp(21, 6)/ 1.69379699d-07, 2.86702479d-07/
      data fpppp(21, 7),fpppp(21, 8)/-3.67865022d-07, 1.07917592d-06/
      data fpppp(21, 9),fpppp(21,10)/-1.62651302d-06, 1.38556111d-06/
      data fpppp(21,11),fpppp(21,12)/-8.99266700d-07, 4.18592846d-07/
      data fpppp(21,13),fpppp(21,14)/-5.20948393d-07, 7.88666437d-07/
      data fpppp(21,15),fpppp(21,16)/-4.56698539d-07, 1.61043901d-08/
      data fpppp(21,17),fpppp(21,18)/ 8.65486385d-08, 2.73800119d-08/
      data fpppp(21,19),fpppp(21,20)/-2.65396391d-07, 3.79352037d-07/
      data fpppp(21,21),fpppp(21,22)/-3.38737170d-07, 1.85715340d-07/
      data fpppp(21,23) /             3.55155932d-07 /
      data fpppp(22, 1),fpppp(22, 2)/ 8.64245978d-07, 4.39950361d-07/
      data fpppp(22, 3),fpppp(22, 4)/-1.50184509d-06, 1.86760888d-06/
      data fpppp(22, 5),fpppp(22, 6)/-1.02404404d-06, 5.37438849d-08/
      data fpppp(22, 7),fpppp(22, 8)/ 3.56027652d-07,-5.94346476d-07/
      data fpppp(22, 9),fpppp(22,10)/ 1.02717660d-06,-1.13315330d-06/
      data fpppp(22,11),fpppp(22,12)/ 7.52170948d-07,-2.84349525d-07/
      data fpppp(22,13),fpppp(22,14)/ 2.45670785d-07,-3.25845966d-07/
      data fpppp(22,15),fpppp(22,16)/ 1.91855625d-07,-2.96027084d-08/
      data fpppp(22,17),fpppp(22,18)/-1.09117634d-08,-1.51835581d-08/
      data fpppp(22,19),fpppp(22,20)/ 8.61631598d-08,-1.21499054d-07/
      data fpppp(22,21),fpppp(22,22)/ 1.25208537d-07,-8.10348628d-08/
      data fpppp(22,23) /            -1.57863694d-07 /
      data fpppp(23, 1),fpppp(23, 2)/-6.17612372d-07,-3.05479979d-07/
      data fpppp(23, 3),fpppp(23, 4)/ 1.00260982d-06,-1.17515130d-06/
      data fpppp(23, 5),fpppp(23, 6)/ 7.20482797d-07,-2.14198153d-07/
      data fpppp(23, 7),fpppp(23, 8)/-9.42513807d-08, 2.73153303d-07/
      data fpppp(23, 9),fpppp(23,10)/-5.53560854d-07, 6.52882852d-07/
      data fpppp(23,11),fpppp(23,12)/-4.40572637d-07, 1.66396681d-07/
      data fpppp(23,13),fpppp(23,14)/-1.08144906d-07, 1.13566637d-07/
      data fpppp(23,15),fpppp(23,16)/-6.77106396d-08, 2.10039418d-08/
      data fpppp(23,17),fpppp(23,18)/-3.90490096d-09, 1.86998706d-09/
      data fpppp(23,19),fpppp(23,20)/-2.11159978d-08, 3.51674125d-08/
      data fpppp(23,21),fpppp(23,22)/-3.51301575d-08, 1.88335903d-08/
      data fpppp(23,23) /             3.72941045d-08 /
      data fpppp(24, 1),fpppp(24, 2)/ 2.47990415d-07, 1.09595747d-07/
      data fpppp(24, 3),fpppp(24, 4)/-2.46485882d-07, 1.59336854d-07/
      data fpppp(24, 5),fpppp(24, 6)/-1.06957535d-07, 1.01789761d-07/
      data fpppp(24, 7),fpppp(24, 8)/-1.93158764d-08,-9.66327796d-08/
      data fpppp(24, 9),fpppp(24,10)/ 1.96824741d-07,-2.06068860d-07/
      data fpppp(24,11),fpppp(24,12)/ 1.51124688d-07,-8.95667975d-08/
      data fpppp(24,13),fpppp(24,14)/ 9.52221495d-08,-1.10944228d-07/
      data fpppp(24,15),fpppp(24,16)/ 7.19682025d-08,-2.94144917d-08/
      data fpppp(24,17),fpppp(24,18)/ 5.55582892d-09, 9.00719603d-09/
      data fpppp(24,19),fpppp(24,20)/-3.37975018d-10,-1.15189569d-08/
      data fpppp(24,21),fpppp(24,22)/ 1.21443438d-08,-3.68014158d-09/
      data fpppp(24,23) /            -8.22240236d-09 /
      data fpppp(25, 1),fpppp(25, 2)/-2.17508424d-08,-2.89990101d-09/
      data fpppp(25, 3),fpppp(25, 4)/-2.52771801d-08, 9.66443125d-08/
      data fpppp(25, 5),fpppp(25, 6)/-7.46034624d-08, 9.60190916d-09/
      data fpppp(25, 7),fpppp(25, 8)/ 7.21448726d-09, 4.96166101d-08/
      data fpppp(25, 9),fpppp(25,10)/-1.02392889d-07, 9.72375270d-08/
      data fpppp(25,11),fpppp(25,12)/-8.50510923d-08, 8.01254793d-08/
      data fpppp(25,13),fpppp(25,14)/-1.35038595d-07, 1.79134915d-07/
      data fpppp(25,15),fpppp(25,16)/-1.13565829d-07, 3.73440205d-08/
      data fpppp(25,17),fpppp(25,18)/-2.87473843d-09,-1.15634720d-08/
      data fpppp(25,19),fpppp(25,20)/ 2.48302484d-09, 6.91260796d-09/
      data fpppp(25,21),fpppp(25,22)/-6.27911570d-09, 1.03754540d-11/
      data fpppp(25,23) /             7.33805235d-10 /
      data fpppp(26, 1),fpppp(26, 2)/-1.76042818d-08,-1.03616706d-08/
      data fpppp(26, 3),fpppp(26, 4)/ 2.64739480d-08,-4.02659591d-08/
      data fpppp(26, 5),fpppp(26, 6)/ 2.86994606d-08,-3.15784652d-09/
      data fpppp(26, 7),fpppp(26, 8)/-8.22835423d-09,-1.37280860d-08/
      data fpppp(26, 9),fpppp(26,10)/ 3.18107963d-08,-2.97259816d-08/
      data fpppp(26,11),fpppp(26,12)/ 3.09946331d-08,-3.97501945d-08/
      data fpppp(26,13),fpppp(26,14)/ 8.30775763d-08,-1.12561745d-07/
      data fpppp(26,15),fpppp(26,16)/ 6.80150184d-08,-1.82748895d-08/
      data fpppp(26,17),fpppp(26,18)/-1.23581428d-10, 3.02681616d-09/
      data fpppp(26,19),fpppp(26,20)/ 3.75208550d-09,-6.49643836d-09/
      data fpppp(26,21),fpppp(26,22)/ 4.28576303d-09,-5.09728104d-11/
      data fpppp(26,23) /            -6.80122984d-11 /
      data fpppp(27, 1),fpppp(27, 2)/ 4.21044489d-09, 2.69060571d-09/
      data fpppp(27, 3),fpppp(27, 4)/-3.12800596d-09, 6.09908606d-09/
      data fpppp(27, 5),fpppp(27, 6)/-5.34535893d-09,-1.95594653d-09/
      data fpppp(27, 7),fpppp(27, 8)/ 4.14065356d-09, 4.35314643d-09/
      data fpppp(27, 9),fpppp(27,10)/-8.00755302d-09, 6.28541034d-09/
      data fpppp(27,11),fpppp(27,12)/-7.19166061d-09, 1.23948446d-08/
      data fpppp(27,13),fpppp(27,14)/-2.26081266d-08, 2.40895575d-08/
      data fpppp(27,15),fpppp(27,16)/-1.14545645d-08, 1.35057513d-09/
      data fpppp(27,17),fpppp(27,18)/ 1.60886999d-09,-9.96553754d-11/
      data fpppp(27,19),fpppp(27,20)/-3.49475384d-09, 5.62189366d-09/
      data fpppp(27,21),fpppp(27,22)/-5.87627654d-09, 2.39302936d-09/
      data fpppp(27,23) /             5.01448495d-09 /
      data fpppp(28, 1),fpppp(28, 2)/ 2.43861891d-08, 1.23518741d-08/
      data fpppp(28, 3),fpppp(28, 4)/-1.65961162d-08, 1.36537568d-08/
      data fpppp(28, 5),fpppp(28, 6)/-1.02204008d-08,-3.99300549d-09/
      data fpppp(28, 7),fpppp(28, 8)/ 1.12666685d-08, 4.88642435d-09/
      data fpppp(28, 9),fpppp(28,10)/-1.04652090d-08, 7.15275269d-09/
      data fpppp(28,11),fpppp(28,12)/-1.26170156d-08, 2.91585035d-08/
      data fpppp(28,13),fpppp(28,14)/-6.26067938d-08, 7.34627239d-08/
      data fpppp(28,15),fpppp(28,16)/-3.72718712d-08, 5.11382342d-09/
      data fpppp(28,17),fpppp(28,18)/ 3.79827446d-09, 6.89878893d-10/
      data fpppp(28,19),fpppp(28,20)/-9.55553735d-09, 1.30206591d-08/
      data fpppp(28,21),fpppp(28,22)/-1.22453710d-08, 4.52591654d-09/
      data fpppp(28,23) /             9.28654191d-09 /
 
      c(1,1)=fpppp(ix+1,iy+1)
      c(1,2)=fpppp(ix+1,iy  )
      c(2,1)=fpppp(ix  ,iy+1)
      c(2,2)=fpppp(ix,  iy  )
      c(1,3)=fpp(ix+1,iy+1,1)
      c(1,4)=fpp(ix+1,iy  ,1)
      c(2,3)=fpp(ix,  iy+1,1)
      c(2,4)=fpp(ix,  iy,  1)
      c(3,1)=fpp(ix+1,iy+1,2)
      c(3,2)=fpp(ix+1,iy  ,2)
      c(4,1)=fpp(ix,  iy+1,2)
      c(4,2)=fpp(ix,  iy,  2)
      c(3,3)=f(ix+1,iy+1)
      c(3,4)=f(ix+1,iy  )
      c(4,3)=f(ix,  iy+1)
      c(4,4)=f(ix,  iy  )
      px(1)=((xi-xix)**3/(6.0*delxi))-(xi-xix)*delxi/6.0
      px(2)=(xi-xixp1)*delxi/6.0-((xi-xixp1)**3/(6.0*delxi))
      px(3)=(xi-xix)/delxi
      px(4)=(xixp1-xi)/delxi
      py(1)=((yi-yiy)**3/(6.0*delyi))-(yi-yiy)*delyi/6.0
      py(2)=(yi-yiyp1)*delyi/6.0-((yi-yiyp1)**3/(6.0*delyi))
      py(3)=(yi-yiy)/delyi
      py(4)=(yiyp1-yi)/delyi

      fi=0.0d 00
      do l=1,4
        sum=0.0d 00
        do i=1,4
          sum=sum + c(i,l) * px(i)
        enddo
        fi = fi + sum * py(l)
      enddo
      return
      end  
      subroutine c11_spl(xi,yi,ix,iy,delxi,delyi,xix,xixp1,
     x                    yiy,yiyp1,fi)
      implicit real*8 (a-h,o-z)
      dimension fpp(28,23,2),f(28,23),fpppp(28,23)
      dimension c(4,4),px(4),py(4)
 
      data f( 4, 9),f( 4,10) / -8.62200000d-05 , -1.79860000d-04 /
      data f( 4,11),f( 4,12) /  1.94500000d-05 ,  1.45700000d-05 /
      data f( 4,13),f( 4,14) /  1.60000000d-06 , -7.00000000d-08 /
      data f( 4,15),f( 4,16) / -5.06000000d-06 , -1.35600000d-05 /
      data f( 4,17),f( 4,18) / -8.59000000d-06 , -2.56000000d-06 /
      data f( 4,19),f( 4,20) / -3.10000000d-07 , -2.30000000d-07 /
      data f( 4,21),f( 4,22) /  1.00000000d-08 , -4.00000000d-08 /
      data f( 4,23) /           0.00000000d+00 /
      data f( 5, 1),f( 5, 2) /  0.00000000d+00 ,  2.00000000d-08 /
      data f( 5, 3),f( 5, 4) / -7.01100000d-05 , -2.48969000d-03 /
      data f( 5, 5),f( 5, 6) / -4.52179000d-03 , -5.65193000d-03 /
      data f( 5, 7),f( 5, 8) / -3.12689000d-03 , -6.29150000d-04 /
      data f( 5, 9),f( 5,10) / -9.37900000d-05 , -1.36910000d-04 /
      data f( 5,11),f( 5,12) /  1.38900000d-05 ,  8.09000000d-06 /
      data f( 5,13),f( 5,14) /  7.50000000d-07 , -1.00000000d-08 /
      data f( 5,15),f( 5,16) / -3.62000000d-06 , -6.49000000d-06 /
      data f( 5,17),f( 5,18) / -2.52000000d-06 , -5.40000000d-07 /
      data f( 5,19),f( 5,20) / -1.40000000d-07 , -1.60000000d-07 /
      data f( 5,21),f( 5,22) /  2.00000000d-08 , -2.00000000d-08 /
      data f( 5,23) /           0.00000000d+00 /
      data f( 6, 1),f( 6, 2) /  0.00000000d+00 , -1.00000000d-07 /
      data f( 6, 3),f( 6, 4) / -9.38000000d-06 , -3.76265000d-03 /
      data f( 6, 5),f( 6, 6) / -2.89300000d-03 , -8.37388000d-03 /
      data f( 6, 7),f( 6, 8) / -3.46740000d-03 , -6.91970000d-04 /
      data f( 6, 9),f( 6,10) / -9.37800000d-05 , -9.69100000d-05 /
      data f( 6,11),f( 6,12) /  9.59000000d-06 ,  4.48000000d-06 /
      data f( 6,13),f( 6,14) /  5.20000000d-07 ,  2.00000000d-08 /
      data f( 6,15),f( 6,16) / -2.66000000d-06 , -2.99000000d-06 /
      data f( 6,17),f( 6,18) /  3.00000000d-07 ,  8.00000000d-08 /
      data f( 6,19),f( 6,20) / -1.10000000d-07 ,  7.00000000d-08 /
      data f( 6,21),f( 6,22) /  8.00000000d-08 ,  0.00000000d+00 /
      data f( 6,23) /           0.00000000d+00 /
      data f( 7, 1),f( 7, 2) /  0.00000000d+00 ,  2.57100000d-05 /
      data f( 7, 3),f( 7, 4) / -6.72900000d-05 , -4.14193000d-03 /
      data f( 7, 5),f( 7, 6) / -1.20403000d-03 , -8.08095000d-03 /
      data f( 7, 7),f( 7, 8) / -3.50261000d-03 , -6.84660000d-04 /
      data f( 7, 9),f( 7,10) / -1.71930000d-04 , -4.58100000d-05 /
      data f( 7,11),f( 7,12) /  3.97000000d-06 ,  1.31000000d-06 /
      data f( 7,13),f( 7,14) /  9.00000000d-08 ,  3.60000000d-07 /
      data f( 7,15),f( 7,16) / -1.41000000d-06 , -8.00000000d-07 /
      data f( 7,17),f( 7,18) /  4.90000000d-07 , -5.00000000d-08 /
      data f( 7,19),f( 7,20) / -2.40000000d-07 , -7.00000000d-08 /
      data f( 7,21),f( 7,22) /  7.00000000d-08 ,  1.00000000d-08 /
      data f( 7,23) /           0.00000000d+00 /
      data f( 8, 1),f( 8, 2) /  0.00000000d+00 , -5.70000000d-07 /
      data f( 8, 3),f( 8, 4) / -6.93500000d-05 , -3.95057000d-03 /
      data f( 8, 5),f( 8, 6) / -4.05385000d-03 , -8.27286000d-03 /
      data f( 8, 7),f( 8, 8) / -3.52163000d-03 , -2.87700000d-04 /
      data f( 8, 9),f( 8,10) / -1.62780000d-04 , -2.26700000d-05 /
      data f( 8,11),f( 8,12) /  1.50000000d-06 ,  5.20000000d-07 /
      data f( 8,13),f( 8,14) /  3.00000000d-08 ,  2.00000000d-08 /
      data f( 8,15),f( 8,16) / -5.90000000d-07 , -4.70000000d-07 /
      data f( 8,17),f( 8,18) /  1.00000000d-07 , -1.60000000d-07 /
      data f( 8,19),f( 8,20) / -1.00000000d-08 ,  1.10000000d-07 /
      data f( 8,21),f( 8,22) /  1.00000000d-07 ,  1.00000000d-08 /
      data f( 8,23) /           0.00000000d+00 /
      data f( 9, 1),f( 9, 2) /  0.00000000d+00 ,  9.00000000d-08 /
      data f( 9, 3),f( 9, 4) / -3.15100000d-05 , -2.07279000d-03 /
      data f( 9, 5),f( 9, 6) / -6.51998000d-03 , -4.50405000d-03 /
      data f( 9, 7),f( 9, 8) / -9.25710000d-04 , -1.52330000d-04 /
      data f( 9, 9),f( 9,10) / -8.37500000d-05 , -1.07700000d-05 /
      data f( 9,11),f( 9,12) /  3.70000000d-07 ,  1.50000000d-07 /
      data f( 9,13),f( 9,14) /  0.00000000d+00 ,  2.60000000d-07 /
      data f( 9,15),f( 9,16) / -2.90000000d-07 , -2.30000000d-07 /
      data f( 9,17),f( 9,18) / -1.10000000d-07 , -4.00000000d-08 /
      data f( 9,19),f( 9,20) /  8.00000000d-08 ,  1.00000000d-08 /
      data f( 9,21),f( 9,22) /  6.00000000d-08 ,  6.00000000d-08 /
      data f( 9,23) /           0.00000000d+00 /
      data f(10, 1),f(10, 2) /  0.00000000d+00 ,  1.20000000d-07 /
      data f(10, 3),f(10, 4) / -1.36100000d-05 , -1.61120000d-04 /
      data f(10, 5),f(10, 6) / -1.78497000d-03 , -5.43880000d-04 /
      data f(10, 7),f(10, 8) / -2.83020000d-04 , -8.39400000d-05 /
      data f(10, 9),f(10,10) / -4.90800000d-05 , -4.83000000d-06 /
      data f(10,11),f(10,12) /  6.00000000d-08 ,  1.40000000d-07 /
      data f(10,13),f(10,14) /  9.00000000d-08 ,  5.00000000d-08 /
      data f(10,15),f(10,16) / -5.00000000d-08 , -3.50000000d-07 /
      data f(10,17),f(10,18) / -1.00000000d-07 , -5.00000000d-08 /
      data f(10,19),f(10,20) / -2.00000000d-08 ,  5.00000000d-08 /
      data f(10,21),f(10,22) /  1.30000000d-07 , -6.70000000d-07 /
      data f(10,23) /           0.00000000d+00 /
      data f(11, 1),f(11, 2) /  0.00000000d+00 , -3.00000000d-08 /
      data f(11, 3),f(11, 4) / -2.90000000d-07 ,  8.43600000d-05 /
      data f(11, 5),f(11, 6) /  1.39698000d-03 ,  2.60150000d-04 /
      data f(11, 7),f(11, 8) / -1.16600000d-04 , -5.22500000d-05 /
      data f(11, 9),f(11,10) / -2.72700000d-05 , -2.14000000d-06 /
      data f(11,11),f(11,12) / -1.00000000d-07 ,  1.10000000d-07 /
      data f(11,13),f(11,14) / -1.10000000d-07 ,  6.00000000d-08 /
      data f(11,15),f(11,16) /  1.60000000d-07 , -2.00000000d-08 /
      data f(11,17),f(11,18) / -1.00000000d-07 , -1.00000000d-08 /
      data f(11,19),f(11,20) /  2.00000000d-08 ,  5.00000000d-08 /
      data f(11,21),f(11,22) /  3.00000000d-08 ,  2.70000000d-07 /
      data f(11,23) /           0.00000000d+00 /
      data f(12, 1),f(12, 2) /  0.00000000d+00 , -4.00000000d-08 /
      data f(12, 3),f(12, 4) / -4.10400000d-05 , -2.13730000d-04 /
      data f(12, 5),f(12, 6) /  6.71960000d-04 ,  3.05300000d-05 /
      data f(12, 7),f(12, 8) / -4.50500000d-05 , -2.97800000d-05 /
      data f(12, 9),f(12,10) / -1.38800000d-05 , -9.30000000d-07 /
      data f(12,11),f(12,12) / -2.00000000d-08 ,  9.00000000d-08 /
      data f(12,13),f(12,14) / -9.00000000d-08 , -1.00000000d-08 /
      data f(12,15),f(12,16) / -4.00000000d-08 ,  0.00000000d+00 /
      data f(12,17),f(12,18) /  1.00000000d-08 ,  2.00000000d-08 /
      data f(12,19),f(12,20) /  4.00000000d-08 ,  1.00000000d-08 /
      data f(12,21),f(12,22) /  2.00000000d-08 ,  1.10000000d-07 /
      data f(12,23) /           0.00000000d+00 /
      data f(13, 1),f(13, 2) /  0.00000000d+00 ,  8.00000000d-08 /
      data f(13, 3),f(13, 4) /  6.70000000d-07 , -7.57500000d-05 /
      data f(13, 5),f(13, 6) /  2.93700000d-05 , -3.30000000d-06 /
      data f(13, 7),f(13, 8) / -1.48900000d-05 , -1.14100000d-05 /
      data f(13, 9),f(13,10) / -4.52000000d-06 , -4.10000000d-07 /
      data f(13,11),f(13,12) / -2.00000000d-08 , -1.30000000d-07 /
      data f(13,13),f(13,14) / -5.00000000d-08 , -7.00000000d-08 /
      data f(13,15),f(13,16) /  1.00000000d-08 ,  1.00000000d-07 /
      data f(13,17),f(13,18) / -3.00000000d-08 ,  0.00000000d+00 /
      data f(13,19),f(13,20) / -1.00000000d-08 , -9.00000000d-08 /
      data f(13,21),f(13,22) / -3.00000000d-08 ,  1.20000000d-07 /
      data f(13,23) /           0.00000000d+00 /
      data f(14, 1),f(14, 2) /  0.00000000d+00 , -2.50000000d-07 /
      data f(14, 3),f(14, 4) / -2.60000000d-07 , -1.63000000d-06 /
      data f(14, 5),f(14, 6) /  3.40000000d-07 , -4.35000000d-06 /
      data f(14, 7),f(14, 8) / -5.68000000d-06 , -3.59000000d-06 /
      data f(14, 9),f(14,10) / -1.36000000d-06 , -1.20000000d-07 /
      data f(14,11),f(14,12) / -5.00000000d-08 , -3.00000000d-08 /
      data f(14,13),f(14,14) /  1.70000000d-07 ,  0.00000000d+00 /
      data f(14,15),f(14,16) / -1.00000000d-08 , -1.10000000d-07 /
      data f(14,17),f(14,18) /  6.00000000d-08 ,  3.00000000d-08 /
      data f(14,19),f(14,20) / -9.00000000d-08 , -2.00000000d-08 /
      data f(14,21),f(14,22) /  1.80000000d-07 ,  0.00000000d+00 /
      data f(14,23) /           0.00000000d+00 /
      data f(15, 1),f(15, 2) /  0.00000000d+00 ,  1.20000000d-07 /
      data f(15, 3),f(15, 4) / -7.80000000d-07 , -5.00000000d-08 /
      data f(15, 5),f(15, 6) / -7.10000000d-07 , -2.35000000d-06 /
      data f(15, 7),f(15, 8) / -2.86000000d-06 , -1.78000000d-06 /
      data f(15, 9),f(15,10) / -7.40000000d-07 , -7.00000000d-08 /
      data f(15,11),f(15,12) /  1.00000000d-07 , -5.00000000d-08 /
      data f(15,13),f(15,14) / -3.80000000d-07 ,  6.00000000d-08 /
      data f(15,15),f(15,16) /  5.00000000d-08 , -2.00000000d-08 /
      data f(15,17),f(15,18) / -8.00000000d-08 , -1.00000000d-07 /
      data f(15,19),f(15,20) / -5.00000000d-08 , -3.00000000d-08 /
      data f(15,21),f(15,22) / -3.60000000d-07 ,  6.00000000d-08 /
      data f(15,23) /           0.00000000d+00 /
      data f(16, 1),f(16, 2) /  0.00000000d+00 , -1.60000000d-07 /
      data f(16, 3),f(16, 4) / -1.10000000d-07 , -3.80000000d-07 /
      data f(16, 5),f(16, 6) / -6.50000000d-07 , -1.26000000d-06 /
      data f(16, 7),f(16, 8) / -1.39000000d-06 , -8.70000000d-07 /
      data f(16, 9),f(16,10) / -4.20000000d-07 , -7.00000000d-08 /
      data f(16,11),f(16,12) / -1.30000000d-07 , -4.00000000d-08 /
      data f(16,13),f(16,14) /  0.00000000d+00 ,  6.00000000d-08 /
      data f(16,15),f(16,16) /  9.00000000d-08 ,  7.00000000d-08 /
      data f(16,17),f(16,18) / -2.00000000d-08 , -3.00000000d-08 /
      data f(16,19),f(16,20) / -4.00000000d-08 , -2.00000000d-08 /
      data f(16,21),f(16,22) /  5.20000000d-07 ,  6.00000000d-08 /
      data f(16,23) /           0.00000000d+00 /
      data f(17, 1),f(17, 2) /  0.00000000d+00 , -1.40000000d-07 /
      data f(17, 3),f(17, 4) / -4.00000000d-07 , -6.40000000d-07 /
      data f(17, 5),f(17, 6) / -4.60000000d-07 , -4.90000000d-07 /
      data f(17, 7),f(17, 8) / -5.10000000d-07 , -3.20000000d-07 /
      data f(17, 9),f(17,10) / -2.00000000d-07 , -6.00000000d-08 /
      data f(17,11),f(17,12) /  0.00000000d+00 ,  7.00000000d-08 /
      data f(17,13),f(17,14) /  0.00000000d+00 , -4.70000000d-07 /
      data f(17,15),f(17,16) /  4.00000000d-08 , -1.00000000d-07 /
      data f(17,17),f(17,18) /  6.00000000d-08 , -3.00000000d-08 /
      data f(17,19),f(17,20) / -4.00000000d-08 ,  1.00000000d-07 /
      data f(17,21),f(17,22) / -1.00000000d-08 ,  2.00000000d-08 /
      data f(17,23) /           0.00000000d+00 /
      data f(18, 1),f(18, 2) /  0.00000000d+00 , -9.00000000d-08 /
      data f(18, 3),f(18, 4) / -2.80000000d-07 , -4.40000000d-07 /
      data f(18, 5),f(18, 6) / -2.00000000d-07 , -2.70000000d-07 /
      data f(18, 7),f(18, 8) / -2.40000000d-07 , -1.50000000d-07 /
      data f(18, 9),f(18,10) / -8.00000000d-08 ,  2.30000000d-07 /
      data f(18,11),f(18,12) /  2.00000000d-08 ,  3.00000000d-08 /
      data f(18,13),f(18,14) /  3.00000000d-08 , -3.00000000d-08 /
      data f(18,15),f(18,16) / -2.00000000d-08 , -1.60000000d-07 /
      data f(18,17),f(18,18) / -1.00000000d-08 ,  1.10000000d-07 /
      data f(18,19),f(18,20) /  1.20000000d-07 ,  2.80000000d-07 /
      data f(18,21),f(18,22) / -4.00000000d-08 ,  8.00000000d-08 /
      data f(18,23) /           0.00000000d+00 /
      data f(19, 1),f(19, 2) /  0.00000000d+00 ,  4.00000000d-08 /
      data f(19, 3),f(19, 4) / -2.00000000d-07 , -8.70000000d-07 /
      data f(19, 5),f(19, 6) / -4.60000000d-07 , -1.40000000d-07 /
      data f(19, 7),f(19, 8) / -3.00000000d-08 , -1.00000000d-08 /
      data f(19, 9),f(19,10) / -1.20000000d-07 ,  2.00000000d-08 /
      data f(19,11),f(19,12) / -2.00000000d-08 ,  2.00000000d-08 /
      data f(19,13),f(19,14) /  1.00000000d-08 , -3.00000000d-08 /
      data f(19,15),f(19,16) /  2.00000000d-08 ,  1.30000000d-07 /
      data f(19,17),f(19,18) / -2.00000000d-08 ,  9.00000000d-08 /
      data f(19,19),f(19,20) /  1.10000000d-07 , -2.80000000d-07 /
      data f(19,21),f(19,22) /  6.00000000d-08 ,  1.00000000d-07 /
      data f(19,23) /           0.00000000d+00 /
      data f(20, 1),f(20, 2) /  0.00000000d+00 ,  1.10000000d-07 /
      data f(20, 3),f(20, 4) / -6.00000000d-08 , -1.70000000d-07 /
      data f(20, 5),f(20, 6) / -8.10000000d-07 , -2.20000000d-07 /
      data f(20, 7),f(20, 8) / -2.20000000d-07 ,  4.30000000d-07 /
      data f(20, 9),f(20,10) /  5.30000000d-07 , -1.00000000d-08 /
      data f(20,11),f(20,12) /  1.00000000d-07 , -7.00000000d-08 /
      data f(20,13),f(20,14) / -4.00000000d-08 , -3.00000000d-08 /
      data f(20,15),f(20,16) /  1.00000000d-08 , -5.00000000d-08 /
      data f(20,17),f(20,18) / -2.00000000d-08 , -1.00000000d-07 /
      data f(20,19),f(20,20) / -1.30000000d-07 ,  3.00000000d-08 /
      data f(20,21),f(20,22) / -1.00000000d-08 ,  3.00000000d-08 /
      data f(20,23) /           0.00000000d+00 /
      data f(21, 1),f(21, 2) /  0.00000000d+00 ,  1.60000000d-07 /
      data f(21, 3),f(21, 4) / -6.00000000d-08 , -9.00000000d-08 /
      data f(21, 5),f(21, 6) / -7.00000000d-08 , -6.00000000d-08 /
      data f(21, 7),f(21, 8) /  5.00000000d-08 ,  1.00000000d-08 /
      data f(21, 9),f(21,10) /  4.00000000d-08 , -5.00000000d-08 /
      data f(21,11),f(21,12) / -3.00000000d-08 ,  1.00000000d-08 /
      data f(21,13),f(21,14) / -3.00000000d-08 ,  6.00000000d-08 /
      data f(21,15),f(21,16) /  0.00000000d+00 ,  0.00000000d+00 /
      data f(21,17),f(21,18) /  0.00000000d+00 ,  1.00000000d-08 /
      data f(21,19),f(21,20) /  5.00000000d-08 ,  0.00000000d+00 /
      data f(21,21),f(21,22) /  0.00000000d+00 , -3.80000000d-07 /
      data f(21,23) /           0.00000000d+00 /
      data f(22, 1),f(22, 2) /  0.00000000d+00 ,  7.00000000d-08 /
      data f(22, 3),f(22, 4) /  1.80000000d-07 , -1.27000000d-06 /
      data f(22, 5),f(22, 6) /  2.50000000d-07 , -4.00000000d-08 /
      data f(22, 7),f(22, 8) / -1.80000000d-07 , -1.00000000d-07 /
      data f(22, 9),f(22,10) / -6.00000000d-08 , -2.90000000d-07 /
      data f(22,11),f(22,12) / -9.00000000d-08 ,  0.00000000d+00 /
      data f(22,13),f(22,14) /  2.00000000d-08 , -2.00000000d-08 /
      data f(22,15),f(22,16) /  0.00000000d+00 ,  0.00000000d+00 /
      data f(22,17),f(22,18) /  0.00000000d+00 ,  0.00000000d+00 /
      data f(22,19),f(22,20) /  0.00000000d+00 ,  0.00000000d+00 /
      data f(22,21),f(22,22) /  0.00000000d+00 ,  3.00000000d-08 /
      data f(22,23) /           0.00000000d+00 /
      data f(23, 1),f(23, 2) /  0.00000000d+00 ,  7.00000000d-08 /
      data f(23, 3),f(23, 4) / -3.20000000d-07 , -3.00000000d-08 /
      data f(23, 5),f(23, 6) / -1.00000000d-08 ,  6.00000000d-08 /
      data f(23, 7),f(23, 8) /  1.00000000d-08 ,  0.00000000d+00 /
      data f(23, 9),f(23,10) /  3.00000000d-08 , -4.00000000d-08 /
      data f(23,11),f(23,12) /  0.00000000d+00 ,  0.00000000d+00 /
      data f(23,13),f(23,14) /  2.00000000d-08 , -1.00000000d-08 /
      data f(23,15),f(23,16) /  0.00000000d+00 ,  0.00000000d+00 /
      data f(23,17),f(23,18) /  0.00000000d+00 ,  0.00000000d+00 /
      data f(23,19),f(23,20) /  0.00000000d+00 ,  0.00000000d+00 /
      data f(23,21),f(23,22) /  0.00000000d+00 ,  3.00000000d-08 /
      data f(23,23) /           0.00000000d+00 /
      data f(24, 1),f(24, 2) /  0.00000000d+00 ,  3.00000000d-08 /
      data f(24, 3),f(24, 4) /  8.00000000d-08 ,  4.00000000d-08 /
      data f(24, 5),f(24, 6) / -2.00000000d-08 ,  0.00000000d+00 /
      data f(24, 7),f(24, 8) /  1.00000000d-08 ,  2.00000000d-08 /
      data f(24, 9),f(24,10) /  0.00000000d+00 ,  0.00000000d+00 /
      data f(24,11),f(24,12) /  0.00000000d+00 ,  0.00000000d+00 /
      data f(24,13),f(24,14) /  0.00000000d+00 , -1.00000000d-08 /
      data f(24,15),f(24,16) /  1.00000000d-08 ,  0.00000000d+00 /
      data f(24,17),f(24,18) /  0.00000000d+00 ,  0.00000000d+00 /
      data f(24,19),f(24,20) /  0.00000000d+00 ,  0.00000000d+00 /
      data f(24,21),f(24,22) /  0.00000000d+00 ,  1.00000000d-08 /
      data f(24,23) /           0.00000000d+00 /
      data f(25, 1),f(25, 2) /  0.00000000d+00 ,  0.00000000d+00 /
      data f(25, 3),f(25, 4) /  0.00000000d+00 , -1.00000000d-08 /
      data f(25, 5),f(25, 6) /  1.00000000d-08 , -1.00000000d-08 /
      data f(25, 7),f(25, 8) / -1.00000000d-08 ,  4.00000000d-08 /
      data f(25, 9),f(25,10) / -1.00000000d-08 ,  0.00000000d+00 /
      data f(25,11),f(25,12) /  1.00000000d-08 ,  0.00000000d+00 /
      data f(25,13),f(25,14) /  1.00000000d-08 , -8.00000000d-08 /
      data f(25,15),f(25,16) /  0.00000000d+00 ,  0.00000000d+00 /
      data f(25,17),f(25,18) / -1.00000000d-08 ,  0.00000000d+00 /
      data f(25,19),f(25,20) /  0.00000000d+00 ,  0.00000000d+00 /
      data f(25,21),f(25,22) /  0.00000000d+00 ,  1.00000000d-08 /
      data f(25,23) /           0.00000000d+00 /
      data f(26, 1),f(26, 2) /  0.00000000d+00 ,  2.00000000d-08 /
      data f(26, 3),f(26, 4) /  0.00000000d+00 ,  1.00000000d-08 /
      data f(26, 5),f(26, 6) / -1.00000000d-08 ,  2.00000000d-08 /
      data f(26, 7),f(26, 8) /  1.00000000d-08 ,  0.00000000d+00 /
      data f(26, 9),f(26,10) /  0.00000000d+00 ,  1.00000000d-08 /
      data f(26,11),f(26,12) / -1.00000000d-08 ,  0.00000000d+00 /
      data f(26,13),f(26,14) /  0.00000000d+00 ,  7.00000000d-08 /
      data f(26,15),f(26,16) /  0.00000000d+00 ,  0.00000000d+00 /
      data f(26,17),f(26,18) /  0.00000000d+00 ,  0.00000000d+00 /
      data f(26,19),f(26,20) / -1.00000000d-08 ,  0.00000000d+00 /
      data f(26,21),f(26,22) /  0.00000000d+00 ,  1.00000000d-08 /
      data f(26,23) /           0.00000000d+00 /
      data f(27, 1),f(27, 2) /  0.00000000d+00 ,  0.00000000d+00 /
      data f(27, 3),f(27, 4) /  1.00000000d-08 ,  1.00000000d-08 /
      data f(27, 5),f(27, 6) /  0.00000000d+00 ,  0.00000000d+00 /
      data f(27, 7),f(27, 8) /  0.00000000d+00 ,  0.00000000d+00 /
      data f(27, 9),f(27,10) /  0.00000000d+00 ,  0.00000000d+00 /
      data f(27,11),f(27,12) /  0.00000000d+00 ,  0.00000000d+00 /
      data f(27,13),f(27,14) /  0.00000000d+00 ,  1.00000000d-08 /
      data f(27,15),f(27,16) / -1.00000000d-08 ,  0.00000000d+00 /
      data f(27,17),f(27,18) / -1.00000000d-08 , -1.00000000d-08 /
      data f(27,19),f(27,20) /  0.00000000d+00 , -1.00000000d-08 /
      data f(27,21),f(27,22) /  0.00000000d+00 , -1.00000000d-08 /
      data f(27,23) /           0.00000000d+00 /
      data f(28, 1),f(28, 2) /  0.00000000d+00 , -1.00000000d-08 /
      data f(28, 3),f(28, 4) /  0.00000000d+00 ,  0.00000000d+00 /
      data f(28, 5),f(28, 6) /  0.00000000d+00 ,  0.00000000d+00 /
      data f(28, 7),f(28, 8) /  0.00000000d+00 ,  0.00000000d+00 /
      data f(28, 9),f(28,10) /  0.00000000d+00 ,  0.00000000d+00 /
      data f(28,11),f(28,12) /  0.00000000d+00 , -1.00000000d-08 /
      data f(28,13),f(28,14) /  3.00000000d-08 ,  5.00000000d-08 /
      data f(28,15),f(28,16) / -1.00000000d-08 , -1.00000000d-08 /
      data f(28,17),f(28,18) /  0.00000000d+00 ,  0.00000000d+00 /
      data f(28,19),f(28,20) /  0.00000000d+00 , -1.00000000d-08 /
      data f(28,21),f(28,22) / -5.00000000d-08 ,  1.00000000d-08 /
      data f(28,23) /           0.00000000d+00 /
 
      data fpp( 1, 1,1),fpp( 1, 1,2)/ 0.00000000d+00,-4.43285860d-05/
      data fpp( 1, 2,1),fpp( 1, 2,2)/-4.01821050d-05,-3.33908279d-05/
      data fpp( 1, 3,1),fpp( 1, 3,2)/-7.30912375d-04, 1.77608698d-04/
      data fpp( 1, 4,1),fpp( 1, 4,2)/ 3.89380195d-01,-3.11607963d-04/
      data fpp( 1, 5,1),fpp( 1, 5,2)/-1.48203287d-01, 2.11173554d-04/
      data fpp( 1, 6,1),fpp( 1, 6,2)/-2.92635777d-02,-1.18325451d-04/
      data fpp( 1, 7,1),fpp( 1, 7,2)/-8.86594517d-02, 1.89031451d-04/
      data fpp( 1, 8,1),fpp( 1, 8,2)/ 9.31650313d-02,-1.77965154d-04/
      data fpp( 1, 9,1),fpp( 1, 9,2)/-5.13808413d-02, 7.39259652d-05/
      data fpp( 1,10,1),fpp( 1,10,2)/ 4.39589751d-03,-2.48319186d-05/
      data fpp( 1,11,1),fpp( 1,11,2)/ 4.47576057d-03, 2.14450922d-06/
      data fpp( 1,12,1),fpp( 1,12,2)/ 1.79525375d-04,-8.12518266d-07/
      data fpp( 1,13,1),fpp( 1,13,2)/ 7.65701472d-04, 6.46563845d-07/
      data fpp( 1,14,1),fpp( 1,14,2)/ 1.12863117d-04, 1.27662888d-07/
      data fpp( 1,15,1),fpp( 1,15,2)/ 7.58557462d-05,-7.24015395d-07/
      data fpp( 1,16,1),fpp( 1,16,2)/ 1.80956729d-03, 1.07939869d-06/
      data fpp( 1,17,1),fpp( 1,17,2)/ 8.13841505d-04,-5.64179380d-07/
      data fpp( 1,18,1),fpp( 1,18,2)/ 7.62530101d-04, 4.90318827d-07/
      data fpp( 1,19,1),fpp( 1,19,2)/-1.98104749d-04,-3.78295929d-07/
      data fpp( 1,20,1),fpp( 1,20,2)/-1.13151122d-04, 4.06488815d-09/
      data fpp( 1,21,1),fpp( 1,21,2)/-2.42109021d-04, 5.36363763d-08/
      data fpp( 1,22,1),fpp( 1,22,2)/ 1.93730391d-05,-2.30103932d-08/
      data fpp( 1,23,1),fpp( 1,23,2)/ 0.00000000d+00,-6.35948034d-08/
      data fpp( 2, 1,1),fpp( 2, 1,2)/ 0.00000000d+00, 1.84022829d-05/
      data fpp( 2, 2,1),fpp( 2, 2,2)/-3.63579001d-06, 1.88983426d-06/
      data fpp( 2, 3,1),fpp( 2, 3,2)/-1.66917525d-03,-2.38400199d-05/
      data fpp( 2, 4,1),fpp( 2, 4,2)/ 1.94170610d-01,-1.73089546d-05/
      data fpp( 2, 5,1),fpp( 2, 5,2)/-6.31704259d-02, 3.44702384d-05/
      data fpp( 2, 6,1),fpp( 2, 6,2)/-4.17278446d-02, 1.19944010d-05/
      data fpp( 2, 7,1),fpp( 2, 7,2)/-6.24010966d-02,-4.07824227d-06/
      data fpp( 2, 8,1),fpp( 2, 8,2)/ 5.76339374d-02,-3.83031874d-07/
      data fpp( 2, 9,1),fpp( 2, 9,2)/-1.98483174d-02, 8.01516977d-06/
      data fpp( 2,10,1),fpp( 2,10,2)/ 2.72520499d-03,-7.83399337d-06/
      data fpp( 2,11,1),fpp( 2,11,2)/ 2.95147886d-03,-1.14359629d-06/
      data fpp( 2,12,1),fpp( 2,12,2)/ 3.25949251d-04,-2.55221475d-07/
      data fpp( 2,13,1),fpp( 2,13,2)/ 4.91597056d-04, 4.79082190d-07/
      data fpp( 2,14,1),fpp( 2,14,2)/ 5.82737665d-05, 3.50927171d-08/
      data fpp( 2,15,1),fpp( 2,15,2)/ 6.02885077d-05,-6.27253058d-07/
      data fpp( 2,16,1),fpp( 2,16,2)/ 9.40865413d-04, 9.11519515d-07/
      data fpp( 2,17,1),fpp( 2,17,2)/ 5.27316991d-04,-3.02625003d-07/
      data fpp( 2,18,1),fpp( 2,18,2)/ 2.37939797d-04, 2.04780497d-07/
      data fpp( 2,19,1),fpp( 2,19,2)/-1.28790503d-04,-2.64496984d-07/
      data fpp( 2,20,1),fpp( 2,20,2)/-5.26977559d-05, 4.20074390d-08/
      data fpp( 2,21,1),fpp( 2,21,2)/-1.40781958d-04,-6.73277204d-09/
      data fpp( 2,22,1),fpp( 2,22,2)/ 9.25392170d-06, 1.72364915d-09/
      data fpp( 2,23,1),fpp( 2,23,2)/ 0.00000000d+00,-6.16182458d-09/
      data fpp( 3, 1,1),fpp( 3, 1,2)/ 0.00000000d+00, 2.93942201d-05/
      data fpp( 3, 2,1),fpp( 3, 2,2)/-4.12747350d-05,-6.33044024d-06/
      data fpp( 3, 3,1),fpp( 3, 3,2)/-4.21438662d-03,-4.11805915d-06/
      data fpp( 3, 4,1),fpp( 3, 4,2)/-1.15444636d-01,-1.34685323d-04/
      data fpp( 3, 5,1),fpp( 3, 5,2)/-1.79093009d-01, 2.06163352d-04/
      data fpp( 3, 6,1),fpp( 3, 6,2)/-4.58950438d-02,-5.21944841d-05/
      data fpp( 3, 7,1),fpp( 3, 7,2)/-1.21456162d-01, 1.02273846d-05/
      data fpp( 3, 8,1),fpp( 3, 8,2)/ 9.37312190d-02,-2.00326541d-05/
      data fpp( 3, 9,1),fpp( 3, 9,2)/ 1.36774111d-01, 8.18243199d-06/
      data fpp( 3,10,1),fpp( 3,10,2)/-8.22271746d-03,-8.06056891d-06/
      data fpp( 3,11,1),fpp( 3,11,2)/ 1.49632399d-03,-6.48756336d-07/
      data fpp( 3,12,1),fpp( 3,12,2)/ 6.10677622d-04,-2.44005741d-07/
      data fpp( 3,13,1),fpp( 3,13,2)/ 1.65910303d-04, 3.61779300d-07/
      data fpp( 3,14,1),fpp( 3,14,2)/-4.59581827d-05,-5.23114601d-08/
      data fpp( 3,15,1),fpp( 3,15,2)/ 3.09902232d-05,-3.36733460d-07/
      data fpp( 3,16,1),fpp( 3,16,2)/ 2.10971055d-04, 5.02245300d-07/
      data fpp( 3,17,1),fpp( 3,17,2)/ 9.46890532d-04,-4.24773898d-09/
      data fpp( 3,18,1),fpp( 3,18,2)/-7.00289291d-04,-8.08543438d-08/
      data fpp( 3,19,1),fpp( 3,19,2)/-4.87332403d-05,-7.91348858d-08/
      data fpp( 3,20,1),fpp( 3,20,2)/ 6.59421457d-05, 2.17938869d-08/
      data fpp( 3,21,1),fpp( 3,21,2)/-4.76314607d-06,-1.16406619d-08/
      data fpp( 3,22,1),fpp( 3,22,2)/-2.03887260d-05, 2.56876053d-09/
      data fpp( 3,23,1),fpp( 3,23,2)/ 0.00000000d+00, 3.16561973d-09/
      data fpp( 4, 1,1),fpp( 4, 1,2)/ 0.00000000d+00, 5.25538528d-05/
      data fpp( 4, 2,1),fpp( 4, 2,2)/ 1.80734730d-04,-1.17265056d-05/
      data fpp( 4, 3,1),fpp( 4, 3,2)/-1.13527826d-03,-1.57350304d-05/
      data fpp( 4, 4,1),fpp( 4, 4,2)/-2.46400650d-02,-2.30694973d-04/
      data fpp( 4, 5,1),fpp( 4, 5,2)/ 4.08328463d-01, 4.01176521d-04/
      data fpp( 4, 6,1),fpp( 4, 6,2)/-7.91019800d-02,-1.72722313d-04/
      data fpp( 4, 7,1),fpp( 4, 7,2)/ 1.18085744d-01, 1.49555130d-04/
      data fpp( 4, 8,1),fpp( 4, 8,2)/-1.20870814d-01,-1.36408606d-04/
      data fpp( 4, 9,1),fpp( 4, 9,2)/-1.44418126d-01, 1.95849287d-06/
      data fpp( 4,10,1),fpp( 4,10,2)/ 1.32996648d-02, 5.05162421d-06/
      data fpp( 4,11,1),fpp( 4,11,2)/-2.00774836d-04,-4.58798971d-06/
      data fpp( 4,12,1),fpp( 4,12,2)/ 4.11340263d-04, 1.04893463d-06/
      data fpp( 4,13,1),fpp( 4,13,2)/ 2.07617318d-05,-9.31488161d-08/
      data fpp( 4,14,1),fpp( 4,14,2)/ 2.35589643d-05, 1.66063277d-09/
      data fpp( 4,15,1),fpp( 4,15,2)/ 4.97505995d-05,-1.12693715d-07/
      data fpp( 4,16,1),fpp( 4,16,2)/-1.00474963d-03, 2.38514227d-07/
      data fpp( 4,17,1),fpp( 4,17,2)/-1.10487912d-03,-3.31631933d-08/
      data fpp( 4,18,1),fpp( 4,18,2)/-1.90782635d-04,-4.22614537d-08/
      data fpp( 4,19,1),fpp( 4,19,2)/-6.27653587d-06,-2.45909917d-08/
      data fpp( 4,20,1),fpp( 4,20,2)/-1.90708269d-05, 1.04254204d-08/
      data fpp( 4,21,1),fpp( 4,21,2)/ 9.83454253d-06,-7.51069012d-09/
      data fpp( 4,22,1),fpp( 4,22,2)/ 1.83009821d-05, 2.21734003d-09/
      data fpp( 4,23,1),fpp( 4,23,2)/ 0.00000000d+00, 4.04132998d-09/
      data fpp( 5, 1,1),fpp( 5, 1,2)/ 0.00000000d+00, 7.85827177d-05/
      data fpp( 5, 2,1),fpp( 5, 2,2)/-6.69664185d-04, 1.67605645d-05/
      data fpp( 5, 3,1),fpp( 5, 3,2)/ 1.70114997d-02,-1.62460976d-04/
      data fpp( 5, 4,1),fpp( 5, 4,2)/-4.60771037d-02, 6.92153390d-05/
      data fpp( 5, 5,1),fpp( 5, 5,2)/ 9.47991579d-02,-2.14051799d-05/
      data fpp( 5, 6,1),fpp( 5, 6,2)/-1.50409036d-01, 2.32875781d-04/
      data fpp( 5, 7,1),fpp( 5, 7,2)/-1.24028149d-02,-3.28547433d-05/
      data fpp( 5, 8,1),fpp( 5, 8,2)/ 3.93100351d-02,-1.08008808d-04/
      data fpp( 5, 9,1),fpp( 5, 9,2)/ 4.04043944d-02,-6.08122623d-06/
      data fpp( 5,10,1),fpp( 5,10,2)/-3.62994192d-03, 5.41768249d-06/
      data fpp( 5,11,1),fpp( 5,11,2)/ 2.18775348d-04,-3.95430375d-06/
      data fpp( 5,12,1),fpp( 5,12,2)/ 2.93961328d-04, 1.00353250d-06/
      data fpp( 5,13,1),fpp( 5,13,2)/ 9.30427699d-05,-1.52226236d-07/
      data fpp( 5,14,1),fpp( 5,14,2)/-1.82776744d-05, 1.72446634d-10/
      data fpp( 5,15,1),fpp( 5,15,2)/-7.99926211d-05,-1.94635509d-08/
      data fpp( 5,16,1),fpp( 5,16,2)/-2.35972523d-04, 1.22081757d-07/
      data fpp( 5,17,1),fpp( 5,17,2)/-1.45374057d-04,-5.84634776d-08/
      data fpp( 5,18,1),fpp( 5,18,2)/-1.50580169d-04,-7.62784687d-09/
      data fpp( 5,19,1),fpp( 5,19,2)/-1.61606162d-05,-5.82513495d-09/
      data fpp( 5,20,1),fpp( 5,20,2)/ 4.03411620d-05, 5.72838669d-09/
      data fpp( 5,21,1),fpp( 5,21,2)/ 7.42497595d-06,-5.08841180d-09/
      data fpp( 5,22,1),fpp( 5,22,2)/-4.81520258d-06, 1.42526051d-09/
      data fpp( 5,23,1),fpp( 5,23,2)/ 0.00000000d+00, 2.98736974d-09/
      data fpp( 6, 1,1),fpp( 6, 1,2)/ 0.00000000d+00, 1.16033083d-04/
      data fpp( 6, 2,1),fpp( 6, 2,2)/ 2.42592201d-03, 6.56170331d-05/
      data fpp( 6, 3,1),fpp( 6, 3,2)/-1.36007204d-02,-3.80704416d-04/
      data fpp( 6, 4,1),fpp( 6, 4,2)/ 1.25182480d-01, 5.58643031d-04/
      data fpp( 6, 5,1),fpp( 6, 5,2)/-4.29370945d-02,-7.44366908d-04/
      data fpp( 6, 6,1),fpp( 6, 6,2)/ 3.64232125d-01, 8.94697399d-04/
      data fpp( 6, 7,1),fpp( 6, 7,2)/ 4.97315154d-02,-3.41456290d-04/
      data fpp( 6, 8,1),fpp( 6, 8,2)/-6.59732704d-03,-4.03242408d-05/
      data fpp( 6, 9,1),fpp( 6, 9,2)/-1.26514512d-02,-1.97843471d-05/
      data fpp( 6,10,1),fpp( 6,10,2)/-5.49897154d-04, 7.54456182d-06/
      data fpp( 6,11,1),fpp( 6,11,2)/ 8.16734442d-05,-3.81610015d-06/
      data fpp( 6,12,1),fpp( 6,12,2)/ 1.34814425d-04, 1.02323877d-06/
      data fpp( 6,13,1),fpp( 6,13,2)/-2.09328114d-05,-2.07854928d-07/
      data fpp( 6,14,1),fpp( 6,14,2)/ 3.15517333d-05, 1.57809429d-08/
      data fpp( 6,15,1),fpp( 6,15,2)/-1.77801149d-05, 1.39311565d-08/
      data fpp( 6,16,1),fpp( 6,16,2)/-1.93360275d-04, 6.94944310d-08/
      data fpp( 6,17,1),fpp( 6,17,2)/-2.63624654d-04,-7.47088807d-08/
      data fpp( 6,18,1),fpp( 6,18,2)/-4.68966884d-05, 1.87410916d-08/
      data fpp( 6,19,1),fpp( 6,19,2)/-1.30809995d-05, 1.54451412d-09/
      data fpp( 6,20,1),fpp( 6,20,2)/-4.62938210d-05,-2.71914811d-09/
      data fpp( 6,21,1),fpp( 6,21,2)/-9.53444633d-06,-8.67921661d-10/
      data fpp( 6,22,1),fpp( 6,22,2)/ 9.59828195d-07, 7.90834760d-10/
      data fpp( 6,23,1),fpp( 6,23,2)/ 0.00000000d+00, 2.50458262d-09/
      data fpp( 7, 1,1),fpp( 7, 1,2)/ 0.00000000d+00, 1.07037033d-04/
      data fpp( 7, 2,1),fpp( 7, 2,2)/-3.03543393d-03, 8.07151340d-05/
      data fpp( 7, 3,1),fpp( 7, 3,2)/ 5.39091143d-03,-4.58387969d-04/
      data fpp( 7, 4,1),fpp( 7, 4,2)/-2.75128872d-02, 7.97243142d-04/
      data fpp( 7, 5,1),fpp( 7, 5,2)/-1.53879795d-01,-1.04757500d-03/
      data fpp( 7, 6,1),fpp( 7, 6,2)/-1.56967356d-01, 1.03750005d-03/
      data fpp( 7, 7,1),fpp( 7, 7,2)/-4.61216386d-02,-3.53162817d-04/
      data fpp( 7, 8,1),fpp( 7, 8,2)/ 2.00794635d-02,-4.73423864d-05/
      data fpp( 7, 9,1),fpp( 7, 9,2)/ 6.02665639d-03,-1.07204376d-05/
      data fpp( 7,10,1),fpp( 7,10,2)/-8.70337578d-04, 1.87210595d-06/
      data fpp( 7,11,1),fpp( 7,11,2)/ 9.25919935d-05,-1.34838620d-06/
      data fpp( 7,12,1),fpp( 7,12,2)/ 5.60760606d-05, 3.75038863d-07/
      data fpp( 7,13,1),fpp( 7,13,2)/ 2.07770492d-05,-6.53692479d-08/
      data fpp( 7,14,1),fpp( 7,14,2)/-4.35163626d-05,-2.41618711d-08/
      data fpp( 7,15,1),fpp( 7,15,2)/-7.16334470d-06, 3.96167321d-08/
      data fpp( 7,16,1),fpp( 7,16,2)/-2.34329139d-05, 8.49494270d-09/
      data fpp( 7,17,1),fpp( 7,17,2)/ 4.60609916d-05,-3.27965029d-08/
      data fpp( 7,18,1),fpp( 7,18,2)/ 1.04801496d-05, 1.28910689d-08/
      data fpp( 7,19,1),fpp( 7,19,2)/ 1.88233065d-05, 2.23222740d-09/
      data fpp( 7,20,1),fpp( 7,20,2)/ 2.87108821d-05,-2.19978479d-10/
      data fpp( 7,21,1),fpp( 7,21,2)/ 5.39085101d-06,-3.15231349d-09/
      data fpp( 7,22,1),fpp( 7,22,2)/-4.97188329d-06, 8.29232425d-10/
      data fpp( 7,23,1),fpp( 7,23,2)/ 0.00000000d+00, 2.83538379d-09/
      data fpp( 8, 1,1),fpp( 8, 1,2)/ 0.00000000d+00, 1.18054354d-04/
      data fpp( 8, 2,1),fpp( 8, 2,2)/ 1.90231372d-03, 5.52444926d-05/
      data fpp( 8, 3,1),fpp( 8, 3,2)/ 4.14574690d-04,-3.55402724d-04/
      data fpp( 8, 4,1),fpp( 8, 4,2)/ 7.04650690d-02, 4.51380804d-04/
      data fpp( 8, 5,1),fpp( 8, 5,2)/-2.23622237d-02,-5.43414893d-04/
      data fpp( 8, 6,1),fpp( 8, 6,2)/ 1.90911299d-01, 7.34503566d-04/
      data fpp( 8, 7,1),fpp( 8, 7,2)/ 1.37183539d-01,-2.41741771d-04/
      data fpp( 8, 8,1),fpp( 8, 8,2)/-1.52730271d-02,-1.31688482d-04/
      data fpp( 8, 9,1),fpp( 8, 9,2)/ 1.63982564d-03, 2.23332984d-05/
      data fpp( 8,10,1),fpp( 8,10,2)/-1.62752535d-04,-7.73945433d-06/
      data fpp( 8,11,1),fpp( 8,11,2)/ 2.04585817d-05, 1.66811892d-06/
      data fpp( 8,12,1),fpp( 8,12,2)/-2.11866737d-06,-4.42021335d-07/
      data fpp( 8,13,1),fpp( 8,13,2)/-6.67538529d-06, 1.29366422d-07/
      data fpp( 8,14,1),fpp( 8,14,2)/ 4.05137173d-05,-4.66443530d-08/
      data fpp( 8,15,1),fpp( 8,15,2)/-1.80665063d-05, 2.12109901d-08/
      data fpp( 8,16,1),fpp( 8,16,2)/ 8.09193030d-06, 5.60039262d-09/
      data fpp( 8,17,1),fpp( 8,17,2)/-7.61931208d-06,-1.66125606d-08/
      data fpp( 8,18,1),fpp( 8,18,2)/ 7.97608980d-06, 1.10498497d-08/
      data fpp( 8,19,1),fpp( 8,19,2)/-8.21222656d-06,-2.98683818d-09/
      data fpp( 8,20,1),fpp( 8,20,2)/-2.05497075d-05,-9.02496984d-10/
      data fpp( 8,21,1),fpp( 8,21,2)/-6.02895771d-06,-1.20317389d-09/
      data fpp( 8,22,1),fpp( 8,22,2)/ 1.74277050d-05, 9.15192540d-10/
      data fpp( 8,23,1),fpp( 8,23,2)/ 0.00000000d+00, 2.34240373d-09/
      data fpp( 9, 1,1),fpp( 9, 1,2)/ 0.00000000d+00, 8.09438232d-05/
      data fpp( 9, 2,1),fpp( 9, 2,2)/-5.32820961d-04,-7.45124649d-06/
      data fpp( 9, 3,1),fpp( 9, 3,2)/-1.06421019d-03,-5.87444373d-05/
      data fpp( 9, 4,1),fpp( 9, 4,2)/-1.38438895d-03,-2.39894204d-04/
      data fpp( 9, 5,1),fpp( 9, 5,2)/ 3.00882190d-01, 4.40902855d-04/
      data fpp( 9, 6,1),fpp( 9, 6,2)/-1.25698417d-02, 2.74315861d-05/
      data fpp( 9, 7,1),fpp( 9, 7,2)/-1.10371518d-01,-1.75650799d-04/
      data fpp( 9, 8,1),fpp( 9, 8,2)/ 1.77414500d-03, 1.98121004d-06/
      data fpp( 9, 9,1),fpp( 9, 9,2)/-2.10395895d-03,-1.42604113d-06/
      data fpp( 9,10,1),fpp( 9,10,2)/-1.64652282d-04,-5.63281634d-07/
      data fpp( 9,11,1),fpp( 9,11,2)/ 2.65736798d-05,-3.12323361d-08/
      data fpp( 9,12,1),fpp( 9,12,2)/ 1.53986089d-05, 6.61097792d-09/
      data fpp( 9,13,1),fpp( 9,13,2)/ 1.04244920d-05, 8.98842438d-09/
      data fpp( 9,14,1),fpp( 9,14,2)/-3.15385066d-05,-1.79646754d-08/
      data fpp( 9,15,1),fpp( 9,15,2)/ 1.42936982d-06, 1.42702774d-08/
      data fpp( 9,16,1),fpp( 9,16,2)/-2.24348073d-05,-2.51643399d-09/
      data fpp( 9,17,1),fpp( 9,17,2)/ 1.14162567d-05,-6.04541388d-10/
      data fpp( 9,18,1),fpp( 9,18,2)/-7.88450884d-06, 1.93459954d-09/
      data fpp( 9,19,1),fpp( 9,19,2)/-6.97440028d-06,-4.13385678d-09/
      data fpp( 9,20,1),fpp( 9,20,2)/ 1.14879477d-05, 3.20082759d-09/
      data fpp( 9,21,1),fpp( 9,21,2)/ 8.22497983d-06,-1.46945358d-09/
      data fpp( 9,22,1),fpp( 9,22,2)/-5.72389366d-05,-3.23013262d-10/
      data fpp( 9,23,1),fpp( 9,23,2)/ 0.00000000d+00,-8.38493369d-10/
      data fpp(10, 1,1),fpp(10, 1,2)/ 0.00000000d+00, 9.93145569d-06/
      data fpp(10, 2,1),fpp(10, 2,2)/ 1.34470119d-04,-1.19305114d-05/
      data fpp(10, 3,1),fpp(10, 3,2)/ 8.51266085d-04, 3.44665898d-05/
      data fpp(10, 4,1),fpp(10, 4,2)/-5.98440132d-02,-1.58043048d-04/
      data fpp(10, 5,1),fpp(10, 5,2)/-1.00995537d-01, 2.43384002d-04/
      data fpp(10, 6,1),fpp(10, 6,2)/-1.11927933d-01,-1.27907360d-04/
      data fpp(10, 7,1),fpp(10, 7,2)/ 1.13180337d-02, 3.29902397d-05/
      data fpp(10, 8,1),fpp(10, 8,2)/-1.87055286d-03,-1.88807983d-05/
      data fpp(10, 9,1),fpp(10, 9,2)/ 1.22010170d-04, 3.12015335d-06/
      data fpp(10,10,1),fpp(10,10,2)/-7.26383370d-05,-1.44826093d-06/
      data fpp(10,11,1),fpp(10,11,2)/-3.75330104d-06, 3.11290361d-07/
      data fpp(10,12,1),fpp(10,12,2)/-5.47576825d-06,-8.55005141d-08/
      data fpp(10,13,1),fpp(10,13,2)/-1.70225826d-05, 2.29116958d-08/
      data fpp(10,14,1),fpp(10,14,2)/ 1.81403091d-05,-5.54626918d-09/
      data fpp(10,15,1),fpp(10,15,2)/ 3.34902701d-06,-4.32661910d-09/
      data fpp(10,16,1),fpp(10,16,2)/ 2.76472991d-05, 1.08527456d-08/
      data fpp(10,17,1),fpp(10,17,2)/-5.04571473d-06,-6.08436320d-09/
      data fpp(10,18,1),fpp(10,18,2)/ 4.06194554d-06, 1.48470724d-09/
      data fpp(10,19,1),fpp(10,19,2)/ 7.60982768d-06,-1.05446575d-09/
      data fpp(10,20,1),fpp(10,20,2)/-4.40208330d-06, 5.13315577d-09/
      data fpp(10,21,1),fpp(10,21,2)/-1.03709616d-05,-1.88781573d-08/
      data fpp(10,22,1),fpp(10,22,2)/ 9.45280415d-05, 1.75794735d-08/
      data fpp(10,23,1),fpp(10,23,2)/ 0.00000000d+00, 3.67602632d-08/
      data fpp(11, 1,1),fpp(11, 1,2)/ 0.00000000d+00,-8.24040332d-06/
      data fpp(11, 2,1),fpp(11, 2,2)/-3.20595159d-05, 9.64200664d-06/
      data fpp(11, 3,1),fpp(11, 3,2)/-3.02785415d-03,-3.03828232d-05/
      data fpp(11, 4,1),fpp(11, 4,2)/-9.16805806d-03, 1.32267686d-04/
      data fpp(11, 5,1),fpp(11, 5,2)/-1.29859041d-01,-2.03975122d-04/
      data fpp(11, 6,1),fpp(11, 6,2)/-1.31394271d-02, 9.57648024d-05/
      data fpp(11, 7,1),fpp(11, 7,2)/-6.34111640d-03, 3.33511276d-06/
      data fpp(11, 8,1),fpp(11, 8,2)/ 2.03066424d-04,-3.24125338d-06/
      data fpp(11, 9,1),fpp(11, 9,2)/-3.13081727d-04, 1.81100755d-07/
      data fpp(11,10,1),fpp(11,10,2)/-3.22943701d-05,-4.12475576d-07/
      data fpp(11,11,1),fpp(11,11,2)/ 1.09395243d-05, 8.34015474d-08/
      data fpp(11,12,1),fpp(11,12,2)/ 3.50446410d-06,-3.09306140d-08/
      data fpp(11,13,1),fpp(11,13,2)/ 1.41658385d-05, 1.45209088d-08/
      data fpp(11,14,1),fpp(11,14,2)/-8.02272978d-06,-3.75302110d-09/
      data fpp(11,15,1),fpp(11,15,2)/-1.93254779d-05,-3.70882440d-09/
      data fpp(11,16,1),fpp(11,16,2)/-2.06543889d-05, 1.78831868d-09/
      data fpp(11,17,1),fpp(11,17,2)/ 7.26660221d-06, 2.55554968d-09/
      data fpp(11,18,1),fpp(11,18,2)/-8.63273330d-07,-1.81051738d-09/
      data fpp(11,19,1),fpp(11,19,2)/-2.46491043d-06, 1.08651985d-09/
      data fpp(11,20,1),fpp(11,20,2)/ 1.20385497d-07,-2.53556202d-09/
      data fpp(11,21,1),fpp(11,21,2)/ 7.75886667d-06, 6.05572824d-09/
      data fpp(11,22,1),fpp(11,22,2)/-7.03732293d-05,-6.08735092d-09/
      data fpp(11,23,1),fpp(11,23,2)/ 0.00000000d+00,-1.23063245d-08/
      data fpp(12, 1,1),fpp(12, 1,2)/ 0.00000000d+00,-2.45221779d-06/
      data fpp(12, 2,1),fpp(12, 2,2)/ 1.47679446d-05, 7.24763557d-06/
      data fpp(12, 3,1),fpp(12, 3,2)/ 3.14965050d-03,-3.63687245d-05/
      data fpp(12, 4,1),fpp(12, 4,2)/ 1.49807455d-02, 1.06621662d-04/
      data fpp(12, 5,1),fpp(12, 5,2)/ 3.43862024d-02,-1.36106725d-04/
      data fpp(12, 6,1),fpp(12, 6,2)/ 9.43814139d-03, 7.12964386d-05/
      data fpp(12, 7,1),fpp(12, 7,2)/-1.84068038d-04,-1.32750290d-05/
      data fpp(12, 8,1),fpp(12, 8,2)/-3.24712840d-04, 3.60767744d-06/
      data fpp(12, 9,1),fpp(12, 9,2)/-1.32683262d-04,-1.00448076d-06/
      data fpp(12,10,1),fpp(12,10,2)/-2.01841828d-05, 7.86035649d-08/
      data fpp(12,11,1),fpp(12,11,2)/-4.00479615d-06,-3.23334978d-08/
      data fpp(12,12,1),fpp(12,12,2)/-7.04208817d-06, 2.73042649d-09/
      data fpp(12,13,1),fpp(12,13,2)/-6.64077148d-06, 4.01179190d-09/
      data fpp(12,14,1),fpp(12,14,2)/ 1.95061001d-06,-3.17759407d-09/
      data fpp(12,15,1),fpp(12,15,2)/ 1.24528845d-05, 2.09858439d-09/
      data fpp(12,16,1),fpp(12,16,2)/ 8.47025658d-06,-1.01674350d-09/
      data fpp(12,17,1),fpp(12,17,2)/-7.52069411d-06, 1.68389622d-10/
      data fpp(12,18,1),fpp(12,18,2)/-2.10885222d-06, 3.43185016d-10/
      data fpp(12,19,1),fpp(12,19,2)/-7.50185945d-07,-9.41129687d-10/
      data fpp(12,20,1),fpp(12,20,2)/-2.07945869d-06, 4.21333730d-10/
      data fpp(12,21,1),fpp(12,21,2)/-7.16450507d-06, 1.65579476d-09/
      data fpp(12,22,1),fpp(12,22,2)/ 2.19648758d-05,-2.24451279d-09/
      data fpp(12,23,1),fpp(12,23,2)/ 0.00000000d+00,-4.67774361d-09/
      data fpp(13, 1,1),fpp(13, 1,2)/ 0.00000000d+00, 2.24509963d-06/
      data fpp(13, 2,1),fpp(13, 2,2)/-1.88534714d-05, 1.77260074d-06/
      data fpp(13, 3,1),fpp(13, 3,2)/-1.62459891d-03,-9.21310258d-06/
      data fpp(13, 4,1),fpp(13, 4,2)/-4.81611293d-03, 1.65974096d-05/
      data fpp(13, 5,1),fpp(13, 5,2)/ 1.61468630d-03,-1.36069358d-05/
      data fpp(13, 6,1),fpp(13, 6,2)/-1.99418652d-03, 4.76073353d-06/
      data fpp(13, 7,1),fpp(13, 7,2)/-3.03362270d-04,-3.76798330d-07/
      data fpp(13, 8,1),fpp(13, 8,2)/-7.53348174d-05, 3.63259793d-07/
      data fpp(13, 9,1),fpp(13, 9,2)/-6.40013074d-05,-2.57840840d-07/
      data fpp(13,10,1),fpp(13,10,2)/ 2.47685592d-06, 1.16926241d-08/
      data fpp(13,11,1),fpp(13,11,2)/-1.94369571d-06,-1.21296562d-08/
      data fpp(13,12,1),fpp(13,12,2)/ 8.47065115d-06, 6.82600085d-09/
      data fpp(13,13,1),fpp(13,13,2)/ 1.33586793d-05,-3.77434715d-09/
      data fpp(13,14,1),fpp(13,14,2)/ 1.84645315d-06, 2.27138776d-09/
      data fpp(13,15,1),fpp(13,15,2)/-5.29262970d-06, 6.88796124d-10/
      data fpp(13,16,1),fpp(13,16,2)/-9.79792933d-06,-4.42657225d-09/
      data fpp(13,17,1),fpp(13,17,2)/ 6.55791223d-06, 3.81749288d-09/
      data fpp(13,18,1),fpp(13,18,2)/ 3.27168962d-06,-1.24339928d-09/
      data fpp(13,19,1),fpp(13,19,2)/-1.18943989d-06,-1.24389577d-09/
      data fpp(13,20,1),fpp(13,20,2)/ 4.18460531d-06, 2.01898237d-09/
      data fpp(13,21,1),fpp(13,21,2)/ 1.63757724d-05, 1.56796628d-09/
      data fpp(13,22,1),fpp(13,22,2)/-9.63409990d-06,-2.89084751d-09/
      data fpp(13,23,1),fpp(13,23,2)/ 0.00000000d+00,-6.20457625d-09/
      data fpp(14, 1,1),fpp(14, 1,2)/ 0.00000000d+00, 5.39541832d-08/
      data fpp(14, 2,1),fpp(14, 2,2)/ 3.06459411d-05, 4.88916336d-08/
      data fpp(14, 3,1),fpp(14, 3,2)/ 5.06078460d-04,-1.91920718d-07/
      data fpp(14, 4,1),fpp(14, 4,2)/ 2.63728780d-05, 3.92391237d-07/
      data fpp(14, 5,1),fpp(14, 5,2)/ 5.90524438d-05,-5.76044231d-07/
      data fpp(14, 6,1),fpp(14, 6,2)/ 7.23938029d-04, 3.13385688d-07/
      data fpp(14, 7,1),fpp(14, 7,2)/ 8.50451639d-07, 1.28901481d-07/
      data fpp(14, 8,1),fpp(14, 8,2)/-7.72812243d-05,-8.19161210d-09/
      data fpp(14, 9,1),fpp(14, 9,2)/-2.46448413d-05,-6.25350328d-08/
      data fpp(14,10,1),fpp(14,10,2)/-5.05657424d-06,-1.49909566d-09/
      data fpp(14,11,1),fpp(14,11,2)/ 9.77957897d-06,-1.66858460d-09/
      data fpp(14,12,1),fpp(14,12,2)/-5.50718311d-06, 5.17343407d-09/
      data fpp(14,13,1),fpp(14,13,2)/-3.47939456d-05,-8.22515168d-09/
      data fpp(14,14,1),fpp(14,14,2)/-6.69755957d-07, 5.52717266d-09/
      data fpp(14,15,1),fpp(14,15,2)/ 4.05096766d-06,-4.28353897d-09/
      data fpp(14,16,1),fpp(14,16,2)/ 1.00547941d-05, 6.20698323d-09/
      data fpp(14,17,1),fpp(14,17,2)/-1.00442881d-05,-4.34439396d-09/
      data fpp(14,18,1),fpp(14,18,2)/-7.64457294d-06,-8.29407392d-10/
      data fpp(14,19,1),fpp(14,19,2)/ 3.50794552d-06, 2.26202353d-09/
      data fpp(14,20,1),fpp(14,20,2)/-3.32562920d-06, 3.18131328d-09/
      data fpp(14,21,1),fpp(14,21,2)/-4.10052514d-05,-7.18727665d-09/
      data fpp(14,22,1),fpp(14,22,2)/ 7.90485709d-06, 2.76779333d-09/
      data fpp(14,23,1),fpp(14,23,2)/ 0.00000000d+00, 6.91610334d-09/
      data fpp(15, 1,1),fpp(15, 1,2)/ 0.00000000d+00,-1.36109835d-07/
      data fpp(15, 2,1),fpp(15, 2,2)/-3.64494981d-05,-6.21803300d-08/
      data fpp(15, 3,1),fpp(15, 3,2)/-7.84939377d-05, 1.40031155d-07/
      data fpp(15, 4,1),fpp(15, 4,2)/-8.26950022d-05,-1.06744290d-07/
      data fpp(15, 5,1),fpp(15, 5,2)/ 2.82083350d-05,-4.66539942d-08/
      data fpp(15, 6,1),fpp(15, 6,2)/-2.23410365d-04, 5.81602670d-08/
      data fpp(15, 7,1),fpp(15, 7,2)/-4.72088531d-05, 8.52129261d-08/
      data fpp(15, 8,1),fpp(15, 8,2)/-1.10916525d-05,-1.74119715d-08/
      data fpp(15, 9,1),fpp(15, 9,2)/-3.77383258d-06,-2.51650400d-08/
      data fpp(15,10,1),fpp(15,10,2)/ 6.75873017d-08,-3.98894259d-10/
      data fpp(15,11,1),fpp(15,11,2)/-2.04823513d-05,-3.23938297d-09/
      data fpp(15,12,1),fpp(15,12,2)/ 1.82993882d-06,-5.84357386d-09/
      data fpp(15,13,1),fpp(15,13,2)/ 4.94317089d-05, 1.58136784d-08/
      data fpp(15,14,1),fpp(15,14,2)/ 2.57910005d-06,-1.12111397d-08/
      data fpp(15,15,1),fpp(15,15,2)/-1.31589374d-06, 2.03088053d-09/
      data fpp(15,16,1),fpp(15,16,2)/-1.07707631d-06,-5.12382402d-10/
      data fpp(15,17,1),fpp(15,17,2)/ 1.03845724d-05, 6.18649073d-10/
      data fpp(15,18,1),fpp(15,18,2)/ 1.08153303d-05, 4.37786111d-10/
      data fpp(15,19,1),fpp(15,19,2)/-1.75556776d-06, 1.83020648d-09/
      data fpp(15,20,1),fpp(15,20,2)/ 1.85123805d-06,-9.55861205d-09/
      data fpp(15,21,1),fpp(15,21,2)/ 7.84625981d-05, 1.54042417d-08/
      data fpp(15,22,1),fpp(15,22,2)/-4.07313560d-06,-7.05835477d-09/
      data fpp(15,23,1),fpp(15,23,2)/ 0.00000000d+00,-1.59708226d-08/
      data fpp(16, 1,1),fpp(16, 1,2)/ 0.00000000d+00, 2.77474527d-08/
      data fpp(16, 2,1),fpp(16, 2,2)/ 1.76520515d-05, 1.21050945d-08/
      data fpp(16, 3,1),fpp(16, 3,2)/-1.36027090d-05,-2.57678309d-08/
      data fpp(16, 4,1),fpp(16, 4,2)/ 1.79071310d-05, 1.41662291d-08/
      data fpp(16, 5,1),fpp(16, 5,2)/-5.38578391d-06,-3.08970856d-08/
      data fpp(16, 6,1),fpp(16, 6,2)/ 3.32034309d-05, 2.78221133d-08/
      data fpp(16, 7,1),fpp(16, 7,2)/-1.45150392d-05, 3.48086326d-08/
      data fpp(16, 8,1),fpp(16, 8,2)/-1.33521659d-05,-1.10566435d-08/
      data fpp(16, 9,1),fpp(16, 9,2)/-5.25982841d-06,-7.38205846d-09/
      data fpp(16,10,1),fpp(16,10,2)/-2.71377497d-06,-5.32550286d-09/
      data fpp(16,11,1),fpp(16,11,2)/ 1.51498262d-05, 4.08406990d-09/
      data fpp(16,12,1),fpp(16,12,2)/ 2.68742782d-06,-2.01077674d-09/
      data fpp(16,13,1),fpp(16,13,2)/-2.34328900d-05, 9.59037056d-10/
      data fpp(16,14,1),fpp(16,14,2)/-1.86466443d-05,-6.25371485d-10/
      data fpp(16,15,1),fpp(16,15,2)/-1.78739271d-06,-2.57551117d-10/
      data fpp(16,16,1),fpp(16,16,2)/-5.74648883d-06,-1.34442405d-09/
      data fpp(16,17,1),fpp(16,17,2)/-1.49400131d-06, 1.43524730d-09/
      data fpp(16,18,1),fpp(16,18,2)/-5.61674812d-06, 4.03434846d-10/
      data fpp(16,19,1),fpp(16,19,2)/-9.85674494d-07,-3.04898669d-09/
      data fpp(16,20,1),fpp(16,20,2)/-1.07932299d-06, 1.35925119d-08/
      data fpp(16,21,1),fpp(16,21,2)/-5.98451412d-05,-2.01210609d-08/
      data fpp(16,22,1),fpp(16,22,2)/-6.12314677d-07, 6.89173168d-09/
      data fpp(16,23,1),fpp(16,23,2)/ 0.00000000d+00, 1.65541342d-08/
      data fpp(17, 1,1),fpp(17, 1,2)/ 0.00000000d+00,-1.13857227d-08/
      data fpp(17, 2,1),fpp(17, 2,2)/-5.20717302d-06,-2.82855469d-09/
      data fpp(17, 3,1),fpp(17, 3,2)/ 1.13383218d-05,-6.10005857d-09/
      data fpp(17, 4,1),fpp(17, 4,2)/ 1.11062316d-05, 3.20287890d-08/
      data fpp(17, 5,1),fpp(17, 5,2)/ 5.81372302d-06,-2.12150973d-08/
      data fpp(17, 6,1),fpp(17, 6,2)/-1.94045265d-05, 2.43160036d-09/
      data fpp(17, 7,1),fpp(17, 7,2)/-8.47730074d-06, 1.38886959d-08/
      data fpp(17, 8,1),fpp(17, 8,2)/-2.43167874d-06,-7.58638390d-09/
      data fpp(17, 9,1),fpp(17, 9,2)/ 2.71531641d-06,-3.43160299d-10/
      data fpp(17,10,1),fpp(17,10,2)/ 9.66752504d-06,-1.17732715d-09/
      data fpp(17,11,1),fpp(17,11,2)/-5.17785307d-06, 2.52468915d-10/
      data fpp(17,12,1),fpp(17,12,2)/-3.84471860d-06, 7.67451494d-10/
      data fpp(17,13,1),fpp(17,13,2)/ 7.15516077d-06,-1.17222749d-08/
      data fpp(17,14,1),fpp(17,14,2)/ 2.51027475d-05, 2.21216481d-08/
      data fpp(17,15,1),fpp(17,15,2)/-4.98095142d-07,-1.79643174d-08/
      data fpp(17,16,1),fpp(17,16,2)/-4.60319683d-07, 1.07356214d-08/
      data fpp(17,17,1),fpp(17,17,2)/-2.60971054d-06,-6.97816829d-09/
      data fpp(17,18,1),fpp(17,18,2)/ 4.51227356d-06, 2.17705176d-09/
      data fpp(17,19,1),fpp(17,19,2)/ 3.45596015d-06, 3.06996127d-09/
      data fpp(17,20,1),fpp(17,20,2)/ 9.36358461d-06,-5.45689684d-09/
      data fpp(17,21,1),fpp(17,21,2)/ 2.38420718d-05, 3.75762607d-09/
      data fpp(17,22,1),fpp(17,22,2)/ 2.08980599d-06,-1.17360745d-09/
      data fpp(17,23,1),fpp(17,23,2)/ 0.00000000d+00,-2.06319628d-09/
      data fpp(18, 1,1),fpp(18, 1,2)/ 0.00000000d+00,-1.02244693d-08/
      data fpp(18, 2,1),fpp(18, 2,2)/ 5.17664054d-06,-1.95106135d-09/
      data fpp(18, 3,1),fpp(18, 3,2)/-4.41724475d-06,-5.97128527d-09/
      data fpp(18, 4,1),fpp(18, 4,2)/-3.16653908d-05, 3.30362024d-08/
      data fpp(18, 5,1),fpp(18, 5,2)/-1.32024415d-05,-3.01735244d-08/
      data fpp(18, 6,1),fpp(18, 6,2)/ 7.74800830d-06, 1.32578951d-08/
      data fpp(18, 7,1),fpp(18, 7,2)/ 7.75757546d-06, 1.14194382d-09/
      data fpp(18, 8,1),fpp(18, 8,2)/-2.25445250d-06,-3.42567043d-09/
      data fpp(18, 9,1),fpp(18, 9,2)/-1.22681039d-05, 7.76073789d-09/
      data fpp(18,10,1),fpp(18,10,2)/-1.72896585d-05,-1.13693785d-08/
      data fpp(18,11,1),fpp(18,11,2)/-1.77174723d-06, 6.51677595d-09/
      data fpp(18,12,1),fpp(18,12,2)/ 2.69144659d-06,-1.49772535d-09/
      data fpp(18,13,1),fpp(18,13,2)/-3.18775306d-06,-1.12587454d-09/
      data fpp(18,14,1),fpp(18,14,2)/-1.70976790d-05, 2.40122351d-09/
      data fpp(18,15,1),fpp(18,15,2)/ 3.11310661d-06,-4.27901949d-09/
      data fpp(18,16,1),fpp(18,16,2)/ 1.49211009d-05, 5.71485445d-09/
      data fpp(18,17,1),fpp(18,17,2)/ 1.93284347d-06,-1.18039833d-09/
      data fpp(18,18,1),fpp(18,18,2)/-3.09901278d-06,-2.79326114d-09/
      data fpp(18,19,1),fpp(18,19,2)/-2.17149944d-06, 5.75344290d-09/
      data fpp(18,20,1),fpp(18,20,2)/-3.23750155d-05,-1.12205105d-08/
      data fpp(18,21,1),fpp(18,21,2)/-2.18981262d-06, 1.03285990d-08/
      data fpp(18,22,1),fpp(18,22,2)/-1.08024263d-06,-3.69388542d-09/
      data fpp(18,23,1),fpp(18,23,2)/ 0.00000000d+00,-7.55305729d-09/
      data fpp(19, 1,1),fpp(19, 1,2)/ 0.00000000d+00,-9.25810821d-09/
      data fpp(19, 2,1),fpp(19, 2,2)/-3.57244315d-06,-3.08378358d-09/
      data fpp(19, 3,1),fpp(19, 3,2)/ 5.07874109d-06,-4.56067575d-08/
      data fpp(19, 4,1),fpp(19, 4,2)/ 5.71676065d-05, 8.23108135d-08/
      data fpp(19, 5,1),fpp(19, 5,2)/-7.70837707d-06,-2.44364964d-08/
      data fpp(19, 6,1),fpp(19, 6,2)/-1.21332518d-05,-6.16482779d-09/
      data fpp(19, 7,1),fpp(19, 7,2)/-2.15719262d-05,-1.30419242d-09/
      data fpp(19, 8,1),fpp(19, 8,2)/ 1.89197806d-05,-1.02184025d-08/
      data fpp(19, 9,1),fpp(19, 9,2)/ 3.92675450d-05, 1.09778026d-08/
      data fpp(19,10,1),fpp(19,10,2)/ 1.14470050d-05,-6.22420641d-09/
      data fpp(19,11,1),fpp(19,11,2)/ 8.62551575d-06, 3.11902307d-09/
      data fpp(19,12,1),fpp(19,12,2)/-5.19015503d-06,-1.45188588d-09/
      data fpp(19,13,1),fpp(19,13,2)/-7.93975871d-07,-3.11479533d-10/
      data fpp(19,14,1),fpp(19,14,2)/ 3.83427373d-06, 8.97804018d-10/
      data fpp(19,15,1),fpp(19,15,2)/-2.81839034d-06, 2.12026346d-09/
      data fpp(19,16,1),fpp(19,16,2)/-2.44150250d-05,-5.77885786d-09/
      data fpp(19,17,1),fpp(19,17,2)/-2.49651546d-07, 5.39516798d-09/
      data fpp(19,18,1),fpp(19,18,2)/-8.27334646d-06,-2.01814071d-10/
      data fpp(19,19,1),fpp(19,19,2)/-1.18264430d-05,-9.98791170d-09/
      data fpp(19,20,1),fpp(19,20,2)/ 4.58297004d-05, 1.55534609d-08/
      data fpp(19,21,1),fpp(19,21,2)/-6.81404457d-06,-8.42593177d-09/
      data fpp(19,22,1),fpp(19,22,2)/-7.33495838d-07, 1.50266221d-10/
      data fpp(19,23,1),fpp(19,23,2)/ 0.00000000d+00,-5.75133110d-10/
      data fpp(20, 1,1),fpp(20, 1,2)/ 0.00000000d+00,-2.16663578d-08/
      data fpp(20, 2,1),fpp(20, 2,2)/ 1.13132083d-07,-1.74672844d-08/
      data fpp(20, 3,1),fpp(20, 3,2)/-6.89771962d-06, 2.43354955d-08/
      data fpp(20, 4,1),fpp(20, 4,2)/-2.75050354d-05,-6.54746978d-08/
      data fpp(20, 5,1),fpp(20, 5,2)/ 3.05359498d-05, 1.10363295d-07/
      data fpp(20, 6,1),fpp(20, 6,2)/ 9.28499881d-06,-8.07784841d-08/
      data fpp(20, 7,1),fpp(20, 7,2)/ 1.85301293d-05, 7.11506408d-08/
      data fpp(20, 8,1),fpp(20, 8,2)/-2.84246699d-05,-4.78240792d-08/
      data fpp(20, 9,1),fpp(20, 9,2)/-4.13020760d-05,-1.18543240d-08/
      data fpp(20,10,1),fpp(20,10,2)/-1.49836154d-06, 1.50750115d-08/
      data fpp(20,11,1),fpp(20,11,2)/-8.73031576d-06,-9.44572216d-09/
      data fpp(20,12,1),fpp(20,12,2)/ 6.06917355d-06, 5.90787712d-09/
      data fpp(20,13,1),fpp(20,13,2)/ 1.86365654d-06,-2.18578632d-09/
      data fpp(20,14,1),fpp(20,14,2)/ 1.76058406d-06, 1.63526818d-09/
      data fpp(20,15,1),fpp(20,15,2)/ 6.60454760d-07,-2.55528638d-09/
      data fpp(20,16,1),fpp(20,16,2)/ 1.22389990d-05, 2.58587734d-09/
      data fpp(20,17,1),fpp(20,17,2)/ 5.65762713d-07,-2.38822298d-09/
      data fpp(20,18,1),fpp(20,18,2)/ 1.06923986d-05, 3.67014597d-10/
      data fpp(20,19,1),fpp(20,19,2)/ 1.49772715d-05, 3.92016460d-09/
      data fpp(20,20,1),fpp(20,20,2)/-2.04437861d-05,-4.64767298d-09/
      data fpp(20,21,1),fpp(20,21,2)/ 3.94599090d-06, 2.67052734d-09/
      data fpp(20,22,1),fpp(20,22,2)/-9.48577402d-06,-1.23443638d-09/
      data fpp(20,23,1),fpp(20,23,2)/ 0.00000000d+00,-1.93278181d-09/
      data fpp(21, 1,1),fpp(21, 1,2)/ 0.00000000d+00,-3.68238460d-08/
      data fpp(21, 2,1),fpp(21, 2,2)/-1.66214484d-06,-1.75523081d-08/
      data fpp(21, 3,1),fpp(21, 3,2)/ 5.60657135d-06, 1.58330783d-08/
      data fpp(21, 4,1),fpp(21, 4,2)/-1.10949531d-05,-1.80005235d-10/
      data fpp(21, 5,1),fpp(21, 5,2)/-1.23142478d-05,-3.11305739d-09/
      data fpp(21, 6,1),fpp(21, 6,2)/-4.19449486d-06, 1.02322348d-08/
      data fpp(21, 7,1),fpp(21, 7,2)/-1.03858135d-05,-1.38158818d-08/
      data fpp(21, 8,1),fpp(21, 8,2)/ 1.01357124d-05, 9.03129249d-09/
      data fpp(21, 9,1),fpp(21, 9,2)/ 1.38285565d-05,-5.50928814d-09/
      data fpp(21,10,1),fpp(21,10,2)/-2.30346489d-06, 3.01221818d-09/
      data fpp(21,11,1),fpp(21,11,2)/ 2.68404203d-06, 6.04154164d-11/
      data fpp(21,12,1),fpp(21,12,2)/-2.43714181d-06,-2.05387985d-09/
      data fpp(21,13,1),fpp(21,13,2)/-1.62045500d-08, 3.35510397d-09/
      data fpp(21,14,1),fpp(21,14,2)/-2.42479603d-06,-3.56653604d-09/
      data fpp(21,15,1),fpp(21,15,2)/ 1.07443618d-08, 1.91104019d-09/
      data fpp(21,16,1),fpp(21,16,2)/-3.18664668d-06,-4.77624736d-10/
      data fpp(21,17,1),fpp(21,17,2)/-3.86108013d-07,-5.41249789d-13/
      data fpp(21,18,1),fpp(21,18,2)/-3.79243103d-06, 1.07978974d-09/
      data fpp(21,19,1),fpp(21,19,2)/-6.03994308d-06,-2.51861769d-09/
      data fpp(21,20,1),fpp(21,20,2)/ 4.59282013d-06, 3.59468103d-09/
      data fpp(21,21,1),fpp(21,21,2)/-9.43939955d-07,-8.86010643d-09/
      data fpp(21,22,1),fpp(21,22,2)/ 1.17749106d-05, 9.04574469d-09/
      data fpp(21,23,1),fpp(21,23,2)/ 0.00000000d+00, 1.82771277d-08/
      data fpp(22, 1,1),fpp(22, 1,2)/ 0.00000000d+00, 5.04400948d-08/
      data fpp(22, 2,1),fpp(22, 2,2)/ 1.09098424d-06, 3.19198103d-08/
      data fpp(22, 3,1),fpp(22, 3,2)/-8.04239653d-06,-1.68519336d-07/
      data fpp(22, 4,1),fpp(22, 4,2)/ 2.04868713d-05, 2.67757534d-07/
      data fpp(22, 5,1),fpp(22, 5,2)/-8.35976771d-07,-1.89710800d-07/
      data fpp(22, 6,1),fpp(22, 6,2)/ 1.93138425d-06, 5.66856668d-08/
      data fpp(22, 7,1),fpp(22, 7,2)/ 5.79652566d-06,-1.03186687d-09/
      data fpp(22, 8,1),fpp(22, 8,2)/-1.21947792d-06, 2.41800722d-10/
      data fpp(22, 9,1),fpp(22, 9,2)/-2.27013535d-06,-9.53533601d-09/
      data fpp(22,10,1),fpp(22,10,2)/ 4.11010457d-06, 9.88510768d-09/
      data fpp(22,11,1),fpp(22,11,2)/ 4.09254964d-07,-4.20509472d-09/
      data fpp(22,12,1),fpp(22,12,2)/ 7.17349652d-07, 3.35271181d-10/
      data fpp(22,13,1),fpp(22,13,2)/-2.66339364d-07,-1.33599001d-09/
      data fpp(22,14,1),fpp(22,14,2)/ 1.18299687d-06, 1.40868885d-09/
      data fpp(22,15,1),fpp(22,15,2)/-3.06548138d-08,-6.98765387d-10/
      data fpp(22,16,1),fpp(22,16,2)/ 8.53869964d-07, 1.86372699d-10/
      data fpp(22,17,1),fpp(22,17,2)/ 9.60880147d-08,-4.67254099d-11/
      data fpp(22,18,1),fpp(22,18,2)/ 1.08034013d-06, 5.28940324d-13/
      data fpp(22,19,1),fpp(22,19,2)/ 1.94145495d-06, 4.46096486d-11/
      data fpp(22,20,1),fpp(22,20,2)/-1.23075273d-06,-1.78967535d-10/
      data fpp(22,21,1),fpp(22,21,2)/ 2.53013315d-07, 6.71260490d-10/
      data fpp(22,22,1),fpp(22,22,2)/-5.74824956d-06,-7.06074426d-10/
      data fpp(22,23,1),fpp(22,23,2)/ 0.00000000d+00,-1.44696279d-09/
      data fpp(23, 1,1),fpp(23, 1,2)/ 0.00000000d+00,-5.99004719d-08/
      data fpp(23, 2,1),fpp(23, 2,2)/-5.41792120d-07,-2.65990562d-08/
      data fpp(23, 3,1),fpp(23, 3,2)/ 8.80301479d-06, 5.58966967d-08/
      data fpp(23, 4,1),fpp(23, 4,2)/-1.27725320d-05,-3.37877308d-08/
      data fpp(23, 5,1),fpp(23, 5,2)/ 1.73815492d-06, 1.44542264d-08/
      data fpp(23, 6,1),fpp(23, 6,2)/-1.61104215d-06,-1.20291747d-08/
      data fpp(23, 7,1),fpp(23, 7,2)/-2.72028913d-06, 4.86247235d-09/
      data fpp(23, 8,1),fpp(23, 8,2)/-2.17800775d-07, 2.17928526d-09/
      data fpp(23, 9,1),fpp(23, 9,2)/-1.88015147d-07,-3.97961340d-09/
      data fpp(23,10,1),fpp(23,10,2)/-2.37695337d-06, 3.04919757d-09/
      data fpp(23,11,1),fpp(23,11,2)/-7.21061884d-07,-1.61717688d-09/
      data fpp(23,12,1),fpp(23,12,2)/-1.92256803d-07, 1.01950993d-09/
      data fpp(23,13,1),fpp(23,13,2)/-1.18437996d-07,-1.26086286d-09/
      data fpp(23,14,1),fpp(23,14,2)/-1.47191450d-07, 1.02394150d-09/
      data fpp(23,15,1),fpp(23,15,2)/ 1.11874893d-07,-4.34903129d-10/
      data fpp(23,16,1),fpp(23,16,2)/-2.28833179d-07, 1.15671020d-10/
      data fpp(23,17,1),fpp(23,17,2)/ 1.75595454d-09,-2.77809495d-11/
      data fpp(23,18,1),fpp(23,18,2)/-2.88929486d-07,-4.54722152d-12/
      data fpp(23,19,1),fpp(23,19,2)/-5.25876709d-07, 4.59698356d-11/
      data fpp(23,20,1),fpp(23,20,2)/ 3.30190796d-07,-1.79332121d-10/
      data fpp(23,21,1),fpp(23,21,2)/-6.81133054d-08, 6.71358648d-10/
      data fpp(23,22,1),fpp(23,22,2)/ 1.37808762d-06,-7.06102471d-10/
      data fpp(23,23,1),fpp(23,23,2)/ 0.00000000d+00,-1.44694876d-09/
      data fpp(24, 1,1),fpp(24, 1,2)/ 0.00000000d+00, 4.94121913d-09/
      data fpp(24, 2,1),fpp(24, 2,2)/ 1.16184239d-07, 1.31756175d-09/
      data fpp(24, 3,1),fpp(24, 3,2)/-5.56966263d-06,-5.41146612d-09/
      data fpp(24, 4,1),fpp(24, 4,2)/ 2.52325672d-06,-1.27169728d-09/
      data fpp(24, 5,1),fpp(24, 5,2)/-1.16642922d-07, 5.69825523d-09/
      data fpp(24, 6,1),fpp(24, 6,2)/ 6.72784338d-07,-2.32132363d-09/
      data fpp(24, 7,1),fpp(24, 7,2)/ 5.24630856d-07, 1.18703928d-09/
      data fpp(24, 8,1),fpp(24, 8,2)/ 1.70681019d-07,-2.42683349d-09/
      data fpp(24, 9,1),fpp(24, 9,2)/ 1.42195934d-07, 1.32029467d-09/
      data fpp(24,10,1),fpp(24,10,2)/ 3.57708928d-07,-3.47467265d-10/
      data fpp(24,11,1),fpp(24,11,2)/ 3.14992570d-07, 6.95743901d-11/
      data fpp(24,12,1),fpp(24,12,2)/ 5.16775579d-08, 6.91697045d-11/
      data fpp(24,13,1),fpp(24,13,2)/ 2.60091346d-07,-3.46253208d-10/
      data fpp(24,14,1),fpp(24,14,2)/-8.34231070d-07, 7.15843128d-10/
      data fpp(24,15,1),fpp(24,15,2)/-1.76844759d-07,-7.17119302d-10/
      data fpp(24,16,1),fpp(24,16,2)/ 6.14627507d-08, 3.52634082d-10/
      data fpp(24,17,1),fpp(24,17,2)/-1.03111833d-07,-9.34170260d-11/
      data fpp(24,18,1),fpp(24,18,2)/ 7.53778144d-08, 2.10340218d-11/
      data fpp(24,19,1),fpp(24,19,2)/ 1.62051887d-07, 9.28093892d-12/
      data fpp(24,20,1),fpp(24,20,2)/-9.00104527d-08,-5.81577774d-11/
      data fpp(24,21,1),fpp(24,21,2)/ 1.94399064d-08, 2.23350171d-10/
      data fpp(24,22,1),fpp(24,22,2)/-2.44100932d-07,-2.35242906d-10/
      data fpp(24,23,1),fpp(24,23,2)/ 0.00000000d+00,-4.82378547d-10/
      data fpp(25, 1,1),fpp(25, 1,2)/ 0.00000000d+00, 2.54060390d-10/
      data fpp(25, 2,1),fpp(25, 2,2)/ 3.17055165d-07, 2.91879220d-10/
      data fpp(25, 3,1),fpp(25, 3,2)/ 1.95563572d-06,-1.42157727d-09/
      data fpp(25, 4,1),fpp(25, 4,2)/-2.00494864d-07, 2.99442986d-09/
      data fpp(25, 5,1),fpp(25, 5,2)/-3.11583234d-07,-3.35614217d-09/
      data fpp(25, 6,1),fpp(25, 6,2)/ 1.19904794d-07, 8.30138818d-10/
      data fpp(25, 7,1),fpp(25, 7,2)/ 1.41765707d-07, 4.83558690d-09/
      data fpp(25, 8,1),fpp(25, 8,2)/-4.64923302d-07,-8.17248640d-09/
      data fpp(25, 9,1),fpp(25, 9,2)/ 9.92314104d-08, 3.85435871d-09/
      data fpp(25,10,1),fpp(25,10,2)/-1.38823398d-08,-8.76832938d-10/
      data fpp(25,11,1),fpp(25,11,2)/-2.98908398d-07,-3.47026962d-10/
      data fpp(25,12,1),fpp(25,12,2)/-1.44534290d-08, 1.06494078d-09/
      data fpp(25,13,1),fpp(25,13,2)/-2.01927387d-07,-2.71273618d-09/
      data fpp(25,14,1),fpp(25,14,2)/ 1.80411573d-06, 3.78600393d-09/
      data fpp(25,15,1),fpp(25,15,2)/ 1.15504144d-07,-2.23127952d-09/
      data fpp(25,16,1),fpp(25,16,2)/-1.70178243d-08, 3.39114171d-10/
      data fpp(25,17,1),fpp(25,17,2)/ 1.70691377d-07, 2.74822839d-10/
      data fpp(25,18,1),fpp(25,18,2)/-1.25817721d-08,-2.38405528d-10/
      data fpp(25,19,1),fpp(25,19,2)/-1.22330839d-07, 7.87992712d-11/
      data fpp(25,20,1),fpp(25,20,2)/ 2.98510152d-08,-7.67915572d-11/
      data fpp(25,21,1),fpp(25,21,2)/-9.64632030d-09, 2.28366958d-10/
      data fpp(25,22,1),fpp(25,22,2)/ 7.83161064d-08,-2.36676274d-10/
      data fpp(25,23,1),fpp(25,23,2)/ 0.00000000d+00,-4.81661863d-10/
      data fpp(26, 1,1),fpp(26, 1,2)/ 0.00000000d+00,-4.09763457d-09/
      data fpp(26, 2,1),fpp(26, 2,2)/-1.84404899d-07,-2.20473087d-09/
      data fpp(26, 3,1),fpp(26, 3,2)/-3.32880265d-07, 3.31655804d-09/
      data fpp(26, 4,1),fpp(26, 4,2)/-4.12772620d-08,-3.86150129d-09/
      data fpp(26, 5,1),fpp(26, 5,2)/ 1.62975859d-07, 4.92944710d-09/
      data fpp(26, 6,1),fpp(26, 6,2)/-1.92403515d-07,-3.85628712d-09/
      data fpp(26, 7,1),fpp(26, 7,2)/-1.31693683d-07, 8.95701396d-10/
      data fpp(26, 8,1),fpp(26, 8,2)/ 2.49012187d-07, 2.73481540d-10/
      data fpp(26, 9,1),fpp(26, 9,2)/-5.91215756d-08, 4.10372443d-10/
      data fpp(26,10,1),fpp(26,10,2)/-6.21795690d-08,-7.67858099d-10/
      data fpp(26,11,1),fpp(26,11,2)/ 1.60641021d-07, 8.61059953d-10/
      data fpp(26,12,1),fpp(26,12,2)/ 6.13615797d-09,-8.76381714d-10/
      data fpp(26,13,1),fpp(26,13,2)/ 6.76182029d-08, 2.04446690d-09/
      data fpp(26,14,1),fpp(26,14,2)/-1.10223184d-06,-3.10148589d-09/
      data fpp(26,15,1),fpp(26,15,2)/-4.51718160d-08, 1.96147666d-09/
      data fpp(26,16,1),fpp(26,16,2)/ 6.60854659d-09,-5.44420754d-10/
      data fpp(26,17,1),fpp(26,17,2)/-9.96536747d-08, 2.16206354d-10/
      data fpp(26,18,1),fpp(26,18,2)/-2.50507262d-08,-3.20404663d-10/
      data fpp(26,19,1),fpp(26,19,2)/ 8.72714704d-08, 4.65412299d-10/
      data fpp(26,20,1),fpp(26,20,2)/-2.93936081d-08,-3.41244534d-10/
      data fpp(26,21,1),fpp(26,21,2)/ 1.91453748d-08, 2.99565836d-10/
      data fpp(26,22,1),fpp(26,22,2)/-6.91634933d-08,-2.57018810d-10/
      data fpp(26,23,1),fpp(26,23,2)/ 0.00000000d+00,-4.71490595d-10/
      data fpp(27, 1,1),fpp(27, 1,2)/ 0.00000000d+00, 1.17961446d-09/
      data fpp(27, 2,1),fpp(27, 2,2)/ 3.46871139d-08, 4.40771081d-10/
      data fpp(27, 3,1),fpp(27, 3,2)/ 8.08229328d-08,-5.42698785d-10/
      data fpp(27, 4,1),fpp(27, 4,2)/-1.59207823d-08,-6.69975941d-10/
      data fpp(27, 5,1),fpp(27, 5,2)/-3.31359597d-08, 8.22602548d-10/
      data fpp(27, 6,1),fpp(27, 6,2)/ 3.72581471d-08,-2.20434250d-10/
      data fpp(27, 7,1),fpp(27, 7,2)/ 2.41981951d-08, 5.91344511d-11/
      data fpp(27, 8,1),fpp(27, 8,2)/-3.45749106d-08,-1.61035546d-11/
      data fpp(27, 9,1),fpp(27, 9,2)/ 7.74902160d-09, 5.27976728d-12/
      data fpp(27,10,1),fpp(27,10,2)/ 1.34798769d-08,-7.78752455d-12/
      data fpp(27,11,1),fpp(27,11,2)/-3.24688630d-08, 2.58703309d-11/
      data fpp(27,12,1),fpp(27,12,2)/-1.11817594d-08,-9.56937991d-11/
      data fpp(27,13,1),fpp(27,13,2)/ 1.81090849d-08, 3.56904865d-10/
      data fpp(27,14,1),fpp(27,14,2)/ 2.44637670d-07,-7.31925662d-10/
      data fpp(27,15,1),fpp(27,15,2)/ 1.77633760d-08, 7.70797784d-10/
      data fpp(27,16,1),fpp(27,16,2)/-1.13167276d-08,-5.51265474d-10/
      data fpp(27,17,1),fpp(27,17,2)/ 3.36153356d-08, 2.34264113d-10/
      data fpp(27,18,1),fpp(27,18,2)/ 2.14430646d-08, 2.14209024d-10/
      data fpp(27,19,1),fpp(27,19,2)/-2.06489915d-08,-4.91100208d-10/
      data fpp(27,20,1),fpp(27,20,2)/ 1.32553166d-08, 5.50191808d-10/
      data fpp(27,21,1),fpp(27,21,2)/-5.26129642d-08,-5.09667025d-10/
      data fpp(27,22,1),fpp(27,22,2)/ 4.83324267d-08, 2.88476293d-10/
      data fpp(27,23,1),fpp(27,23,2)/ 0.00000000d+00, 5.55761854d-10/
      data fpp(28, 1,1),fpp(28, 1,2)/ 0.00000000d+00, 1.92923216d-09/
      data fpp(28, 2,1),fpp(28, 2,2)/ 1.05656443d-07, 9.41535671d-10/
      data fpp(28, 3,1),fpp(28, 3,2)/-1.10411466d-07,-8.95374849d-10/
      data fpp(28, 4,1),fpp(28, 4,2)/ 4.49603911d-08, 2.39963723d-10/
      data fpp(28, 5,1),fpp(28, 5,2)/-9.04320202d-08,-6.44800439d-11/
      data fpp(28, 6,1),fpp(28, 6,2)/ 1.63370926d-07, 1.79564526d-11/
      data fpp(28, 7,1),fpp(28, 7,2)/ 9.49009025d-08,-7.34576661d-12/
      data fpp(28, 8,1),fpp(28, 8,2)/-1.10712545d-07, 1.14266138d-11/
      data fpp(28, 9,1),fpp(28, 9,2)/ 2.81254892d-08,-3.83606886d-11/
      data fpp(28,10,1),fpp(28,10,2)/ 6.82600616d-08, 1.09368759d-10/
      data fpp(28,11,1),fpp(28,11,2)/-9.07655685d-08,-3.99114347d-10/
      data fpp(28,12,1),fpp(28,12,2)/-2.14091203d-08, 8.87088630d-10/
      data fpp(28,13,1),fpp(28,13,2)/ 3.99454576d-08,-1.49240174d-10/
      data fpp(28,14,1),fpp(28,14,2)/ 7.23681165d-07,-1.49012793d-09/
      data fpp(28,15,1),fpp(28,15,2)/ 3.41183120d-08, 1.30975191d-09/
      data fpp(28,16,1),fpp(28,16,2)/-2.13416362d-08,-1.48879689d-10/
      data fpp(28,17,1),fpp(28,17,2)/ 8.51923322d-08,-1.14233150d-10/
      data fpp(28,18,1),fpp(28,18,2)/ 5.92784677d-08, 5.81228731d-12/
      data fpp(28,19,1),fpp(28,19,2)/-6.46755042d-08, 9.09840004d-11/
      data fpp(28,20,1),fpp(28,20,2)/ 3.63723417d-08,-9.69748289d-10/
      data fpp(28,21,1),fpp(28,21,2)/-1.08693518d-07, 1.98800915d-09/
      data fpp(28,22,1),fpp(28,22,2)/ 1.15833787d-07,-9.82288330d-10/
      data fpp(28,23,1),fpp(28,23,2)/ 0.00000000d+00,-2.25885584d-09/
 
      data fpppp( 1, 1),fpppp( 1, 2)/-1.12202977d-02,-8.95366128d-03/
      data fpppp( 1, 3),fpppp( 1, 4)/ 4.68788112d-02,-8.47691427d-02/
      data fpppp( 1, 5),fpppp( 1, 6)/ 6.95510582d-02,-3.58695242d-02/
      data fpppp( 1, 7),fpppp( 1, 8)/ 3.11264987d-02,-3.07435849d-02/
      data fpppp( 1, 9),fpppp( 1,10)/ 1.35189557d-02,-4.49296555d-03/
      data fpppp( 1,11),fpppp( 1,12)/ 1.11109397d-03,-2.13976215d-04/
      data fpppp( 1,13),fpppp( 1,14)/ 3.77555711d-05,-1.13869363d-05/
      data fpppp( 1,15),fpppp( 1,16)/ 4.47420334d-05,-6.13380620d-05/
      data fpppp( 1,17),fpppp( 1,18)/ 3.68439746d-05,-2.93729732d-05/
      data fpppp( 1,19),fpppp( 1,20)/ 2.60885115d-05,-1.22457641d-05/
      data fpppp( 1,21),fpppp( 1,22)/ 1.00598534d-05,-4.56725209d-06/
      data fpppp( 1,23) /            -8.64215102d-06 /
      data fpppp( 2, 1),fpppp( 2, 2)/-5.86240957d-03,-4.40798760d-03/
      data fpppp( 2, 3),fpppp( 2, 4)/ 2.30955031d-02,-4.05727467d-02/
      data fpppp( 2, 5),fpppp( 2, 6)/ 3.04320866d-02,-1.42475314d-02/
      data fpppp( 2, 7),fpppp( 2, 8)/ 1.64502392d-02,-1.77834366d-02/
      data fpppp( 2, 9),fpppp( 2,10)/ 7.27935774d-03,-2.29407303d-03/
      data fpppp( 2,11),fpppp( 2,12)/ 5.56099462d-04,-1.01433026d-04/
      data fpppp( 2,13),fpppp( 2,14)/ 1.71032862d-05,-2.91838467d-06/
      data fpppp( 2,15),fpppp( 2,16)/ 2.06905344d-05,-2.71300230d-05/
      data fpppp( 2,17),fpppp( 2,18)/ 1.01820378d-05,-6.14785467d-06/
      data fpppp( 2,19),fpppp( 2,20)/ 9.76819446d-06,-6.35554037d-06/
      data fpppp( 2,21),fpppp( 2,22)/ 5.80335006d-06,-2.57065494d-06/
      data fpppp( 2,23) /            -5.07811839d-06 /
      data fpppp( 3, 1),fpppp( 3, 2)/ 3.62657696d-03, 4.85049682d-04/
      data fpppp( 3, 3),fpppp( 3, 4)/-6.55841660d-03, 5.49036434d-05/
      data fpppp( 3, 5),fpppp( 3, 6)/ 1.77584525d-02,-2.38455924d-02/
      data fpppp( 3, 7),fpppp( 3, 8)/ 2.75217369d-02,-1.64617156d-02/
      data fpppp( 3, 9),fpppp( 3,10)/-2.98955205d-03, 3.33455719d-03/
      data fpppp( 3,11),fpppp( 3,12)/-1.06572454d-03, 2.92059684d-04/
      data fpppp( 3,13),fpppp( 3,14)/-7.60614563d-05, 2.61600710d-05/
      data fpppp( 3,15),fpppp( 3,16)/-1.12498143d-05, 2.50211317d-05/
      data fpppp( 3,17),fpppp( 3,18)/-5.54783939d-05, 5.39064859d-05/
      data fpppp( 3,19),fpppp( 3,20)/-2.22233974d-05, 2.77426383d-06/
      data fpppp( 3,21),fpppp( 3,22)/ 3.50140478d-09, 5.16513263d-07/
      data fpppp( 3,23) /             9.13038962d-08 /
      data fpppp( 4, 1),fpppp( 4, 2)/-1.34328100d-03, 4.16231436d-03/
      data fpppp( 4, 3),fpppp( 4, 4)/-1.56651959d-02, 5.31731635d-02/
      data fpppp( 4, 5),fpppp( 4, 6)/-8.74738628d-02, 7.58265347d-02/
      data fpppp( 4, 7),fpppp( 4, 8)/-5.15239159d-02, 2.55945013d-02/
      data fpppp( 4, 9),fpppp( 4,10)/ 8.44129639d-04,-3.04089455d-03/
      data fpppp( 4,11),fpppp( 4,12)/ 1.04635469d-03,-2.97770928d-04/
      data fpppp( 4,13),fpppp( 4,14)/ 8.45674027d-05,-1.68961373d-05/
      data fpppp( 4,15),fpppp( 4,16)/-1.55791891d-05, 1.43713818d-05/
      data fpppp( 4,17),fpppp( 4,18)/ 1.53559068d-05,-1.49414506d-05/
      data fpppp( 4,19),fpppp( 4,20)/ 6.34472699d-07, 5.65536419d-07/
      data fpppp( 4,21),fpppp( 4,22)/-3.94638744d-07,-2.13317233d-07/
      data fpppp( 4,23) /            -3.58137629d-07 /
      data fpppp( 5, 1),fpppp( 5, 2)/ 3.46808642d-03, 3.19557415d-03/
      data fpppp( 5, 3),fpppp( 5, 4)/-1.18461843d-02, 2.48044189d-02/
      data fpppp( 5, 5),fpppp( 5, 6)/-3.84199238d-02, 3.62150069d-02/
      data fpppp( 5, 7),fpppp( 5, 8)/-1.44686440d-02, 9.49160184d-04/
      data fpppp( 5, 9),fpppp( 5,10)/-1.47643449d-03, 1.18134008d-03/
      data fpppp( 5,11),fpppp( 5,12)/-3.75942620d-04, 9.60185209d-05/
      data fpppp( 5,13),fpppp( 5,14)/-2.46977363d-05, 8.14831096d-06/
      data fpppp( 5,15),fpppp( 5,16)/-4.91917775d-06, 5.87250272d-06/
      data fpppp( 5,17),fpppp( 5,18)/-3.77613104d-06, 3.48374670d-06/
      data fpppp( 5,19),fpppp( 5,20)/-1.78131582d-06,-1.03354989d-06/
      data fpppp( 5,21),fpppp( 5,22)/ 5.50437521d-07, 7.23602553d-08/
      data fpppp( 5,23) /             1.83444325d-07 /
      data fpppp( 6, 1),fpppp( 6, 2)/-5.67616420d-03,-4.72297189d-03/
      data fpppp( 6, 3),fpppp( 6, 4)/ 2.01394363d-02,-3.86804111d-02/
      data fpppp( 6, 5),fpppp( 6, 6)/ 6.09255422d-02,-6.69524473d-02/
      data fpppp( 6, 7),fpppp( 6, 8)/ 3.36834880d-02,-5.82028071d-03/
      data fpppp( 6, 9),fpppp( 6,10)/ 1.66356721d-03,-6.27973148d-04/
      data fpppp( 6,11),fpppp( 6,12)/ 1.60126370d-04,-4.72381105d-05/
      data fpppp( 6,13),fpppp( 6,14)/ 1.62927786d-05,-5.43909709d-06/
      data fpppp( 6,15),fpppp( 6,16)/-6.45373814d-07, 4.45693643d-07/
      data fpppp( 6,17),fpppp( 6,18)/ 5.18154607d-06,-3.95233718d-06/
      data fpppp( 6,19),fpppp( 6,20)/-3.46933988d-07, 1.31836250d-06/
      data fpppp( 6,21),fpppp( 6,22)/-7.28184246d-07, 1.84684712d-08/
      data fpppp( 6,23) /            -3.29358017d-08 /
      data fpppp( 7, 1),fpppp( 7, 2)/ 2.70993212d-03, 1.78903137d-04/
      data fpppp( 7, 3),fpppp( 7, 4)/-6.74717636d-04,-7.39926715d-03/
      data fpppp( 7, 5),fpppp( 7, 6)/ 7.84063990d-03, 5.62375101d-03/
      data fpppp( 7, 7),fpppp( 7, 8)/-2.99165720d-03,-4.37182984d-03/
      data fpppp( 7, 9),fpppp( 7,10)/ 1.21803830d-03,-1.95682776d-04/
      data fpppp( 7,11),fpppp( 7,12)/ 3.62882106d-05,-9.43679682d-06/
      data fpppp( 7,13),fpppp( 7,14)/ 1.53199199d-06, 1.56916485d-06/
      data fpppp( 7,15),fpppp( 7,16)/-1.76986559d-06, 2.35294229d-06/
      data fpppp( 7,17),fpppp( 7,18)/-2.49609509d-06, 1.32695322d-06/
      data fpppp( 7,19),fpppp( 7,20)/-1.76277854d-07,-5.29176678d-07/
      data fpppp( 7,21),fpppp( 7,22)/ 3.00528163d-07, 1.04501835d-07/
      data fpppp( 7,23) /             2.01541555d-07 /
      data fpppp( 8, 1),fpppp( 8, 2)/-2.16155861d-03,-2.07795199d-03/
      data fpppp( 8, 3),fpppp( 8, 4)/ 9.65975392d-03,-1.93918877d-02/
      data fpppp( 8, 5),fpppp( 8, 6)/ 2.88171279d-02,-2.24124282d-02/
      data fpppp( 8, 7),fpppp( 8, 8)/-3.24772322d-03, 1.17084076d-02/
      data fpppp( 8, 9),fpppp( 8,10)/-2.93724647d-03, 8.19838590d-04/
      data fpppp( 8,11),fpppp( 8,12)/-2.22960537d-04, 5.96562541d-05/
      data fpppp( 8,13),fpppp( 8,14)/-1.45832481d-05, 1.78148750d-06/
      data fpppp( 8,15),fpppp( 8,16)/ 1.11113854d-06,-1.14172206d-06/
      data fpppp( 8,17),fpppp( 8,18)/ 9.43568970d-07,-7.54155160d-07/
      data fpppp( 8,19),fpppp( 8,20)/ 1.66028575d-07, 3.21090989d-07/
      data fpppp( 8,21),fpppp( 8,22)/ 1.61101307d-07,-4.29341442d-07/
      data fpppp( 8,23) /            -8.96797600d-07 /
      data fpppp( 9, 1),fpppp( 9, 2)/-1.28287533d-03, 2.54914017d-03/
      data fpppp( 9, 3),fpppp( 9, 4)/-8.91334173d-03, 3.31549173d-02/
      data fpppp( 9, 5),fpppp( 9, 6)/-5.10855055d-02, 2.34146379d-02/
      data fpppp( 9, 7),fpppp( 9, 8)/ 9.18303898d-03,-9.75943233d-03/
      data fpppp( 9, 9),fpppp( 9,10)/ 2.00898623d-03,-5.65511637d-04/
      data fpppp( 9,11),fpppp( 9,12)/ 1.48175480d-04,-3.93343431d-05/
      data fpppp( 9,13),fpppp( 9,14)/ 9.53395029d-06,-1.02079090d-06/
      data fpppp( 9,15),fpppp( 9,16)/-9.54934200d-07, 1.43060448d-06/
      data fpppp( 9,17),fpppp( 9,18)/-1.30456926d-06, 5.98562776d-07/
      data fpppp( 9,19),fpppp( 9,20)/ 1.22970601d-07,-3.73108161d-08/
      data fpppp( 9,21),fpppp( 9,22)/-1.27724629d-06, 1.41423905d-06/
      data fpppp( 9,23) /             2.98246129d-06 /
      data fpppp(10, 1),fpppp(10, 2)/ 2.20778437d-03, 6.13862446d-04/
      data fpppp(10, 3),fpppp(10, 4)/-4.52347595d-03, 2.74114330d-03/
      data fpppp(10, 5),fpppp(10, 6)/-1.75059597d-03, 1.15138314d-02/
      data fpppp(10, 7),fpppp(10, 8)/-1.21019227d-02, 4.14956673d-03/
      data fpppp(10, 9),fpppp(10,10)/-8.52868333d-04, 2.33035159d-04/
      data fpppp(10,11),fpppp(10,12)/-6.34602891d-05, 1.65695478d-05/
      data fpppp(10,13),fpppp(10,14)/-3.40736269d-06,-1.37514608d-07/
      data fpppp(10,15),fpppp(10,16)/ 9.60170699d-07,-1.35779494d-06/
      data fpppp(10,17),fpppp(10,18)/ 1.05153191d-06,-3.40292267d-07/
      data fpppp(10,19),fpppp(10,20)/-2.39495339d-08,-4.97497184d-07/
      data fpppp(10,21),fpppp(10,22)/ 2.37652023d-06,-2.35651085d-06/
      data fpppp(10,23) /            -4.91609950d-06 /
      data fpppp(11, 1),fpppp(11, 2)/ 3.77814117d-04,-1.09682252d-03/
      data fpppp(11, 3),fpppp(11, 4)/ 3.29817952d-03,-1.28505538d-02/
      data fpppp(11, 5),fpppp(11, 6)/ 2.06118486d-02,-1.26182971d-02/
      data fpppp(11, 7),fpppp(11, 8)/ 3.48022700d-03,-1.36360162d-03/
      data fpppp(11, 9),fpppp(11,10)/ 2.79700043d-04,-7.85143004d-05/
      data fpppp(11,11),fpppp(11,12)/ 2.01039505d-05,-4.94163905d-06/
      data fpppp(11,13),fpppp(11,14)/ 7.48391720d-07,-2.29243964d-08/
      data fpppp(11,15),fpppp(11,16)/-3.54492246d-09, 6.35534310d-07/
      data fpppp(11,17),fpppp(11,18)/-7.83598188d-07, 3.35806444d-07/
      data fpppp(11,19),fpppp(11,20)/-1.67933280d-07, 5.87142659d-07/
      data fpppp(11,21),fpppp(11,22)/-1.87744624d-06, 1.77640767d-06/
      data fpppp(11,23) /             3.68213507d-06 /
      data fpppp(12, 1),fpppp(12, 2)/-1.25034161d-04, 1.78394251d-04/
      data fpppp(12, 3),fpppp(12, 4)/ 1.60284666d-04, 1.26755807d-03/
      data fpppp(12, 5),fpppp(12, 6)/-3.41267009d-03, 1.73827800d-03/
      data fpppp(12, 7),fpppp(12, 8)/ 1.37762468d-04,-1.37523595d-05/
      data fpppp(12, 9),fpppp(12,10)/-2.91117865d-06,-6.83888765d-07/
      data fpppp(12,11),fpppp(12,12)/-1.32447867d-07, 6.06795134d-08/
      data fpppp(12,13),fpppp(12,14)/ 9.60463350d-08, 4.65390351d-08/
      data fpppp(12,15),fpppp(12,16)/-1.67548896d-07,-2.45437593d-07/
      data fpppp(12,17),fpppp(12,18)/ 4.28799901d-07,-1.85594455d-07/
      data fpppp(12,19),fpppp(12,20)/ 7.03873834d-08,-2.57231420d-07/
      data fpppp(12,21),fpppp(12,22)/ 7.33191878d-07,-6.22670455d-07/
      data fpppp(12,23) /            -1.30816546d-06 /
      data fpppp(13, 1),fpppp(13, 2)/-1.00759600d-04, 1.10022931d-05/
      data fpppp(13, 3),fpppp(13, 4)/-3.24103644d-04, 9.04827824d-04/
      data fpppp(13, 5),fpppp(13, 6)/-9.85852473d-04, 6.29060777d-04/
      data fpppp(13, 7),fpppp(13, 8)/-2.58463341d-04, 5.37213537d-05/
      data fpppp(13, 9),fpppp(13,10)/-8.42862032d-06, 1.05385273d-06/
      data fpppp(13,11),fpppp(13,12)/-4.07135125d-08,-9.04775368d-10/
      data fpppp(13,13),fpppp(13,14)/-2.87246511d-07, 1.65875567d-07/
      data fpppp(13,15),fpppp(13,16)/-1.13867161d-07, 4.47620072d-07/
      data fpppp(13,17),fpppp(13,18)/-4.24944654d-07, 7.36346957d-08/
      data fpppp(13,19),fpppp(13,20)/ 5.99114567d-08, 2.76829961d-07/
      data fpppp(13,21),fpppp(13,22)/-7.58203983d-07, 4.63923605d-07/
      data fpppp(13,23) /             1.04114790d-06 /
      data fpppp(14, 1),fpppp(14, 2)/ 6.88417022d-05, 2.76849590d-05/
      data fpppp(14, 3),fpppp(14, 4)/-7.28327598d-05, 3.44129360d-05/
      data fpppp(14, 5),fpppp(14, 6)/ 5.81534510d-05,-1.15297295d-04/
      data fpppp(14, 7),fpppp(14, 8)/ 6.99221710d-05,-9.60197229d-06/
      data fpppp(14, 9),fpppp(14,10)/-1.29947678d-07, 4.97592327d-08/
      data fpppp(14,11),fpppp(14,12)/-3.54216082d-07,-4.40269821d-07/
      data fpppp(14,13),fpppp(14,14)/ 1.27529534d-06,-8.56254430d-07/
      data fpppp(14,15),fpppp(14,16)/ 3.85514419d-07,-6.08817078d-07/
      data fpppp(14,17),fpppp(14,18)/ 4.83579376d-07, 2.44274175d-08/
      data fpppp(14,19),fpppp(14,20)/-5.61208508d-08,-8.79109605d-07/
      data fpppp(14,21),fpppp(14,22)/ 1.72179643d-06,-8.12692261d-07/
      data fpppp(14,23) /            -1.87992531d-06 /
      data fpppp(15, 1),fpppp(15, 2)/-2.46416964d-06, 7.81881026d-07/
      data fpppp(15, 3),fpppp(15, 4)/-2.00614038d-06, 1.63250905d-05/
      data fpppp(15, 5),fpppp(15, 6)/-3.56691651d-05, 3.93462811d-05/
      data fpppp(15, 7),fpppp(15, 8)/-1.90391083d-05, 3.18991747d-06/
      data fpppp(15, 9),fpppp(15,10)/-6.32412948d-07,-3.45373081d-07/
      data fpppp(15,11),fpppp(15,12)/ 5.50423762d-07, 7.15411755d-07/
      data fpppp(15,13),fpppp(15,14)/-1.89470199d-06, 1.19613345d-06/
      data fpppp(15,15),fpppp(15,16)/-3.12374916d-07, 3.01394888d-07/
      data fpppp(15,17),fpppp(15,18)/-2.19834760d-07,-8.39092945d-08/
      data fpppp(15,19),fpppp(15,20)/-2.24627418d-07, 1.95308119d-06/
      data fpppp(15,21),fpppp(15,22)/-3.20742411d-06, 1.32778960d-06/
      data fpppp(15,23) /             3.09279787d-06 /
      data fpppp(16, 1),fpppp(16, 2)/-5.89682777d-06,-3.00887491d-06/
      data fpppp(16, 3),fpppp(16, 4)/ 6.19469250d-06,-6.70639099d-06/
      data fpppp(16, 5),fpppp(16, 6)/ 7.47821029d-06,-8.35473904d-06/
      data fpppp(16, 7),fpppp(16, 8)/ 5.22690148d-06,-8.21344462d-07/
      data fpppp(16, 9),fpppp(16,10)/-2.78452217d-07, 4.27711590d-07/
      data fpppp(16,11),fpppp(16,12)/-5.13341279d-07,-1.93906443d-07/
      data fpppp(16,13),fpppp(16,14)/ 4.69491884d-07, 1.70332723d-07/
      data fpppp(16,15),fpppp(16,16)/-4.26442427d-07, 2.86336126d-07/
      data fpppp(16,17),fpppp(16,18)/-2.26207058d-07, 1.15978045d-07/
      data fpppp(16,19),fpppp(16,20)/ 2.87524103d-07,-1.54955778d-06/
      data fpppp(16,21),fpppp(16,22)/ 2.39037685d-06,-9.32030948d-07/
      data fpppp(16,23) /            -2.17948377d-06 /
      data fpppp(17, 1),fpppp(17, 2)/ 2.30426521d-06, 1.08420993d-06/
      data fpppp(17, 3),fpppp(17, 4)/-1.42046467d-06, 5.71028357d-07/
      data fpppp(17, 5),fpppp(17, 6)/-2.07814919d-06, 2.95939060d-06/
      data fpppp(17, 7),fpppp(17, 8)/-1.08449914d-06, 2.07021071d-07/
      data fpppp(17, 9),fpppp(17,10)/ 4.07444118d-08,-4.26250672d-07/
      data fpppp(17,11),fpppp(17,12)/ 3.56403071d-07,-2.86508564d-08/
      data fpppp(17,13),fpppp(17,14)/ 3.38205049d-07,-9.07306898d-07/
      data fpppp(17,15),fpppp(17,16)/ 6.78116783d-07,-2.66843150d-07/
      data fpppp(17,17),fpppp(17,18)/ 2.58025837d-07,-2.08977701d-07/
      data fpppp(17,19),fpppp(17,20)/ 8.71871167d-08, 2.78065507d-07/
      data fpppp(17,21),fpppp(17,22)/-6.85197381d-07, 2.88878841d-07/
      data fpppp(17,23) /             7.09429604d-07 /
      data fpppp(18, 1),fpppp(18, 2)/-6.33937826d-07,-2.73888651d-07/
      data fpppp(18, 3),fpppp(18, 4)/-1.81543377d-06, 3.29860113d-06/
      data fpppp(18, 5),fpppp(18, 6)/-4.08307878d-07,-1.06836950d-06/
      data fpppp(18, 7),fpppp(18, 8)/-3.44025940d-07, 3.92904341d-08/
      data fpppp(18, 9),fpppp(18,10)/ 1.86474572d-07, 3.21275962d-07/
      data fpppp(18,11),fpppp(18,12)/-2.39210469d-07,-2.77171367d-08/
      data fpppp(18,13),fpppp(18,14)/-2.70464592d-07, 6.27731929d-07/
      data fpppp(18,15),fpppp(18,16)/-1.93220430d-07,-3.59017688d-07/
      data fpppp(18,17),fpppp(18,18)/ 1.41516080d-07, 2.70337438d-07/
      data fpppp(18,19),fpppp(18,20)/-8.65303657d-07, 1.32301543d-06/
      data fpppp(18,21),fpppp(18,22)/-8.03434932d-07, 1.46186327d-07/
      data fpppp(18,23) /             2.16929981d-07 /
      data fpppp(19, 1),fpppp(19, 2)/-2.57879853d-07,-5.14529310d-07/
      data fpppp(19, 3),fpppp(19, 4)/ 5.24966767d-06,-1.00590979d-05/
      data fpppp(19, 5),fpppp(19, 6)/ 6.91516008d-06,-3.09327630d-06/
      data fpppp(19, 7),fpppp(19, 8)/ 4.25463318d-06,-1.94196494d-06/
      data fpppp(19, 9),fpppp(19,10)/-1.32131960d-06, 8.23977134d-07/
      data fpppp(19,11),fpppp(19,12)/-4.74645900d-07, 4.14955573d-07/
      data fpppp(19,13),fpppp(19,14)/-9.24653958d-08,-3.11697633d-08/
      data fpppp(19,15),fpppp(19,16)/-4.59710371d-07, 9.73373015d-07/
      data fpppp(19,17),fpppp(19,18)/-6.88061207d-07,-1.52472288d-07/
      data fpppp(19,19),fpppp(19,20)/ 1.56618626d-06,-2.43971835d-06/
      data fpppp(19,21),fpppp(19,22)/ 1.57469383d-06,-3.35599356d-07/
      data fpppp(19,23) /            -5.53119581d-07 /
      data fpppp(20, 1),fpppp(20, 2)/-3.40734365d-07, 3.44389096d-07/
      data fpppp(20, 3),fpppp(20, 4)/-2.74657813d-06, 7.37877205d-06/
      data fpppp(20, 5),fpppp(20, 6)/-7.89291785d-06, 5.16283469d-06/
      data fpppp(20, 7),fpppp(20, 8)/-5.43936136d-06, 3.10662764d-06/
      data fpppp(20, 9),fpppp(20,10)/ 1.19142513d-06,-1.19407762d-06/
      data fpppp(20,11),fpppp(20,12)/ 7.62745213d-07,-5.35016625d-07/
      data fpppp(20,13),fpppp(20,14)/ 2.37020906d-07,-1.66920328d-07/
      data fpppp(20,15),fpppp(20,16)/ 3.70836997d-07,-5.55707246d-07/
      data fpppp(20,17),fpppp(20,18)/ 4.56885156d-07, 3.61589524d-08/
      data fpppp(20,19),fpppp(20,20)/-9.52026743d-07, 1.38959218d-06/
      data fpppp(20,21),fpppp(20,22)/-1.01769192d-06, 4.11882960d-07/
      data fpppp(20,23) /             7.45212413d-07 /
      data fpppp(21, 1),fpppp(21, 2)/ 1.53802687d-06, 6.27737730d-07/
      data fpppp(21, 3),fpppp(21, 4)/-1.90557114d-06, 1.24168906d-06/
      data fpppp(21, 5),fpppp(21, 6)/ 6.54550066d-07,-1.61851788d-06/
      data fpppp(21, 7),fpppp(21, 8)/ 2.38486424d-06,-1.50985639d-06/
      data fpppp(21, 9),fpppp(21,10)/-3.84322331d-07, 4.96832612d-07/
      data fpppp(21,11),fpppp(21,12)/-3.35836414d-07, 2.39991601d-07/
      data fpppp(21,13),fpppp(21,14)/-1.71602724d-07, 1.56647572d-07/
      data fpppp(21,15),fpppp(21,16)/-1.64339652d-07, 1.62735151d-07/
      data fpppp(21,17),fpppp(21,18)/-1.26725169d-07,-2.82461736d-08/
      data fpppp(21,19),fpppp(21,20)/ 3.09238521d-07,-4.35891396d-07/
      data fpppp(21,21),fpppp(21,22)/ 4.64155666d-07,-3.25394629d-07/
      data fpppp(21,23) /            -6.32202822d-07 /
      data fpppp(22, 1),fpppp(22, 2)/-2.01661124d-06,-1.02466240d-06/
      data fpppp(22, 3),fpppp(22, 4)/ 3.66141326d-06,-4.58195496d-06/
      data fpppp(22, 5),fpppp(22, 6)/ 2.70189879d-06,-4.43989999d-07/
      data fpppp(22, 7),fpppp(22, 8)/-6.62471498d-07, 4.82401194d-07/
      data fpppp(22, 9),fpppp(22,10)/ 1.64549798d-07,-2.25956705d-07/
      data fpppp(22,11),fpppp(22,12)/ 1.34411652d-07,-7.11532454d-08/
      data fpppp(22,13),fpppp(22,14)/ 7.26943073d-08,-7.36424688d-08/
      data fpppp(22,15),fpppp(22,16)/ 6.20962926d-08,-4.88521139d-08/
      data fpppp(22,17),fpppp(22,18)/ 3.47737596d-08, 1.42791195d-08/
      data fpppp(22,19),fpppp(22,20)/-9.92784751d-08, 1.40835431d-07/
      data fpppp(22,21),fpppp(22,22)/-1.84704825d-07, 1.48882135d-07/
      data fpppp(22,23) /             2.94147033d-07 /
      data fpppp(23, 1),fpppp(23, 2)/ 1.78590993d-06, 8.79128250d-07/
      data fpppp(23, 3),fpppp(23, 4)/-2.92963916d-06, 3.41854350d-06/
      data fpppp(23, 5),fpppp(23, 6)/-2.08383874d-06, 6.30439308d-07/
      data fpppp(23, 7),fpppp(23, 8)/ 9.96695316d-08,-1.62300954d-07/
      data fpppp(23, 9),fpppp(23,10)/-4.39143704d-08, 7.79830189d-08/
      data fpppp(23,11),fpppp(23,12)/-3.73279223d-08, 3.70348588d-09/
      data fpppp(23,13),fpppp(23,14)/-4.78519762d-09, 9.28296887d-09/
      data fpppp(23,15),fpppp(23,16)/-1.50774900d-08, 1.50405260d-08/
      data fpppp(23,17),fpppp(23,18)/-1.08067818d-08,-3.08987308d-09/
      data fpppp(23,19),fpppp(23,20)/ 2.63905672d-08,-3.68915120d-08/
      data fpppp(23,21),fpppp(23,22)/ 4.59131844d-08,-3.60909238d-08/
      data fpppp(23,23) /            -7.10068022d-08 /
      data fpppp(24, 1),fpppp(24, 2)/-9.22654275d-07,-4.17398968d-07/
      data fpppp(24, 3),fpppp(24, 4)/ 1.19976268d-06,-1.07474787d-06/
      data fpppp(24, 5),fpppp(24, 6)/ 5.23352234d-07,-1.95622612d-07/
      data fpppp(24, 7),fpppp(24, 8)/ 3.41188362d-08, 9.75614249d-09/
      data fpppp(24, 9),fpppp(24,10)/ 4.96813411d-09,-3.43348369d-09/
      data fpppp(24,11),fpppp(24,12)/-6.72796048d-09, 1.71094063d-08/
      data fpppp(24,13),fpppp(24,14)/-3.34059368d-08, 3.83501689d-08/
      data fpppp(24,15),fpppp(24,16)/-1.48922151d-08,-3.92603635d-09/
      data fpppp(24,17),fpppp(24,18)/ 6.42343491d-09,-1.18384943d-09/
      data fpppp(24,19),fpppp(24,20)/-7.19697165d-09, 9.64755130d-09/
      data fpppp(24,21),fpppp(24,22)/-9.70247163d-09, 6.78286332d-09/
      data fpppp(24,23) /             1.30295246d-08 /
      data fpppp(25, 1),fpppp(25, 2)/ 2.36014780d-07, 9.58524102d-08/
      data fpppp(25, 3),fpppp(25, 4)/-3.02258326d-07, 2.02450221d-07/
      data fpppp(25, 5),fpppp(25, 6)/-1.67324248d-08,-5.30218578d-09/
      data fpppp(25, 7),fpppp(25, 8)/-6.03693398d-08, 9.59275638d-08/
      data fpppp(25, 9),fpppp(25,10)/-4.23384227d-08, 4.56609570d-09/
      data fpppp(25,11),fpppp(25,12)/ 1.37593014d-08,-2.54344398d-08/
      data fpppp(25,13),fpppp(25,14)/ 5.96627222d-08,-8.16054244d-08/
      data fpppp(25,15),fpppp(25,16)/ 4.50796933d-08,-5.34797200d-09/
      data fpppp(25,17),fpppp(25,18)/-4.47393520d-09, 9.84771793d-10/
      data fpppp(25,19),fpppp(25,20)/ 4.94629293d-09,-5.05408819d-09/
      data fpppp(25,21),fpppp(25,22)/ 3.76930844d-09,-2.37555985d-09/
      data fpppp(25,23) /            -4.24378102d-09 /
      data fpppp(26, 1),fpppp(26, 2)/-1.33537143d-08,-1.31293424d-09/
      data fpppp(26, 3),fpppp(26, 4)/ 2.72285392d-08,-1.98241405d-09/
      data fpppp(26, 5),fpppp(26, 6)/-4.02628546d-08, 2.87220340d-08/
      data fpppp(26, 7),fpppp(26, 8)/ 2.52361281d-08,-5.28674973d-08/
      data fpppp(26, 9),fpppp(26,10)/ 2.09123491d-08, 4.89273167d-10/
      data fpppp(26,11),fpppp(26,12)/-9.31672682d-09, 1.41381070d-08/
      data fpppp(26,13),fpppp(26,14)/-3.42764866d-08, 4.90879139d-08/
      data fpppp(26,15),fpppp(26,16)/-2.84605645d-08, 4.43756398d-09/
      data fpppp(26,17),fpppp(26,18)/ 1.22775350d-09, 1.50333219d-09/
      data fpppp(26,19),fpppp(26,20)/-4.97792736d-09, 4.66914075d-09/
      data fpppp(26,21),fpppp(26,22)/-3.78639196d-09, 2.26555603d-09/
      data fpppp(26,23) /             4.17250953d-09 /
      data fpppp(27, 1),fpppp(27, 2)/ 5.93758666d-09, 1.84493039d-09/
      data fpppp(27, 3),fpppp(27, 4)/-1.05696190d-08, 6.14245758d-09/
      data fpppp(27, 5),fpppp(27, 6)/ 5.08663776d-09,-5.46278043d-09/
      data fpppp(27, 7),fpppp(27, 8)/-3.26449012d-09, 7.54958402d-09/
      data fpppp(27, 9),fpppp(27,10)/-2.67055686d-09,-4.98141969d-10/
      data fpppp(27,11),fpppp(27,12)/ 1.56234903d-09,-1.71710355d-09/
      data fpppp(27,13),fpppp(27,14)/ 5.78628960d-09,-9.59379040d-09/
      data fpppp(27,15),fpppp(27,16)/ 5.38469925d-09,-7.73551735d-11/
      data fpppp(27,17),fpppp(27,18)/-6.34548545d-10,-8.10710700d-10/
      data fpppp(27,19),fpppp(27,20)/ 2.08220423d-09,-2.95832438d-09/
      data fpppp(27,21),fpppp(27,22)/ 3.76473794d-09,-2.09180710d-09/
      data fpppp(27,23) /            -4.35417861d-09 /
      data fpppp(28, 1),fpppp(28, 2)/-3.75624202d-08,-1.89352115d-08/
      data fpppp(28, 3),fpppp(28, 4)/ 3.60894215d-08,-3.62769303d-08/
      data fpppp(28, 5),fpppp(28, 6)/ 3.92348754d-08,-2.72556853d-08/
      data fpppp(28, 7),fpppp(28, 8)/-7.55764726d-09, 2.45718528d-08/
      data fpppp(28, 9),fpppp(28,10)/-8.06140836d-09,-2.35419104d-09/
      data fpppp(28,11),fpppp(28,12)/ 5.52856036d-09,-6.05712569d-09/
      data fpppp(28,13),fpppp(28,14)/ 1.82198302d-08,-2.94793273d-08/
      data fpppp(28,15),fpppp(28,16)/ 1.72995655d-08,-1.67276026d-09/
      data fpppp(28,17),fpppp(28,18)/-8.88889447d-10,-2.71855193d-09/
      data fpppp(28,19),fpppp(28,20)/ 5.88069072d-09,-7.30410187d-09/
      data fpppp(28,21),fpppp(28,22)/ 8.56889443d-09,-4.79588599d-09/
      data fpppp(28,23) /            -9.80701593d-09 /
 
      c(1,1)=fpppp(ix+1,iy+1)
      c(1,2)=fpppp(ix+1,iy  )
      c(2,1)=fpppp(ix  ,iy+1)
      c(2,2)=fpppp(ix,  iy  )
      c(1,3)=fpp(ix+1,iy+1,1)
      c(1,4)=fpp(ix+1,iy  ,1)
      c(2,3)=fpp(ix,  iy+1,1)
      c(2,4)=fpp(ix,  iy,  1)
      c(3,1)=fpp(ix+1,iy+1,2)
      c(3,2)=fpp(ix+1,iy  ,2)
      c(4,1)=fpp(ix,  iy+1,2)
      c(4,2)=fpp(ix,  iy,  2)
      c(3,3)=f(ix+1,iy+1)
      c(3,4)=f(ix+1,iy  )
      c(4,3)=f(ix,  iy+1)
      c(4,4)=f(ix,  iy  )
      px(1)=((xi-xix)**3/(6.0*delxi))-(xi-xix)*delxi/6.0
      px(2)=(xi-xixp1)*delxi/6.0-((xi-xixp1)**3/(6.0*delxi))
      px(3)=(xi-xix)/delxi
      px(4)=(xixp1-xi)/delxi
      py(1)=((yi-yiy)**3/(6.0*delyi))-(yi-yiy)*delyi/6.0
      py(2)=(yi-yiyp1)*delyi/6.0-((yi-yiyp1)**3/(6.0*delyi))
      py(3)=(yi-yiy)/delyi
      py(4)=(yiyp1-yi)/delyi

      fi=0.0d 00
      do l=1,4
        sum=0.0d 00
        do i=1,4
          sum=sum + c(i,l) * px(i)
        enddo
        fi = fi + sum * py(l)
      enddo
      return
      end  
      subroutine c12_spl(xi,yi,ix,iy,delxi,delyi,xix,xixp1,
     x                    yiy,yiyp1,fi)
      implicit real*8 (a-h,o-z)
      dimension fpp(28,23,2),f(28,23),fpppp(28,23)
      dimension c(4,4),px(4),py(4)
 
      data f( 4,17),f( 4,18) /  3.73300000d-05 ,  1.47500000d-05 /
      data f( 4,19),f( 4,20) /  2.40000000d-06 ,  1.80000000d-07 /
      data f( 4,21),f( 4,22) /  0.00000000d+00 ,  2.00000000d-08 /
      data f( 4,23) /           0.00000000d+00 /
      data f( 5, 1),f( 5, 2) /  0.00000000d+00 , -1.00000000d-08 /
      data f( 5, 3),f( 5, 4) /  1.72500000d-05 ,  1.04416000d-03 /
      data f( 5, 5),f( 5, 6) /  1.30728000d-03 ,  2.68089000d-03 /
      data f( 5, 7),f( 5, 8) /  1.98065000d-03 ,  6.26830000d-04 /
      data f( 5, 9),f( 5,10) /  1.33160000d-04 ,  6.14000000d-06 /
      data f( 5,11),f( 5,12) / -1.57200000d-05 , -3.05000000d-06 /
      data f( 5,13),f( 5,14) /  3.00000000d-07 ,  3.46000000d-06 /
      data f( 5,15),f( 5,16) /  2.04100000d-05 ,  2.68700000d-05 /
      data f( 5,17),f( 5,18) /  2.25300000d-05 ,  9.25000000d-06 /
      data f( 5,19),f( 5,20) /  1.57000000d-06 ,  1.20000000d-07 /
      data f( 5,21),f( 5,22) /  0.00000000d+00 , -1.00000000d-08 /
      data f( 5,23) /           0.00000000d+00 /
      data f( 6, 1),f( 6, 2) /  0.00000000d+00 ,  6.00000000d-08 /
      data f( 6, 3),f( 6, 4) / -1.42900000d-05 ,  1.17844000d-03 /
      data f( 6, 5),f( 6, 6) /  9.83080000d-04 ,  3.86810000d-03 /
      data f( 6, 7),f( 6, 8) /  2.13980000d-03 ,  6.56050000d-04 /
      data f( 6, 9),f( 6,10) /  1.24810000d-04 ,  1.31500000d-05 /
      data f( 6,11),f( 6,12) / -9.42000000d-06 , -1.53000000d-06 /
      data f( 6,13),f( 6,14) /  2.40000000d-07 ,  2.41000000d-06 /
      data f( 6,15),f( 6,16) /  1.37800000d-05 ,  1.63700000d-05 /
      data f( 6,17),f( 6,18) /  1.41300000d-05 ,  5.88000000d-06 /
      data f( 6,19),f( 6,20) /  1.03000000d-06 ,  3.00000000d-08 /
      data f( 6,21),f( 6,22) / -4.00000000d-08 , -2.00000000d-08 /
      data f( 6,23) /           0.00000000d+00 /
      data f( 7, 1),f( 7, 2) /  0.00000000d+00 , -1.09900000d-05 /
      data f( 7, 3),f( 7, 4) /  2.83200000d-05 ,  1.72255000d-03 /
      data f( 7, 5),f( 7, 6) / -8.76700000d-05 ,  3.35907000d-03 /
      data f( 7, 7),f( 7, 8) /  1.89607000d-03 ,  4.00810000d-04 /
      data f( 7, 9),f( 7,10) /  4.03700000d-05 ,  6.11000000d-06 /
      data f( 7,11),f( 7,12) / -3.79000000d-06 , -5.00000000d-07 /
      data f( 7,13),f( 7,14) /  2.10000000d-07 ,  8.20000000d-07 /
      data f( 7,15),f( 7,16) /  6.95000000d-06 ,  6.41000000d-06 /
      data f( 7,17),f( 7,18) /  5.89000000d-06 ,  2.51000000d-06 /
      data f( 7,19),f( 7,20) /  4.60000000d-07 ,  7.00000000d-08 /
      data f( 7,21),f( 7,22) / -1.00000000d-08 , -3.00000000d-08 /
      data f( 7,23) /           0.00000000d+00 /
      data f( 8, 1),f( 8, 2) /  0.00000000d+00 , -1.30000000d-07 /
      data f( 8, 3),f( 8, 4) /  2.41700000d-05 ,  1.47794000d-03 /
      data f( 8, 5),f( 8, 6) /  1.16123000d-03 ,  3.62372000d-03 /
      data f( 8, 7),f( 8, 8) /  2.02736000d-03 ,  1.55420000d-04 /
      data f( 8, 9),f( 8,10) /  6.58600000d-05 ,  3.17000000d-06 /
      data f( 8,11),f( 8,12) / -1.24000000d-06 , -2.60000000d-07 /
      data f( 8,13),f( 8,14) /  9.00000000d-08 ,  6.80000000d-07 /
      data f( 8,15),f( 8,16) /  3.29000000d-06 ,  2.76000000d-06 /
      data f( 8,17),f( 8,18) /  2.31000000d-06 ,  9.60000000d-07 /
      data f( 8,19),f( 8,20) /  9.00000000d-08 , -1.00000000d-08 /
      data f( 8,21),f( 8,22) / -1.00000000d-08 , -4.00000000d-08 /
      data f( 8,23) /           0.00000000d+00 /
      data f( 9, 1),f( 9, 2) /  0.00000000d+00 , -7.00000000d-08 /
      data f( 9, 3),f( 9, 4) /  8.97000000d-06 ,  8.50410000d-04 /
      data f( 9, 5),f( 9, 6) /  2.72804000d-03 ,  2.10773000d-03 /
      data f( 9, 7),f( 9, 8) /  5.57560000d-04 ,  7.94300000d-05 /
      data f( 9, 9),f( 9,10) /  3.12800000d-05 ,  1.30000000d-06 /
      data f( 9,11),f( 9,12) / -2.00000000d-07 , -8.00000000d-08 /
      data f( 9,13),f( 9,14) /  3.00000000d-08 ,  2.00000000d-08 /
      data f( 9,15),f( 9,16) /  1.69000000d-06 ,  1.28000000d-06 /
      data f( 9,17),f( 9,18) /  9.00000000d-07 ,  2.80000000d-07 /
      data f( 9,19),f( 9,20) /  9.00000000d-08 ,  4.00000000d-08 /
      data f( 9,21),f( 9,22) /  1.00000000d-08 , -7.00000000d-08 /
      data f( 9,23) /           0.00000000d+00 /
      data f(10, 1),f(10, 2) /  0.00000000d+00 , -8.00000000d-08 /
      data f(10, 3),f(10, 4) /  4.50000000d-06 ,  1.62000000d-05 /
      data f(10, 5),f(10, 6) /  7.50030000d-04 ,  3.02610000d-04 /
      data f(10, 7),f(10, 8) /  1.83120000d-04 ,  3.81900000d-05 /
      data f(10, 9),f(10,10) /  1.73100000d-05 ,  4.20000000d-07 /
      data f(10,11),f(10,12) / -3.00000000d-07 , -2.10000000d-07 /
      data f(10,13),f(10,14) / -2.00000000d-08 ,  1.00000000d-07 /
      data f(10,15),f(10,16) /  4.90000000d-07 ,  7.50000000d-07 /
      data f(10,17),f(10,18) /  4.20000000d-07 ,  1.90000000d-07 /
      data f(10,19),f(10,20) /  6.00000000d-08 ,  2.00000000d-08 /
      data f(10,21),f(10,22) / -2.00000000d-08 ,  3.90000000d-07 /
      data f(10,23) /           0.00000000d+00 /
      data f(11, 1),f(11, 2) /  0.00000000d+00 ,  0.00000000d+00 /
      data f(11, 3),f(11, 4) / -7.70000000d-07 , -6.95900000d-05 /
      data f(11, 5),f(11, 6) / -7.97240000d-04 , -1.03340000d-04 /
      data f(11, 7),f(11, 8) /  7.27100000d-05 ,  2.08500000d-05 /
      data f(11, 9),f(11,10) /  8.78000000d-06 ,  2.90000000d-07 /
      data f(11,11),f(11,12) /  1.90000000d-07 , -1.80000000d-07 /
      data f(11,13),f(11,14) /  3.00000000d-08 ,  8.00000000d-08 /
      data f(11,15),f(11,16) / -1.30000000d-07 ,  1.70000000d-07 /
      data f(11,17),f(11,18) /  1.20000000d-07 ,  0.00000000d+00 /
      data f(11,19),f(11,20) /  3.00000000d-08 ,  2.00000000d-08 /
      data f(11,21),f(11,22) /  0.00000000d+00 , -1.00000000d-07 /
      data f(11,23) /           0.00000000d+00 /
      data f(12, 1),f(12, 2) /  0.00000000d+00 ,  2.00000000d-08 /
      data f(12, 3),f(12, 4) /  1.49800000d-05 ,  5.96500000d-05 /
      data f(12, 5),f(12, 6) / -3.95780000d-04 , -1.58000000d-06 /
      data f(12, 7),f(12, 8) /  2.38400000d-05 ,  1.06700000d-05 /
      data f(12, 9),f(12,10) /  4.19000000d-06 ,  2.50000000d-07 /
      data f(12,11),f(12,12) /  8.00000000d-08 , -1.90000000d-07 /
      data f(12,13),f(12,14) /  7.00000000d-08 , -5.00000000d-08 /
      data f(12,15),f(12,16) /  4.60000000d-07 , -1.00000000d-08 /
      data f(12,17),f(12,18) / -6.00000000d-08 , -5.00000000d-08 /
      data f(12,19),f(12,20) / -4.00000000d-08 , -4.00000000d-08 /
      data f(12,21),f(12,22) /  0.00000000d+00 , -2.00000000d-08 /
      data f(12,23) /           0.00000000d+00 /
      data f(13, 1),f(13, 2) /  0.00000000d+00 , -5.00000000d-08 /
      data f(13, 3),f(13, 4) / -2.00000000d-07 ,  2.43500000d-05 /
      data f(13, 5),f(13, 6) / -1.84100000d-05 ,  3.24000000d-06 /
      data f(13, 7),f(13, 8) /  5.53000000d-06 ,  3.91000000d-06 /
      data f(13, 9),f(13,10) /  1.37000000d-06 ,  3.30000000d-07 /
      data f(13,11),f(13,12) /  1.10000000d-07 ,  3.60000000d-07 /
      data f(13,13),f(13,14) /  0.00000000d+00 ,  1.20000000d-07 /
      data f(13,15),f(13,16) / -5.00000000d-08 , -1.70000000d-07 /
      data f(13,17),f(13,18) / -7.00000000d-08 , -7.00000000d-08 /
      data f(13,19),f(13,20) / -3.00000000d-08 ,  1.00000000d-08 /
      data f(13,21),f(13,22) / -2.00000000d-08 , -4.00000000d-08 /
      data f(13,23) /           0.00000000d+00 /
      data f(14, 1),f(14, 2) /  0.00000000d+00 ,  1.80000000d-07 /
      data f(14, 3),f(14, 4) /  1.40000000d-07 ,  4.00000000d-08 /
      data f(14, 5),f(14, 6) / -3.20000000d-07 ,  1.82000000d-06 /
      data f(14, 7),f(14, 8) /  1.86000000d-06 ,  1.11000000d-06 /
      data f(14, 9),f(14,10) /  4.30000000d-07 ,  9.00000000d-08 /
      data f(14,11),f(14,12) /  6.00000000d-08 ,  5.00000000d-08 /
      data f(14,13),f(14,14) / -8.00000000d-08 , -5.00000000d-08 /
      data f(14,15),f(14,16) / -2.00000000d-08 ,  6.00000000d-08 /
      data f(14,17),f(14,18) / -9.00000000d-08 , -4.00000000d-08 /
      data f(14,19),f(14,20) /  4.00000000d-08 , -3.00000000d-08 /
      data f(14,21),f(14,22) / -9.00000000d-08 , -3.00000000d-08 /
      data f(14,23) /           0.00000000d+00 /
      data f(15, 1),f(15, 2) /  0.00000000d+00 , -8.00000000d-08 /
      data f(15, 3),f(15, 4) /  4.20000000d-07 , -7.00000000d-08 /
      data f(15, 5),f(15, 6) /  2.60000000d-07 ,  8.10000000d-07 /
      data f(15, 7),f(15, 8) /  9.30000000d-07 ,  6.20000000d-07 /
      data f(15, 9),f(15,10) /  3.20000000d-07 ,  9.00000000d-08 /
      data f(15,11),f(15,12) / -1.70000000d-07 ,  6.00000000d-08 /
      data f(15,13),f(15,14) /  2.80000000d-07 ,  3.00000000d-08 /
      data f(15,15),f(15,16) / -1.60000000d-07 , -3.00000000d-08 /
      data f(15,17),f(15,18) /  0.00000000d+00 ,  2.00000000d-08 /
      data f(15,19),f(15,20) /  1.00000000d-08 ,  1.00000000d-08 /
      data f(15,21),f(15,22) /  1.70000000d-07 , -3.00000000d-08 /
      data f(15,23) /           0.00000000d+00 /
      data f(16, 1),f(16, 2) /  0.00000000d+00 ,  1.10000000d-07 /
      data f(16, 3),f(16, 4) /  1.00000000d-07 ,  2.30000000d-07 /
      data f(16, 5),f(16, 6) /  2.90000000d-07 ,  4.60000000d-07 /
      data f(16, 7),f(16, 8) /  4.90000000d-07 ,  3.30000000d-07 /
      data f(16, 9),f(16,10) /  2.00000000d-07 ,  1.60000000d-07 /
      data f(16,11),f(16,12) /  3.90000000d-07 ,  5.00000000d-08 /
      data f(16,13),f(16,14) /  0.00000000d+00 ,  3.00000000d-08 /
      data f(16,15),f(16,16) / -1.50000000d-07 , -4.00000000d-08 /
      data f(16,17),f(16,18) / -2.00000000d-08 , -1.00000000d-08 /
      data f(16,19),f(16,20) /  1.00000000d-08 ,  0.00000000d+00 /
      data f(16,21),f(16,22) / -3.00000000d-07 , -4.00000000d-08 /
      data f(16,23) /           0.00000000d+00 /
      data f(17, 1),f(17, 2) /  0.00000000d+00 ,  6.00000000d-08 /
      data f(17, 3),f(17, 4) /  2.40000000d-07 ,  3.60000000d-07 /
      data f(17, 5),f(17, 6) /  3.00000000d-07 ,  2.30000000d-07 /
      data f(17, 7),f(17, 8) /  2.40000000d-07 ,  1.60000000d-07 /
      data f(17, 9),f(17,10) /  1.80000000d-07 ,  1.10000000d-07 /
      data f(17,11),f(17,12) /  4.00000000d-08 , -1.10000000d-07 /
      data f(17,13),f(17,14) /  1.00000000d-08 , -3.10000000d-07 /
      data f(17,15),f(17,16) / -3.20000000d-07 ,  7.00000000d-08 /
      data f(17,17),f(17,18) / -6.00000000d-08 ,  0.00000000d+00 /
      data f(17,19),f(17,20) /  2.00000000d-08 ,  0.00000000d+00 /
      data f(17,21),f(17,22) /  1.00000000d-08 , -1.00000000d-08 /
      data f(17,23) /           0.00000000d+00 /
      data f(18, 1),f(18, 2) /  0.00000000d+00 ,  1.00000000d-07 /
      data f(18, 3),f(18, 4) /  2.20000000d-07 ,  2.60000000d-07 /
      data f(18, 5),f(18, 6) /  1.50000000d-07 ,  2.10000000d-07 /
      data f(18, 7),f(18, 8) /  1.90000000d-07 ,  1.40000000d-07 /
      data f(18, 9),f(18,10) /  1.00000000d-07 , -5.80000000d-07 /
      data f(18,11),f(18,12) /  2.00000000d-08 , -3.00000000d-08 /
      data f(18,13),f(18,14) / -2.00000000d-08 , -2.00000000d-08 /
      data f(18,15),f(18,16) / -3.00000000d-08 ,  7.00000000d-08 /
      data f(18,17),f(18,18) /  4.00000000d-08 , -1.00000000d-08 /
      data f(18,19),f(18,20) / -2.00000000d-08 , -1.50000000d-07 /
      data f(18,21),f(18,22) /  2.00000000d-08 , -4.00000000d-08 /
      data f(18,23) /           0.00000000d+00 /
      data f(19, 1),f(19, 2) /  0.00000000d+00 ,  0.00000000d+00 /
      data f(19, 3),f(19, 4) /  1.70000000d-07 ,  6.10000000d-07 /
      data f(19, 5),f(19, 6) /  3.00000000d-07 ,  1.40000000d-07 /
      data f(19, 7),f(19, 8) /  3.00000000d-08 ,  2.00000000d-08 /
      data f(19, 9),f(19,10) /  8.00000000d-08 ,  1.00000000d-08 /
      data f(19,11),f(19,12) /  5.00000000d-08 , -2.00000000d-08 /
      data f(19,13),f(19,14) / -1.00000000d-08 , -3.00000000d-08 /
      data f(19,15),f(19,16) / -3.00000000d-08 , -1.00000000d-07 /
      data f(19,17),f(19,18) /  4.00000000d-08 , -2.00000000d-08 /
      data f(19,19),f(19,20) / -1.00000000d-08 ,  2.00000000d-07 /
      data f(19,21),f(19,22) / -4.00000000d-08 , -4.00000000d-08 /
      data f(19,23) /           0.00000000d+00 /
      data f(20, 1),f(20, 2) /  0.00000000d+00 , -5.00000000d-08 /
      data f(20, 3),f(20, 4) /  6.00000000d-08 ,  1.40000000d-07 /
      data f(20, 5),f(20, 6) /  5.90000000d-07 ,  1.30000000d-07 /
      data f(20, 7),f(20, 8) /  1.50000000d-07 , -3.10000000d-07 /
      data f(20, 9),f(20,10) / -6.80000000d-07 ,  6.00000000d-08 /
      data f(20,11),f(20,12) / -1.00000000d-07 ,  2.00000000d-08 /
      data f(20,13),f(20,14) /  3.00000000d-08 ,  8.00000000d-08 /
      data f(20,15),f(20,16) / -4.00000000d-08 ,  8.00000000d-08 /
      data f(20,17),f(20,18) / -2.00000000d-08 ,  1.00000000d-08 /
      data f(20,19),f(20,20) /  3.00000000d-08 , -1.00000000d-08 /
      data f(20,21),f(20,22) /  0.00000000d+00 , -1.00000000d-08 /
      data f(20,23) /           0.00000000d+00 /
      data f(21, 1),f(21, 2) /  0.00000000d+00 , -9.00000000d-08 /
      data f(21, 3),f(21, 4) /  7.00000000d-08 ,  8.00000000d-08 /
      data f(21, 5),f(21, 6) /  5.00000000d-08 ,  5.00000000d-08 /
      data f(21, 7),f(21, 8) /  3.00000000d-08 ,  1.00000000d-08 /
      data f(21, 9),f(21,10) / -2.00000000d-08 ,  6.00000000d-08 /
      data f(21,11),f(21,12) /  2.00000000d-08 , -1.00000000d-08 /
      data f(21,13),f(21,14) /  2.00000000d-08 , -1.70000000d-07 /
      data f(21,15),f(21,16) / -2.00000000d-08 , -1.00000000d-08 /
      data f(21,17),f(21,18) / -2.00000000d-08 , -3.00000000d-08 /
      data f(21,19),f(21,20) / -4.00000000d-08 ,  0.00000000d+00 /
      data f(21,21),f(21,22) /  0.00000000d+00 ,  1.50000000d-07 /
      data f(21,23) /           0.00000000d+00 /
      data f(22, 1),f(22, 2) /  0.00000000d+00 , -5.00000000d-08 /
      data f(22, 3),f(22, 4) / -9.00000000d-08 ,  9.20000000d-07 /
      data f(22, 5),f(22, 6) / -1.10000000d-07 ,  6.00000000d-08 /
      data f(22, 7),f(22, 8) /  1.10000000d-07 ,  9.00000000d-08 /
      data f(22, 9),f(22,10) /  7.00000000d-08 ,  8.50000000d-07 /
      data f(22,11),f(22,12) /  4.00000000d-08 , -1.00000000d-08 /
      data f(22,13),f(22,14) / -1.00000000d-08 ,  1.00000000d-08 /
      data f(22,15),f(22,16) /  1.00000000d-08 ,  0.00000000d+00 /
      data f(22,17),f(22,18) /  0.00000000d+00 ,  0.00000000d+00 /
      data f(22,19),f(22,20) /  0.00000000d+00 ,  0.00000000d+00 /
      data f(22,21),f(22,22) /  0.00000000d+00 , -1.00000000d-08 /
      data f(22,23) /           0.00000000d+00 /
      data f(23, 1),f(23, 2) /  0.00000000d+00 , -5.00000000d-08 /
      data f(23, 3),f(23, 4) /  1.40000000d-07 ,  0.00000000d+00 /
      data f(23, 5),f(23, 6) /  0.00000000d+00 , -1.00000000d-08 /
      data f(23, 7),f(23, 8) / -1.00000000d-08 ,  0.00000000d+00 /
      data f(23, 9),f(23,10) / -2.00000000d-08 ,  3.00000000d-08 /
      data f(23,11),f(23,12) /  0.00000000d+00 , -1.00000000d-08 /
      data f(23,13),f(23,14) / -2.00000000d-08 ,  1.00000000d-08 /
      data f(23,15),f(23,16) /  0.00000000d+00 ,  0.00000000d+00 /
      data f(23,17),f(23,18) /  0.00000000d+00 ,  0.00000000d+00 /
      data f(23,19),f(23,20) /  0.00000000d+00 ,  0.00000000d+00 /
      data f(23,21),f(23,22) /  0.00000000d+00 , -2.00000000d-08 /
      data f(23,23) /           0.00000000d+00 /
      data f(24, 1),f(24, 2) /  0.00000000d+00 , -2.00000000d-08 /
      data f(24, 3),f(24, 4) / -3.00000000d-08 ,  1.00000000d-08 /
      data f(24, 5),f(24, 6) /  2.00000000d-08 ,  0.00000000d+00 /
      data f(24, 7),f(24, 8) / -1.00000000d-08 , -1.00000000d-08 /
      data f(24, 9),f(24,10) / -1.00000000d-08 , -1.00000000d-08 /
      data f(24,11),f(24,12) /  0.00000000d+00 ,  1.00000000d-08 /
      data f(24,13),f(24,14) /  0.00000000d+00 ,  0.00000000d+00 /
      data f(24,15),f(24,16) /  1.00000000d-08 ,  1.00000000d-08 /
      data f(24,17),f(24,18) /  0.00000000d+00 , -1.00000000d-08 /
      data f(24,19),f(24,20) /  0.00000000d+00 ,  0.00000000d+00 /
      data f(24,21),f(24,22) /  0.00000000d+00 ,  0.00000000d+00 /
      data f(24,23) /           0.00000000d+00 /
      data f(25, 1),f(25, 2) /  0.00000000d+00 ,  0.00000000d+00 /
      data f(25, 3),f(25, 4) /  0.00000000d+00 ,  1.00000000d-08 /
      data f(25, 5),f(25, 6) / -1.00000000d-08 ,  0.00000000d+00 /
      data f(25, 7),f(25, 8) /  0.00000000d+00 , -3.00000000d-08 /
      data f(25, 9),f(25,10) /  2.00000000d-08 , -1.00000000d-08 /
      data f(25,11),f(25,12) /  1.00000000d-08 ,  0.00000000d+00 /
      data f(25,13),f(25,14) /  0.00000000d+00 , -1.00000000d-07 /
      data f(25,15),f(25,16) /  1.00000000d-08 ,  0.00000000d+00 /
      data f(25,17),f(25,18) /  0.00000000d+00 ,  1.00000000d-08 /
      data f(25,19),f(25,20) /  0.00000000d+00 ,  0.00000000d+00 /
      data f(25,21),f(25,22) /  1.00000000d-08 ,  0.00000000d+00 /
      data f(25,23) /           0.00000000d+00 /
      data f(26, 1),f(26, 2) /  0.00000000d+00 , -2.00000000d-08 /
      data f(26, 3),f(26, 4) /  0.00000000d+00 ,  0.00000000d+00 /
      data f(26, 5),f(26, 6) /  1.00000000d-08 , -2.00000000d-08 /
      data f(26, 7),f(26, 8) / -1.00000000d-08 ,  0.00000000d+00 /
      data f(26, 9),f(26,10) /  0.00000000d+00 , -1.00000000d-08 /
      data f(26,11),f(26,12) / -1.00000000d-08 ,  0.00000000d+00 /
      data f(26,13),f(26,14) / -1.00000000d-08 ,  9.00000000d-08 /
      data f(26,15),f(26,16) /  2.00000000d-08 ,  2.00000000d-08 /
      data f(26,17),f(26,18) /  1.00000000d-08 ,  1.00000000d-08 /
      data f(26,19),f(26,20) /  0.00000000d+00 ,  0.00000000d+00 /
      data f(26,21),f(26,22) /  0.00000000d+00 , -1.00000000d-08 /
      data f(26,23) /           0.00000000d+00 /
      data f(27, 1),f(27, 2) /  0.00000000d+00 ,  0.00000000d+00 /
      data f(27, 3),f(27, 4) / -1.00000000d-08 , -1.00000000d-08 /
      data f(27, 5),f(27, 6) /  0.00000000d+00 ,  0.00000000d+00 /
      data f(27, 7),f(27, 8) / -1.00000000d-08 , -1.00000000d-08 /
      data f(27, 9),f(27,10) /  0.00000000d+00 ,  1.00000000d-08 /
      data f(27,11),f(27,12) / -1.00000000d-08 ,  0.00000000d+00 /
      data f(27,13),f(27,14) /  0.00000000d+00 ,  0.00000000d+00 /
      data f(27,15),f(27,16) /  1.00000000d-08 ,  1.00000000d-08 /
      data f(27,17),f(27,18) /  0.00000000d+00 ,  1.00000000d-08 /
      data f(27,19),f(27,20) /  1.00000000d-08 ,  0.00000000d+00 /
      data f(27,21),f(27,22) /  0.00000000d+00 , -1.00000000d-08 /
      data f(27,23) /           0.00000000d+00 /
      data f(28, 1),f(28, 2) /  0.00000000d+00 ,  2.00000000d-08 /
      data f(28, 3),f(28, 4) /  0.00000000d+00 ,  0.00000000d+00 /
      data f(28, 5),f(28, 6) /  0.00000000d+00 ,  0.00000000d+00 /
      data f(28, 7),f(28, 8) /  0.00000000d+00 ,  0.00000000d+00 /
      data f(28, 9),f(28,10) /  0.00000000d+00 ,  0.00000000d+00 /
      data f(28,11),f(28,12) /  0.00000000d+00 ,  2.00000000d-08 /
      data f(28,13),f(28,14) / -8.00000000d-08 , -6.00000000d-08 /
      data f(28,15),f(28,16) /  2.00000000d-08 ,  1.00000000d-08 /
      data f(28,17),f(28,18) /  1.00000000d-08 ,  2.00000000d-08 /
      data f(28,19),f(28,20) /  0.00000000d+00 ,  1.00000000d-08 /
      data f(28,21),f(28,22) / -4.00000000d-08 ,  0.00000000d+00 /
      data f(28,23) /           0.00000000d+00 /
 
      data fpp( 1, 1,1),fpp( 1, 1,2)/ 0.00000000d+00, 2.87391166d-05/
      data fpp( 1, 2,1),fpp( 1, 2,2)/ 2.41960438d-05, 1.87909667d-05/
      data fpp( 1, 3,1),fpp( 1, 3,2)/ 3.88059062d-04,-1.03838184d-04/
      data fpp( 1, 4,1),fpp( 1, 4,2)/-1.41029993d-01, 1.67916168d-04/
      data fpp( 1, 5,1),fpp( 1, 5,2)/ 5.45939275d-02,-8.33888871d-05/
      data fpp( 1, 6,1),fpp( 1, 6,2)/ 4.06005839d-02, 3.88257806d-05/
      data fpp( 1, 7,1),fpp( 1, 7,2)/-7.12778008d-02,-1.05123035d-04/
      data fpp( 1, 8,1),fpp( 1, 8,2)/-2.74585573d-02, 7.94031613d-05/
      data fpp( 1, 9,1),fpp( 1, 9,2)/ 2.91648162d-03,-1.42736096d-05/
      data fpp( 1,10,1),fpp( 1,10,2)/ 6.38747446d-03,-1.21951815d-07/
      data fpp( 1,11,1),fpp( 1,11,2)/-6.62422083d-03, 7.12941687d-06/
      data fpp( 1,12,1),fpp( 1,12,2)/-1.61869025d-03,-3.48611565d-06/
      data fpp( 1,13,1),fpp( 1,13,2)/ 1.68184764d-04, 7.88457509d-08/
      data fpp( 1,14,1),fpp( 1,14,2)/ 3.17357929d-04, 7.28132651d-07/
      data fpp( 1,15,1),fpp( 1,15,2)/ 1.10573519d-03, 8.72623645d-07/
      data fpp( 1,16,1),fpp( 1,16,2)/ 2.36521365d-03,-2.22962723d-06/
      data fpp( 1,17,1),fpp( 1,17,2)/ 3.73285418d-03,-6.14514718d-07/
      data fpp( 1,18,1),fpp( 1,18,2)/ 1.07440900d-03, 6.56286105d-07/
      data fpp( 1,19,1),fpp( 1,19,2)/ 2.40973143d-04, 5.73570298d-07/
      data fpp( 1,20,1),fpp( 1,20,2)/ 3.03896577d-05, 8.63270368d-09/
      data fpp( 1,21,1),fpp( 1,21,2)/ 1.54809394d-04,-3.03011125d-08/
      data fpp( 1,22,1),fpp( 1,22,2)/-8.85162130d-06, 1.41717464d-08/
      data fpp( 1,23,1),fpp( 1,23,2)/ 0.00000000d+00, 3.48141268d-08/
      data fpp( 2, 1,1),fpp( 2, 1,2)/ 0.00000000d+00,-3.95615256d-06/
      data fpp( 2, 2,1),fpp( 2, 2,2)/ 5.60791230d-06, 2.14670512d-06/
      data fpp( 2, 3,1),fpp( 2, 3,2)/ 5.85881875d-04,-5.73466791d-06/
      data fpp( 2, 4,1),fpp( 2, 4,2)/-7.40390145d-02, 3.53287665d-05/
      data fpp( 2, 5,1),fpp( 2, 5,2)/ 1.12381450d-02,-2.77771982d-05/
      data fpp( 2, 6,1),fpp( 2, 6,2)/ 3.93318322d-02, 9.69602633d-06/
      data fpp( 2, 7,1),fpp( 2, 7,2)/-9.85339847d-03,-4.85549071d-05/
      data fpp( 2, 8,1),fpp( 2, 8,2)/-1.27408853d-02, 3.64412020d-05/
      data fpp( 2, 9,1),fpp( 2, 9,2)/ 8.52036761d-04,-2.30670104d-06/
      data fpp( 2,10,1),fpp( 2,10,2)/ 2.67705109d-03,-7.94497886d-07/
      data fpp( 2,11,1),fpp( 2,11,2)/-5.13555833d-03, 3.96009259d-06/
      data fpp( 2,12,1),fpp( 2,12,2)/-1.13961950d-03,-1.71267247d-06/
      data fpp( 2,13,1),fpp( 2,13,2)/ 1.08630472d-04, 8.79727633d-09/
      data fpp( 2,14,1),fpp( 2,14,2)/ 2.18284142d-04, 5.79483361d-07/
      data fpp( 2,15,1),fpp( 2,15,2)/ 8.35529624d-04, 3.91869281d-07/
      data fpp( 2,16,1),fpp( 2,16,2)/ 2.08257270d-03,-1.43896048d-06/
      data fpp( 2,17,1),fpp( 2,17,2)/ 2.65429164d-03,-2.52027348d-07/
      data fpp( 2,18,1),fpp( 2,18,2)/ 8.89181992d-04, 3.66269874d-07/
      data fpp( 2,19,1),fpp( 2,19,2)/ 1.64053714d-04, 3.66147851d-07/
      data fpp( 2,20,1),fpp( 2,20,2)/ 1.62206846d-05,-1.22612798d-08/
      data fpp( 2,21,1),fpp( 2,21,2)/ 8.93812114d-05, 4.49726763d-09/
      data fpp( 2,22,1),fpp( 2,22,2)/-4.29675739d-06,-3.27790751d-10/
      data fpp( 2,23,1),fpp( 2,23,2)/ 0.00000000d+00, 1.01389538d-09/
      data fpp( 3, 1,1),fpp( 3, 1,2)/ 0.00000000d+00,-1.43374560d-05/
      data fpp( 3, 2,1),fpp( 3, 2,2)/ 1.33723069d-05, 1.25291191d-06/
      data fpp( 3, 3,1),fpp( 3, 3,2)/ 2.18841344d-03, 8.97300833d-06/
      data fpp( 3, 4,1),fpp( 3, 4,2)/ 6.12805058d-03, 4.42390548d-05/
      data fpp( 3, 5,1),fpp( 3, 5,2)/ 7.96149254d-03,-6.49428274d-05/
      data fpp( 3, 6,1),fpp( 3, 6,2)/-9.44459127d-02,-6.85894499d-06/
      data fpp( 3, 7,1),fpp( 3, 7,2)/ 1.06773395d-01, 9.14180742d-06/
      data fpp( 3, 8,1),fpp( 3, 8,2)/ 3.28700987d-02, 2.69651530d-06/
      data fpp( 3, 9,1),fpp( 3, 9,2)/-9.19862866d-03, 5.38733138d-06/
      data fpp( 3,10,1),fpp( 3,10,2)/-1.84636788d-02,-1.64205180d-06/
      data fpp( 3,11,1),fpp( 3,11,2)/-5.46154584d-03, 2.48707581d-06/
      data fpp( 3,12,1),fpp( 3,12,2)/-5.72831742d-04,-8.35651454d-07/
      data fpp( 3,13,1),fpp( 3,13,2)/ 6.32933472d-05,-1.80699968d-08/
      data fpp( 3,14,1),fpp( 3,14,2)/ 8.75055018d-05, 4.74131441d-07/
      data fpp( 3,15,1),fpp( 3,15,2)/ 5.26146316d-04, 3.14423100d-09/
      data fpp( 3,16,1),fpp( 3,16,2)/ 1.67049555d-03,-6.90108365d-07/
      data fpp( 3,17,1),fpp( 3,17,2)/ 9.85979264d-04,-2.56510769d-07/
      data fpp( 3,18,1),fpp( 3,18,2)/ 7.92863029d-04, 2.97751442d-07/
      data fpp( 3,19,1),fpp( 3,19,2)/ 6.28120019d-05, 1.84505000d-07/
      data fpp( 3,20,1),fpp( 3,20,2)/-5.27239624d-06, 1.62855662d-09/
      data fpp( 3,21,1),fpp( 3,21,2)/-2.33423990d-06, 3.38077322d-09/
      data fpp( 3,22,1),fpp( 3,22,2)/ 1.40386509d-05,-1.51649490d-10/
      data fpp( 3,23,1),fpp( 3,23,2)/ 0.00000000d+00,-2.17417525d-09/
      data fpp( 4, 1,1),fpp( 4, 1,2)/ 0.00000000d+00,-2.19688444d-05/
      data fpp( 4, 2,1),fpp( 4, 2,2)/-7.10971401d-05, 1.04368881d-06/
      data fpp( 4, 3,1),fpp( 4, 3,2)/-1.12553562d-03, 2.14876892d-05/
      data fpp( 4, 4,1),fpp( 4, 4,2)/ 4.01788121d-02, 5.09215546d-05/
      data fpp( 4, 5,1),fpp( 4, 5,2)/-1.35592115d-01,-1.17243507d-04/
      data fpp( 4, 6,1),fpp( 4, 6,2)/ 2.35557818d-01, 6.84636751d-05/
      data fpp( 4, 7,1),fpp( 4, 7,2)/ 3.01918199d-02,-6.12519929d-05/
      data fpp( 4, 8,1),fpp( 4, 8,2)/-2.96455095d-02, 2.59706966d-05/
      data fpp( 4, 9,1),fpp( 4, 9,2)/ 8.70247789d-03, 9.89800645d-06/
      data fpp( 4,10,1),fpp( 4,10,2)/ 2.14016641d-02,-4.35767650d-07/
      data fpp( 4,11,1),fpp( 4,11,2)/ 5.63741691d-04, 5.71464153d-07/
      data fpp( 4,12,1),fpp( 4,12,2)/-3.13053528d-04,-3.10488961d-07/
      data fpp( 4,13,1),fpp( 4,13,2)/-3.18038609d-05,-5.49083098d-08/
      data fpp( 4,14,1),fpp( 4,14,2)/ 6.76938504d-05, 3.83722200d-07/
      data fpp( 4,15,1),fpp( 4,15,2)/ 3.53885111d-04,-2.00180489d-07/
      data fpp( 4,16,1),fpp( 4,16,2)/ 1.71144510d-03,-2.45400243d-07/
      data fpp( 4,17,1),fpp( 4,17,2)/ 1.38179130d-03,-1.97618539d-07/
      data fpp( 4,18,1),fpp( 4,18,2)/ 3.85365892d-04, 1.76074397d-07/
      data fpp( 4,19,1),fpp( 4,19,2)/ 4.66982787d-05, 1.07120949d-07/
      data fpp( 4,20,1),fpp( 4,20,2)/-1.13109968d-06, 3.24180755d-09/
      data fpp( 4,21,1),fpp( 4,21,2)/-2.04425179d-06, 2.31182104d-09/
      data fpp( 4,22,1),fpp( 4,22,2)/-1.58578461d-05,-4.89091727d-10/
      data fpp( 4,23,1),fpp( 4,23,2)/ 0.00000000d+00,-2.75545414d-09/
      data fpp( 5, 1,1),fpp( 5, 1,2)/ 0.00000000d+00,-3.20542311d-05/
      data fpp( 5, 2,1),fpp( 5, 2,2)/ 2.83016253d-04,-1.32095377d-05/
      data fpp( 5, 3,1),fpp( 5, 3,2)/-6.65027096d-03, 8.90371820d-05/
      data fpp( 5, 4,1),fpp( 5, 4,2)/-6.51132992d-02,-1.00623190d-04/
      data fpp( 5, 5,1),fpp( 5, 5,2)/ 5.13709681d-02, 1.30145979d-04/
      data fpp( 5, 6,1),fpp( 5, 6,2)/-5.73273612d-02,-1.53443125d-04/
      data fpp( 5, 7,1),fpp( 5, 7,2)/-9.27866742d-02,-1.40974796d-05/
      data fpp( 5, 8,1),fpp( 5, 8,2)/ 6.49393922d-03, 5.29738432d-05/
      data fpp( 5, 9,1),fpp( 5, 9,2)/-2.06728291d-03, 8.63810667d-06/
      data fpp( 5,10,1),fpp( 5,10,2)/-8.07297767d-03,-7.82041620d-07/
      data fpp( 5,11,1),fpp( 5,11,2)/-5.67420925d-04, 7.99659812d-07/
      data fpp( 5,12,1),fpp( 5,12,2)/-1.60954145d-04,-3.44797628d-07/
      data fpp( 5,13,1),fpp( 5,13,2)/ 4.59220965d-05, 2.03307011d-08/
      data fpp( 5,14,1),fpp( 5,14,2)/ 6.77190968d-05, 2.52074824d-07/
      data fpp( 5,15,1),fpp( 5,15,2)/ 4.22313238d-04,-2.01229997d-07/
      data fpp( 5,16,1),fpp( 5,16,2)/ 7.05724050d-04,-7.65548364d-08/
      data fpp( 5,17,1),fpp( 5,17,2)/ 5.36855518d-04,-1.40550658d-07/
      data fpp( 5,18,1),fpp( 5,18,2)/ 1.91673403d-04, 1.02357467d-07/
      data fpp( 5,19,1),fpp( 5,19,2)/ 2.63948832d-05, 6.71207892d-08/
      data fpp( 5,20,1),fpp( 5,20,2)/-8.20320502d-06, 2.95937609d-09/
      data fpp( 5,21,1),fpp( 5,21,2)/-7.48875293d-06, 8.41706437d-10/
      data fpp( 5,22,1),fpp( 5,22,2)/ 7.39273346d-06, 2.73798161d-10/
      data fpp( 5,23,1),fpp( 5,23,2)/ 0.00000000d+00,-7.36899080d-10/
      data fpp( 6, 1,1),fpp( 6, 1,2)/ 0.00000000d+00,-3.80888663d-05/
      data fpp( 6, 2,1),fpp( 6, 2,2)/-1.03096787d-03,-2.32706675d-05/
      data fpp( 6, 3,1),fpp( 6, 3,2)/ 7.65061946d-03, 1.27713136d-04/
      data fpp( 6, 4,1),fpp( 6, 4,2)/ 3.75503845d-02,-1.97882677d-04/
      data fpp( 6, 5,1),fpp( 6, 5,2)/-6.17437572d-02, 3.30675973d-04/
      data fpp( 6, 6,1),fpp( 6, 6,2)/-1.65560374d-01,-3.85530013d-04/
      data fpp( 6, 7,1),fpp( 6, 7,2)/-2.67911232d-02, 1.04247280d-04/
      data fpp( 6, 8,1),fpp( 6, 8,2)/-1.79182474d-02, 2.72328924d-05/
      data fpp( 6, 9,1),fpp( 6, 9,2)/-5.21534624d-03, 1.54235501d-05/
      data fpp( 6,10,1),fpp( 6,10,2)/ 2.64246568d-04,-2.83789654d-06/
      data fpp( 6,11,1),fpp( 6,11,2)/-2.38057991d-04, 1.27343607d-06/
      data fpp( 6,12,1),fpp( 6,12,2)/-6.91298933d-05,-4.28247723d-07/
      data fpp( 6,13,1),fpp( 6,13,2)/-1.88452515d-06, 7.23548255d-08/
      data fpp( 6,14,1),fpp( 6,14,2)/-8.57023742d-06, 1.62828421d-07/
      data fpp( 6,15,1),fpp( 6,15,2)/ 2.36861936d-04,-1.71668510d-07/
      data fpp( 6,16,1),fpp( 6,16,2)/ 3.91658698d-04,-2.95438015d-09/
      data fpp( 6,17,1),fpp( 6,17,2)/ 3.10786624d-04,-1.06313969d-07/
      data fpp( 6,18,1),fpp( 6,18,2)/ 1.25940495d-04, 6.76102567d-08/
      data fpp( 6,19,1),fpp( 6,19,2)/ 2.17221885d-05, 3.98729423d-08/
      data fpp( 6,20,1),fpp( 6,20,2)/ 1.59439198d-05, 3.89797424d-09/
      data fpp( 6,21,1),fpp( 6,21,2)/ 7.99926351d-06, 3.35160782d-10/
      data fpp( 6,22,1),fpp( 6,22,2)/-1.71308775d-06, 1.61382634d-10/
      data fpp( 6,23,1),fpp( 6,23,2)/ 0.00000000d+00,-9.80691317d-10/
      data fpp( 7, 1,1),fpp( 7, 1,2)/ 0.00000000d+00,-4.20129066d-05/
      data fpp( 7, 2,1),fpp( 7, 2,2)/ 1.27289549d-03,-3.83077867d-05/
      data fpp( 7, 3,1),fpp( 7, 3,2)/-3.77322290d-03, 2.07316054d-04/
      data fpp( 7, 4,1),fpp( 7, 4,2)/-3.87620039d-02,-3.93775627d-04/
      data fpp( 7, 5,1),fpp( 7, 5,2)/ 9.61932876d-02, 5.26718456d-04/
      data fpp( 7, 6,1),fpp( 7, 6,2)/ 9.28273015d-02,-4.51427796d-04/
      data fpp( 7, 7,1),fpp( 7, 7,2)/ 4.24622068d-02, 1.00655128d-04/
      data fpp( 7, 8,1),fpp( 7, 8,2)/ 3.45577263d-03, 4.10648854d-05/
      data fpp( 7, 9,1),fpp( 7, 9,2)/ 6.51868017d-03, 7.44213069d-06/
      data fpp( 7,10,1),fpp( 7,10,2)/ 8.47491313d-05,-1.66163479d-06/
      data fpp( 7,11,1),fpp( 7,11,2)/-4.76155639d-05, 6.66008472d-07/
      data fpp( 7,12,1),fpp( 7,12,2)/-1.36332479d-05,-2.10999097d-07/
      data fpp( 7,13,1),fpp( 7,13,2)/-3.80747282d-06, 2.31879176d-08/
      data fpp( 7,14,1),fpp( 7,14,2)/ 6.83511639d-05, 1.12247427d-07/
      data fpp( 7,15,1),fpp( 7,15,2)/ 4.27575729d-05,-1.40977626d-07/
      data fpp( 7,16,1),fpp( 7,16,2)/ 1.28161880d-04, 5.14630753d-08/
      data fpp( 7,17,1),fpp( 7,17,2)/ 8.32123701d-05,-6.36746757d-08/
      data fpp( 7,18,1),fpp( 7,18,2)/ 3.18418131d-05, 3.16356274d-08/
      data fpp( 7,19,1),fpp( 7,19,2)/-1.86400722d-06, 1.69321661d-08/
      data fpp( 7,20,1),fpp( 7,20,2)/-1.07301568d-05, 2.35708044d-10/
      data fpp( 7,21,1),fpp( 7,21,2)/-3.75341407d-06, 7.25001680d-10/
      data fpp( 7,22,1),fpp( 7,22,2)/ 2.94289651d-06, 4.64285234d-10/
      data fpp( 7,23,1),fpp( 7,23,2)/ 0.00000000d+00, 4.17857383d-10/
      data fpp( 8, 1,1),fpp( 8, 1,2)/ 0.00000000d+00,-4.24460556d-05/
      data fpp( 8, 2,1),fpp( 8, 2,2)/-7.74114098d-04,-2.45794889d-05/
      data fpp( 8, 3,1),fpp( 8, 3,2)/ 4.28272145d-04, 1.46627211d-04/
      data fpp( 8, 4,1),fpp( 8, 4,2)/-8.10368989d-04,-2.18856555d-04/
      data fpp( 8, 5,1),fpp( 8, 5,2)/ 2.49181067d-02, 3.03883810d-04/
      data fpp( 8, 6,1),fpp( 8, 6,2)/-8.96968325d-02,-3.29670686d-04/
      data fpp( 8, 7,1),fpp( 8, 7,2)/-8.68047040d-02, 4.06749321d-05/
      data fpp( 8, 8,1),fpp( 8, 8,2)/ 5.57265691d-03, 1.00831757d-04/
      data fpp( 8, 9,1),fpp( 8, 9,2)/-4.36987445d-03,-1.62307604d-05/
      data fpp( 8,10,1),fpp( 8,10,2)/ 1.17569067d-05, 5.26220253d-06/
      data fpp( 8,11,1),fpp( 8,11,2)/-3.34797533d-05,-1.32124977d-06/
      data fpp( 8,12,1),fpp( 8,12,2)/ 5.16288494d-06, 3.46196538d-07/
      data fpp( 8,13,1),fpp( 8,13,2)/ 3.61441643d-06,-1.01336383d-07/
      data fpp( 8,14,1),fpp( 8,14,2)/-4.73344180d-05, 7.35489954d-08/
      data fpp( 8,15,1),fpp( 8,15,2)/ 6.76077722d-05,-7.16595982d-08/
      data fpp( 8,16,1),fpp( 8,16,2)/ 4.21937829d-05, 2.46893976d-08/
      data fpp( 8,17,1),fpp( 8,17,2)/ 5.53638958d-05,-2.22979921d-08/
      data fpp( 8,18,1),fpp( 8,18,2)/ 1.96922526d-05, 1.05025708d-08/
      data fpp( 8,19,1),fpp( 8,19,2)/ 1.57338404d-05, 9.08770893d-09/
      data fpp( 8,20,1),fpp( 8,20,2)/ 8.97670750d-06,-6.53406518d-10/
      data fpp( 8,21,1),fpp( 8,21,2)/ 2.51439276d-06,-4.74082861d-10/
      data fpp( 8,22,1),fpp( 8,22,2)/-1.00584983d-05, 7.49737960d-10/
      data fpp( 8,23,1),fpp( 8,23,2)/ 0.00000000d+00, 1.67513102d-09/
      data fpp( 9, 1,1),fpp( 9, 1,2)/ 0.00000000d+00,-3.37713230d-05/
      data fpp( 9, 2,1),fpp( 9, 2,2)/ 2.03560899d-04, 2.77264598d-06/
      data fpp( 9, 3,1),fpp( 9, 3,2)/ 4.02634320d-04, 2.48671391d-05/
      data fpp( 9, 4,1),fpp( 9, 4,2)/-1.54345202d-02, 9.75347977d-05/
      data fpp( 9, 5,1),fpp( 9, 5,2)/-1.48179215d-01,-1.66320730d-04/
      data fpp( 9, 6,1),fpp( 9, 6,2)/-1.13597156d-03,-3.17574780d-05/
      data fpp( 9, 7,1),fpp( 9, 7,2)/ 6.45931093d-02, 7.01842419d-05/
      data fpp( 9, 8,1),fpp( 9, 8,2)/-3.36400265d-04, 8.31011033d-06/
      data fpp( 9, 9,1),fpp( 9, 9,2)/ 1.95031764d-03,-2.29483219d-07/
      data fpp( 9,10,1),fpp( 9,10,2)/ 2.87232418d-05, 5.12594494d-07/
      data fpp( 9,11,1),fpp( 9,11,2)/-4.49654229d-05,-1.12094756d-07/
      data fpp( 9,12,1),fpp( 9,12,2)/-1.60182918d-05, 3.29845293d-08/
      data fpp( 9,13,1),fpp( 9,13,2)/-1.65019291d-06,-2.04433615d-08/
      data fpp( 9,14,1),fpp( 9,14,2)/ 4.29865083d-05, 4.15889167d-08/
      data fpp( 9,15,1),fpp( 9,15,2)/-4.18866194d-06,-4.51123052d-08/
      data fpp( 9,16,1),fpp( 9,16,2)/ 2.85629888d-05, 1.40603041d-08/
      data fpp( 9,17,1),fpp( 9,17,2)/ 2.08320465d-05,-9.32891132d-09/
      data fpp( 9,18,1),fpp( 9,18,2)/ 1.98891767d-05, 8.85534115d-09/
      data fpp( 9,19,1),fpp( 9,19,2)/-5.57135419d-06,-2.92453292d-10/
      data fpp( 9,20,1),fpp( 9,20,2)/-5.67667317d-06, 7.14472017d-10/
      data fpp( 9,21,1),fpp( 9,21,2)/-3.30415699d-06,-1.36543477d-09/
      data fpp( 9,22,1),fpp( 9,22,2)/ 3.42910967d-05, 1.74726708d-09/
      data fpp( 9,23,1),fpp( 9,23,2)/ 0.00000000d+00, 3.37636646d-09/
      data fpp(10, 1,1),fpp(10, 1,2)/ 0.00000000d+00,-2.72733330d-06/
      data fpp(10, 2,1),fpp(10, 2,2)/-5.06294993d-05, 5.81706660d-06/
      data fpp(10, 3,1),fpp(10, 3,2)/-4.29309425d-04,-1.94225331d-05/
      data fpp(10, 4,1),fpp(10, 4,2)/ 3.15464497d-02, 7.35818657d-05/
      data fpp(10, 5,1),fpp(10, 5,2)/ 3.60757515d-02,-1.01593730d-04/
      data fpp(10, 6,1),fpp(10, 6,2)/ 5.08712187d-02, 4.92930537d-05/
      data fpp(10, 7,1),fpp(10, 7,2)/-7.26373320d-03,-1.68752850d-05/
      data fpp(10, 8,1),fpp(10, 8,2)/ 9.85444151d-04, 1.21024863d-05/
      data fpp(10, 9,1),fpp(10, 9,2)/-3.39896111d-04,-1.76266005d-06/
      data fpp(10,10,1),fpp(10,10,2)/ 2.18501261d-05, 7.28937018d-07/
      data fpp(10,11,1),fpp(10,11,2)/ 4.23414451d-05,-1.82888022d-07/
      data fpp(10,12,1),fpp(10,12,2)/ 1.24102824d-05, 5.12150717d-08/
      data fpp(10,13,1),fpp(10,13,2)/ 4.48635522d-06,-1.59722643d-08/
      data fpp(10,14,1),fpp(10,14,2)/-1.36116152d-05, 8.47398548d-09/
      data fpp(10,15,1),fpp(10,15,2)/ 9.14687550d-06,-1.72367762d-09/
      data fpp(10,16,1),fpp(10,16,2)/-1.39457382d-05,-9.37927499d-09/
      data fpp(10,17,1),fpp(10,17,2)/ 8.07918250d-07, 3.84077757d-09/
      data fpp(10,18,1),fpp(10,18,2)/-1.07489593d-05, 1.61647074d-11/
      data fpp(10,19,1),fpp(10,19,2)/ 2.05157640d-06, 2.09456360d-09/
      data fpp(10,20,1),fpp(10,20,2)/ 3.22998518d-06,-2.99441911d-09/
      data fpp(10,21,1),fpp(10,21,2)/ 3.20223519d-06, 9.88311284d-09/
      data fpp(10,22,1),fpp(10,22,2)/-5.36058886d-05,-9.53803224d-09/
      data fpp(10,23,1),fpp(10,23,2)/ 0.00000000d+00,-1.97309839d-08/
      data fpp(11, 1,1),fpp(11, 1,2)/ 0.00000000d+00, 5.26427775d-06/
      data fpp(11, 2,1),fpp(11, 2,2)/ 1.24570979d-05,-5.23855551d-06/
      data fpp(11, 3,1),fpp(11, 3,2)/ 1.19460338d-03, 1.55051443d-05/
      data fpp(11, 4,1),fpp(11, 4,2)/ 1.51172151d-03,-7.31140216d-05/
      data fpp(11, 5,1),fpp(11, 5,2)/ 6.84872085d-02, 1.18831742d-04/
      data fpp(11, 6,1),fpp(11, 6,2)/ 7.52659662d-03,-6.10409471d-05/
      data fpp(11, 7,1),fpp(11, 7,2)/ 4.06632350d-03, 1.04804634d-06/
      data fpp(11, 8,1),fpp(11, 8,2)/-2.03763377d-05, 2.15036176d-06/
      data fpp(11, 9,1),fpp(11, 9,2)/ 2.25266804d-04,-9.98933846d-08/
      data fpp(11,10,1),fpp(11,10,2)/-3.62374606d-06, 1.63499274d-07/
      data fpp(11,11,1),fpp(11,11,2)/-3.59003574d-05,-5.07037097d-08/
      data fpp(11,12,1),fpp(11,12,2)/-9.62283784d-06, 2.31155652d-08/
      data fpp(11,13,1),fpp(11,13,2)/-1.29522795d-06,-6.95855112d-09/
      data fpp(11,14,1),fpp(11,14,2)/-3.54004749d-06,-4.88136073d-09/
      data fpp(11,15,1),fpp(11,15,2)/ 5.46011599d-05, 1.08839940d-08/
      data fpp(11,16,1),fpp(11,16,2)/ 1.97199642d-05,-8.05461540d-09/
      data fpp(11,17,1),fpp(11,17,2)/ 2.93628052d-06, 3.34467553d-10/
      data fpp(11,18,1),fpp(11,18,2)/ 8.10666062d-06, 2.51674519d-09/
      data fpp(11,19,1),fpp(11,19,2)/-2.63495143d-06,-1.40144830d-09/
      data fpp(11,20,1),fpp(11,20,2)/-4.24326755d-06, 6.89047997d-10/
      data fpp(11,21,1),fpp(11,21,2)/-2.00478378d-06,-1.95474369d-09/
      data fpp(11,22,1),fpp(11,22,2)/ 3.76324577d-05, 2.32992677d-09/
      data fpp(11,23,1),fpp(11,23,2)/ 0.00000000d+00, 4.63503662d-09/
      data fpp(12, 1,1),fpp(12, 1,2)/ 0.00000000d+00, 2.10222897d-06/
      data fpp(12, 2,1),fpp(12, 2,2)/-8.19889221d-06,-3.59325793d-06/
      data fpp(12, 3,1),fpp(12, 3,2)/-1.19610410d-03, 1.58564028d-05/
      data fpp(12, 4,1),fpp(12, 4,2)/-5.33883570d-03,-5.27019531d-05/
      data fpp(12, 5,1),fpp(12, 5,2)/-1.77150856d-02, 7.49274098d-05/
      data fpp(12, 6,1),fpp(12, 6,2)/-4.82110520d-03,-4.30964861d-05/
      data fpp(12, 7,1),fpp(12, 7,2)/ 2.29439214d-04, 8.95133451d-06/
      data fpp(12, 8,1),fpp(12, 8,2)/ 1.70061200d-04,-1.97045194d-06/
      data fpp(12, 9,1),fpp(12, 9,2)/ 2.98288949d-05, 5.36073271d-07/
      data fpp(12,10,1),fpp(12,10,2)/ 6.14485816d-06,-8.17938404d-08/
      data fpp(12,11,1),fpp(12,11,2)/ 1.12599844d-05, 1.73020908d-08/
      data fpp(12,12,1),fpp(12,12,2)/ 2.00810689d-05, 6.58547708d-09/
      data fpp(12,13,1),fpp(12,13,2)/-8.05443418d-07,-1.18439991d-08/
      data fpp(12,14,1),fpp(12,14,2)/ 1.12718052d-05, 1.79905195d-08/
      data fpp(12,15,1),fpp(12,15,2)/-4.60515152d-05,-2.23180789d-08/
      data fpp(12,16,1),fpp(12,16,2)/-4.93411836d-06, 1.24817959d-08/
      data fpp(12,17,1),fpp(12,17,2)/ 5.44695965d-06,-2.40910477d-09/
      data fpp(12,18,1),fpp(12,18,2)/-6.77683155d-07, 7.54623189d-10/
      data fpp(12,19,1),fpp(12,19,2)/ 2.48822930d-06,-6.09387982d-10/
      data fpp(12,20,1),fpp(12,20,2)/ 4.74308501d-06, 1.08292874d-09/
      data fpp(12,21,1),fpp(12,21,2)/ 1.81689991d-06,-1.32232697d-09/
      data fpp(12,22,1),fpp(12,22,2)/-1.14239420d-05, 6.06379134d-10/
      data fpp(12,23,1),fpp(12,23,2)/ 0.00000000d+00, 1.29681043d-09/
      data fpp(13, 1,1),fpp(13, 1,2)/ 0.00000000d+00,-6.73997545d-07/
      data fpp(13, 2,1),fpp(13, 2,2)/ 1.23582421d-05,-6.48004910d-07/
      data fpp(13, 3,1),fpp(13, 3,2)/ 6.03611403d-04, 3.24201719d-06/
      data fpp(13, 4,1),fpp(13, 4,2)/ 1.51097134d-03,-6.39206384d-06/
      data fpp(13, 5,1),fpp(13, 5,2)/-1.59585381d-03, 6.17183816d-06/
      data fpp(13, 6,1),fpp(13, 6,2)/ 1.19795292d-03,-2.83688880d-06/
      data fpp(13, 7,1),fpp(13, 7,2)/ 1.90653622d-04, 5.29317041d-07/
      data fpp(13, 8,1),fpp(13, 8,2)/ 1.40468920d-05,-2.18779363d-07/
      data fpp(13, 9,1),fpp(13, 9,2)/ 2.13924808d-05, 1.25000411d-07/
      data fpp(13,10,1),fpp(13,10,2)/-8.73369649d-06,-2.32115522d-08/
      data fpp(13,11,1),fpp(13,11,2)/-5.99709673d-07, 1.70457975d-08/
      data fpp(13,12,1),fpp(13,12,2)/-2.28550046d-05,-1.67716378d-08/
      data fpp(13,13,1),fpp(13,13,2)/-5.11836997d-06, 1.34407539d-08/
      data fpp(13,14,1),fpp(13,14,2)/-1.08793189d-05,-8.19137760d-09/
      data fpp(13,15,1),fpp(13,15,2)/ 2.41042774d-05, 1.92475653d-09/
      data fpp(13,16,1),fpp(13,16,2)/ 1.06337518d-05, 3.49235147d-09/
      data fpp(13,17,1),fpp(13,17,2)/-2.78071919d-06,-2.69416240d-09/
      data fpp(13,18,1),fpp(13,18,2)/ 5.21170103d-07, 1.28429814d-09/
      data fpp(13,19,1),fpp(13,19,2)/ 1.12920328d-06,-4.30301651d-11/
      data fpp(13,20,1),fpp(13,20,2)/-3.64810500d-06,-1.11217748d-09/
      data fpp(13,21,1),fpp(13,21,2)/-6.05314385d-06, 2.91740091d-10/
      data fpp(13,22,1),fpp(13,22,2)/ 3.65816826d-06, 5.45217117d-10/
      data fpp(13,23,1),fpp(13,23,2)/ 0.00000000d+00, 1.12739144d-09/
      data fpp(14, 1,1),fpp(14, 1,2)/ 0.00000000d+00,-1.22204849d-08/
      data fpp(14, 2,1),fpp(14, 2,2)/-2.12340762d-05,-1.47590302d-08/
      data fpp(14, 3,1),fpp(14, 3,2)/-1.83674849d-04, 1.84566057d-08/
      data fpp(14, 4,1),fpp(14, 4,2)/ 2.76170022d-05,-7.34673925d-08/
      data fpp(14, 5,1),fpp(14, 5,2)/ 1.46500798d-04, 2.13012964d-07/
      data fpp(14, 6,1),fpp(14, 6,2)/-3.86706482d-04,-1.78584465d-07/
      data fpp(14, 7,1),fpp(14, 7,2)/-1.60537025d-05,-2.67510481d-09/
      data fpp(14, 8,1),fpp(14, 8,2)/ 3.77512321d-05,-3.15115866d-10/
      data fpp(14, 9,1),fpp(14, 9,2)/ 9.93451504d-06, 2.07355683d-08/
      data fpp(14,10,1),fpp(14,10,2)/ 7.45659445d-06,-8.49146899d-10/
      data fpp(14,11,1),fpp(14,11,2)/-1.41944790d-05, 1.26101932d-09/
      data fpp(14,12,1),fpp(14,12,2)/ 1.40056160d-05,-2.99493038d-09/
      data fpp(14,13,1),fpp(14,13,2)/ 2.06122566d-05, 3.51870218d-09/
      data fpp(14,14,1),fpp(14,14,2)/ 9.57880361d-06,-1.47987836d-09/
      data fpp(14,15,1),fpp(14,15,2)/-1.43655944d-05, 2.40081125d-09/
      data fpp(14,16,1),fpp(14,16,2)/-1.16008887d-05,-5.12336665d-09/
      data fpp(14,17,1),fpp(14,17,2)/ 5.00925043d-06, 4.29265537d-09/
      data fpp(14,18,1),fpp(14,18,2)/ 1.92633608d-06,-4.72548054d-11/
      data fpp(14,19,1),fpp(14,19,2)/-3.00504241d-06,-2.30363614d-09/
      data fpp(14,20,1),fpp(14,20,2)/ 3.84933501d-06, 2.61799379d-10/
      data fpp(14,21,1),fpp(14,21,2)/ 1.90623422d-05, 1.85643863d-09/
      data fpp(14,22,1),fpp(14,22,2)/-1.20873105d-06,-4.87553894d-10/
      data fpp(14,23,1),fpp(14,23,2)/ 0.00000000d+00,-1.70622305d-09/
      data fpp(15, 1,1),fpp(15, 1,2)/ 0.00000000d+00, 7.93474149d-08/
      data fpp(15, 2,1),fpp(15, 2,2)/ 2.56330179d-05, 3.65051701d-08/
      data fpp(15, 3,1),fpp(15, 3,2)/ 2.09571411d-05,-8.61680954d-08/
      data fpp(15, 4,1),fpp(15, 4,2)/ 9.95797579d-06, 7.05672115d-08/
      data fpp(15, 5,1),fpp(15, 5,2)/-6.07232758d-05, 6.99249478d-10/
      data fpp(15, 6,1),fpp(15, 6,2)/ 1.27103027d-04,-2.05642094d-08/
      data fpp(15, 7,1),fpp(15, 7,2)/ 2.17880795d-05,-2.16424119d-08/
      data fpp(15, 8,1),fpp(15, 8,2)/-3.32649869d-06, 3.93385705d-09/
      data fpp(15, 9,1),fpp(15, 9,2)/-4.26129646d-06, 8.30698370d-09/
      data fpp(15,10,1),fpp(15,10,2)/-1.82427535d-07,-4.68787962d-09/
      data fpp(15,11,1),fpp(15,11,2)/ 4.23719596d-05, 8.64453478d-09/
      data fpp(15,12,1),fpp(15,12,2)/-3.24557306d-06,-4.90259494d-10/
      data fpp(15,13,1),fpp(15,13,2)/-3.33837283d-05,-7.28349680d-09/
      data fpp(15,14,1),fpp(15,14,2)/-2.57503978d-06, 1.42424671d-09/
      data fpp(15,15,1),fpp(15,15,2)/ 1.16715557d-05, 5.18650998d-09/
      data fpp(15,16,1),fpp(15,16,2)/ 5.55381595d-06,-2.97028662d-09/
      data fpp(15,17,1),fpp(15,17,2)/-5.37517337d-06, 6.94636498d-10/
      data fpp(15,18,1),fpp(15,18,2)/-4.41343553d-06,-4.08259372d-10/
      data fpp(15,19,1),fpp(15,19,2)/ 1.83140714d-06,-8.61599008d-10/
      data fpp(15,20,1),fpp(15,20,2)/-3.77451753d-06, 4.45465540d-09/
      data fpp(15,21,1),fpp(15,21,2)/-4.02319950d-05,-7.35702261d-09/
      data fpp(15,22,1),fpp(15,22,2)/-4.43597161d-07, 3.37343503d-09/
      data fpp(15,23,1),fpp(15,23,2)/ 0.00000000d+00, 7.66328248d-09/
      data fpp(16, 1,1),fpp(16, 1,2)/ 0.00000000d+00,-1.41926178d-08/
      data fpp(16, 2,1),fpp(16, 2,2)/-1.37979954d-05,-6.81476444d-09/
      data fpp(16, 3,1),fpp(16, 3,2)/ 9.84628477d-06, 1.26516755d-08/
      data fpp(16, 4,1),fpp(16, 4,2)/-5.94890533d-06,-1.01919377d-08/
      data fpp(16, 5,1),fpp(16, 5,2)/ 1.38923050d-05, 1.13160753d-08/
      data fpp(16, 6,1),fpp(16, 6,2)/-2.27056277d-05,-8.67236331d-09/
      data fpp(16, 7,1),fpp(16, 7,2)/ 2.40138472d-06,-1.02266220d-08/
      data fpp(16, 8,1),fpp(16, 8,2)/ 5.55476263d-06, 3.97885140d-09/
      data fpp(16, 9,1),fpp(16, 9,2)/ 5.61067079d-06, 1.51121642d-09/
      data fpp(16,10,1),fpp(16,10,2)/ 3.77311569d-06, 6.67692504d-09/
      data fpp(16,11,1),fpp(16,11,2)/-3.67933594d-05,-1.20189166d-08/
      data fpp(16,12,1),fpp(16,12,2)/-4.02332373d-06, 7.19874127d-09/
      data fpp(16,13,1),fpp(16,13,2)/ 1.69226564d-05, 6.23951509d-10/
      data fpp(16,14,1),fpp(16,14,2)/-1.12786445d-05,-4.89454730d-09/
      data fpp(16,15,1),fpp(16,15,2)/-9.82062849d-06, 6.35423770d-09/
      data fpp(16,16,1),fpp(16,16,2)/ 1.38562491d-06,-3.12240349d-09/
      data fpp(16,17,1),fpp(16,17,2)/-8.55696381d-09, 7.35376262d-10/
      data fpp(16,18,1),fpp(16,18,2)/ 2.22740606d-06,-4.19101560d-10/
      data fpp(16,19,1),fpp(16,19,2)/ 1.79413844d-07, 1.54102998d-09/
      data fpp(16,20,1),fpp(16,20,2)/ 3.74873510d-06,-7.54501834d-09/
      data fpp(16,21,1),fpp(16,21,2)/ 3.23656379d-05, 1.12390434d-08/
      data fpp(16,22,1),fpp(16,22,2)/ 1.48311969d-06,-3.81115526d-09/
      data fpp(16,23,1),fpp(16,23,2)/ 0.00000000d+00,-9.19442237d-09/
      data fpp(17, 1,1),fpp(17, 1,2)/ 0.00000000d+00, 1.20266754d-08/
      data fpp(17, 2,1),fpp(17, 2,2)/ 6.57130621d-06, 4.74664929d-09/
      data fpp(17, 3,1),fpp(17, 3,2)/-5.45904332d-06,-2.21327251d-09/
      data fpp(17, 4,1),fpp(17, 4,2)/-8.14229944d-06,-1.02935592d-08/
      data fpp(17, 5,1),fpp(17, 5,2)/-8.15883295d-06, 1.87509451d-10/
      data fpp(17, 6,1),fpp(17, 6,2)/ 1.06167407d-05, 7.14352143d-09/
      data fpp(17, 7,1),fpp(17, 7,2)/ 4.80333130d-06,-9.56159517d-09/
      data fpp(17, 8,1),fpp(17, 8,2)/ 1.36845704d-06, 9.50285926d-09/
      data fpp(17, 9,1),fpp(17, 9,2)/-5.19470501d-06,-4.44984187d-09/
      data fpp(17,10,1),fpp(17,10,2)/-2.27887673d-05, 1.99809599d-09/
      data fpp(17,11,1),fpp(17,11,2)/ 1.50632248d-05,-3.54254208d-09/
      data fpp(17,12,1),fpp(17,12,2)/ 5.90812782d-06, 7.37207234d-09/
      data fpp(17,13,1),fpp(17,13,2)/-5.48636928d-06,-9.74574728d-09/
      data fpp(17,14,1),fpp(17,14,2)/ 1.66455082d-05, 5.21091679d-09/
      data fpp(17,15,1),fpp(17,15,2)/ 1.26210578d-05, 7.50208012d-09/
      data fpp(17,16,1),fpp(17,16,2)/ 1.20396630d-08,-1.12192373d-08/
      data fpp(17,17,1),fpp(17,17,2)/ 2.94530546d-06, 6.17486901d-09/
      data fpp(17,18,1),fpp(17,18,2)/-8.15729855d-07,-2.08023877d-09/
      data fpp(17,19,1),fpp(17,19,2)/-1.15231758d-06,-2.53913920d-10/
      data fpp(17,20,1),fpp(17,20,2)/-8.97943865d-06, 6.95894453d-10/
      data fpp(17,21,1),fpp(17,21,2)/-1.33974629d-05,-7.29663891d-10/
      data fpp(17,22,1),fpp(17,22,2)/-1.64800086d-06, 4.22761112d-10/
      data fpp(17,23,1),fpp(17,23,2)/ 0.00000000d+00, 8.38619444d-10/
      data fpp(18, 1,1),fpp(18, 1,2)/ 0.00000000d+00, 4.99970321d-09/
      data fpp(18, 2,1),fpp(18, 2,2)/-6.48722939d-06, 4.00593572d-10/
      data fpp(18, 3,1),fpp(18, 3,2)/ 1.32322183d-06,-1.80207750d-09/
      data fpp(18, 4,1),fpp(18, 4,2)/ 2.31847697d-05,-1.23922836d-08/
      data fpp(18, 5,1),fpp(18, 5,2)/ 8.07636009d-06, 1.53712118d-08/
      data fpp(18, 6,1),fpp(18, 6,2)/-5.76133512d-06,-8.29256353d-09/
      data fpp(18, 7,1),fpp(18, 7,2)/-8.28137657d-06,-1.40095767d-09/
      data fpp(18, 8,1),fpp(18, 8,2)/-1.02859079d-06, 6.69639421d-09/
      data fpp(18, 9,1),fpp(18, 9,2)/ 1.11681492d-05,-2.29846192d-08/
      data fpp(18,10,1),fpp(18,10,2)/ 4.47152867d-05, 2.96056604d-08/
      data fpp(18,11,1),fpp(18,11,2)/-1.45953983d-06,-1.86380224d-08/
      data fpp(18,12,1),fpp(18,12,2)/-3.60918755d-06, 5.94642921d-09/
      data fpp(18,13,1),fpp(18,13,2)/ 2.35615400d-06,-1.54769445d-09/
      data fpp(18,14,1),fpp(18,14,2)/-1.33033881d-05,-3.55651403d-10/
      data fpp(18,15,1),fpp(18,15,2)/-9.99693610d-06, 2.37030007d-09/
      data fpp(18,16,1),fpp(18,16,2)/-8.76711690d-06,-2.52554886d-09/
      data fpp(18,17,1),fpp(18,17,2)/-2.43933153d-06,-6.81046187d-11/
      data fpp(18,18,1),fpp(18,18,2)/-2.97819978d-07, 1.59796734d-09/
      data fpp(18,19,1),fpp(18,19,2)/ 1.09652312d-06,-3.92376473d-09/
      data fpp(18,20,1),fpp(18,20,2)/ 2.21690195d-05, 6.89709158d-09/
      data fpp(18,21,1),fpp(18,21,2)/ 1.22421380d-06,-5.66460158d-09/
      data fpp(18,22,1),fpp(18,22,2)/ 1.10888374d-06, 1.96131474d-09/
      data fpp(18,23,1),fpp(18,23,2)/ 0.00000000d+00, 3.81934263d-09/
      data fpp(19, 1,1),fpp(19, 1,2)/ 0.00000000d+00, 5.63417210d-09/
      data fpp(19, 2,1),fpp(19, 2,2)/ 3.57918764d-06, 1.13165579d-09/
      data fpp(19, 3,1),fpp(19, 3,2)/-3.92754419d-06, 3.06392047d-08/
      data fpp(19, 4,1),fpp(19, 4,2)/-4.12103996d-05,-5.88884747d-08/
      data fpp(19, 5,1),fpp(19, 5,2)/ 9.35644898d-06, 2.49146941d-08/
      data fpp(19, 6,1),fpp(19, 6,2)/ 4.38156454d-06,-4.77030185d-09/
      data fpp(19, 7,1),fpp(19, 7,2)/ 1.52018859d-05, 6.16651324d-09/
      data fpp(19, 8,1),fpp(19, 8,2)/-1.29097316d-05, 4.10424889d-09/
      data fpp(19, 9,1),fpp(19, 9,2)/-4.30486887d-05,-5.78350878d-09/
      data fpp(19,10,1),fpp(19,10,2)/-3.18932826d-05, 3.89840191d-09/
      data fpp(19,11,1),fpp(19,11,2)/-8.79713806d-06,-3.21009886d-09/
      data fpp(19,12,1),fpp(19,12,2)/ 2.68374602d-06, 2.34199353d-09/
      data fpp(19,13,1),fpp(19,13,2)/ 9.48783896d-07,-1.35787525d-09/
      data fpp(19,14,1),fpp(19,14,2)/ 1.10486785d-05, 1.28950748d-09/
      data fpp(19,15,1),fpp(19,15,2)/ 2.05309379d-06,-2.60015468d-09/
      data fpp(19,16,1),fpp(19,16,2)/ 1.83175250d-05, 4.91111122d-09/
      data fpp(19,17,1),fpp(19,17,2)/-2.22130053d-06,-4.44429021d-09/
      data fpp(19,18,1),fpp(19,18,2)/ 2.21269467d-06, 8.66049636d-10/
      data fpp(19,19,1),fpp(19,19,2)/ 1.74586075d-06, 5.18009167d-09/
      data fpp(19,20,1),fpp(19,20,2)/-2.98759395d-05,-9.58641632d-09/
      data fpp(19,21,1),fpp(19,21,2)/ 3.97512537d-06, 6.16557363d-09/
      data fpp(19,22,1),fpp(19,22,2)/-7.24174288d-08,-6.75878179d-10/
      data fpp(19,23,1),fpp(19,23,2)/ 0.00000000d+00,-1.06206091d-09/
      data fpp(20, 1,1),fpp(20, 1,2)/ 0.00000000d+00, 1.18701228d-08/
      data fpp(20, 2,1),fpp(20, 2,2)/-3.29521154d-07, 1.06597544d-08/
      data fpp(20, 3,1),fpp(20, 3,2)/ 5.38695491d-06,-1.61091403d-08/
      data fpp(20, 4,1),fpp(20, 4,2)/ 1.86568286d-05, 4.65768069d-08/
      data fpp(20, 5,1),fpp(20, 5,2)/-2.45021560d-05,-8.13980872d-08/
      data fpp(20, 6,1),fpp(20, 6,2)/-2.76492304d-06, 6.06155417d-08/
      data fpp(20, 7,1),fpp(20, 7,2)/-1.05261671d-05,-4.58640798d-08/
      data fpp(20, 8,1),fpp(20, 8,2)/ 2.11675172d-05, 7.64077747d-09/
      data fpp(20, 9,1),fpp(20, 9,2)/ 5.00266054d-05, 3.69009699d-08/
      data fpp(20,10,1),fpp(20,10,2)/ 1.85784367d-06,-2.57232985d-08/
      data fpp(20,11,1),fpp(20,11,2)/ 9.64809205d-06, 1.19922240d-08/
      data fpp(20,12,1),fpp(20,12,2)/-2.62579653d-06,-5.44559761d-09/
      data fpp(20,13,1),fpp(20,13,2)/-1.65128959d-06, 3.19016640d-09/
      data fpp(20,14,1),fpp(20,14,2)/-1.28913258d-05,-4.91506800d-09/
      data fpp(20,15,1),fpp(20,15,2)/ 2.84560927d-07, 6.27010558d-09/
      data fpp(20,16,1),fpp(20,16,2)/-1.20029830d-05,-5.76535433d-09/
      data fpp(20,17,1),fpp(20,17,2)/ 2.32453366d-06, 3.59131172d-09/
      data fpp(20,18,1),fpp(20,18,2)/-2.55295871d-06,-7.99892556d-10/
      data fpp(20,19,1),fpp(20,19,2)/-3.57996611d-06,-9.91741498d-10/
      data fpp(20,20,1),fpp(20,20,2)/ 1.33347384d-05, 1.16685855d-09/
      data fpp(20,21,1),fpp(20,21,2)/-2.12471528d-06,-6.75692685d-10/
      data fpp(20,22,1),fpp(20,22,2)/ 3.68078597d-06, 3.35912196d-10/
      data fpp(20,23,1),fpp(20,23,2)/ 0.00000000d+00, 5.32043902d-10/
      data fpp(21, 1,1),fpp(21, 1,2)/ 0.00000000d+00, 2.51536417d-08/
      data fpp(21, 2,1),fpp(21, 2,2)/ 1.04561209d-06, 1.16927166d-08/
      data fpp(21, 3,1),fpp(21, 3,2)/-3.67148691d-06,-1.19245082d-08/
      data fpp(21, 4,1),fpp(21, 4,2)/ 8.28417104d-06, 5.31627892d-12/
      data fpp(21, 5,1),fpp(21, 5,2)/ 1.04362208d-05, 2.30324311d-09/
      data fpp(21, 6,1),fpp(21, 6,2)/ 1.96203376d-06,-2.01828873d-09/
      data fpp(21, 7,1),fpp(21, 7,2)/ 4.95263301d-06, 9.69911814d-10/
      data fpp(21, 8,1),fpp(21, 8,2)/-7.61856968d-06,-1.86135853d-09/
      data fpp(21, 9,1),fpp(21, 9,2)/-1.80562256d-05, 4.07552229d-09/
      data fpp(21,10,1),fpp(21,10,2)/ 1.00693762d-05,-2.89588760d-09/
      data fpp(21,11,1),fpp(21,11,2)/-3.29554813d-06, 3.08028124d-10/
      data fpp(21,12,1),fpp(21,12,2)/ 9.63491091d-07, 2.26377511d-09/
      data fpp(21,13,1),fpp(21,13,2)/ 2.05109356d-07,-5.76312855d-09/
      data fpp(21,14,1),fpp(21,14,2)/ 7.93863369d-06, 7.58873910d-09/
      data fpp(21,15,1),fpp(21,15,2)/ 1.60677148d-08,-4.19182787d-09/
      data fpp(21,16,1),fpp(21,16,2)/ 3.79826016d-06, 7.78572360d-10/
      data fpp(21,17,1),fpp(21,17,2)/-2.67578510d-07,-1.22461574d-10/
      data fpp(21,18,1),fpp(21,18,2)/ 1.36806590d-06,-2.88726062d-10/
      data fpp(21,19,1),fpp(21,19,2)/ 2.10264654d-06, 1.27736582d-09/
      data fpp(21,20,1),fpp(21,20,2)/-2.86516841d-06,-1.82073723d-09/
      data fpp(21,21,1),fpp(21,21,2)/ 4.32300683d-07, 3.60558310d-09/
      data fpp(21,22,1),fpp(21,22,2)/-4.55434162d-06,-3.60159517d-09/
      data fpp(21,23,1),fpp(21,23,2)/ 0.00000000d+00,-7.19920241d-09/
      data fpp(22, 1,1),fpp(22, 1,2)/ 0.00000000d+00,-3.09520580d-08/
      data fpp(22, 2,1),fpp(22, 2,2)/-5.88245994d-07,-2.00958840d-08/
      data fpp(22, 3,1),fpp(22, 3,2)/ 4.27658517d-06, 1.13735594d-07/
      data fpp(22, 4,1),fpp(22, 4,2)/-1.51434445d-05,-1.82846492d-07/
      data fpp(22, 5,1),fpp(22, 5,2)/-9.34612792d-07, 1.28050373d-07/
      data fpp(22, 6,1),fpp(22, 6,2)/-1.17955421d-06,-4.13550005d-08/
      data fpp(22, 7,1),fpp(22, 7,2)/-2.81272537d-06, 8.56962899d-09/
      data fpp(22, 8,1),fpp(22, 8,2)/ 7.98912644d-07,-9.72351546d-09/
      data fpp(22, 9,1),fpp(22, 9,2)/ 3.52395873d-06, 3.03244329d-08/
      data fpp(22,10,1),fpp(22,10,2)/-1.43767099d-05,-3.69115408d-08/
      data fpp(22,11,1),fpp(22,11,2)/ 4.36898791d-07, 2.19217304d-08/
      data fpp(22,12,1),fpp(22,12,2)/-3.07693573d-07,-5.17538090d-09/
      data fpp(22,13,1),fpp(22,13,2)/ 1.44238108d-08, 1.77979317d-09/
      data fpp(22,14,1),fpp(22,14,2)/-3.34883231d-06,-7.43791776d-10/
      data fpp(22,15,1),fpp(22,15,2)/-3.02153243d-07,-4.62606670d-12/
      data fpp(22,16,1),fpp(22,16,2)/-1.11264269d-06, 1.62296042d-10/
      data fpp(22,17,1),fpp(22,17,2)/-5.84689635d-08,-4.45581026d-11/
      data fpp(22,18,1),fpp(22,18,2)/-5.26035672d-07, 1.59363680d-11/
      data fpp(22,19,1),fpp(22,19,2)/-8.20489265d-07,-1.91873693d-11/
      data fpp(22,20,1),fpp(22,20,2)/ 7.67695853d-07, 6.08131093d-11/
      data fpp(22,21,1),fpp(22,21,2)/-1.08533017d-07,-2.24065068d-10/
      data fpp(22,22,1),fpp(22,22,2)/ 2.12542160d-06, 2.35447162d-10/
      data fpp(22,23,1),fpp(22,23,2)/ 0.00000000d+00, 4.82276419d-10/
      data fpp(23, 1,1),fpp(23, 1,2)/ 0.00000000d+00, 3.03799219d-08/
      data fpp(23, 2,1),fpp(23, 2,2)/ 3.47371888d-07, 1.36401561d-08/
      data fpp(23, 3,1),fpp(23, 3,2)/-4.07485376d-06,-2.73405465d-08/
      data fpp(23, 4,1),fpp(23, 4,2)/ 1.00496070d-05, 1.65220298d-08/
      data fpp(23, 5,1),fpp(23, 5,2)/-2.17769583d-07,-5.14757287d-09/
      data fpp(23, 6,1),fpp(23, 6,2)/ 8.36183086d-07, 1.66826164d-09/
      data fpp(23, 7,1),fpp(23, 7,2)/ 1.49826849d-06, 8.74526326d-10/
      data fpp(23, 8,1),fpp(23, 8,2)/ 3.42919104d-07,-2.76636694d-09/
      data fpp(23, 9,1),fpp(23, 9,2)/-3.59609309d-07, 2.99094143d-09/
      data fpp(23,10,1),fpp(23,10,2)/ 8.79746356d-06,-2.18964082d-09/
      data fpp(23,11,1),fpp(23,11,2)/ 1.07952969d-07, 9.67621849d-10/
      data fpp(23,12,1),fpp(23,12,2)/ 2.67283202d-07,-4.80846575d-10/
      data fpp(23,13,1),fpp(23,13,2)/ 2.17195400d-07, 9.55764451d-10/
      data fpp(23,14,1),fpp(23,14,2)/ 1.13669556d-06,-9.42211229d-10/
      data fpp(23,15,1),fpp(23,15,2)/ 2.32545258d-07, 4.13080464d-10/
      data fpp(23,16,1),fpp(23,16,2)/ 4.12310597d-07,-1.10110629d-10/
      data fpp(23,17,1),fpp(23,17,2)/ 2.14543639d-08, 2.73620507d-11/
      data fpp(23,18,1),fpp(23,18,2)/ 1.60767842d-08, 6.62426098d-13/
      data fpp(23,19,1),fpp(23,19,2)/ 2.19310520d-07,-3.00117551d-11/
      data fpp(23,20,1),fpp(23,20,2)/-2.05615004d-07, 1.19384594d-10/
      data fpp(23,21,1),fpp(23,21,2)/ 1.83138676d-09,-4.47526621d-10/
      data fpp(23,22,1),fpp(23,22,2)/-3.47344789d-07, 4.70721892d-10/
      data fpp(23,23,1),fpp(23,23,2)/ 0.00000000d+00, 9.64639054d-10/
      data fpp(24, 1,1),fpp(24, 1,2)/ 0.00000000d+00,-9.71421180d-10/
      data fpp(24, 2,1),fpp(24, 2,2)/-8.12415567d-08,-5.71576391d-11/
      data fpp(24, 3,1),fpp(24, 3,2)/ 2.42282988d-06, 3.60005174d-09/
      data fpp(24, 4,1),fpp(24, 4,2)/-2.73498342d-06,-2.34304931d-09/
      data fpp(24, 5,1),fpp(24, 5,2)/-3.54308875d-07,-1.42785450d-09/
      data fpp(24, 6,1),fpp(24, 6,2)/-2.45178132d-07, 8.54467318d-10/
      data fpp(24, 7,1),fpp(24, 7,2)/-3.00348581d-07, 4.09985231d-10/
      data fpp(24, 8,1),fpp(24, 8,2)/-2.50589059d-07,-9.44082404d-11/
      data fpp(24, 9,1),fpp(24, 9,2)/ 3.14478505d-07,-3.23522691d-11/
      data fpp(24,10,1),fpp(24,10,2)/-2.09314431d-06, 1.44260927d-10/
      data fpp(24,11,1),fpp(24,11,2)/ 9.12893350d-08, 5.53085596d-11/
      data fpp(24,12,1),fpp(24,12,2)/-2.81439233d-07,-3.65495166d-10/
      data fpp(24,13,1),fpp(24,13,2)/-1.63205411d-07, 2.06672104d-10/
      data fpp(24,14,1),fpp(24,14,2)/-1.43794992d-06, 1.38806751d-10/
      data fpp(24,15,1),fpp(24,15,2)/-1.48027791d-07,-1.61899106d-10/
      data fpp(24,16,1),fpp(24,16,2)/-2.96599698d-07,-9.12103261d-11/
      data fpp(24,17,1),fpp(24,17,2)/-2.73484922d-08,-7.32595893d-11/
      data fpp(24,18,1),fpp(24,18,2)/ 2.21728536d-07, 3.84248683d-10/
      data fpp(24,19,1),fpp(24,19,2)/-5.67528144d-08,-2.63735144d-10/
      data fpp(24,20,1),fpp(24,20,2)/ 5.47641615d-08, 7.06918944d-11/
      data fpp(24,21,1),fpp(24,21,2)/ 1.01207470d-07,-1.90324331d-11/
      data fpp(24,22,1),fpp(24,22,2)/-1.60424457d-08, 5.43783803d-12/
      data fpp(24,23,1),fpp(24,23,2)/ 0.00000000d+00,-2.71891902d-12/
      data fpp(25, 1,1),fpp(25, 1,2)/ 0.00000000d+00,-2.61872610d-10/
      data fpp(25, 2,1),fpp(25, 2,2)/-2.62405661d-07,-2.76254779d-10/
      data fpp(25, 3,1),fpp(25, 3,2)/-8.16465762d-07, 1.36689173d-09/
      data fpp(25, 4,1),fpp(25, 4,2)/ 6.50326689d-07,-2.79131213d-09/
      data fpp(25, 5,1),fpp(25, 5,2)/ 4.35005085d-07, 2.59835679d-09/
      data fpp(25, 6,1),fpp(25, 6,2)/-9.54705586d-08,-4.02115020d-10/
      data fpp(25, 7,1),fpp(25, 7,2)/-5.68741650d-08,-3.38989671d-09/
      data fpp(25, 8,1),fpp(25, 8,2)/ 4.19437133d-07, 6.76170185d-09/
      data fpp(25, 9,1),fpp(25, 9,2)/-4.18304712d-07,-4.45691070d-09/
      data fpp(25,10,1),fpp(25,10,2)/ 5.35113681d-07, 2.18988116d-09/
      data fpp(25,11,1),fpp(25,11,2)/-2.33110308d-07,-1.30261395d-09/
      data fpp(25,12,1),fpp(25,12,2)/ 1.38473730d-07, 1.22057463d-09/
      data fpp(25,13,1),fpp(25,13,2)/-4.43737542d-08,-2.97968458d-09/
      data fpp(25,14,1),fpp(25,14,2)/ 2.45510412d-06, 4.69816370d-09/
      data fpp(25,15,1),fpp(25,15,2)/ 1.19565904d-07,-3.21297022d-09/
      data fpp(25,16,1),fpp(25,16,2)/ 2.94088197d-07, 9.53717161d-10/
      data fpp(25,17,1),fpp(25,17,2)/ 8.79396048d-08,-1.89843018d-12/
      data fpp(25,18,1),fpp(25,18,2)/-1.82990927d-07,-3.46123441d-10/
      data fpp(25,19,1),fpp(25,19,2)/ 7.70073756d-09, 1.86392193d-10/
      data fpp(25,20,1),fpp(25,20,2)/-1.34416423d-08, 2.00554670d-10/
      data fpp(25,21,1),fpp(25,21,2)/-1.66661268d-07,-3.88610873d-10/
      data fpp(25,22,1),fpp(25,22,2)/-6.84854280d-08, 1.53888821d-10/
      data fpp(25,23,1),fpp(25,23,2)/ 0.00000000d+00, 3.73055590d-10/
      data fpp(26, 1,1),fpp(26, 1,2)/ 0.00000000d+00, 3.79570757d-09/
      data fpp(26, 2,1),fpp(26, 2,2)/ 1.70864201d-07, 2.00858485d-09/
      data fpp(26, 3,1),fpp(26, 3,2)/ 1.23033167d-07,-2.23004699d-09/
      data fpp(26, 4,1),fpp(26, 4,2)/-1.06323337d-07, 2.11160309d-09/
      data fpp(26, 5,1),fpp(26, 5,2)/-1.85711463d-07,-3.81636539d-09/
      data fpp(26, 6,1),fpp(26, 6,2)/ 1.47060366d-07, 3.55385846d-09/
      data fpp(26, 7,1),fpp(26, 7,2)/ 4.78452409d-08,-7.99068451d-10/
      data fpp(26, 8,1),fpp(26, 8,2)/-2.27159472d-07,-3.57584654d-10/
      data fpp(26, 9,1),fpp(26, 9,2)/ 1.58740342d-07,-1.70592932d-10/
      data fpp(26,10,1),fpp(26,10,2)/-4.73104150d-08, 9.05711230d-11/
      data fpp(26,11,1),fpp(26,11,2)/ 1.21151899d-07, 4.08308440d-10/
      data fpp(26,12,1),fpp(26,12,2)/-3.24556871d-08,-1.12380488d-09/
      data fpp(26,13,1),fpp(26,13,2)/ 1.00700428d-07, 2.88691109d-09/
      data fpp(26,14,1),fpp(26,14,2)/-1.42246655d-06,-3.82383948d-09/
      data fpp(26,15,1),fpp(26,15,2)/-9.02358244d-08, 2.20844684d-09/
      data fpp(26,16,1),fpp(26,16,2)/-1.59753089d-07,-8.09947864d-10/
      data fpp(26,17,1),fpp(26,17,2)/-8.44099272d-08, 4.31344618d-10/
      data fpp(26,18,1),fpp(26,18,2)/ 3.02351707d-08,-3.15430608d-10/
      data fpp(26,19,1),fpp(26,19,2)/ 2.59498641d-08, 2.30377815d-10/
      data fpp(26,20,1),fpp(26,20,2)/-9.97592205d-10,-6.08065142d-12/
      data fpp(26,21,1),fpp(26,21,2)/ 8.54376020d-08,-2.06055209d-10/
      data fpp(26,22,1),fpp(26,22,2)/ 4.99841578d-08, 2.30301488d-10/
      data fpp(26,23,1),fpp(26,23,2)/ 0.00000000d+00, 4.84849256d-10/
      data fpp(27, 1,1),fpp(27, 1,2)/ 0.00000000d+00,-1.17732242d-09/
      data fpp(27, 2,1),fpp(27, 2,2)/-2.13897716d-08,-4.45355155d-10/
      data fpp(27, 3,1),fpp(27, 3,2)/-2.08666190d-08, 5.58743043d-10/
      data fpp(27, 4,1),fpp(27, 4,2)/ 5.38066678d-08, 6.10382983d-10/
      data fpp(27, 5,1),fpp(27, 5,2)/ 3.96318466d-08,-6.00274975d-10/
      data fpp(27, 6,1),fpp(27, 6,2)/-3.34458189d-08,-6.09283082d-10/
      data fpp(27, 7,1),fpp(27, 7,2)/ 4.90135974d-09, 6.37407301d-10/
      data fpp(27, 8,1),fpp(27, 8,2)/ 5.17598491d-08, 4.59653876d-10/
      data fpp(27, 9,1),fpp(27, 9,2)/-2.70686690d-08,-7.60228037d-11/
      data fpp(27,10,1),fpp(27,10,2)/-5.62559572d-09,-6.01758527d-10/
      data fpp(27,11,1),fpp(27,11,2)/-6.90054255d-09, 6.83056911d-10/
      data fpp(27,12,1),fpp(27,12,2)/ 2.81301963d-08,-3.30469116d-10/
      data fpp(27,13,1),fpp(27,13,2)/-9.99144081d-08, 3.88195534d-11/
      data fpp(27,14,1),fpp(27,14,2)/ 2.19847585d-07, 1.75190902d-10/
      data fpp(27,15,1),fpp(27,15,2)/ 3.09245212d-08,-1.39583163d-10/
      data fpp(27,16,1),fpp(27,16,2)/ 3.22151683d-08,-2.16858250d-10/
      data fpp(27,17,1),fpp(27,17,2)/ 2.92599792d-08, 4.07016163d-10/
      data fpp(27,18,1),fpp(27,18,2)/ 7.89951233d-10,-2.11206404d-10/
      data fpp(27,19,1),fpp(27,19,2)/-2.16999612d-08,-1.62190549d-10/
      data fpp(27,20,1),fpp(27,20,2)/ 9.71359777d-09, 2.59968601d-10/
      data fpp(27,21,1),fpp(27,21,2)/-5.29821720d-08,-2.77683854d-10/
      data fpp(27,22,1),fpp(27,22,2)/ 4.29024063d-09, 2.50766815d-10/
      data fpp(27,23,1),fpp(27,23,2)/ 0.00000000d+00, 4.74616592d-10/
      data fpp(28, 1,1),fpp(28, 1,2)/ 0.00000000d+00,-3.85846317d-09/
      data fpp(28, 2,1),fpp(28, 2,2)/-8.53051142d-08,-1.88307366d-09/
      data fpp(28, 3,1),fpp(28, 3,2)/ 8.04333095d-08, 1.79075780d-09/
      data fpp(28, 4,1),fpp(28, 4,2)/ 1.10966661d-08,-4.79957552d-10/
      data fpp(28, 5,1),fpp(28, 5,2)/ 8.71840767d-08, 1.29072405d-10/
      data fpp(28, 6,1),fpp(28, 6,2)/-1.33277091d-07,-3.63320664d-11/
      data fpp(28, 7,1),fpp(28, 7,2)/-7.45067987d-09, 1.62558612d-11/
      data fpp(28, 8,1),fpp(28, 8,2)/ 1.40120075d-07,-2.86913784d-11/
      data fpp(28, 9,1),fpp(28, 9,2)/-5.04656655d-08, 9.85096524d-11/
      data fpp(28,10,1),fpp(28,10,2)/-1.10187202d-07,-2.81183268d-10/
      data fpp(28,11,1),fpp(28,11,2)/-3.35497287d-08, 1.02622342d-09/
      data fpp(28,12,1),fpp(28,12,2)/ 3.99349018d-08,-2.62371041d-09/
      data fpp(28,13,1),fpp(28,13,2)/-2.41042796d-07, 2.26861822d-09/
      data fpp(28,14,1),fpp(28,14,2)/ 7.23076207d-07, 7.49237531d-10/
      data fpp(28,15,1),fpp(28,15,2)/ 8.65377394d-08,-1.66556835d-09/
      data fpp(28,16,1),fpp(28,16,2)/ 9.08924159d-08, 5.13035850d-10/
      data fpp(28,17,1),fpp(28,17,2)/ 8.73700104d-08, 2.13424944d-10/
      data fpp(28,18,1),fpp(28,18,2)/ 2.66050244d-08,-7.66735625d-10/
      data fpp(28,19,1),fpp(28,19,2)/-5.91500194d-08, 1.05351756d-09/
      data fpp(28,20,1),fpp(28,20,2)/ 2.21432011d-08,-1.64733460d-09/
      data fpp(28,21,1),fpp(28,21,2)/-1.13508914d-07, 1.93582085d-09/
      data fpp(28,22,1),fpp(28,22,2)/-7.14512032d-09,-6.95948816d-10/
      data fpp(28,23,1),fpp(28,23,2)/ 0.00000000d+00,-1.55202559d-09/
 
      data fpppp( 1, 1),fpppp( 1, 2)/ 4.14337855d-03, 3.12372948d-03/
      data fpppp( 1, 3),fpppp( 1, 4)/-1.65567764d-02, 2.90757166d-02/
      data fpppp( 1, 5),fpppp( 1, 6)/-1.88560165d-02,-3.95979381d-03/
      data fpppp( 1, 7),fpppp( 1, 8)/ 1.12027819d-02,-3.48390301d-03/
      data fpppp( 1, 9),fpppp( 1,10)/-4.93778924d-04,-2.13456825d-04/
      data fpppp( 1,11),fpppp( 1,12)/ 3.58644936d-04,-1.40089368d-04/
      data fpppp( 1,13),fpppp( 1,14)/ 8.59320038d-06, 7.45445537d-06/
      data fpppp( 1,15),fpppp( 1,16)/-5.87762060d-08, 2.10467216d-05/
      data fpppp( 1,17),fpppp( 1,18)/-7.76383862d-05, 4.79416806d-05/
      data fpppp( 1,19),fpppp( 1,20)/-4.62777736d-06, 7.94057137d-06/
      data fpppp( 1,21),fpppp( 1,22)/-7.03431481d-06, 2.91184274d-06/
      data fpppp( 1,23) /             5.73770208d-06 /
      data fpppp( 2, 1),fpppp( 2, 2)/ 2.32024281d-03, 1.49086122d-03/
      data fpppp( 2, 3),fpppp( 2, 4)/-8.14576784d-03, 1.30429693d-02/
      data fpppp( 2, 5),fpppp( 2, 6)/-5.64961586d-03,-4.16853917d-03/
      data fpppp( 2, 7),fpppp( 2, 8)/ 3.77683225d-03, 1.72668662d-04/
      data fpppp( 2, 9),fpppp( 2,10)/-5.12208747d-04,-7.13578836d-05/
      data fpppp( 2,11),fpppp( 2,12)/ 2.19382857d-04,-9.76606490d-05/
      data fpppp( 2,13),fpppp( 2,14)/ 6.39840789d-06, 3.75123920d-06/
      data fpppp( 2,15),fpppp( 2,16)/ 9.05214400d-06,-2.17195952d-06/
      data fpppp( 2,17),fpppp( 2,18)/-4.08837542d-05, 2.54972610d-05/
      data fpppp( 2,19),fpppp( 2,20)/ 1.29359243d-06, 3.96608426d-06/
      data fpppp( 2,21),fpppp( 2,22)/-3.89831611d-06, 1.61687045d-06/
      data fpppp( 2,23) /             3.30931789d-06 /
      data fpppp( 3, 1),fpppp( 3, 2)/-3.59702987d-05, 3.63106681d-04/
      data fpppp( 3, 3),fpppp( 3, 4)/-8.97655907d-04, 3.65101999d-03/
      data fpppp( 3, 5),fpppp( 3, 6)/-1.42119109d-02, 2.81788203d-02/
      data fpppp( 3, 7),fpppp( 3, 8)/-2.56329592d-02, 8.32359186d-03/
      data fpppp( 3, 9),fpppp( 3,10)/-2.11117702d-05, 3.93883654d-04/
      data fpppp( 3,11),fpppp( 3,12)/-2.18391861d-04,-7.12134210d-06/
      data fpppp( 3,13),fpppp( 3,14)/-8.27811109d-06, 3.51901037d-06/
      data fpppp( 3,15),fpppp( 3,16)/ 1.90677892d-05,-3.74476620d-05/
      data fpppp( 3,17),fpppp( 3,18)/ 2.09909275d-05,-1.70320450d-05/
      data fpppp( 3,19),fpppp( 3,20)/ 1.49211648d-05,-2.93461651d-06/
      data fpppp( 3,21),fpppp( 3,22)/ 1.07865451d-06,-5.73917464d-07/
      data fpppp( 3,23) /            -6.07677153d-07 /
      data fpppp( 4, 1),fpppp( 4, 2)/-5.26412647d-04,-2.53254587d-03/
      data fpppp( 4, 3),fpppp( 4, 4)/ 1.04205942d-02,-2.89837223d-02/
      data fpppp( 4, 5),fpppp( 4, 6)/ 5.34162290d-02,-5.34201871d-02/
      data fpppp( 4, 7),fpppp( 4, 8)/ 2.19006958d-02, 7.44284713d-04/
      data fpppp( 4, 9),fpppp( 4,10)/-1.31335859d-03,-2.71873896d-04/
      data fpppp( 4,11),fpppp( 4,12)/ 3.88627656d-04,-8.49690937d-05/
      data fpppp( 4,13),fpppp( 4,14)/ 2.07314126d-05,-8.86167414d-06/
      data fpppp( 4,15),fpppp( 4,16)/ 2.59168969d-05,-3.05237898d-05/
      data fpppp( 4,17),fpppp( 4,18)/-5.05456457d-06, 1.07357511d-05/
      data fpppp( 4,19),fpppp( 4,20)/ 1.57702812d-06, 4.06430512d-07/
      data fpppp( 4,21),fpppp( 4,22)/-3.87776588d-07, 3.70649308d-07/
      data fpppp( 4,23) /             6.85465777d-07 /
      data fpppp( 5, 1),fpppp( 5, 2)/ 6.69221912d-04, 1.34067476d-03/
      data fpppp( 5, 3),fpppp( 5, 4)/-7.76383379d-03, 1.73475225d-02/
      data fpppp( 5, 5),fpppp( 5, 6)/-1.96389055d-02, 7.16427625d-03/
      data fpppp( 5, 7),fpppp( 5, 8)/ 8.55916440d-03,-9.06335154d-03/
      data fpppp( 5, 9),fpppp( 5,10)/ 1.81220123d-03,-2.37922942d-04/
      data fpppp( 5,11),fpppp( 5,12)/-4.98343691d-05, 1.13150205d-05/
      data fpppp( 5,13),fpppp( 5,14)/-7.40114517d-06, 7.18480575d-06/
      data fpppp( 5,15),fpppp( 5,16)/-1.37024935d-06,-5.97480808d-06/
      data fpppp( 5,17),fpppp( 5,18)/-1.86727901d-06, 2.86510919d-06/
      data fpppp( 5,19),fpppp( 5,20)/ 1.20105792d-06, 1.71485028d-07/
      data fpppp( 5,21),fpppp( 5,22)/ 2.31754381d-07,-2.48480495d-07/
      data fpppp( 5,23) /            -5.74285592d-07 /
      data fpppp( 6, 1),fpppp( 6, 2)/ 2.79975972d-04,-3.14895118d-04/
      data fpppp( 6, 3),fpppp( 6, 4)/ 3.31061775d-03,-7.83521324d-03/
      data fpppp( 6, 5),fpppp( 6, 6)/-2.97630242d-03, 1.86550290d-02/
      data fpppp( 6, 7),fpppp( 6, 8)/-1.34232055d-02, 3.86266298d-03/
      data fpppp( 6, 9),fpppp( 6,10)/-1.10824039d-03, 1.97817091d-04/
      data fpppp( 6,11),fpppp( 6,12)/-4.19418218d-05, 1.02241555d-05/
      data fpppp( 6,13),fpppp( 6,14)/-5.05576381d-06, 5.56303495d-06/
      data fpppp( 6,15),fpppp( 6,16)/-2.06930287d-06,-2.72394814d-06/
      data fpppp( 6,17),fpppp( 6,18)/-1.17503479d-06, 1.18564409d-06/
      data fpppp( 6,19),fpppp( 6,20)/ 1.27012776d-06,-3.59752861d-07/
      data fpppp( 6,21),fpppp( 6,22)/ 3.89004346d-08, 9.80894231d-08/
      data fpppp( 6,23) /             2.54268214d-07 /
      data fpppp( 7, 1),fpppp( 7, 2)/ 4.72456048d-05, 1.03711902d-03/
      data fpppp( 7, 3),fpppp( 7, 4)/-5.71228501d-03, 1.46257820d-02/
      data fpppp( 7, 5),fpppp( 7, 6)/-1.20042657d-02, 1.94174061d-04/
      data fpppp( 7, 7),fpppp( 7, 8)/-5.22166377d-05, 2.74077102d-03/
      data fpppp( 7, 9),fpppp( 7,10)/-8.14225404d-04, 3.18705938d-04/
      data fpppp( 7,11),fpppp( 7,12)/-8.25043657d-05, 2.12923457d-05/
      data fpppp( 7,13),fpppp( 7,14)/-4.11440949d-06,-1.09473604d-06/
      data fpppp( 7,15),fpppp( 7,16)/ 2.62822000d-06,-2.75827008d-06/
      data fpppp( 7,17),fpppp( 7,18)/ 5.83631343d-07, 3.84818598d-08/
      data fpppp( 7,19),fpppp( 7,20)/ 3.22325422d-07, 1.62596695d-07/
      data fpppp( 7,21),fpppp( 7,22)/-2.21386630d-08,-9.08679735d-08/
      data fpppp( 7,23) /            -1.92741869d-07 /
      data fpppp( 8, 1),fpppp( 8, 2)/ 5.46753271d-05, 4.81231604d-04/
      data fpppp( 8, 3),fpppp( 8, 4)/-1.50524166d-03, 4.95388848d-03/
      data fpppp( 8, 5),fpppp( 8, 6)/-1.18382042d-02, 8.71650871d-03/
      data fpppp( 8, 7),fpppp( 8, 8)/ 5.17386558d-03,-7.93551525d-03/
      data fpppp( 8, 9),fpppp( 8,10)/ 2.01142126d-03,-6.10504507d-04/
      data fpppp( 8,11),fpppp( 8,12)/ 1.64984688d-04,-4.44014868d-05/
      data fpppp( 8,13),fpppp( 8,14)/ 1.02097928d-05, 5.98293599d-07/
      data fpppp( 8,15),fpppp( 8,16)/-2.64950571d-06, 1.57835848d-06/
      data fpppp( 8,17),fpppp( 8,18)/-1.34888206d-06, 8.86664384d-07/
      data fpppp( 8,19),fpppp( 8,20)/-2.94981612d-07, 1.25338825d-07/
      data fpppp( 8,21),fpppp( 8,22)/-1.88684599d-07, 2.62764990d-07/
      data fpppp( 8,23) /             4.95508003d-07 /
      data fpppp( 9, 1),fpppp( 9, 2)/ 1.10023531d-03,-9.18469887d-04/
      data fpppp( 9, 3),fpppp( 9, 4)/ 2.57256724d-03,-1.32204938d-02/
      data fpppp( 9, 5),fpppp( 9, 6)/ 2.22515983d-02,-8.63679432d-03/
      data fpppp( 9, 7),fpppp( 9, 8)/-7.21981990d-03, 6.15801223d-03/
      data fpppp( 9, 9),fpppp( 9,10)/-1.28033440d-03, 3.72295287d-04/
      data fpppp( 9,11),fpppp( 9,12)/-9.79723985d-05, 2.57524550d-05/
      data fpppp( 9,13),fpppp( 9,14)/-5.91216336d-06,-2.87685413d-07/
      data fpppp( 9,15),fpppp( 9,16)/ 1.55419272d-06,-1.13347620d-06/
      data fpppp( 9,17),fpppp( 9,18)/ 5.50756476d-07,-6.62265354d-07/
      data fpppp( 9,19),fpppp( 9,20)/ 6.27245274d-07,-3.25403029d-07/
      data fpppp( 9,21),fpppp( 9,22)/ 8.23036952d-07,-8.53380526d-07/
      data fpppp( 9,23) /            -1.72269587d-06 /
      data fpppp(10, 1),fpppp(10, 2)/-1.10022801d-03,-4.53509193d-04/
      data fpppp(10, 3),fpppp(10, 4)/ 2.83553268d-03,-3.12355614d-03/
      data fpppp(10, 5),fpppp(10, 6)/ 3.07154216d-03,-6.69873282d-03/
      data fpppp(10, 7),fpppp(10, 8)/ 6.22008853d-03,-2.24943025d-03/
      data fpppp(10, 9),fpppp(10,10)/ 4.79748263d-04,-1.33784056d-04/
      data fpppp(10,11),fpppp(10,12)/ 3.49126643d-05,-8.89195053d-06/
      data fpppp(10,13),fpppp(10,14)/ 1.97557194d-06, 3.79220176d-07/
      data fpppp(10,15),fpppp(10,16)/-1.04106497d-06, 1.03397345d-06/
      data fpppp(10,17),fpppp(10,18)/-8.24052627d-07, 6.83605011d-07/
      data fpppp(10,19),fpppp(10,20)/-4.48922618d-07, 4.14757843d-07/
      data fpppp(10,21),fpppp(10,22)/-1.28247828d-06, 1.30833285d-06/
      data fpppp(10,23) /             2.67398762d-06 /
      data fpppp(11, 1),fpppp(11, 2)/-1.57180080d-04, 6.17500249d-04/
      data fpppp(11, 3),fpppp(11, 4)/-2.03209551d-03, 7.30327504d-03/
      data fpppp(11, 5),fpppp(11, 6)/-1.11829961d-02, 6.72404572d-03/
      data fpppp(11, 7),fpppp(11, 8)/-1.91310547d-03, 7.78033726d-04/
      data fpppp(11, 9),fpppp(11,10)/-1.59267123d-04, 4.55738952d-05/
      data fpppp(11,11),fpppp(11,12)/-1.12316218d-05, 2.86583980d-06/
      data fpppp(11,13),fpppp(11,14)/-1.30873201d-06, 1.73474246d-06/
      data fpppp(11,15),fpppp(11,16)/-2.00707621d-06, 7.12218185d-07/
      data fpppp(11,17),fpppp(11,18)/ 2.44054197d-07,-3.71191151d-07/
      data fpppp(11,19),fpppp(11,20)/ 2.85990879d-07,-2.24774608d-07/
      data fpppp(11,21),fpppp(11,22)/ 8.43915548d-07,-9.06962126d-07/
      data fpppp(11,23) /            -1.85224899d-06 /
      data fpppp(12, 1),fpppp(12, 2)/ 5.58993506d-05,-1.11353852d-04/
      data fpppp(12, 3),fpppp(12, 4)/ 1.06386541d-04,-1.02335065d-03/
      data fpppp(12, 5),fpppp(12, 6)/ 2.01097167d-03,-9.55680790d-04/
      data fpppp(12, 7),fpppp(12, 8)/-7.06731410d-05, 1.19919712d-05/
      data fpppp(12, 9),fpppp(12,10)/ 3.30022650d-06,-4.89830688d-07/
      data fpppp(12,11),fpppp(12,12)/ 3.87046032d-07,-8.35995939d-07/
      data fpppp(12,13),fpppp(12,14)/ 1.17448191d-06,-1.88410604d-06/
      data fpppp(12,15),fpppp(12,16)/ 2.19790813d-06,-1.00108344d-06/
      data fpppp(12,17),fpppp(12,18)/-3.77535086d-08, 1.61754223d-07/
      data fpppp(12,19),fpppp(12,20)/-5.18300658d-08,-9.09736444d-09/
      data fpppp(12,21),fpppp(12,22)/-2.22642925d-07, 2.80789656d-07/
      data fpppp(12,23) /             5.79371339d-07 /
      data fpppp(13, 1),fpppp(13, 2)/ 4.95786624d-05,-8.66688322d-06/
      data fpppp(13, 3),fpppp(13, 4)/ 1.24023651d-04,-4.11562094d-04/
      data fpppp(13, 5),fpppp(13, 6)/ 5.58820304d-04,-4.07567471d-04/
      data fpppp(13, 7),fpppp(13, 8)/ 1.59184133d-04,-2.98028451d-05/
      data fpppp(13, 9),fpppp(13,10)/ 4.17580394d-06,-3.15030559d-07/
      data fpppp(13,11),fpppp(13,12)/-6.20071856d-07, 9.71961079d-07/
      data fpppp(13,13),fpppp(13,14)/-8.68256691d-07, 1.09121068d-06/
      data fpppp(13,15),fpppp(13,16)/-1.05191331d-06, 2.09195242d-07/
      data fpppp(13,17),fpppp(13,18)/ 2.18495621d-07,-8.01961111d-08/
      data fpppp(13,19),fpppp(13,20)/-5.93425437d-08,-5.55420160d-09/
      data fpppp(13,21),fpppp(13,22)/ 2.23895516d-07,-1.63046806d-07/
      data fpppp(13,23) /            -3.73877116d-07 /
      data fpppp(14, 1),fpppp(14, 2)/-2.50137621d-05,-8.11242506d-06/
      data fpppp(14, 3),fpppp(14, 4)/ 2.35738551d-05, 3.51283434d-06/
      data fpppp(14, 5),fpppp(14, 6)/-5.98031258d-05, 7.91978108d-05/
      data fpppp(14, 7),fpppp(14, 8)/-4.00617035d-05, 5.00552038d-06/
      data fpppp(14, 9),fpppp(14,10)/ 4.50425523d-07,-6.64705941d-07/
      data fpppp(14,11),fpppp(14,12)/ 1.05800907d-06,-5.76260217d-07/
      data fpppp(14,13),fpppp(14,14)/-4.85754576d-08,-2.87843574d-07/
      data fpppp(14,15),fpppp(14,16)/ 4.25293058d-07, 1.89217559d-07/
      data fpppp(14,17),fpppp(14,18)/-3.51437283d-07, 3.49483618d-08/
      data fpppp(14,19),fpppp(14,20)/ 1.00735987d-07, 2.69253043d-07/
      data fpppp(14,21),fpppp(14,22)/-6.76230375d-07, 3.06623634d-07/
      data fpppp(14,23) /             7.38524093d-07 /
      data fpppp(15, 1),fpppp(15, 2)/-1.74170401d-06,-2.07250785d-06/
      data fpppp(15, 3),fpppp(15, 4)/ 2.75760068d-06,-1.04754841d-05/
      data fpppp(15, 5),fpppp(15, 6)/ 2.48206350d-05,-2.67652428d-05/
      data fpppp(15, 7),fpppp(15, 8)/ 1.18864361d-05,-1.53241298d-06/
      data fpppp(15, 9),fpppp(15,10)/ 4.63630847d-08, 9.84025105d-07/
      data fpppp(15,11),fpppp(15,12)/-1.67393241d-06, 4.21389353d-07/
      data fpppp(15,13),fpppp(15,14)/ 9.17137644d-07,-4.33129308d-07/
      data fpppp(15,15),fpppp(15,16)/-1.78345992d-07,-7.53468392d-08/
      data fpppp(15,17),fpppp(15,18)/ 1.91058375d-07, 2.45569673d-08/
      data fpppp(15,19),fpppp(15,20)/ 2.77000464d-08,-8.46403194d-07/
      data fpppp(15,21),fpppp(15,22)/ 1.50681956d-06,-6.06122523d-07/
      data fpppp(15,23) /            -1.44301751d-06 /
      data fpppp(16, 1),fpppp(16, 2)/ 4.21438826d-06, 2.21483624d-06/
      data fpppp(16, 3),fpppp(16, 4)/-4.08758705d-06, 4.67003907d-06/
      data fpppp(16, 5),fpppp(16, 6)/-6.03983313d-06, 5.94389912d-06/
      data fpppp(16, 7),fpppp(16, 8)/-2.92657654d-06, 4.93534768d-07/
      data fpppp(16, 9),fpppp(16,10)/ 2.09044734d-07,-9.90863872d-07/
      data fpppp(16,11),fpppp(16,12)/ 1.43067556d-06,-3.31647715d-07/
      data fpppp(16,13),fpppp(16,14)/-8.13528024d-07, 6.36922945d-07/
      data fpppp(16,15),fpppp(16,16)/ 4.53952590d-08,-2.33609738d-07/
      data fpppp(16,17),fpppp(16,18)/ 1.33017576d-07,-8.06518739d-08/
      data fpppp(16,19),fpppp(16,20)/-6.74473958d-08, 6.87480265d-07/
      data fpppp(16,21),fpppp(16,22)/-1.17961877d-06, 4.61029575d-07/
      data fpppp(16,23) /             1.09946438d-06 /
      data fpppp(17, 1),fpppp(17, 2)/-1.78486872d-06,-8.98361183d-07/
      data fpppp(17, 3),fpppp(17, 4)/ 9.13916074d-07,-5.14000697d-07/
      data fpppp(17, 5),fpppp(17, 6)/ 1.78210014d-06,-2.10429415d-06/
      data fpppp(17, 7),fpppp(17, 8)/ 7.33720516d-07,-2.59739481d-07/
      data fpppp(17, 9),fpppp(17,10)/-4.45551661d-07, 1.19846043d-06/
      data fpppp(17,11),fpppp(17,12)/-1.02152681d-06, 6.72214763d-08/
      data fpppp(17,13),fpppp(17,14)/ 6.18276900d-07,-5.28746605d-07/
      data fpppp(17,15),fpppp(17,16)/-7.26701458d-08, 3.04353120d-07/
      data fpppp(17,17),fpppp(17,18)/-2.12205298d-07, 1.42810006d-07/
      data fpppp(17,19),fpppp(17,20)/-1.53567870d-07, 2.20294722d-08/
      data fpppp(17,21),fpppp(17,22)/ 2.69995789d-07,-1.31963448d-07/
      data fpppp(17,23) /            -3.48229669d-07 /
      data fpppp(18, 1),fpppp(18, 2)/ 7.08668927d-07, 3.18110534d-07/
      data fpppp(18, 3),fpppp(18, 4)/ 1.45033229d-06,-2.74717647d-06/
      data fpppp(18, 5),fpppp(18, 6)/ 6.65583781d-07, 3.89812816d-07/
      data fpppp(18, 7),fpppp(18, 8)/ 4.91401856d-07,-9.94170328d-09/
      data fpppp(18, 9),fpppp(18,10)/ 7.34913976d-07,-1.65055163d-06/
      data fpppp(18,11),fpppp(18,12)/ 1.08397471d-06,-4.38364704d-08/
      data fpppp(18,13),fpppp(18,14)/-4.21729469d-07, 4.33261324d-07/
      data fpppp(18,15),fpppp(18,16)/-1.73356175d-07, 1.35565405d-07/
      data fpppp(18,17),fpppp(18,18)/-6.30274765d-08,-1.34631928d-07/
      data fpppp(18,19),fpppp(18,20)/ 5.56725081d-07,-9.11579199d-07/
      data fpppp(18,21),fpppp(18,22)/ 5.68553592d-07,-1.12866633d-07/
      data fpppp(18,23) /            -1.76700282d-07 /
      data fpppp(19, 1),fpppp(19, 2)/-6.81740085d-08, 3.01254012d-07/
      data fpppp(19, 3),fpppp(19, 4)/-3.79746271d-06, 7.74232716d-06/
      data fpppp(19, 5),fpppp(19, 6)/-6.08791699d-06, 3.27932489d-06/
      data fpppp(19, 7),fpppp(19, 8)/-3.23853317d-06, 3.31142445d-07/
      data fpppp(19, 9),fpppp(19,10)/ 1.42740190d-06,-1.61777709d-07/
      data fpppp(19,11),fpppp(19,12)/-6.38467540d-08,-2.79750902d-07/
      data fpppp(19,13),fpppp(19,14)/ 3.89899591d-07,-5.69756059d-07/
      data fpppp(19,15),fpppp(19,16)/ 7.43395887d-07,-8.88226536d-07/
      data fpppp(19,17),fpppp(19,18)/ 6.01314854d-07,-1.86636358d-08/
      data fpppp(19,19),fpppp(19,20)/-8.20710058d-07, 1.43220589d-06/
      data fpppp(19,21),fpppp(19,22)/-9.79741596d-07, 2.12844036d-07/
      data fpppp(19,23) /             3.75563064d-07 /
      data fpppp(20, 1),fpppp(20, 2)/ 4.04249380d-07,-2.03571126d-07/
      data fpppp(20, 3),fpppp(20, 4)/ 1.86107446d-06,-5.42791128d-06/
      data fpppp(20, 5),fpppp(20, 6)/ 6.30764465d-06,-4.22757509d-06/
      data fpppp(20, 7),fpppp(20, 8)/ 3.52302122d-06,-3.95326992d-07/
      data fpppp(20, 9),fpppp(20,10)/-2.62201632d-06, 1.71049618d-06/
      data fpppp(20,11),fpppp(20,12)/-8.62427790d-07, 5.35366762d-07/
      data fpppp(20,13),fpppp(20,14)/-4.84135527d-07, 6.68302757d-07/
      data fpppp(20,15),fpppp(20,16)/-7.24120123d-07, 7.00371893d-07/
      data fpppp(20,17),fpppp(20,18)/-4.80463809d-07, 6.91827977d-08/
      data fpppp(20,19),fpppp(20,20)/ 4.34761715d-07,-7.31726943d-07/
      data fpppp(20,21),fpppp(20,22)/ 5.49696565d-07,-1.91162020d-07/
      data fpppp(20,23) /            -3.54225720d-07 /
      data fpppp(21, 1),fpppp(21, 2)/-1.04007574d-06,-4.06211294d-07/
      data fpppp(21, 3),fpppp(21, 4)/ 1.28187025d-06,-7.19808054d-07/
      data fpppp(21, 5),fpppp(21, 6)/-7.55504017d-07, 1.19152732d-06/
      data fpppp(21, 7),fpppp(21, 8)/-1.25905655d-06, 1.09866417d-07/
      data fpppp(21, 9),fpppp(21,10)/ 1.33164210d-06,-1.10980470d-06/
      data fpppp(21,11),fpppp(21,12)/ 6.18145122d-07,-3.05337978d-07/
      data fpppp(21,13),fpppp(21,14)/ 3.02161534d-07,-3.93793796d-07/
      data fpppp(21,15),fpppp(21,16)/ 3.33648230d-07,-2.38513619d-07/
      data fpppp(21,17),fpppp(21,18)/ 1.49524380d-07,-1.74949164d-08/
      data fpppp(21,19),fpppp(21,20)/-1.33608541d-07, 2.09785346d-07/
      data fpppp(21,21),fpppp(21,22)/-2.09615802d-07, 1.31631179d-07/
      data fpppp(21,23) /             2.55550123d-07 /
      data fpppp(22, 1),fpppp(22, 2)/ 1.20781519d-06, 6.17773911d-07/
      data fpppp(22, 3),fpppp(22, 4)/-2.37017232d-06, 3.03454877d-06/
      data fpppp(22, 5),fpppp(22, 6)/-1.69709603d-06, 2.84929779d-07/
      data fpppp(22, 7),fpppp(22, 8)/ 2.24201772d-07, 7.70173351d-08/
      data fpppp(22, 9),fpppp(22,10)/-7.45053176d-07, 7.95605211d-07/
      data fpppp(22,11),fpppp(22,12)/-4.74511024d-07, 1.68946821d-07/
      data fpppp(22,13),fpppp(22,14)/-1.37273674d-07, 1.59025467d-07/
      data fpppp(22,15),fpppp(22,16)/-1.14232081d-07, 6.64727470d-08/
      data fpppp(22,17),fpppp(22,18)/-3.97791164d-08, 1.33929249d-09/
      data fpppp(22,19),fpppp(22,20)/ 4.48087334d-08,-6.76159033d-08/
      data fpppp(22,21),fpppp(22,22)/ 7.77900406d-08,-5.69332496d-08/
      data fpppp(22,23) /            -1.11619616d-07 /
      data fpppp(23, 1),fpppp(23, 2)/-9.72680723d-07,-4.92292973d-07/
      data fpppp(23, 3),fpppp(23, 4)/ 1.79714921d-06,-2.24509911d-06/
      data fpppp(23, 5),fpppp(23, 6)/ 1.32920630d-06,-3.54607056d-07/
      data fpppp(23, 7),fpppp(23, 8)/-4.82621678d-09,-6.22724261d-08/
      data fpppp(23, 9),fpppp(23,10)/ 3.62592955d-07,-4.22914869d-07/
      data fpppp(23,11),fpppp(23,12)/ 2.58271514d-07,-7.92407372d-08/
      data fpppp(23,13),fpppp(23,14)/ 4.61263530d-08,-4.70893971d-08/
      data fpppp(23,15),fpppp(23,16)/ 3.28122081d-08,-1.91244970d-08/
      data fpppp(23,17),fpppp(23,18)/ 9.44848567d-09, 4.45927352d-09/
      data fpppp(23,19),fpppp(23,20)/-1.47689008d-08, 1.69267742d-08/
      data fpppp(23,21),fpppp(23,22)/-1.49958813d-08, 9.65939698d-09/
      data fpppp(23,23) /             1.81495513d-08 /
      data fpppp(24, 1),fpppp(24, 2)/ 4.58507946d-07, 2.12997486d-07/
      data fpppp(24, 3),fpppp(24, 4)/-6.90022773d-07, 7.08241268d-07/
      data fpppp(24, 5),fpppp(24, 6)/-3.33705217d-07, 8.14090897d-08/
      data fpppp(24, 7),fpppp(24, 8)/-3.13634276d-08, 6.92278137d-08/
      data fpppp(24, 9),fpppp(24,10)/-1.21873897d-07, 1.18742307d-07/
      data fpppp(24,11),fpppp(24,12)/-7.75719445d-08, 3.81157381d-08/
      data fpppp(24,13),fpppp(24,14)/-4.54332645d-08, 6.00386201d-08/
      data fpppp(24,15),fpppp(24,16)/-4.08412177d-08, 1.70166085d-08/
      data fpppp(24,17),fpppp(24,18)/-2.15582935d-09,-9.60374179d-09/
      data fpppp(24,19),fpppp(24,20)/ 8.91729385d-09,-2.66553408d-09/
      data fpppp(24,21),fpppp(24,22)/-2.15957757d-09, 1.48225085d-09/
      data fpppp(24,23) /             4.22811587d-09 /
      data fpppp(25, 1),fpppp(25, 2)/-9.18896593d-08,-3.62197736d-08/
      data fpppp(25, 3),fpppp(25, 4)/ 1.66771688d-07,-1.45862366d-07/
      data fpppp(25, 5),fpppp(25, 6)/ 1.29704030d-08, 1.83437847d-08/
      data fpppp(25, 7),fpppp(25, 8)/ 5.02317469d-08,-1.14219195d-07/
      data fpppp(25, 9),fpppp(25,10)/ 9.12722796d-08,-5.89731164d-08/
      data fpppp(25,11),fpppp(25,12)/ 4.13216430d-08,-3.79249738d-08/
      data fpppp(25,13),fpppp(25,14)/ 7.71123607d-08,-1.09584948d-07/
      data fpppp(25,15),fpppp(25,16)/ 7.11264657d-08,-2.43172844d-08/
      data fpppp(25,17),fpppp(25,18)/ 3.30241889d-09, 7.22069250d-09/
      data fpppp(25,19),fpppp(25,20)/-4.48785715d-09,-1.97930652d-09/
      data fpppp(25,21),fpppp(25,22)/ 4.48044849d-09,-8.58759502d-10/
      data fpppp(25,23) /            -2.82683521d-09 /
      data fpppp(26, 1),fpppp(26, 2)/-1.05965499d-08,-8.02390959d-09/
      data fpppp(26, 3),fpppp(26, 4)/-9.79466810d-09, 3.63646918d-09/
      data fpppp(26, 5),fpppp(26, 6)/ 3.12412022d-08,-2.96828890d-08/
      data fpppp(26, 7),fpppp(26, 8)/-1.61865152d-08, 5.22394486d-08/
      data fpppp(26, 9),fpppp(26,10)/-3.41541930d-08, 1.76718318d-08/
      data fpppp(26,11),fpppp(26,12)/-1.40623498d-08, 1.92533734d-08/
      data fpppp(26,13),fpppp(26,14)/-4.57453218d-08, 6.43485282d-08/
      data fpppp(26,15),fpppp(26,16)/-4.03249291d-08, 1.28463089d-08/
      data fpppp(26,17),fpppp(26,18)/-2.36868086d-09,-1.01346925d-09/
      data fpppp(26,19),fpppp(26,20)/-7.13266394d-10, 2.50680584d-09/
      data fpppp(26,21),fpppp(26,22)/-2.51099794d-09, 2.23867593d-10/
      data fpppp(26,23) /             7.43684749d-10 /
      data fpppp(27, 1),fpppp(27, 2)/-7.94662911d-10, 3.98999207d-11/
      data fpppp(27, 3),fpppp(27, 4)/ 5.89416504d-09,-5.82052785d-09/
      data fpppp(27, 5),fpppp(27, 6)/-3.93559961d-09, 7.42624367d-09/
      data fpppp(27, 7),fpppp(27, 8)/ 9.72587487d-10,-9.27387904d-09/
      data fpppp(27, 9),fpppp(27,10)/ 5.95804688d-09,-2.49119454d-09/
      data fpppp(27,11),fpppp(27,12)/ 2.64365007d-09,-5.90506458d-09/
      data fpppp(27,13),fpppp(27,14)/ 1.11920877d-08,-1.19948902d-08/
      data fpppp(27,15),fpppp(27,16)/ 6.26636984d-09,-1.65776646d-09/
      data fpppp(27,17),fpppp(27,18)/ 1.09945845d-10,-3.12907255d-10/
      data fpppp(27,19),fpppp(27,20)/ 1.50049011d-09,-2.45484489d-09/
      data fpppp(27,21),fpppp(27,22)/ 2.67232973d-09,-1.03638308d-09/
      data fpppp(27,23) /            -2.22055662d-09 /
      data fpppp(28, 1),fpppp(28, 2)/ 2.75265370d-08, 1.39616389d-08/
      data fpppp(28, 3),fpppp(28, 4)/-2.31226437d-08, 2.21109197d-08/
      data fpppp(28, 5),fpppp(28, 6)/-3.04192620d-08, 2.83944697d-08/
      data fpppp(28, 7),fpppp(28, 8)/-4.95979497d-11,-2.29774352d-08/
      data fpppp(28, 9),fpppp(28,10)/ 1.08017795d-08,-1.62962416d-09/
      data fpppp(28,11),fpppp(28,12)/ 3.89825776d-09,-1.41525774d-08/
      data fpppp(28,13),fpppp(28,14)/ 3.14443123d-08,-3.69188698d-08/
      data fpppp(28,15),fpppp(28,16)/ 2.01917187d-08,-5.39441612d-09/
      data fpppp(28,17),fpppp(28,18)/ 9.13320893d-10,-1.69342229d-09/
      data fpppp(28,19),fpppp(28,20)/ 4.36096479d-09,-5.72754102d-09/
      data fpppp(28,21),fpppp(28,22)/ 5.53247915d-09,-1.88142104d-09/
      data fpppp(28,23) /            -3.95991540d-09 /
 
      c(1,1)=fpppp(ix+1,iy+1)
      c(1,2)=fpppp(ix+1,iy  )
      c(2,1)=fpppp(ix  ,iy+1)
      c(2,2)=fpppp(ix,  iy  )
      c(1,3)=fpp(ix+1,iy+1,1)
      c(1,4)=fpp(ix+1,iy  ,1)
      c(2,3)=fpp(ix,  iy+1,1)
      c(2,4)=fpp(ix,  iy,  1)
      c(3,1)=fpp(ix+1,iy+1,2)
      c(3,2)=fpp(ix+1,iy  ,2)
      c(4,1)=fpp(ix,  iy+1,2)
      c(4,2)=fpp(ix,  iy,  2)
      c(3,3)=f(ix+1,iy+1)
      c(3,4)=f(ix+1,iy  )
      c(4,3)=f(ix,  iy+1)
      c(4,4)=f(ix,  iy  )
      px(1)=((xi-xix)**3/(6.0*delxi))-(xi-xix)*delxi/6.0
      px(2)=(xi-xixp1)*delxi/6.0-((xi-xixp1)**3/(6.0*delxi))
      px(3)=(xi-xix)/delxi
      px(4)=(xixp1-xi)/delxi
      py(1)=((yi-yiy)**3/(6.0*delyi))-(yi-yiy)*delyi/6.0
      py(2)=(yi-yiyp1)*delyi/6.0-((yi-yiyp1)**3/(6.0*delyi))
      py(3)=(yi-yiy)/delyi
      py(4)=(yiyp1-yi)/delyi

      fi=0.0d 00
      do l=1,4
        sum=0.0d 00
        do i=1,4
          sum=sum + c(i,l) * px(i)
        enddo
        fi = fi + sum * py(l)
      enddo
      return
      end  


