c***********************************************************************

      real*8 function c2h3o_h(r, rpar, ipar)

c     
c     this is a general subroutine for evaluating the potential 
c     energy for the transitional modes.
c     
c     the potential should be output in au in vtot
c     the cartesian coordinates of the atoms of each fragment are 
c     stored in r
c     the bond length or some other suitable approximation to a 
c     distinguished reaction coordinate should be passed back in rmepi
c     
c     
c     the most important current utility of this routine is its 
c     evaluation of a particular set of valence bending and 
c     torsional angles for the incipient bond (qq).
c     it also generates the atom-atom interfragment distances and the 
c     center-of-mass to center-of-mass separation. 
c     it is also currently setup to consider
c     (i) valence stretching and bending potentials and/or 
c     lennard-jones and/or hard sphere interactions.
c     (ii) ion-molecule potentials including ion-induced dipole, 
c     ion-dipole, hard sphere, and/or lennard-jones interactions.
c     
c     the valence stretching and bending potential works in terms  of
c     either 
c     (i) an exponential extrapolation of an equilibrium set 
c     of force constants 
c     or
c     (ii) an exponential interpolation of force constants along the 
c     bond stretching path.
c     
c     for the ion-dipole component some work needs to be done on 
c     defining the axis for the dipole.  once this is done it should 
c     also be easy to include the ion-quadrupole interaction.
c     

      implicit double precision (a-h,o-z)

      include 'param2.fi'
      include 'commonpot.fi'

c     
c     vectors for primary coordinates 
c     

      dimension r(nfrag,natommx,ndim)
c      dimension cm(nfrag,ndim),rij(natommx,natommx)
      dimension qq(5)

c     
c     vectors from mcpot calling routine
c     

      dimension ift(nfrag),natom(nfrag)
c      dimension dmss(nfrag,natommx),dmsst(nfrag)

c     
c     intermediate use vectors
c     

      dimension r1(ndim),r2p(ndim),r2d(ndim),r2q(ndim)
      dimension nr(nfrag)
      dimension rbvec(ndim),rax1v(ndim),rbx1v(ndim),rax2v(ndim),
     $     rbx2v(ndim),rx1x2v(ndim),ray1v(ndim),rby1v(ndim),
     $     ray2v(ndim),rby2v(ndim),ry1y2v(ndim)
      dimension cptmp1(ndim),cptmp2(ndim),cptmp3(ndim)

c     
c     specific potential parameter vectors
c     

      dimension fijrb(5,5),qqerb(5)
      dimension rpathv(nrpotm),vrr(nrpotm)

      include 'data.fi'
c     
c     for generality/ease of modification purposes i have set this up to 
c     begin by evaluating the interfragment atom-atom distances
c     and a particular set of valence stretching, bending and torsional 
c     angles.
c     for efficient use one might wish to only evaluate the components 
c     that are required for the particular potential being used.  for a 
c     variety of reasons this seems to me to be best left for the specific 
c     applications.
c     
      pi2 = asin(1.0d0)
      pi = 2.0d0*pi2

      ift(1) = 2
      ift(2) = 0
      iel = 1
      ieff = 1
      ich = 1

c     
c     start by evaluating bonding separation
c     

c      rij(1,1) = dsqrt((r(1,1,1)-r(2,1,1))**2+(r(1,1,2)-r(2,1,2))**2+ 
c     $     (r(1,1,3)-r(2,1,3))**2)
c      rbond = rij(1,1)
c      rmepi = rbond

c
c     now evaluate the atom-atom separations
c

c      do 30 iatom = 1 , natom(1)
c         do 20 jatom = 1 , natom(2)
c            rij(iatom,jatom) = dsqrt((r(1,iatom,1)-r(2,jatom,1))**2 + 
c     $           (r(1,iatom,2)-r(2,jatom,2))**2 + 
c     $           (r(1,iatom,3)-r(2,jatom,3))**2)
c 20      continue
c 30   continue

 40   continue

c     
c     next is the center-of-mass (cm) separation and the
c     cm-center-of-charge separations 
c     
c
c      do 150 ifrag = 1 , nfrag
c         do 100 idim = 1 , ndim
c            cm(ifrag,idim) = 0.0d0
c            do 50 iatom = 1 , natom(ifrag)
c               cm(ifrag,idim) = cm(ifrag,idim) + dmss(ifrag,iatom)*
c     $              r(ifrag,iatom,idim)
c 50         continue
c            cm(ifrag,idim) = cm(ifrag,idim)/dmsst(ifrag)
c 100     continue
c 150  continue
c      
c      rcmcm = dsqrt((cm(1,1)-cm(2,1))**2 + (cm(1,2)-cm(2,2))**2 + 
c     $     (cm(1,3)-cm(2,3))**2)
c
c     
c     now proceed to the valence bending/torsional coordinates.
c     

c     
c     start by evaluating fragment's number of angular degrees of freedom
c     
      do 500 ifrag = 1, nfrag
         if (ift(ifrag).eq.0) nr(ifrag) = 0
         if (ift(ifrag).eq.1) then
            nr(ifrag) = 2
         endif
         if (ift(ifrag).ge.2) then
            nr(ifrag) = 3
         endif
 500  continue
c     
c     determine distances needed for bending angles
c     
      rbond2 = 0.0d0
      rax12 = 0.0d0
      rbx12 = 0.0d0
      rby12 = 0.0d0
      ray12 = 0.0d0
      do 1500 idim = 1 , ndim
         rbvec(idim) = r(2,1,idim) - r(1,1,idim)
         rbond2 = rbond2 + rbvec(idim)**2
         rax1v(idim) = r(1,2,idim) - r(1,1,idim)
         rax12 = rax12 + rax1v(idim)**2
         rbx1v(idim) = r(2,1,idim) - r(1,2,idim)
         rbx12 = rbx12 + rbx1v(idim)**2
 1500 continue
      rbond0 = sqrt(rbond2)
      rax1 = sqrt(rax12)
      rbx1 = sqrt(rbx12)
      ray1 = sqrt(ray12)
      rby1 = sqrt(rby12)
c     
c     calculate the bending angles.
c     

      cthe1 = (rax12 + rbond2 - rbx12)/(2.0d0*rax1*rbond0)
      if (dabs(cthe1).le.1.0d0) go to 2030
      if(dabs(cthe1)-1.d0.gt.1.e-6) 
     x     write (6,*) 'error in the1, cthe1 = ',cthe1
      the1 = 0.0d0
      if (cthe1.lt.1.0d0) the1 = 2.0d0*dasin(1.0d0)
      go to 2050
 2030 continue
      the1 = dacos(cthe1)
 2050 continue
      
c     
c     evaluate the number of degrees of freedom
c     
      ntdof = nr(1) + nr(2) - 1

c     
c     determine distances needed for torsional angles
c     

      rax22 = 0.0d0
      rbx22 = 0.0d0
      rx1x22 = 0.0d0
      do idim = 1 , ndim
         rax2v(idim) = r(1,3,idim) - r(1,1,idim)
         rax22 = rax22 + rax2v(idim)**2
         rbx2v(idim) = r(2,1,idim) - r(1,3,idim)
         rbx22 = rbx22 + rbx2v(idim)**2
         rx1x2v(idim) = r(1,3,idim) - r(1,2,idim)
         rx1x22 = rx1x22 + rx1x2v(idim)**2
      enddo
      rax2 = sqrt(rax22)
      rbx2 = sqrt(rbx22)
      rx1x2 = sqrt(rx1x22)

c     
c     now evaluate tau 3 (torsion angle for x2,x1,11,21.
c     
c     
c     consider the terminal atom case.
c     
c     first evaluate internal x2,x1,11 bending angle
c     

      ctaint = (rax12 + rx1x22 - rax22)/(2.0d0*rax1*rx1x2)
      if (dabs(ctaint).le.1.0d0) go to 2810
      write (6,*) 'error in taint, ctaint = ',ctaint
      taint = 0.0d0
      if (ctaint.lt.1.0d0) taint = 2.0d0*dasin(1.0d0)
      go to 2820
 2810 continue
      taint = dacos(ctaint)
 2820 continue
            
      sum = 0.0d0
      call cross(rbvec,rax1v,cptmp1)
      call cross(rax1v,rx1x2v,cptmp2)
      do 2830 idim = 1 , ndim
         sum = sum - cptmp1(idim)*cptmp2(idim)
 2830 continue
      ctau3 = sum/(rbond0*rax12*rx1x2*sin(the1)*sin(taint))
      if (dabs(ctau3).le.1.0d0) go to 2840
      write (6,*) 'error in tau3, ctau3 = ',ctau3
      tau3 = 0.0d0
      if (ctau3.lt.1.0d0) tau3 = 2.0d0*dasin(1.0d0)
      go to 2850
 2840 continue
      tau3 = dacos(ctau3)
 2850 continue
            
c     
c     still need to determine whether it is +/-
c     
            
      sum = 0.0d0
      call cross(rbvec,rax1v,cptmp1)
      call cross(rax1v,cptmp2,cptmp3)
      do 2860 idim = 1 , ndim
         sum = sum - cptmp1(idim)*cptmp3(idim)
 2860 continue
      ctau3b = sum/(rbond0*rax12*rax1*rx1x2*sin(the1)*
     $     sin(taint))
      if (dabs(ctau3b).le.1.0d0) go to 2870
      write (6,*) 'error in tau3b, ctau3b = ',ctau3b
      tau3b = 0.0d0
      if (ctau3b.lt.1.0d0) tau3b = 2.0d0*dasin(1.0d0)
      go to 2880
 2870 continue
      tau3b = dacos(ctau3b)
 2880 continue
            
      if (tau3b.lt.pi2) tau3 = -tau3

c     
c     finished generating the valence bending and torsional angles. 
c     now need to put them in the order that one is likely to 
c     generate them in during a z-matrix calculation.
c     

      rtmp = rbond
      if (rtmp.lt.3.4) then
         rtmp=3.4
c        write (6,*) 'error: r too small for potential',rbond
      endif
      if (rtmp.gt.15.0) rtmp=15.0
      theta = the1*180.0d0/pi
      phi = abs(tau3*180.0d0/pi)

c ***************************************************************
c
c     call harding potential
c
c ***************************************************************

      call hpvinoxy(rtmp,theta,phi,eraw,ebs,erl,ebsrl)
c     if () vtot=eraw
c     if () vtot=ebs
c     if () vtot=er1
c     if () vtot=ebsrl
      c2h3o_h = ebsrl

c
c now need to set potential to infinity if on wrong side of ch plane
c to do so first need to evaluate tau hcho
c this simply involves replacing o atom with h atom for x1
c

c     
c     determine distances needed for bending angles
c     
      rax12 = 0.0d0
      rbx12 = 0.0d0
      do 3500 idim = 1 , ndim
         rax1v(idim) = r(1,4,idim) - r(1,1,idim)
         rax12 = rax12 + rax1v(idim)**2
         rbx1v(idim) = r(2,1,idim) - r(1,4,idim)
         rbx12 = rbx12 + rbx1v(idim)**2
 3500 continue
      rax1 = sqrt(rax12)
      rbx1 = sqrt(rbx12)

c     
c     calculate the bending angles.
c     

      cthe1 = (rax12 + rbond2 - rbx12)/(2.0d0*rax1*rbond0)
      if (dabs(cthe1).le.1.0d0) go to 4030
      if(dabs(cthe1)-1.d0.gt.1.e-6) 
     x     write (6,*) 'error in the1, cthe1 = ',cthe1
      the1 = 0.0d0
      if (cthe1.lt.1.0d0) the1 = 2.0d0*dasin(1.0d0)
      go to 4050
 4030 continue
      the1 = dacos(cthe1)
 4050 continue

      rx1x22 = 0.0d0
      do idim = 1 , ndim
         rx1x2v(idim) = r(1,3,idim) - r(1,4,idim)
         rx1x22 = rx1x22 + rx1x2v(idim)**2
      enddo
      rx1x2 = sqrt(rx1x22)

c     
c     now evaluate tau 3 (torsion angle for x2,x1,11,21.
c     
c     
c     consider the terminal atom case.
c     
c     first evaluate internal x2,x1,11 bending angle
c     

      ctaint = (rax12 + rx1x22 - rax22)/(2.0d0*rax1*rx1x2)
      if (dabs(ctaint).le.1.0d0) go to 4810
      write (6,*) 'error in taint, ctaint = ',ctaint
      taint = 0.0d0
      if (ctaint.lt.1.0d0) taint = 2.0d0*dasin(1.0d0)
      go to 4820
 4810 continue
      taint = dacos(ctaint)
 4820 continue
            
      sum = 0.0d0
      call cross(rbvec,rax1v,cptmp1)
      call cross(rax1v,rx1x2v,cptmp2)
      do 4830 idim = 1 , ndim
         sum = sum - cptmp1(idim)*cptmp2(idim)
 4830 continue
      ctau3 = sum/(rbond0*rax12*rx1x2*sin(the1)*sin(taint))
      if (dabs(ctau3).le.1.0d0) go to 4840
      write (6,*) 'error in tau3, ctau3 = ',ctau3
      tau3 = 0.0d0
      if (ctau3.lt.1.0d0) tau3 = 2.0d0*dasin(1.0d0)
      go to 4850
 4840 continue
      tau3 = dacos(ctau3)
 4850 continue
            
c     if (abs(tau3).lt.pi2) vtot = 1.0d20
      
      return

c
c     error messages
c

 9010 continue
      write (6,*) 'error in potcalc.f.  must designate atom ',
     $     'type in potential input.'
      go to 9900

 9020 continue
      write (6,*) 'error in potcalc.f.  must designate atom ',
     $     'type in potential input.'
      go to 9900

 9100 continue
      write (6,*) 'error in potcalc.f. incorrect stretching',
     $     ' or bending parameters in potential input.'
      go to 9900

 9200 continue
      write (6,*) 'error in potcalc.f.  incorrect atom-atoma',
     $     ' inverse 6 or anisotropy parameters in potential input.'
      go to 9900

 9300 continue
      write (6,*) 'error in potcalc.f.  incorrect ion-',
     $     'molecule parameters in potential input.'
      go to 9900

 9350 write (6,*) 'error in potcalc.f.  distance coordinate out',
     $     ' of range of interpolation points.'
      go to 9900

 9380 write (6,*) 'error in potcalc.f.  input number of angles',
     $     ' nanglesd not equal to calculated degrees of freedom'
      go to 9900 

 9400 continue

 9410 continue

 9900 continue
      stop
      end


c     implicit real*8 (a-h,o-z)
c
c     sample main for calling h+ch2cho 3d spline
c
c     analytic 3d fit for h+vinoxy
c
c
c     coordinates:            hd
c                            /
c                        ha /
c                        | /
c                        c1
c                       / \
c                   hb-c2  o
c                      |   
c                      hc  
c
c       r     = r(hd-c1)                     (au)     3.4 <   r   < 15.0
c       theta = hd-c1-c2 angle             (degrees)  0.0 < theta < 180
c       phi   = hd-c1--c2-o dihedral angle (degrees)  0.0 <  phi  < 180
c
c     output: 
c
c       eraw  = cas+1+2+qc/aug-cc-pvdz energy (au) relative to h+vinoxy
c       ebs   = eraw + basis set correction (aug-cc-pvtz)
c       erl   = eraw + geometry relaxation correction
c       ebsrl = eraw + both corrections
c
c
c     vinoxy cartesian coordinates:
c
c                  x              y              z
c      c      0.000000000    0.000000000    0.000000000
c      c      0.000000000    0.000000000    2.750000000
c      o      0.000000000    1.925007304   -1.347904625
c      h      0.000000000   -1.857930963   -0.866367437
c      h      0.000000000    1.775352078    3.775000000
c      h      0.000000000   -1.775352078    3.775000000
c
c

c10    read(5,*,end=100) r,theta,phi
c      call hpvinoxy(r,theta,phi,eraw,ebs,erl,ebsrl)
c      write(6,1) r,theta,phi,eraw,ebs,erl,ebsrl
c1     format(3f8.2,5x,4f10.6)
c      go to 10
c100   stop
c      end

      subroutine hpvinoxy(r,theta,phi,eraw,ebs,erl,ebsrl)
      implicit real*8 (a-h,o-z)

      call spl3de(r,theta,phi,eraw, dfx, dfy, dfz)

      call geom (r,theta,phi,rch,roh)

      call basis(rch,roh,ebs)
      call relax(rch,roh,erl)
      call bsrl(rch,roh,ebsrl)

      ebsrl = eraw+ebsrl
      ebs = eraw+ebs
      erl = eraw+erl
      
      return
      end

      subroutine geom (rd,theta,phi, rch,roh)
      implicit real*8 (a-h,o-z)
      data degrad / 57.29577951308232d 00 /
      data zc /    2.750000000d0 /
      data yo,zo /    1.925007304d0,   -1.347904625d0 /

c
c     calculates ch and oh distances used in corrections for
c     basis set and geometry relaxation
c
      xi = rd*sin(theta/degrad) * sin(phi/degrad)
      yi = rd*sin(theta/degrad) * cos(phi/degrad)
      zi = rd*cos(theta/degrad)
      
      rch = dsqrt ( xi**2 + yi**2 + (zi-zc)**2)
      roh = dsqrt ( xi**2 + (yi-yo)**2 + (zi-zo)**2)

      return
      end
 
      subroutine basis(rch,roh,ebs)
      implicit real*8 (a-h,o-z)

      rc=rch
      if(rc .lt. 3.0) rc=3.0
      call cbasis(rc,ecbs)

      ro=roh
      if(ro .lt. 2.0) ro=2.0
      call obasis(ro,eobs)

      ebs=min(ecbs,eobs)
      return
      end
 
      subroutine relax(rch,roh,erl)
      implicit real*8 (a-h,o-z)

      rc=rch
      if(rc .lt. 3.0) rc=3.0
      call crelax(rc,ecrl)

      ro=roh
      if(ro .lt. 2.4) ro=2.4
      call orelax(ro,eorl)

      erl=min(ecrl,eorl)
      return
      end
 
      subroutine bsrl(rch,roh,ebsrl)
      implicit real*8 (a-h,o-z)

      rc=rch
      if(rc .lt. 3.0) rc=3.0
      call cbsrl(rc,ecbsrl)

      ro=roh
      if(ro .lt. 2.4) ro=2.4
      call obsrl(ro,eobsrl)

      ebsrl=min(ecbsrl,eobsrl)
      return
      end

      subroutine obsrl(xi,fi)
      implicit real*8 (a-h,o-z)
      dimension x( 23), f( 23),fpp( 23),del( 22)
 
      data fpp(  1), fpp(  2) /  5.9338272810d-02 ,  5.6223454381d-02 /
      data fpp(  3), fpp(  4) /  5.3267909667d-02 ,  4.9754906951d-02 /
      data fpp(  5), fpp(  6) / -5.2337537473d-02 , -6.1804757061d-02 /
      data fpp(  7), fpp(  8) / -4.1843434282d-02 , -1.5771505809d-02 /
      data fpp(  9), fpp( 10) / -9.0705424804d-03 , -3.7463242691d-03 /
      data fpp( 11), fpp( 12) / -8.6522411622d-04 , -2.3488266656d-05 /
      data fpp( 13), fpp( 14) / -2.1682281715d-04 , -4.5220464727d-05 /
      data fpp( 15), fpp( 16) / -3.7927197243d-05 , -1.0707463022d-06 /
      data fpp( 17), fpp( 18) /  2.1018245144d-07 ,  2.3001649641d-07 /
      data fpp( 19), fpp( 20) /  7.0485928506d-07 ,  4.9712471887d-07 /
      data fpp( 21), fpp( 22) / -9.1575606107d-08 ,  2.6164458888d-08 /
      data fpp( 23) / -1.3082229444d-08 /
 
      data f(  1), f(  2) / -2.8329000000d-02 , -2.7192000000d-02 /
      data f(  3), f(  4) / -2.3805000000d-02 , -1.8291000000d-02 /
      data f(  5), f(  6) / -1.1444000000d-02 , -6.0730000000d-03 /
      data f(  7), f(  8) / -2.9780000000d-03 , -1.5160000000d-03 /
      data f(  9), f( 10) / -8.1400000000d-04 , -4.8400000000d-04 /
      data f( 11), f( 12) / -2.8000000000d-04 , -1.5000000000d-04 /
      data f( 13), f( 14) / -6.9000000000d-05 , -2.7000000000d-05 /
      data f( 15), f( 16) /  1.0000000000d-05 ,  1.4000000000d-05 /
      data f( 17), f( 18) /  1.1000000000d-05 ,  8.0000000000d-06 /
      data f( 19), f( 20) /  3.0000000000d-06 ,  0.0000000000d+00 /
      data f( 21), f( 22) /  0.0000000000d+00 ,  0.0000000000d+00 /
      data f( 23) /  0.0000000000d+00 /
 
      data x(  1), x(  2) /  2.4000000000d+00 ,  2.6000000000d+00 /
      data x(  3), x(  4) /  2.8000000000d+00 ,  3.0000000000d+00 /
      data x(  5), x(  6) /  3.2000000000d+00 ,  3.4000000000d+00 /
      data x(  7), x(  8) /  3.6000000000d+00 ,  3.8000000000d+00 /
      data x(  9), x( 10) /  4.0000000000d+00 ,  4.2000000000d+00 /
      data x( 11), x( 12) /  4.5000000000d+00 ,  5.0000000000d+00 /
      data x( 13), x( 14) /  5.5000000000d+00 ,  6.0000000000d+00 /
      data x( 15), x( 16) /  7.0000000000d+00 ,  8.0000000000d+00 /
      data x( 17), x( 18) /  9.0000000000d+00 ,  1.0000000000d+01 /
      data x( 19), x( 20) /  1.2000000000d+01 ,  1.5000000000d+01 /
      data x( 21), x( 22) /  1.6000000000d+01 ,  1.8000000000d+01 /
      data x( 23) /  2.0000000000d+01 /
 
      data del(  1), del(  2) /  2.0000000000d-01 ,  2.0000000000d-01 /
      data del(  3), del(  4) /  2.0000000000d-01 ,  2.0000000000d-01 /
      data del(  5), del(  6) /  2.0000000000d-01 ,  2.0000000000d-01 /
      data del(  7), del(  8) /  2.0000000000d-01 ,  2.0000000000d-01 /
      data del(  9), del( 10) /  2.0000000000d-01 ,  3.0000000000d-01 /
      data del( 11), del( 12) /  5.0000000000d-01 ,  5.0000000000d-01 /
      data del( 13), del( 14) /  5.0000000000d-01 ,  1.0000000000d+00 /
      data del( 15), del( 16) /  1.0000000000d+00 ,  1.0000000000d+00 /
      data del( 17), del( 18) /  1.0000000000d+00 ,  2.0000000000d+00 /
      data del( 19), del( 20) /  3.0000000000d+00 ,  1.0000000000d+00 /
      data del( 21), del( 22) /  2.0000000000d+00 ,  2.0000000000d+00 /
      data npts / 23/
 

      if(xi .le. x(1)) then
        ii=1
      else if( xi .ge. x(npts)) then
        ii=npts-1
      else
        call hunt(x,npts,xi,ii)
      endif
      
 20   fi = fpp(ii)   * (x(ii+1)-xi)**3 / (6.0*del(ii)) + 
     x     fpp(ii+1) * (xi-x(ii))**3   / (6.0*del(ii)) +
     x     ((f(ii+1)/del(ii))-(fpp(ii+1)*del(ii)/6.0)) * (xi-x(ii)) + 
     x     ((f(ii)  /del(ii))-(fpp(ii)  *del(ii)/6.0)) * (x(ii+1)-xi)

      return
      end  

      subroutine cbsrl(xi,fi)
      implicit real*8 (a-h,o-z)
      dimension x( 20), f( 20),fpp( 20),del( 19)
 
      data fpp(  1), fpp(  2) / -2.5198902758d-02 , -1.7552194484d-02 /
      data fpp(  3), fpp(  4) /  2.4076806926d-03 , -2.0728528287d-02 /
      data fpp(  5), fpp(  6) / -1.1443567546d-02 ,  7.1027984706d-03 /
      data fpp(  7), fpp(  8) / -2.3417626336d-02 ,  1.8902221412d-03 /
      data fpp(  9), fpp( 10) / -6.1981350501d-03 ,  1.4223180591d-03 /
      data fpp( 11), fpp( 12) / -1.1471371863d-03 ,  5.5825252947d-04 /
      data fpp( 13), fpp( 14) / -1.8587293154d-04 ,  4.1239196686d-05 /
      data fpp( 15), fpp( 16) / -3.0838552051d-06 ,  2.1319672724d-06 /
      data fpp( 17), fpp( 18) / -5.0654104555d-08 ,  9.3310192602d-09 /
      data fpp( 19), fpp( 20) / -2.6660055029d-09 ,  1.3330027515d-09 /
 
      data f(  1), f(  2) / -1.5190000000d-02 , -1.1944000000d-02 /
      data f(  3), f(  4) / -9.3180000000d-03 , -6.8830000000d-03 /
      data f(  5), f(  6) / -5.0610000000d-03 , -3.6350000000d-03 /
      data f(  7), f(  8) / -2.2520000000d-03 , -1.2490000000d-03 /
      data f(  9), f( 10) / -1.6900000000d-04 ,  1.6000000000d-05 /
      data f( 11), f( 12) /  1.3200000000d-04 ,  2.0000000000d-06 /
      data f( 13), f( 14) /  2.2000000000d-05 ,  1.8000000000d-05 /
      data f( 15), f( 16) /  1.0000000000d-05 ,  3.0000000000d-06 /
      data f( 17), f( 18) /  0.0000000000d+00 ,  0.0000000000d+00 /
      data f( 19), f( 20) /  0.0000000000d+00 ,  0.0000000000d+00 /
 
      data x(  1), x(  2) /  3.0000000000d+00 ,  3.2000000000d+00 /
      data x(  3), x(  4) /  3.4000000000d+00 ,  3.6000000000d+00 /
      data x(  5), x(  6) /  3.8000000000d+00 ,  4.0000000000d+00 /
      data x(  7), x(  8) /  4.2000000000d+00 ,  4.5000000000d+00 /
      data x(  9), x( 10) /  5.0000000000d+00 ,  5.5000000000d+00 /
      data x( 11), x( 12) /  6.0000000000d+00 ,  7.0000000000d+00 /
      data x( 13), x( 14) /  8.0000000000d+00 ,  9.0000000000d+00 /
      data x( 15), x( 16) /  1.0000000000d+01 ,  1.2000000000d+01 /
      data x( 17), x( 18) /  1.5000000000d+01 ,  1.6000000000d+01 /
      data x( 19), x( 20) /  1.8000000000d+01 ,  2.0000000000d+01 /
 
      data del(  1), del(  2) /  2.0000000000d-01 ,  2.0000000000d-01 /
      data del(  3), del(  4) /  2.0000000000d-01 ,  2.0000000000d-01 /
      data del(  5), del(  6) /  2.0000000000d-01 ,  2.0000000000d-01 /
      data del(  7), del(  8) /  3.0000000000d-01 ,  5.0000000000d-01 /
      data del(  9), del( 10) /  5.0000000000d-01 ,  5.0000000000d-01 /
      data del( 11), del( 12) /  1.0000000000d+00 ,  1.0000000000d+00 /
      data del( 13), del( 14) /  1.0000000000d+00 ,  1.0000000000d+00 /
      data del( 15), del( 16) /  2.0000000000d+00 ,  3.0000000000d+00 /
      data del( 17), del( 18) /  1.0000000000d+00 ,  2.0000000000d+00 /
      data del( 19) /  2.0000000000d+00 /
      data npts / 20/
 

      if(xi .le. x(1)) then
        ii=1
      else if( xi .ge. x(npts)) then
        ii=npts-1
      else
        call hunt(x,npts,xi,ii)
      endif
      
 20   fi = fpp(ii)   * (x(ii+1)-xi)**3 / (6.0*del(ii)) + 
     x     fpp(ii+1) * (xi-x(ii))**3   / (6.0*del(ii)) +
     x     ((f(ii+1)/del(ii))-(fpp(ii+1)*del(ii)/6.0)) * (xi-x(ii)) + 
     x     ((f(ii)  /del(ii))-(fpp(ii)  *del(ii)/6.0)) * (x(ii+1)-xi)

      return
      end  

      subroutine crelax(xi,fi)
      implicit real*8 (a-h,o-z)
 
      dimension x( 18), f( 18),fpp( 18),del( 17)
 
      data fpp(  1), fpp(  2) / -1.3242760376d-02 , -1.2314479248d-02 /
      data fpp(  3), fpp(  4) / -1.0999322632d-02 , -1.1038230224d-02 /
      data fpp(  5), fpp(  6) / -8.5977564737d-03 , -7.8207438817d-03 /
      data fpp(  7), fpp(  8) / -6.3192679995d-03 , -4.4886107473d-03 /
      data fpp(  9), fpp( 10) / -1.9888848090d-03 , -5.8785001659d-04 /
      data fpp( 11), fpp( 12) / -9.9715124605d-05 ,  1.7070382109d-05 /
      data fpp( 13), fpp( 14) / -4.5664038317d-06 ,  1.1952332177d-06 /
      data fpp( 15), fpp( 16) / -2.1452903907d-07 ,  4.5970508373d-08 /
      data fpp( 17), fpp( 18) / -1.0215668527d-08 ,  5.1078342636d-09 /
 
      data f(  1), f(  2) / -1.3396000000d-02 , -1.0414000000d-02 /
      data f(  3), f(  4) / -7.9220000000d-03 , -5.8790000000d-03 /
      data f(  5), f(  6) / -4.2610000000d-03 , -2.9980000000d-03 /
      data f(  7), f(  8) / -2.0430000000d-03 , -1.0720000000d-03 /
      data f(  9), f( 10) / -2.9300000000d-04 , -5.7000000000d-05 /
      data f( 11), f( 12) / -6.0000000000d-06 ,  0.0000000000d+00 /
      data f( 13), f( 14) /  0.0000000000d+00 ,  0.0000000000d+00 /
      data f( 15), f( 16) /  0.0000000000d+00 ,  0.0000000000d+00 /
      data f( 17), f( 18) /  0.0000000000d+00 ,  0.0000000000d+00 /
 
      data x(  1), x(  2) /  3.0000000000d+00 ,  3.2000000000d+00 /
      data x(  3), x(  4) /  3.4000000000d+00 ,  3.6000000000d+00 /
      data x(  5), x(  6) /  3.8000000000d+00 ,  4.0000000000d+00 /
      data x(  7), x(  8) /  4.2000000000d+00 ,  4.5000000000d+00 /
      data x(  9), x( 10) /  5.0000000000d+00 ,  5.5000000000d+00 /
      data x( 11), x( 12) /  6.0000000000d+00 ,  7.0000000000d+00 /
      data x( 13), x( 14) /  8.0000000000d+00 ,  9.0000000000d+00 /
      data x( 15), x( 16) /  1.0000000000d+01 ,  1.2000000000d+01 /
      data x( 17), x( 18) /  1.5000000000d+01 ,  2.0000000000d+01 /
 
      data del(  1), del(  2) /  2.0000000000d-01 ,  2.0000000000d-01 /
      data del(  3), del(  4) /  2.0000000000d-01 ,  2.0000000000d-01 /
      data del(  5), del(  6) /  2.0000000000d-01 ,  2.0000000000d-01 /
      data del(  7), del(  8) /  3.0000000000d-01 ,  5.0000000000d-01 /
      data del(  9), del( 10) /  5.0000000000d-01 ,  5.0000000000d-01 /
      data del( 11), del( 12) /  1.0000000000d+00 ,  1.0000000000d+00 /
      data del( 13), del( 14) /  1.0000000000d+00 ,  1.0000000000d+00 /
      data del( 15), del( 16) /  2.0000000000d+00 ,  3.0000000000d+00 /
      data del( 17) /  5.0000000000d+00 /
      data npts / 18/

      if(xi .le. x(1)) then
        ii=1
      else if( xi .ge. x(npts)) then
        ii=npts-1
      else
        call hunt(x,npts,xi,ii)
      endif
      
 20   fi = fpp(ii)   * (x(ii+1)-xi)**3 / (6.0*del(ii)) + 
     x     fpp(ii+1) * (xi-x(ii))**3   / (6.0*del(ii)) +
     x     ((f(ii+1)/del(ii))-(fpp(ii+1)*del(ii)/6.0)) * (xi-x(ii)) + 
     x     ((f(ii)  /del(ii))-(fpp(ii)  *del(ii)/6.0)) * (x(ii+1)-xi)

      return
      end  
      subroutine orelax(xi,fi)
      implicit real*8 (a-h,o-z)
      dimension x( 21), f( 21),fpp( 21),del( 20)
 
      data fpp(  1), fpp(  2) /  5.3914567317d-02 ,  5.4295865366d-02 /
      data fpp(  3), fpp(  4) /  7.1651971219d-02 ,  2.9596249757d-02 /
      data fpp(  5), fpp(  6) / -2.9986970248d-02 , -6.6998368764d-02 /
      data fpp(  7), fpp(  8) / -3.7419554695d-02 , -1.5673412455d-02 /
      data fpp(  9), fpp( 10) / -7.2867954840d-03 , -3.3294056089d-03 /
      data fpp( 11), fpp( 12) / -1.0107843144d-03 , -1.5184682844d-04 /
      data fpp( 13), fpp( 14) / -6.1828371783d-05 ,  1.5160315575d-05 /
      data fpp( 15), fpp( 16) / -2.6566760835d-05 ,  7.1067277637d-06 /
      data fpp( 17), fpp( 18) / -1.8601502200d-06 ,  3.3387311642d-07 /
      data fpp( 19), fpp( 20) / -7.1544239232d-08 ,  1.5898719829d-08 /
      data fpp( 21) / -7.9493599147d-09 /
 
      data f(  1), f(  2) / -2.4828000000d-02 , -2.4482000000d-02 /
      data f(  3), f(  4) / -2.1851000000d-02 , -1.6750000000d-02 /
      data f(  5), f(  6) / -1.0582000000d-02 , -5.4630000000d-03 /
      data f(  7), f(  8) / -2.5800000000d-03 , -1.2460000000d-03 /
      data f(  9), f( 10) / -6.2800000000d-04 , -3.3100000000d-04 /
      data f( 11), f( 12) / -1.4000000000d-04 , -4.6000000000d-05 /
      data f( 13), f( 14) / -2.2000000000d-05 , -1.4000000000d-05 /
      data f( 15), f( 16) /  0.0000000000d+00 ,  0.0000000000d+00 /
      data f( 17), f( 18) /  0.0000000000d+00 ,  0.0000000000d+00 /
      data f( 19), f( 20) /  0.0000000000d+00 ,  0.0000000000d+00 /
      data f( 21) /  0.0000000000d+00 /
 
      data x(  1), x(  2) /  2.4000000000d+00 ,  2.6000000000d+00 /
      data x(  3), x(  4) /  2.8000000000d+00 ,  3.0000000000d+00 /
      data x(  5), x(  6) /  3.2000000000d+00 ,  3.4000000000d+00 /
      data x(  7), x(  8) /  3.6000000000d+00 ,  3.8000000000d+00 /
      data x(  9), x( 10) /  4.0000000000d+00 ,  4.2000000000d+00 /
      data x( 11), x( 12) /  4.5000000000d+00 ,  5.0000000000d+00 /
      data x( 13), x( 14) /  5.5000000000d+00 ,  6.0000000000d+00 /
      data x( 15), x( 16) /  7.0000000000d+00 ,  8.0000000000d+00 /
      data x( 17), x( 18) /  9.0000000000d+00 ,  1.0000000000d+01 /
      data x( 19), x( 20) /  1.2000000000d+01 ,  1.5000000000d+01 /
      data x( 21) /  2.0000000000d+01 /
 
      data del(  1), del(  2) /  2.0000000000d-01 ,  2.0000000000d-01 /
      data del(  3), del(  4) /  2.0000000000d-01 ,  2.0000000000d-01 /
      data del(  5), del(  6) /  2.0000000000d-01 ,  2.0000000000d-01 /
      data del(  7), del(  8) /  2.0000000000d-01 ,  2.0000000000d-01 /
      data del(  9), del( 10) /  2.0000000000d-01 ,  3.0000000000d-01 /
      data del( 11), del( 12) /  5.0000000000d-01 ,  5.0000000000d-01 /
      data del( 13), del( 14) /  5.0000000000d-01 ,  1.0000000000d+00 /
      data del( 15), del( 16) /  1.0000000000d+00 ,  1.0000000000d+00 /
      data del( 17), del( 18) /  1.0000000000d+00 ,  2.0000000000d+00 /
      data del( 19), del( 20) /  3.0000000000d+00 ,  5.0000000000d+00 /
      data npts / 21/
 

      if(xi .le. x(1)) then
        ii=1
      else if( xi .ge. x(npts)) then
        ii=npts-1
      else
        call hunt(x,npts,xi,ii)
      endif
      
 20   fi = fpp(ii)   * (x(ii+1)-xi)**3 / (6.0*del(ii)) + 
     x     fpp(ii+1) * (xi-x(ii))**3   / (6.0*del(ii)) +
     x     ((f(ii+1)/del(ii))-(fpp(ii+1)*del(ii)/6.0)) * (xi-x(ii)) + 
     x     ((f(ii)  /del(ii))-(fpp(ii)  *del(ii)/6.0)) * (x(ii+1)-xi)

      return
      end  
      subroutine cbasis(xi,fi)
      implicit real*8 (a-h,o-z)
      dimension x( 16), f( 16),fpp( 16),del( 15)
 
      data fpp(  1), fpp(  2) /  5.5069536248d-04 ,  1.9860927505d-04 /
      data fpp(  3), fpp(  4) / -4.4513246266d-04 , -6.8079424397d-05 /
      data fpp(  5), fpp(  6) / -3.2549839751d-05 , -1.1517212166d-03 /
      data fpp(  7), fpp(  8) / -1.2105652938d-03 , -1.2303015428d-03 /
      data fpp(  9), fpp( 10) / -6.3269588681d-04 , -2.2291491000d-04 /
      data fpp( 11), fpp( 12) /  1.2355526796d-05 ,  3.2390874610d-05 /
      data fpp( 13), fpp( 14) / -2.7919025235d-05 ,  7.5616383994d-06 /
      data fpp( 15), fpp( 16) / -8.2752836289d-07 ,  2.7173356100d-06 /
 
      data f(  1), f(  2) / -2.2720000000d-03 , -1.9730000000d-03 /
      data f(  3), f(  4) / -1.6680000000d-03 , -1.3740000000d-03 /
      data f(  5), f(  6) / -1.0850000000d-03 , -8.0500000000d-04 /
      data f(  7), f(  8) / -5.6400000000d-04 , -2.9300000000d-04 /
      data f(  9), f( 10) / -6.2000000000d-05 ,  3.0000000000d-06 /
      data f( 11), f( 12) /  5.0000000000d-06 ,  2.0000000000d-06 /
      data f( 13), f( 14) /  1.8000000000d-05 ,  1.0000000000d-05 /
      data f( 15), f( 16) /  3.0000000000d-06 ,  0.0000000000d+00 /
 
      data x(  1), x(  2) /  3.0000000000d+00 ,  3.2000000000d+00 /
      data x(  3), x(  4) /  3.4000000000d+00 ,  3.6000000000d+00 /
      data x(  5), x(  6) /  3.8000000000d+00 ,  4.0000000000d+00 /
      data x(  7), x(  8) /  4.2000000000d+00 ,  4.5000000000d+00 /
      data x(  9), x( 10) /  5.0000000000d+00 ,  5.5000000000d+00 /
      data x( 11), x( 12) /  6.0000000000d+00 ,  7.0000000000d+00 /
      data x( 13), x( 14) /  8.0000000000d+00 ,  1.0000000000d+01 /
      data x( 15), x( 16) /  1.2000000000d+01 ,  1.5000000000d+01 /
 
      data del(  1), del(  2) /  2.0000000000d-01 ,  2.0000000000d-01 /
      data del(  3), del(  4) /  2.0000000000d-01 ,  2.0000000000d-01 /
      data del(  5), del(  6) /  2.0000000000d-01 ,  2.0000000000d-01 /
      data del(  7), del(  8) /  3.0000000000d-01 ,  5.0000000000d-01 /
      data del(  9), del( 10) /  5.0000000000d-01 ,  5.0000000000d-01 /
      data del( 11), del( 12) /  1.0000000000d+00 ,  1.0000000000d+00 /
      data del( 13), del( 14) /  2.0000000000d+00 ,  2.0000000000d+00 /
      data del( 15) /  3.0000000000d+00 /
      data npts / 16/
 

      if(xi .le. x(1)) then
        ii=1
      else if( xi .ge. x(npts)) then
        ii=npts-1
      else
        call hunt(x,npts,xi,ii)
      endif
      
 20   fi = fpp(ii)   * (x(ii+1)-xi)**3 / (6.0*del(ii)) + 
     x     fpp(ii+1) * (xi-x(ii))**3   / (6.0*del(ii)) +
     x     ((f(ii+1)/del(ii))-(fpp(ii+1)*del(ii)/6.0)) * (xi-x(ii)) + 
     x     ((f(ii)  /del(ii))-(fpp(ii)  *del(ii)/6.0)) * (x(ii+1)-xi)

      return
      end  
      subroutine obasis(xi,fi)
      implicit real*8 (a-h,o-z)
      dimension x( 25), f( 25),fpp( 25),del( 24)
 
      data fpp(  1), fpp(  2) / -1.4488281558d-02 , -6.6484368843d-03 /
      data fpp(  3), fpp(  4) /  9.1320290951d-03 , -2.8796794963d-03 /
      data fpp(  5), fpp(  6) / -1.5133111101d-03 , -6.2170760633d-03 /
      data fpp(  7), fpp(  8) / -4.5183846368d-03 , -3.7593853895d-03 /
      data fpp(  9), fpp( 10) / -1.8940738054d-03 , -8.1431938909d-04 /
      data fpp( 11), fpp( 12) / -3.9864863826d-04 , -1.4108605786d-04 /
      data fpp( 13), fpp( 14) / -1.6394738162d-04 , -1.5871674411d-04 /
      data fpp( 15), fpp( 16) / -8.9185641945d-05 , -6.0540688112d-05 /
      data fpp( 17), fpp( 18) / -2.5785114693d-05 , -4.3188531160d-06 /
      data fpp( 19), fpp( 20) /  1.0605271571d-06 ,  7.6744487740d-08 /
      data fpp( 21), fpp( 22) /  7.3950295825d-07 ,  4.8382714734d-07 /
      data fpp( 23), fpp( 24) / -8.9126053457d-08 ,  2.5464586702d-08 /
      data fpp( 25) / -1.2732293351d-08 /
 
      data f(  1), f(  2) / -5.6060000000d-03 , -4.7140000000d-03 /
      data f(  3), f(  4) / -4.0350000000d-03 , -3.1760000000d-03 /
      data f(  5), f(  6) / -2.3430000000d-03 , -1.6110000000d-03 /
      data f(  7), f(  8) / -1.0850000000d-03 , -7.4600000000d-04 /
      data f(  9), f( 10) / -5.5000000000d-04 , -4.3500000000d-04 /
      data f( 11), f( 12) / -3.5700000000d-04 , -2.9600000000d-04 /
      data f( 13), f( 14) / -2.1800000000d-04 , -1.2000000000d-04 /
      data f( 15), f( 16) / -5.9000000000d-05 , -2.2000000000d-05 /
      data f( 17), f( 18) /  1.0000000000d-05 ,  1.4000000000d-05 /
      data f( 19), f( 20) /  1.1000000000d-05 ,  8.0000000000d-06 /
      data f( 21), f( 22) /  3.0000000000d-06 ,  0.0000000000d+00 /
      data f( 23), f( 24) /  0.0000000000d+00 ,  0.0000000000d+00 /
      data f( 25) /  0.0000000000d+00 /
 
      data x(  1), x(  2) /  2.0000000000d+00 ,  2.2000000000d+00 /
      data x(  3), x(  4) /  2.4000000000d+00 ,  2.6000000000d+00 /
      data x(  5), x(  6) /  2.8000000000d+00 ,  3.0000000000d+00 /
      data x(  7), x(  8) /  3.2000000000d+00 ,  3.4000000000d+00 /
      data x(  9), x( 10) /  3.6000000000d+00 ,  3.8000000000d+00 /
      data x( 11), x( 12) /  4.0000000000d+00 ,  4.2000000000d+00 /
      data x( 13), x( 14) /  4.5000000000d+00 ,  5.0000000000d+00 /
      data x( 15), x( 16) /  5.5000000000d+00 ,  6.0000000000d+00 /
      data x( 17), x( 18) /  7.0000000000d+00 ,  8.0000000000d+00 /
      data x( 19), x( 20) /  9.0000000000d+00 ,  1.0000000000d+01 /
      data x( 21), x( 22) /  1.2000000000d+01 ,  1.5000000000d+01 /
      data x( 23), x( 24) /  1.6000000000d+01 ,  1.8000000000d+01 /
      data x( 25) /  2.0000000000d+01 /
 
      data del(  1), del(  2) /  2.0000000000d-01 ,  2.0000000000d-01 /
      data del(  3), del(  4) /  2.0000000000d-01 ,  2.0000000000d-01 /
      data del(  5), del(  6) /  2.0000000000d-01 ,  2.0000000000d-01 /
      data del(  7), del(  8) /  2.0000000000d-01 ,  2.0000000000d-01 /
      data del(  9), del( 10) /  2.0000000000d-01 ,  2.0000000000d-01 /
      data del( 11), del( 12) /  2.0000000000d-01 ,  3.0000000000d-01 /
      data del( 13), del( 14) /  5.0000000000d-01 ,  5.0000000000d-01 /
      data del( 15), del( 16) /  5.0000000000d-01 ,  1.0000000000d+00 /
      data del( 17), del( 18) /  1.0000000000d+00 ,  1.0000000000d+00 /
      data del( 19), del( 20) /  1.0000000000d+00 ,  2.0000000000d+00 /
      data del( 21), del( 22) /  3.0000000000d+00 ,  1.0000000000d+00 /
      data del( 23), del( 24) /  2.0000000000d+00 ,  2.0000000000d+00 /
      data npts / 25/
 

      if(xi .le. x(1)) then
        ii=1
      else if( xi .ge. x(npts)) then
        ii=npts-1
      else
        call hunt(x,npts,xi,ii)
      endif
      
 20   fi = fpp(ii)   * (x(ii+1)-xi)**3 / (6.0*del(ii)) + 
     x     fpp(ii+1) * (xi-x(ii))**3   / (6.0*del(ii)) +
     x     ((f(ii+1)/del(ii))-(fpp(ii+1)*del(ii)/6.0)) * (xi-x(ii)) + 
     x     ((f(ii)  /del(ii))-(fpp(ii)  *del(ii)/6.0)) * (x(ii+1)-xi)

      return
      end  

      subroutine spl3de(xi,yi,zi,fi,dfx,dfy,dfz)
      implicit real*8 (a-h,o-z)
      dimension fpp(30,19,23,3),f(30,19,23),fpppp(30,19,23,3)
      dimension fxyz(30,19,23)
      dimension delx(29),dely(18),delz(22),x(30),y(19),z(23)
      dimension c(4,4,4),px(4),py(4),pz(4)
      dimension dpx(4),dpy(4),dpz(4)
 
      data f( 1, 1, 1),f( 1, 1, 2) /  4.1013620d-01 ,  4.1013620d-01 /
      data f( 1, 1, 3),f( 1, 1, 4) /  4.1013620d-01 ,  4.1013620d-01 /
      data f( 1, 1, 5),f( 1, 1, 6) /  4.1013620d-01 ,  4.1013620d-01 /
      data f( 1, 1, 7),f( 1, 1, 8) /  4.1013620d-01 ,  4.1013620d-01 /
      data f( 1, 1, 9),f( 1, 1,10) /  4.1013620d-01 ,  4.1013620d-01 /
      data f( 1, 1,11),f( 1, 1,12) /  4.1013620d-01 ,  4.1013620d-01 /
      data f( 1, 1,13),f( 1, 1,14) /  4.1013620d-01 ,  4.1013620d-01 /
      data f( 1, 1,15),f( 1, 1,16) /  4.1013620d-01 ,  4.1013620d-01 /
      data f( 1, 1,17),f( 1, 1,18) /  4.1013620d-01 ,  4.1013620d-01 /
      data f( 1, 1,19),f( 1, 1,20) /  4.1013620d-01 ,  4.1013620d-01 /
      data f( 1, 1,21),f( 1, 1,22) /  4.1013620d-01 ,  4.1013620d-01 /
      data f( 1, 1,23) /              4.1013620d-01 /
      data f( 1, 2, 1),f( 1, 2, 2) /  2.8391360d-01 ,  2.8578460d-01 /
      data f( 1, 2, 3),f( 1, 2, 4) /  2.8692110d-01 ,  2.8692110d-01 /
      data f( 1, 2, 5),f( 1, 2, 6) /  2.8578460d-01 ,  2.8391360d-01 /
      data f( 1, 2, 7),f( 1, 2, 8) /  2.8190800d-01 ,  2.8002090d-01 /
      data f( 1, 2, 9),f( 1, 2,10) /  2.7842790d-01 ,  2.7751380d-01 /
      data f( 1, 2,11),f( 1, 2,12) /  2.7651210d-01 ,  2.7627970d-01 /
      data f( 1, 2,13),f( 1, 2,14) /  2.7655030d-01 ,  2.7731040d-01 /
      data f( 1, 2,15),f( 1, 2,16) /  2.7854560d-01 ,  2.8043120d-01 /
      data f( 1, 2,17),f( 1, 2,18) /  2.8211840d-01 ,  2.8418340d-01 /
      data f( 1, 2,19),f( 1, 2,20) /  2.8611640d-01 ,  2.8755350d-01 /
      data f( 1, 2,21),f( 1, 2,22) /  2.8755350d-01 ,  2.8611640d-01 /
      data f( 1, 2,23) /              2.8418340d-01 /
      data f( 1, 3, 1),f( 1, 3, 2) /  1.8266410d-01 ,  1.8932850d-01 /
      data f( 1, 3, 3),f( 1, 3, 4) /  1.9557240d-01 ,  1.9557240d-01 /
      data f( 1, 3, 5),f( 1, 3, 6) /  1.8932850d-01 ,  1.8266410d-01 /
      data f( 1, 3, 7),f( 1, 3, 8) /  1.7732240d-01 ,  1.7335950d-01 /
      data f( 1, 3, 9),f( 1, 3,10) /  1.7052180d-01 ,  1.6858760d-01 /
      data f( 1, 3,11),f( 1, 3,12) /  1.6746350d-01 ,  1.6709540d-01 /
      data f( 1, 3,13),f( 1, 3,14) /  1.6747760d-01 ,  1.6861190d-01 /
      data f( 1, 3,15),f( 1, 3,16) /  1.7056790d-01 ,  1.7345450d-01 /
      data f( 1, 3,17),f( 1, 3,18) /  1.7748900d-01 ,  1.8292000d-01 /
      data f( 1, 3,19),f( 1, 3,20) /  1.8965970d-01 ,  1.9625630d-01 /
      data f( 1, 3,21),f( 1, 3,22) /  1.9625630d-01 ,  1.8965970d-01 /
      data f( 1, 3,23) /              1.8292000d-01 /
      data f( 1, 4, 1),f( 1, 4, 2) /  6.8750800d-02 ,  1.3905260d-01 /
      data f( 1, 4, 3),f( 1, 4, 4) /  1.6525160d-01 ,  1.6525160d-01 /
      data f( 1, 4, 5),f( 1, 4, 6) /  1.3905260d-01 ,  6.8750800d-02 /
      data f( 1, 4, 7),f( 1, 4, 8) /  1.8257700d-02 , -1.7897200d-02 /
      data f( 1, 4, 9),f( 1, 4,10) / -4.4071300d-02 , -6.2372600d-02 /
      data f( 1, 4,11),f( 1, 4,12) / -7.3236200d-02 , -7.6992000d-02 /
      data f( 1, 4,13),f( 1, 4,14) / -7.3611700d-02 , -6.3120400d-02 /
      data f( 1, 4,15),f( 1, 4,16) / -4.4941100d-02 , -1.8313700d-02 /
      data f( 1, 4,17),f( 1, 4,18) /  1.8852800d-02 ,  7.0688600d-02 /
      data f( 1, 4,19),f( 1, 4,20) /  1.4285490d-01 ,  1.6597870d-01 /
      data f( 1, 4,21),f( 1, 4,22) /  1.6597870d-01 ,  1.4285490d-01 /
      data f( 1, 4,23) /              7.0688600d-02 /
      data f( 1, 5, 1),f( 1, 5, 2) / -1.5862500d-02 ,  1.5839900d-02 /
      data f( 1, 5, 3),f( 1, 5, 4) /  4.0965800d-02 ,  4.0965800d-02 /
      data f( 1, 5, 5),f( 1, 5, 6) /  1.5839900d-02 , -1.5862500d-02 /
      data f( 1, 5, 7),f( 1, 5, 8) / -4.5590900d-02 , -7.4503600d-02 /
      data f( 1, 5, 9),f( 1, 5,10) / -9.3851600d-02 , -1.0990190d-01 /
      data f( 1, 5,11),f( 1, 5,12) / -1.1960720d-01 , -1.2379250d-01 /
      data f( 1, 5,13),f( 1, 5,14) / -1.2101520d-01 , -1.1241260d-01 /
      data f( 1, 5,15),f( 1, 5,16) / -9.7074800d-02 , -7.5373600d-02 /
      data f( 1, 5,17),f( 1, 5,18) / -4.7506100d-02 , -1.4829700d-02 /
      data f( 1, 5,19),f( 1, 5,20) /  2.0522400d-02 ,  5.2213700d-02 /
      data f( 1, 5,21),f( 1, 5,22) /  5.2213700d-02 ,  2.0522400d-02 /
      data f( 1, 5,23) /             -1.4829700d-02 /
      data f( 1, 6, 1),f( 1, 6, 2) / -9.4713000d-03 ,  1.1173800d-02 /
      data f( 1, 6, 3),f( 1, 6, 4) /  2.4167000d-02 ,  2.4167000d-02 /
      data f( 1, 6, 5),f( 1, 6, 6) /  1.1173800d-02 , -9.4713000d-03 /
      data f( 1, 6, 7),f( 1, 6, 8) / -3.2340500d-02 , -5.4234100d-02 /
      data f( 1, 6, 9),f( 1, 6,10) / -7.3059200d-02 , -8.7575700d-02 /
      data f( 1, 6,11),f( 1, 6,12) / -9.7107600d-02 , -1.0128780d-01 /
      data f( 1, 6,13),f( 1, 6,14) / -9.9942900d-02 , -9.2991800d-02 /
      data f( 1, 6,15),f( 1, 6,16) / -8.0422200d-02 , -6.2330400d-02 /
      data f( 1, 6,17),f( 1, 6,18) / -3.9106800d-02 , -1.1754700d-02 /
      data f( 1, 6,19),f( 1, 6,20) /  1.7599800d-02 ,  4.4294000d-02 /
      data f( 1, 6,21),f( 1, 6,22) /  4.4294000d-02 ,  1.7599800d-02 /
      data f( 1, 6,23) /             -1.1754700d-02 /
      data f( 1, 7, 1),f( 1, 7, 2) /  7.1656000d-03 ,  2.2627900d-02 /
      data f( 1, 7, 3),f( 1, 7, 4) /  1.9061100d-02 ,  1.9061100d-02 /
      data f( 1, 7, 5),f( 1, 7, 6) /  2.2627900d-02 ,  7.1656000d-03 /
      data f( 1, 7, 7),f( 1, 7, 8) / -7.3514000d-03 , -2.4219500d-02 /
      data f( 1, 7, 9),f( 1, 7,10) / -3.9044100d-02 , -5.2921900d-02 /
      data f( 1, 7,11),f( 1, 7,12) / -6.2119300d-02 , -6.6526000d-02 /
      data f( 1, 7,13),f( 1, 7,14) / -6.7003300d-02 , -6.2358500d-02 /
      data f( 1, 7,15),f( 1, 7,16) / -5.2185400d-02 , -3.9181400d-02 /
      data f( 1, 7,17),f( 1, 7,18) / -2.1127000d-02 ,  3.0343000d-03 /
      data f( 1, 7,19),f( 1, 7,20) /  2.4982900d-02 ,  5.5761900d-02 /
      data f( 1, 7,21),f( 1, 7,22) /  5.5761900d-02 ,  2.4982900d-02 /
      data f( 1, 7,23) /              3.0343000d-03 /
      data f( 1, 8, 1),f( 1, 8, 2) /  1.4986800d-02 ,  1.9456000d-03 /
      data f( 1, 8, 3),f( 1, 8, 4) / -7.3419000d-03 , -7.3419000d-03 /
      data f( 1, 8, 5),f( 1, 8, 6) /  1.9456000d-03 ,  1.4986800d-02 /
      data f( 1, 8, 7),f( 1, 8, 8) /  1.3544600d-02 ,  2.7789000d-03 /
      data f( 1, 8, 9),f( 1, 8,10) / -5.2861000d-03 , -2.1110300d-02 /
      data f( 1, 8,11),f( 1, 8,12) / -2.6746000d-02 , -3.2516500d-02 /
      data f( 1, 8,13),f( 1, 8,14) / -3.4201300d-02 , -3.5244000d-02 /
      data f( 1, 8,15),f( 1, 8,16) / -2.5377000d-02 , -1.9885200d-02 /
      data f( 1, 8,17),f( 1, 8,18) / -2.2064000d-03 ,  1.3623400d-02 /
      data f( 1, 8,19),f( 1, 8,20) /  3.1529900d-02 ,  5.0900100d-02 /
      data f( 1, 8,21),f( 1, 8,22) /  5.0900100d-02 ,  3.1529900d-02 /
      data f( 1, 8,23) /              1.3623400d-02 /
      data f( 1, 9, 1),f( 1, 9, 2) / -1.1927800d-02 , -3.7280800d-02 /
      data f( 1, 9, 3),f( 1, 9, 4) / -5.5578100d-02 , -5.5578100d-02 /
      data f( 1, 9, 5),f( 1, 9, 6) / -3.7280800d-02 , -1.1927800d-02 /
      data f( 1, 9, 7),f( 1, 9, 8) /  1.6190500d-02 ,  4.3208800d-02 /
      data f( 1, 9, 9),f( 1, 9,10) /  2.3949800d-02 ,  4.5070000d-03 /
      data f( 1, 9,11),f( 1, 9,12) /  3.4873000d-03 , -3.3613000d-03 /
      data f( 1, 9,13),f( 1, 9,14) / -6.7323000d-03 , -1.4202700d-02 /
      data f( 1, 9,15),f( 1, 9,16) / -3.4487000d-03 , -5.4922000d-03 /
      data f( 1, 9,17),f( 1, 9,18) /  1.0351500d-02 ,  1.9919500d-02 /
      data f( 1, 9,19),f( 1, 9,20) /  3.0732800d-02 ,  4.2016200d-02 /
      data f( 1, 9,21),f( 1, 9,22) /  4.2016200d-02 ,  3.0732800d-02 /
      data f( 1, 9,23) /              1.9919500d-02 /
      data f( 1,10, 1),f( 1,10, 2) / -5.2874600d-02 , -8.1637000d-02 /
      data f( 1,10, 3),f( 1,10, 4) / -1.0180920d-01 , -1.0180920d-01 /
      data f( 1,10, 5),f( 1,10, 6) / -8.1637000d-02 , -5.2874600d-02 /
      data f( 1,10, 7),f( 1,10, 8) / -1.5708200d-02 ,  1.9951900d-02 /
      data f( 1,10, 9),f( 1,10,10) /  5.1124200d-02 ,  2.3888700d-02 /
      data f( 1,10,11),f( 1,10,12) /  7.2666300d-02 ,  6.7252600d-02 /
      data f( 1,10,13),f( 1,10,14) /  2.9728000d-03 ,  5.5673300d-02 /
      data f( 1,10,15),f( 1,10,16) /  2.3438000d-03 ,  5.4134000d-03 /
      data f( 1,10,17),f( 1,10,18) /  1.0347400d-02 ,  1.7064300d-02 /
      data f( 1,10,19),f( 1,10,20) /  2.5999700d-02 ,  3.7719300d-02 /
      data f( 1,10,21),f( 1,10,22) /  3.7719300d-02 ,  2.5999700d-02 /
      data f( 1,10,23) /              1.7064300d-02 /
      data f( 1,11, 1),f( 1,11, 2) / -9.0686300d-02 , -1.0942480d-01 /
      data f( 1,11, 3),f( 1,11, 4) / -1.0636700d-01 , -1.0636700d-01 /
      data f( 1,11, 5),f( 1,11, 6) / -1.0942480d-01 , -9.0686300d-02 /
      data f( 1,11, 7),f( 1,11, 8) / -5.4186100d-02 , -1.2533100d-02 /
      data f( 1,11, 9),f( 1,11,10) /  2.5041300d-02 ,  3.7303500d-02 /
      data f( 1,11,11),f( 1,11,12) /  2.7320000d-02 ,  1.9943200d-02 /
      data f( 1,11,13),f( 1,11,14) /  1.5262200d-02 ,  5.9837300d-02 /
      data f( 1,11,15),f( 1,11,16) /  1.2795800d-02 ,  1.4422200d-02 /
      data f( 1,11,17),f( 1,11,18) /  1.7538200d-02 ,  2.2241900d-02 /
      data f( 1,11,19),f( 1,11,20) /  2.9509900d-02 ,  3.9730700d-02 /
      data f( 1,11,21),f( 1,11,22) /  3.9730700d-02 ,  2.9509900d-02 /
      data f( 1,11,23) /              2.2241900d-02 /
      data f( 1,12, 1),f( 1,12, 2) / -1.0465250d-01 , -7.7824000d-02 /
      data f( 1,12, 3),f( 1,12, 4) /  4.3203000d-03 ,  4.3203000d-03 /
      data f( 1,12, 5),f( 1,12, 6) / -7.7824000d-02 , -1.0465250d-01 /
      data f( 1,12, 7),f( 1,12, 8) / -8.2900400d-02 , -4.2552800d-02 /
      data f( 1,12, 9),f( 1,12,10) / -1.7064000d-03 ,  3.0460000d-02 /
      data f( 1,12,11),f( 1,12,12) /  3.4811500d-02 ,  2.8272000d-02 /
      data f( 1,12,13),f( 1,12,14) /  2.3826800d-02 ,  6.6149600d-02 /
      data f( 1,12,15),f( 1,12,16) /  2.1266400d-02 ,  2.2513800d-02 /
      data f( 1,12,17),f( 1,12,18) /  2.4945800d-02 ,  2.8761800d-02 /
      data f( 1,12,19),f( 1,12,20) /  3.4696200d-02 ,  3.2876300d-02 /
      data f( 1,12,21),f( 1,12,22) /  3.2876300d-02 ,  3.4696200d-02 /
      data f( 1,12,23) /              2.8761800d-02 /
      data f( 1,13, 1),f( 1,13, 2) / -9.2856300d-02 ,  6.5508000d-03 /
      data f( 1,13, 3),f( 1,13, 4) /  1.6533200d-01 ,  1.6533200d-01 /
      data f( 1,13, 5),f( 1,13, 6) /  6.5508000d-03 , -9.2856300d-02 /
      data f( 1,13, 7),f( 1,13, 8) / -9.8455300d-02 , -6.5700100d-02 /
      data f( 1,13, 9),f( 1,13,10) / -2.5070000d-02 ,  1.1081000d-02 /
      data f( 1,13,11),f( 1,13,12) /  3.3497900d-02 ,  3.2488400d-02 /
      data f( 1,13,13),f( 1,13,14) /  2.9265600d-02 ,  6.2476100d-02 /
      data f( 1,13,15),f( 1,13,16) /  2.7825600d-02 ,  2.9413100d-02 /
      data f( 1,13,17),f( 1,13,18) /  3.2145000d-02 ,  3.6340500d-02 /
      data f( 1,13,19),f( 1,13,20) /  4.3210300d-02 ,  3.6655800d-02 /
      data f( 1,13,21),f( 1,13,22) /  3.6655800d-02 ,  4.3210300d-02 /
      data f( 1,13,23) /              3.6340500d-02 /
      data f( 1,14, 1),f( 1,14, 2) / -8.5432600d-02 ,  2.6473600d-02 /
      data f( 1,14, 3),f( 1,14, 4) /  1.6666940d-01 ,  1.6666940d-01 /
      data f( 1,14, 5),f( 1,14, 6) /  2.6473600d-02 , -8.5432600d-02 /
      data f( 1,14, 7),f( 1,14, 8) / -1.0414170d-01 , -7.9727100d-02 /
      data f( 1,14, 9),f( 1,14,10) / -4.1274900d-02 , -6.3057000d-03 /
      data f( 1,14,11),f( 1,14,12) /  2.2645700d-02 ,  6.1828300d-02 /
      data f( 1,14,13),f( 1,14,14) /  3.1751500d-02 ,  3.1102800d-02 /
      data f( 1,14,15),f( 1,14,16) /  3.1731000d-02 ,  3.3589000d-02 /
      data f( 1,14,17),f( 1,14,18) /  3.6510900d-02 ,  4.0658800d-02 /
      data f( 1,14,19),f( 1,14,20) /  4.6634500d-02 ,  5.3970600d-02 /
      data f( 1,14,21),f( 1,14,22) /  5.3970600d-02 ,  4.6634500d-02 /
      data f( 1,14,23) /              4.0658800d-02 /
      data f( 1,15, 1),f( 1,15, 2) / -1.0144490d-01 , -5.4712800d-02 /
      data f( 1,15, 3),f( 1,15, 4) /  1.9563500d-02 ,  1.9563500d-02 /
      data f( 1,15, 5),f( 1,15, 6) / -5.4712800d-02 , -1.0144490d-01 /
      data f( 1,15, 7),f( 1,15, 8) / -1.0573920d-01 , -8.4116800d-02 /
      data f( 1,15, 9),f( 1,15,10) / -5.0933500d-02 , -1.9011900d-02 /
      data f( 1,15,11),f( 1,15,12) /  1.0256600d-02 ,  4.0410500d-02 /
      data f( 1,15,13),f( 1,15,14) /  3.2063500d-02 ,  3.2225600d-02 /
      data f( 1,15,15),f( 1,15,16) /  3.2929700d-02 ,  3.4425900d-02 /
      data f( 1,15,17),f( 1,15,18) /  3.6589300d-02 ,  3.9258100d-02 /
      data f( 1,15,19),f( 1,15,20) /  4.2209300d-02 ,  4.4800700d-02 /
      data f( 1,15,21),f( 1,15,22) /  4.4800700d-02 ,  4.2209300d-02 /
      data f( 1,15,23) /              3.9258100d-02 /
      data f( 1,16, 1),f( 1,16, 2) / -1.0981570d-01 , -1.0932960d-01 /
      data f( 1,16, 3),f( 1,16, 4) / -1.0178980d-01 , -1.0178980d-01 /
      data f( 1,16, 5),f( 1,16, 6) / -1.0932960d-01 , -1.0981570d-01 /
      data f( 1,16, 7),f( 1,16, 8) / -9.8678500d-02 , -7.7930300d-02 /
      data f( 1,16, 9),f( 1,16,10) / -5.2049300d-02 , -2.4992100d-02 /
      data f( 1,16,11),f( 1,16,12) /  5.4060000d-04 ,  2.2377200d-02 /
      data f( 1,16,13),f( 1,16,14) /  3.1457900d-02 ,  3.2327700d-02 /
      data f( 1,16,15),f( 1,16,16) /  3.2795200d-02 ,  3.3577400d-02 /
      data f( 1,16,17),f( 1,16,18) /  3.4673200d-02 ,  3.5920900d-02 /
      data f( 1,16,19),f( 1,16,20) /  3.7107100d-02 ,  3.7979800d-02 /
      data f( 1,16,21),f( 1,16,22) /  3.7979800d-02 ,  3.7107100d-02 /
      data f( 1,16,23) /              3.5920900d-02 /
      data f( 1,17, 1),f( 1,17, 2) / -8.8165800d-02 , -9.6812600d-02 /
      data f( 1,17, 3),f( 1,17, 4) / -1.0164000d-01 , -1.0164000d-01 /
      data f( 1,17, 5),f( 1,17, 6) / -9.6812600d-02 , -8.8165800d-02 /
      data f( 1,17, 7),f( 1,17, 8) / -7.5616300d-02 , -5.9787600d-02 /
      data f( 1,17, 9),f( 1,17,10) / -4.1813700d-02 , -2.2951600d-02 /
      data f( 1,17,11),f( 1,17,12) / -4.3269000d-03 ,  1.3174700d-02 /
      data f( 1,17,13),f( 1,17,14) /  2.8743400d-02 ,  3.2594000d-02 /
      data f( 1,17,15),f( 1,17,16) /  3.2852200d-02 ,  3.3014100d-02 /
      data f( 1,17,17),f( 1,17,18) /  3.3270400d-02 ,  3.3596000d-02 /
      data f( 1,17,19),f( 1,17,20) /  3.3913900d-02 ,  3.4144000d-02 /
      data f( 1,17,21),f( 1,17,22) /  3.4144000d-02 ,  3.3913900d-02 /
      data f( 1,17,23) /              3.3596000d-02 /
      data f( 1,18, 1),f( 1,18, 2) / -4.5175100d-02 , -4.9975000d-02 /
      data f( 1,18, 3),f( 1,18, 4) / -5.2938100d-02 , -5.2938100d-02 /
      data f( 1,18, 5),f( 1,18, 6) / -4.9975000d-02 , -4.5175100d-02 /
      data f( 1,18, 7),f( 1,18, 8) / -3.8743500d-02 , -3.0976700d-02 /
      data f( 1,18, 9),f( 1,18,10) / -2.2214700d-02 , -1.2831800d-02 /
      data f( 1,18,11),f( 1,18,12) / -3.1960000d-03 ,  6.3532000d-03 /
      data f( 1,18,13),f( 1,18,14) /  1.5523500d-02 ,  2.4077200d-02 /
      data f( 1,18,15),f( 1,18,16) /  3.1829300d-02 ,  3.8643700d-02 /
      data f( 1,18,17),f( 1,18,18) /  4.4419000d-02 ,  4.9073600d-02 /
      data f( 1,18,19),f( 1,18,20) /  5.2529500d-02 ,  5.4673000d-02 /
      data f( 1,18,21),f( 1,18,22) /  5.4673000d-02 ,  5.2529500d-02 /
      data f( 1,18,23) /              4.9073600d-02 /
      data f( 1,19, 1),f( 1,19, 2) /  1.3629900d-02 ,  1.3629900d-02 /
      data f( 1,19, 3),f( 1,19, 4) /  1.3629900d-02 ,  1.3629900d-02 /
      data f( 1,19, 5),f( 1,19, 6) /  1.3629900d-02 ,  1.3629900d-02 /
      data f( 1,19, 7),f( 1,19, 8) /  1.3629900d-02 ,  1.3629900d-02 /
      data f( 1,19, 9),f( 1,19,10) /  1.3629900d-02 ,  1.3629900d-02 /
      data f( 1,19,11),f( 1,19,12) /  1.3629900d-02 ,  1.3629900d-02 /
      data f( 1,19,13),f( 1,19,14) /  1.3629900d-02 ,  1.3629900d-02 /
      data f( 1,19,15),f( 1,19,16) /  1.3629900d-02 ,  1.3629900d-02 /
      data f( 1,19,17),f( 1,19,18) /  1.3629900d-02 ,  1.3629900d-02 /
      data f( 1,19,19),f( 1,19,20) /  1.3629900d-02 ,  1.3629900d-02 /
      data f( 1,19,21),f( 1,19,22) /  1.3629900d-02 ,  1.3629900d-02 /
      data f( 1,19,23) /              1.3629900d-02 /
      data f( 2, 1, 1),f( 2, 1, 2) /  3.3523040d-01 ,  3.3523040d-01 /
      data f( 2, 1, 3),f( 2, 1, 4) /  3.3523040d-01 ,  3.3523040d-01 /
      data f( 2, 1, 5),f( 2, 1, 6) /  3.3523040d-01 ,  3.3523040d-01 /
      data f( 2, 1, 7),f( 2, 1, 8) /  3.3523040d-01 ,  3.3523040d-01 /
      data f( 2, 1, 9),f( 2, 1,10) /  3.3523040d-01 ,  3.3523040d-01 /
      data f( 2, 1,11),f( 2, 1,12) /  3.3523040d-01 ,  3.3523040d-01 /
      data f( 2, 1,13),f( 2, 1,14) /  3.3523040d-01 ,  3.3523040d-01 /
      data f( 2, 1,15),f( 2, 1,16) /  3.3523040d-01 ,  3.3523040d-01 /
      data f( 2, 1,17),f( 2, 1,18) /  3.3523040d-01 ,  3.3523040d-01 /
      data f( 2, 1,19),f( 2, 1,20) /  3.3523040d-01 ,  3.3523040d-01 /
      data f( 2, 1,21),f( 2, 1,22) /  3.3523040d-01 ,  3.3523040d-01 /
      data f( 2, 1,23) /              3.3523040d-01 /
      data f( 2, 2, 1),f( 2, 2, 2) /  2.5075240d-01 ,  2.5264130d-01 /
      data f( 2, 2, 3),f( 2, 2, 4) /  2.5403190d-01 ,  2.5403190d-01 /
      data f( 2, 2, 5),f( 2, 2, 6) /  2.5264130d-01 ,  2.5075240d-01 /
      data f( 2, 2, 7),f( 2, 2, 8) /  2.4897570d-01 ,  2.4708430d-01 /
      data f( 2, 2, 9),f( 2, 2,10) /  2.4549910d-01 ,  2.4457840d-01 /
      data f( 2, 2,11),f( 2, 2,12) /  2.4360590d-01 ,  2.4337530d-01 /
      data f( 2, 2,13),f( 2, 2,14) /  2.4364040d-01 ,  2.4439400d-01 /
      data f( 2, 2,15),f( 2, 2,16) /  2.4561520d-01 ,  2.4724060d-01 /
      data f( 2, 2,17),f( 2, 2,18) /  2.4918010d-01 ,  2.5125570d-01 /
      data f( 2, 2,19),f( 2, 2,20) /  2.5296200d-01 ,  2.5438970d-01 /
      data f( 2, 2,21),f( 2, 2,22) /  2.5438970d-01 ,  2.5296200d-01 /
      data f( 2, 2,23) /              2.5125570d-01 /
      data f( 2, 3, 1),f( 2, 3, 2) /  1.7664990d-01 ,  1.8510440d-01 /
      data f( 2, 3, 3),f( 2, 3, 4) /  1.9421880d-01 ,  1.9421880d-01 /
      data f( 2, 3, 5),f( 2, 3, 6) /  1.8510440d-01 ,  1.7664990d-01 /
      data f( 2, 3, 7),f( 2, 3, 8) /  1.7069510d-01 ,  1.6639350d-01 /
      data f( 2, 3, 9),f( 2, 3,10) /  1.6343400d-01 ,  1.6147090d-01 /
      data f( 2, 3,11),f( 2, 3,12) /  1.6033930d-01 ,  1.5997040d-01 /
      data f( 2, 3,13),f( 2, 3,14) /  1.6034920d-01 ,  1.6149810d-01 /
      data f( 2, 3,15),f( 2, 3,16) /  1.6348950d-01 ,  1.6649350d-01 /
      data f( 2, 3,17),f( 2, 3,18) /  1.7086190d-01 ,  1.7689970d-01 /
      data f( 2, 3,19),f( 2, 3,20) /  1.8543900d-01 ,  1.9461770d-01 /
      data f( 2, 3,21),f( 2, 3,22) /  1.9461770d-01 ,  1.8543900d-01 /
      data f( 2, 3,23) /              1.7689970d-01 /
      data f( 2, 4, 1),f( 2, 4, 2) /  6.1958000d-02 ,  1.4983600d-01 /
      data f( 2, 4, 3),f( 2, 4, 4) /  1.6984050d-01 ,  1.6984050d-01 /
      data f( 2, 4, 5),f( 2, 4, 6) /  1.4983600d-01 ,  6.1958000d-02 /
      data f( 2, 4, 7),f( 2, 4, 8) /  7.9027000d-03 , -3.0027900d-02 /
      data f( 2, 4, 9),f( 2, 4,10) / -5.6678500d-02 , -7.4944900d-02 /
      data f( 2, 4,11),f( 2, 4,12) / -8.5785200d-02 , -9.2067200d-02 /
      data f( 2, 4,13),f( 2, 4,14) / -8.6238300d-02 , -7.5712800d-02 /
      data f( 2, 4,15),f( 2, 4,16) / -5.7500200d-02 , -3.0477800d-02 /
      data f( 2, 4,17),f( 2, 4,18) /  8.3441000d-03 ,  6.3838600d-02 /
      data f( 2, 4,19),f( 2, 4,20) /  1.5323750d-01 ,  1.7029110d-01 /
      data f( 2, 4,21),f( 2, 4,22) /  1.7029110d-01 ,  1.5323750d-01 /
      data f( 2, 4,23) /              6.3838600d-02 /
      data f( 2, 5, 1),f( 2, 5, 2) / -1.7642900d-02 ,  1.5855400d-02 /
      data f( 2, 5, 3),f( 2, 5, 4) /  4.6357800d-02 ,  4.6357800d-02 /
      data f( 2, 5, 5),f( 2, 5, 6) /  1.5855400d-02 , -1.7642900d-02 /
      data f( 2, 5, 7),f( 2, 5, 8) / -4.5979800d-02 , -7.2421700d-02 /
      data f( 2, 5, 9),f( 2, 5,10) / -9.3935700d-02 , -1.0987200d-01 /
      data f( 2, 5,11),f( 2, 5,12) / -1.1984300d-01 , -1.2366100d-01 /
      data f( 2, 5,13),f( 2, 5,14) / -1.2121820d-01 , -1.1243190d-01 /
      data f( 2, 5,15),f( 2, 5,16) / -9.7238900d-02 , -7.5670800d-02 /
      data f( 2, 5,17),f( 2, 5,18) / -4.7942100d-02 , -1.4592900d-02 /
      data f( 2, 5,19),f( 2, 5,20) /  2.0660700d-02 ,  5.5115600d-02 /
      data f( 2, 5,21),f( 2, 5,22) /  5.5115600d-02 ,  2.0660700d-02 /
      data f( 2, 5,23) /             -1.4592900d-02 /
      data f( 2, 6, 1),f( 2, 6, 2) / -7.9001000d-03 ,  1.0616600d-02 /
      data f( 2, 6, 3),f( 2, 6, 4) /  2.4608300d-02 ,  2.4608300d-02 /
      data f( 2, 6, 5),f( 2, 6, 6) /  1.0616600d-02 , -7.9001000d-03 /
      data f( 2, 6, 7),f( 2, 6, 8) / -3.0753000d-02 , -5.2436300d-02 /
      data f( 2, 6, 9),f( 2, 6,10) / -7.0983300d-02 , -8.5247900d-02 /
      data f( 2, 6,11),f( 2, 6,12) / -9.4606000d-02 , -9.8726800d-02 /
      data f( 2, 6,13),f( 2, 6,14) / -9.7438700d-02 , -9.0668300d-02 /
      data f( 2, 6,15),f( 2, 6,16) / -7.8382700d-02 , -6.0654500d-02 /
      data f( 2, 6,17),f( 2, 6,18) / -3.7827600d-02 , -1.0810400d-02 /
      data f( 2, 6,19),f( 2, 6,20) /  1.8456600d-02 ,  4.4083800d-02 /
      data f( 2, 6,21),f( 2, 6,22) /  4.4083800d-02 ,  1.8456600d-02 /
      data f( 2, 6,23) /             -1.0810400d-02 /
      data f( 2, 7, 1),f( 2, 7, 2) /  9.8494000d-03 ,  1.8320600d-02 /
      data f( 2, 7, 3),f( 2, 7, 4) /  2.4877800d-02 ,  2.4877800d-02 /
      data f( 2, 7, 5),f( 2, 7, 6) /  1.8320600d-02 ,  9.8494000d-03 /
      data f( 2, 7, 7),f( 2, 7, 8) / -6.4020000d-03 , -2.2912900d-02 /
      data f( 2, 7, 9),f( 2, 7,10) / -3.8162500d-02 , -5.0751400d-02 /
      data f( 2, 7,11),f( 2, 7,12) / -5.9669800d-02 , -6.4337000d-02 /
      data f( 2, 7,13),f( 2, 7,14) / -6.4487500d-02 , -6.0068700d-02 /
      data f( 2, 7,15),f( 2, 7,16) / -5.1129800d-02 , -3.7831300d-02 /
      data f( 2, 7,17),f( 2, 7,18) / -2.0484300d-02 ,  3.3320000d-04 /
      data f( 2, 7,19),f( 2, 7,20) /  2.3626000d-02 ,  4.7336700d-02 /
      data f( 2, 7,21),f( 2, 7,22) /  4.7336700d-02 ,  2.3626000d-02 /
      data f( 2, 7,23) /              3.3320000d-04 /
      data f( 2, 8, 1),f( 2, 8, 2) /  2.1204300d-02 ,  6.2320000d-03 /
      data f( 2, 8, 3),f( 2, 8, 4) / -5.5611000d-03 , -5.5611000d-03 /
      data f( 2, 8, 5),f( 2, 8, 6) /  6.2320000d-03 ,  2.1204300d-02 /
      data f( 2, 8, 7),f( 2, 8, 8) /  1.3967200d-02 ,  3.1413000d-03 /
      data f( 2, 8, 9),f( 2, 8,10) / -8.7020000d-03 , -1.9764500d-02 /
      data f( 2, 8,11),f( 2, 8,12) / -2.8476200d-02 , -3.3883500d-02 /
      data f( 2, 8,13),f( 2, 8,14) / -3.5596300d-02 , -3.3579700d-02 /
      data f( 2, 8,15),f( 2, 8,16) / -2.8005700d-02 , -1.9173200d-02 /
      data f( 2, 8,17),f( 2, 8,18) / -7.5105000d-03 ,  6.3818000d-03 /
      data f( 2, 8,19),f( 2, 8,20) /  2.1560000d-02 ,  3.5857600d-02 /
      data f( 2, 8,21),f( 2, 8,22) /  3.5857600d-02 ,  2.1560000d-02 /
      data f( 2, 8,23) /              6.3818000d-03 /
      data f( 2, 9, 1),f( 2, 9, 2) / -7.5687000d-03 , -3.3551800d-02 /
      data f( 2, 9, 3),f( 2, 9, 4) / -5.1241200d-02 , -5.1241200d-02 /
      data f( 2, 9, 5),f( 2, 9, 6) / -3.3551800d-02 , -7.5687000d-03 /
      data f( 2, 9, 7),f( 2, 9, 8) /  2.2001100d-02 ,  2.5127800d-02 /
      data f( 2, 9, 9),f( 2, 9,10) /  1.4990200d-02 ,  4.7647000d-03 /
      data f( 2, 9,11),f( 2, 9,12) / -3.9696000d-03 , -1.0130900d-02 /
      data f( 2, 9,13),f( 2, 9,14) / -1.3258600d-02 , -1.3336700d-02 /
      data f( 2, 9,15),f( 2, 9,16) / -1.0589900d-02 , -5.3401000d-03 /
      data f( 2, 9,17),f( 2, 9,18) /  2.0403000d-03 ,  1.1175100d-02 /
      data f( 2, 9,19),f( 2, 9,20) /  2.1637100d-02 ,  3.2158200d-02 /
      data f( 2, 9,21),f( 2, 9,22) /  3.2158200d-02 ,  2.1637100d-02 /
      data f( 2, 9,23) /              1.1175100d-02 /
      data f( 2,10, 1),f( 2,10, 2) / -4.8486300d-02 , -7.8566400d-02 /
      data f( 2,10, 3),f( 2,10, 4) / -9.7097800d-02 , -9.7097800d-02 /
      data f( 2,10, 5),f( 2,10, 6) / -7.8566400d-02 , -4.8486300d-02 /
      data f( 2,10, 7),f( 2,10, 8) / -1.2052100d-02 ,  2.4165000d-02 /
      data f( 2,10, 9),f( 2,10,10) /  3.2914800d-02 ,  2.2666800d-02 /
      data f( 2,10,11),f( 2,10,12) /  1.3713500d-02 ,  7.0352000d-03 /
      data f( 2,10,13),f( 2,10,14) /  2.9490000d-03 ,  1.4117000d-03 /
      data f( 2,10,15),f( 2,10,16) /  2.2097000d-03 ,  5.0638000d-03 /
      data f( 2,10,17),f( 2,10,18) /  9.6880000d-03 ,  1.5931600d-02 /
      data f( 2,10,19),f( 2,10,20) /  2.4007100d-02 ,  3.3812500d-02 /
      data f( 2,10,21),f( 2,10,22) /  3.3812500d-02 ,  2.4007100d-02 /
      data f( 2,10,23) /              1.5931600d-02 /
      data f( 2,11, 1),f( 2,11, 2) / -8.5389300d-02 , -1.0806930d-01 /
      data f( 2,11, 3),f( 2,11, 4) / -1.1176700d-01 , -1.1176700d-01 /
      data f( 2,11, 5),f( 2,11, 6) / -1.0806930d-01 , -8.5389300d-02 /
      data f( 2,11, 7),f( 2,11, 8) / -4.8237000d-02 , -7.8073000d-03 /
      data f( 2,11, 9),f( 2,11,10) /  2.6238100d-02 ,  3.3306700d-02 /
      data f( 2,11,11),f( 2,11,12) /  2.5244000d-02 ,  1.8568300d-02 /
      data f( 2,11,13),f( 2,11,14) /  1.4179500d-02 ,  1.2009500d-02 /
      data f( 2,11,15),f( 2,11,16) /  1.1864700d-02 ,  1.3480800d-02 /
      data f( 2,11,17),f( 2,11,18) /  1.6555300d-02 ,  2.1094400d-02 /
      data f( 2,11,19),f( 2,11,20) /  2.7970100d-02 ,  2.7319500d-02 /
      data f( 2,11,21),f( 2,11,22) /  2.7319500d-02 ,  2.7970100d-02 /
      data f( 2,11,23) /              2.1094400d-02 /
      data f( 2,12, 1),f( 2,12, 2) / -1.0407040d-01 , -9.3238900d-02 /
      data f( 2,12, 3),f( 2,12, 4) / -4.0068000d-02 , -4.0068000d-02 /
      data f( 2,12, 5),f( 2,12, 6) / -9.3238900d-02 , -1.0407040d-01 /
      data f( 2,12, 7),f( 2,12, 8) / -7.7459400d-02 , -3.7133800d-02 /
      data f( 2,12, 9),f( 2,12,10) /  1.5958000d-03 ,  2.8595600d-02 /
      data f( 2,12,11),f( 2,12,12) /  3.0733000d-02 ,  2.5507200d-02 /
      data f( 2,12,13),f( 2,12,14) /  2.1582700d-02 ,  1.9563200d-02 /
      data f( 2,12,15),f( 2,12,16) /  1.9356400d-02 ,  2.0696200d-02 /
      data f( 2,12,17),f( 2,12,18) /  2.3233400d-02 ,  2.7085200d-02 /
      data f( 2,12,19),f( 2,12,20) /  3.3502100d-02 ,  2.9322400d-02 /
      data f( 2,12,21),f( 2,12,22) /  2.9322400d-02 ,  3.3502100d-02 /
      data f( 2,12,23) /              2.7085200d-02 /
      data f( 2,13, 1),f( 2,13, 2) / -1.0082460d-01 , -3.7265800d-02 /
      data f( 2,13, 3),f( 2,13, 4) /  1.0525000d-01 ,  1.0525000d-01 /
      data f( 2,13, 5),f( 2,13, 6) / -3.7265800d-02 , -1.0082460d-01 /
      data f( 2,13, 7),f( 2,13, 8) / -9.4819800d-02 , -6.0063300d-02 /
      data f( 2,13, 9),f( 2,13,10) / -2.0625100d-02 ,  1.2545100d-02 /
      data f( 2,13,11),f( 2,13,12) /  2.9217700d-02 ,  2.8456100d-02 /
      data f( 2,13,13),f( 2,13,14) /  2.5877500d-02 ,  2.4559900d-02 /
      data f( 2,13,15),f( 2,13,16) /  2.4791700d-02 ,  2.6400800d-02 /
      data f( 2,13,17),f( 2,13,18) /  2.9100700d-02 ,  3.3065400d-02 /
      data f( 2,13,19),f( 2,13,20) /  3.9473800d-02 ,  3.2983700d-02 /
      data f( 2,13,21),f( 2,13,22) /  3.2983700d-02 ,  3.9473800d-02 /
      data f( 2,13,23) /              3.3065400d-02 /
      data f( 2,14, 1),f( 2,14, 2) / -9.7351200d-02 , -2.4139900d-02 /
      data f( 2,14, 3),f( 2,14, 4) /  1.1411520d-01 ,  1.1411520d-01 /
      data f( 2,14, 5),f( 2,14, 6) / -2.4139900d-02 , -9.7351200d-02 /
      data f( 2,14, 7),f( 2,14, 8) / -1.0206210d-01 , -7.4226700d-02 /
      data f( 2,14, 9),f( 2,14,10) / -3.7467600d-02 , -3.1603000d-03 /
      data f( 2,14,11),f( 2,14,12) /  2.1691000d-02 ,  2.8146600d-02 /
      data f( 2,14,13),f( 2,14,14) /  2.7571500d-02 ,  2.7119600d-02 /
      data f( 2,14,15),f( 2,14,16) /  2.7761700d-02 ,  2.9508500d-02 /
      data f( 2,14,17),f( 2,14,18) /  3.2172300d-02 ,  3.5738800d-02 /
      data f( 2,14,19),f( 2,14,20) /  4.0469700d-02 ,  4.5762500d-02 /
      data f( 2,14,21),f( 2,14,22) /  4.5762500d-02 ,  4.0469700d-02 /
      data f( 2,14,23) /              3.5738800d-02 /
      data f( 2,15, 1),f( 2,15, 2) / -1.0731280d-01 , -7.9021700d-02 /
      data f( 2,15, 3),f( 2,15, 4) / -2.9789800d-02 , -2.9789800d-02 /
      data f( 2,15, 5),f( 2,15, 6) / -7.9021700d-02 , -1.0731280d-01 /
      data f( 2,15, 7),f( 2,15, 8) / -1.0296290d-01 , -7.8620800d-02 /
      data f( 2,15, 9),f( 2,15,10) / -4.6649100d-02 , -1.4897600d-02 /
      data f( 2,15,11),f( 2,15,12) /  1.1940600d-02 ,  2.5885300d-02 /
      data f( 2,15,13),f( 2,15,14) /  2.7613900d-02 ,  2.7814900d-02 /
      data f( 2,15,15),f( 2,15,16) /  2.8496400d-02 ,  2.9868800d-02 /
      data f( 2,15,17),f( 2,15,18) /  3.1806200d-02 ,  3.4108800d-02 /
      data f( 2,15,19),f( 2,15,20) /  3.6527800d-02 ,  3.8551900d-02 /
      data f( 2,15,21),f( 2,15,22) /  3.8551900d-02 ,  3.6527800d-02 /
      data f( 2,15,23) /              3.4108800d-02 /
      data f( 2,16, 1),f( 2,16, 2) / -1.0773710d-01 , -1.1141800d-01 /
      data f( 2,16, 3),f( 2,16, 4) / -1.1007180d-01 , -1.1007180d-01 /
      data f( 2,16, 5),f( 2,16, 6) / -1.1141800d-01 , -1.0773710d-01 /
      data f( 2,16, 7),f( 2,16, 8) / -9.3876700d-02 , -7.2172500d-02 /
      data f( 2,16, 9),f( 2,16,10) / -4.6509200d-02 , -2.0361100d-02 /
      data f( 2,16,11),f( 2,16,12) /  3.7313000d-03 ,  2.1997700d-02 /
      data f( 2,16,13),f( 2,16,14) /  2.7171800d-02 ,  2.7779000d-02 /
      data f( 2,16,15),f( 2,16,16) /  2.8203500d-02 ,  2.8921000d-02 /
      data f( 2,16,17),f( 2,16,18) /  2.9912000d-02 ,  3.1022100d-02 /
      data f( 2,16,19),f( 2,16,20) /  3.2056600d-02 ,  3.2803100d-02 /
      data f( 2,16,21),f( 2,16,22) /  3.2803100d-02 ,  3.2056600d-02 /
      data f( 2,16,23) /              3.1022100d-02 /
      data f( 2,17, 1),f( 2,17, 2) / -8.2512500d-02 , -9.1618200d-02 /
      data f( 2,17, 3),f( 2,17, 4) / -9.6901200d-02 , -9.6901200d-02 /
      data f( 2,17, 5),f( 2,17, 6) / -9.1618200d-02 , -8.2512500d-02 /
      data f( 2,17, 7),f( 2,17, 8) / -6.9726400d-02 , -5.3979000d-02 /
      data f( 2,17, 9),f( 2,17,10) / -3.6391300d-02 , -1.8162000d-02 /
      data f( 2,17,11),f( 2,17,12) / -3.6920000d-04 ,  1.6076100d-02 /
      data f( 2,17,13),f( 2,17,14) /  2.9502600d-02 ,  2.8064400d-02 /
      data f( 2,17,15),f( 2,17,16) /  2.8190700d-02 ,  2.8315000d-02 /
      data f( 2,17,17),f( 2,17,18) /  2.8541400d-02 ,  2.8833400d-02 /
      data f( 2,17,19),f( 2,17,20) /  2.9118300d-02 ,  2.9325400d-02 /
      data f( 2,17,21),f( 2,17,22) /  2.9325400d-02 ,  2.9118300d-02 /
      data f( 2,17,23) /              2.8833400d-02 /
      data f( 2,18, 1),f( 2,18, 2) / -3.9547300d-02 , -4.4241900d-02 /
      data f( 2,18, 3),f( 2,18, 4) / -4.7147600d-02 , -4.7147600d-02 /
      data f( 2,18, 5),f( 2,18, 6) / -4.4241900d-02 , -3.9547300d-02 /
      data f( 2,18, 7),f( 2,18, 8) / -3.3282800d-02 , -2.5741500d-02 /
      data f( 2,18, 9),f( 2,18,10) / -1.7263600d-02 , -8.2261000d-03 /
      data f( 2,18,11),f( 2,18,12) /  1.0167000d-03 ,  1.0137800d-02 /
      data f( 2,18,13),f( 2,18,14) /  1.8858100d-02 ,  2.6953200d-02 /
      data f( 2,18,15),f( 2,18,16) /  3.4254600d-02 ,  4.0646300d-02 /
      data f( 2,18,17),f( 2,18,18) /  4.6056200d-02 ,  5.0431000d-02 /
      data f( 2,18,19),f( 2,18,20) /  5.3722900d-02 ,  5.5778900d-02 /
      data f( 2,18,21),f( 2,18,22) /  5.5778900d-02 ,  5.3722900d-02 /
      data f( 2,18,23) /              5.0431000d-02 /
      data f( 2,19, 1),f( 2,19, 2) /  3.2861000d-02 ,  3.2861000d-02 /
      data f( 2,19, 3),f( 2,19, 4) /  3.2861000d-02 ,  3.2861000d-02 /
      data f( 2,19, 5),f( 2,19, 6) /  3.2861000d-02 ,  3.2861000d-02 /
      data f( 2,19, 7),f( 2,19, 8) /  3.2861000d-02 ,  3.2861000d-02 /
      data f( 2,19, 9),f( 2,19,10) /  3.2861000d-02 ,  3.2861000d-02 /
      data f( 2,19,11),f( 2,19,12) /  3.2861000d-02 ,  3.2861000d-02 /
      data f( 2,19,13),f( 2,19,14) /  3.2861000d-02 ,  3.2861000d-02 /
      data f( 2,19,15),f( 2,19,16) /  3.2861000d-02 ,  3.2861000d-02 /
      data f( 2,19,17),f( 2,19,18) /  3.2861000d-02 ,  3.2861000d-02 /
      data f( 2,19,19),f( 2,19,20) /  3.2861000d-02 ,  3.2861000d-02 /
      data f( 2,19,21),f( 2,19,22) /  3.2861000d-02 ,  3.2861000d-02 /
      data f( 2,19,23) /              3.2861000d-02 /
      data f( 3, 1, 1),f( 3, 1, 2) /  2.8226670d-01 ,  2.8226670d-01 /
      data f( 3, 1, 3),f( 3, 1, 4) /  2.8226670d-01 ,  2.8226670d-01 /
      data f( 3, 1, 5),f( 3, 1, 6) /  2.8226670d-01 ,  2.8226670d-01 /
      data f( 3, 1, 7),f( 3, 1, 8) /  2.8226670d-01 ,  2.8226670d-01 /
      data f( 3, 1, 9),f( 3, 1,10) /  2.8226670d-01 ,  2.8226670d-01 /
      data f( 3, 1,11),f( 3, 1,12) /  2.8226670d-01 ,  2.8226670d-01 /
      data f( 3, 1,13),f( 3, 1,14) /  2.8226670d-01 ,  2.8226670d-01 /
      data f( 3, 1,15),f( 3, 1,16) /  2.8226670d-01 ,  2.8226670d-01 /
      data f( 3, 1,17),f( 3, 1,18) /  2.8226670d-01 ,  2.8226670d-01 /
      data f( 3, 1,19),f( 3, 1,20) /  2.8226670d-01 ,  2.8226670d-01 /
      data f( 3, 1,21),f( 3, 1,22) /  2.8226670d-01 ,  2.8226670d-01 /
      data f( 3, 1,23) /              2.8226670d-01 /
      data f( 3, 2, 1),f( 3, 2, 2) /  2.2509510d-01 ,  2.2701540d-01 /
      data f( 3, 2, 3),f( 3, 2, 4) /  2.2842980d-01 ,  2.2842980d-01 /
      data f( 3, 2, 5),f( 3, 2, 6) /  2.2701540d-01 ,  2.2509510d-01 /
      data f( 3, 2, 7),f( 3, 2, 8) /  2.2329970d-01 ,  2.2140670d-01 /
      data f( 3, 2, 9),f( 3, 2,10) /  2.1983480d-01 ,  2.1893110d-01 /
      data f( 3, 2,11),f( 3, 2,12) /  2.1797350d-01 ,  2.1774790d-01 /
      data f( 3, 2,13),f( 3, 2,14) /  2.1800780d-01 ,  2.1874720d-01 /
      data f( 3, 2,15),f( 3, 2,16) /  2.1994860d-01 ,  2.2156110d-01 /
      data f( 3, 2,17),f( 3, 2,18) /  2.2349780d-01 ,  2.2534320d-01 /
      data f( 3, 2,19),f( 3, 2,20) /  2.2730840d-01 ,  2.2875490d-01 /
      data f( 3, 2,21),f( 3, 2,22) /  2.2875490d-01 ,  2.2730840d-01 /
      data f( 3, 2,23) /              2.2534320d-01 /
      data f( 3, 3, 1),f( 3, 3, 2) /  1.7217490d-01 ,  1.8298550d-01 /
      data f( 3, 3, 3),f( 3, 3, 4) /  1.9597450d-01 ,  1.9597450d-01 /
      data f( 3, 3, 5),f( 3, 3, 6) /  1.8298550d-01 ,  1.7217490d-01 /
      data f( 3, 3, 7),f( 3, 3, 8) /  1.6522360d-01 ,  1.6057510d-01 /
      data f( 3, 3, 9),f( 3, 3,10) /  1.4089700d-01 ,  1.2105930d-01 /
      data f( 3, 3,11),f( 3, 3,12) /  1.0974680d-01 ,  1.0607650d-01 /
      data f( 3, 3,13),f( 3, 3,14) /  1.0985770d-01 ,  1.2135770d-01 /
      data f( 3, 3,15),f( 3, 3,16) /  1.4149320d-01 ,  1.6067990d-01 /
      data f( 3, 3,17),f( 3, 3,18) /  1.6539530d-01 ,  1.7242060d-01 /
      data f( 3, 3,19),f( 3, 3,20) /  1.8330850d-01 ,  1.9635080d-01 /
      data f( 3, 3,21),f( 3, 3,22) /  1.9635080d-01 ,  1.8330850d-01 /
      data f( 3, 3,23) /              1.7242060d-01 /
      data f( 3, 4, 1),f( 3, 4, 2) /  6.0614400d-02 ,  1.6038210d-01 /
      data f( 3, 4, 3),f( 3, 4, 4) /  1.7650610d-01 ,  1.7650610d-01 /
      data f( 3, 4, 5),f( 3, 4, 6) /  1.6038210d-01 ,  6.0614400d-02 /
      data f( 3, 4, 7),f( 3, 4, 8) /  1.8700000d-05 , -3.9470000d-02 /
      data f( 3, 4, 9),f( 3, 4,10) / -6.6355400d-02 , -8.4561500d-02 /
      data f( 3, 4,11),f( 3, 4,12) / -9.5299500d-02 , -9.9045100d-02 /
      data f( 3, 4,13),f( 3, 4,14) / -9.5786200d-02 , -8.5345200d-02 /
      data f( 3, 4,15),f( 3, 4,16) / -6.7199700d-02 , -3.9946900d-02 /
      data f( 3, 4,17),f( 3, 4,18) /  4.5790000d-04 ,  6.2448700d-02 /
      data f( 3, 4,19),f( 3, 4,20) /  1.6071140d-01 ,  1.7693530d-01 /
      data f( 3, 4,21),f( 3, 4,22) /  1.7693530d-01 ,  1.6071140d-01 /
      data f( 3, 4,23) /              6.2448700d-02 /
      data f( 3, 5, 1),f( 3, 5, 2) / -1.6383600d-02 ,  1.8982000d-02 /
      data f( 3, 5, 3),f( 3, 5, 4) /  5.3027500d-02 ,  5.3027500d-02 /
      data f( 3, 5, 5),f( 3, 5, 6) /  1.8982000d-02 , -1.6383600d-02 /
      data f( 3, 5, 7),f( 3, 5, 8) / -4.5248100d-02 , -7.1646700d-02 /
      data f( 3, 5, 9),f( 3, 5,10) / -9.2985800d-02 , -1.0875580d-01 /
      data f( 3, 5,11),f( 3, 5,12) / -1.1861470d-01 , -1.2239750d-01 /
      data f( 3, 5,13),f( 3, 5,14) / -1.2000580d-01 , -1.1135270d-01 /
      data f( 3, 5,15),f( 3, 5,16) / -9.6357100d-02 , -7.5005200d-02 /
      data f( 3, 5,17),f( 3, 5,18) / -4.7363200d-02 , -1.3480500d-02 /
      data f( 3, 5,19),f( 3, 5,20) /  2.3637000d-02 ,  6.1481000d-02 /
      data f( 3, 5,21),f( 3, 5,22) /  6.1481000d-02 ,  2.3637000d-02 /
      data f( 3, 5,23) /             -1.3480500d-02 /
      data f( 3, 6, 1),f( 3, 6, 2) / -6.1216000d-03 ,  1.2779700d-02 /
      data f( 3, 6, 3),f( 3, 6, 4) /  2.7086100d-02 ,  2.7086100d-02 /
      data f( 3, 6, 5),f( 3, 6, 6) /  1.2779700d-02 , -6.1216000d-03 /
      data f( 3, 6, 7),f( 3, 6, 8) / -2.8895300d-02 , -5.0294000d-02 /
      data f( 3, 6, 9),f( 3, 6,10) / -6.8499900d-02 , -8.2464300d-02 /
      data f( 3, 6,11),f( 3, 6,12) / -9.1620300d-02 , -9.5666100d-02 /
      data f( 3, 6,13),f( 3, 6,14) / -9.4442500d-02 , -8.7863000d-02 /
      data f( 3, 6,15),f( 3, 6,16) / -7.5898100d-02 , -5.6261400d-02 /
      data f( 3, 6,17),f( 3, 6,18) / -3.6229100d-02 , -9.6402000d-03 /
      data f( 3, 6,19),f( 3, 6,20) /  1.9439100d-02 ,  4.7168400d-02 /
      data f( 3, 6,21),f( 3, 6,22) /  4.7168400d-02 ,  1.9439100d-02 /
      data f( 3, 6,23) /             -9.6402000d-03 /
      data f( 3, 7, 1),f( 3, 7, 2) /  1.0489000d-02 ,  2.0727100d-02 /
      data f( 3, 7, 3),f( 3, 7, 4) /  2.8436600d-02 ,  2.8436600d-02 /
      data f( 3, 7, 5),f( 3, 7, 6) /  2.0727100d-02 ,  1.0489000d-02 /
      data f( 3, 7, 7),f( 3, 7, 8) / -5.5567000d-03 , -2.1597000d-02 /
      data f( 3, 7, 9),f( 3, 7,10) / -3.6315300d-02 , -4.8444300d-02 /
      data f( 3, 7,11),f( 3, 7,12) / -5.7048800d-02 , -6.1578500d-02 /
      data f( 3, 7,13),f( 3, 7,14) / -6.1774300d-02 , -5.7580600d-02 /
      data f( 3, 7,15),f( 3, 7,16) / -4.9044100d-02 , -3.6322000d-02 /
      data f( 3, 7,17),f( 3, 7,18) / -1.9723300d-02 ,  1.6030000d-04 /
      data f( 3, 7,19),f( 3, 7,20) /  2.2241200d-02 ,  4.4075800d-02 /
      data f( 3, 7,21),f( 3, 7,22) /  4.4075800d-02 ,  2.2241200d-02 /
      data f( 3, 7,23) /              1.6030000d-04 /
      data f( 3, 8, 1),f( 3, 8, 2) /  2.5713300d-02 ,  1.0530500d-02 /
      data f( 3, 8, 3),f( 3, 8, 4) / -1.1928000d-03 , -1.1928000d-03 /
      data f( 3, 8, 5),f( 3, 8, 6) /  1.0530500d-02 ,  2.5713300d-02 /
      data f( 3, 8, 7),f( 3, 8, 8) /  1.3640400d-02 ,  3.2049000d-03 /
      data f( 3, 8, 9),f( 3, 8,10) / -8.0314000d-03 , -1.8518100d-02 /
      data f( 3, 8,11),f( 3, 8,12) / -2.6807400d-02 , -3.1999400d-02 /
      data f( 3, 8,13),f( 3, 8,14) / -3.3704100d-02 , -3.1880500d-02 /
      data f( 3, 8,15),f( 3, 8,16) / -2.6684700d-02 , -1.8413500d-02 /
      data f( 3, 8,17),f( 3, 8,18) / -7.4921000d-03 ,  5.4583000d-03 /
      data f( 3, 8,19),f( 3, 8,20) /  1.9421100d-02 ,  3.2146800d-02 /
      data f( 3, 8,21),f( 3, 8,22) /  3.2146800d-02 ,  1.9421100d-02 /
      data f( 3, 8,23) /              5.4583000d-03 /
      data f( 3, 9, 1),f( 3, 9, 2) / -2.2439000d-03 , -2.7688100d-02 /
      data f( 3, 9, 3),f( 3, 9, 4) / -4.5072800d-02 , -4.5072800d-02 /
      data f( 3, 9, 5),f( 3, 9, 6) / -2.7688100d-02 , -2.2439000d-03 /
      data f( 3, 9, 7),f( 3, 9, 8) /  2.6742100d-02 ,  2.3451000d-02 /
      data f( 3, 9, 9),f( 3, 9,10) /  1.4160400d-02 ,  4.6916000d-03 /
      data f( 3, 9,11),f( 3, 9,12) / -3.4986000d-03 , -9.3418000d-03 /
      data f( 3, 9,13),f( 3, 9,14) / -1.2368400d-02 , -1.2540100d-02 /
      data f( 3, 9,15),f( 3, 9,16) / -1.0056800d-02 , -5.2220000d-03 /
      data f( 3, 9,17),f( 3, 9,18) /  1.6010000d-03 ,  9.9995000d-03 /
      data f( 3, 9,19),f( 3, 9,20) /  1.9432600d-02 ,  2.8476700d-02 /
      data f( 3, 9,21),f( 3, 9,22) /  2.8476700d-02 ,  1.9432600d-02 /
      data f( 3, 9,23) /              9.9995000d-03 /
      data f( 3,10, 1),f( 3,10, 2) / -4.1988100d-02 , -7.1776400d-02 /
      data f( 3,10, 3),f( 3,10, 4) / -9.0706600d-02 , -9.0706600d-02 /
      data f( 3,10, 5),f( 3,10, 6) / -7.1776400d-02 , -4.1988100d-02 /
      data f( 3,10, 7),f( 3,10, 8) / -6.7089000d-03 ,  2.6750000d-02 /
      data f( 3,10, 9),f( 3,10,10) /  2.9497500d-02 ,  2.0909600d-02 /
      data f( 3,10,11),f( 3,10,12) /  1.2837400d-02 ,  6.6350000d-03 /
      data f( 3,10,13),f( 3,10,14) /  2.7705000d-03 ,  1.2731000d-03 /
      data f( 3,10,15),f( 3,10,16) /  1.9702000d-03 ,  4.6106000d-03 /
      data f( 3,10,17),f( 3,10,18) /  8.9140000d-03 ,  1.4668700d-02 /
      data f( 3,10,19),f( 3,10,20) /  2.1866200d-02 ,  2.9950800d-02 /
      data f( 3,10,21),f( 3,10,22) /  2.9950800d-02 ,  2.1866200d-02 /
      data f( 3,10,23) /              1.4668700d-02 /
      data f( 3,11, 1),f( 3,11, 2) / -7.8882300d-02 , -1.0407130d-01 /
      data f( 3,11, 3),f( 3,11, 4) / -1.1254540d-01 , -1.1254540d-01 /
      data f( 3,11, 5),f( 3,11, 6) / -1.0407130d-01 , -7.8882300d-02 /
      data f( 3,11, 7),f( 3,11, 8) / -4.1931900d-02 , -3.5193000d-03 /
      data f( 3,11, 9),f( 3,11,10) /  2.5443200d-02 ,  2.9273700d-02 /
      data f( 3,11,11),f( 3,11,12) /  2.2842100d-02 ,  1.6947300d-02 /
      data f( 3,11,13),f( 3,11,14) /  1.2928500d-02 ,  1.0920500d-02 /
      data f( 3,11,15),f( 3,11,16) /  1.0813400d-02 ,  1.2390900d-02 /
      data f( 3,11,17),f( 3,11,18) /  1.5366800d-02 ,  1.9652400d-02 /
      data f( 3,11,19),f( 3,11,20) /  2.5804900d-02 ,  3.4322600d-02 /
      data f( 3,11,21),f( 3,11,22) /  3.4322600d-02 ,  2.5804900d-02 /
      data f( 3,11,23) /              1.9652400d-02 /
      data f( 3,12, 1),f( 3,12, 2) / -1.0066950d-01 , -1.0140760d-01 /
      data f( 3,12, 3),f( 3,12, 4) / -6.9103500d-02 , -6.9103500d-02 /
      data f( 3,12, 5),f( 3,12, 6) / -1.0140760d-01 , -1.0066950d-01 /
      data f( 3,12, 7),f( 3,12, 8) / -7.1031500d-02 , -3.1614400d-02 /
      data f( 3,12, 9),f( 3,12,10) /  4.1662000d-03 ,  2.5714300d-02 /
      data f( 3,12,11),f( 3,12,12) /  2.6892400d-02 ,  2.2702900d-02 /
      data f( 3,12,13),f( 3,12,14) /  1.9294600d-02 ,  1.7509900d-02 /
      data f( 3,12,15),f( 3,12,16) /  1.7398700d-02 ,  1.8770900d-02 /
      data f( 3,12,17),f( 3,12,18) /  2.1305300d-02 ,  2.4992600d-02 /
      data f( 3,12,19),f( 3,12,20) /  3.0773700d-02 ,  2.7761700d-02 /
      data f( 3,12,21),f( 3,12,22) /  2.7761700d-02 ,  3.0773700d-02 /
      data f( 3,12,23) /              2.4992600d-02 /
      data f( 3,13, 1),f( 3,13, 2) / -1.0349090d-01 , -6.5756200d-02 /
      data f( 3,13, 3),f( 3,13, 4) /  2.8230900d-02 ,  2.8230900d-02 /
      data f( 3,13, 5),f( 3,13, 6) / -6.5756200d-02 , -1.0349090d-01 /
      data f( 3,13, 7),f( 3,13, 8) / -8.9409800d-02 , -5.3906400d-02 /
      data f( 3,13, 9),f( 3,13,10) / -1.6380000d-02 ,  1.3074400d-02 /
      data f( 3,13,11),f( 3,13,12) /  2.5325800d-02 ,  2.4783200d-02 /
      data f( 3,13,13),f( 3,13,14) /  2.2702600d-02 ,  2.1612600d-02 /
      data f( 3,13,15),f( 3,13,16) /  2.1906200d-02 ,  2.3485300d-02 /
      data f( 3,13,17),f( 3,13,18) /  2.6071300d-02 ,  2.9667900d-02 /
      data f( 3,13,19),f( 3,13,20) /  3.5008600d-02 ,  3.1574600d-02 /
      data f( 3,13,21),f( 3,13,22) /  3.1574600d-02 ,  3.5008600d-02 /
      data f( 3,13,23) /              2.9667900d-02 /
      data f( 3,14, 1),f( 3,14, 2) / -1.0295220d-01 , -5.7384100d-02 /
      data f( 3,14, 3),f( 3,14, 4) /  3.4086800d-02 ,  3.4086800d-02 /
      data f( 3,14, 5),f( 3,14, 6) / -5.7384100d-02 , -1.0295220d-01 /
      data f( 3,14, 7),f( 3,14, 8) / -9.7658500d-02 , -6.7887400d-02 /
      data f( 3,14, 9),f( 3,14,10) / -3.2238500d-02 , -4.9540000d-04 /
      data f( 3,14,11),f( 3,14,12) /  1.9830100d-02 ,  2.4255900d-02 /
      data f( 3,14,13),f( 3,14,14) /  2.3856000d-02 ,  2.3542700d-02 /
      data f( 3,14,15),f( 3,14,16) /  2.4178800d-02 ,  2.5808100d-02 /
      data f( 3,14,17),f( 3,14,18) /  2.8231700d-02 ,  3.1311800d-02 /
      data f( 3,14,19),f( 3,14,20) /  3.5073700d-02 ,  3.8938700d-02 /
      data f( 3,14,21),f( 3,14,22) /  3.8938700d-02 ,  3.5073700d-02 /
      data f( 3,14,23) /              3.1311800d-02 /
      data f( 3,15, 1),f( 3,15, 2) / -1.0846500d-01 , -9.3619300d-02 /
      data f( 3,15, 3),f( 3,15, 4) / -6.2093600d-02 , -6.2093600d-02 /
      data f( 3,15, 5),f( 3,15, 6) / -9.3619300d-02 , -1.0846500d-01 /
      data f( 3,15, 7),f( 3,15, 8) / -9.8046500d-02 , -7.2181800d-02 /
      data f( 3,15, 9),f( 3,15,10) / -4.0904400d-02 , -1.0942700d-02 /
      data f( 3,15,11),f( 3,15,12) /  1.2703700d-02 ,  2.2502700d-02 /
      data f( 3,15,13),f( 3,15,14) /  2.3727300d-02 ,  2.3943100d-02 /
      data f( 3,15,15),f( 3,15,16) /  2.4588600d-02 ,  2.5845700d-02 /
      data f( 3,15,17),f( 3,15,18) /  2.7589500d-02 ,  2.9601500d-02 /
      data f( 3,15,19),f( 3,15,20) /  3.1622500d-02 ,  3.3238600d-02 /
      data f( 3,15,21),f( 3,15,22) /  3.3238600d-02 ,  3.1622500d-02 /
      data f( 3,15,23) /              2.9601500d-02 /
      data f( 3,16, 1),f( 3,16, 2) / -1.0322700d-01 , -1.1012100d-01 /
      data f( 3,16, 3),f( 3,16, 4) / -1.1114100d-01 , -1.1114100d-01 /
      data f( 3,16, 5),f( 3,16, 6) / -1.1012100d-01 , -1.0322700d-01 /
      data f( 3,16, 7),f( 3,16, 8) / -8.7634600d-02 , -6.5615700d-02 /
      data f( 3,16, 9),f( 3,16,10) / -4.0596200d-02 , -1.5697900d-02 /
      data f( 3,16,11),f( 3,16,12) /  6.5121000d-03 ,  2.0630700d-02 /
      data f( 3,16,13),f( 3,16,14) /  2.3370300d-02 ,  2.3812900d-02 /
      data f( 3,16,15),f( 3,16,16) /  2.4194200d-02 ,  2.4847900d-02 /
      data f( 3,16,17),f( 3,16,18) /  2.5744000d-02 ,  2.6736800d-02 /
      data f( 3,16,19),f( 3,16,20) /  2.7648100d-02 ,  2.8295600d-02 /
      data f( 3,16,21),f( 3,16,22) /  2.8295600d-02 ,  2.7648100d-02 /
      data f( 3,16,23) /              2.6736800d-02 /
      data f( 3,17, 1),f( 3,17, 2) / -7.5801200d-02 , -8.5091200d-02 /
      data f( 3,17, 3),f( 3,17, 4) / -9.0618600d-02 , -9.0618600d-02 /
      data f( 3,17, 5),f( 3,17, 6) / -8.5091200d-02 , -7.5801200d-02 /
      data f( 3,17, 7),f( 3,17, 8) / -6.3056100d-02 , -4.7640300d-02 /
      data f( 3,17, 9),f( 3,17,10) / -3.0658400d-02 , -1.3262400d-02 /
      data f( 3,17,11),f( 3,17,12) /  3.4925000d-03 ,  1.8548500d-02 /
      data f( 3,17,13),f( 3,17,14) /  2.3693900d-02 ,  2.4088100d-02 /
      data f( 3,17,15),f( 3,17,16) /  2.4132300d-02 ,  2.4225600d-02 /
      data f( 3,17,17),f( 3,17,18) /  2.4423500d-02 ,  2.4683700d-02 /
      data f( 3,17,19),f( 3,17,20) /  2.4938400d-02 ,  2.5123300d-02 /
      data f( 3,17,21),f( 3,17,22) /  2.5123300d-02 ,  2.4938400d-02 /
      data f( 3,17,23) /              2.4683700d-02 /
      data f( 3,18, 1),f( 3,18, 2) / -3.3525900d-02 , -3.8062400d-02 /
      data f( 3,18, 3),f( 3,18, 4) / -4.0876600d-02 , -4.0876600d-02 /
      data f( 3,18, 5),f( 3,18, 6) / -3.8062400d-02 , -3.3525900d-02 /
      data f( 3,18, 7),f( 3,18, 8) / -2.7491100d-02 , -2.0251800d-02 /
      data f( 3,18, 9),f( 3,18,10) / -1.2149000d-02 , -3.5363000d-03 /
      data f( 3,18,11),f( 3,18,12) /  5.2278000d-03 ,  1.3834800d-02 /
      data f( 3,18,13),f( 3,18,14) /  2.2018900d-02 ,  2.9569700d-02 /
      data f( 3,18,15),f( 3,18,16) /  3.6334400d-02 ,  4.2214800d-02 /
      data f( 3,18,17),f( 3,18,18) /  4.7189500d-02 ,  5.1262200d-02 /
      data f( 3,18,19),f( 3,18,20) /  5.4415300d-02 ,  5.6417200d-02 /
      data f( 3,18,21),f( 3,18,22) /  5.6417200d-02 ,  5.4415300d-02 /
      data f( 3,18,23) /              5.1262200d-02 /
      data f( 3,19, 1),f( 3,19, 2) /  2.8428600d-02 ,  2.8428600d-02 /
      data f( 3,19, 3),f( 3,19, 4) /  2.8428600d-02 ,  2.8428600d-02 /
      data f( 3,19, 5),f( 3,19, 6) /  2.8428600d-02 ,  2.8428600d-02 /
      data f( 3,19, 7),f( 3,19, 8) /  2.8428600d-02 ,  2.8428600d-02 /
      data f( 3,19, 9),f( 3,19,10) /  2.8428600d-02 ,  2.8428600d-02 /
      data f( 3,19,11),f( 3,19,12) /  2.8428600d-02 ,  2.8428600d-02 /
      data f( 3,19,13),f( 3,19,14) /  2.8428600d-02 ,  2.8428600d-02 /
      data f( 3,19,15),f( 3,19,16) /  2.8428600d-02 ,  2.8428600d-02 /
      data f( 3,19,17),f( 3,19,18) /  2.8428600d-02 ,  2.8428600d-02 /
      data f( 3,19,19),f( 3,19,20) /  2.8428600d-02 ,  2.8428600d-02 /
      data f( 3,19,21),f( 3,19,22) /  2.8428600d-02 ,  2.8428600d-02 /
      data f( 3,19,23) /              2.8428600d-02 /
      data f( 4, 1, 1),f( 4, 1, 2) /  2.4425640d-01 ,  2.4425640d-01 /
      data f( 4, 1, 3),f( 4, 1, 4) /  2.4425640d-01 ,  2.4425640d-01 /
      data f( 4, 1, 5),f( 4, 1, 6) /  2.4425640d-01 ,  2.4425640d-01 /
      data f( 4, 1, 7),f( 4, 1, 8) /  2.4425640d-01 ,  2.4425640d-01 /
      data f( 4, 1, 9),f( 4, 1,10) /  2.4425640d-01 ,  2.4425640d-01 /
      data f( 4, 1,11),f( 4, 1,12) /  2.4425640d-01 ,  2.4425640d-01 /
      data f( 4, 1,13),f( 4, 1,14) /  2.4425640d-01 ,  2.4425640d-01 /
      data f( 4, 1,15),f( 4, 1,16) /  2.4425640d-01 ,  2.4425640d-01 /
      data f( 4, 1,17),f( 4, 1,18) /  2.4425640d-01 ,  2.4425640d-01 /
      data f( 4, 1,19),f( 4, 1,20) /  2.4425640d-01 ,  2.4425640d-01 /
      data f( 4, 1,21),f( 4, 1,22) /  2.4425640d-01 ,  2.4425640d-01 /
      data f( 4, 1,23) /              2.4425640d-01 /
      data f( 4, 2, 1),f( 4, 2, 2) /  2.0531570d-01 ,  2.0751470d-01 /
      data f( 4, 2, 3),f( 4, 2, 4) /  2.0872880d-01 ,  2.0872880d-01 /
      data f( 4, 2, 5),f( 4, 2, 6) /  2.0751470d-01 ,  2.0531570d-01 /
      data f( 4, 2, 7),f( 4, 2, 8) /  2.0324970d-01 ,  2.0161270d-01 /
      data f( 4, 2, 9),f( 4, 2,10) /  2.0006220d-01 ,  1.9892780d-01 /
      data f( 4, 2,11),f( 4, 2,12) /  1.9824440d-01 ,  1.9802530d-01 /
      data f( 4, 2,13),f( 4, 2,14) /  1.9827840d-01 ,  1.9925580d-01 /
      data f( 4, 2,15),f( 4, 2,16) /  2.0017280d-01 ,  2.0176510d-01 /
      data f( 4, 2,17),f( 4, 2,18) /  2.0369350d-01 ,  2.0555360d-01 /
      data f( 4, 2,19),f( 4, 2,20) /  2.0755390d-01 ,  2.0903230d-01 /
      data f( 4, 2,21),f( 4, 2,22) /  2.0903230d-01 ,  2.0755390d-01 /
      data f( 4, 2,23) /              2.0555360d-01 /
      data f( 4, 3, 1),f( 4, 3, 2) /  1.6882000d-01 ,  1.8251500d-01 /
      data f( 4, 3, 3),f( 4, 3, 4) /  2.0101390d-01 ,  2.0101390d-01 /
      data f( 4, 3, 5),f( 4, 3, 6) /  1.8251500d-01 ,  1.6882000d-01 /
      data f( 4, 3, 7),f( 4, 3, 8) /  1.6080010d-01 ,  1.2402380d-01 /
      data f( 4, 3, 9),f( 4, 3,10) /  9.2647700d-02 ,  7.2768500d-02 /
      data f( 4, 3,11),f( 4, 3,12) /  6.1548700d-02 ,  5.7923600d-02 /
      data f( 4, 3,13),f( 4, 3,14) /  6.1670200d-02 ,  7.3091500d-02 /
      data f( 4, 3,15),f( 4, 3,16) /  9.3281000d-02 ,  1.2511580d-01 /
      data f( 4, 3,17),f( 4, 3,18) /  1.6097670d-01 ,  1.6906570d-01 /
      data f( 4, 3,19),f( 4, 3,20) /  1.8282670d-01 ,  2.0136460d-01 /
      data f( 4, 3,21),f( 4, 3,22) /  2.0136460d-01 ,  1.8282670d-01 /
      data f( 4, 3,23) /              1.6906570d-01 /
      data f( 4, 4, 1),f( 4, 4, 2) /  6.1402700d-02 ,  1.6286680d-01 /
      data f( 4, 4, 3),f( 4, 4, 4) /  1.8539390d-01 ,  1.8539390d-01 /
      data f( 4, 4, 5),f( 4, 4, 6) /  1.6286680d-01 ,  6.1402700d-02 /
      data f( 4, 4, 7),f( 4, 4, 8) / -5.6940000d-03 , -4.6420100d-02 /
      data f( 4, 4, 9),f( 4, 4,10) / -7.3346300d-02 , -9.1388700d-02 /
      data f( 4, 4,11),f( 4, 4,12) / -1.0199700d-01 , -1.0567960d-01 /
      data f( 4, 4,13),f( 4, 4,14) / -1.0249320d-01 , -9.2184600d-02 /
      data f( 4, 4,15),f( 4, 4,16) / -7.4209100d-02 , -4.6919400d-02 /
      data f( 4, 4,17),f( 4, 4,18) / -5.2703000d-03 ,  6.3173500d-02 /
      data f( 4, 4,19),f( 4, 4,20) /  1.6318510d-01 ,  1.8580400d-01 /
      data f( 4, 4,21),f( 4, 4,22) /  1.8580400d-01 ,  1.6318510d-01 /
      data f( 4, 4,23) /              6.3173500d-02 /
      data f( 4, 5, 1),f( 4, 5, 2) / -1.4563100d-02 ,  2.2431300d-02 /
      data f( 4, 5, 3),f( 4, 5, 4) /  5.9920200d-02 ,  5.9920200d-02 /
      data f( 4, 5, 5),f( 4, 5, 6) /  2.2431300d-02 , -1.4563100d-02 /
      data f( 4, 5, 7),f( 4, 5, 8) / -4.3793700d-02 , -7.0039600d-02 /
      data f( 4, 5, 9),f( 4, 5,10) / -9.1128500d-02 , -1.0668000d-01 /
      data f( 4, 5,11),f( 4, 5,12) / -1.1639670d-01 , -1.2013320d-01 /
      data f( 4, 5,13),f( 4, 5,14) / -1.1779910d-01 , -1.0930470d-01 /
      data f( 4, 5,15),f( 4, 5,16) / -9.4554800d-02 , -7.3496200d-02 /
      data f( 4, 5,17),f( 4, 5,18) / -4.6065000d-02 , -1.1853000d-02 /
      data f( 4, 5,19),f( 4, 5,20) /  2.6979000d-02 ,  6.8162500d-02 /
      data f( 4, 5,21),f( 4, 5,22) /  6.8162500d-02 ,  2.6979000d-02 /
      data f( 4, 5,23) /             -1.1853000d-02 /
      data f( 4, 6, 1),f( 4, 6, 2) / -4.2153000d-03 ,  1.5117700d-02 /
      data f( 4, 6, 3),f( 4, 6, 4) /  2.9773800d-02 ,  2.9773800d-02 /
      data f( 4, 6, 5),f( 4, 6, 6) /  1.5117700d-02 , -4.2153000d-03 /
      data f( 4, 6, 7),f( 4, 6, 8) / -2.6839500d-02 , -4.7879900d-02 /
      data f( 4, 6, 9),f( 4, 6,10) / -6.5684800d-02 , -7.9305600d-02 /
      data f( 4, 6,11),f( 4, 6,12) / -8.8232000d-02 , -9.2189700d-02 /
      data f( 4, 6,13),f( 4, 6,14) / -9.1028900d-02 , -8.4664600d-02 /
      data f( 4, 6,15),f( 4, 6,16) / -7.3046000d-02 , -5.6199600d-02 /
      data f( 4, 6,17),f( 4, 6,18) / -3.4381300d-02 , -8.3132000d-03 /
      data f( 4, 6,19),f( 4, 6,20) /  2.0466000d-02 ,  4.8737900d-02 /
      data f( 4, 6,21),f( 4, 6,22) /  4.8737900d-02 ,  2.0466000d-02 /
      data f( 4, 6,23) /             -8.3132000d-03 /
      data f( 4, 7, 1),f( 4, 7, 2) /  1.0843700d-02 ,  2.5943600d-02 /
      data f( 4, 7, 3),f( 4, 7, 4) /  2.7468800d-02 ,  2.7468800d-02 /
      data f( 4, 7, 5),f( 4, 7, 6) /  2.5943600d-02 ,  1.0843700d-02 /
      data f( 4, 7, 7),f( 4, 7, 8) / -4.8145000d-03 , -2.0285100d-02 /
      data f( 4, 7, 9),f( 4, 7,10) / -3.4409200d-02 , -4.6035800d-02 /
      data f( 4, 7,11),f( 4, 7,12) / -5.4298200d-02 , -5.8673100d-02 /
      data f( 4, 7,13),f( 4, 7,14) / -5.8909100d-02 , -5.4938900d-02 /
      data f( 4, 7,15),f( 4, 7,16) / -4.6814600d-02 , -3.4687900d-02 /
      data f( 4, 7,17),f( 4, 7,18) / -1.8867800d-02 ,  3.8500000d-05 /
      data f( 4, 7,19),f( 4, 7,20) /  2.0858200d-02 ,  4.0874700d-02 /
      data f( 4, 7,21),f( 4, 7,22) /  4.0874700d-02 ,  2.0858200d-02 /
      data f( 4, 7,23) /              3.8500000d-05 /
      data f( 4, 8, 1),f( 4, 8, 2) /  2.1391100d-02 ,  1.4747800d-02 /
      data f( 4, 8, 3),f( 4, 8, 4) /  3.2264000d-03 ,  3.2264000d-03 /
      data f( 4, 8, 5),f( 4, 8, 6) /  1.4747800d-02 ,  2.1391100d-02 /
      data f( 4, 8, 7),f( 4, 8, 8) /  1.2941600d-02 ,  3.0588000d-03 /
      data f( 4, 8, 9),f( 4, 8,10) / -7.4940000d-03 , -1.7352700d-02 /
      data f( 4, 8,11),f( 4, 8,12) / -2.5184400d-02 , -3.0130000d-02 /
      data f( 4, 8,13),f( 4, 8,14) / -3.1805800d-02 , -3.0158800d-02 /
      data f( 4, 8,15),f( 4, 8,16) / -2.5332200d-02 , -1.7612900d-02 /
      data f( 4, 8,17),f( 4, 8,18) / -7.4223000d-03 ,  4.6065000d-03 /
      data f( 4, 8,19),f( 4, 8,20) /  1.7410000d-02 ,  2.8740900d-02 /
      data f( 4, 8,21),f( 4, 8,22) /  2.8740900d-02 ,  1.7410000d-02 /
      data f( 4, 8,23) /              4.6065000d-03 /
      data f( 4, 9, 1),f( 4, 9, 2) /  2.9532000d-03 , -2.1668800d-02 /
      data f( 4, 9, 3),f( 4, 9, 4) / -3.8579600d-02 , -3.8579600d-02 /
      data f( 4, 9, 5),f( 4, 9, 6) / -2.1668800d-02 ,  2.9532000d-03 /
      data f( 4, 9, 7),f( 4, 9, 8) /  3.0841300d-02 ,  2.1347300d-02 /
      data f( 4, 9, 9),f( 4, 9,10) /  1.3026100d-02 ,  4.3880000d-03 /
      data f( 4, 9,11),f( 4, 9,12) / -3.1926000d-03 , -8.6685000d-03 /
      data f( 4, 9,13),f( 4, 9,14) / -1.1559100d-02 , -1.1797500d-02 /
      data f( 4, 9,15),f( 4, 9,16) / -9.5546000d-03 , -5.1180000d-03 /
      data f( 4, 9,17),f( 4, 9,18) /  1.1641000d-03 ,  8.8543000d-03 /
      data f( 4, 9,19),f( 4, 9,20) /  1.7329100d-02 ,  2.5120100d-02 /
      data f( 4, 9,21),f( 4, 9,22) /  2.5120100d-02 ,  1.7329100d-02 /
      data f( 4, 9,23) /              8.8543000d-03 /
      data f( 4,10, 1),f( 4,10, 2) / -3.5264100d-02 , -6.4314500d-02 /
      data f( 4,10, 3),f( 4,10, 4) / -8.3234400d-02 , -8.3234400d-02 /
      data f( 4,10, 5),f( 4,10, 6) / -6.4314500d-02 , -3.5264100d-02 /
      data f( 4,10, 7),f( 4,10, 8) / -1.6914000d-03 ,  2.6549300d-02 /
      data f( 4,10, 9),f( 4,10,10) /  2.6029900d-02 ,  1.8908300d-02 /
      data f( 4,10,11),f( 4,10,12) /  1.1748100d-02 ,  6.0781000d-03 /
      data f( 4,10,13),f( 4,10,14) /  2.4815000d-03 ,  1.0549000d-03 /
      data f( 4,10,15),f( 4,10,16) /  1.6680000d-03 ,  4.0997000d-03 /
      data f( 4,10,17),f( 4,10,18) /  8.0803000d-03 ,  1.3348900d-02 /
      data f( 4,10,19),f( 4,10,20) /  1.9716400d-02 ,  2.6378500d-02 /
      data f( 4,10,21),f( 4,10,22) /  2.6378500d-02 ,  1.9716400d-02 /
      data f( 4,10,23) /              1.3348900d-02 /
      data f( 4,11, 1),f( 4,11, 2) / -7.1493700d-02 , -9.8005600d-02 /
      data f( 4,11, 3),f( 4,11, 4) / -1.0966180d-01 , -1.0966180d-01 /
      data f( 4,11, 5),f( 4,11, 6) / -9.8005600d-02 , -7.1493700d-02 /
      data f( 4,11, 7),f( 4,11, 8) / -3.5496100d-02 ,  1.1930000d-04 /
      data f( 4,11, 9),f( 4,11,10) /  2.3412900d-02 ,  2.5549300d-02 /
      data f( 4,11,11),f( 4,11,12) /  2.0372100d-02 ,  1.5232800d-02 /
      data f( 4,11,13),f( 4,11,14) /  1.1611400d-02 ,  9.7852000d-03 /
      data f( 4,11,15),f( 4,11,16) /  9.7159000d-03 ,  1.1232900d-02 /
      data f( 4,11,17),f( 4,11,18) /  1.4069700d-02 ,  1.8054600d-02 /
      data f( 4,11,19),f( 4,11,20) /  2.3431600d-02 ,  3.0121600d-02 /
      data f( 4,11,21),f( 4,11,22) /  3.0121600d-02 ,  2.3431600d-02 /
      data f( 4,11,23) /              1.8054600d-02 /
      data f( 4,12, 1),f( 4,12, 2) / -9.5077100d-02 , -1.0386940d-01 /
      data f( 4,12, 3),f( 4,12, 4) / -8.6351600d-02 , -8.6351600d-02 /
      data f( 4,12, 5),f( 4,12, 6) / -1.0386940d-01 , -9.5077100d-02 /
      data f( 4,12, 7),f( 4,12, 8) / -6.3928400d-02 , -2.6209300d-02 /
      data f( 4,12, 9),f( 4,12,10) /  5.9171000d-03 ,  2.2653200d-02 /
      data f( 4,12,11),f( 4,12,12) /  2.3408800d-02 ,  2.0013200d-02 /
      data f( 4,12,13),f( 4,12,14) /  1.7076200d-02 ,  1.5518700d-02 /
      data f( 4,12,15),f( 4,12,16) /  1.5484900d-02 ,  1.6846400d-02 /
      data f( 4,12,17),f( 4,12,18) /  1.9308700d-02 ,  2.2744000d-02 /
      data f( 4,12,19),f( 4,12,20) /  2.7681300d-02 ,  3.4098300d-02 /
      data f( 4,12,21),f( 4,12,22) /  3.4098300d-02 ,  2.7681300d-02 /
      data f( 4,12,23) /              2.2744000d-02 /
      data f( 4,13, 1),f( 4,13, 2) / -1.0226870d-01 , -8.2683900d-02 /
      data f( 4,13, 3),f( 4,13, 4) / -2.2147400d-02 , -2.2147400d-02 /
      data f( 4,13, 5),f( 4,13, 6) / -8.2683900d-02 , -1.0226870d-01 /
      data f( 4,13, 7),f( 4,13, 8) / -8.2668000d-02 , -4.7478300d-02 /
      data f( 4,13, 9),f( 4,13,10) / -1.2504200d-02 ,  1.2819600d-02 /
      data f( 4,13,11),f( 4,13,12) /  2.1881200d-02 ,  2.1491300d-02 /
      data f( 4,13,13),f( 4,13,14) /  1.9798300d-02 ,  1.8899700d-02 /
      data f( 4,13,15),f( 4,13,16) /  1.9232300d-02 ,  2.0750100d-02 /
      data f( 4,13,17),f( 4,13,18) /  2.3185800d-02 ,  2.6406700d-02 /
      data f( 4,13,19),f( 4,13,20) /  3.0746600d-02 ,  3.5984900d-02 /
      data f( 4,13,21),f( 4,13,22) /  3.5984900d-02 ,  3.0746600d-02 /
      data f( 4,13,23) /              2.6406700d-02 /
      data f( 4,14, 1),f( 4,14, 2) / -1.0357050d-01 , -7.7612700d-02 /
      data f( 4,14, 3),f( 4,14, 4) / -1.8307100d-02 , -1.8307100d-02 /
      data f( 4,14, 5),f( 4,14, 6) / -7.7612700d-02 , -1.0357050d-01 /
      data f( 4,14, 7),f( 4,14, 8) / -9.1467000d-02 , -6.0990800d-02 /
      data f( 4,14, 9),f( 4,14,10) / -2.7076600d-02 ,  1.5711000d-03 /
      data f( 4,14,11),f( 4,14,12) /  1.7654500d-02 ,  2.0855800d-02 /
      data f( 4,14,13),f( 4,14,14) /  2.0574400d-02 ,  2.0360700d-02 /
      data f( 4,14,15),f( 4,14,16) /  2.0977600d-02 ,  2.2488600d-02 /
      data f( 4,14,17),f( 4,14,18) /  2.4694400d-02 ,  2.7380200d-02 /
      data f( 4,14,19),f( 4,14,20) /  3.0422800d-02 ,  3.3306700d-02 /
      data f( 4,14,21),f( 4,14,22) /  3.3306700d-02 ,  3.0422800d-02 /
      data f( 4,14,23) /              2.7380200d-02 /
      data f( 4,15, 1),f( 4,15, 2) / -1.0589030d-01 , -1.0060710d-01 /
      data f( 4,15, 3),f( 4,15, 4) / -8.1746100d-02 , -8.1746100d-02 /
      data f( 4,15, 5),f( 4,15, 6) / -1.0060710d-01 , -1.0589030d-01 /
      data f( 4,15, 7),f( 4,15, 8) / -9.1482100d-02 , -6.5083600d-02 /
      data f( 4,15, 9),f( 4,15,10) / -3.5040500d-02 , -7.3190000d-03 /
      data f( 4,15,11),f( 4,15,12) /  1.2579700d-02 ,  1.9425100d-02 /
      data f( 4,15,13),f( 4,15,14) /  2.0339100d-02 ,  2.0554200d-02 /
      data f( 4,15,15),f( 4,15,16) /  2.1156900d-02 ,  2.2305900d-02 /
      data f( 4,15,17),f( 4,15,18) /  2.3880900d-02 ,  2.5658000d-02 /
      data f( 4,15,19),f( 4,15,20) /  2.7378200d-02 ,  2.8699100d-02 /
      data f( 4,15,21),f( 4,15,22) /  2.8699100d-02 ,  2.7378200d-02 /
      data f( 4,15,23) /              2.5658000d-02 /
      data f( 4,16, 1),f( 4,16, 2) / -9.6820300d-02 , -1.0612980d-01 /
      data f( 4,16, 3),f( 4,16, 4) / -1.0922810d-01 , -1.0922810d-01 /
      data f( 4,16, 5),f( 4,16, 6) / -1.0612980d-01 , -9.6820300d-02 /
      data f( 4,16, 7),f( 4,16, 8) / -8.0305700d-02 , -5.8505000d-02 /
      data f( 4,16, 9),f( 4,16,10) / -3.4495400d-02 , -1.1163200d-02 /
      data f( 4,16,11),f( 4,16,12) /  8.5482000d-03 ,  1.8352300d-02 /
      data f( 4,16,13),f( 4,16,14) /  2.0035300d-02 ,  2.0362300d-02 /
      data f( 4,16,15),f( 4,16,16) /  2.0700400d-02 ,  2.1292200d-02 /
      data f( 4,16,17),f( 4,16,18) /  2.2101800d-02 ,  2.2992900d-02 /
      data f( 4,16,19),f( 4,16,20) /  2.3801800d-02 ,  2.4369500d-02 /
      data f( 4,16,21),f( 4,16,22) /  2.4369500d-02 ,  2.3801800d-02 /
      data f( 4,16,23) /              2.2992900d-02 /
      data f( 4,17, 1),f( 4,17, 2) / -6.8306100d-02 , -7.7553800d-02 /
      data f( 4,17, 3),f( 4,17, 4) / -8.3156800d-02 , -8.3156800d-02 /
      data f( 4,17, 5),f( 4,17, 6) / -7.7553800d-02 , -6.8306100d-02 /
      data f( 4,17, 7),f( 4,17, 8) / -5.5833100d-02 , -4.0964000d-02 /
      data f( 4,17, 9),f( 4,17,10) / -2.4772100d-02 , -8.3858000d-03 /
      data f( 4,17,11),f( 4,17,12) /  7.1226000d-03 ,  1.9749900d-02 /
      data f( 4,17,13),f( 4,17,14) /  2.0470400d-02 ,  2.0619900d-02 /
      data f( 4,17,15),f( 4,17,16) /  2.0607900d-02 ,  2.0674100d-02 /
      data f( 4,17,17),f( 4,17,18) /  2.0844600d-02 ,  2.1074900d-02 /
      data f( 4,17,19),f( 4,17,20) /  2.1301600d-02 ,  2.1466500d-02 /
      data f( 4,17,21),f( 4,17,22) /  2.1466500d-02 ,  2.1301600d-02 /
      data f( 4,17,23) /              2.1074900d-02 /
      data f( 4,18, 1),f( 4,18, 2) / -2.7267800d-02 , -3.1601000d-02 /
      data f( 4,18, 3),f( 4,18, 4) / -3.4294500d-02 , -3.4294500d-02 /
      data f( 4,18, 5),f( 4,18, 6) / -3.1601000d-02 , -2.7267800d-02 /
      data f( 4,18, 7),f( 4,18, 8) / -2.1518800d-02 , -1.4645200d-02 /
      data f( 4,18, 9),f( 4,18,10) / -6.9810000d-03 ,  1.1309000d-03 /
      data f( 4,18,11),f( 4,18,12) /  9.3454000d-03 ,  1.7367200d-02 /
      data f( 4,18,13),f( 4,18,14) /  2.2305900d-02 ,  2.2033900d-02 /
      data f( 4,18,15),f( 4,18,16) /  2.1742300d-02 ,  2.1494600d-02 /
      data f( 4,18,17),f( 4,18,18) /  2.1308200d-02 ,  2.1180300d-02 /
      data f( 4,18,19),f( 4,18,20) /  2.1101800d-02 ,  2.1059900d-02 /
      data f( 4,18,21),f( 4,18,22) /  2.1059900d-02 ,  2.1101800d-02 /
      data f( 4,18,23) /              2.1180300d-02 /
      data f( 4,19, 1),f( 4,19, 2) /  2.4576800d-02 ,  2.4576800d-02 /
      data f( 4,19, 3),f( 4,19, 4) /  2.4576800d-02 ,  2.4576800d-02 /
      data f( 4,19, 5),f( 4,19, 6) /  2.4576800d-02 ,  2.4576800d-02 /
      data f( 4,19, 7),f( 4,19, 8) /  2.4576800d-02 ,  2.4576800d-02 /
      data f( 4,19, 9),f( 4,19,10) /  2.4576800d-02 ,  2.4576800d-02 /
      data f( 4,19,11),f( 4,19,12) /  2.4576800d-02 ,  2.4576800d-02 /
      data f( 4,19,13),f( 4,19,14) /  2.4576800d-02 ,  2.4576800d-02 /
      data f( 4,19,15),f( 4,19,16) /  2.4576800d-02 ,  2.4576800d-02 /
      data f( 4,19,17),f( 4,19,18) /  2.4576800d-02 ,  2.4576800d-02 /
      data f( 4,19,19),f( 4,19,20) /  2.4576800d-02 ,  2.4576800d-02 /
      data f( 4,19,21),f( 4,19,22) /  2.4576800d-02 ,  2.4576800d-02 /
      data f( 4,19,23) /              2.4576800d-02 /
      data f( 5, 1, 1),f( 5, 1, 2) /  2.1671840d-01 ,  2.1671840d-01 /
      data f( 5, 1, 3),f( 5, 1, 4) /  2.1671840d-01 ,  2.1671840d-01 /
      data f( 5, 1, 5),f( 5, 1, 6) /  2.1671840d-01 ,  2.1671840d-01 /
      data f( 5, 1, 7),f( 5, 1, 8) /  2.1671840d-01 ,  2.1671840d-01 /
      data f( 5, 1, 9),f( 5, 1,10) /  2.1671840d-01 ,  2.1671840d-01 /
      data f( 5, 1,11),f( 5, 1,12) /  2.1671840d-01 ,  2.1671840d-01 /
      data f( 5, 1,13),f( 5, 1,14) /  2.1671840d-01 ,  2.1671840d-01 /
      data f( 5, 1,15),f( 5, 1,16) /  2.1671840d-01 ,  2.1671840d-01 /
      data f( 5, 1,17),f( 5, 1,18) /  2.1671840d-01 ,  2.1671840d-01 /
      data f( 5, 1,19),f( 5, 1,20) /  2.1671840d-01 ,  2.1671840d-01 /
      data f( 5, 1,21),f( 5, 1,22) /  2.1671840d-01 ,  2.1671840d-01 /
      data f( 5, 1,23) /              2.1671840d-01 /
      data f( 5, 2, 1),f( 5, 2, 2) /  1.9017280d-01 ,  1.9241060d-01 /
      data f( 5, 2, 3),f( 5, 2, 4) /  1.9367330d-01 ,  1.9367330d-01 /
      data f( 5, 2, 5),f( 5, 2, 6) /  1.9241060d-01 ,  1.9017280d-01 /
      data f( 5, 2, 7),f( 5, 2, 8) /  1.8809260d-01 ,  1.8647700d-01 /
      data f( 5, 2, 9),f( 5, 2,10) /  1.8495590d-01 ,  1.8385560d-01 /
      data f( 5, 2,11),f( 5, 2,12) /  1.8319480d-01 ,  1.8298400d-01 /
      data f( 5, 2,13),f( 5, 2,14) /  1.8322880d-01 ,  1.8392540d-01 /
      data f( 5, 2,15),f( 5, 2,16) /  1.8506570d-01 ,  1.8662660d-01 /
      data f( 5, 2,17),f( 5, 2,18) /  1.8828370d-01 ,  1.9040370d-01 /
      data f( 5, 2,19),f( 5, 2,20) /  1.9244030d-01 ,  1.9396210d-01 /
      data f( 5, 2,21),f( 5, 2,22) /  1.9396210d-01 ,  1.9244030d-01 /
      data f( 5, 2,23) /              1.9040370d-01 /
      data f( 5, 3, 1),f( 5, 3, 2) /  1.6632980d-01 ,  1.8325100d-01 /
      data f( 5, 3, 3),f( 5, 3, 4) /  2.0907360d-01 ,  2.0907360d-01 /
      data f( 5, 3, 5),f( 5, 3, 6) /  1.8325100d-01 ,  1.6632980d-01 /
      data f( 5, 3, 7),f( 5, 3, 8) /  1.3844180d-01 ,  8.6020200d-02 /
      data f( 5, 3, 9),f( 5, 3,10) /  5.3591100d-02 ,  3.4513600d-02 /
      data f( 5, 3,11),f( 5, 3,12) /  2.3479100d-02 ,  1.9363200d-02 /
      data f( 5, 3,13),f( 5, 3,14) /  2.3609300d-02 ,  3.4856900d-02 /
      data f( 5, 3,15),f( 5, 3,16) /  5.4274000d-02 ,  8.7149700d-02 /
      data f( 5, 3,17),f( 5, 3,18) /  1.4023490d-01 ,  1.6657130d-01 /
      data f( 5, 3,19),f( 5, 3,20) /  1.8354860d-01 ,  2.0940260d-01 /
      data f( 5, 3,21),f( 5, 3,22) /  2.0940260d-01 ,  1.8354860d-01 /
      data f( 5, 3,23) /              1.6657130d-01 /
      data f( 5, 4, 1),f( 5, 4, 2) /  6.3269000d-02 ,  1.6556210d-01 /
      data f( 5, 4, 3),f( 5, 4, 4) /  1.9625020d-01 ,  1.9625020d-01 /
      data f( 5, 4, 5),f( 5, 4, 6) /  1.6556210d-01 ,  6.3269000d-02 /
      data f( 5, 4, 7),f( 5, 4, 8) / -9.5968000d-03 , -5.1143500d-02 /
      data f( 5, 4, 9),f( 5, 4,10) / -7.8498400d-02 , -9.5673100d-02 /
      data f( 5, 4,11),f( 5, 4,12) / -1.0615110d-01 , -1.1032820d-01 /
      data f( 5, 4,13),f( 5, 4,14) / -1.0660970d-01 , -9.6420400d-02 /
      data f( 5, 4,15),f( 5, 4,16) / -7.9355100d-02 , -5.1662700d-02 /
      data f( 5, 4,17),f( 5, 4,18) / -9.1941000d-03 ,  6.4997700d-02 /
      data f( 5, 4,19),f( 5, 4,20) /  1.6587000d-01 ,  1.9663950d-01 /
      data f( 5, 4,21),f( 5, 4,22) /  1.9663950d-01 ,  1.6587000d-01 /
      data f( 5, 4,23) /              6.4997700d-02 /
      data f( 5, 5, 1),f( 5, 5, 2) / -1.2264200d-02 ,  2.6093000d-02 /
      data f( 5, 5, 3),f( 5, 5, 4) /  6.6552800d-02 ,  6.6552800d-02 /
      data f( 5, 5, 5),f( 5, 5, 6) /  2.6093000d-02 , -1.2264200d-02 /
      data f( 5, 5, 7),f( 5, 5, 8) / -4.1764200d-02 , -6.7725900d-02 /
      data f( 5, 5, 9),f( 5, 5,10) / -8.8494000d-02 , -1.0378110d-01 /
      data f( 5, 5,11),f( 5, 5,12) / -1.1332720d-01 , -1.1700620d-01 /
      data f( 5, 5,13),f( 5, 5,14) / -1.1473590d-01 , -1.0642180d-01 /
      data f( 5, 5,15),f( 5, 5,16) / -9.1964100d-02 , -6.9038000d-02 /
      data f( 5, 5,17),f( 5, 5,18) / -4.4173900d-02 , -1.0151300d-02 /
      data f( 5, 5,19),f( 5, 5,20) /  3.0346600d-02 ,  7.4499600d-02 /
      data f( 5, 5,21),f( 5, 5,22) /  7.4499600d-02 ,  3.0346600d-02 /
      data f( 5, 5,23) /             -1.0151300d-02 /
      data f( 5, 6, 1),f( 5, 6, 2) / -2.2609000d-03 ,  1.7560000d-02 /
      data f( 5, 6, 3),f( 5, 6, 4) /  3.2607600d-02 ,  3.2607600d-02 /
      data f( 5, 6, 5),f( 5, 6, 6) /  1.7560000d-02 , -2.2609000d-03 /
      data f( 5, 6, 7),f( 5, 6, 8) / -2.4655700d-02 , -4.5264000d-02 /
      data f( 5, 6, 9),f( 5, 6,10) / -6.2611000d-02 , -7.5848300d-02 /
      data f( 5, 6,11),f( 5, 6,12) / -8.4519700d-02 , -8.8377300d-02 /
      data f( 5, 6,13),f( 5, 6,14) / -8.7280200d-02 , -8.1114900d-02 /
      data f( 5, 6,15),f( 5, 6,16) / -6.9900800d-02 , -5.3562200d-02 /
      data f( 5, 6,17),f( 5, 6,18) / -3.2350800d-02 , -6.8956000d-03 /
      data f( 5, 6,19),f( 5, 6,20) /  2.1454000d-02 ,  5.0174400d-02 /
      data f( 5, 6,21),f( 5, 6,22) /  5.0174400d-02 ,  2.1454000d-02 /
      data f( 5, 6,23) /             -6.8956000d-03 /
      data f( 5, 7, 1),f( 5, 7, 2) /  1.0946700d-02 ,  2.5703000d-02 /
      data f( 5, 7, 3),f( 5, 7, 4) /  3.4988800d-02 ,  3.4988800d-02 /
      data f( 5, 7, 5),f( 5, 7, 6) /  2.5703000d-02 ,  1.0946700d-02 /
      data f( 5, 7, 7),f( 5, 7, 8) / -4.1694000d-03 , -1.8988200d-02 /
      data f( 5, 7, 9),f( 5, 7,10) / -3.2467900d-02 , -4.3559300d-02 /
      data f( 5, 7,11),f( 5, 7,12) / -5.1457500d-02 , -5.5663500d-02 /
      data f( 5, 7,13),f( 5, 7,14) / -5.5929500d-02 , -5.2185200d-02 /
      data f( 5, 7,15),f( 5, 7,16) / -4.4479200d-02 , -3.2961000d-02 /
      data f( 5, 7,17),f( 5, 7,18) / -1.7940100d-02 , -3.9000000d-05 /
      data f( 5, 7,19),f( 5, 7,20) /  1.9498000d-02 ,  3.7787900d-02 /
      data f( 5, 7,21),f( 5, 7,22) /  3.7787900d-02 ,  1.9498000d-02 /
      data f( 5, 7,23) /             -3.9000000d-05 /
      data f( 5, 8, 1),f( 5, 8, 2) /  2.0062100d-02 ,  1.8806100d-02 /
      data f( 5, 8, 3),f( 5, 8, 4) /  7.6133000d-03 ,  7.6133000d-03 /
      data f( 5, 8, 5),f( 5, 8, 6) /  1.8806100d-02 ,  2.0062100d-02 /
      data f( 5, 8, 7),f( 5, 8, 8) /  1.2015600d-02 ,  2.7724000d-03 /
      data f( 5, 8, 9),f( 5, 8,10) / -7.0564000d-03 , -1.6258100d-02 /
      data f( 5, 8,11),f( 5, 8,12) / -2.3605800d-02 , -2.8284900d-02 /
      data f( 5, 8,13),f( 5, 8,14) / -2.9917400d-02 , -2.8430900d-02 /
      data f( 5, 8,15),f( 5, 8,16) / -2.3960300d-02 , -1.6779100d-02 /
      data f( 5, 8,17),f( 5, 8,18) / -7.3016000d-03 ,  3.8347000d-03 /
      data f( 5, 8,19),f( 5, 8,20) /  1.5543800d-02 ,  2.5638900d-02 /
      data f( 5, 8,21),f( 5, 8,22) /  2.5638900d-02 ,  1.5543800d-02 /
      data f( 5, 8,23) /              3.8347000d-03 /
      data f( 5, 9, 1),f( 5, 9, 2) /  7.9066000d-03 , -1.5621900d-02 /
      data f( 5, 9, 3),f( 5, 9, 4) / -3.1906000d-02 , -3.1906000d-02 /
      data f( 5, 9, 5),f( 5, 9, 6) / -1.5621900d-02 ,  7.9066000d-03 /
      data f( 5, 9, 7),f( 5, 9, 8) /  2.5227500d-02 ,  1.9108800d-02 /
      data f( 5, 9, 9),f( 5, 9,10) /  1.1745300d-02 ,  3.9458000d-03 /
      data f( 5, 9,11),f( 5, 9,12) / -3.0013000d-03 , -8.0848000d-03 /
      data f( 5, 9,13),f( 5, 9,14) / -1.0815000d-02 , -1.1098200d-02 /
      data f( 5, 9,15),f( 5, 9,16) / -9.0793000d-03 , -5.0165000d-03 /
      data f( 5, 9,17),f( 5, 9,18) /  7.4740000d-04 ,  7.7646000d-03 /
      data f( 5, 9,19),f( 5, 9,20) /  1.5359900d-02 ,  2.2092000d-02 /
      data f( 5, 9,21),f( 5, 9,22) /  2.2092000d-02 ,  1.5359900d-02 /
      data f( 5, 9,23) /              7.7646000d-03 /
      data f( 5,10, 1),f( 5,10, 2) / -2.8495800d-02 , -5.6411300d-02 /
      data f( 5,10, 3),f( 5,10, 4) / -7.4979200d-02 , -7.4979200d-02 /
      data f( 5,10, 5),f( 5,10, 6) / -5.6411300d-02 , -2.8495800d-02 /
      data f( 5,10, 7),f( 5,10, 8) /  2.7880000d-03 ,  2.4071700d-02 /
      data f( 5,10, 9),f( 5,10,10) /  2.2780800d-02 ,  1.6853900d-02 /
      data f( 5,10,11),f( 5,10,12) /  1.0561200d-02 ,  5.4365000d-03 /
      data f( 5,10,13),f( 5,10,14) /  2.1301000d-03 ,  7.9330000d-04 /
      data f( 5,10,15),f( 5,10,16) /  1.3358000d-03 ,  3.5663000d-03 /
      data f( 5,10,17),f( 5,10,18) /  7.2292000d-03 ,  1.2026700d-02 /
      data f( 5,10,19),f( 5,10,20) /  1.7640400d-02 ,  2.3160700d-02 /
      data f( 5,10,21),f( 5,10,22) /  2.3160700d-02 ,  1.7640400d-02 /
      data f( 5,10,23) /              1.2026700d-02 /
      data f( 5,11, 1),f( 5,11, 2) / -6.3525400d-02 , -9.0388200d-02 /
      data f( 5,11, 3),f( 5,11, 4) / -1.0407940d-01 , -1.0407940d-01 /
      data f( 5,11, 5),f( 5,11, 6) / -9.0388200d-02 , -6.3525400d-02 /
      data f( 5,11, 7),f( 5,11, 8) / -2.9144200d-02 ,  2.9482000d-03 /
      data f( 5,11, 9),f( 5,11,10) /  2.0935100d-02 ,  2.2205700d-02 /
      data f( 5,11,11),f( 5,11,12) /  1.7981500d-02 ,  1.3527900d-02 /
      data f( 5,11,13),f( 5,11,14) /  1.0299400d-02 ,  8.6593000d-03 /
      data f( 5,11,15),f( 5,11,16) /  8.6245000d-03 ,  1.0065200d-02 /
      data f( 5,11,17),f( 5,11,18) /  1.2736500d-02 ,  1.6405100d-02 /
      data f( 5,11,19),f( 5,11,20) /  2.1065900d-02 ,  2.6318700d-02 /
      data f( 5,11,21),f( 5,11,22) /  2.6318700d-02 ,  2.1065900d-02 /
      data f( 5,11,23) /              1.6405100d-02 /
      data f( 5,12, 1),f( 5,12, 2) / -8.7853300d-02 , -1.0194180d-01 /
      data f( 5,12, 3),f( 5,12, 4) / -9.4288900d-02 , -9.4288900d-02 /
      data f( 5,12, 5),f( 5,12, 6) / -1.0194180d-01 , -8.7853300d-02 /
      data f( 5,12, 7),f( 5,12, 8) / -5.6439500d-02 , -2.1114900d-02 /
      data f( 5,12, 9),f( 5,12,10) /  6.9091000d-03 ,  1.9763500d-02 /
      data f( 5,12,11),f( 5,12,12) /  2.0296500d-02 ,  1.7513700d-02 /
      data f( 5,12,13),f( 5,12,14) /  1.4991600d-02 ,  1.3644000d-02 /
      data f( 5,12,15),f( 5,12,16) /  1.3670100d-02 ,  1.4990600d-02 /
      data f( 5,12,17),f( 5,12,18) /  1.7338400d-02 ,  2.0497700d-02 /
      data f( 5,12,19),f( 5,12,20) /  2.4656700d-02 ,  2.9644400d-02 /
      data f( 5,12,21),f( 5,12,22) /  2.9644400d-02 ,  2.4656700d-02 /
      data f( 5,12,23) /              2.0497700d-02 /
      data f( 5,13, 1),f( 5,13, 2) / -9.7647300d-02 , -9.0916300d-02 /
      data f( 5,13, 3),f( 5,13, 4) / -5.3252300d-02 , -5.3252300d-02 /
      data f( 5,13, 5),f( 5,13, 6) / -9.0916300d-02 , -9.7647300d-02 /
      data f( 5,13, 7),f( 5,13, 8) / -7.4996600d-02 , -4.1011700d-02 /
      data f( 5,13, 9),f( 5,13,10) / -9.1283000d-03 ,  1.2039300d-02 /
      data f( 5,13,11),f( 5,13,12) /  1.8853600d-02 ,  1.8568800d-02 /
      data f( 5,13,13),f( 5,13,14) /  1.7180200d-02 ,  1.6441600d-02 /
      data f( 5,13,15),f( 5,13,16) /  1.6795700d-02 ,  1.8233100d-02 /
      data f( 5,13,17),f( 5,13,18) /  2.0503800d-02 ,  2.3383700d-02 /
      data f( 5,13,19),f( 5,13,20) /  2.6924500d-02 ,  3.0756500d-02 /
      data f( 5,13,21),f( 5,13,22) /  3.0756500d-02 ,  2.6924500d-02 /
      data f( 5,13,23) /              2.3383700d-02 /
      data f( 5,14, 1),f( 5,14, 2) / -1.0035950d-01 , -8.8050000d-02 /
      data f( 5,14, 3),f( 5,14, 4) / -5.0769900d-02 , -5.0769900d-02 /
      data f( 5,14, 5),f( 5,14, 6) / -8.8050000d-02 , -1.0035950d-01 /
      data f( 5,14, 7),f( 5,14, 8) / -8.3969200d-02 , -5.3797900d-02 /
      data f( 5,14, 9),f( 5,14,10) / -2.2159800d-02 ,  2.9983000d-03 /
      data f( 5,14,11),f( 5,14,12) /  1.5482200d-02 ,  1.7889200d-02 /
      data f( 5,14,13),f( 5,14,14) /  1.7689200d-02 ,  1.7547800d-02 /
      data f( 5,14,15),f( 5,14,16) /  1.8137400d-02 ,  1.9531800d-02 /
      data f( 5,14,17),f( 5,14,18) /  2.1539800d-02 ,  2.3905800d-02 /
      data f( 5,14,19),f( 5,14,20) /  2.6419800d-02 ,  2.8632900d-02 /
      data f( 5,14,21),f( 5,14,22) /  2.8632900d-02 ,  2.6419800d-02 /
      data f( 5,14,23) /              2.3905800d-02 /
      data f( 5,15, 1),f( 5,15, 2) / -1.0054070d-01 , -1.0179650d-01 /
      data f( 5,15, 3),f( 5,15, 4) / -9.1688900d-02 , -9.1688900d-02 /
      data f( 5,15, 5),f( 5,15, 6) / -1.0179650d-01 , -1.0054070d-01 /
      data f( 5,15, 7),f( 5,15, 8) / -8.3711000d-02 , -5.7586300d-02 /
      data f( 5,15, 9),f( 5,15,10) / -2.9244300d-02 , -4.1899000d-03 /
      data f( 5,15,11),f( 5,15,12) /  1.1883000d-02 ,  1.6689700d-02 /
      data f( 5,15,13),f( 5,15,14) /  1.7390300d-02 ,  1.7595200d-02 /
      data f( 5,15,15),f( 5,15,16) /  1.8152000d-02 ,  1.9199600d-02 /
      data f( 5,15,17),f( 5,15,18) /  2.0624900d-02 ,  2.2207700d-02 /
      data f( 5,15,19),f( 5,15,20) /  2.3696100d-02 ,  2.4800600d-02 /
      data f( 5,15,21),f( 5,15,22) /  2.4800600d-02 ,  2.3696100d-02 /
      data f( 5,15,23) /              2.2207700d-02 /
      data f( 5,16, 1),f( 5,16, 2) / -8.8994400d-02 , -9.9536200d-02 /
      data f( 5,16, 3),f( 5,16, 4) / -1.0420480d-01 , -1.0420480d-01 /
      data f( 5,16, 5),f( 5,16, 6) / -9.9536200d-02 , -8.8994400d-02 /
      data f( 5,16, 7),f( 5,16, 8) / -7.2207200d-02 , -5.1063800d-02 /
      data f( 5,16, 9),f( 5,16,10) / -2.8379700d-02 , -6.9295000d-03 /
      data f( 5,16,11),f( 5,16,12) /  9.3952000d-03 ,  1.6030000d-02 /
      data f( 5,16,13),f( 5,16,14) /  1.7126200d-02 ,  1.7365700d-02 /
      data f( 5,16,15),f( 5,16,16) /  1.7661700d-02 ,  1.8194100d-02 /
      data f( 5,16,17),f( 5,16,18) /  1.8924500d-02 ,  1.9725900d-02 /
      data f( 5,16,19),f( 5,16,20) /  2.0448200d-02 ,  2.0950400d-02 /
      data f( 5,16,21),f( 5,16,22) /  2.0950400d-02 ,  2.0448200d-02 /
      data f( 5,16,23) /              1.9725900d-02 /
      data f( 5,17, 1),f( 5,17, 2) / -6.0272700d-02 , -6.9298000d-02 /
      data f( 5,17, 3),f( 5,17, 4) / -7.4828900d-02 , -7.4828900d-02 /
      data f( 5,17, 5),f( 5,17, 6) / -6.9298000d-02 , -6.0272700d-02 /
      data f( 5,17, 7),f( 5,17, 8) / -4.8262100d-02 , -3.4112300d-02 /
      data f( 5,17, 9),f( 5,17,10) / -1.8874700d-02 , -3.6596000d-03 /
      data f( 5,17,11),f( 5,17,12) /  1.0328700d-02 ,  1.6907000d-02 /
      data f( 5,17,13),f( 5,17,14) /  1.7605100d-02 ,  1.7606000d-02 /
      data f( 5,17,15),f( 5,17,16) /  1.7553100d-02 ,  1.7595200d-02 /
      data f( 5,17,17),f( 5,17,18) /  1.7739700d-02 ,  1.7942000d-02 /
      data f( 5,17,19),f( 5,17,20) /  1.8142900d-02 ,  1.8289500d-02 /
      data f( 5,17,21),f( 5,17,22) /  1.8289500d-02 ,  1.8142900d-02 /
      data f( 5,17,23) /              1.7942000d-02 /
      data f( 5,18, 1),f( 5,18, 2) / -2.0911500d-02 , -2.5004800d-02 /
      data f( 5,18, 3),f( 5,18, 4) / -2.7553900d-02 , -2.7553900d-02 /
      data f( 5,18, 5),f( 5,18, 6) / -2.5004800d-02 , -2.0911500d-02 /
      data f( 5,18, 7),f( 5,18, 8) / -1.5494900d-02 , -9.0398000d-03 /
      data f( 5,18, 9),f( 5,18,10) / -1.8700000d-03 ,  5.6758000d-03 /
      data f( 5,18,11),f( 5,18,12) /  1.3291800d-02 ,  1.9591400d-02 /
      data f( 5,18,13),f( 5,18,14) /  1.9283100d-02 ,  1.8931400d-02 /
      data f( 5,18,15),f( 5,18,16) /  1.8614700d-02 ,  1.8360900d-02 /
      data f( 5,18,17),f( 5,18,18) /  1.8174300d-02 ,  1.8047400d-02 /
      data f( 5,18,19),f( 5,18,20) /  1.7969100d-02 ,  1.7927200d-02 /
      data f( 5,18,21),f( 5,18,22) /  1.7927200d-02 ,  1.7969100d-02 /
      data f( 5,18,23) /              1.8047400d-02 /
      data f( 5,19, 1),f( 5,19, 2) /  2.1231600d-02 ,  2.1231600d-02 /
      data f( 5,19, 3),f( 5,19, 4) /  2.1231600d-02 ,  2.1231600d-02 /
      data f( 5,19, 5),f( 5,19, 6) /  2.1231600d-02 ,  2.1231600d-02 /
      data f( 5,19, 7),f( 5,19, 8) /  2.1231600d-02 ,  2.1231600d-02 /
      data f( 5,19, 9),f( 5,19,10) /  2.1231600d-02 ,  2.1231600d-02 /
      data f( 5,19,11),f( 5,19,12) /  2.1231600d-02 ,  2.1231600d-02 /
      data f( 5,19,13),f( 5,19,14) /  2.1231600d-02 ,  2.1231600d-02 /
      data f( 5,19,15),f( 5,19,16) /  2.1231600d-02 ,  2.1231600d-02 /
      data f( 5,19,17),f( 5,19,18) /  2.1231600d-02 ,  2.1231600d-02 /
      data f( 5,19,19),f( 5,19,20) /  2.1231600d-02 ,  2.1231600d-02 /
      data f( 5,19,21),f( 5,19,22) /  2.1231600d-02 ,  2.1231600d-02 /
      data f( 5,19,23) /              2.1231600d-02 /
      data f( 6, 1, 1),f( 6, 1, 2) /  1.9664800d-01 ,  1.9664800d-01 /
      data f( 6, 1, 3),f( 6, 1, 4) /  1.9664800d-01 ,  1.9664800d-01 /
      data f( 6, 1, 5),f( 6, 1, 6) /  1.9664800d-01 ,  1.9664800d-01 /
      data f( 6, 1, 7),f( 6, 1, 8) /  1.9664800d-01 ,  1.9664800d-01 /
      data f( 6, 1, 9),f( 6, 1,10) /  1.9664800d-01 ,  1.9664800d-01 /
      data f( 6, 1,11),f( 6, 1,12) /  1.9664800d-01 ,  1.9664800d-01 /
      data f( 6, 1,13),f( 6, 1,14) /  1.9664800d-01 ,  1.9664800d-01 /
      data f( 6, 1,15),f( 6, 1,16) /  1.9664800d-01 ,  1.9664800d-01 /
      data f( 6, 1,17),f( 6, 1,18) /  1.9664800d-01 ,  1.9664800d-01 /
      data f( 6, 1,19),f( 6, 1,20) /  1.9664800d-01 ,  1.9664800d-01 /
      data f( 6, 1,21),f( 6, 1,22) /  1.9664800d-01 ,  1.9664800d-01 /
      data f( 6, 1,23) /              1.9664800d-01 /
      data f( 6, 2, 1),f( 6, 2, 2) /  1.7862430d-01 ,  1.8065300d-01 /
      data f( 6, 2, 3),f( 6, 2, 4) /  1.8219050d-01 ,  1.8219050d-01 /
      data f( 6, 2, 5),f( 6, 2, 6) /  1.8065300d-01 ,  1.7862430d-01 /
      data f( 6, 2, 7),f( 6, 2, 8) /  1.7655280d-01 ,  1.7471390d-01 /
      data f( 6, 2, 9),f( 6, 2,10) /  1.7349470d-01 ,  1.7243540d-01 /
      data f( 6, 2,11),f( 6, 2,12) /  1.7173030d-01 ,  1.7160350d-01 /
      data f( 6, 2,13),f( 6, 2,14) /  1.7176520d-01 ,  1.7250600d-01 /
      data f( 6, 2,15),f( 6, 2,16) /  1.7360320d-01 ,  1.7512470d-01 /
      data f( 6, 2,17),f( 6, 2,18) /  1.7674040d-01 ,  1.7885080d-01 /
      data f( 6, 2,19),f( 6, 2,20) /  1.8090990d-01 ,  1.8246810d-01 /
      data f( 6, 2,21),f( 6, 2,22) /  1.8246810d-01 ,  1.8090990d-01 /
      data f( 6, 2,23) /              1.7885080d-01 /
      data f( 6, 3, 1),f( 6, 3, 2) /  1.6439440d-01 ,  1.8448890d-01 /
      data f( 6, 3, 3),f( 6, 3, 4) /  2.1900910d-01 ,  2.1900910d-01 /
      data f( 6, 3, 5),f( 6, 3, 6) /  1.8448890d-01 ,  1.6439440d-01 /
      data f( 6, 3, 7),f( 6, 3, 8) /  1.0955900d-01 ,  5.6135700d-02 /
      data f( 6, 3, 9),f( 6, 3,10) /  2.3737900d-02 ,  5.0249000d-03 /
      data f( 6, 3,11),f( 6, 3,12) / -6.3180000d-03 , -9.7524000d-03 /
      data f( 6, 3,13),f( 6, 3,14) / -6.1594000d-03 ,  5.3820000d-03 /
      data f( 6, 3,15),f( 6, 3,16) /  2.4441500d-02 ,  5.7293100d-02 /
      data f( 6, 3,17),f( 6, 3,18) /  1.1131190d-01 ,  1.6463400d-01 /
      data f( 6, 3,19),f( 6, 3,20) /  1.8477960d-01 ,  2.1932270d-01 /
      data f( 6, 3,21),f( 6, 3,22) /  2.1932270d-01 ,  1.8477960d-01 /
      data f( 6, 3,23) /              1.6463400d-01 /
      data f( 6, 4, 1),f( 6, 4, 2) /  6.5123000d-02 ,  1.6804510d-01 /
      data f( 6, 4, 3),f( 6, 4, 4) /  2.0802130d-01 ,  2.0802130d-01 /
      data f( 6, 4, 5),f( 6, 4, 6) /  1.6804510d-01 ,  6.5123000d-02 /
      data f( 6, 4, 7),f( 6, 4, 8) / -1.2801400d-02 , -5.3932000d-02 /
      data f( 6, 4, 9),f( 6, 4,10) / -8.0882400d-02 , -9.7786800d-02 /
      data f( 6, 4,11),f( 6, 4,12) / -1.0851710d-01 , -1.1206880d-01 /
      data f( 6, 4,13),f( 6, 4,14) / -1.0897590d-01 , -9.8562300d-02 /
      data f( 6, 4,15),f( 6, 4,16) / -8.1758300d-02 , -5.4476300d-02 /
      data f( 6, 4,17),f( 6, 4,18) / -1.2423200d-02 ,  6.6803800d-02 /
      data f( 6, 4,19),f( 6, 4,20) /  1.6834130d-01 ,  2.0839380d-01 /
      data f( 6, 4,21),f( 6, 4,22) /  2.0839380d-01 ,  1.6834130d-01 /
      data f( 6, 4,23) /              6.6803800d-02 /
      data f( 6, 5, 1),f( 6, 5, 2) / -9.7529000d-03 ,  2.9453400d-02 /
      data f( 6, 5, 3),f( 6, 5, 4) /  7.2230000d-02 ,  7.2230000d-02 /
      data f( 6, 5, 5),f( 6, 5, 6) /  2.9453400d-02 , -9.7529000d-03 /
      data f( 6, 5, 7),f( 6, 5, 8) / -3.9254700d-02 , -6.4834200d-02 /
      data f( 6, 5, 9),f( 6, 5,10) / -8.5217200d-02 , -1.0019640d-01 /
      data f( 6, 5,11),f( 6, 5,12) / -1.0954530d-01 , -1.1315660d-01 /
      data f( 6, 5,13),f( 6, 5,14) / -1.1095500d-01 , -1.0284770d-01 /
      data f( 6, 5,15),f( 6, 5,16) / -8.8718500d-02 , -6.6218100d-02 /
      data f( 6, 5,17),f( 6, 5,18) / -4.1814300d-02 , -7.8358000d-03 /
      data f( 6, 5,19),f( 6, 5,20) /  3.3439300d-02 ,  7.9850700d-02 /
      data f( 6, 5,21),f( 6, 5,22) /  7.9850700d-02 ,  3.3439300d-02 /
      data f( 6, 5,23) /             -7.8358000d-03 /
      data f( 6, 6, 1),f( 6, 6, 2) / -3.3640000d-04 ,  2.0038900d-02 /
      data f( 6, 6, 3),f( 6, 6, 4) /  3.5522900d-02 ,  3.5522900d-02 /
      data f( 6, 6, 5),f( 6, 6, 6) /  2.0038900d-02 , -3.3640000d-04 /
      data f( 6, 6, 7),f( 6, 6, 8) / -2.2409500d-02 , -4.2512000d-02 /
      data f( 6, 6, 9),f( 6, 6,10) / -5.9347700d-02 , -7.2158300d-02 /
      data f( 6, 6,11),f( 6, 6,12) / -8.0548700d-02 , -8.4304600d-02 /
      data f( 6, 6,13),f( 6, 6,14) / -8.3271400d-02 , -7.7370600d-02 /
      data f( 6, 6,15),f( 6, 6,16) / -6.6532800d-02 , -5.0746000d-02 /
      data f( 6, 6,17),f( 6, 6,18) / -3.0199300d-02 , -5.4487000d-03 /
      data f( 6, 6,19),f( 6, 6,20) /  2.2323200d-02 ,  5.1178200d-02 /
      data f( 6, 6,21),f( 6, 6,22) /  5.1178200d-02 ,  2.2323200d-02 /
      data f( 6, 6,23) /             -5.4487000d-03 /
      data f( 6, 7, 1),f( 6, 7, 2) /  1.0839100d-02 ,  2.4979700d-02 /
      data f( 6, 7, 3),f( 6, 7, 4) /  3.8016700d-02 ,  3.8016700d-02 /
      data f( 6, 7, 5),f( 6, 7, 6) /  2.4979700d-02 ,  1.0839100d-02 /
      data f( 6, 7, 7),f( 6, 7, 8) / -3.6127000d-03 , -1.7715600d-02 /
      data f( 6, 7, 9),f( 6, 7,10) / -3.0513400d-02 , -4.1045600d-02 /
      data f( 6, 7,11),f( 6, 7,12) / -4.8563300d-02 , -5.2589200d-02 /
      data f( 6, 7,13),f( 6, 7,14) / -5.2878400d-02 , -4.9355600d-02 /
      data f( 6, 7,15),f( 6, 7,16) / -4.2073000d-02 , -3.1170700d-02 /
      data f( 6, 7,17),f( 6, 7,18) / -1.6961100d-02 , -7.9800000d-05 /
      data f( 6, 7,19),f( 6, 7,20) /  1.8175000d-02 ,  3.4845000d-02 /
      data f( 6, 7,21),f( 6, 7,22) /  3.4845000d-02 ,  1.8175000d-02 /
      data f( 6, 7,23) /             -7.9800000d-05 /
      data f( 6, 8, 1),f( 6, 8, 2) /  1.8469700d-02 ,  2.2643000d-02 /
      data f( 6, 8, 3),f( 6, 8, 4) /  1.1896300d-02 ,  1.1896300d-02 /
      data f( 6, 8, 5),f( 6, 8, 6) /  2.2643000d-02 ,  1.8469700d-02 /
      data f( 6, 8, 7),f( 6, 8, 8) /  1.0968300d-02 ,  2.4066000d-03 /
      data f( 6, 8, 9),f( 6, 8,10) / -6.6857000d-03 , -1.5220900d-02 /
      data f( 6, 8,11),f( 6, 8,12) / -2.2073300d-02 , -2.6473200d-02 /
      data f( 6, 8,13),f( 6, 8,14) / -2.8047200d-02 , -2.6710100d-02 /
      data f( 6, 8,15),f( 6, 8,16) / -2.2581100d-02 , -1.5920400d-02 /
      data f( 6, 8,17),f( 6, 8,18) / -7.1334000d-03 ,  3.1457000d-03 /
      data f( 6, 8,19),f( 6, 8,20) /  1.3828500d-02 ,  2.2827900d-02 /
      data f( 6, 8,21),f( 6, 8,22) /  2.2827900d-02 ,  1.3828500d-02 /
      data f( 6, 8,23) /              3.1457000d-03 /
      data f( 6, 9, 1),f( 6, 9, 2) /  1.2508900d-02 , -9.6611000d-03 /
      data f( 6, 9, 3),f( 6, 9, 4) / -2.5179600d-02 , -2.5179600d-02 /
      data f( 6, 9, 5),f( 6, 9, 6) / -9.6611000d-03 ,  1.2508900d-02 /
      data f( 6, 9, 7),f( 6, 9, 8) /  2.2110600d-02 ,  1.6905200d-02 /
      data f( 6, 9, 9),f( 6, 9,10) /  1.0423600d-02 ,  3.4308000d-03 /
      data f( 6, 9,11),f( 6, 9,12) / -2.8865000d-03 , -7.5678000d-03 /
      data f( 6, 9,13),f( 6, 9,14) / -1.0121200d-02 , -1.0433500d-02 /
      data f( 6, 9,15),f( 6, 9,16) / -8.6172000d-03 , -4.9090000d-03 /
      data f( 6, 9,17),f( 6, 9,18) /  3.6280000d-04 ,  6.7463000d-03 /
      data f( 6, 9,19),f( 6, 9,20) /  1.3541400d-02 ,  1.9377600d-02 /
      data f( 6, 9,21),f( 6, 9,22) /  1.9377600d-02 ,  1.3541400d-02 /
      data f( 6, 9,23) /              6.7463000d-03 /
      data f( 6,10, 1),f( 6,10, 2) / -2.1853100d-02 , -4.8273400d-02 /
      data f( 6,10, 3),f( 6,10, 4) / -6.6202900d-02 , -6.6202900d-02 /
      data f( 6,10, 5),f( 6,10, 6) / -4.8273400d-02 , -2.1853100d-02 /
      data f( 6,10, 7),f( 6,10, 8) /  6.4835000d-03 ,  2.1213600d-02 /
      data f( 6,10, 9),f( 6,10,10) /  1.9832100d-02 ,  1.4862200d-02 /
      data f( 6,10,11),f( 6,10,12) /  9.3576000d-03 ,  4.7639000d-03 /
      data f( 6,10,13),f( 6,10,14) /  1.7525000d-03 ,  5.1530000d-04 /
      data f( 6,10,15),f( 6,10,16) /  9.9790000d-04 ,  3.0372000d-03 /
      data f( 6,10,17),f( 6,10,18) /  6.3899000d-03 ,  1.0740700d-02 /
      data f( 6,10,19),f( 6,10,20) /  1.5683800d-02 ,  2.0294000d-02 /
      data f( 6,10,21),f( 6,10,22) /  2.0294000d-02 ,  1.5683800d-02 /
      data f( 6,10,23) /              1.0740700d-02 /
      data f( 6,11, 1),f( 6,11, 2) / -5.5243400d-02 , -8.1667300d-02 /
      data f( 6,11, 3),f( 6,11, 4) / -9.6444200d-02 , -9.6444200d-02 /
      data f( 6,11, 5),f( 6,11, 6) / -8.1667300d-02 , -5.5243400d-02 /
      data f( 6,11, 7),f( 6,11, 8) / -2.3081000d-02 ,  4.9034000d-03 /
      data f( 6,11, 9),f( 6,11,10) /  1.8448000d-02 ,  1.9238100d-02 /
      data f( 6,11,11),f( 6,11,12) /  1.5747200d-02 ,  1.1897100d-02 /
      data f( 6,11,13),f( 6,11,14) /  9.0394000d-03 ,  7.5794000d-03 /
      data f( 6,11,15),f( 6,11,16) /  7.5742000d-03 ,  8.9281000d-03 /
      data f( 6,11,17),f( 6,11,18) /  1.1418700d-02 ,  1.4773500d-02 /
      data f( 6,11,19),f( 6,11,20) /  1.8811200d-02 ,  2.2986900d-02 /
      data f( 6,11,21),f( 6,11,22) /  2.2986900d-02 ,  1.8811200d-02 /
      data f( 6,11,23) /              1.4773500d-02 /
      data f( 6,12, 1),f( 6,12, 2) / -7.9489000d-02 , -9.6728700d-02 /
      data f( 6,12, 3),f( 6,12, 4) / -9.6076200d-02 , -9.6076200d-02 /
      data f( 6,12, 5),f( 6,12, 6) / -9.6728700d-02 , -7.9489000d-02 /
      data f( 6,12, 7),f( 6,12, 8) / -4.8831100d-02 , -1.6498700d-02 /
      data f( 6,12, 9),f( 6,12,10) /  7.2754000d-03 ,  1.7146700d-02 /
      data f( 6,12,11),f( 6,12,12) /  1.7539600d-02 ,  1.5235800d-02 /
      data f( 6,12,13),f( 6,12,14) /  1.3073200d-02 ,  1.1913900d-02 /
      data f( 6,12,15),f( 6,12,16) /  1.1984600d-02 ,  1.3243500d-02 /
      data f( 6,12,17),f( 6,12,18) /  1.5452000d-02 ,  1.8338000d-02 /
      data f( 6,12,19),f( 6,12,20) /  2.1851600d-02 ,  2.5626900d-02 /
      data f( 6,12,21),f( 6,12,22) /  2.5626900d-02 ,  2.1851600d-02 /
      data f( 6,12,23) /              1.8338000d-02 /
      data f( 6,13, 1),f( 6,13, 2) / -9.0867000d-02 , -9.2581600d-02 /
      data f( 6,13, 3),f( 6,13, 4) / -7.0057600d-02 , -7.0057600d-02 /
      data f( 6,13, 5),f( 6,13, 6) / -9.2581600d-02 , -9.0867000d-02 /
      data f( 6,13, 7),f( 6,13, 8) / -6.6756500d-02 , -3.4721000d-02 /
      data f( 6,13, 9),f( 6,13,10) / -6.3296000d-03 ,  1.0981000d-02 /
      data f( 6,13,11),f( 6,13,12) /  1.6201900d-02 ,  1.5989200d-02 /
      data f( 6,13,13),f( 6,13,14) /  1.4843000d-02 ,  1.4237900d-02 /
      data f( 6,13,15),f( 6,13,16) /  1.4600100d-02 ,  1.5946000d-02 /
      data f( 6,13,17),f( 6,13,18) /  1.8047500d-02 ,  2.0628700d-02 /
      data f( 6,13,19),f( 6,13,20) /  2.3563000d-02 ,  2.6432000d-02 /
      data f( 6,13,21),f( 6,13,22) /  2.6432000d-02 ,  2.3563000d-02 /
      data f( 6,13,23) /              2.0628700d-02 /
      data f( 6,14, 1),f( 6,14, 2) / -9.4372900d-02 , -9.1398200d-02 /
      data f( 6,14, 3),f( 6,14, 4) / -6.8517200d-02 , -6.8517200d-02 /
      data f( 6,14, 5),f( 6,14, 6) / -9.1398200d-02 , -9.4372900d-02 /
      data f( 6,14, 7),f( 6,14, 8) / -7.5590700d-02 , -4.6549300d-02 /
      data f( 6,14, 9),f( 6,14,10) / -1.7644100d-02 ,  3.8398000d-03 /
      data f( 6,14,11),f( 6,14,12) /  1.3447200d-02 ,  1.5304400d-02 /
      data f( 6,14,13),f( 6,14,14) /  1.5160800d-02 ,  1.5072800d-02 /
      data f( 6,14,15),f( 6,14,16) /  1.5630100d-02 ,  1.6911000d-02 /
      data f( 6,14,17),f( 6,14,18) /  1.8738200d-02 ,  2.0840500d-02 /
      data f( 6,14,19),f( 6,14,20) /  2.2962200d-02 ,  2.4713400d-02 /
      data f( 6,14,21),f( 6,14,22) /  2.4713400d-02 ,  2.2962200d-02 /
      data f( 6,14,23) /              2.0840500d-02 /
      data f( 6,15, 1),f( 6,15, 2) / -9.3157100d-02 , -9.8997900d-02 /
      data f( 6,15, 3),f( 6,15, 4) / -9.4575000d-02 , -9.4575000d-02 /
      data f( 6,15, 5),f( 6,15, 6) / -9.8997900d-02 , -9.3157100d-02 /
      data f( 6,15, 7),f( 6,15, 8) / -7.5121800d-02 , -4.9927900d-02 /
      data f( 6,15, 9),f( 6,15,10) / -2.3692600d-02 , -1.6814000d-03 /
      data f( 6,15,11),f( 6,15,12) /  1.0849300d-02 ,  1.4284500d-02 /
      data f( 6,15,13),f( 6,15,14) /  1.4827900d-02 ,  1.5017300d-02 /
      data f( 6,15,15),f( 6,15,16) /  1.5527600d-02 ,  1.6480100d-02 /
      data f( 6,15,17),f( 6,15,18) /  1.7770700d-02 ,  1.9188300d-02 /
      data f( 6,15,19),f( 6,15,20) /  2.0493400d-02 ,  2.1435700d-02 /
      data f( 6,15,21),f( 6,15,22) /  2.1435700d-02 ,  2.0493400d-02 /
      data f( 6,15,23) /              1.9188300d-02 /
      data f( 6,16, 1),f( 6,16, 2) / -8.0159100d-02 , -9.1260800d-02 /
      data f( 6,16, 3),f( 6,16, 4) / -9.6857400d-02 , -9.6857400d-02 /
      data f( 6,16, 5),f( 6,16, 6) / -9.1260800d-02 , -8.0159100d-02 /
      data f( 6,16, 7),f( 6,16, 8) / -6.3620400d-02 , -4.3495300d-02 /
      data f( 6,16, 9),f( 6,16,10) / -2.2414400d-02 , -3.2077000d-03 /
      data f( 6,16,11),f( 6,16,12) /  9.7844000d-03 ,  1.3872800d-02 /
      data f( 6,16,13),f( 6,16,14) /  1.4597200d-02 ,  1.4767700d-02 /
      data f( 6,16,15),f( 6,16,16) /  1.5023500d-02 ,  1.5500200d-02 /
      data f( 6,16,17),f( 6,16,18) /  1.6157400d-02 ,  1.6878800d-02 /
      data f( 6,16,19),f( 6,16,20) /  1.7526000d-02 ,  1.7973200d-02 /
      data f( 6,16,21),f( 6,16,22) /  1.7973200d-02 ,  1.7526000d-02 /
      data f( 6,16,23) /              1.6878800d-02 /
      data f( 6,17, 1),f( 6,17, 2) / -5.1918600d-02 , -6.0568700d-02 /
      data f( 6,17, 3),f( 6,17, 4) / -6.5919300d-02 , -6.5919300d-02 /
      data f( 6,17, 5),f( 6,17, 6) / -6.0568700d-02 , -5.1918600d-02 /
      data f( 6,17, 7),f( 6,17, 8) / -4.0525800d-02 , -2.7242000d-02 /
      data f( 6,17, 9),f( 6,17,10) / -1.3096700d-02 ,  7.8200000d-04 /
      data f( 6,17,11),f( 6,17,12) /  1.2403200d-02 ,  1.4822500d-02 /
      data f( 6,17,13),f( 6,17,14) /  1.5088200d-02 ,  1.4993200d-02 /
      data f( 6,17,15),f( 6,17,16) /  1.4909600d-02 ,  1.4930200d-02 /
      data f( 6,17,17),f( 6,17,18) /  1.5050600d-02 ,  1.5226700d-02 /
      data f( 6,17,19),f( 6,17,20) /  1.5404000d-02 ,  1.5533900d-02 /
      data f( 6,17,21),f( 6,17,22) /  1.5533900d-02 ,  1.5404000d-02 /
      data f( 6,17,23) /              1.5226700d-02 /
      data f( 6,18, 1),f( 6,18, 2) / -1.4579000d-02 , -1.8402600d-02 /
      data f( 6,18, 3),f( 6,18, 4) / -2.0787900d-02 , -2.0787900d-02 /
      data f( 6,18, 5),f( 6,18, 6) / -1.8402600d-02 , -1.4579000d-02 /
      data f( 6,18, 7),f( 6,18, 8) / -9.5320000d-03 , -3.5370000d-03 /
      data f( 6,18, 9),f( 6,18,10) /  3.0338000d-03 ,  1.0046200d-02 /
      data f( 6,18,11),f( 6,18,12) /  1.6999300d-02 ,  1.7036900d-02 /
      data f( 6,18,13),f( 6,18,14) /  1.6619300d-02 ,  1.6230700d-02 /
      data f( 6,18,15),f( 6,18,16) /  1.5904400d-02 ,  1.5650500d-02 /
      data f( 6,18,17),f( 6,18,18) /  1.5465700d-02 ,  1.5340500d-02 /
      data f( 6,18,19),f( 6,18,20) /  1.5262800d-02 ,  1.5221100d-02 /
      data f( 6,18,21),f( 6,18,22) /  1.5221100d-02 ,  1.5262800d-02 /
      data f( 6,18,23) /              1.5340500d-02 /
      data f( 6,19, 1),f( 6,19, 2) /  1.8326600d-02 ,  1.8326600d-02 /
      data f( 6,19, 3),f( 6,19, 4) /  1.8326600d-02 ,  1.8326600d-02 /
      data f( 6,19, 5),f( 6,19, 6) /  1.8326600d-02 ,  1.8326600d-02 /
      data f( 6,19, 7),f( 6,19, 8) /  1.8326600d-02 ,  1.8326600d-02 /
      data f( 6,19, 9),f( 6,19,10) /  1.8326600d-02 ,  1.8326600d-02 /
      data f( 6,19,11),f( 6,19,12) /  1.8326600d-02 ,  1.8326600d-02 /
      data f( 6,19,13),f( 6,19,14) /  1.8326600d-02 ,  1.8326600d-02 /
      data f( 6,19,15),f( 6,19,16) /  1.8326600d-02 ,  1.8326600d-02 /
      data f( 6,19,17),f( 6,19,18) /  1.8326600d-02 ,  1.8326600d-02 /
      data f( 6,19,19),f( 6,19,20) /  1.8326600d-02 ,  1.8326600d-02 /
      data f( 6,19,21),f( 6,19,22) /  1.8326600d-02 ,  1.8326600d-02 /
      data f( 6,19,23) /              1.8326600d-02 /
      data f( 7, 1, 1),f( 7, 1, 2) /  1.8197540d-01 ,  1.8197540d-01 /
      data f( 7, 1, 3),f( 7, 1, 4) /  1.8197540d-01 ,  1.8197540d-01 /
      data f( 7, 1, 5),f( 7, 1, 6) /  1.8197540d-01 ,  1.8197540d-01 /
      data f( 7, 1, 7),f( 7, 1, 8) /  1.8197540d-01 ,  1.8197540d-01 /
      data f( 7, 1, 9),f( 7, 1,10) /  1.8197540d-01 ,  1.8197540d-01 /
      data f( 7, 1,11),f( 7, 1,12) /  1.8197540d-01 ,  1.8197540d-01 /
      data f( 7, 1,13),f( 7, 1,14) /  1.8197540d-01 ,  1.8197540d-01 /
      data f( 7, 1,15),f( 7, 1,16) /  1.8197540d-01 ,  1.8197540d-01 /
      data f( 7, 1,17),f( 7, 1,18) /  1.8197540d-01 ,  1.8197540d-01 /
      data f( 7, 1,19),f( 7, 1,20) /  1.8197540d-01 ,  1.8197540d-01 /
      data f( 7, 1,21),f( 7, 1,22) /  1.8197540d-01 ,  1.8197540d-01 /
      data f( 7, 1,23) /              1.8197540d-01 /
      data f( 7, 2, 1),f( 7, 2, 2) /  1.6983740d-01 ,  1.7185680d-01 /
      data f( 7, 2, 3),f( 7, 2, 4) /  1.7340720d-01 ,  1.7340720d-01 /
      data f( 7, 2, 5),f( 7, 2, 6) /  1.7185680d-01 ,  1.6983740d-01 /
      data f( 7, 2, 7),f( 7, 2, 8) /  1.6780000d-01 ,  1.6601730d-01 /
      data f( 7, 2, 9),f( 7, 2,10) /  1.6485940d-01 ,  1.6385110d-01 /
      data f( 7, 2,11),f( 7, 2,12) /  1.6325310d-01 ,  1.6306380d-01 /
      data f( 7, 2,13),f( 7, 2,14) /  1.6328700d-01 ,  1.6392150d-01 /
      data f( 7, 2,15),f( 7, 2,16) /  1.6496670d-01 ,  1.6616410d-01 /
      data f( 7, 2,17),f( 7, 2,18) /  1.6798510d-01 ,  1.7005830d-01 /
      data f( 7, 2,19),f( 7, 2,20) /  1.7210880d-01 ,  1.7367870d-01 /
      data f( 7, 2,21),f( 7, 2,22) /  1.7367870d-01 ,  1.7210880d-01 /
      data f( 7, 2,23) /              1.7005830d-01 /
      data f( 7, 3, 1),f( 7, 3, 2) /  1.6271430d-01 ,  1.8535110d-01 /
      data f( 7, 3, 3),f( 7, 3, 4) /  2.2837750d-01 ,  2.2837750d-01 /
      data f( 7, 3, 5),f( 7, 3, 6) /  1.8535110d-01 ,  1.6271430d-01 /
      data f( 7, 3, 7),f( 7, 3, 8) /  8.5237000d-02 ,  3.3060000d-02 /
      data f( 7, 3, 9),f( 7, 3,10) /  1.8163000d-03 , -1.6994200d-02 /
      data f( 7, 3,11),f( 7, 3,12) / -2.7396500d-02 , -3.0730800d-02 /
      data f( 7, 3,13),f( 7, 3,14) / -2.7257100d-02 , -1.6630200d-02 /
      data f( 7, 3,15),f( 7, 3,16) /  2.5177000d-03 ,  3.4216400d-02 /
      data f( 7, 3,17),f( 7, 3,18) /  8.9560000d-02 ,  1.6295160d-01 /
      data f( 7, 3,19),f( 7, 3,20) /  1.8563380d-01 ,  2.2867670d-01 /
      data f( 7, 3,21),f( 7, 3,22) /  2.2867670d-01 ,  1.8563380d-01 /
      data f( 7, 3,23) /              1.6295160d-01 /
      data f( 7, 4, 1),f( 7, 4, 2) /  6.5989900d-02 ,  1.6983520d-01 /
      data f( 7, 4, 3),f( 7, 4, 4) /  2.1851060d-01 ,  2.1851060d-01 /
      data f( 7, 4, 5),f( 7, 4, 6) /  1.6983520d-01 ,  6.5989900d-02 /
      data f( 7, 4, 7),f( 7, 4, 8) / -1.6088600d-02 , -5.5189400d-02 /
      data f( 7, 4, 9),f( 7, 4,10) / -8.0977200d-02 , -9.7997400d-02 /
      data f( 7, 4,11),f( 7, 4,12) / -1.0803260d-01 , -1.1151180d-01 /
      data f( 7, 4,13),f( 7, 4,14) / -1.0848490d-01 , -9.8786400d-02 /
      data f( 7, 4,15),f( 7, 4,16) / -8.1845400d-02 , -5.5624300d-02 /
      data f( 7, 4,17),f( 7, 4,18) / -1.3265500d-02 ,  6.7618300d-02 /
      data f( 7, 4,19),f( 7, 4,20) /  1.7012010d-01 ,  2.1886380d-01 /
      data f( 7, 4,21),f( 7, 4,22) /  2.1886380d-01 ,  1.7012010d-01 /
      data f( 7, 4,23) /              6.7618300d-02 /
      data f( 7, 5, 1),f( 7, 5, 2) / -7.1186000d-03 ,  3.2320300d-02 /
      data f( 7, 5, 3),f( 7, 5, 4) /  7.6401600d-02 ,  7.6401600d-02 /
      data f( 7, 5, 5),f( 7, 5, 6) /  3.2320300d-02 , -7.1186000d-03 /
      data f( 7, 5, 7),f( 7, 5, 8) / -3.6391000d-02 , -6.1487700d-02 /
      data f( 7, 5, 9),f( 7, 5,10) / -8.1426500d-02 , -9.6058400d-02 /
      data f( 7, 5,11),f( 7, 5,12) / -1.0518530d-01 , -1.0871870d-01 /
      data f( 7, 5,13),f( 7, 5,14) / -1.0659130d-01 , -9.8709600d-02 /
      data f( 7, 5,15),f( 7, 5,16) / -8.4947800d-02 , -6.5181900d-02 /
      data f( 7, 5,17),f( 7, 5,18) / -3.9100300d-02 , -5.4369000d-03 /
      data f( 7, 5,19),f( 7, 5,20) /  3.6028000d-02 ,  8.3703400d-02 /
      data f( 7, 5,21),f( 7, 5,22) /  8.3703400d-02 ,  3.6028000d-02 /
      data f( 7, 5,23) /             -5.4369000d-03 /
      data f( 7, 6, 1),f( 7, 6, 2) /  1.4861000d-03 ,  2.2526000d-02 /
      data f( 7, 6, 3),f( 7, 6, 4) /  3.8452500d-02 ,  3.8452500d-02 /
      data f( 7, 6, 5),f( 7, 6, 6) /  2.2526000d-02 ,  1.4861000d-03 /
      data f( 7, 6, 7),f( 7, 6, 8) / -2.0160400d-02 , -3.9684100d-02 /
      data f( 7, 6, 9),f( 7, 6,10) / -5.5958700d-02 , -6.8322400d-02 /
      data f( 7, 6,11),f( 7, 6,12) / -7.6417500d-02 , -8.0042600d-02 /
      data f( 7, 6,13),f( 7, 6,14) / -7.9073000d-02 , -7.3412500d-02 /
      data f( 7, 6,15),f( 7, 6,16) / -6.3006900d-02 , -4.7810100d-02 /
      data f( 7, 6,17),f( 7, 6,18) / -2.7980900d-02 , -4.0267000d-03 /
      data f( 7, 6,19),f( 7, 6,20) /  2.3004700d-02 ,  5.1487000d-02 /
      data f( 7, 6,21),f( 7, 6,22) /  5.1487000d-02 ,  2.3004700d-02 /
      data f( 7, 6,23) /             -4.0267000d-03 /
      data f( 7, 7, 1),f( 7, 7, 2) /  1.0562900d-02 ,  2.3908900d-02 /
      data f( 7, 7, 3),f( 7, 7, 4) /  3.6166100d-02 ,  3.6166100d-02 /
      data f( 7, 7, 5),f( 7, 7, 6) /  2.3908900d-02 ,  1.0562900d-02 /
      data f( 7, 7, 7),f( 7, 7, 8) / -3.1349000d-03 , -1.6475500d-02 /
      data f( 7, 7, 9),f( 7, 7,10) / -2.8566000d-02 , -3.8523300d-02 /
      data f( 7, 7,11),f( 7, 7,12) / -4.5649200d-02 , -4.9486200d-02 /
      data f( 7, 7,13),f( 7, 7,14) / -4.9792200d-02 , -4.6492000d-02 /
      data f( 7, 7,15),f( 7, 7,16) / -3.9627600d-02 , -2.9343600d-02 /
      data f( 7, 7,17),f( 7, 7,18) / -1.5949700d-02 , -9.1200000d-05 /
      data f( 7, 7,19),f( 7, 7,20) /  1.6898400d-02 ,  3.2059600d-02 /
      data f( 7, 7,21),f( 7, 7,22) /  3.2059600d-02 ,  1.6898400d-02 /
      data f( 7, 7,23) /             -9.1200000d-05 /
      data f( 7, 8, 1),f( 7, 8, 2) /  1.6781500d-02 ,  2.2601200d-02 /
      data f( 7, 8, 3),f( 7, 8, 4) /  1.6014000d-02 ,  1.6014000d-02 /
      data f( 7, 8, 5),f( 7, 8, 6) /  2.2601200d-02 ,  1.6781500d-02 /
      data f( 7, 8, 7),f( 7, 8, 8) /  9.8805000d-03 ,  2.0048000d-03 /
      data f( 7, 8, 9),f( 7, 8,10) / -6.3585000d-03 , -1.4232600d-02 /
      data f( 7, 8,11),f( 7, 8,12) / -2.0589100d-02 , -2.4705300d-02 /
      data f( 7, 8,13),f( 7, 8,14) / -2.6209000d-02 , -2.5008700d-02 /
      data f( 7, 8,15),f( 7, 8,16) / -2.1205700d-02 , -1.5045900d-02 /
      data f( 7, 8,17),f( 7, 8,18) / -6.9230000d-03 ,  2.5377000d-03 /
      data f( 7, 8,19),f( 7, 8,20) /  1.2263000d-02 ,  2.0289400d-02 /
      data f( 7, 8,21),f( 7, 8,22) /  2.0289400d-02 ,  1.2263000d-02 /
      data f( 7, 8,23) /              2.5377000d-03 /
      data f( 7, 9, 1),f( 7, 9, 2) /  1.6648700d-02 , -3.8864000d-03 /
      data f( 7, 9, 3),f( 7, 9, 4) / -1.8513000d-02 , -1.8513000d-02 /
      data f( 7, 9, 5),f( 7, 9, 6) / -3.8864000d-03 ,  1.6648700d-02 /
      data f( 7, 9, 7),f( 7, 9, 8) /  1.9292800d-02 ,  1.4825300d-02 /
      data f( 7, 9, 9),f( 7, 9,10) /  9.1309000d-03 ,  2.8917000d-03 /
      data f( 7, 9,11),f( 7, 9,12) / -2.8176000d-03 , -7.1000000d-03 /
      data f( 7, 9,13),f( 7, 9,14) / -9.4712000d-03 , -9.7975000d-03 /
      data f( 7, 9,15),f( 7, 9,16) / -8.1668000d-03 , -4.7900000d-03 /
      data f( 7, 9,17),f( 7, 9,18) /  1.7200000d-05 ,  5.8080000d-03 /
      data f( 7, 9,19),f( 7, 9,20) /  1.1879000d-02 ,  1.6954200d-02 /
      data f( 7, 9,21),f( 7, 9,22) /  1.6954200d-02 ,  1.1879000d-02 /
      data f( 7, 9,23) /              5.8080000d-03 /
      data f( 7,10, 1),f( 7,10, 2) / -1.5495100d-02 , -4.0084800d-02 /
      data f( 7,10, 3),f( 7,10, 4) / -5.7133100d-02 , -5.7133100d-02 /
      data f( 7,10, 5),f( 7,10, 6) / -4.0084800d-02 , -1.5495100d-02 /
      data f( 7,10, 7),f( 7,10, 8) /  9.0965000d-03 ,  1.8528000d-02 /
      data f( 7,10, 9),f( 7,10,10) /  1.7195900d-02 ,  1.2993100d-02 /
      data f( 7,10,11),f( 7,10,12) /  8.1922000d-03 ,  4.0979000d-03 /
      data f( 7,10,13),f( 7,10,14) /  1.3744000d-03 ,  2.4010000d-04 /
      data f( 7,10,15),f( 7,10,16) /  6.7100000d-04 ,  2.5281000d-03 /
      data f( 7,10,17),f( 7,10,18) /  5.5845000d-03 ,  9.5164000d-03 /
      data f( 7,10,19),f( 7,10,20) /  1.3868900d-02 ,  1.7750800d-02 /
      data f( 7,10,21),f( 7,10,22) /  1.7750800d-02 ,  1.3868900d-02 /
      data f( 7,10,23) /              9.5164000d-03 /
      data f( 7,11, 1),f( 7,11, 2) / -4.6896100d-02 , -7.2227900d-02 /
      data f( 7,11, 3),f( 7,11, 4) / -8.7318200d-02 , -8.7318200d-02 /
      data f( 7,11, 5),f( 7,11, 6) / -7.2227900d-02 , -4.6896100d-02 /
      data f( 7,11, 7),f( 7,11, 8) / -1.7497500d-02 ,  6.0438000d-03 /
      data f( 7,11, 9),f( 7,11,10) /  1.6124100d-02 ,  1.6619700d-02 /
      data f( 7,11,11),f( 7,11,12) /  1.3703200d-02 ,  1.0377200d-02 /
      data f( 7,11,13),f( 7,11,14) /  7.8597000d-03 ,  6.5681000d-03 /
      data f( 7,11,15),f( 7,11,16) /  6.5867000d-03 ,  7.8477000d-03 /
      data f( 7,11,17),f( 7,11,18) /  1.0150800d-02 ,  1.3202800d-02 /
      data f( 7,11,19),f( 7,11,20) /  1.6712500d-02 ,  2.0086100d-02 /
      data f( 7,11,21),f( 7,11,22) /  2.0086100d-02 ,  1.6712500d-02 /
      data f( 7,11,23) /              1.3202800d-02 /
      data f( 7,12, 1),f( 7,12, 2) / -7.0410300d-02 , -8.9141900d-02 /
      data f( 7,12, 3),f( 7,12, 4) / -9.2981700d-02 , -9.2981700d-02 /
      data f( 7,12, 5),f( 7,12, 6) / -8.9141900d-02 , -7.0410300d-02 /
      data f( 7,12, 7),f( 7,12, 8) / -4.1348700d-02 , -1.2484100d-02 /
      data f( 7,12, 9),f( 7,12,10) /  7.1917000d-03 ,  1.4816800d-02 /
      data f( 7,12,11),f( 7,12,12) /  1.5110200d-02 ,  1.3186600d-02 /
      data f( 7,12,13),f( 7,12,14) /  1.1333000d-02 ,  1.0339600d-02 /
      data f( 7,12,15),f( 7,12,16) /  1.0442000d-02 ,  1.1626100d-02 /
      data f( 7,12,17),f( 7,12,18) /  1.3682000d-02 ,  1.6308600d-02 /
      data f( 7,12,19),f( 7,12,20) /  1.9305600d-02 ,  2.2232600d-02 /
      data f( 7,12,21),f( 7,12,22) /  2.2232600d-02 ,  1.9305600d-02 /
      data f( 7,12,23) /              1.6308600d-02 /
      data f( 7,13, 1),f( 7,13, 2) / -8.2478700d-02 , -8.9521400d-02 /
      data f( 7,13, 3),f( 7,13, 4) / -7.7427100d-02 , -7.7427100d-02 /
      data f( 7,13, 5),f( 7,13, 6) / -8.9521400d-02 , -8.2478700d-02 /
      data f( 7,13, 7),f( 7,13, 8) / -5.8270400d-02 , -2.8796500d-02 /
      data f( 7,13, 9),f( 7,13,10) / -4.1231000d-03 ,  9.8196000d-03 /
      data f( 7,13,11),f( 7,13,12) /  1.3885300d-02 ,  1.3721800d-02 /
      data f( 7,13,13),f( 7,13,14) /  1.2771100d-02 ,  1.2277100d-02 /
      data f( 7,13,15),f( 7,13,16) /  1.2637700d-02 ,  1.3886200d-02 /
      data f( 7,13,17),f( 7,13,18) /  1.5819700d-02 ,  1.8140100d-02 /
      data f( 7,13,19),f( 7,13,20) /  2.0615900d-02 ,  2.2832700d-02 /
      data f( 7,13,21),f( 7,13,22) /  2.2832700d-02 ,  2.0615900d-02 /
      data f( 7,13,23) /              1.8140100d-02 /
      data f( 7,14, 1),f( 7,14, 2) / -8.6436500d-02 , -8.9369400d-02 /
      data f( 7,14, 3),f( 7,14, 4) / -7.6427300d-02 , -7.6427300d-02 /
      data f( 7,14, 5),f( 7,14, 6) / -8.9369400d-02 , -8.6436500d-02 /
      data f( 7,14, 7),f( 7,14, 8) / -6.6705300d-02 , -3.9465200d-02 /
      data f( 7,14, 9),f( 7,14,10) / -1.3652200d-02 ,  4.2155000d-03 /
      data f( 7,14,11),f( 7,14,12) /  1.1598300d-02 ,  1.3055600d-02 /
      data f( 7,14,13),f( 7,14,14) /  1.2951800d-02 ,  1.2903100d-02 /
      data f( 7,14,15),f( 7,14,16) /  1.3425300d-02 ,  1.4596800d-02 /
      data f( 7,14,17),f( 7,14,18) /  1.6257100d-02 ,  1.8136600d-02 /
      data f( 7,14,19),f( 7,14,20) /  1.9960700d-02 ,  2.1388400d-02 /
      data f( 7,14,21),f( 7,14,22) /  2.1388400d-02 ,  1.9960700d-02 /
      data f( 7,14,23) /              1.8136600d-02 /
      data f( 7,15, 1),f( 7,15, 2) / -8.4294000d-02 , -9.2678900d-02 /
      data f( 7,15, 3),f( 7,15, 4) / -9.2199400d-02 , -9.2199400d-02 /
      data f( 7,15, 5),f( 7,15, 6) / -9.2678900d-02 , -8.4294000d-02 /
      data f( 7,15, 7),f( 7,15, 8) / -6.6054700d-02 , -4.2326600d-02 /
      data f( 7,15, 9),f( 7,15,10) / -1.8551600d-02 ,  1.7760000d-04 /
      data f( 7,15,11),f( 7,15,12) /  9.6786000d-03 ,  1.2182000d-02 /
      data f( 7,15,13),f( 7,15,14) /  1.2604400d-02 ,  1.2775900d-02 /
      data f( 7,15,15),f( 7,15,16) /  1.3240000d-02 ,  1.4104300d-02 /
      data f( 7,15,17),f( 7,15,18) /  1.5272100d-02 ,  1.6546300d-02 /
      data f( 7,15,19),f( 7,15,20) /  1.7701600d-02 ,  1.8518600d-02 /
      data f( 7,15,21),f( 7,15,22) /  1.8518600d-02 ,  1.7701600d-02 /
      data f( 7,15,23) /              1.6546300d-02 /
      data f( 7,16, 1),f( 7,16, 2) / -7.0671500d-02 , -8.1809500d-02 /
      data f( 7,16, 3),f( 7,16, 4) / -8.7844000d-02 , -8.7844000d-02 /
      data f( 7,16, 5),f( 7,16, 6) / -8.1809500d-02 , -7.0671500d-02 /
      data f( 7,16, 7),f( 7,16, 8) / -5.4793300d-02 , -3.5985000d-02 /
      data f( 7,16, 9),f( 7,16,10) / -1.6765100d-02 , -2.7960000d-04 /
      data f( 7,16,11),f( 7,16,12) /  9.3928000d-03 ,  1.1932200d-02 /
      data f( 7,16,13),f( 7,16,14) /  1.2403700d-02 ,  1.2518600d-02 /
      data f( 7,16,15),f( 7,16,16) /  1.2737000d-02 ,  1.3161400d-02 /
      data f( 7,16,17),f( 7,16,18) /  1.3751700d-02 ,  1.4400700d-02 /
      data f( 7,16,19),f( 7,16,20) /  1.4981800d-02 ,  1.5381700d-02 /
      data f( 7,16,21),f( 7,16,22) /  1.5381700d-02 ,  1.4981800d-02 /
      data f( 7,16,23) /              1.4400700d-02 /
      data f( 7,17, 1),f( 7,17, 2) / -4.3439300d-02 , -5.1590400d-02 /
      data f( 7,17, 3),f( 7,17, 4) / -5.6671600d-02 , -5.6671600d-02 /
      data f( 7,17, 5),f( 7,17, 6) / -5.1590400d-02 , -4.3439300d-02 /
      data f( 7,17, 7),f( 7,17, 8) / -3.2786600d-02 , -2.0489600d-02 /
      data f( 7,17, 9),f( 7,17,10) / -7.5619000d-03 ,  4.7487000d-03 /
      data f( 7,17,11),f( 7,17,12) /  1.1860600d-02 ,  1.2875900d-02 /
      data f( 7,17,13),f( 7,17,14) /  1.2890800d-02 ,  1.2732000d-02 /
      data f( 7,17,15),f( 7,17,16) /  1.2625400d-02 ,  1.2627100d-02 /
      data f( 7,17,17),f( 7,17,18) /  1.2725200d-02 ,  1.2877300d-02 /
      data f( 7,17,19),f( 7,17,20) /  1.3033000d-02 ,  1.3147700d-02 /
      data f( 7,17,21),f( 7,17,22) /  1.3147700d-02 ,  1.3033000d-02 /
      data f( 7,17,23) /              1.2877300d-02 /
      data f( 7,18, 1),f( 7,18, 2) / -8.3750000d-03 , -1.1906100d-02 /
      data f( 7,18, 3),f( 7,18, 4) / -1.4112700d-02 , -1.4112700d-02 /
      data f( 7,18, 5),f( 7,18, 6) / -1.1906100d-02 , -8.3750000d-03 /
      data f( 7,18, 7),f( 7,18, 8) / -3.7259000d-03 ,  1.7785000d-03 /
      data f( 7,18, 9),f( 7,18,10) /  7.8376000d-03 ,  1.4150500d-02 /
      data f( 7,18,11),f( 7,18,12) /  1.5254300d-02 ,  1.4753700d-02 /
      data f( 7,18,13),f( 7,18,14) /  1.4287800d-02 ,  1.3885400d-02 /
      data f( 7,18,15),f( 7,18,16) /  1.3558700d-02 ,  1.3308300d-02 /
      data f( 7,18,17),f( 7,18,18) /  1.3127100d-02 ,  1.3004300d-02 /
      data f( 7,18,19),f( 7,18,20) /  1.2927400d-02 ,  1.2886000d-02 /
      data f( 7,18,21),f( 7,18,22) /  1.2886000d-02 ,  1.2927400d-02 /
      data f( 7,18,23) /              1.3004300d-02 /
      data f( 7,19, 1),f( 7,19, 2) /  1.5803000d-02 ,  1.5803000d-02 /
      data f( 7,19, 3),f( 7,19, 4) /  1.5803000d-02 ,  1.5803000d-02 /
      data f( 7,19, 5),f( 7,19, 6) /  1.5803000d-02 ,  1.5803000d-02 /
      data f( 7,19, 7),f( 7,19, 8) /  1.5803000d-02 ,  1.5803000d-02 /
      data f( 7,19, 9),f( 7,19,10) /  1.5803000d-02 ,  1.5803000d-02 /
      data f( 7,19,11),f( 7,19,12) /  1.5803000d-02 ,  1.5803000d-02 /
      data f( 7,19,13),f( 7,19,14) /  1.5803000d-02 ,  1.5803000d-02 /
      data f( 7,19,15),f( 7,19,16) /  1.5803000d-02 ,  1.5803000d-02 /
      data f( 7,19,17),f( 7,19,18) /  1.5803000d-02 ,  1.5803000d-02 /
      data f( 7,19,19),f( 7,19,20) /  1.5803000d-02 ,  1.5803000d-02 /
      data f( 7,19,21),f( 7,19,22) /  1.5803000d-02 ,  1.5803000d-02 /
      data f( 7,19,23) /              1.5803000d-02 /
      data f( 8, 1, 1),f( 8, 1, 2) /  1.7124780d-01 ,  1.7124780d-01 /
      data f( 8, 1, 3),f( 8, 1, 4) /  1.7124780d-01 ,  1.7124780d-01 /
      data f( 8, 1, 5),f( 8, 1, 6) /  1.7124780d-01 ,  1.7124780d-01 /
      data f( 8, 1, 7),f( 8, 1, 8) /  1.7124780d-01 ,  1.7124780d-01 /
      data f( 8, 1, 9),f( 8, 1,10) /  1.7124780d-01 ,  1.7124780d-01 /
      data f( 8, 1,11),f( 8, 1,12) /  1.7124780d-01 ,  1.7124780d-01 /
      data f( 8, 1,13),f( 8, 1,14) /  1.7124780d-01 ,  1.7124780d-01 /
      data f( 8, 1,15),f( 8, 1,16) /  1.7124780d-01 ,  1.7124780d-01 /
      data f( 8, 1,17),f( 8, 1,18) /  1.7124780d-01 ,  1.7124780d-01 /
      data f( 8, 1,19),f( 8, 1,20) /  1.7124780d-01 ,  1.7124780d-01 /
      data f( 8, 1,21),f( 8, 1,22) /  1.7124780d-01 ,  1.7124780d-01 /
      data f( 8, 1,23) /              1.7124780d-01 /
      data f( 8, 2, 1),f( 8, 2, 2) /  1.6315670d-01 ,  1.6512880d-01 /
      data f( 8, 2, 3),f( 8, 2, 4) /  1.6665460d-01 ,  1.6665460d-01 /
      data f( 8, 2, 5),f( 8, 2, 6) /  1.6512880d-01 ,  1.6315670d-01 /
      data f( 8, 2, 7),f( 8, 2, 8) /  1.6118880d-01 ,  1.5948920d-01 /
      data f( 8, 2, 9),f( 8, 2,10) /  1.4728570d-01 ,  1.4045290d-01 /
      data f( 8, 2,11),f( 8, 2,12) /  1.3473520d-01 ,  1.3298460d-01 /
      data f( 8, 2,13),f( 8, 2,14) /  1.3507380d-01 ,  1.4106300d-01 /
      data f( 8, 2,15),f( 8, 2,16) /  1.4836070d-01 ,  1.5963430d-01 /
      data f( 8, 2,17),f( 8, 2,18) /  1.6137370d-01 ,  1.6337410d-01 /
      data f( 8, 2,19),f( 8, 2,20) /  1.6537130d-01 ,  1.6691840d-01 /
      data f( 8, 2,21),f( 8, 2,22) /  1.6691840d-01 ,  1.6537130d-01 /
      data f( 8, 2,23) /              1.6337410d-01 /
      data f( 8, 3, 1),f( 8, 3, 2) /  1.6104990d-01 ,  1.8500790d-01 /
      data f( 8, 3, 3),f( 8, 3, 4) /  2.3366060d-01 ,  2.3366060d-01 /
      data f( 8, 3, 5),f( 8, 3, 6) /  1.8500790d-01 ,  1.6104990d-01 /
      data f( 8, 3, 7),f( 8, 3, 8) /  6.6961800d-02 ,  1.5518900d-02 /
      data f( 8, 3, 9),f( 8, 3,10) / -1.4701400d-02 , -3.2769700d-02 /
      data f( 8, 3,11),f( 8, 3,12) / -4.2744300d-02 , -4.5915600d-02 /
      data f( 8, 3,13),f( 8, 3,14) / -4.5115600d-02 , -3.2405400d-02 /
      data f( 8, 3,15),f( 8, 3,16) / -1.3997100d-02 ,  1.6721200d-02 /
      data f( 8, 3,17),f( 8, 3,18) /  6.8723800d-02 ,  1.6128470d-01 /
      data f( 8, 3,19),f( 8, 3,20) /  1.8528530d-01 ,  2.3395070d-01 /
      data f( 8, 3,21),f( 8, 3,22) /  2.3395070d-01 ,  1.8528530d-01 /
      data f( 8, 3,23) /              1.6128470d-01 /
      data f( 8, 4, 1),f( 8, 4, 2) /  6.5214500d-02 ,  1.7053020d-01 /
      data f( 8, 4, 3),f( 8, 4, 4) /  2.2470520d-01 ,  2.2470520d-01 /
      data f( 8, 4, 5),f( 8, 4, 6) /  1.7053020d-01 ,  6.5214500d-02 /
      data f( 8, 4, 7),f( 8, 4, 8) / -1.6875900d-02 , -5.5068000d-02 /
      data f( 8, 4, 9),f( 8, 4,10) / -8.0085800d-02 , -9.6580000d-02 /
      data f( 8, 4,11),f( 8, 4,12) / -1.0637010d-01 , -1.0976480d-01 /
      data f( 8, 4,13),f( 8, 4,14) / -1.0683040d-01 , -9.7412100d-02 /
      data f( 8, 4,15),f( 8, 4,16) / -8.0980800d-02 , -5.5620700d-02 /
      data f( 8, 4,17),f( 8, 4,18) / -1.4092100d-02 ,  6.6789600d-02 /
      data f( 8, 4,19),f( 8, 4,20) /  1.7102390d-01 ,  2.2504070d-01 /
      data f( 8, 4,21),f( 8, 4,22) /  2.2504070d-01 ,  1.7102390d-01 /
      data f( 8, 4,23) /              6.6789600d-02 /
      data f( 8, 5, 1),f( 8, 5, 2) / -4.4510000d-03 ,  3.4585900d-02 /
      data f( 8, 5, 3),f( 8, 5, 4) /  7.8796000d-02 ,  7.8796000d-02 /
      data f( 8, 5, 5),f( 8, 5, 6) /  3.4585900d-02 , -4.4510000d-03 /
      data f( 8, 5, 7),f( 8, 5, 8) / -3.3277000d-02 , -5.7802800d-02 /
      data f( 8, 5, 9),f( 8, 5,10) / -7.7246000d-02 , -9.1494200d-02 /
      data f( 8, 5,11),f( 8, 5,12) / -1.0037630d-01 , -1.0382220d-01 /
      data f( 8, 5,13),f( 8, 5,14) / -1.0177450d-01 , -9.4136000d-02 /
      data f( 8, 5,15),f( 8, 5,16) / -8.0774400d-02 , -6.1553800d-02 /
      data f( 8, 5,17),f( 8, 5,18) / -3.6134800d-02 , -3.1623000d-03 /
      data f( 8, 5,19),f( 8, 5,20) /  3.7983900d-02 ,  8.5787500d-02 /
      data f( 8, 5,21),f( 8, 5,22) /  8.5787500d-02 ,  3.7983900d-02 /
      data f( 8, 5,23) /             -3.1623000d-03 /
      data f( 8, 6, 1),f( 8, 6, 2) /  3.1452000d-03 ,  2.5049500d-02 /
      data f( 8, 6, 3),f( 8, 6, 4) /  4.1324400d-02 ,  4.1324400d-02 /
      data f( 8, 6, 5),f( 8, 6, 6) /  2.5049500d-02 ,  3.1452000d-03 /
      data f( 8, 6, 7),f( 8, 6, 8) / -1.7959800d-02 , -3.6833600d-02 /
      data f( 8, 6, 9),f( 8, 6,10) / -5.2501400d-02 , -6.4382700d-02 /
      data f( 8, 6,11),f( 8, 6,12) / -7.2161700d-02 , -7.5656800d-02 /
      data f( 8, 6,13),f( 8, 6,14) / -7.4749700d-02 , -6.9351100d-02 /
      data f( 8, 6,15),f( 8, 6,16) / -5.9382100d-02 , -4.4804900d-02 /
      data f( 8, 6,17),f( 8, 6,18) / -2.5750400d-02 , -2.6752000d-03 /
      data f( 8, 6,19),f( 8, 6,20) /  2.3447100d-02 ,  5.0997000d-02 /
      data f( 8, 6,21),f( 8, 6,22) /  5.0997000d-02 ,  2.3447100d-02 /
      data f( 8, 6,23) /             -2.6752000d-03 /
      data f( 8, 7, 1),f( 8, 7, 2) /  1.0157700d-02 ,  2.2607100d-02 /
      data f( 8, 7, 3),f( 8, 7, 4) /  3.3540400d-02 ,  3.3540400d-02 /
      data f( 8, 7, 5),f( 8, 7, 6) /  2.2607100d-02 ,  1.0157700d-02 /
      data f( 8, 7, 7),f( 8, 7, 8) / -2.7265000d-03 , -1.5274900d-02 /
      data f( 8, 7, 9),f( 8, 7,10) / -2.6643500d-02 , -3.6017900d-02 /
      data f( 8, 7,11),f( 8, 7,12) / -4.2745400d-02 , -4.6386800d-02 /
      data f( 8, 7,13),f( 8, 7,14) / -4.6703700d-02 , -4.3618900d-02 /
      data f( 8, 7,15),f( 8, 7,16) / -3.7171700d-02 , -2.7503600d-02 /
      data f( 8, 7,17),f( 8, 7,18) / -1.4923100d-02 , -8.0700000d-05 /
      data f( 8, 7,19),f( 8, 7,20) /  1.5673300d-02 ,  2.9436200d-02 /
      data f( 8, 7,21),f( 8, 7,22) /  2.9436200d-02 ,  1.5673300d-02 /
      data f( 8, 7,23) /             -8.0700000d-05 /
      data f( 8, 8, 1),f( 8, 8, 2) /  1.5097400d-02 ,  2.0322800d-02 /
      data f( 8, 8, 3),f( 8, 8, 4) /  1.9917500d-02 ,  1.9917500d-02 /
      data f( 8, 8, 5),f( 8, 8, 6) /  2.0322800d-02 ,  1.5097400d-02 /
      data f( 8, 8, 7),f( 8, 8, 8) /  8.8019000d-03 ,  1.5961000d-03 /
      data f( 8, 8, 9),f( 8, 8,10) / -6.0582000d-03 , -1.3287900d-02 /
      data f( 8, 8,11),f( 8, 8,12) / -1.9156000d-02 , -2.2985700d-02 /
      data f( 8, 8,13),f( 8, 8,14) / -2.4413400d-02 , -2.3337800d-02 /
      data f( 8, 8,15),f( 8, 8,16) / -1.9844600d-02 , -1.4164400d-02 /
      data f( 8, 8,17),f( 8, 8,18) / -6.6771000d-03 ,  2.0064000d-03 /
      data f( 8, 8,19),f( 8, 8,20) /  1.0841800d-02 ,  1.8002200d-02 /
      data f( 8, 8,21),f( 8, 8,22) /  1.8002200d-02 ,  1.0841800d-02 /
      data f( 8, 8,23) /              2.0064000d-03 /
      data f( 8, 9, 1),f( 8, 9, 2) /  1.9238000d-02 ,  1.6150000d-03 /
      data f( 8, 9, 3),f( 8, 9, 4) / -1.2003200d-02 , -1.2003200d-02 /
      data f( 8, 9, 5),f( 8, 9, 6) /  1.6150000d-03 ,  1.9238000d-02 /
      data f( 8, 9, 7),f( 8, 9, 8) /  1.6777400d-02 ,  1.2910800d-02 /
      data f( 8, 9, 9),f( 8, 9,10) /  7.9093000d-03 ,  2.3618000d-03 /
      data f( 8, 9,11),f( 8, 9,12) / -2.7727000d-03 , -6.6684000d-03 /
      data f( 8, 9,13),f( 8, 9,14) / -8.8560000d-03 , -9.1862000d-03 /
      data f( 8, 9,15),f( 8, 9,16) / -7.7234000d-03 , -4.6573000d-03 /
      data f( 8, 9,17),f( 8, 9,18) / -2.8620000d-04 ,  4.9532000d-03 /
      data f( 8, 9,19),f( 8, 9,20) /  1.0371200d-02 ,  1.4796300d-02 /
      data f( 8, 9,21),f( 8, 9,22) /  1.4796300d-02 ,  1.0371200d-02 /
      data f( 8, 9,23) /              4.9532000d-03 /
      data f( 8,10, 1),f( 8,10, 2) / -9.6000000d-03 , -3.2009400d-02 /
      data f( 8,10, 3),f( 8,10, 4) / -4.7966900d-02 , -4.7966900d-02 /
      data f( 8,10, 5),f( 8,10, 6) / -3.2009400d-02 , -9.6000000d-03 /
      data f( 8,10, 7),f( 8,10, 8) /  1.0425000d-02 ,  1.6106700d-02 /
      data f( 8,10, 9),f( 8,10,10) /  1.4858500d-02 ,  1.1279800d-02 /
      data f( 8,10,11),f( 8,10,12) /  7.0965000d-03 ,  3.4632000d-03 /
      data f( 8,10,13),f( 8,10,14) /  1.0134000d-03 , -1.9200000d-05 /
      data f( 8,10,15),f( 8,10,16) /  3.6630000d-04 ,  2.0520000d-03 /
      data f( 8,10,17),f( 8,10,18) /  4.8273000d-03 ,  8.3694000d-03 /
      data f( 8,10,19),f( 8,10,20) /  1.2203700d-02 ,  1.5497600d-02 /
      data f( 8,10,21),f( 8,10,22) /  1.5497600d-02 ,  1.2203700d-02 /
      data f( 8,10,23) /              8.3694000d-03 /
      data f( 8,11, 1),f( 8,11, 2) / -3.8709500d-02 , -6.2399400d-02 /
      data f( 8,11, 3),f( 8,11, 4) / -7.7197200d-02 , -7.7197200d-02 /
      data f( 8,11, 5),f( 8,11, 6) / -6.2399400d-02 , -3.8709500d-02 /
      data f( 8,11, 7),f( 8,11, 8) / -1.2563100d-02 ,  6.5279000d-03 /
      data f( 8,11, 9),f( 8,11,10) /  1.4016800d-02 ,  1.4317900d-02 /
      data f( 8,11,11),f( 8,11,12) /  1.1860100d-02 ,  8.9865000d-03 /
      data f( 8,11,13),f( 8,11,14) /  6.7755000d-03 ,  5.6375000d-03 /
      data f( 8,11,15),f( 8,11,16) /  5.6745000d-03 ,  6.8398000d-03 /
      data f( 8,11,17),f( 8,11,18) /  8.9546000d-03 ,  1.1719700d-02 /
      data f( 8,11,19),f( 8,11,20) /  1.4783300d-02 ,  1.7554000d-02 /
      data f( 8,11,21),f( 8,11,22) /  1.7554000d-02 ,  1.4783300d-02 /
      data f( 8,11,23) /              1.1719700d-02 /
      data f( 8,12, 1),f( 8,12, 2) / -6.0987800d-02 , -7.9922500d-02 /
      data f( 8,12, 3),f( 8,12, 4) / -8.6389300d-02 , -8.6389300d-02 /
      data f( 8,12, 5),f( 8,12, 6) / -7.9922500d-02 , -6.0987800d-02 /
      data f( 8,12, 7),f( 8,12, 8) / -3.4215500d-02 , -9.1361000d-03 /
      data f( 8,12, 9),f( 8,12,10) /  6.8211000d-03 ,  1.2759400d-02 /
      data f( 8,12,11),f( 8,12,12) /  1.2977300d-02 ,  1.1360100d-02 /
      data f( 8,12,13),f( 8,12,14) /  9.7711000d-03 ,  8.9218000d-03 /
      data f( 8,12,15),f( 8,12,16) /  9.0453000d-03 ,  1.0147300d-02 /
      data f( 8,12,17),f( 8,12,18) /  1.2045000d-02 ,  1.4429300d-02 /
      data f( 8,12,19),f( 8,12,20) /  1.7013000d-02 ,  1.9343800d-02 /
      data f( 8,12,21),f( 8,12,22) /  1.9343800d-02 ,  1.7013000d-02 /
      data f( 8,12,23) /              1.4429300d-02 /
      data f( 8,13, 1),f( 8,13, 2) / -7.3062600d-02 , -8.3064100d-02 /
      data f( 8,13, 3),f( 8,13, 4) / -7.7709600d-02 , -7.7709600d-02 /
      data f( 8,13, 5),f( 8,13, 6) / -8.3064100d-02 , -7.3062600d-02 /
      data f( 8,13, 7),f( 8,13, 8) / -4.9827900d-02 , -2.3396200d-02 /
      data f( 8,13, 9),f( 8,13,10) / -2.4666000d-03 ,  8.6594000d-03 /
      data f( 8,13,11),f( 8,13,12) /  1.1865400d-02 ,  1.1735600d-02 /
      data f( 8,13,13),f( 8,13,14) /  1.0944100d-02 ,  1.0542500d-02 /
      data f( 8,13,15),f( 8,13,16) /  1.0894100d-02 ,  1.2043200d-02 /
      data f( 8,13,17),f( 8,13,18) /  1.3812800d-02 ,  1.5903000d-02 /
      data f( 8,13,19),f( 8,13,20) /  1.8027500d-02 ,  1.9796300d-02 /
      data f( 8,13,21),f( 8,13,22) /  1.9796300d-02 ,  1.8027500d-02 /
      data f( 8,13,23) /              1.5903000d-02 /
      data f( 8,14, 1),f( 8,14, 2) / -7.7146700d-02 , -8.3541400d-02 /
      data f( 8,14, 3),f( 8,14, 4) / -7.7088500d-02 , -7.7088500d-02 /
      data f( 8,14, 5),f( 8,14, 6) / -8.3541400d-02 , -7.7146700d-02 /
      data f( 8,14, 7),f( 8,14, 8) / -5.7641900d-02 , -3.2744300d-02 /
      data f( 8,14, 9),f( 8,14,10) / -1.0260700d-02 ,  4.2594000d-03 /
      data f( 8,14,11),f( 8,14,12) /  9.9468000d-03 ,  1.1101800d-02 /
      data f( 8,14,13),f( 8,14,14) /  1.1025600d-02 ,  1.1006700d-02 /
      data f( 8,14,15),f( 8,14,16) /  1.1492600d-02 ,  1.2559100d-02 /
      data f( 8,14,17),f( 8,14,18) /  1.4064600d-02 ,  1.5751100d-02 /
      data f( 8,14,19),f( 8,14,20) /  1.7342300d-02 ,  1.8536900d-02 /
      data f( 8,14,21),f( 8,14,22) /  1.8536900d-02 ,  1.7342300d-02 /
      data f( 8,14,23) /              1.5751100d-02 /
      data f( 8,15, 1),f( 8,15, 2) / -7.4472100d-02 , -8.4098800d-02 /
      data f( 8,15, 3),f( 8,15, 4) / -8.6031800d-02 , -8.6031800d-02 /
      data f( 8,15, 5),f( 8,15, 6) / -8.4098800d-02 , -7.4472100d-02 /
      data f( 8,15, 7),f( 8,15, 8) / -5.6808400d-02 , -3.4984600d-02 /
      data f( 8,15, 9),f( 8,15,10) / -1.3969100d-02 ,  1.4540000d-03 /
      data f( 8,15,11),f( 8,15,12) /  8.5012000d-03 ,  1.0351100d-02 /
      data f( 8,15,13),f( 8,15,14) /  1.0677900d-02 ,  1.0830800d-02 /
      data f( 8,15,15),f( 8,15,16) /  1.1251600d-02 ,  1.2032900d-02 /
      data f( 8,15,17),f( 8,15,18) /  1.3087700d-02 ,  1.4234400d-02 /
      data f( 8,15,19),f( 8,15,20) /  1.5263600d-02 ,  1.5980600d-02 /
      data f( 8,15,21),f( 8,15,22) /  1.5980600d-02 ,  1.5263600d-02 /
      data f( 8,15,23) /              1.4234400d-02 /
      data f( 8,16, 1),f( 8,16, 2) / -6.0835600d-02 , -7.1604600d-02 /
      data f( 8,16, 3),f( 8,16, 4) / -7.7698400d-02 , -7.7698400d-02 /
      data f( 8,16, 5),f( 8,16, 6) / -7.1604600d-02 , -6.0835600d-02 /
      data f( 8,16, 7),f( 8,16, 8) / -4.5945600d-02 , -2.8706200d-02 /
      data f( 8,16, 9),f( 8,16,10) / -1.1615900d-02 ,  1.8159000d-03 /
      data f( 8,16,11),f( 8,16,12) /  8.5950000d-03 ,  1.0212400d-02 /
      data f( 8,16,13),f( 8,16,14) /  1.0504700d-02 ,  1.0574500d-02 /
      data f( 8,16,15),f( 8,16,16) /  1.0758900d-02 ,  1.1135000d-02 /
      data f( 8,16,17),f( 8,16,18) /  1.1663800d-02 ,  1.2247000d-02 /
      data f( 8,16,19),f( 8,16,20) /  1.2768900d-02 ,  1.3127100d-02 /
      data f( 8,16,21),f( 8,16,22) /  1.3127100d-02 ,  1.2768900d-02 /
      data f( 8,16,23) /              1.2247000d-02 /
      data f( 8,17, 1),f( 8,17, 2) / -3.4993500d-02 , -4.2554500d-02 /
      data f( 8,17, 3),f( 8,17, 4) / -4.7296000d-02 , -4.7296000d-02 /
      data f( 8,17, 5),f( 8,17, 6) / -4.2554500d-02 , -3.4993500d-02 /
      data f( 8,17, 7),f( 8,17, 8) / -2.5186700d-02 , -1.3978700d-02 /
      data f( 8,17, 9),f( 8,17,10) / -2.4019000d-03 ,  7.5683000d-03 /
      data f( 8,17,11),f( 8,17,12) /  1.0764100d-02 ,  1.1118800d-02 /
      data f( 8,17,13),f( 8,17,14) /  1.0979000d-02 ,  1.0777900d-02 /
      data f( 8,17,15),f( 8,17,16) /  1.0654100d-02 ,  1.0639900d-02 /
      data f( 8,17,17),f( 8,17,18) /  1.0717700d-02 ,  1.0848000d-02 /
      data f( 8,17,19),f( 8,17,20) /  1.0983900d-02 ,  1.1084900d-02 /
      data f( 8,17,21),f( 8,17,22) /  1.1084900d-02 ,  1.0983900d-02 /
      data f( 8,17,23) /              1.0848000d-02 /
      data f( 8,18, 1),f( 8,18, 2) / -2.3876000d-03 , -5.6095000d-03 /
      data f( 8,18, 3),f( 8,18, 4) / -7.6266000d-03 , -7.6266000d-03 /
      data f( 8,18, 5),f( 8,18, 6) / -5.6095000d-03 , -2.3876000d-03 /
      data f( 8,18, 7),f( 8,18, 8) /  1.8432000d-03 ,  6.8323000d-03 /
      data f( 8,18, 9),f( 8,18,10) /  1.2299600d-02 ,  1.3902600d-02 /
      data f( 8,18,11),f( 8,18,12) /  1.3290700d-02 ,  1.2736500d-02 /
      data f( 8,18,13),f( 8,18,14) /  1.2253800d-02 ,  1.1851100d-02 /
      data f( 8,18,15),f( 8,18,16) /  1.1530000d-02 ,  1.1285800d-02 /
      data f( 8,18,17),f( 8,18,18) /  1.1109400d-02 ,  1.0989500d-02 /
      data f( 8,18,19),f( 8,18,20) /  1.0914000d-02 ,  1.0873100d-02 /
      data f( 8,18,21),f( 8,18,22) /  1.0873100d-02 ,  1.0914000d-02 /
      data f( 8,18,23) /              1.0989500d-02 /
      data f( 8,19, 1),f( 8,19, 2) /  1.3609300d-02 ,  1.3609300d-02 /
      data f( 8,19, 3),f( 8,19, 4) /  1.3609300d-02 ,  1.3609300d-02 /
      data f( 8,19, 5),f( 8,19, 6) /  1.3609300d-02 ,  1.3609300d-02 /
      data f( 8,19, 7),f( 8,19, 8) /  1.3609300d-02 ,  1.3609300d-02 /
      data f( 8,19, 9),f( 8,19,10) /  1.3609300d-02 ,  1.3609300d-02 /
      data f( 8,19,11),f( 8,19,12) /  1.3609300d-02 ,  1.3609300d-02 /
      data f( 8,19,13),f( 8,19,14) /  1.3609300d-02 ,  1.3609300d-02 /
      data f( 8,19,15),f( 8,19,16) /  1.3609300d-02 ,  1.3609300d-02 /
      data f( 8,19,17),f( 8,19,18) /  1.3609300d-02 ,  1.3609300d-02 /
      data f( 8,19,19),f( 8,19,20) /  1.3609300d-02 ,  1.3609300d-02 /
      data f( 8,19,21),f( 8,19,22) /  1.3609300d-02 ,  1.3609300d-02 /
      data f( 8,19,23) /              1.3609300d-02 /
      data f( 9, 1, 1),f( 9, 1, 2) /  1.6343150d-01 ,  1.6343150d-01 /
      data f( 9, 1, 3),f( 9, 1, 4) /  1.6343150d-01 ,  1.6343150d-01 /
      data f( 9, 1, 5),f( 9, 1, 6) /  1.6343150d-01 ,  1.6343150d-01 /
      data f( 9, 1, 7),f( 9, 1, 8) /  1.6343150d-01 ,  1.6343150d-01 /
      data f( 9, 1, 9),f( 9, 1,10) /  1.6343150d-01 ,  1.6343150d-01 /
      data f( 9, 1,11),f( 9, 1,12) /  1.6343150d-01 ,  1.6343150d-01 /
      data f( 9, 1,13),f( 9, 1,14) /  1.6343150d-01 ,  1.6343150d-01 /
      data f( 9, 1,15),f( 9, 1,16) /  1.6343150d-01 ,  1.6343150d-01 /
      data f( 9, 1,17),f( 9, 1,18) /  1.6343150d-01 ,  1.6343150d-01 /
      data f( 9, 1,19),f( 9, 1,20) /  1.6343150d-01 ,  1.6343150d-01 /
      data f( 9, 1,21),f( 9, 1,22) /  1.6343150d-01 ,  1.6343150d-01 /
      data f( 9, 1,23) /              1.6343150d-01 /
      data f( 9, 2, 1),f( 9, 2, 2) /  1.4661740d-01 ,  1.5996230d-01 /
      data f( 9, 2, 3),f( 9, 2, 4) /  1.6142640d-01 ,  1.6142640d-01 /
      data f( 9, 2, 5),f( 9, 2, 6) /  1.5996230d-01 ,  1.4661740d-01 /
      data f( 9, 2, 7),f( 9, 2, 8) /  1.2803830d-01 ,  1.1207050d-01 /
      data f( 9, 2, 9),f( 9, 2,10) /  9.9616200d-02 ,  9.0794000d-02 /
      data f( 9, 2,11),f( 9, 2,12) /  8.5591700d-02 ,  8.6521400d-02 /
      data f( 9, 2,13),f( 9, 2,14) /  8.8482500d-02 ,  9.1610500d-02 /
      data f( 9, 2,15),f( 9, 2,16) /  1.0067940d-01 ,  1.1353330d-01 /
      data f( 9, 2,17),f( 9, 2,18) /  1.2987020d-01 ,  1.4878120d-01 /
      data f( 9, 2,19),f( 9, 2,20) /  1.6020500d-01 ,  1.6168310d-01 /
      data f( 9, 2,21),f( 9, 2,22) /  1.6168310d-01 ,  1.6020500d-01 /
      data f( 9, 2,23) /              1.4878120d-01 /
      data f( 9, 3, 1),f( 9, 3, 2) /  1.5841230d-01 ,  1.8299010d-01 /
      data f( 9, 3, 3),f( 9, 3, 4) /  2.3203230d-01 ,  2.3203230d-01 /
      data f( 9, 3, 5),f( 9, 3, 6) /  1.8299010d-01 ,  1.5841230d-01 /
      data f( 9, 3, 7),f( 9, 3, 8) /  5.1879000d-02 ,  2.5217000d-03 /
      data f( 9, 3, 9),f( 9, 3,10) / -2.6231700d-02 , -4.3409900d-02 /
      data f( 9, 3,11),f( 9, 3,12) / -5.2907100d-02 , -5.5928400d-02 /
      data f( 9, 3,13),f( 9, 3,14) / -5.2772700d-02 , -4.3053300d-02 /
      data f( 9, 3,15),f( 9, 3,16) / -2.5536300d-02 ,  3.7300000d-03 /
      data f( 9, 3,17),f( 9, 3,18) /  5.3630500d-02 ,  1.5949700d-01 /
      data f( 9, 3,19),f( 9, 3,20) /  1.8325990d-01 ,  2.3231750d-01 /
      data f( 9, 3,21),f( 9, 3,22) /  2.3231750d-01 ,  1.8325990d-01 /
      data f( 9, 3,23) /              1.5949700d-01 /
      data f( 9, 4, 1),f( 9, 4, 2) /  6.2563900d-02 ,  1.6995170d-01 /
      data f( 9, 4, 3),f( 9, 4, 4) /  2.2431780d-01 ,  2.2431780d-01 /
      data f( 9, 4, 5),f( 9, 4, 6) /  1.6995170d-01 ,  6.2563900d-02 /
      data f( 9, 4, 7),f( 9, 4, 8) / -1.7085800d-02 , -5.3782700d-02 /
      data f( 9, 4, 9),f( 9, 4,10) / -7.7940900d-02 , -9.0141800d-02 /
      data f( 9, 4,11),f( 9, 4,12) / -1.0338790d-01 , -1.0669390d-01 /
      data f( 9, 4,13),f( 9, 4,14) / -1.0385820d-01 , -9.2206200d-02 /
      data f( 9, 4,15),f( 9, 4,16) / -7.8868500d-02 , -5.4452400d-02 /
      data f( 9, 4,17),f( 9, 4,18) / -1.4467400d-02 ,  6.4068500d-02 /
      data f( 9, 4,19),f( 9, 4,20) /  1.7021680d-01 ,  2.2463830d-01 /
      data f( 9, 4,21),f( 9, 4,22) /  2.2463830d-01 ,  1.7021680d-01 /
      data f( 9, 4,23) /              6.4068500d-02 /
      data f( 9, 5, 1),f( 9, 5, 2) / -2.5930000d-04 ,  3.6224100d-02 /
      data f( 9, 5, 3),f( 9, 5, 4) /  7.9417300d-02 ,  7.9417300d-02 /
      data f( 9, 5, 5),f( 9, 5, 6) /  3.6224100d-02 , -2.5930000d-04 /
      data f( 9, 5, 7),f( 9, 5, 8) / -3.0006600d-02 , -5.3886600d-02 /
      data f( 9, 5, 9),f( 9, 5,10) / -7.2788900d-02 , -8.6620400d-02 /
      data f( 9, 5,11),f( 9, 5,12) / -9.5236400d-02 , -9.8586500d-02 /
      data f( 9, 5,13),f( 9, 5,14) / -9.6621900d-02 , -8.9244100d-02 /
      data f( 9, 5,15),f( 9, 5,16) / -7.6311900d-02 , -5.7681600d-02 /
      data f( 9, 5,17),f( 9, 5,18) / -3.3009800d-02 , -9.4830000d-04 /
      data f( 9, 5,19),f( 9, 5,20) /  3.9295500d-02 ,  8.6085000d-02 /
      data f( 9, 5,21),f( 9, 5,22) /  8.6085000d-02 ,  3.9295500d-02 /
      data f( 9, 5,23) /             -9.4830000d-04 /
      data f( 9, 6, 1),f( 9, 6, 2) /  4.5933000d-03 ,  2.6139700d-02 /
      data f( 9, 6, 3),f( 9, 6, 4) /  4.4056800d-02 ,  4.4056800d-02 /
      data f( 9, 6, 5),f( 9, 6, 6) /  2.6139700d-02 ,  4.5933000d-03 /
      data f( 9, 6, 7),f( 9, 6, 8) / -1.5850000d-02 , -3.4006500d-02 /
      data f( 9, 6, 9),f( 9, 6,10) / -4.9026900d-02 , -6.0400600d-02 /
      data f( 9, 6,11),f( 9, 6,12) / -6.7848500d-02 , -7.1205600d-02 /
      data f( 9, 6,13),f( 9, 6,14) / -7.0360000d-02 , -6.5222900d-02 /
      data f( 9, 6,15),f( 9, 6,16) / -5.5711200d-02 , -4.1780300d-02 /
      data f( 9, 6,17),f( 9, 6,18) / -2.3543700d-02 , -1.4273000d-03 /
      data f( 9, 6,19),f( 9, 6,20) /  2.3620800d-02 ,  4.9771700d-02 /
      data f( 9, 6,21),f( 9, 6,22) /  4.9771700d-02 ,  2.3620800d-02 /
      data f( 9, 6,23) /             -1.4273000d-03 /
      data f( 9, 7, 1),f( 9, 7, 2) /  9.6585000d-03 ,  2.1167300d-02 /
      data f( 9, 7, 3),f( 9, 7, 4) /  3.0865900d-02 ,  3.0865900d-02 /
      data f( 9, 7, 5),f( 9, 7, 6) /  2.1167300d-02 ,  9.6585000d-03 /
      data f( 9, 7, 7),f( 9, 7, 8) / -2.3784000d-03 , -1.4119600d-02 /
      data f( 9, 7, 9),f( 9, 7,10) / -2.4762000d-02 , -3.3551800d-02 /
      data f( 9, 7,11),f( 9, 7,12) / -3.9878300d-02 , -4.3319900d-02 /
      data f( 9, 7,13),f( 9, 7,14) / -4.3642100d-02 , -4.0766800d-02 /
      data f( 9, 7,15),f( 9, 7,16) / -3.4730500d-02 , -2.5671700d-02 /
      data f( 9, 7,17),f( 9, 7,18) / -1.3896100d-02 , -5.4700000d-05 /
      data f( 9, 7,19),f( 9, 7,20) /  1.4502500d-02 ,  2.6973900d-02 /
      data f( 9, 7,21),f( 9, 7,22) /  2.6973900d-02 ,  1.4502500d-02 /
      data f( 9, 7,23) /             -5.4700000d-05 /
      data f( 9, 8, 1),f( 9, 8, 2) /  1.3477600d-02 ,  1.8146000d-02 /
      data f( 9, 8, 3),f( 9, 8, 4) /  2.1417700d-02 ,  2.1417700d-02 /
      data f( 9, 8, 5),f( 9, 8, 6) /  1.8146000d-02 ,  1.3477600d-02 /
      data f( 9, 8, 7),f( 9, 8, 8) /  7.7659000d-03 ,  1.2039000d-03 /
      data f( 9, 8, 9),f( 9, 8,10) / -5.7736000d-03 , -1.2383600d-02 /
      data f( 9, 8,11),f( 9, 8,12) / -1.7778500d-02 , -2.1323300d-02 /
      data f( 9, 8,13),f( 9, 8,14) / -2.2669700d-02 , -2.1707400d-02 /
      data f( 9, 8,15),f( 9, 8,16) / -1.8507500d-02 , -1.3284500d-02 /
      data f( 9, 8,17),f( 9, 8,18) / -6.4025000d-03 ,  1.5459000d-03 /
      data f( 9, 8,19),f( 9, 8,20) /  9.5565000d-03 ,  1.5944800d-02 /
      data f( 9, 8,21),f( 9, 8,22) /  1.5944800d-02 ,  9.5565000d-03 /
      data f( 9, 8,23) /              1.5459000d-03 /
      data f( 9, 9, 1),f( 9, 9, 2) /  1.6830000d-02 ,  6.7660000d-03 /
      data f( 9, 9, 3),f( 9, 9, 4) / -5.7326000d-03 , -5.7326000d-03 /
      data f( 9, 9, 5),f( 9, 9, 6) /  6.7660000d-03 ,  1.6830000d-02 /
      data f( 9, 9, 7),f( 9, 9, 8) /  1.4547200d-02 ,  1.1176400d-02 /
      data f( 9, 9, 9),f( 9, 9,10) /  6.7822000d-03 ,  1.8625000d-03 /
      data f( 9, 9,11),f( 9, 9,12) / -2.7368000d-03 , -6.2640000d-03 /
      data f( 9, 9,13),f( 9, 9,14) / -8.2707000d-03 , -8.5971000d-03 /
      data f( 9, 9,15),f( 9, 9,16) / -7.2871000d-03 , -4.5101000d-03 /
      data f( 9, 9,17),f( 9, 9,18) / -5.4680000d-04 ,  4.1819000d-03 /
      data f( 9, 9,19),f( 9, 9,20) /  9.0117000d-03 ,  1.2878800d-02 /
      data f( 9, 9,21),f( 9, 9,22) /  1.2878800d-02 ,  9.0117000d-03 /
      data f( 9, 9,23) /              4.1819000d-03 /
      data f( 9,10, 1),f( 9,10, 2) / -4.3498000d-03 , -2.4194100d-02 /
      data f( 9,10, 3),f( 9,10, 4) / -3.8873600d-02 , -3.8873600d-02 /
      data f( 9,10, 5),f( 9,10, 6) / -2.4194100d-02 , -4.3498000d-03 /
      data f( 9,10, 7),f( 9,10, 8) /  1.0615400d-02 ,  1.3954000d-02 /
      data f( 9,10, 9),f( 9,10,10) /  1.2796700d-02 ,  9.7320000d-03 /
      data f( 9,10,11),f( 9,10,12) /  6.0890000d-03 ,  2.8751000d-03 /
      data f( 9,10,13),f( 9,10,14) /  6.8070000d-04 , -2.5440000d-04 /
      data f( 9,10,15),f( 9,10,16) /  9.0500000d-05 ,  1.6158000d-03 /
      data f( 9,10,17),f( 9,10,18) /  4.1263000d-03 ,  7.3087000d-03 /
      data f( 9,10,19),f( 9,10,20) /  1.0687900d-02 ,  1.3501700d-02 /
      data f( 9,10,21),f( 9,10,22) /  1.3501700d-02 ,  1.0687900d-02 /
      data f( 9,10,23) /              7.3087000d-03 /
      data f( 9,11, 1),f( 9,11, 2) / -3.0895000d-02 , -5.2465200d-02 /
      data f( 9,11, 3),f( 9,11, 4) / -6.6488400d-02 , -6.6488400d-02 /
      data f( 9,11, 5),f( 9,11, 6) / -5.2465200d-02 , -3.0895000d-02 /
      data f( 9,11, 7),f( 9,11, 8) / -8.4057000d-03 ,  6.5482000d-03 /
      data f( 9,11, 9),f( 9,11,10) /  1.2133200d-02 ,  1.2300200d-02 /
      data f( 9,11,11),f( 9,11,12) /  1.0215000d-02 ,  7.7313000d-03 /
      data f( 9,11,13),f( 9,11,14) /  5.7934000d-03 ,  4.7932000d-03 /
      data f( 9,11,15),f( 9,11,16) /  4.8433000d-03 ,  5.9130000d-03 /
      data f( 9,11,17),f( 9,11,18) /  7.8430000d-03 ,  1.0340000d-02 /
      data f( 9,11,19),f( 9,11,20) /  1.3024300d-02 ,  1.5333500d-02 /
      data f( 9,11,21),f( 9,11,22) /  1.5333500d-02 ,  1.3024300d-02 /
      data f( 9,11,23) /              1.0340000d-02 /
      data f( 9,12, 1),f( 9,12, 2) / -5.1547400d-02 , -6.9677400d-02 /
      data f( 9,12, 3),f( 9,12, 4) / -7.7376600d-02 , -7.7376600d-02 /
      data f( 9,12, 5),f( 9,12, 6) / -6.9677400d-02 , -5.1547400d-02 /
      data f( 9,12, 7),f( 9,12, 8) / -2.7628300d-02 , -6.4565000d-03 /
      data f( 9,12, 9),f( 9,12,10) /  6.2895000d-03 ,  1.0951500d-02 /
      data f( 9,12,11),f( 9,12,12) /  1.1110400d-02 ,  9.7434000d-03 /
      data f( 9,12,13),f( 9,12,14) /  8.3806000d-03 ,  7.6554000d-03 /
      data f( 9,12,15),f( 9,12,16) /  7.7915000d-03 ,  8.8080000d-03 /
      data f( 9,12,17),f( 9,12,18) /  1.0547100d-02 ,  1.2706400d-02 /
      data f( 9,12,19),f( 9,12,20) /  1.4955400d-02 ,  1.6857600d-02 /
      data f( 9,12,21),f( 9,12,22) /  1.6857600d-02 ,  1.4955400d-02 /
      data f( 9,12,23) /              1.2706400d-02 /
      data f( 9,13, 1),f( 9,13, 2) / -6.3107200d-02 , -7.4282400d-02 /
      data f( 9,13, 3),f( 9,13, 4) / -7.2997200d-02 , -7.2997200d-02 /
      data f( 9,13, 5),f( 9,13, 6) / -7.4282400d-02 , -6.3107200d-02 /
      data f( 9,13, 7),f( 9,13, 8) / -4.1689300d-02 , -1.8634300d-02 /
      data f( 9,13, 9),f( 9,13,10) / -1.2799000d-03 ,  7.5558000d-03 /
      data f( 9,13,11),f( 9,13,12) /  1.0107500d-02 ,  1.0000700d-02 /
      data f( 9,13,13),f( 9,13,14) /  9.3400000d-03 ,  9.0148000d-03 /
      data f( 9,13,15),f( 9,13,16) /  9.3521000d-03 ,  1.0402600d-02 /
      data f( 9,13,17),f( 9,13,18) /  1.2014200d-02 ,  1.3898500d-02 /
      data f( 9,13,19),f( 9,13,20) /  1.5746600d-02 ,  1.7199600d-02 /
      data f( 9,13,21),f( 9,13,22) /  1.7199600d-02 ,  1.5746600d-02 /
      data f( 9,13,23) /              1.3898500d-02 /
      data f( 9,14, 1),f( 9,14, 2) / -6.7059600d-02 , -7.5092100d-02 /
      data f( 9,14, 3),f( 9,14, 4) / -7.2604000d-02 , -7.2604000d-02 /
      data f( 9,14, 5),f( 9,14, 6) / -7.5092100d-02 , -6.7059600d-02 /
      data f( 9,14, 7),f( 9,14, 8) / -4.8693100d-02 , -2.6559000d-02 /
      data f( 9,14, 9),f( 9,14,10) / -7.4903000d-03 ,  4.0869000d-03 /
      data f( 9,14,11),f( 9,14,12) /  8.4866000d-03 ,  9.4070000d-03 /
      data f( 9,14,13),f( 9,14,14) /  9.3503000d-03 ,  9.3538000d-03 /
      data f( 9,14,15),f( 9,14,16) /  9.8029000d-03 ,  1.0769700d-02 /
      data f( 9,14,17),f( 9,14,18) /  1.2130800d-02 ,  1.3646600d-02 /
      data f( 9,14,19),f( 9,14,20) /  1.5049000d-02 ,  1.6069500d-02 /
      data f( 9,14,21),f( 9,14,22) /  1.6069500d-02 ,  1.5049000d-02 /
      data f( 9,14,23) /              1.3646600d-02 /
      data f( 9,15, 1),f( 9,15, 2) / -6.4126300d-02 , -7.4010800d-02 /
      data f( 9,15, 3),f( 9,15, 4) / -7.7225400d-02 , -7.7225400d-02 /
      data f( 9,15, 5),f( 9,15, 6) / -7.4010800d-02 , -6.4126300d-02 /
      data f( 9,15, 7),f( 9,15, 8) / -4.7648000d-02 , -2.8089800d-02 /
      data f( 9,15, 9),f( 9,15,10) / -1.0053200d-02 ,  2.2309000d-03 /
      data f( 9,15,11),f( 9,15,12) /  7.3841000d-03 ,  8.7612000d-03 /
      data f( 9,15,13),f( 9,15,14) /  9.0114000d-03 ,  9.1466000d-03 /
      data f( 9,15,15),f( 9,15,16) /  9.5263000d-03 ,  1.0230300d-02 /
      data f( 9,15,17),f( 9,15,18) /  1.1180600d-02 ,  1.2212100d-02 /
      data f( 9,15,19),f( 9,15,20) /  1.3132200d-02 ,  1.3766500d-02 /
      data f( 9,15,21),f( 9,15,22) /  1.3766500d-02 ,  1.3132200d-02 /
      data f( 9,15,23) /              1.2212100d-02 /
      data f( 9,16, 1),f( 9,16, 2) / -5.0911300d-02 , -6.0996700d-02 /
      data f( 9,16, 3),f( 9,16, 4) / -6.6863000d-02 , -6.6863000d-02 /
      data f( 9,16, 5),f( 9,16, 6) / -6.0996700d-02 , -5.0911300d-02 /
      data f( 9,16, 7),f( 9,16, 8) / -3.7273600d-02 , -2.1828500d-02 /
      data f( 9,16, 9),f( 9,16,10) / -7.1904000d-03 ,  3.3975000d-03 /
      data f( 9,16,11),f( 9,16,12) /  7.6741000d-03 ,  8.7009000d-03 /
      data f( 9,16,13),f( 9,16,14) /  8.8633000d-03 ,  8.8968000d-03 /
      data f( 9,16,15),f( 9,16,16) /  9.0507000d-03 ,  9.3827000d-03 /
      data f( 9,16,17),f( 9,16,18) /  9.8551000d-03 ,  1.0378000d-02 /
      data f( 9,16,19),f( 9,16,20) /  1.0846300d-02 ,  1.1167300d-02 /
      data f( 9,16,21),f( 9,16,22) /  1.1167300d-02 ,  1.0846300d-02 /
      data f( 9,16,23) /              1.0378000d-02 /
      data f( 9,17, 1),f( 9,17, 2) / -2.6724000d-02 , -3.3626100d-02 /
      data f( 9,17, 3),f( 9,17, 4) / -3.7972100d-02 , -3.7972100d-02 /
      data f( 9,17, 5),f( 9,17, 6) / -3.3626100d-02 , -2.6724000d-02 /
      data f( 9,17, 7),f( 9,17, 8) / -1.7855400d-02 , -7.8262000d-03 /
      data f( 9,17, 9),f( 9,17,10) /  2.1842000d-03 ,  8.5441000d-03 /
      data f( 9,17,11),f( 9,17,12) /  9.5605000d-03 ,  9.5563000d-03 /
      data f( 9,17,13),f( 9,17,14) /  9.3196000d-03 ,  9.0913000d-03 /
      data f( 9,17,15),f( 9,17,16) /  8.9553000d-03 ,  8.9275000d-03 /
      data f( 9,17,17),f( 9,17,18) /  8.9877000d-03 ,  9.0983000d-03 /
      data f( 9,17,19),f( 9,17,20) /  9.2164000d-03 ,  9.3050000d-03 /
      data f( 9,17,21),f( 9,17,22) /  9.3050000d-03 ,  9.2164000d-03 /
      data f( 9,17,23) /              9.0983000d-03 /
      data f( 9,18, 1),f( 9,18, 2) /  3.3115000d-03 ,  4.0940000d-04 /
      data f( 9,18, 3),f( 9,18, 4) / -1.4107000d-03 , -1.4107000d-03 /
      data f( 9,18, 5),f( 9,18, 6) /  4.0940000d-04 ,  3.3115000d-03 /
      data f( 9,18, 7),f( 9,18, 8) /  7.1107000d-03 ,  1.1569300d-02 /
      data f( 9,18, 9),f( 9,18,10) /  1.2936900d-02 ,  1.2189000d-02 /
      data f( 9,18,11),f( 9,18,12) /  1.1532800d-02 ,  1.0964000d-02 /
      data f( 9,18,13),f( 9,18,14) /  1.0482700d-02 ,  1.0088200d-02 /
      data f( 9,18,15),f( 9,18,16) /  9.7766000d-03 ,  9.5406000d-03 /
      data f( 9,18,17),f( 9,18,18) /  9.3700000d-03 ,  9.2536000d-03 /
      data f( 9,18,19),f( 9,18,20) /  9.1799000d-03 ,  9.1398000d-03 /
      data f( 9,18,21),f( 9,18,22) /  9.1398000d-03 ,  9.1799000d-03 /
      data f( 9,18,23) /              9.2536000d-03 /
      data f( 9,19, 1),f( 9,19, 2) /  1.1701200d-02 ,  1.1701200d-02 /
      data f( 9,19, 3),f( 9,19, 4) /  1.1701200d-02 ,  1.1701200d-02 /
      data f( 9,19, 5),f( 9,19, 6) /  1.1701200d-02 ,  1.1701200d-02 /
      data f( 9,19, 7),f( 9,19, 8) /  1.1701200d-02 ,  1.1701200d-02 /
      data f( 9,19, 9),f( 9,19,10) /  1.1701200d-02 ,  1.1701200d-02 /
      data f( 9,19,11),f( 9,19,12) /  1.1701200d-02 ,  1.1701200d-02 /
      data f( 9,19,13),f( 9,19,14) /  1.1701200d-02 ,  1.1701200d-02 /
      data f( 9,19,15),f( 9,19,16) /  1.1701200d-02 ,  1.1701200d-02 /
      data f( 9,19,17),f( 9,19,18) /  1.1701200d-02 ,  1.1701200d-02 /
      data f( 9,19,19),f( 9,19,20) /  1.1701200d-02 ,  1.1701200d-02 /
      data f( 9,19,21),f( 9,19,22) /  1.1701200d-02 ,  1.1701200d-02 /
      data f( 9,19,23) /              1.1701200d-02 /
      data f(10, 1, 1),f(10, 1, 2) /  1.4359040d-01 ,  1.4359040d-01 /
      data f(10, 1, 3),f(10, 1, 4) /  1.4359040d-01 ,  1.4359040d-01 /
      data f(10, 1, 5),f(10, 1, 6) /  1.4359040d-01 ,  1.4359040d-01 /
      data f(10, 1, 7),f(10, 1, 8) /  1.4359040d-01 ,  1.4359040d-01 /
      data f(10, 1, 9),f(10, 1,10) /  1.4359040d-01 ,  1.4359040d-01 /
      data f(10, 1,11),f(10, 1,12) /  1.4359040d-01 ,  1.4359040d-01 /
      data f(10, 1,13),f(10, 1,14) /  1.4359040d-01 ,  1.4359040d-01 /
      data f(10, 1,15),f(10, 1,16) /  1.4359040d-01 ,  1.4359040d-01 /
      data f(10, 1,17),f(10, 1,18) /  1.4359040d-01 ,  1.4359040d-01 /
      data f(10, 1,19),f(10, 1,20) /  1.4359040d-01 ,  1.4359040d-01 /
      data f(10, 1,21),f(10, 1,22) /  1.4359040d-01 ,  1.4359040d-01 /
      data f(10, 1,23) /              1.4359040d-01 /
      data f(10, 2, 1),f(10, 2, 2) /  1.0837280d-01 ,  1.2576290d-01 /
      data f(10, 2, 3),f(10, 2, 4) /  1.3934300d-01 ,  1.3934300d-01 /
      data f(10, 2, 5),f(10, 2, 6) /  1.2576290d-01 ,  1.0837280d-01 /
      data f(10, 2, 7),f(10, 2, 8) /  9.1196100d-02 ,  7.6469200d-02 /
      data f(10, 2, 9),f(10, 2,10) /  6.4984400d-02 ,  5.6869500d-02 /
      data f(10, 2,11),f(10, 2,12) /  5.2090000d-02 ,  5.0611000d-02 /
      data f(10, 2,13),f(10, 2,14) /  5.2555500d-02 ,  5.7556400d-02 /
      data f(10, 2,15),f(10, 2,16) /  6.6035900d-02 ,  7.7891900d-02 /
      data f(10, 2,17),f(10, 2,18) /  9.2979400d-02 ,  1.1047950d-01 /
      data f(10, 2,19),f(10, 2,20) /  1.2813240d-01 ,  1.4187210d-01 /
      data f(10, 2,21),f(10, 2,22) /  1.4187210d-01 ,  1.2813240d-01 /
      data f(10, 2,23) /              1.1047950d-01 /
      data f(10, 3, 1),f(10, 3, 2) /  1.3914770d-01 ,  1.7935380d-01 /
      data f(10, 3, 3),f(10, 3, 4) /  2.2351180d-01 ,  2.2351180d-01 /
      data f(10, 3, 5),f(10, 3, 6) /  1.7935380d-01 ,  1.3914770d-01 /
      data f(10, 3, 7),f(10, 3, 8) /  3.9349000d-02 , -6.7435000d-03 /
      data f(10, 3, 9),f(10, 3,10) / -3.3708200d-02 , -4.9890900d-02 /
      data f(10, 3,11),f(10, 3,12) / -5.8880700d-02 , -6.1778300d-02 /
      data f(10, 3,13),f(10, 3,14) / -5.8755000d-02 , -4.9550600d-02 /
      data f(10, 3,15),f(10, 3,16) / -3.3031400d-02 , -5.5554000d-03 /
      data f(10, 3,17),f(10, 3,18) /  4.1103900d-02 ,  1.4142600d-01 /
      data f(10, 3,19),f(10, 3,20) /  1.7962280d-01 ,  2.2379130d-01 /
      data f(10, 3,21),f(10, 3,22) /  2.2379130d-01 ,  1.7962280d-01 /
      data f(10, 3,23) /              1.4142600d-01 /
      data f(10, 4, 1),f(10, 4, 2) /  5.8208800d-02 ,  1.6820400d-01 /
      data f(10, 4, 3),f(10, 4, 4) /  2.1751260d-01 ,  2.1751260d-01 /
      data f(10, 4, 5),f(10, 4, 6) /  1.6820400d-01 ,  5.8208800d-02 /
      data f(10, 4, 7),f(10, 4, 8) / -1.6858600d-02 , -5.1740900d-02 /
      data f(10, 4, 9),f(10, 4,10) / -7.4803100d-02 , -8.7644000d-02 /
      data f(10, 4,11),f(10, 4,12) / -9.8651800d-02 , -1.0258490d-01 /
      data f(10, 4,13),f(10, 4,14) / -9.9211200d-02 , -8.8512800d-02 /
      data f(10, 4,15),f(10, 4,16) / -7.5770100d-02 , -5.2407000d-02 /
      data f(10, 4,17),f(10, 4,18) / -1.4390100d-02 ,  5.9654200d-02 /
      data f(10, 4,19),f(10, 4,20) /  1.6845680d-01 ,  2.1781600d-01 /
      data f(10, 4,21),f(10, 4,22) /  2.1781600d-01 ,  1.6845680d-01 /
      data f(10, 4,23) /              5.9654200d-02 /
      data f(10, 5, 1),f(10, 5, 2) /  2.1468000d-03 ,  3.7339900d-02 /
      data f(10, 5, 3),f(10, 5, 4) /  7.8515300d-02 ,  7.8515300d-02 /
      data f(10, 5, 5),f(10, 5, 6) /  3.7339900d-02 ,  2.1468000d-03 /
      data f(10, 5, 7),f(10, 5, 8) / -2.6664700d-02 , -4.9837400d-02 /
      data f(10, 5, 9),f(10, 5,10) / -6.8158000d-02 , -8.1542500d-02 /
      data f(10, 5,11),f(10, 5,12) / -8.9873200d-02 , -9.3119900d-02 /
      data f(10, 5,13),f(10, 5,14) / -9.1242400d-02 , -8.4139700d-02 /
      data f(10, 5,15),f(10, 5,16) / -7.1662900d-02 , -5.3662200d-02 /
      data f(10, 5,17),f(10, 5,18) / -2.9806900d-02 ,  1.1644000d-03 /
      data f(10, 5,19),f(10, 5,20) /  4.0032700d-02 ,  8.4844000d-02 /
      data f(10, 5,21),f(10, 5,22) /  8.4844000d-02 ,  4.0032700d-02 /
      data f(10, 5,23) /              1.1644000d-03 /
      data f(10, 6, 1),f(10, 6, 2) /  5.7999000d-03 ,  2.6719500d-02 /
      data f(10, 6, 3),f(10, 6, 4) /  4.8006600d-02 ,  4.8006600d-02 /
      data f(10, 6, 5),f(10, 6, 6) /  2.6719500d-02 ,  5.7999000d-03 /
      data f(10, 6, 7),f(10, 6, 8) / -1.3863800d-02 , -3.1241300d-02 /
      data f(10, 6, 9),f(10, 6,10) / -4.5579200d-02 , -5.6424500d-02 /
      data f(10, 6,11),f(10, 6,12) / -6.3529300d-02 , -6.6742300d-02 /
      data f(10, 6,13),f(10, 6,14) / -6.5956300d-02 , -6.1083700d-02 /
      data f(10, 6,15),f(10, 6,16) / -5.2040500d-02 , -3.8777400d-02 /
      data f(10, 6,17),f(10, 6,18) / -2.1396800d-02 , -3.1320000d-04 /
      data f(10, 6,19),f(10, 6,20) /  2.3519600d-02 ,  4.7947600d-02 /
      data f(10, 6,21),f(10, 6,22) /  4.7947600d-02 ,  2.3519600d-02 /
      data f(10, 6,23) /             -3.1320000d-04 /
      data f(10, 7, 1),f(10, 7, 2) /  9.0952000d-03 ,  1.9660300d-02 /
      data f(10, 7, 3),f(10, 7, 4) /  2.8245700d-02 ,  2.8245700d-02 /
      data f(10, 7, 5),f(10, 7, 6) /  1.9660300d-02 ,  9.0952000d-03 /
      data f(10, 7, 7),f(10, 7, 8) / -2.0826000d-03 , -1.3014600d-02 /
      data f(10, 7, 9),f(10, 7,10) / -2.2934800d-02 , -3.1144400d-02 /
      data f(10, 7,11),f(10, 7,12) / -3.7071000d-02 , -4.0310400d-02 /
      data f(10, 7,13),f(10, 7,14) / -4.0632800d-02 , -3.7960000d-02 /
      data f(10, 7,15),f(10, 7,16) / -3.2326300d-02 , -2.3866300d-02 /
      data f(10, 7,17),f(10, 7,18) / -1.2881700d-02 , -1.9300000d-05 /
      data f(10, 7,19),f(10, 7,20) /  1.3386900d-02 ,  2.4668400d-02 /
      data f(10, 7,21),f(10, 7,22) /  2.4668400d-02 ,  1.3386900d-02 /
      data f(10, 7,23) /             -1.9300000d-05 /
      data f(10, 8, 1),f(10, 8, 2) /  1.1955200d-02 ,  1.6119200d-02 /
      data f(10, 8, 3),f(10, 8, 4) /  1.8961800d-02 ,  1.8961800d-02 /
      data f(10, 8, 5),f(10, 8, 6) /  1.6119200d-02 ,  1.1955200d-02 /
      data f(10, 8, 7),f(10, 8, 8) /  6.7927000d-03 ,  8.3960000d-04 /
      data f(10, 8, 9),f(10, 8,10) / -5.4975000d-03 , -1.1517900d-02 /
      data f(10, 8,11),f(10, 8,12) / -1.6456600d-02 , -1.9724400d-02 /
      data f(10, 8,13),f(10, 8,14) / -2.0985900d-02 , -2.0125000d-02 /
      data f(10, 8,15),f(10, 8,16) / -1.7202900d-02 , -1.2414000d-02 /
      data f(10, 8,17),f(10, 8,18) / -6.1064000d-03 ,  1.1498000d-03 /
      data f(10, 8,19),f(10, 8,20) /  8.3980000d-03 ,  1.4096400d-02 /
      data f(10, 8,21),f(10, 8,22) /  1.4096400d-02 ,  8.3980000d-03 /
      data f(10, 8,23) /              1.1498000d-03 /
      data f(10, 9, 1),f(10, 9, 2) /  1.4675300d-02 ,  1.1490100d-02 /
      data f(10, 9, 3),f(10, 9, 4) /  2.3040000d-04 ,  2.3040000d-04 /
      data f(10, 9, 5),f(10, 9, 6) /  1.1490100d-02 ,  1.4675300d-02 /
      data f(10, 9, 7),f(10, 9, 8) /  1.2577900d-02 ,  9.6222000d-03 /
      data f(10, 9, 9),f(10, 9,10) /  5.7601000d-03 ,  1.4062000d-03 /
      data f(10, 9,11),f(10, 9,12) / -2.7002000d-03 , -5.8798000d-03 /
      data f(10, 9,13),f(10, 9,14) / -7.7121000d-03 , -8.0291000d-03 /
      data f(10, 9,15),f(10, 9,16) / -6.8581000d-03 , -4.3494000d-03 /
      data f(10, 9,17),f(10, 9,18) / -7.6570000d-04 ,  3.4916000d-03 /
      data f(10, 9,19),f(10, 9,20) /  7.7923000d-03 ,  1.1177500d-02 /
      data f(10, 9,21),f(10, 9,22) /  1.1177500d-02 ,  7.7923000d-03 /
      data f(10, 9,23) /              3.4916000d-03 /
      data f(10,10, 1),f(10,10, 2) / -1.2400000d-05 , -1.6773700d-02 /
      data f(10,10, 3),f(10,10, 4) / -2.9998400d-02 , -2.9998400d-02 /
      data f(10,10, 5),f(10,10, 6) / -1.6773700d-02 , -1.2400000d-05 /
      data f(10,10, 7),f(10,10, 8) /  1.0100400d-02 ,  1.2052300d-02 /
      data f(10,10, 9),f(10,10,10) /  1.0985000d-02 ,  8.3487000d-03 /
      data f(10,10,11),f(10,10,12) /  5.1774000d-03 ,  2.3416000d-03 /
      data f(10,10,13),f(10,10,14) /  3.8240000d-04 , -4.6100000d-04 /
      data f(10,10,15),f(10,10,16) / -1.5270000d-04 ,  1.2231000d-03 /
      data f(10,10,17),f(10,10,18) /  3.4861000d-03 ,  6.3374000d-03 /
      data f(10,10,19),f(10,10,20) /  9.3166000d-03 ,  1.1732700d-02 /
      data f(10,10,21),f(10,10,22) /  1.1732700d-02 ,  9.3166000d-03 /
      data f(10,10,23) /              6.3374000d-03 /
      data f(10,11, 1),f(10,11, 2) / -2.3654400d-02 , -4.2669400d-02 /
      data f(10,11, 3),f(10,11, 4) / -5.5525800d-02 , -5.5525800d-02 /
      data f(10,11, 5),f(10,11, 6) / -4.2669400d-02 , -2.3654400d-02 /
      data f(10,11, 7),f(10,11, 8) / -5.0862000d-03 ,  6.2743000d-03 /
      data f(10,11, 9),f(10,11,10) /  1.0463200d-02 ,  1.0535600d-02 /
      data f(10,11,11),f(10,11,12) /  8.7577000d-03 ,  6.6103000d-03 /
      data f(10,11,13),f(10,11,14) /  4.9138000d-03 ,  4.0358000d-03 /
      data f(10,11,15),f(10,11,16) /  4.0943000d-03 ,  5.0704000d-03 /
      data f(10,11,17),f(10,11,18) /  6.8221000d-03 ,  9.0698000d-03 /
      data f(10,11,19),f(10,11,20) /  1.1429100d-02 ,  1.3377000d-02 /
      data f(10,11,21),f(10,11,22) /  1.3377000d-02 ,  1.1429100d-02 /
      data f(10,11,23) /              9.0698000d-03 /
      data f(10,12, 1),f(10,12, 2) / -4.2381800d-02 , -5.8903900d-02 /
      data f(10,12, 3),f(10,12, 4) / -6.6774900d-02 , -6.6774900d-02 /
      data f(10,12, 5),f(10,12, 6) / -5.8903900d-02 , -4.2381800d-02 /
      data f(10,12, 7),f(10,12, 8) / -2.1746600d-02 , -4.3923000d-03 /
      data f(10,12, 9),f(10,12,10) /  5.6827000d-03 ,  9.3683000d-03 /
      data f(10,12,11),f(10,12,12) /  9.4807000d-03 ,  8.3205000d-03 /
      data f(10,12,13),f(10,12,14) /  7.1508000d-03 ,  6.5316000d-03 /
      data f(10,12,15),f(10,12,16) /  6.6735000d-03 ,  7.6042000d-03 /
      data f(10,12,17),f(10,12,18) /  9.1880000d-03 ,  1.1138400d-02 /
      data f(10,12,19),f(10,12,20) /  1.3110800d-02 ,  1.4695800d-02 /
      data f(10,12,21),f(10,12,22) /  1.4695800d-02 ,  1.3110800d-02 /
      data f(10,12,23) /              1.1138400d-02 /
      data f(10,13, 1),f(10,13, 2) / -5.3031200d-02 , -6.4022900d-02 /
      data f(10,13, 3),f(10,13, 4) / -6.4854200d-02 , -6.4854200d-02 /
      data f(10,13, 5),f(10,13, 6) / -6.4022900d-02 , -5.3031200d-02 /
      data f(10,13, 7),f(10,13, 8) / -3.4084500d-02 , -1.4571400d-02 /
      data f(10,13, 9),f(10,13,10) / -4.6860000d-04 ,  6.5358000d-03 /
      data f(10,13,11),f(10,13,12) /  8.5803000d-03 ,  8.4898000d-03 /
      data f(10,13,13),f(10,13,14) /  7.9370000d-03 ,  7.6746000d-03 /
      data f(10,13,15),f(10,13,16) /  7.9938000d-03 ,  8.9484000d-03 /
      data f(10,13,17),f(10,13,18) /  1.0409300d-02 ,  1.2107000d-02 /
      data f(10,13,19),f(10,13,20) /  1.3730600d-02 ,  1.4953000d-02 /
      data f(10,13,21),f(10,13,22) /  1.4953000d-02 ,  1.3730600d-02 /
      data f(10,13,23) /              1.2107000d-02 /
      data f(10,14, 1),f(10,14, 2) / -5.6641600d-02 , -6.4939700d-02 /
      data f(10,14, 3),f(10,14, 4) / -6.4579600d-02 , -6.4579600d-02 /
      data f(10,14, 5),f(10,14, 6) / -6.4939700d-02 , -5.6641600d-02 /
      data f(10,14, 7),f(10,14, 8) / -4.0121800d-02 , -2.1045300d-02 /
      data f(10,14, 9),f(10,14,10) / -5.3098000d-03 ,  3.7855000d-03 /
      data f(10,14,11),f(10,14,12) /  7.2044000d-03 ,  7.9397000d-03 /
      data f(10,14,13),f(10,14,14) /  7.8968000d-03 ,  7.9167000d-03 /
      data f(10,14,15),f(10,14,16) /  8.3294000d-03 ,  9.2018000d-03 /
      data f(10,14,17),f(10,14,18) /  1.0428300d-02 ,  1.1790300d-02 /
      data f(10,14,19),f(10,14,20) /  1.3034400d-02 ,  1.3919400d-02 /
      data f(10,14,21),f(10,14,22) /  1.3919400d-02 ,  1.3034400d-02 /
      data f(10,14,23) /              1.1790300d-02 /
      data f(10,15, 1),f(10,15, 2) / -5.3623400d-02 , -6.3015900d-02 /
      data f(10,15, 3),f(10,15, 4) / -6.6670400d-02 , -6.6670400d-02 /
      data f(10,15, 5),f(10,15, 6) / -6.3015900d-02 , -5.3623400d-02 /
      data f(10,15, 7),f(10,15, 8) / -3.8814700d-02 , -2.1813900d-02 /
      data f(10,15, 9),f(10,15,10) / -6.8438000d-03 ,  2.6086000d-03 /
      data f(10,15,11),f(10,15,12) /  6.3571000d-03 ,  7.3840000d-03 /
      data f(10,15,13),f(10,15,14) /  7.5724000d-03 ,  7.6909000d-03 /
      data f(10,15,15),f(10,15,16) /  8.0326000d-03 ,  8.6647000d-03 /
      data f(10,15,17),f(10,15,18) /  9.5182000d-03 ,  1.0444500d-02 /
      data f(10,15,19),f(10,15,20) /  1.1267700d-02 ,  1.1831300d-02 /
      data f(10,15,21),f(10,15,22) /  1.1831300d-02 ,  1.1267700d-02 /
      data f(10,15,23) /              1.0444500d-02 /
      data f(10,16, 1),f(10,16, 2) / -4.1123200d-02 , -5.0277700d-02 /
      data f(10,16, 3),f(10,16, 4) / -5.5695900d-02 , -5.5695900d-02 /
      data f(10,16, 5),f(10,16, 6) / -5.0277700d-02 , -4.1123200d-02 /
      data f(10,16, 7),f(10,16, 8) / -2.8958000d-02 , -1.5534700d-02 /
      data f(10,16, 9),f(10,16,10) / -3.6734000d-03 ,  4.1346000d-03 /
      data f(10,16,11),f(10,16,12) /  6.7489000d-03 ,  7.3796000d-03 /
      data f(10,16,13),f(10,16,14) /  7.4468000d-03 ,  7.4515000d-03 /
      data f(10,16,15),f(10,16,16) /  7.5787000d-03 ,  7.8707000d-03 /
      data f(10,16,17),f(10,16,18) /  8.2912000d-03 ,  8.7589000d-03 /
      data f(10,16,19),f(10,16,20) /  9.1780000d-03 ,  9.4653000d-03 /
      data f(10,16,21),f(10,16,22) /  9.4653000d-03 ,  9.1780000d-03 /
      data f(10,16,23) /              8.7589000d-03 /
      data f(10,17, 1),f(10,17, 2) / -1.8769600d-02 , -2.4946200d-02 /
      data f(10,17, 3),f(10,17, 4) / -2.8854500d-02 , -2.8854500d-02 /
      data f(10,17, 5),f(10,17, 6) / -2.4946200d-02 , -1.8769600d-02 /
      data f(10,17, 7),f(10,17, 8) / -1.0896000d-02 , -2.1614000d-03 /
      data f(10,17, 9),f(10,17,10) /  5.3411000d-03 ,  8.1712000d-03 /
      data f(10,17,11),f(10,17,12) /  8.3923000d-03 ,  8.1781000d-03 /
      data f(10,17,13),f(10,17,14) /  7.8817000d-03 ,  7.6372000d-03 /
      data f(10,17,15),f(10,17,16) /  7.4934000d-03 ,  7.4548000d-03 /
      data f(10,17,17),f(10,17,18) /  7.4997000d-03 ,  7.5928000d-03 /
      data f(10,17,19),f(10,17,20) /  7.6949000d-03 ,  7.7722000d-03 /
      data f(10,17,21),f(10,17,22) /  7.7722000d-03 ,  7.6949000d-03 /
      data f(10,17,23) /              7.5928000d-03 /
      data f(10,18, 1),f(10,18, 2) /  8.6659000d-03 ,  6.0896000d-03 /
      data f(10,18, 3),f(10,18, 4) /  4.4702000d-03 ,  4.4702000d-03 /
      data f(10,18, 5),f(10,18, 6) /  6.0896000d-03 ,  8.6659000d-03 /
      data f(10,18, 7),f(10,18, 8) /  1.2025200d-02 ,  1.2271400d-02 /
      data f(10,18, 9),f(10,18,10) /  1.1395200d-02 ,  1.0632200d-02 /
      data f(10,18,11),f(10,18,12) /  9.9728000d-03 ,  9.4110000d-03 /
      data f(10,18,13),f(10,18,14) /  8.9422000d-03 ,  8.5614000d-03 /
      data f(10,18,15),f(10,18,16) /  8.2621000d-03 ,  8.0358000d-03 /
      data f(10,18,17),f(10,18,18) /  7.8719000d-03 ,  7.7596000d-03 /
      data f(10,18,19),f(10,18,20) /  7.6881000d-03 ,  7.6490000d-03 /
      data f(10,18,21),f(10,18,22) /  7.6490000d-03 ,  7.6881000d-03 /
      data f(10,18,23) /              7.7596000d-03 /
      data f(10,19, 1),f(10,19, 2) /  1.0040500d-02 ,  1.0040500d-02 /
      data f(10,19, 3),f(10,19, 4) /  1.0040500d-02 ,  1.0040500d-02 /
      data f(10,19, 5),f(10,19, 6) /  1.0040500d-02 ,  1.0040500d-02 /
      data f(10,19, 7),f(10,19, 8) /  1.0040500d-02 ,  1.0040500d-02 /
      data f(10,19, 9),f(10,19,10) /  1.0040500d-02 ,  1.0040500d-02 /
      data f(10,19,11),f(10,19,12) /  1.0040500d-02 ,  1.0040500d-02 /
      data f(10,19,13),f(10,19,14) /  1.0040500d-02 ,  1.0040500d-02 /
      data f(10,19,15),f(10,19,16) /  1.0040500d-02 ,  1.0040500d-02 /
      data f(10,19,17),f(10,19,18) /  1.0040500d-02 ,  1.0040500d-02 /
      data f(10,19,19),f(10,19,20) /  1.0040500d-02 ,  1.0040500d-02 /
      data f(10,19,21),f(10,19,22) /  1.0040500d-02 ,  1.0040500d-02 /
      data f(10,19,23) /              1.0040500d-02 /
      data f(11, 1, 1),f(11, 1, 2) /  1.0338020d-01 ,  1.0338020d-01 /
      data f(11, 1, 3),f(11, 1, 4) /  1.0338020d-01 ,  1.0338020d-01 /
      data f(11, 1, 5),f(11, 1, 6) /  1.0338020d-01 ,  1.0338020d-01 /
      data f(11, 1, 7),f(11, 1, 8) /  1.0338020d-01 ,  1.0338020d-01 /
      data f(11, 1, 9),f(11, 1,10) /  1.0338020d-01 ,  1.0338020d-01 /
      data f(11, 1,11),f(11, 1,12) /  1.0338020d-01 ,  1.0338020d-01 /
      data f(11, 1,13),f(11, 1,14) /  1.0338020d-01 ,  1.0338020d-01 /
      data f(11, 1,15),f(11, 1,16) /  1.0338020d-01 ,  1.0338020d-01 /
      data f(11, 1,17),f(11, 1,18) /  1.0338020d-01 ,  1.0338020d-01 /
      data f(11, 1,19),f(11, 1,20) /  1.0338020d-01 ,  1.0338020d-01 /
      data f(11, 1,21),f(11, 1,22) /  1.0338020d-01 ,  1.0338020d-01 /
      data f(11, 1,23) /              1.0338020d-01 /
      data f(11, 2, 1),f(11, 2, 2) /  7.9773000d-02 ,  9.5511500d-02 /
      data f(11, 2, 3),f(11, 2, 4) /  1.0774380d-01 ,  1.0774380d-01 /
      data f(11, 2, 5),f(11, 2, 6) /  9.5511500d-02 ,  7.9773000d-02 /
      data f(11, 2, 7),f(11, 2, 8) /  6.4193300d-02 ,  5.0879200d-02 /
      data f(11, 2, 9),f(11, 2,10) /  4.0443600d-02 ,  3.3057900d-02 /
      data f(11, 2,11),f(11, 2,12) /  2.8690900d-02 ,  2.7366900d-02 /
      data f(11, 2,13),f(11, 2,14) /  2.9033800d-02 ,  3.3736600d-02 /
      data f(11, 2,15),f(11, 2,16) /  4.1480300d-02 ,  5.2279000d-02 /
      data f(11, 2,17),f(11, 2,18) /  6.5983900d-02 ,  8.1850200d-02 /
      data f(11, 2,19),f(11, 2,20) /  9.7828100d-02 ,  1.1024370d-01 /
      data f(11, 2,21),f(11, 2,22) /  1.1024370d-01 ,  9.7828100d-02 /
      data f(11, 2,23) /              8.1850200d-02 /
      data f(11, 3, 1),f(11, 3, 2) /  1.1914290d-01 ,  1.7463100d-01 /
      data f(11, 3, 3),f(11, 3, 4) /  2.1084660d-01 ,  2.1084660d-01 /
      data f(11, 3, 5),f(11, 3, 6) /  1.7463100d-01 ,  1.1914290d-01 /
      data f(11, 3, 7),f(11, 3, 8) /  2.9080900d-02 , -1.2962500d-02 /
      data f(11, 3, 9),f(11, 3,10) / -3.7915000d-02 , -5.3056100d-02 /
      data f(11, 3,11),f(11, 3,12) / -6.1670500d-02 , -6.4405800d-02 /
      data f(11, 3,13),f(11, 3,14) / -6.1528400d-02 , -5.2741100d-02 /
      data f(11, 3,15),f(11, 3,16) / -3.7275600d-02 , -1.1811600d-02 /
      data f(11, 3,17),f(11, 3,18) /  3.0767100d-02 ,  1.2137740d-01 /
      data f(11, 3,19),f(11, 3,20) /  1.7489180d-01 ,  2.1112330d-01 /
      data f(11, 3,21),f(11, 3,22) /  2.1112330d-01 ,  1.7489180d-01 /
      data f(11, 3,23) /              1.2137740d-01 /
      data f(11, 4, 1),f(11, 4, 2) /  5.2741700d-02 ,  1.6561600d-01 /
      data f(11, 4, 3),f(11, 4, 4) /  2.0672460d-01 ,  2.0672460d-01 /
      data f(11, 4, 5),f(11, 4, 6) /  1.6561600d-01 ,  5.2741700d-02 /
      data f(11, 4, 7),f(11, 4, 8) / -1.3930800d-02 , -4.8934200d-02 /
      data f(11, 4, 9),f(11, 4,10) / -7.0907500d-02 , -8.5717700d-02 /
      data f(11, 4,11),f(11, 4,12) / -9.4577100d-02 , -9.7694700d-02 /
      data f(11, 4,13),f(11, 4,14) / -9.5070500d-02 , -8.6593400d-02 /
      data f(11, 4,15),f(11, 4,16) / -7.1920200d-02 , -4.9671400d-02 /
      data f(11, 4,17),f(11, 4,18) / -1.4026800d-02 ,  5.4056900d-02 /
      data f(11, 4,19),f(11, 4,20) /  1.6585840d-01 ,  2.0701650d-01 /
      data f(11, 4,21),f(11, 4,22) /  2.0701650d-01 ,  1.6585840d-01 /
      data f(11, 4,23) /              5.4056900d-02 /
      data f(11, 5, 1),f(11, 5, 2) /  4.4448000d-03 ,  3.8012300d-02 /
      data f(11, 5, 3),f(11, 5, 4) /  7.6514800d-02 ,  7.6514800d-02 /
      data f(11, 5, 5),f(11, 5, 6) /  3.8012300d-02 ,  4.4448000d-03 /
      data f(11, 5, 7),f(11, 5, 8) / -2.3328800d-02 , -4.5743400d-02 /
      data f(11, 5, 9),f(11, 5,10) / -6.3444800d-02 , -7.6354500d-02 /
      data f(11, 5,11),f(11, 5,12) / -8.4382700d-02 , -8.7518900d-02 /
      data f(11, 5,13),f(11, 5,14) / -8.5731300d-02 , -7.8916800d-02 /
      data f(11, 5,15),f(11, 5,16) / -6.6918500d-02 , -4.9580900d-02 /
      data f(11, 5,17),f(11, 5,18) / -2.6599000d-02 ,  3.1542000d-03 /
      data f(11, 5,19),f(11, 5,20) /  4.0331700d-02 ,  8.2481100d-02 /
      data f(11, 5,21),f(11, 5,22) /  8.2481100d-02 ,  4.0331700d-02 /
      data f(11, 5,23) /              3.1542000d-03 /
      data f(11, 6, 1),f(11, 6, 2) /  6.7523000d-03 ,  2.6792800d-02 /
      data f(11, 6, 3),f(11, 6, 4) /  4.6932100d-02 ,  4.6932100d-02 /
      data f(11, 6, 5),f(11, 6, 6) /  2.6792800d-02 ,  6.7523000d-03 /
      data f(11, 6, 7),f(11, 6, 8) / -1.2024100d-02 , -2.8568900d-02 /
      data f(11, 6, 9),f(11, 6,10) / -4.2195300d-02 , -5.2496300d-02 /
      data f(11, 6,11),f(11, 6,12) / -5.9249000d-02 , -6.2312700d-02 /
      data f(11, 6,13),f(11, 6,14) / -6.1584300d-02 , -5.6977700d-02 /
      data f(11, 6,15),f(11, 6,16) / -4.8410000d-02 , -3.5830500d-02 /
      data f(11, 6,17),f(11, 6,18) / -1.9336400d-02 ,  6.5780000d-04 /
      data f(11, 6,19),f(11, 6,20) /  2.3157000d-02 ,  4.5685800d-02 /
      data f(11, 6,21),f(11, 6,22) /  4.5685800d-02 ,  2.3157000d-02 /
      data f(11, 6,23) /              6.5780000d-04 /
      data f(11, 7, 1),f(11, 7, 2) /  8.4924000d-03 ,  1.8137700d-02 /
      data f(11, 7, 3),f(11, 7, 4) /  2.5734700d-02 ,  2.5734700d-02 /
      data f(11, 7, 5),f(11, 7, 6) /  1.8137700d-02 ,  8.4924000d-03 /
      data f(11, 7, 7),f(11, 7, 8) / -1.8319000d-03 , -1.1963700d-02 /
      data f(11, 7, 9),f(11, 7,10) / -2.1173400d-02 , -2.8811900d-02 /
      data f(11, 7,11),f(11, 7,12) / -3.4342800d-02 , -3.7379200d-02 /
      data f(11, 7,13),f(11, 7,14) / -3.7697600d-02 , -3.5219800d-02 /
      data f(11, 7,15),f(11, 7,16) / -2.9976200d-02 , -2.2103000d-02 /
      data f(11, 7,17),f(11, 7,18) / -1.1891000d-02 ,  2.0200000d-05 /
      data f(11, 7,19),f(11, 7,20) /  1.2326700d-02 ,  2.2514100d-02 /
      data f(11, 7,21),f(11, 7,22) /  2.2514100d-02 ,  1.2326700d-02 /
      data f(11, 7,23) /              2.0200000d-05 /
      data f(11, 8, 1),f(11, 8, 2) /  1.0546400d-02 ,  1.4259700d-02 /
      data f(11, 8, 3),f(11, 8, 4) /  1.6747600d-02 ,  1.6747600d-02 /
      data f(11, 8, 5),f(11, 8, 6) /  1.4259700d-02 ,  1.0546400d-02 /
      data f(11, 8, 7),f(11, 8, 8) /  5.8934000d-03 ,  5.1030000d-04 /
      data f(11, 8, 9),f(11, 8,10) / -5.2260000d-03 , -1.0690500d-02 /
      data f(11, 8,11),f(11, 8,12) / -1.5194700d-02 , -1.8194300d-02 /
      data f(11, 8,13),f(11, 8,14) / -1.9369000d-02 , -1.8600400d-02 /
      data f(11, 8,15),f(11, 8,16) / -1.5938500d-02 , -1.1560200d-02 /
      data f(11, 8,17),f(11, 8,18) / -5.7954000d-03 ,  8.1130000d-04 /
      data f(11, 8,19),f(11, 8,20) /  7.3564000d-03 ,  1.2437600d-02 /
      data f(11, 8,21),f(11, 8,22) /  1.2437600d-02 ,  7.3564000d-03 /
      data f(11, 8,23) /              8.1130000d-04 /
      data f(11, 9, 1),f(11, 9, 2) /  1.2763500d-02 ,  1.4469300d-02 /
      data f(11, 9, 3),f(11, 9, 4) /  5.8305000d-03 ,  5.8305000d-03 /
      data f(11, 9, 5),f(11, 9, 6) /  1.4469300d-02 ,  1.2763500d-02 /
      data f(11, 9, 7),f(11, 9, 8) /  1.0843100d-02 ,  8.2410000d-03 /
      data f(11, 9, 9),f(11, 9,10) /  4.8456000d-03 ,  9.9900000d-04 /
      data f(11, 9,11),f(11, 9,12) / -2.6571000d-03 , -5.5140000d-03 /
      data f(11, 9,13),f(11, 9,14) / -7.1783000d-03 , -7.4834000d-03 /
      data f(11, 9,15),f(11, 9,16) / -6.4372000d-03 , -4.1769000d-03 /
      data f(11, 9,17),f(11, 9,18) / -9.4530000d-04 ,  2.8784000d-03 /
      data f(11, 9,19),f(11, 9,20) /  6.7035000d-03 ,  9.6704000d-03 /
      data f(11, 9,21),f(11, 9,22) /  9.6704000d-03 ,  6.7035000d-03 /
      data f(11, 9,23) /              2.8784000d-03 /
      data f(11,10, 1),f(11,10, 2) /  3.2440000d-03 , -9.8813000d-03 /
      data f(11,10, 3),f(11,10, 4) / -2.1463600d-02 , -2.1463600d-02 /
      data f(11,10, 5),f(11,10, 6) / -9.8813000d-03 ,  3.2440000d-03 /
      data f(11,10, 7),f(11,10, 8) /  9.2669000d-03 ,  1.0378600d-02 /
      data f(11,10, 9),f(11,10,10) /  9.3978000d-03 ,  7.1228000d-03 /
      data f(11,10,11),f(11,10,12) /  4.3630000d-03 ,  1.8658000d-03 /
      data f(11,10,13),f(11,10,14) /  1.2160000d-04 , -6.3690000d-04 /
      data f(11,10,15),f(11,10,16) / -3.6150000d-04 ,  8.7530000d-04 /
      data f(11,10,17),f(11,10,18) /  2.9078000d-03 ,  5.4563000d-03 /
      data f(11,10,19),f(11,10,20) /  8.0821000d-03 ,  1.0165100d-02 /
      data f(11,10,21),f(11,10,22) /  1.0165100d-02 ,  8.0821000d-03 /
      data f(11,10,23) /              5.4563000d-03 /
      data f(11,11, 1),f(11,11, 2) / -1.7178900d-02 , -3.3245000d-02 /
      data f(11,11, 3),f(11,11, 4) / -4.4585300d-02 , -4.4585300d-02 /
      data f(11,11, 5),f(11,11, 6) / -3.3245000d-02 , -1.7178900d-02 /
      data f(11,11, 7),f(11,11, 8) / -2.5840000d-03 ,  5.8314000d-03 /
      data f(11,11, 9),f(11,11,10) /  8.9900000d-03 ,  8.9961000d-03 /
      data f(11,11,11),f(11,11,12) /  7.4746000d-03 ,  5.6175000d-03 /
      data f(11,11,13),f(11,11,14) /  4.1335000d-03 ,  3.3630000d-03 /
      data f(11,11,15),f(11,11,16) /  3.4260000d-03 ,  4.3117000d-03 /
      data f(11,11,17),f(11,11,18) /  5.8937000d-03 ,  7.9106000d-03 /
      data f(11,11,19),f(11,11,20) /  9.9885000d-03 ,  1.1646700d-02 /
      data f(11,11,21),f(11,11,22) /  1.1646700d-02 ,  9.9885000d-03 /
      data f(11,11,23) /              7.9106000d-03 /
      data f(11,12, 1),f(11,12, 2) / -3.3757700d-02 , -4.8019700d-02 /
      data f(11,12, 3),f(11,12, 4) / -5.5236600d-02 , -5.5236600d-02 /
      data f(11,12, 5),f(11,12, 6) / -4.8019700d-02 , -3.3757700d-02 /
      data f(11,12, 7),f(11,12, 8) / -1.6678400d-02 , -2.8561000d-03 /
      data f(11,12, 9),f(11,12,10) /  5.0555000d-03 ,  7.9855000d-03 /
      data f(11,12,11),f(11,12,12) /  8.0617000d-03 ,  7.0741000d-03 /
      data f(11,12,13),f(11,12,14) /  6.0693000d-03 ,  5.5400000d-03 /
      data f(11,12,15),f(11,12,16) /  5.6825000d-03 ,  6.5291000d-03 /
      data f(11,12,17),f(11,12,18) /  7.9634000d-03 ,  9.7200000d-03 /
      data f(11,12,19),f(11,12,20) /  1.1458500d-02 ,  1.2800700d-02 /
      data f(11,12,21),f(11,12,22) /  1.2800700d-02 ,  1.1458500d-02 /
      data f(11,12,23) /              9.7200000d-03 /
      data f(11,13, 1),f(11,13, 2) / -4.3203100d-02 , -5.2962700d-02 /
      data f(11,13, 3),f(11,13, 4) / -5.4447400d-02 , -5.4447400d-02 /
      data f(11,13, 5),f(11,13, 6) / -5.2962700d-02 , -4.3203100d-02 /
      data f(11,13, 7),f(11,13, 8) / -2.7205600d-02 , -1.1212100d-02 /
      data f(11,13, 9),f(11,13,10) /  5.7300000d-05 ,  5.6100000d-03 /
      data f(11,13,11),f(11,13,12) /  7.2560000d-03 ,  7.1777000d-03 /
      data f(11,13,13),f(11,13,14) /  6.7142000d-03 ,  6.5028000d-03 /
      data f(11,13,15),f(11,13,16) /  6.8014000d-03 ,  7.6642000d-03 /
      data f(11,13,17),f(11,13,18) /  8.9825000d-03 ,  1.0509600d-02 /
      data f(11,13,19),f(11,13,20) /  1.1945100d-02 ,  1.2992300d-02 /
      data f(11,13,21),f(11,13,22) /  1.2992300d-02 ,  1.1945100d-02 /
      data f(11,13,23) /              1.0509600d-02 /
      data f(11,14, 1),f(11,14, 2) / -4.6294900d-02 , -5.3809000d-02 /
      data f(11,14, 3),f(11,14, 4) / -5.4209100d-02 , -5.4209100d-02 /
      data f(11,14, 5),f(11,14, 6) / -5.3809000d-02 , -4.6294900d-02 /
      data f(11,14, 7),f(11,14, 8) / -3.2162100d-02 , -1.6291100d-02 /
      data f(11,14, 9),f(11,14,10) / -3.6516000d-03 ,  3.4168000d-03 /
      data f(11,14,11),f(11,14,12) /  6.0844000d-03 ,  6.6719000d-03 /
      data f(11,14,13),f(11,14,14) /  6.6390000d-03 ,  6.6704000d-03 /
      data f(11,14,15),f(11,14,16) /  7.0474000d-03 ,  7.8312000d-03 /
      data f(11,14,17),f(11,14,18) /  8.9323000d-03 ,  1.0154400d-02 /
      data f(11,14,19),f(11,14,20) /  1.1261800d-02 ,  1.2036600d-02 /
      data f(11,14,21),f(11,14,22) /  1.2036600d-02 ,  1.1261800d-02 /
      data f(11,14,23) /              1.0154400d-02 /
      data f(11,15, 1),f(11,15, 2) / -4.3282000d-02 , -5.1598400d-02 /
      data f(11,15, 3),f(11,15, 4) / -5.5055100d-02 , -5.5055100d-02 /
      data f(11,15, 5),f(11,15, 6) / -5.1598400d-02 , -4.3282000d-02 /
      data f(11,15, 7),f(11,15, 8) / -3.0532800d-02 , -1.6295800d-02 /
      data f(11,15, 9),f(11,15,10) / -4.3226000d-03 ,  2.7067000d-03 /
      data f(11,15,11),f(11,15,12) /  5.4307000d-03 ,  6.1938000d-03 /
      data f(11,15,13),f(11,15,14) /  6.3325000d-03 ,  6.4358000d-03 /
      data f(11,15,15),f(11,15,16) /  6.7422000d-03 ,  7.3076000d-03 /
      data f(11,15,17),f(11,15,18) /  8.0714000d-03 ,  8.9009000d-03 /
      data f(11,15,19),f(11,15,20) /  9.6369000d-03 ,  1.0138200d-02 /
      data f(11,15,21),f(11,15,22) /  1.0138200d-02 ,  9.6369000d-03 /
      data f(11,15,23) /              8.9009000d-03 /
      data f(11,16, 1),f(11,16, 2) / -3.1669000d-02 , -3.9692000d-02 /
      data f(11,16, 3),f(11,16, 4) / -4.4489900d-02 , -4.4489900d-02 /
      data f(11,16, 5),f(11,16, 6) / -3.9692000d-02 , -3.1669000d-02 /
      data f(11,16, 7),f(11,16, 8) / -2.1175500d-02 , -1.0050700d-02 /
      data f(11,16, 9),f(11,16,10) / -7.9950000d-04 ,  4.2928000d-03 /
      data f(11,16,11),f(11,16,12) /  5.8712000d-03 ,  6.2290000d-03 /
      data f(11,16,13),f(11,16,14) /  6.2265000d-03 ,  6.2089000d-03 /
      data f(11,16,15),f(11,16,16) /  6.3130000d-03 ,  6.5690000d-03 /
      data f(11,16,17),f(11,16,18) /  6.9421000d-03 ,  7.3587000d-03 /
      data f(11,16,19),f(11,16,20) /  7.7328000d-03 ,  7.9891000d-03 /
      data f(11,16,21),f(11,16,22) /  7.9891000d-03 ,  7.7328000d-03 /
      data f(11,16,23) /              7.3587000d-03 /
      data f(11,17, 1),f(11,17, 2) / -1.1227300d-02 , -1.6633300d-02 /
      data f(11,17, 3),f(11,17, 4) / -2.0071000d-02 , -2.0071000d-02 /
      data f(11,17, 5),f(11,17, 6) / -1.6633300d-02 , -1.1227300d-02 /
      data f(11,17, 7),f(11,17, 8) / -4.4185000d-03 ,  2.8019000d-03 /
      data f(11,17, 9),f(11,17,10) /  7.0665000d-03 ,  7.4882000d-03 /
      data f(11,17,11),f(11,17,12) /  7.3068000d-03 ,  6.9687000d-03 /
      data f(11,17,13),f(11,17,14) /  6.6377000d-03 ,  6.3855000d-03 /
      data f(11,17,15),f(11,17,16) /  6.2375000d-03 ,  6.1906000d-03 /
      data f(11,17,17),f(11,17,18) /  6.2225000d-03 ,  6.3003000d-03 /
      data f(11,17,19),f(11,17,20) /  6.3881000d-03 ,  6.4553000d-03 /
      data f(11,17,21),f(11,17,22) /  6.4553000d-03 ,  6.3881000d-03 /
      data f(11,17,23) /              6.3003000d-03 /
      data f(11,18, 1),f(11,18, 2) /  1.2742300d-02 ,  1.1385100d-02 /
      data f(11,18, 3),f(11,18, 4) /  9.9675000d-03 ,  9.9675000d-03 /
      data f(11,18, 5),f(11,18, 6) /  1.1385100d-02 ,  1.2742300d-02 /
      data f(11,18, 7),f(11,18, 8) /  1.1763300d-02 ,  1.0826200d-02 /
      data f(11,18, 9),f(11,18,10) /  9.9792000d-03 ,  9.2359000d-03 /
      data f(11,18,11),f(11,18,12) /  8.5953000d-03 ,  8.0529000d-03 /
      data f(11,18,13),f(11,18,14) /  7.6033000d-03 ,  7.2399000d-03 /
      data f(11,18,15),f(11,18,16) /  6.9549000d-03 ,  6.7393000d-03 /
      data f(11,18,17),f(11,18,18) /  6.5831000d-03 ,  6.4753000d-03 /
      data f(11,18,19),f(11,18,20) /  6.4065000d-03 ,  6.3686000d-03 /
      data f(11,18,21),f(11,18,22) /  6.3686000d-03 ,  6.4065000d-03 /
      data f(11,18,23) /              6.4753000d-03 /
      data f(11,19, 1),f(11,19, 2) /  8.5945000d-03 ,  8.5945000d-03 /
      data f(11,19, 3),f(11,19, 4) /  8.5945000d-03 ,  8.5945000d-03 /
      data f(11,19, 5),f(11,19, 6) /  8.5945000d-03 ,  8.5945000d-03 /
      data f(11,19, 7),f(11,19, 8) /  8.5945000d-03 ,  8.5945000d-03 /
      data f(11,19, 9),f(11,19,10) /  8.5945000d-03 ,  8.5945000d-03 /
      data f(11,19,11),f(11,19,12) /  8.5945000d-03 ,  8.5945000d-03 /
      data f(11,19,13),f(11,19,14) /  8.5945000d-03 ,  8.5945000d-03 /
      data f(11,19,15),f(11,19,16) /  8.5945000d-03 ,  8.5945000d-03 /
      data f(11,19,17),f(11,19,18) /  8.5945000d-03 ,  8.5945000d-03 /
      data f(11,19,19),f(11,19,20) /  8.5945000d-03 ,  8.5945000d-03 /
      data f(11,19,21),f(11,19,22) /  8.5945000d-03 ,  8.5945000d-03 /
      data f(11,19,23) /              8.5945000d-03 /
      data f(12, 1, 1),f(12, 1, 2) /  7.5469000d-02 ,  7.5469000d-02 /
      data f(12, 1, 3),f(12, 1, 4) /  7.5469000d-02 ,  7.5469000d-02 /
      data f(12, 1, 5),f(12, 1, 6) /  7.5469000d-02 ,  7.5469000d-02 /
      data f(12, 1, 7),f(12, 1, 8) /  7.5469000d-02 ,  7.5469000d-02 /
      data f(12, 1, 9),f(12, 1,10) /  7.5469000d-02 ,  7.5469000d-02 /
      data f(12, 1,11),f(12, 1,12) /  7.5469000d-02 ,  7.5469000d-02 /
      data f(12, 1,13),f(12, 1,14) /  7.5469000d-02 ,  7.5469000d-02 /
      data f(12, 1,15),f(12, 1,16) /  7.5469000d-02 ,  7.5469000d-02 /
      data f(12, 1,17),f(12, 1,18) /  7.5469000d-02 ,  7.5469000d-02 /
      data f(12, 1,19),f(12, 1,20) /  7.5469000d-02 ,  7.5469000d-02 /
      data f(12, 1,21),f(12, 1,22) /  7.5469000d-02 ,  7.5469000d-02 /
      data f(12, 1,23) /              7.5469000d-02 /
      data f(12, 2, 1),f(12, 2, 2) /  5.8805900d-02 ,  7.2697100d-02 /
      data f(12, 2, 3),f(12, 2, 4) /  8.3477500d-02 ,  8.3477500d-02 /
      data f(12, 2, 5),f(12, 2, 6) /  7.2697100d-02 ,  5.8805900d-02 /
      data f(12, 2, 7),f(12, 2, 8) /  4.5000800d-02 ,  3.3076900d-02 /
      data f(12, 2, 9),f(12, 2,10) /  2.3785900d-02 ,  1.7040000d-02 /
      data f(12, 2,11),f(12, 2,12) /  1.3108000d-02 ,  1.1896100d-02 /
      data f(12, 2,13),f(12, 2,14) /  1.3435600d-02 ,  1.7718700d-02 /
      data f(12, 2,15),f(12, 2,16) /  2.4735700d-02 ,  3.4465100d-02 /
      data f(12, 2,17),f(12, 2,18) /  4.6738000d-02 ,  6.0856700d-02 /
      data f(12, 2,19),f(12, 2,20) /  7.4994700d-02 ,  8.5929100d-02 /
      data f(12, 2,21),f(12, 2,22) /  8.5929100d-02 ,  7.4994700d-02 /
      data f(12, 2,23) /              6.0856700d-02 /
      data f(12, 3, 1),f(12, 3, 2) /  9.9551100d-02 ,  1.6950070d-01 /
      data f(12, 3, 3),f(12, 3, 4) /  1.9730780d-01 ,  1.9730780d-01 /
      data f(12, 3, 5),f(12, 3, 6) /  1.6950070d-01 ,  9.9551100d-02 /
      data f(12, 3, 7),f(12, 3, 8) /  2.0825700d-02 , -1.6684800d-02 /
      data f(12, 3, 9),f(12, 3,10) / -3.9728600d-02 , -5.3872800d-02 /
      data f(12, 3,11),f(12, 3,12) / -6.1883700d-02 , -6.4477400d-02 /
      data f(12, 3,13),f(12, 3,14) / -6.1760500d-02 , -5.3562800d-02 /
      data f(12, 3,15),f(12, 3,16) / -4.1460800d-02 , -1.5587900d-02 /
      data f(12, 3,17),f(12, 3,18) /  2.2452600d-02 ,  1.0170810d-01 /
      data f(12, 3,19),f(12, 3,20) /  1.6975670d-01 ,  1.9758110d-01 /
      data f(12, 3,21),f(12, 3,22) /  1.9758110d-01 ,  1.6975670d-01 /
      data f(12, 3,23) /              1.0170810d-01 /
      data f(12, 4, 1),f(12, 4, 2) /  4.6735300d-02 ,  1.6261490d-01 /
      data f(12, 4, 3),f(12, 4, 4) /  1.9485520d-01 ,  1.9485520d-01 /
      data f(12, 4, 5),f(12, 4, 6) /  1.6261490d-01 ,  4.6735300d-02 /
      data f(12, 4, 7),f(12, 4, 8) / -1.3227400d-02 , -4.5590000d-02 /
      data f(12, 4, 9),f(12, 4,10) / -6.6463000d-02 , -8.0683900d-02 /
      data f(12, 4,11),f(12, 4,12) / -8.9228600d-02 , -9.2248600d-02 /
      data f(12, 4,13),f(12, 4,14) / -8.9734800d-02 , -8.1588000d-02 /
      data f(12, 4,15),f(12, 4,16) / -6.7526900d-02 , -4.6410300d-02 /
      data f(12, 4,17),f(12, 4,18) / -1.3285000d-02 ,  4.7934200d-02 /
      data f(12, 4,19),f(12, 4,20) /  1.6284680d-01 ,  1.9513970d-01 /
      data f(12, 4,21),f(12, 4,22) /  1.9513970d-01 ,  1.6284680d-01 /
      data f(12, 4,23) /              4.7934200d-02 /
      data f(12, 5, 1),f(12, 5, 2) /  6.6056000d-03 ,  3.8461200d-02 /
      data f(12, 5, 3),f(12, 5, 4) /  7.3919000d-02 ,  7.3919000d-02 /
      data f(12, 5, 5),f(12, 5, 6) /  3.8461200d-02 ,  6.6056000d-03 /
      data f(12, 5, 7),f(12, 5, 8) / -2.0069700d-02 , -4.1681400d-02 /
      data f(12, 5, 9),f(12, 5,10) / -5.8728700d-02 , -7.1138400d-02 /
      data f(12, 5,11),f(12, 5,12) / -7.8848400d-02 , -8.1867900d-02 /
      data f(12, 5,13),f(12, 5,14) / -8.0172600d-02 , -7.3657400d-02 /
      data f(12, 5,15),f(12, 5,16) / -6.2157800d-02 , -4.5513600d-02 /
      data f(12, 5,17),f(12, 5,18) / -2.3451000d-02 ,  4.9959000d-03 /
      data f(12, 5,19),f(12, 5,20) /  4.0347600d-02 ,  7.9496400d-02 /
      data f(12, 5,21),f(12, 5,22) /  7.9496400d-02 ,  4.0347600d-02 /
      data f(12, 5,23) /              4.9959000d-03 /
      data f(12, 6, 1),f(12, 6, 2) /  7.4532000d-03 ,  2.6410100d-02 /
      data f(12, 6, 3),f(12, 6, 4) /  4.4943100d-02 ,  4.4943100d-02 /
      data f(12, 6, 5),f(12, 6, 6) /  2.6410100d-02 ,  7.4532000d-03 /
      data f(12, 6, 7),f(12, 6, 8) / -1.0344900d-02 , -2.6013100d-02 /
      data f(12, 6, 9),f(12, 6,10) / -3.8906000d-02 , -4.8651400d-02 /
      data f(12, 6,11),f(12, 6,12) / -5.5045900d-02 , -5.7956700d-02 /
      data f(12, 6,13),f(12, 6,14) / -5.7283400d-02 , -5.2942400d-02 /
      data f(12, 6,15),f(12, 6,16) / -4.4853700d-02 , -3.2967800d-02 /
      data f(12, 6,17),f(12, 6,18) / -1.7382500d-02 ,  1.4783000d-03 /
      data f(12, 6,19),f(12, 6,20) /  2.2561600d-02 ,  4.3132200d-02 /
      data f(12, 6,21),f(12, 6,22) /  4.3132200d-02 ,  2.2561600d-02 /
      data f(12, 6,23) /              1.4783000d-03 /
      data f(12, 7, 1),f(12, 7, 2) /  7.8700000d-03 ,  1.6636300d-02 /
      data f(12, 7, 3),f(12, 7, 4) /  2.3361300d-02 ,  2.3361300d-02 /
      data f(12, 7, 5),f(12, 7, 6) /  1.6636300d-02 ,  7.8700000d-03 /
      data f(12, 7, 7),f(12, 7, 8) / -1.6202000d-03 , -1.0969900d-02 /
      data f(12, 7, 9),f(12, 7,10) / -1.9486600d-02 , -2.6567400d-02 /
      data f(12, 7,11),f(12, 7,12) / -3.1709600d-02 , -3.4544200d-02 /
      data f(12, 7,13),f(12, 7,14) / -3.4854800d-02 , -3.2563900d-02 /
      data f(12, 7,15),f(12, 7,16) / -2.7701600d-02 , -2.0395000d-02 /
      data f(12, 7,17),f(12, 7,18) / -1.0933200d-02 ,  5.9600000d-05 /
      data f(12, 7,19),f(12, 7,20) /  1.1320900d-02 ,  2.0504400d-02 /
      data f(12, 7,21),f(12, 7,22) /  2.0504400d-02 ,  1.1320900d-02 /
      data f(12, 7,23) /              5.9600000d-05 /
      data f(12, 8, 1),f(12, 8, 2) /  9.2573000d-03 ,  1.2569400d-02 /
      data f(12, 8, 3),f(12, 8, 4) /  1.4759100d-02 ,  1.4759100d-02 /
      data f(12, 8, 5),f(12, 8, 6) /  1.2569400d-02 ,  9.2573000d-03 /
      data f(12, 8, 7),f(12, 8, 8) /  5.0729000d-03 ,  2.1970000d-04 /
      data f(12, 8, 9),f(12, 8,10) / -4.9571000d-03 , -9.9013000d-03 /
      data f(12, 8,11),f(12, 8,12) / -1.3994900d-02 , -1.6737100d-02 /
      data f(12, 8,13),f(12, 8,14) / -1.7824700d-02 , -1.7140900d-02 /
      data f(12, 8,15),f(12, 8,16) / -1.4720700d-02 , -1.0729400d-02 /
      data f(12, 8,17),f(12, 8,18) / -5.4757000d-03 ,  5.2360000d-04 /
      data f(12, 8,19),f(12, 8,20) /  6.4221000d-03 ,  1.0950300d-02 /
      data f(12, 8,21),f(12, 8,22) /  1.0950300d-02 ,  6.4221000d-03 /
      data f(12, 8,23) /              5.2360000d-04 /
      data f(12, 9, 1),f(12, 9, 2) /  1.1072700d-02 ,  1.2658300d-02 /
      data f(12, 9, 3),f(12, 9, 4) /  1.1024400d-02 ,  1.1024400d-02 /
      data f(12, 9, 5),f(12, 9, 6) /  1.2658300d-02 ,  1.1072700d-02 /
      data f(12, 9, 7),f(12, 9, 8) /  9.3184000d-03 ,  7.0211000d-03 /
      data f(12, 9, 9),f(12, 9,10) /  4.0362000d-03 ,  6.4290000d-04 /
      data f(12, 9,11),f(12, 9,12) / -2.6047000d-03 , -5.1632000d-03 /
      data f(12, 9,13),f(12, 9,14) / -6.6685000d-03 , -6.9570000d-03 /
      data f(12, 9,15),f(12, 9,16) / -6.0257000d-03 , -3.9948000d-03 /
      data f(12, 9,17),f(12, 9,18) / -1.0885000d-03 ,  2.3376000d-03 /
      data f(12, 9,19),f(12, 9,20) /  5.7353000d-03 ,  8.3372000d-03 /
      data f(12, 9,21),f(12, 9,22) /  8.3372000d-03 ,  5.7353000d-03 /
      data f(12, 9,23) /              2.3376000d-03 /
      data f(12,10, 1),f(12,10, 2) /  5.3700000d-03 , -3.6785000d-03 /
      data f(12,10, 3),f(12,10, 4) / -1.3376300d-02 , -1.3376300d-02 /
      data f(12,10, 5),f(12,10, 6) / -3.6785000d-03 ,  5.3700000d-03 /
      data f(12,10, 7),f(12,10, 8) /  8.3261000d-03 ,  8.9094000d-03 /
      data f(12,10, 9),f(12,10,10) /  8.0112000d-03 ,  6.0437000d-03 /
      data f(12,10,11),f(12,10,12) /  3.6428000d-03 ,  1.4475000d-03 /
      data f(12,10,13),f(12,10,14) / -1.0150000d-04 , -7.8180000d-04 /
      data f(12,10,15),f(12,10,16) / -5.3760000d-04 ,  5.7060000d-04 /
      data f(12,10,17),f(12,10,18) /  2.3906000d-03 ,  4.6622000d-03 /
      data f(12,10,19),f(12,10,20) /  6.9760000d-03 ,  8.7764000d-03 /
      data f(12,10,21),f(12,10,22) /  8.7764000d-03 ,  6.9760000d-03 /
      data f(12,10,23) /              4.6622000d-03 /
      data f(12,11, 1),f(12,11, 2) / -1.1630600d-02 , -2.4393200d-02 /
      data f(12,11, 3),f(12,11, 4) / -3.3897300d-02 , -3.3897300d-02 /
      data f(12,11, 5),f(12,11, 6) / -2.4393200d-02 , -1.1630600d-02 /
      data f(12,11, 7),f(12,11, 8) / -8.0830000d-04 ,  5.3040000d-03 /
      data f(12,11, 9),f(12,11,10) /  7.6954000d-03 ,  7.6552000d-03 /
      data f(12,11,11),f(12,11,12) /  6.3506000d-03 ,  4.7444000d-03 /
      data f(12,11,13),f(12,11,14) /  3.4470000d-03 ,  2.7706000d-03 /
      data f(12,11,15),f(12,11,16) /  2.8347000d-03 ,  3.6343000d-03 /
      data f(12,11,17),f(12,11,18) /  5.0564000d-03 ,  6.8603000d-03 /
      data f(12,11,19),f(12,11,20) /  8.6918000d-03 ,  1.0112900d-02 /
      data f(12,11,21),f(12,11,22) /  1.0112900d-02 ,  8.6918000d-03 /
      data f(12,11,23) /              6.8603000d-03 /
      data f(12,12, 1),f(12,12, 2) / -2.5914700d-02 , -3.7391000d-02 /
      data f(12,12, 3),f(12,12, 4) / -4.3274700d-02 , -4.3274700d-02 /
      data f(12,12, 5),f(12,12, 6) / -3.7391000d-02 , -2.5914700d-02 /
      data f(12,12, 7),f(12,12, 8) / -1.2466600d-02 , -1.7483000d-03 /
      data f(12,12, 9),f(12,12,10) /  4.4411000d-03 ,  6.7806000d-03 /
      data f(12,12,11),f(12,12,12) /  6.8291000d-03 ,  5.9870000d-03 /
      data f(12,12,13),f(12,12,14) /  5.1230000d-03 ,  4.6695000d-03 /
      data f(12,12,15),f(12,12,16) /  4.8087000d-03 ,  5.5745000d-03 /
      data f(12,12,17),f(12,12,18) /  6.8668000d-03 ,  8.4436000d-03 /
      data f(12,12,19),f(12,12,20) /  9.9802000d-03 ,  1.1130200d-02 /
      data f(12,12,21),f(12,12,22) /  1.1130200d-02 ,  9.9802000d-03 /
      data f(12,12,23) /              8.4436000d-03 /
      data f(12,13, 1),f(12,13, 2) / -3.3955100d-02 , -4.1663900d-02 /
      data f(12,13, 3),f(12,13, 4) / -4.2658200d-02 , -4.2658200d-02 /
      data f(12,13, 5),f(12,13, 6) / -4.1663900d-02 , -3.3955100d-02 /
      data f(12,13, 7),f(12,13, 8) / -2.1193300d-02 , -8.5120000d-03 /
      data f(12,13, 9),f(12,13,10) /  3.7410000d-04 ,  4.7800000d-03 /
      data f(12,13,11),f(12,13,12) /  6.1100000d-03 ,  6.0414000d-03 /
      data f(12,13,13),f(12,13,14) /  5.6521000d-03 ,  5.4817000d-03 /
      data f(12,13,15),f(12,13,16) /  5.7582000d-03 ,  6.5343000d-03 /
      data f(12,13,17),f(12,13,18) /  7.7187000d-03 ,  9.0889000d-03 /
      data f(12,13,19),f(12,13,20) /  1.0362400d-02 ,  1.1270500d-02 /
      data f(12,13,21),f(12,13,22) /  1.1270500d-02 ,  1.0362400d-02 /
      data f(12,13,23) /              9.0889000d-03 /
      data f(12,14, 1),f(12,14, 2) / -3.6379900d-02 , -4.2290100d-02 /
      data f(12,14, 3),f(12,14, 4) / -4.2389800d-02 , -4.2389800d-02 /
      data f(12,14, 5),f(12,14, 6) / -4.2290100d-02 , -3.6379900d-02 /
      data f(12,14, 7),f(12,14, 8) / -2.5012800d-02 , -1.2327400d-02 /
      data f(12,14, 9),f(12,14,10) / -2.4308000d-03 ,  3.0220000d-03 /
      data f(12,14,11),f(12,14,12) /  5.1101000d-03 ,  5.5791000d-03 /
      data f(12,14,13),f(12,14,14) /  5.5535000d-03 ,  5.5924000d-03 /
      data f(12,14,15),f(12,14,16) /  5.9347000d-03 ,  6.6359000d-03 /
      data f(12,14,17),f(12,14,18) /  7.6207000d-03 ,  8.7144000d-03 /
      data f(12,14,19),f(12,14,20) /  9.7009000d-03 ,  1.0383000d-02 /
      data f(12,14,21),f(12,14,22) /  1.0383000d-02 ,  9.7009000d-03 /
      data f(12,14,23) /              8.7144000d-03 /
      data f(12,15, 1),f(12,15, 2) / -3.3391700d-02 , -4.0158800d-02 /
      data f(12,15, 3),f(12,15, 4) / -4.2915300d-02 , -4.2915300d-02 /
      data f(12,15, 5),f(12,15, 6) / -4.0158800d-02 , -3.3391700d-02 /
      data f(12,15, 7),f(12,15, 8) / -2.3012400d-02 , -1.1634200d-02 /
      data f(12,15, 9),f(12,15,10) / -2.4480000d-03 ,  2.6281000d-03 /
      data f(12,15,11),f(12,15,12) /  4.6052000d-03 ,  5.1676000d-03 /
      data f(12,15,13),f(12,15,14) /  5.2667000d-03 ,  5.3563000d-03 /
      data f(12,15,15),f(12,15,16) /  5.6302000d-03 ,  6.1340000d-03 /
      data f(12,15,17),f(12,15,18) /  6.8146000d-03 ,  7.5549000d-03 /
      data f(12,15,19),f(12,15,20) /  8.2114000d-03 ,  8.6570000d-03 /
      data f(12,15,21),f(12,15,22) /  8.6570000d-03 ,  8.2114000d-03 /
      data f(12,15,23) /              7.5549000d-03 /
      data f(12,16, 1),f(12,16, 2) / -2.2729800d-02 , -2.9447300d-02 /
      data f(12,16, 3),f(12,16, 4) / -3.3485500d-02 , -3.3485500d-02 /
      data f(12,16, 5),f(12,16, 6) / -2.9447300d-02 , -2.2729800d-02 /
      data f(12,16, 7),f(12,16, 8) / -1.4124500d-02 , -5.5987000d-03 /
      data f(12,16, 9),f(12,16,10) /  1.2093000d-03 ,  4.1477000d-03 /
      data f(12,16,11),f(12,16,12) /  5.0628000d-03 ,  5.2303000d-03 /
      data f(12,16,13),f(12,16,14) /  5.1774000d-03 ,  5.1429000d-03 /
      data f(12,16,15),f(12,16,16) /  5.2275000d-03 ,  5.4511000d-03 /
      data f(12,16,17),f(12,16,18) /  5.7808000d-03 ,  6.1505000d-03 /
      data f(12,16,19),f(12,16,20) /  6.4829000d-03 ,  6.7109000d-03 /
      data f(12,16,21),f(12,16,22) /  6.7109000d-03 ,  6.4829000d-03 /
      data f(12,16,23) /              6.1505000d-03 /
      data f(12,17, 1),f(12,17, 2) / -4.1918000d-03 , -8.7865000d-03 /
      data f(12,17, 3),f(12,17, 4) / -1.1729000d-02 , -1.1729000d-02 /
      data f(12,17, 5),f(12,17, 6) / -8.7865000d-03 , -4.1918000d-03 /
      data f(12,17, 7),f(12,17, 8) /  1.4548000d-03 ,  4.7963000d-03 /
      data f(12,17, 9),f(12,17,10) /  6.9732000d-03 ,  6.7201000d-03 /
      data f(12,17,11),f(12,17,12) /  6.3196000d-03 ,  5.9110000d-03 /
      data f(12,17,13),f(12,17,14) /  5.5631000d-03 ,  5.3097000d-03 /
      data f(12,17,15),f(12,17,16) /  5.1607000d-03 ,  5.1080000d-03 /
      data f(12,17,17),f(12,17,18) /  5.1291000d-03 ,  5.1936000d-03 /
      data f(12,17,19),f(12,17,20) /  5.2686000d-03 ,  5.3267000d-03 /
      data f(12,17,21),f(12,17,22) /  5.3267000d-03 ,  5.2686000d-03 /
      data f(12,17,23) /              5.1936000d-03 /
      data f(12,18, 1),f(12,18, 2) /  1.1243000d-02 ,  1.2034400d-02 /
      data f(12,18, 3),f(12,18, 4) /  1.2597700d-02 ,  1.2597700d-02 /
      data f(12,18, 5),f(12,18, 6) /  1.2034400d-02 ,  1.1243000d-02 /
      data f(12,18, 7),f(12,18, 8) /  1.0363200d-02 ,  9.4966000d-03 /
      data f(12,18, 9),f(12,18,10) /  8.6988000d-03 ,  7.9923000d-03 /
      data f(12,18,11),f(12,18,12) /  7.3823000d-03 ,  6.8668000d-03 /
      data f(12,18,13),f(12,18,14) /  6.4407000d-03 ,  6.0970000d-03 /
      data f(12,18,15),f(12,18,16) /  5.8277000d-03 ,  5.6237000d-03 /
      data f(12,18,17),f(12,18,18) /  5.4755000d-03 ,  5.3729000d-03 /
      data f(12,18,19),f(12,18,20) /  5.3071000d-03 ,  5.2716000d-03 /
      data f(12,18,21),f(12,18,22) /  5.2716000d-03 ,  5.3071000d-03 /
      data f(12,18,23) /              5.3729000d-03 /
      data f(12,19, 1),f(12,19, 2) /  7.3352000d-03 ,  7.3352000d-03 /
      data f(12,19, 3),f(12,19, 4) /  7.3352000d-03 ,  7.3352000d-03 /
      data f(12,19, 5),f(12,19, 6) /  7.3352000d-03 ,  7.3352000d-03 /
      data f(12,19, 7),f(12,19, 8) /  7.3352000d-03 ,  7.3352000d-03 /
      data f(12,19, 9),f(12,19,10) /  7.3352000d-03 ,  7.3352000d-03 /
      data f(12,19,11),f(12,19,12) /  7.3352000d-03 ,  7.3352000d-03 /
      data f(12,19,13),f(12,19,14) /  7.3352000d-03 ,  7.3352000d-03 /
      data f(12,19,15),f(12,19,16) /  7.3352000d-03 ,  7.3352000d-03 /
      data f(12,19,17),f(12,19,18) /  7.3352000d-03 ,  7.3352000d-03 /
      data f(12,19,19),f(12,19,20) /  7.3352000d-03 ,  7.3352000d-03 /
      data f(12,19,21),f(12,19,22) /  7.3352000d-03 ,  7.3352000d-03 /
      data f(12,19,23) /              7.3352000d-03 /
      data f(13, 1, 1),f(13, 1, 2) /  5.6895400d-02 ,  5.6895400d-02 /
      data f(13, 1, 3),f(13, 1, 4) /  5.6895400d-02 ,  5.6895400d-02 /
      data f(13, 1, 5),f(13, 1, 6) /  5.6895400d-02 ,  5.6895400d-02 /
      data f(13, 1, 7),f(13, 1, 8) /  5.6895400d-02 ,  5.6895400d-02 /
      data f(13, 1, 9),f(13, 1,10) /  5.6895400d-02 ,  5.6895400d-02 /
      data f(13, 1,11),f(13, 1,12) /  5.6895400d-02 ,  5.6895400d-02 /
      data f(13, 1,13),f(13, 1,14) /  5.6895400d-02 ,  5.6895400d-02 /
      data f(13, 1,15),f(13, 1,16) /  5.6895400d-02 ,  5.6895400d-02 /
      data f(13, 1,17),f(13, 1,18) /  5.6895400d-02 ,  5.6895400d-02 /
      data f(13, 1,19),f(13, 1,20) /  5.6895400d-02 ,  5.6895400d-02 /
      data f(13, 1,21),f(13, 1,22) /  5.6895400d-02 ,  5.6895400d-02 /
      data f(13, 1,23) /              5.6895400d-02 /
      data f(13, 2, 1),f(13, 2, 2) /  4.3991400d-02 ,  5.6003600d-02 /
      data f(13, 2, 3),f(13, 2, 4) /  6.5283600d-02 ,  6.5283600d-02 /
      data f(13, 2, 5),f(13, 2, 6) /  5.6003600d-02 ,  4.3991400d-02 /
      data f(13, 2, 7),f(13, 2, 8) /  3.1922600d-02 ,  2.1384100d-02 /
      data f(13, 2, 9),f(13, 2,10) /  1.3041800d-02 ,  7.0493000d-03 /
      data f(13, 2,11),f(13, 2,12) /  3.4869000d-03 ,  2.3994000d-03 /
      data f(13, 2,13),f(13, 2,14) /  3.8081000d-03 ,  7.6979000d-03 /
      data f(13, 2,15),f(13, 2,16) /  1.4027800d-02 ,  2.2728600d-02 /
      data f(13, 2,17),f(13, 2,18) /  3.3592700d-02 ,  4.5965500d-02 /
      data f(13, 2,19),f(13, 2,20) /  5.8235300d-02 ,  6.7656400d-02 /
      data f(13, 2,21),f(13, 2,22) /  6.7656400d-02 ,  5.8235300d-02 /
      data f(13, 2,23) /              4.5965500d-02 /
      data f(13, 3, 1),f(13, 3, 2) /  8.1531100d-02 ,  1.6456590d-01 /
      data f(13, 3, 3),f(13, 3, 4) /  1.8504850d-01 ,  1.8504850d-01 /
      data f(13, 3, 5),f(13, 3, 6) /  1.6456590d-01 ,  8.1531100d-02 /
      data f(13, 3, 7),f(13, 3, 8) /  1.4515900d-02 , -1.8374300d-02 /
      data f(13, 3, 9),f(13, 3,10) / -3.9459200d-02 , -5.2614200d-02 /
      data f(13, 3,11),f(13, 3,12) / -6.0162500d-02 , -6.2625700d-02 /
      data f(13, 3,13),f(13, 3,14) / -6.0062500d-02 , -5.2350000d-02 /
      data f(13, 3,15),f(13, 3,16) / -3.8910300d-02 , -1.7350300d-02 /
      data f(13, 3,17),f(13, 3,18) /  1.6062100d-02 ,  8.3612400d-02 /
      data f(13, 3,19),f(13, 3,20) /  1.6481370d-01 ,  1.8531660d-01 /
      data f(13, 3,21),f(13, 3,22) /  1.8531660d-01 ,  1.6481370d-01 /
      data f(13, 3,23) /              8.3612400d-02 /
      data f(13, 4, 1),f(13, 4, 2) /  4.0876100d-02 ,  1.5958910d-01 /
      data f(13, 4, 3),f(13, 4, 4) /  1.8389010d-01 ,  1.8389010d-01 /
      data f(13, 4, 5),f(13, 4, 6) /  1.5958910d-01 ,  4.0876100d-02 /
      data f(13, 4, 7),f(13, 4, 8) / -1.1997500d-02 , -4.1856900d-02 /
      data f(13, 4, 9),f(13, 4,10) / -6.1653900d-02 , -7.5292400d-02 /
      data f(13, 4,11),f(13, 4,12) / -8.3520700d-02 , -8.6441300d-02 /
      data f(13, 4,13),f(13, 4,14) / -8.4039700d-02 , -7.6226800d-02 /
      data f(13, 4,15),f(13, 4,16) / -6.2772800d-02 , -4.2770500d-02 /
      data f(13, 4,17),f(13, 4,18) / -1.2170000d-02 ,  4.1932600d-02 /
      data f(13, 4,19),f(13, 4,20) /  1.5980890d-01 ,  1.8416670d-01 /
      data f(13, 4,21),f(13, 4,22) /  1.8416670d-01 ,  1.5980890d-01 /
      data f(13, 4,23) /              4.1932600d-02 /
      data f(13, 5, 1),f(13, 5, 2) /  8.5899000d-03 ,  3.8808100d-02 /
      data f(13, 5, 3),f(13, 5, 4) /  7.1208700d-02 ,  7.1208700d-02 /
      data f(13, 5, 5),f(13, 5, 6) /  3.8808100d-02 ,  8.5899000d-03 /
      data f(13, 5, 7),f(13, 5, 8) / -1.6952000d-02 , -3.7718300d-02 /
      data f(13, 5, 9),f(13, 5,10) / -5.4077800d-02 , -6.5964200d-02 /
      data f(13, 5,11),f(13, 5,12) / -7.3342700d-02 , -7.6239900d-02 /
      data f(13, 5,13),f(13, 5,14) / -7.4638400d-02 , -6.8431600d-02 /
      data f(13, 5,15),f(13, 5,16) / -5.7448300d-02 , -4.1524500d-02 /
      data f(13, 5,17),f(13, 5,18) / -2.0420300d-02 ,  6.6650000d-03 /
      data f(13, 5,19),f(13, 5,20) /  4.0222600d-02 ,  7.6347900d-02 /
      data f(13, 5,21),f(13, 5,22) /  7.6347900d-02 ,  4.0222600d-02 /
      data f(13, 5,23) /              6.6650000d-03 /
      data f(13, 6, 1),f(13, 6, 2) /  7.9177000d-03 ,  2.5645800d-02 /
      data f(13, 6, 3),f(13, 6, 4) /  4.2398800d-02 ,  4.2398800d-02 /
      data f(13, 6, 5),f(13, 6, 6) /  2.5645800d-02 ,  7.9177000d-03 /
      data f(13, 6, 7),f(13, 6, 8) / -8.8324000d-03 , -2.3591500d-02 /
      data f(13, 6, 9),f(13, 6,10) / -3.5736000d-02 , -4.4919300d-02 /
      data f(13, 6,11),f(13, 6,12) / -5.0952300d-02 , -5.3707900d-02 /
      data f(13, 6,13),f(13, 6,14) / -5.3087200d-02 , -4.9009700d-02 /
      data f(13, 6,15),f(13, 6,16) / -4.1399600d-02 , -3.0212100d-02 /
      data f(13, 6,17),f(13, 6,18) / -1.5548900d-02 ,  2.1500000d-03 /
      data f(13, 6,19),f(13, 6,20) /  2.1770100d-02 ,  4.0408300d-02 /
      data f(13, 6,21),f(13, 6,22) /  4.0408300d-02 ,  2.1770100d-02 /
      data f(13, 6,23) /              2.1500000d-03 /
      data f(13, 7, 1),f(13, 7, 2) /  7.2434000d-03 ,  1.5181500d-02 /
      data f(13, 7, 3),f(13, 7, 4) /  2.1138000d-02 ,  2.1138000d-02 /
      data f(13, 7, 5),f(13, 7, 6) /  1.5181500d-02 ,  7.2434000d-03 /
      data f(13, 7, 7),f(13, 7, 8) / -1.4420000d-03 , -1.0035100d-02 /
      data f(13, 7, 9),f(13, 7,10) / -1.7881400d-02 , -2.4421200d-02 /
      data f(13, 7,11),f(13, 7,12) / -2.9184100d-02 , -3.1819700d-02 /
      data f(13, 7,13),f(13, 7,14) / -3.2119400d-02 , -3.0007100d-02 /
      data f(13, 7,15),f(13, 7,16) / -2.5510700d-02 , -1.8753300d-02 /
      data f(13, 7,17),f(13, 7,18) / -1.0015800d-02 ,  9.5300000d-05 /
      data f(13, 7,19),f(13, 7,20) /  1.0368700d-02 ,  1.8632600d-02 /
      data f(13, 7,21),f(13, 7,22) /  1.8632600d-02 ,  1.0368700d-02 /
      data f(13, 7,23) /              9.5300000d-05 /
      data f(13, 8, 1),f(13, 8, 2) /  8.0874000d-03 ,  1.1042100d-02 /
      data f(13, 8, 3),f(13, 8, 4) /  1.2977300d-02 ,  1.2977300d-02 /
      data f(13, 8, 5),f(13, 8, 6) /  1.1042100d-02 ,  8.0874000d-03 /
      data f(13, 8, 7),f(13, 8, 8) /  4.3320000d-03 , -3.1900000d-05 /
      data f(13, 8, 9),f(13, 8,10) / -4.6905000d-03 , -9.1507000d-03 /
      data f(13, 8,11),f(13, 8,12) / -1.2858800d-02 , -1.5355900d-02 /
      data f(13, 8,13),f(13, 8,14) / -1.6357200d-02 , -1.5748200d-02 /
      data f(13, 8,15),f(13, 8,16) / -1.3555000d-02 , -9.9271000d-03 /
      data f(13, 8,17),f(13, 8,18) / -5.1530000d-03 ,  2.8060000d-04 /
      data f(13, 8,19),f(13, 8,20) /  5.5856000d-03 ,  9.6181000d-03 /
      data f(13, 8,21),f(13, 8,22) /  9.6181000d-03 ,  5.5856000d-03 /
      data f(13, 8,23) /              2.8060000d-04 /
      data f(13, 9, 1),f(13, 9, 2) /  9.5800000d-03 ,  1.1171500d-02 /
      data f(13, 9, 3),f(13, 9, 4) /  1.5778100d-02 ,  1.5778100d-02 /
      data f(13, 9, 5),f(13, 9, 6) /  1.1171500d-02 ,  9.5800000d-03 /
      data f(13, 9, 7),f(13, 9, 8) /  7.9812000d-03 ,  5.9497000d-03 /
      data f(13, 9, 9),f(13, 9,10) /  3.3263000d-03 ,  3.3680000d-04 /
      data f(13, 9,11),f(13, 9,12) / -2.5418000d-03 , -4.8263000d-03 /
      data f(13, 9,13),f(13, 9,14) / -6.1822000d-03 , -6.4522000d-03 /
      data f(13, 9,15),f(13, 9,16) / -5.6252000d-03 , -3.8055000d-03 /
      data f(13, 9,17),f(13, 9,18) / -1.1988000d-03 ,  1.8638000d-03 /
      data f(13, 9,19),f(13, 9,20) /  4.8776000d-03 ,  7.1600000d-03 /
      data f(13, 9,21),f(13, 9,22) /  7.1600000d-03 ,  4.8776000d-03 /
      data f(13, 9,23) /              1.8638000d-03 /
      data f(13,10, 1),f(13,10, 2) /  6.1284000d-03 ,  1.4910000d-03 /
      data f(13,10, 3),f(13,10, 4) / -5.8212000d-03 , -5.8212000d-03 /
      data f(13,10, 5),f(13,10, 6) /  1.4910000d-03 ,  6.1284000d-03 /
      data f(13,10, 7),f(13,10, 8) /  7.3798000d-03 ,  7.6225000d-03 /
      data f(13,10, 9),f(13,10,10) /  6.8030000d-03 ,  5.0991000d-03 /
      data f(13,10,11),f(13,10,12) /  3.0114000d-03 ,  1.0846000d-03 /
      data f(13,10,13),f(13,10,14) / -2.8800000d-04 , -8.9690000d-04 /
      data f(13,10,15),f(13,10,16) / -6.8170000d-04 ,  3.0770000d-04 /
      data f(13,10,17),f(13,10,18) /  1.9324000d-03 ,  3.9518000d-03 /
      data f(13,10,19),f(13,10,20) /  5.9887000d-03 ,  7.5474000d-03 /
      data f(13,10,21),f(13,10,22) /  7.5474000d-03 ,  5.9887000d-03 /
      data f(13,10,23) /              3.9518000d-03 /
      data f(13,11, 1),f(13,11, 2) / -7.1022000d-03 , -1.6340300d-02 /
      data f(13,11, 3),f(13,11, 4) / -2.3658200d-02 , -2.3658200d-02 /
      data f(13,11, 5),f(13,11, 6) / -1.6340300d-02 , -7.1022000d-03 /
      data f(13,11, 7),f(13,11, 8) /  3.7260000d-04 ,  4.7459000d-03 /
      data f(13,11, 9),f(13,11,10) /  6.5613000d-03 ,  6.4902000d-03 /
      data f(13,11,11),f(13,11,12) /  5.3701000d-03 ,  3.9811000d-03 /
      data f(13,11,13),f(13,11,14) /  2.8474000d-03 ,  2.2534000d-03 /
      data f(13,11,15),f(13,11,16) /  2.3159000d-03 ,  3.0342000d-03 /
      data f(13,11,17),f(13,11,18) /  4.3070000d-03 ,  5.9151000d-03 /
      data f(13,11,19),f(13,11,20) /  7.5289000d-03 ,  8.7515000d-03 /
      data f(13,11,21),f(13,11,22) /  8.7515000d-03 ,  7.5289000d-03 /
      data f(13,11,23) /              5.9151000d-03 /
      data f(13,12, 1),f(13,12, 2) / -1.9052200d-02 , -2.7360400d-02 /
      data f(13,12, 3),f(13,12, 4) / -3.1304800d-02 , -3.1304800d-02 /
      data f(13,12, 5),f(13,12, 6) / -2.7360400d-02 , -1.9052200d-02 /
      data f(13,12, 7),f(13,12, 8) / -9.0879000d-03 , -9.7410000d-04 /
      data f(13,12, 9),f(13,12,10) /  3.8586000d-03 ,  5.7330000d-03 /
      data f(13,12,11),f(13,12,12) /  5.7611000d-03 ,  5.0425000d-03 /
      data f(13,12,13),f(13,12,14) /  4.2988000d-03 ,  3.9092000d-03 /
      data f(13,12,15),f(13,12,16) /  4.0421000d-03 ,  4.7313000d-03 /
      data f(13,12,17),f(13,12,18) /  5.8901000d-03 ,  7.3004000d-03 /
      data f(13,12,19),f(13,12,20) /  8.6596000d-03 ,  9.6527000d-03 /
      data f(13,12,21),f(13,12,22) /  9.6527000d-03 ,  8.6596000d-03 /
      data f(13,12,23) /              7.3004000d-03 /
      data f(13,13, 1),f(13,13, 2) / -2.5583600d-02 , -3.0624300d-02 /
      data f(13,13, 3),f(13,13, 4) / -3.0165400d-02 , -3.0165400d-02 /
      data f(13,13, 5),f(13,13, 6) / -3.0624300d-02 , -2.5583600d-02 /
      data f(13,13, 7),f(13,13, 8) / -1.6121500d-02 , -6.3940000d-03 /
      data f(13,13, 9),f(13,13,10) /  5.4180000d-04 ,  4.0427000d-03 /
      data f(13,13,11),f(13,13,12) /  5.1205000d-03 ,  5.0603000d-03 /
      data f(13,13,13),f(13,13,14) /  4.7327000d-03 ,  4.5949000d-03 /
      data f(13,13,15),f(13,13,16) /  4.8485000d-03 ,  5.5436000d-03 /
      data f(13,13,17),f(13,13,18) /  6.6031000d-03 ,  7.8287000d-03 /
      data f(13,13,19),f(13,13,20) /  8.9596000d-03 ,  9.7532000d-03 /
      data f(13,13,21),f(13,13,22) /  9.7532000d-03 ,  8.9596000d-03 /
      data f(13,13,23) /              7.8287000d-03 /
      data f(13,14, 1),f(13,14, 2) / -2.7227800d-02 , -3.0894100d-02 /
      data f(13,14, 3),f(13,14, 4) / -2.9806700d-02 , -2.9806700d-02 /
      data f(13,14, 5),f(13,14, 6) / -3.0894100d-02 , -2.7227800d-02 /
      data f(13,14, 7),f(13,14, 8) / -1.8821900d-02 , -9.1292000d-03 /
      data f(13,14, 9),f(13,14,10) / -1.5596000d-03 ,  2.6272000d-03 /
      data f(13,14,11),f(13,14,12) /  4.2655000d-03 ,  4.6396000d-03 /
      data f(13,14,13),f(13,14,14) /  4.6195000d-03 ,  4.6624000d-03 /
      data f(13,14,15),f(13,14,16) /  4.9715000d-03 ,  5.5961000d-03 /
      data f(13,14,17),f(13,14,18) /  6.4734000d-03 ,  7.4492000d-03 /
      data f(13,14,19),f(13,14,20) /  8.3270000d-03 ,  8.9286000d-03 /
      data f(13,14,21),f(13,14,22) /  8.9286000d-03 ,  8.3270000d-03 /
      data f(13,14,23) /              7.4492000d-03 /
      data f(13,15, 1),f(13,15, 2) / -2.4231400d-02 , -2.9044700d-02 /
      data f(13,15, 3),f(13,15, 4) / -3.0676000d-02 , -3.0676000d-02 /
      data f(13,15, 5),f(13,15, 6) / -2.9044700d-02 , -2.4231400d-02 /
      data f(13,15, 7),f(13,15, 8) / -1.6435500d-02 , -7.8385000d-03 /
      data f(13,15, 9),f(13,15,10) / -1.1413000d-03 ,  2.4462000d-03 /
      data f(13,15,11),f(13,15,12) /  3.8761000d-03 ,  4.2851000d-03 /
      data f(13,15,13),f(13,15,14) /  4.3529000d-03 ,  4.4305000d-03 /
      data f(13,15,15),f(13,15,16) /  4.6743000d-03 ,  5.1213000d-03 /
      data f(13,15,17),f(13,15,18) /  5.7253000d-03 ,  6.3833000d-03 /
      data f(13,15,19),f(13,15,20) /  6.9668000d-03 ,  7.3620000d-03 /
      data f(13,15,21),f(13,15,22) /  7.3620000d-03 ,  6.9668000d-03 /
      data f(13,15,23) /              6.3833000d-03 /
      data f(13,16, 1),f(13,16, 2) / -1.4487300d-02 , -1.9724600d-02 /
      data f(13,16, 3),f(13,16, 4) / -2.2882200d-02 , -2.2882200d-02 /
      data f(13,16, 5),f(13,16, 6) / -1.9724600d-02 , -1.4487300d-02 /
      data f(13,16, 7),f(13,16, 8) / -8.0827000d-03 , -1.8918000d-03 /
      data f(13,16, 9),f(13,16,10) / -3.5026000d-03 ,  3.8513000d-03 /
      data f(13,16,11),f(13,16,12) /  4.3311000d-03 ,  4.3657000d-03 /
      data f(13,16,13),f(13,16,14) /  4.2775000d-03 ,  4.2310000d-03 /
      data f(13,16,15),f(13,16,16) /  4.2991000d-03 ,  4.4938000d-03 /
      data f(13,16,17),f(13,16,18) /  4.7839000d-03 ,  5.1104000d-03 /
      data f(13,16,19),f(13,16,20) /  5.4044000d-03 ,  5.6062000d-03 /
      data f(13,16,21),f(13,16,22) /  5.6062000d-03 ,  5.4044000d-03 /
      data f(13,16,23) /              5.1104000d-03 /
      data f(13,17, 1),f(13,17, 2) /  2.2511000d-03 , -1.4864000d-03 /
      data f(13,17, 3),f(13,17, 4) / -3.9145000d-03 , -3.9145000d-03 /
      data f(13,17, 5),f(13,17, 6) / -1.4864000d-03 ,  2.2511000d-03 /
      data f(13,17, 7),f(13,17, 8) /  6.4680000d-03 ,  7.1164000d-03 /
      data f(13,17, 9),f(13,17,10) /  6.5194000d-03 ,  5.9502000d-03 /
      data f(13,17,11),f(13,17,12) /  5.4328000d-03 ,  4.9887000d-03 /
      data f(13,17,13),f(13,17,14) /  4.6365000d-03 ,  4.3869000d-03 /
      data f(13,17,15),f(13,17,16) /  4.2397000d-03 ,  4.1834000d-03 /
      data f(13,17,17),f(13,17,18) /  4.1957000d-03 ,  4.2486000d-03 /
      data f(13,17,19),f(13,17,20) /  4.3129000d-03 ,  4.3623000d-03 /
      data f(13,17,21),f(13,17,22) /  4.3623000d-03 ,  4.3129000d-03 /
      data f(13,17,23) /              4.2486000d-03 /
      data f(13,18, 1),f(13,18, 2) /  9.8723000d-03 ,  1.0566300d-02 /
      data f(13,18, 3),f(13,18, 4) /  1.1051800d-02 ,  1.1051800d-02 /
      data f(13,18, 5),f(13,18, 6) /  1.0566300d-02 ,  9.8723000d-03 /
      data f(13,18, 7),f(13,18, 8) /  9.0836000d-03 ,  8.2910000d-03 /
      data f(13,18, 9),f(13,18,10) /  7.5506000d-03 ,  6.8893000d-03 /
      data f(13,18,11),f(13,18,12) /  6.3165000d-03 ,  5.8323000d-03 /
      data f(13,18,13),f(13,18,14) /  5.4321000d-03 ,  5.1096000d-03 /
      data f(13,18,15),f(13,18,16) /  4.8568000d-03 ,  4.6653000d-03 /
      data f(13,18,17),f(13,18,18) /  4.5255000d-03 ,  4.4285000d-03 /
      data f(13,18,19),f(13,18,20) /  4.3661000d-03 ,  4.3322000d-03 /
      data f(13,18,21),f(13,18,22) /  4.3322000d-03 ,  4.3661000d-03 /
      data f(13,18,23) /              4.4285000d-03 /
      data f(13,19, 1),f(13,19, 2) /  6.2388000d-03 ,  6.2388000d-03 /
      data f(13,19, 3),f(13,19, 4) /  6.2388000d-03 ,  6.2388000d-03 /
      data f(13,19, 5),f(13,19, 6) /  6.2388000d-03 ,  6.2388000d-03 /
      data f(13,19, 7),f(13,19, 8) /  6.2388000d-03 ,  6.2388000d-03 /
      data f(13,19, 9),f(13,19,10) /  6.2388000d-03 ,  6.2388000d-03 /
      data f(13,19,11),f(13,19,12) /  6.2388000d-03 ,  6.2388000d-03 /
      data f(13,19,13),f(13,19,14) /  6.2388000d-03 ,  6.2388000d-03 /
      data f(13,19,15),f(13,19,16) /  6.2388000d-03 ,  6.2388000d-03 /
      data f(13,19,17),f(13,19,18) /  6.2388000d-03 ,  6.2388000d-03 /
      data f(13,19,19),f(13,19,20) /  6.2388000d-03 ,  6.2388000d-03 /
      data f(13,19,21),f(13,19,22) /  6.2388000d-03 ,  6.2388000d-03 /
      data f(13,19,23) /              6.2388000d-03 /
      data f(14, 1, 1),f(14, 1, 2) /  4.5426000d-02 ,  4.5426000d-02 /
      data f(14, 1, 3),f(14, 1, 4) /  4.5426000d-02 ,  4.5426000d-02 /
      data f(14, 1, 5),f(14, 1, 6) /  4.5426000d-02 ,  4.5426000d-02 /
      data f(14, 1, 7),f(14, 1, 8) /  4.5426000d-02 ,  4.5426000d-02 /
      data f(14, 1, 9),f(14, 1,10) /  4.5426000d-02 ,  4.5426000d-02 /
      data f(14, 1,11),f(14, 1,12) /  4.5426000d-02 ,  4.5426000d-02 /
      data f(14, 1,13),f(14, 1,14) /  4.5426000d-02 ,  4.5426000d-02 /
      data f(14, 1,15),f(14, 1,16) /  4.5426000d-02 ,  4.5426000d-02 /
      data f(14, 1,17),f(14, 1,18) /  4.5426000d-02 ,  4.5426000d-02 /
      data f(14, 1,19),f(14, 1,20) /  4.5426000d-02 ,  4.5426000d-02 /
      data f(14, 1,21),f(14, 1,22) /  4.5426000d-02 ,  4.5426000d-02 /
      data f(14, 1,23) /              4.5426000d-02 /
      data f(14, 2, 1),f(14, 2, 2) /  3.4078800d-02 ,  4.4327500d-02 /
      data f(14, 2, 3),f(14, 2, 4) /  5.2155400d-02 ,  5.2155400d-02 /
      data f(14, 2, 5),f(14, 2, 6) /  4.4327500d-02 ,  3.4078800d-02 /
      data f(14, 2, 7),f(14, 2, 8) /  2.3651600d-02 ,  1.4355000d-02 /
      data f(14, 2, 9),f(14, 2,10) /  7.0106000d-03 ,  1.6362000d-03 /
      data f(14, 2,11),f(14, 2,12) / -1.5855000d-03 , -2.5726000d-03 /
      data f(14, 2,13),f(14, 2,14) / -1.2808000d-03 ,  2.2548000d-03 /
      data f(14, 2,15),f(14, 2,16) /  7.9637000d-03 ,  1.5714500d-02 /
      data f(14, 2,17),f(14, 2,18) /  2.5265800d-02 ,  3.5987900d-02 /
      data f(14, 2,19),f(14, 2,20) /  4.6482200d-02 ,  5.4464600d-02 /
      data f(14, 2,21),f(14, 2,22) /  5.4464600d-02 ,  4.6482200d-02 /
      data f(14, 2,23) /              3.5987900d-02 /
      data f(14, 3, 1),f(14, 3, 2) /  6.5971200d-02 ,  1.6021250d-01 /
      data f(14, 3, 3),f(14, 3, 4) /  1.7494980d-01 ,  1.7494980d-01 /
      data f(14, 3, 5),f(14, 3, 6) /  1.6021250d-01 ,  6.5971200d-02 /
      data f(14, 3, 7),f(14, 3, 8) /  1.0069700d-02 , -1.8672800d-02 /
      data f(14, 3, 9),f(14, 3,10) / -3.7658900d-02 , -4.9905700d-02 /
      data f(14, 3,11),f(14, 3,12) / -5.7034200d-02 , -5.9381200d-02 /
      data f(14, 3,13),f(14, 3,14) / -5.6961400d-02 , -4.9695500d-02 /
      data f(14, 3,15),f(14, 3,16) / -3.7188300d-02 , -1.7790400d-02 /
      data f(14, 3,17),f(14, 3,18) /  1.1516900d-02 ,  6.7977400d-02 /
      data f(14, 3,19),f(14, 3,20) /  1.6045480d-01 ,  1.7521120d-01 /
      data f(14, 3,21),f(14, 3,22) /  1.7521120d-01 ,  1.6045480d-01 /
      data f(14, 3,23) /              6.7977400d-02 /
      data f(14, 4, 1),f(14, 4, 2) /  3.5692200d-02 ,  1.3391420d-01 /
      data f(14, 4, 3),f(14, 4, 4) /  1.7470760d-01 ,  1.7470760d-01 /
      data f(14, 4, 5),f(14, 4, 6) /  1.3391420d-01 ,  3.5692200d-02 /
      data f(14, 4, 7),f(14, 4, 8) / -1.0382200d-02 , -3.7871900d-02 /
      data f(14, 4, 9),f(14, 4,10) / -5.6641000d-02 , -6.9709000d-02 /
      data f(14, 4,11),f(14, 4,12) / -7.7618500d-02 , -8.0437500d-02 /
      data f(14, 4,13),f(14, 4,14) / -7.8149700d-02 , -7.0671500d-02 /
      data f(14, 4,15),f(14, 4,16) / -5.7816600d-02 , -3.8886400d-02 /
      data f(14, 4,17),f(14, 4,18) / -1.0706000d-02 ,  3.6574300d-02 /
      data f(14, 4,19),f(14, 4,20) /  1.3597590d-01 ,  1.7497810d-01 /
      data f(14, 4,21),f(14, 4,22) /  1.7497810d-01 ,  1.3597590d-01 /
      data f(14, 4,23) /              3.6574300d-02 /
      data f(14, 5, 1),f(14, 5, 2) /  1.0347100d-02 ,  3.9152600d-02 /
      data f(14, 5, 3),f(14, 5, 4) /  6.8750200d-02 ,  6.8750200d-02 /
      data f(14, 5, 5),f(14, 5, 6) /  3.9152600d-02 ,  1.0347100d-02 /
      data f(14, 5, 7),f(14, 5, 8) / -1.4031600d-02 , -3.3909000d-02 /
      data f(14, 5, 9),f(14, 5,10) / -4.9548300d-02 , -6.0890900d-02 /
      data f(14, 5,11),f(14, 5,12) / -6.7926500d-02 , -7.0696900d-02 /
      data f(14, 5,13),f(14, 5,14) / -6.9189900d-02 , -6.3298300d-02 /
      data f(14, 5,15),f(14, 5,16) / -5.2846200d-02 , -3.7667100d-02 /
      data f(14, 5,17),f(14, 5,18) / -1.7555700d-02 ,  8.1264000d-03 /
      data f(14, 5,19),f(14, 5,20) /  4.0185700d-02 ,  7.3384100d-02 /
      data f(14, 5,21),f(14, 5,22) /  7.3384100d-02 ,  4.0185700d-02 /
      data f(14, 5,23) /              8.1264000d-03 /
      data f(14, 6, 1),f(14, 6, 2) /  8.1698000d-03 ,  2.4585700d-02 /
      data f(14, 6, 3),f(14, 6, 4) /  3.9560900d-02 ,  3.9560900d-02 /
      data f(14, 6, 5),f(14, 6, 6) /  2.4585700d-02 ,  8.1698000d-03 /
      data f(14, 6, 7),f(14, 6, 8) / -7.4864000d-03 , -2.1315700d-02 /
      data f(14, 6, 9),f(14, 6,10) / -3.2704400d-02 , -4.1323700d-02 /
      data f(14, 6,11),f(14, 6,12) / -4.6995100d-02 , -4.9594300d-02 /
      data f(14, 6,13),f(14, 6,14) / -4.9023500d-02 , -4.5205600d-02 /
      data f(14, 6,15),f(14, 6,16) / -3.8070800d-02 , -2.7580800d-02 /
      data f(14, 6,17),f(14, 6,18) / -1.3844300d-02 ,  2.6799000d-03 /
      data f(14, 6,19),f(14, 6,20) /  2.0822800d-02 ,  3.7609700d-02 /
      data f(14, 6,21),f(14, 6,22) /  3.7609700d-02 ,  2.0822800d-02 /
      data f(14, 6,23) /              2.6799000d-03 /
      data f(14, 7, 1),f(14, 7, 2) /  6.6246000d-03 ,  1.3790300d-02 /
      data f(14, 7, 3),f(14, 7, 4) /  1.9069000d-02 ,  1.9069000d-02 /
      data f(14, 7, 5),f(14, 7, 6) /  1.3790300d-02 ,  6.6246000d-03 /
      data f(14, 7, 7),f(14, 7, 8) / -1.2928000d-03 , -9.1602000d-03 /
      data f(14, 7, 9),f(14, 7,10) / -1.6362700d-02 , -2.2381100d-02 /
      data f(14, 7,11),f(14, 7,12) / -2.6776300d-02 , -2.9216900d-02 /
      data f(14, 7,13),f(14, 7,14) / -2.9503400d-02 , -2.7561200d-02 /
      data f(14, 7,15),f(14, 7,16) / -2.3416000d-02 , -1.7186500d-02 /
      data f(14, 7,17),f(14, 7,18) / -9.1446000d-03 ,  1.2450000d-04 /
      data f(14, 7,19),f(14, 7,20) /  9.4686000d-03 ,  1.6891900d-02 /
      data f(14, 7,21),f(14, 7,22) /  1.6891900d-02 ,  9.4686000d-03 /
      data f(14, 7,23) /              1.2450000d-04 /
      data f(14, 8, 1),f(14, 8, 2) /  7.0326000d-03 ,  9.6684000d-03 /
      data f(14, 8, 3),f(14, 8, 4) /  1.1383400d-02 ,  1.1383400d-02 /
      data f(14, 8, 5),f(14, 8, 6) /  9.6684000d-03 ,  7.0326000d-03 /
      data f(14, 8, 7),f(14, 8, 8) /  3.6687000d-03 , -2.4530000d-04 /
      data f(14, 8, 9),f(14, 8,10) / -4.4267000d-03 , -8.4400000d-03 /
      data f(14, 8,11),f(14, 8,12) / -1.1787500d-02 , -1.4052700d-02 /
      data f(14, 8,13),f(14, 8,14) / -1.4969700d-02 , -1.4427800d-02 /
      data f(14, 8,15),f(14, 8,16) / -1.2445600d-02 , -9.1578000d-03 /
      data f(14, 8,17),f(14, 8,18) / -4.8318000d-03 ,  7.6500000d-05 /
      data f(14, 8,19),f(14, 8,20) /  4.8381000d-03 ,  8.4259000d-03 /
      data f(14, 8,21),f(14, 8,22) /  8.4259000d-03 ,  4.8381000d-03 /
      data f(14, 8,23) /              7.6500000d-05 /
      data f(14, 9, 1),f(14, 9, 2) /  8.2640000d-03 ,  9.7484000d-03 /
      data f(14, 9, 3),f(14, 9, 4) /  1.1360700d-02 ,  1.1360700d-02 /
      data f(14, 9, 5),f(14, 9, 6) /  9.7484000d-03 ,  8.2640000d-03 /
      data f(14, 9, 7),f(14, 9, 8) /  6.8106000d-03 ,  5.0129000d-03 /
      data f(14, 9, 9),f(14, 9,10) /  2.7087000d-03 ,  7.8200000d-05 /
      data f(14, 9,11),f(14, 9,12) / -2.4685000d-03 , -4.5029000d-03 /
      data f(14, 9,13),f(14, 9,14) / -5.7194000d-03 , -5.9699000d-03 /
      data f(14, 9,15),f(14, 9,16) / -5.2374000d-03 , -3.6116000d-03 /
      data f(14, 9,17),f(14, 9,18) / -1.2800000d-03 ,  1.4514000d-03 /
      data f(14, 9,19),f(14, 9,20) /  4.1208000d-03 ,  6.1227000d-03 /
      data f(14, 9,21),f(14, 9,22) /  6.1227000d-03 ,  4.1208000d-03 /
      data f(14, 9,23) /              1.4514000d-03 /
      data f(14,10, 1),f(14,10, 2) /  6.1420000d-03 ,  6.1744000d-03 /
      data f(14,10, 3),f(14,10, 4) /  1.1264000d-03 ,  1.1264000d-03 /
      data f(14,10, 5),f(14,10, 6) /  6.1744000d-03 ,  6.1420000d-03 /
      data f(14,10, 7),f(14,10, 8) /  6.4760000d-03 ,  6.4976000d-03 /
      data f(14,10, 9),f(14,10,10) /  5.7528000d-03 ,  4.2764000d-03 /
      data f(14,10,11),f(14,10,12) /  2.4620000d-03 ,  7.7320000d-04 /
      data f(14,10,13),f(14,10,14) / -4.4030000d-04 , -9.8430000d-04 /
      data f(14,10,15),f(14,10,16) / -7.9610000d-04 ,  8.4100000d-05 /
      data f(14,10,17),f(14,10,18) /  1.5299000d-03 ,  3.3205000d-03 /
      data f(14,10,19),f(14,10,20) /  5.1111000d-03 ,  6.4611000d-03 /
      data f(14,10,21),f(14,10,22) /  6.4611000d-03 ,  5.1111000d-03 /
      data f(14,10,23) /              3.3205000d-03 /
      data f(14,11, 1),f(14,11, 2) / -3.6132000d-03 , -9.3576000d-03 /
      data f(14,11, 3),f(14,11, 4) / -1.4039900d-02 , -1.4039900d-02 /
      data f(14,11, 5),f(14,11, 6) / -9.3576000d-03 , -3.6132000d-03 /
      data f(14,11, 7),f(14,11, 8) /  1.0998000d-03 ,  4.1908000d-03 /
      data f(14,11, 9),f(14,11,10) /  5.5705000d-03 ,  5.4802000d-03 /
      data f(14,11,11),f(14,11,12) /  4.5183000d-03 ,  3.3175000d-03 /
      data f(14,11,13),f(14,11,14) /  2.3274000d-03 ,  1.8055000d-03 /
      data f(14,11,15),f(14,11,16) /  1.8641000d-03 ,  2.5064000d-03 /
      data f(14,11,17),f(14,11,18) /  3.6408000d-03 ,  5.0694000d-03 /
      data f(14,11,19),f(14,11,20) /  6.4898000d-03 ,  7.5435000d-03 /
      data f(14,11,21),f(14,11,22) /  7.5435000d-03 ,  6.4898000d-03 /
      data f(14,11,23) /              5.0694000d-03 /
      data f(14,12, 1),f(14,12, 2) / -1.3304300d-02 , -1.8270000d-02 /
      data f(14,12, 3),f(14,12, 4) / -1.9682500d-02 , -1.9682500d-02 /
      data f(14,12, 5),f(14,12, 6) / -1.8270000d-02 , -1.3304300d-02 /
      data f(14,12, 7),f(14,12, 8) / -6.4644000d-03 , -4.5190000d-04 /
      data f(14,12, 9),f(14,12,10) /  3.3182000d-03 ,  4.8243000d-03 /
      data f(14,12,11),f(14,12,12) /  4.8381000d-03 ,  4.2247000d-03 /
      data f(14,12,13),f(14,12,14) /  3.5840000d-03 ,  3.2484000d-03 /
      data f(14,12,15),f(14,12,16) /  3.3728000d-03 ,  3.9903000d-03 /
      data f(14,12,17),f(14,12,18) /  5.0245000d-03 ,  6.2812000d-03 /
      data f(14,12,19),f(14,12,20) /  7.4829000d-03 ,  8.3438000d-03 /
      data f(14,12,21),f(14,12,22) /  8.3438000d-03 ,  7.4829000d-03 /
      data f(14,12,23) /              6.2812000d-03 /
      data f(14,13, 1),f(14,13, 2) / -1.8332200d-02 , -2.0321800d-02 /
      data f(14,13, 3),f(14,13, 4) / -1.7532700d-02 , -1.7532700d-02 /
      data f(14,13, 5),f(14,13, 6) / -2.0321800d-02 , -1.8332200d-02 /
      data f(14,13, 7),f(14,13, 8) / -1.1989800d-02 , -4.7665000d-03 /
      data f(14,13, 9),f(14,13,10) /  6.0630000d-04 ,  3.3922000d-03 /
      data f(14,13,11),f(14,13,12) /  4.2680000d-03 ,  4.2157000d-03 /
      data f(14,13,13),f(14,13,14) /  3.9396000d-03 ,  3.8274000d-03 /
      data f(14,13,15),f(14,13,16) /  4.0579000d-03 ,  4.6781000d-03 /
      data f(14,13,17),f(14,13,18) /  5.6220000d-03 ,  6.7141000d-03 /
      data f(14,13,19),f(14,13,20) /  7.7175000d-03 ,  8.4138000d-03 /
      data f(14,13,21),f(14,13,22) /  8.4138000d-03 ,  7.7175000d-03 /
      data f(14,13,23) /              6.7141000d-03 /
      data f(14,14, 1),f(14,14, 2) / -1.9135500d-02 , -2.0107600d-02 /
      data f(14,14, 3),f(14,14, 4) / -1.7018100d-02 , -1.7018100d-02 /
      data f(14,14, 5),f(14,14, 6) / -2.0107600d-02 , -1.9135500d-02 /
      data f(14,14, 7),f(14,14, 8) / -1.3667600d-02 , -6.6278000d-03 /
      data f(14,14, 9),f(14,14,10) / -9.5740000d-04 ,  2.2483000d-03 /
      data f(14,14,11),f(14,14,12) /  3.5360000d-03 ,  3.8342000d-03 /
      data f(14,14,13),f(14,14,14) /  3.8183000d-03 ,  3.8626000d-03 /
      data f(14,14,15),f(14,14,16) /  4.1397000d-03 ,  4.6941000d-03 /
      data f(14,14,17),f(14,14,18) /  5.4726000d-03 ,  6.3399000d-03 /
      data f(14,14,19),f(14,14,20) /  7.1191000d-03 ,  7.6493000d-03 /
      data f(14,14,21),f(14,14,22) /  7.6493000d-03 ,  7.1191000d-03 /
      data f(14,14,23) /              6.3399000d-03 /
      data f(14,15, 1),f(14,15, 2) / -1.6082000d-02 , -1.8587700d-02 /
      data f(14,15, 3),f(14,15, 4) / -1.8686700d-02 , -1.8686700d-02 /
      data f(14,15, 5),f(14,15, 6) / -1.8587700d-02 , -1.6082000d-02 /
      data f(14,15, 7),f(14,15, 8) / -1.0918800d-02 , -4.8956000d-03 /
      data f(14,15, 9),f(14,15,10) / -2.8480000d-04 ,  2.2096000d-03 /
      data f(14,15,11),f(14,15,12) /  3.2364000d-03 ,  3.5285000d-03 /
      data f(14,15,13),f(14,15,14) /  3.5719000d-03 ,  3.6387000d-03 /
      data f(14,15,15),f(14,15,16) /  3.8547000d-03 ,  4.2497000d-03 /
      data f(14,15,17),f(14,15,18) /  4.7834000d-03 ,  5.3657000d-03 /
      data f(14,15,19),f(14,15,20) /  5.8822000d-03 ,  6.2312000d-03 /
      data f(14,15,21),f(14,15,22) /  6.2312000d-03 ,  5.8822000d-03 /
      data f(14,15,23) /              5.3657000d-03 /
      data f(14,16, 1),f(14,16, 2) / -7.1741000d-03 , -1.0691000d-02 /
      data f(14,16, 3),f(14,16, 4) / -1.2848800d-02 , -1.2848800d-02 /
      data f(14,16, 5),f(14,16, 6) / -1.0691000d-02 , -7.1741000d-03 /
      data f(14,16, 7),f(14,16, 8) / -3.3152000d-03 ,  7.8570000d-04 /
      data f(14,16, 9),f(14,16,10) /  2.7260000d-03 ,  3.4854000d-03 /
      data f(14,16,11),f(14,16,12) /  3.6763000d-03 ,  3.6195000d-03 /
      data f(14,16,13),f(14,16,14) /  3.5078000d-03 ,  3.4532000d-03 /
      data f(14,16,15),f(14,16,16) /  3.5075000d-03 ,  3.6763000d-03 /
      data f(14,16,17),f(14,16,18) /  3.9304000d-03 ,  4.2173000d-03 /
      data f(14,16,19),f(14,16,20) /  4.4763000d-03 ,  4.6536000d-03 /
      data f(14,16,21),f(14,16,22) /  4.6536000d-03 ,  4.4763000d-03 /
      data f(14,16,23) /              4.2173000d-03 /
      data f(14,17, 1),f(14,17, 2) /  7.9936000d-03 ,  5.2027000d-03 /
      data f(14,17, 3),f(14,17, 4) /  3.3067000d-03 ,  3.3067000d-03 /
      data f(14,17, 5),f(14,17, 6) /  5.2027000d-03 ,  7.9936000d-03 /
      data f(14,17, 7),f(14,17, 8) /  8.0751000d-03 ,  6.8674000d-03 /
      data f(14,17, 9),f(14,17,10) /  5.9337000d-03 ,  5.2158000d-03 /
      data f(14,17,11),f(14,17,12) /  4.6426000d-03 ,  4.1865000d-03 /
      data f(14,17,13),f(14,17,14) /  3.8392000d-03 ,  3.5973000d-03 /
      data f(14,17,15),f(14,17,16) /  3.4543000d-03 ,  3.3961000d-03 /
      data f(14,17,17),f(14,17,18) /  3.4014000d-03 ,  3.4444000d-03 /
      data f(14,17,19),f(14,17,20) /  3.4987000d-03 ,  3.5409000d-03 /
      data f(14,17,21),f(14,17,22) /  3.5409000d-03 ,  3.4987000d-03 /
      data f(14,17,23) /              3.4444000d-03 /
      data f(14,18, 1),f(14,18, 2) /  8.6318000d-03 ,  9.2430000d-03 /
      data f(14,18, 3),f(14,18, 4) /  9.6649000d-03 ,  9.6649000d-03 /
      data f(14,18, 5),f(14,18, 6) /  9.2430000d-03 ,  8.6318000d-03 /
      data f(14,18, 7),f(14,18, 8) /  7.9263000d-03 ,  7.2066000d-03 /
      data f(14,18, 9),f(14,18,10) /  6.5263000d-03 ,  5.9142000d-03 /
      data f(14,18,11),f(14,18,12) /  5.3819000d-03 ,  4.9310000d-03 /
      data f(14,18,13),f(14,18,14) /  4.5582000d-03 ,  4.2577000d-03 /
      data f(14,18,15),f(14,18,16) /  4.0220000d-03 ,  3.8432000d-03 /
      data f(14,18,17),f(14,18,18) /  3.7124000d-03 ,  3.6214000d-03 /
      data f(14,18,19),f(14,18,20) /  3.5625000d-03 ,  3.5305000d-03 /
      data f(14,18,21),f(14,18,22) /  3.5305000d-03 ,  3.5625000d-03 /
      data f(14,18,23) /              3.6214000d-03 /
      data f(14,19, 1),f(14,19, 2) /  5.2847000d-03 ,  5.2847000d-03 /
      data f(14,19, 3),f(14,19, 4) /  5.2847000d-03 ,  5.2847000d-03 /
      data f(14,19, 5),f(14,19, 6) /  5.2847000d-03 ,  5.2847000d-03 /
      data f(14,19, 7),f(14,19, 8) /  5.2847000d-03 ,  5.2847000d-03 /
      data f(14,19, 9),f(14,19,10) /  5.2847000d-03 ,  5.2847000d-03 /
      data f(14,19,11),f(14,19,12) /  5.2847000d-03 ,  5.2847000d-03 /
      data f(14,19,13),f(14,19,14) /  5.2847000d-03 ,  5.2847000d-03 /
      data f(14,19,15),f(14,19,16) /  5.2847000d-03 ,  5.2847000d-03 /
      data f(14,19,17),f(14,19,18) /  5.2847000d-03 ,  5.2847000d-03 /
      data f(14,19,19),f(14,19,20) /  5.2847000d-03 ,  5.2847000d-03 /
      data f(14,19,21),f(14,19,22) /  5.2847000d-03 ,  5.2847000d-03 /
      data f(14,19,23) /              5.2847000d-03 /
      data f(15, 1, 1),f(15, 1, 2) /  3.5661000d-02 ,  3.5661000d-02 /
      data f(15, 1, 3),f(15, 1, 4) /  3.5661000d-02 ,  3.5661000d-02 /
      data f(15, 1, 5),f(15, 1, 6) /  3.5661000d-02 ,  3.5661000d-02 /
      data f(15, 1, 7),f(15, 1, 8) /  3.5661000d-02 ,  3.5661000d-02 /
      data f(15, 1, 9),f(15, 1,10) /  3.5661000d-02 ,  3.5661000d-02 /
      data f(15, 1,11),f(15, 1,12) /  3.5661000d-02 ,  3.5661000d-02 /
      data f(15, 1,13),f(15, 1,14) /  3.5661000d-02 ,  3.5661000d-02 /
      data f(15, 1,15),f(15, 1,16) /  3.5661000d-02 ,  3.5661000d-02 /
      data f(15, 1,17),f(15, 1,18) /  3.5661000d-02 ,  3.5661000d-02 /
      data f(15, 1,19),f(15, 1,20) /  3.5661000d-02 ,  3.5661000d-02 /
      data f(15, 1,21),f(15, 1,22) /  3.5661000d-02 ,  3.5661000d-02 /
      data f(15, 1,23) /              3.5661000d-02 /
      data f(15, 2, 1),f(15, 2, 2) /  2.8142100d-02 ,  3.6816200d-02 /
      data f(15, 2, 3),f(15, 2, 4) /  4.3345900d-02 ,  4.3345900d-02 /
      data f(15, 2, 5),f(15, 2, 6) /  3.6816200d-02 ,  2.8142100d-02 /
      data f(15, 2, 7),f(15, 2, 8) /  1.9190700d-02 ,  1.1127700d-02 /
      data f(15, 2, 9),f(15, 2,10) /  4.5290000d-03 , -3.2710000d-04 /
      data f(15, 2,11),f(15, 2,12) / -3.2650000d-03 , -4.1655000d-03 /
      data f(15, 2,13),f(15, 2,14) / -2.9799000d-03 ,  2.5510000d-04 /
      data f(15, 2,15),f(15, 2,16) /  5.4246000d-03 ,  1.2350100d-02 /
      data f(15, 2,17),f(15, 2,18) /  2.0737200d-02 ,  2.9983600d-02 /
      data f(15, 2,19),f(15, 2,20) /  3.8888800d-02 ,  4.5572900d-02 /
      data f(15, 2,21),f(15, 2,22) /  4.5572900d-02 ,  3.8888800d-02 /
      data f(15, 2,23) /              2.9983600d-02 /
      data f(15, 3, 1),f(15, 3, 2) /  5.3363000d-02 ,  1.3193590d-01 /
      data f(15, 3, 3),f(15, 3, 4) /  1.6710010d-01 ,  1.6710010d-01 /
      data f(15, 3, 5),f(15, 3, 6) /  1.3193590d-01 ,  5.3363000d-02 /
      data f(15, 3, 7),f(15, 3, 8) /  7.3771000d-03 , -1.7489400d-02 /
      data f(15, 3, 9),f(15, 3,10) / -3.4738400d-02 , -4.6181400d-02 /
      data f(15, 3,11),f(15, 3,12) / -5.2938700d-02 , -5.5184200d-02 /
      data f(15, 3,13),f(15, 3,14) / -5.2896500d-02 , -4.6032600d-02 /
      data f(15, 3,15),f(15, 3,16) / -3.4358400d-02 , -1.6719900d-02 /
      data f(15, 3,17),f(15, 3,18) /  8.7032000d-03 ,  5.5263900d-02 /
      data f(15, 3,19),f(15, 3,20) /  1.3426140d-01 ,  1.6735360d-01 /
      data f(15, 3,21),f(15, 3,22) /  1.6735360d-01 ,  1.3426140d-01 /
      data f(15, 3,23) /              5.5263900d-02 /
      data f(15, 4, 1),f(15, 4, 2) /  3.1496800d-02 ,  1.1025110d-01 /
      data f(15, 4, 3),f(15, 4, 4) /  1.6746920d-01 ,  1.6746920d-01 /
      data f(15, 4, 5),f(15, 4, 6) /  1.1025110d-01 ,  3.1496800d-02 /
      data f(15, 4, 7),f(15, 4, 8) / -7.1236000d-03 , -3.3763300d-02 /
      data f(15, 4, 9),f(15, 4,10) / -5.1564500d-02 , -6.4071900d-02 /
      data f(15, 4,11),f(15, 4,12) / -7.1660300d-02 , -7.4375300d-02 /
      data f(15, 4,13),f(15, 4,14) / -7.2202200d-02 , -6.5061100d-02 /
      data f(15, 4,15),f(15, 4,16) / -5.2795200d-02 , -3.4882500d-02 /
      data f(15, 4,17),f(15, 4,18) / -8.9343000d-03 ,  3.2195600d-02 /
      data f(15, 4,19),f(15, 4,20) /  1.1215330d-01 ,  1.6773220d-01 /
      data f(15, 4,21),f(15, 4,22) /  1.6773220d-01 ,  1.1215330d-01 /
      data f(15, 4,23) /              3.2195600d-02 /
      data f(15, 5, 1),f(15, 5, 2) /  1.1821300d-02 ,  3.9493900d-02 /
      data f(15, 5, 3),f(15, 5, 4) /  6.6739500d-02 ,  6.6739500d-02 /
      data f(15, 5, 5),f(15, 5, 6) /  3.9493900d-02 ,  1.1821300d-02 /
      data f(15, 5, 7),f(15, 5, 8) / -1.1354100d-02 , -3.0297400d-02 /
      data f(15, 5, 9),f(15, 5,10) / -4.5185900d-02 , -5.5966900d-02 /
      data f(15, 5,11),f(15, 5,12) / -6.2650800d-02 , -6.5290500d-02 /
      data f(15, 5,13),f(15, 5,14) / -6.3877800d-02 , -5.8305800d-02 /
      data f(15, 5,15),f(15, 5,16) / -4.8396700d-02 , -3.3983600d-02 /
      data f(15, 5,17),f(15, 5,18) / -1.4896200d-02 ,  9.3499000d-03 /
      data f(15, 5,19),f(15, 5,20) /  3.9329800d-02 ,  7.0801400d-02 /
      data f(15, 5,21),f(15, 5,22) /  7.0801400d-02 ,  3.9329800d-02 /
      data f(15, 5,23) /              9.3499000d-03 /
      data f(15, 6, 1),f(15, 6, 2) /  8.2378000d-03 ,  2.3311900d-02 /
      data f(15, 6, 3),f(15, 6, 4) /  3.6606400d-02 ,  3.6606400d-02 /
      data f(15, 6, 5),f(15, 6, 6) /  2.3311900d-02 ,  8.2378000d-03 /
      data f(15, 6, 7),f(15, 6, 8) / -6.3018000d-03 , -1.9193100d-02 /
      data f(15, 6, 9),f(15, 6,10) / -2.9825700d-02 , -3.7883800d-02 /
      data f(15, 6,11),f(15, 6,12) / -4.3195700d-02 , -4.5638400d-02 /
      data f(15, 6,13),f(15, 6,14) / -4.5114800d-02 , -4.1551300d-02 /
      data f(15, 6,15),f(15, 6,16) / -3.4885400d-02 , -2.5086800d-02 /
      data f(15, 6,17),f(15, 6,18) / -1.2273200d-02 ,  3.0786000d-03 /
      data f(15, 6,19),f(15, 6,20) /  1.9760300d-02 ,  3.4808700d-02 /
      data f(15, 6,21),f(15, 6,22) /  3.4808700d-02 ,  1.9760300d-02 /
      data f(15, 6,23) /              3.0786000d-03 /
      data f(15, 7, 1),f(15, 7, 2) /  6.0225000d-03 ,  1.2473100d-02 /
      data f(15, 7, 3),f(15, 7, 4) /  1.7153000d-02 ,  1.7153000d-02 /
      data f(15, 7, 5),f(15, 7, 6) /  1.2473100d-02 ,  6.0225000d-03 /
      data f(15, 7, 7),f(15, 7, 8) / -1.1685000d-03 , -8.3455000d-03 /
      data f(15, 7, 9),f(15, 7,10) / -1.4933700d-02 , -2.0452600d-02 /
      data f(15, 7,11),f(15, 7,12) / -2.4493300d-02 , -2.6744400d-02 /
      data f(15, 7,13),f(15, 7,14) / -2.7016000d-02 , -2.5235400d-02 /
      data f(15, 7,15),f(15, 7,16) / -2.1425700d-02 , -1.5700200d-02 /
      data f(15, 7,17),f(15, 7,18) / -8.3241000d-03 ,  1.4530000d-04 /
      data f(15, 7,19),f(15, 7,20) /  8.6193000d-03 ,  1.5275600d-02 /
      data f(15, 7,21),f(15, 7,22) /  1.5275600d-02 ,  8.6193000d-03 /
      data f(15, 7,23) /              1.4530000d-04 /
      data f(15, 8, 1),f(15, 8, 2) /  6.0868000d-03 ,  8.4370000d-03 /
      data f(15, 8, 3),f(15, 8, 4) /  1.3900300d-02 ,  1.3900300d-02 /
      data f(15, 8, 5),f(15, 8, 6) /  8.4370000d-03 ,  6.0868000d-03 /
      data f(15, 8, 7),f(15, 8, 8) /  3.0793000d-03 , -4.2210000d-04 /
      data f(15, 8, 9),f(15, 8,10) / -4.1668000d-03 , -7.7677000d-03 /
      data f(15, 8,11),f(15, 8,12) / -1.0781100d-02 , -1.2828800d-02 /
      data f(15, 8,13),f(15, 8,14) / -1.3664500d-02 , -1.3182500d-02 /
      data f(15, 8,15),f(15, 8,16) / -1.1395800d-02 , -8.4248000d-03 /
      data f(15, 8,17),f(15, 8,18) / -4.5161000d-03 , -9.3800000d-05 /
      data f(15, 8,19),f(15, 8,20) /  4.1714000d-03 ,  7.3601000d-03 /
      data f(15, 8,21),f(15, 8,22) /  7.3601000d-03 ,  4.1714000d-03 /
      data f(15, 8,23) /             -9.3800000d-05 /
      data f(15, 9, 1),f(15, 9, 2) /  7.1056000d-03 ,  8.4742000d-03 /
      data f(15, 9, 3),f(15, 9, 4) /  1.3847500d-02 ,  1.3847500d-02 /
      data f(15, 9, 5),f(15, 9, 6) /  8.4742000d-03 ,  7.1056000d-03 /
      data f(15, 9, 7),f(15, 9, 8) /  5.7879000d-03 ,  4.1976000d-03 /
      data f(15, 9, 9),f(15, 9,10) /  2.1751000d-03 , -1.3670000d-04 /
      data f(15, 9,11),f(15, 9,12) / -2.3860000d-03 , -4.1927000d-03 /
      data f(15, 9,13),f(15, 9,14) / -5.2804000d-03 , -5.5110000d-03 /
      data f(15, 9,15),f(15, 9,16) / -4.8638000d-03 , -3.4155000d-03 /
      data f(15, 9,17),f(15, 9,18) / -1.3354000d-03 ,  1.0951000d-03 /
      data f(15, 9,19),f(15, 9,20) /  3.4555000d-03 ,  5.2102000d-03 /
      data f(15, 9,21),f(15, 9,22) /  5.2102000d-03 ,  3.4555000d-03 /
      data f(15, 9,23) /              1.0951000d-03 /
      data f(15,10, 1),f(15,10, 2) /  5.8123000d-03 ,  7.3150000d-03 /
      data f(15,10, 3),f(15,10, 4) /  7.3983000d-03 ,  7.3983000d-03 /
      data f(15,10, 5),f(15,10, 6) /  7.3150000d-03 ,  5.8123000d-03 /
      data f(15,10, 7),f(15,10, 8) /  5.6370000d-03 ,  5.5162000d-03 /
      data f(15,10, 9),f(15,10,10) /  4.8426000d-03 ,  3.5633000d-03 /
      data f(15,10,11),f(15,10,12) /  1.9872000d-03 ,  5.0930000d-04 /
      data f(15,10,13),f(15,10,14) / -5.6130000d-04 , -1.0465000d-03 /
      data f(15,10,15),f(15,10,16) / -8.8330000d-04 , -1.0360000d-04 /
      data f(15,10,17),f(15,10,18) /  1.1793000d-03 ,  2.7630000d-03 /
      data f(15,10,19),f(15,10,20) /  4.3345000d-03 ,  5.5031000d-03 /
      data f(15,10,21),f(15,10,22) /  5.5031000d-03 ,  4.3345000d-03 /
      data f(15,10,23) /              2.7630000d-03 /
      data f(15,11, 1),f(15,11, 2) / -1.1319000d-03 , -3.7029000d-03 /
      data f(15,11, 3),f(15,11, 4) / -5.2019000d-03 , -5.2019000d-03 /
      data f(15,11, 5),f(15,11, 6) / -3.7029000d-03 , -1.1319000d-03 /
      data f(15,11, 7),f(15,11, 8) /  1.5003000d-03 ,  3.6585000d-03 /
      data f(15,11, 9),f(15,11,10) /  4.7072000d-03 ,  4.6069000d-03 /
      data f(15,11,11),f(15,11,12) /  3.7810000d-03 ,  2.7434000d-03 /
      data f(15,11,13),f(15,11,14) /  1.8793000d-03 ,  1.4206000d-03 /
      data f(15,11,15),f(15,11,16) /  1.4738000d-03 ,  2.0452000d-03 /
      data f(15,11,17),f(15,11,18) /  3.0524000d-03 ,  4.3171000d-03 /
      data f(15,11,19),f(15,11,20) /  5.5647000d-03 ,  6.4730000d-03 /
      data f(15,11,21),f(15,11,22) /  6.4730000d-03 ,  5.5647000d-03 /
      data f(15,11,23) /              4.3171000d-03 /
      data f(15,12, 1),f(15,12, 2) / -8.7177000d-03 , -1.0445800d-02 /
      data f(15,12, 3),f(15,12, 4) / -8.7437000d-03 , -8.7437000d-03 /
      data f(15,12, 5),f(15,12, 6) / -1.0445800d-02 , -8.7177000d-03 /
      data f(15,12, 7),f(15,12, 8) / -4.4862000d-03 , -1.1580000d-04 /
      data f(15,12, 9),f(15,12,10) /  2.8246000d-03 ,  4.0379000d-03 /
      data f(15,12,11),f(15,12,12) /  4.0424000d-03 ,  3.5192000d-03 /
      data f(15,12,13),f(15,12,14) /  2.9669000d-03 ,  2.6768000d-03 /
      data f(15,12,15),f(15,12,16) /  2.7913000d-03 ,  3.3421000d-03 /
      data f(15,12,17),f(15,12,18) /  4.2614000d-03 ,  5.3766000d-03 /
      data f(15,12,19),f(15,12,20) /  6.4369000d-03 ,  7.1845000d-03 /
      data f(15,12,21),f(15,12,22) /  7.1845000d-03 ,  6.4369000d-03 /
      data f(15,12,23) /              5.3766000d-03 /
      data f(15,13, 1),f(15,13, 2) / -1.2358200d-02 , -1.1228100d-02 /
      data f(15,13, 3),f(15,13, 4) / -5.3032000d-03 , -5.3032000d-03 /
      data f(15,13, 5),f(15,13, 6) / -1.1228100d-02 , -1.2358200d-02 /
      data f(15,13, 7),f(15,13, 8) / -8.7320000d-03 , -3.5375000d-03 /
      data f(15,13, 9),f(15,13,10) /  6.0110000d-04 ,  2.8216000d-03 /
      data f(15,13,11),f(15,13,12) /  3.5355000d-03 ,  3.4909000d-03 /
      data f(15,13,13),f(15,13,14) /  3.2578000d-03 ,  3.1655000d-03 /
      data f(15,13,15),f(15,13,16) /  3.3733000d-03 ,  3.9246000d-03 /
      data f(15,13,17),f(15,13,18) /  4.7621000d-03 ,  5.7315000d-03 /
      data f(15,13,19),f(15,13,20) /  6.6200000d-03 ,  7.2313000d-03 /
      data f(15,13,21),f(15,13,22) /  7.2313000d-03 ,  6.6200000d-03 /
      data f(15,13,23) /              5.7315000d-03 /
      data f(15,14, 1),f(15,14, 2) / -1.2337100d-02 , -1.0431800d-02 /
      data f(15,14, 3),f(15,14, 4) / -4.5440000d-03 , -4.5440000d-03 /
      data f(15,14, 5),f(15,14, 6) / -1.0431800d-02 , -1.2337100d-02 /
      data f(15,14, 7),f(15,14, 8) / -9.5484000d-03 , -4.7266000d-03 /
      data f(15,14, 9),f(15,14,10) / -5.5590000d-04 ,  1.8943000d-03 /
      data f(15,14,11),f(15,14,12) /  2.9079000d-03 ,  3.1459000d-03 /
      data f(15,14,13),f(15,14,14) /  3.1333000d-03 ,  3.1768000d-03 /
      data f(15,14,15),f(15,14,16) /  3.4238000d-03 ,  3.9139000d-03 /
      data f(15,14,17),f(15,14,18) /  4.6021000d-03 ,  5.3699000d-03 /
      data f(15,14,19),f(15,14,20) /  6.0592000d-03 ,  6.5254000d-03 /
      data f(15,14,21),f(15,14,22) /  6.5254000d-03 ,  6.0592000d-03 /
      data f(15,14,23) /              5.3699000d-03 /
      data f(15,15, 1),f(15,15, 2) / -9.1887000d-03 , -9.1616000d-03 /
      data f(15,15, 3),f(15,15, 4) / -7.2558000d-03 , -7.2558000d-03 /
      data f(15,15, 5),f(15,15, 6) / -9.1616000d-03 , -9.1887000d-03 /
      data f(15,15, 7),f(15,15, 8) / -6.4976000d-03 , -2.7512000d-03 /
      data f(15,15, 9),f(15,15,10) /  2.4310000d-04 ,  1.9492000d-03 /
      data f(15,15,11),f(15,15,12) /  2.6782000d-03 ,  2.8818000d-03 /
      data f(15,15,13),f(15,15,14) /  2.9068000d-03 ,  2.9639000d-03 /
      data f(15,15,15),f(15,15,16) /  3.1543000d-03 ,  3.5017000d-03 /
      data f(15,15,17),f(15,15,18) /  3.9713000d-03 ,  4.4843000d-03 /
      data f(15,15,19),f(15,15,20) /  4.9393000d-03 ,  5.2461000d-03 /
      data f(15,15,21),f(15,15,22) /  5.2461000d-03 ,  4.9393000d-03 /
      data f(15,15,23) /              4.4843000d-03 /
      data f(15,16, 1),f(15,16, 2) / -1.2871000d-03 , -2.5067000d-03 /
      data f(15,16, 3),f(15,16, 4) / -3.5261000d-03 , -3.5261000d-03 /
      data f(15,16, 5),f(15,16, 6) / -2.5067000d-03 , -1.2871000d-03 /
      data f(15,16, 7),f(15,16, 8) /  8.6330000d-04 ,  2.2074000d-03 /
      data f(15,16, 9),f(15,16,10) /  2.8470000d-03 ,  3.0955000d-03 /
      data f(15,16,11),f(15,16,12) /  3.0954000d-03 ,  2.9775000d-03 /
      data f(15,16,13),f(15,16,14) /  2.8514000d-03 ,  2.7920000d-03 /
      data f(15,16,15),f(15,16,16) /  2.8348000d-03 ,  2.9805000d-03 /
      data f(15,16,17),f(15,16,18) /  3.2020000d-03 ,  3.4528000d-03 /
      data f(15,16,19),f(15,16,20) /  3.6794000d-03 ,  3.8346000d-03 /
      data f(15,16,21),f(15,16,22) /  3.8346000d-03 ,  3.6794000d-03 /
      data f(15,16,23) /              3.4528000d-03 /
      data f(15,17, 1),f(15,17, 2) /  1.2766400d-02 ,  1.1227100d-02 /
      data f(15,17, 3),f(15,17, 4) /  9.8886000d-03 ,  9.8886000d-03 /
      data f(15,17, 5),f(15,17, 6) /  1.1227100d-02 ,  1.2766400d-02 /
      data f(15,17, 7),f(15,17, 8) /  7.8433000d-03 ,  6.3631000d-03 /
      data f(15,17, 9),f(15,17,10) /  5.3097000d-03 ,  4.5333000d-03 /
      data f(15,17,11),f(15,17,12) /  3.9427000d-03 ,  3.4905000d-03 /
      data f(15,17,13),f(15,17,14) /  3.1547000d-03 ,  2.9237000d-03 /
      data f(15,17,15),f(15,17,16) /  2.7866000d-03 ,  2.7281000d-03 /
      data f(15,17,17),f(15,17,18) /  2.7279000d-03 ,  2.7623000d-03 /
      data f(15,17,19),f(15,17,20) /  2.8079000d-03 ,  2.8436000d-03 /
      data f(15,17,21),f(15,17,22) /  2.8436000d-03 ,  2.8079000d-03 /
      data f(15,17,23) /              2.7623000d-03 /
      data f(15,18, 1),f(15,18, 2) /  7.5162000d-03 ,  8.0553000d-03 /
      data f(15,18, 3),f(15,18, 4) /  8.4238000d-03 ,  8.4238000d-03 /
      data f(15,18, 5),f(15,18, 6) /  8.0553000d-03 ,  7.5162000d-03 /
      data f(15,18, 7),f(15,18, 8) /  6.8863000d-03 ,  6.2364000d-03 /
      data f(15,18, 9),f(15,18,10) /  5.6162000d-03 ,  5.0543000d-03 /
      data f(15,18,11),f(15,18,12) /  4.5636000d-03 ,  4.1471000d-03 /
      data f(15,18,13),f(15,18,14) /  3.8023000d-03 ,  3.5242000d-03 /
      data f(15,18,15),f(15,18,16) /  3.3058000d-03 ,  3.1400000d-03 /
      data f(15,18,17),f(15,18,18) /  3.0184000d-03 ,  2.9335000d-03 /
      data f(15,18,19),f(15,18,20) /  2.8785000d-03 ,  2.8488000d-03 /
      data f(15,18,21),f(15,18,22) /  2.8488000d-03 ,  2.8785000d-03 /
      data f(15,18,23) /              2.9335000d-03 /
      data f(15,19, 1),f(15,19, 2) /  4.4551000d-03 ,  4.4551000d-03 /
      data f(15,19, 3),f(15,19, 4) /  4.4551000d-03 ,  4.4551000d-03 /
      data f(15,19, 5),f(15,19, 6) /  4.4551000d-03 ,  4.4551000d-03 /
      data f(15,19, 7),f(15,19, 8) /  4.4551000d-03 ,  4.4551000d-03 /
      data f(15,19, 9),f(15,19,10) /  4.4551000d-03 ,  4.4551000d-03 /
      data f(15,19,11),f(15,19,12) /  4.4551000d-03 ,  4.4551000d-03 /
      data f(15,19,13),f(15,19,14) /  4.4551000d-03 ,  4.4551000d-03 /
      data f(15,19,15),f(15,19,16) /  4.4551000d-03 ,  4.4551000d-03 /
      data f(15,19,17),f(15,19,18) /  4.4551000d-03 ,  4.4551000d-03 /
      data f(15,19,19),f(15,19,20) /  4.4551000d-03 ,  4.4551000d-03 /
      data f(15,19,21),f(15,19,22) /  4.4551000d-03 ,  4.4551000d-03 /
      data f(15,19,23) /              4.4551000d-03 /
      data f(16, 1, 1),f(16, 1, 2) /  3.3670400d-02 ,  3.3670400d-02 /
      data f(16, 1, 3),f(16, 1, 4) /  3.3670400d-02 ,  3.3670400d-02 /
      data f(16, 1, 5),f(16, 1, 6) /  3.3670400d-02 ,  3.3670400d-02 /
      data f(16, 1, 7),f(16, 1, 8) /  3.3670400d-02 ,  3.3670400d-02 /
      data f(16, 1, 9),f(16, 1,10) /  3.3670400d-02 ,  3.3670400d-02 /
      data f(16, 1,11),f(16, 1,12) /  3.3670400d-02 ,  3.3670400d-02 /
      data f(16, 1,13),f(16, 1,14) /  3.3670400d-02 ,  3.3670400d-02 /
      data f(16, 1,15),f(16, 1,16) /  3.3670400d-02 ,  3.3670400d-02 /
      data f(16, 1,17),f(16, 1,18) /  3.3670400d-02 ,  3.3670400d-02 /
      data f(16, 1,19),f(16, 1,20) /  3.3670400d-02 ,  3.3670400d-02 /
      data f(16, 1,21),f(16, 1,22) /  3.3670400d-02 ,  3.3670400d-02 /
      data f(16, 1,23) /              3.3670400d-02 /
      data f(16, 2, 1),f(16, 2, 2) /  2.5430800d-02 ,  3.2744800d-02 /
      data f(16, 2, 3),f(16, 2, 4) /  3.8180600d-02 ,  3.8180600d-02 /
      data f(16, 2, 5),f(16, 2, 6) /  3.2744800d-02 ,  2.5430800d-02 /
      data f(16, 2, 7),f(16, 2, 8) /  1.7719500d-02 ,  1.0615300d-02 /
      data f(16, 2, 9),f(16, 2,10) /  4.6841000d-03 ,  2.4100000d-04 /
      data f(16, 2,11),f(16, 2,12) / -4.2110000d-04 , -1.2687000d-03 /
      data f(16, 2,13),f(16, 2,14) / -2.2161000d-03 ,  7.8360000d-04 /
      data f(16, 2,15),f(16, 2,16) /  5.5173000d-03 ,  1.1762600d-02 /
      data f(16, 2,17),f(16, 2,18) /  1.9177500d-02 ,  2.7177800d-02 /
      data f(16, 2,19),f(16, 2,20) /  3.4729200d-02 ,  4.0310900d-02 /
      data f(16, 2,21),f(16, 2,22) /  4.0310900d-02 ,  3.4729200d-02 /
      data f(16, 2,23) /              2.7177800d-02 /
      data f(16, 3, 1),f(16, 3, 2) /  4.3864000d-02 ,  1.0384560d-01 /
      data f(16, 3, 3),f(16, 3, 4) /  1.6123780d-01 ,  1.6123780d-01 /
      data f(16, 3, 5),f(16, 3, 6) /  1.0384560d-01 ,  4.3864000d-02 /
      data f(16, 3, 7),f(16, 3, 8) /  6.2663000d-03 , -1.5293300d-02 /
      data f(16, 3, 9),f(16, 3,10) / -3.1052700d-02 , -4.1806100d-02 /
      data f(16, 3,11),f(16, 3,12) / -4.8240400d-02 , -5.0398100d-02 /
      data f(16, 3,13),f(16, 3,14) / -4.8231200d-02 , -4.1724400d-02 /
      data f(16, 3,15),f(16, 3,16) / -3.0774300d-02 , -1.4652700d-02 /
      data f(16, 3,17),f(16, 3,18) /  7.4544000d-03 ,  4.5618900d-02 /
      data f(16, 3,19),f(16, 3,20) /  1.0604510d-01 ,  1.6148190d-01 /
      data f(16, 3,21),f(16, 3,22) /  1.6148190d-01 ,  1.0604510d-01 /
      data f(16, 3,23) /              4.5618900d-02 /
      data f(16, 4, 1),f(16, 4, 2) /  2.8465000d-02 ,  9.1205000d-02 /
      data f(16, 4, 3),f(16, 4, 4) /  1.6199160d-01 ,  1.6199160d-01 /
      data f(16, 4, 5),f(16, 4, 6) /  9.1205000d-02 ,  2.8465000d-02 /
      data f(16, 4, 7),f(16, 4, 8) / -6.2569000d-03 , -2.9651500d-02 /
      data f(16, 4, 9),f(16, 4,10) / -4.6543500d-02 , -5.8496900d-02 /
      data f(16, 4,11),f(16, 4,12) / -6.5759700d-02 , -6.8367600d-02 /
      data f(16, 4,13),f(16, 4,14) / -6.6310000d-02 , -5.9508600d-02 /
      data f(16, 4,15),f(16, 4,16) / -4.7824600d-02 , -3.0874200d-02 /
      data f(16, 4,17),f(16, 4,18) / -6.9310000d-03 ,  2.8946800d-02 /
      data f(16, 4,19),f(16, 4,20) /  9.2931200d-02 ,  1.6224660d-01 /
      data f(16, 4,21),f(16, 4,22) /  1.6224660d-01 ,  9.2931200d-02 /
      data f(16, 4,23) /              2.8946800d-02 /
      data f(16, 5, 1),f(16, 5, 2) /  1.2965000d-02 ,  3.8996800d-02 /
      data f(16, 5, 3),f(16, 5, 4) /  6.5137100d-02 ,  6.5137100d-02 /
      data f(16, 5, 5),f(16, 5, 6) /  3.8996800d-02 ,  1.2965000d-02 /
      data f(16, 5, 7),f(16, 5, 8) / -8.9517000d-03 , -2.6915700d-02 /
      data f(16, 5, 9),f(16, 5,10) / -4.1025600d-02 , -5.1230800d-02 /
      data f(16, 5,11),f(16, 5,12) / -5.7556600d-02 , -6.0062700d-02 /
      data f(16, 5,13),f(16, 5,14) / -5.8743300d-02 , -5.3493200d-02 /
      data f(16, 5,15),f(16, 5,16) / -4.4135400d-02 , -3.0506100d-02 /
      data f(16, 5,17),f(16, 5,18) / -1.2470000d-02 ,  1.0310600d-02 /
      data f(16, 5,19),f(16, 5,20) /  3.8195500d-02 ,  6.8751100d-02 /
      data f(16, 5,21),f(16, 5,22) /  6.8751100d-02 ,  3.8195500d-02 /
      data f(16, 5,23) /              1.0310600d-02 /
      data f(16, 6, 1),f(16, 6, 2) /  8.1517000d-03 ,  2.1896800d-02 /
      data f(16, 6, 3),f(16, 6, 4) /  3.3650600d-02 ,  3.3650600d-02 /
      data f(16, 6, 5),f(16, 6, 6) /  2.1896800d-02 ,  8.1517000d-03 /
      data f(16, 6, 7),f(16, 6, 8) / -5.2703000d-03 , -1.7226800d-02 /
      data f(16, 6, 9),f(16, 6,10) / -2.7110100d-02 , -3.4613700d-02 /
      data f(16, 6,11),f(16, 6,12) / -3.9570800d-02 , -4.1858200d-02 /
      data f(16, 6,13),f(16, 6,14) / -4.1379000d-02 , -3.8063600d-02 /
      data f(16, 6,15),f(16, 6,16) / -3.1857400d-02 , -2.2739300d-02 /
      data f(16, 6,17),f(16, 6,18) / -1.0836500d-02 ,  3.3587000d-03 /
      data f(16, 6,19),f(16, 6,20) /  1.8616300d-02 ,  3.2058000d-02 /
      data f(16, 6,21),f(16, 6,22) /  3.2058000d-02 ,  1.8616300d-02 /
      data f(16, 6,23) /              3.3587000d-03 /
      data f(16, 7, 1),f(16, 7, 2) /  5.4434000d-03 ,  1.1236100d-02 /
      data f(16, 7, 3),f(16, 7, 4) /  1.5385700d-02 ,  1.5385700d-02 /
      data f(16, 7, 5),f(16, 7, 6) /  1.1236100d-02 ,  5.4434000d-03 /
      data f(16, 7, 7),f(16, 7, 8) / -1.0661000d-03 , -7.5905000d-03 /
      data f(16, 7, 9),f(16, 7,10) / -1.3596000d-02 , -1.8639000d-02 /
      data f(16, 7,11),f(16, 7,12) / -2.2340100d-02 , -2.4408300d-02 /
      data f(16, 7,13),f(16, 7,14) / -2.4664000d-02 , -2.3036300d-02 /
      data f(16, 7,15),f(16, 7,16) / -1.9545900d-02 , -1.4302400d-02 /
      data f(16, 7,17),f(16, 7,18) / -7.5571000d-03 ,  1.5660000d-04 /
      data f(16, 7,19),f(16, 7,20) /  7.8196000d-03 ,  1.3777300d-02 /
      data f(16, 7,21),f(16, 7,22) /  1.3777300d-02 ,  7.8196000d-03 /
      data f(16, 7,23) /              1.5660000d-04 /
      data f(16, 8, 1),f(16, 8, 2) /  5.2428000d-03 ,  7.3365000d-03 /
      data f(16, 8, 3),f(16, 8, 4) /  8.6893000d-03 ,  8.6893000d-03 /
      data f(16, 8, 5),f(16, 8, 6) /  7.3365000d-03 ,  5.2428000d-03 /
      data f(16, 8, 7),f(16, 8, 8) /  2.5590000d-03 , -5.6690000d-04 /
      data f(16, 8, 9),f(16, 8,10) / -3.9120000d-03 , -7.1348000d-03 /
      data f(16, 8,11),f(16, 8,12) / -9.8396000d-03 , -1.1684200d-02 /
      data f(16, 8,13),f(16, 8,14) / -1.2442300d-02 , -1.2014100d-02 /
      data f(16, 8,15),f(16, 8,16) / -1.0407800d-02 , -7.7307000d-03 /
      data f(16, 8,17),f(16, 8,18) / -4.2091000d-03 , -2.3500000d-04 /
      data f(16, 8,19),f(16, 8,20) /  3.5777000d-03 ,  6.4086000d-03 /
      data f(16, 8,21),f(16, 8,22) /  6.4086000d-03 ,  3.5777000d-03 /
      data f(16, 8,23) /             -2.3500000d-04 /
      data f(16, 9, 1),f(16, 9, 2) /  6.0868000d-03 ,  7.3384000d-03 /
      data f(16, 9, 3),f(16, 9, 4) /  8.6245000d-03 ,  8.6245000d-03 /
      data f(16, 9, 5),f(16, 9, 6) /  7.3384000d-03 ,  6.0868000d-03 /
      data f(16, 9, 7),f(16, 9, 8) /  4.8964000d-03 ,  3.4909000d-03 /
      data f(16, 9, 9),f(16, 9,10) /  1.7175000d-03 , -3.1220000d-04 /
      data f(16, 9,11),f(16, 9,12) / -2.2954000d-03 , -3.8961000d-03 /
      data f(16, 9,13),f(16, 9,14) / -4.8652000d-03 , -5.0760000d-03 /
      data f(16, 9,15),f(16, 9,16) / -4.5058000d-03 , -3.2194000d-03 /
      data f(16, 9,17),f(16, 9,18) / -1.3686000d-03 ,  7.8930000d-04 /
      data f(16, 9,19),f(16, 9,20) /  2.8731000d-03 ,  4.4098000d-03 /
      data f(16, 9,21),f(16, 9,22) /  4.4098000d-03 ,  2.8731000d-03 /
      data f(16, 9,23) /              7.8930000d-04 /
      data f(16,10, 1),f(16,10, 2) /  5.3288000d-03 ,  7.2362000d-03 /
      data f(16,10, 3),f(16,10, 4) /  1.1686000d-02 ,  1.1686000d-02 /
      data f(16,10, 5),f(16,10, 6) /  7.2362000d-03 ,  5.3288000d-03 /
      data f(16,10, 7),f(16,10, 8) /  4.8714000d-03 ,  4.6619000d-03 /
      data f(16,10, 9),f(16,10,10) /  4.0558000d-03 ,  2.9478000d-03 /
      data f(16,10,11),f(16,10,12) /  1.5797000d-03 ,  2.8820000d-04 /
      data f(16,10,13),f(16,10,14) / -6.5430000d-04 , -1.0863000d-03 /
      data f(16,10,15),f(16,10,16) / -9.4620000d-04 , -2.5820000d-04 /
      data f(16,10,17),f(16,10,18) /  8.7660000d-04 ,  2.2737000d-03 /
      data f(16,10,19),f(16,10,20) /  3.6502000d-03 ,  4.6606000d-03 /
      data f(16,10,21),f(16,10,22) /  4.6606000d-03 ,  3.6502000d-03 /
      data f(16,10,23) /              2.2737000d-03 /
      data f(16,11, 1),f(16,11, 2) /  4.7350000d-04 ,  9.0360000d-04 /
      data f(16,11, 3),f(16,11, 4) /  2.6840000d-03 ,  2.6840000d-03 /
      data f(16,11, 5),f(16,11, 6) /  9.0360000d-04 ,  4.7350000d-04 /
      data f(16,11, 7),f(16,11, 8) /  1.6753000d-03 ,  3.1604000d-03 /
      data f(16,11, 9),f(16,11,10) /  3.9571000d-03 ,  3.8536000d-03 /
      data f(16,11,11),f(16,11,12) /  3.1450000d-03 ,  2.2490000d-03 /
      data f(16,11,13),f(16,11,14) /  1.4958000d-03 ,  1.0925000d-03 /
      data f(16,11,15),f(16,11,16) /  1.1393000d-03 ,  1.6450000d-03 /
      data f(16,11,17),f(16,11,18) /  2.5359000d-03 ,  3.6516000d-03 /
      data f(16,11,19),f(16,11,20) /  4.7446000d-03 ,  5.5263000d-03 /
      data f(16,11,21),f(16,11,22) /  5.5263000d-03 ,  4.7446000d-03 /
      data f(16,11,23) /              3.6516000d-03 /
      data f(16,12, 1),f(16,12, 2) / -5.2433000d-03 , -4.1059000d-03 /
      data f(16,12, 3),f(16,12, 4) /  1.0944000d-03 ,  1.0944000d-03 /
      data f(16,12, 5),f(16,12, 6) / -4.1059000d-03 , -5.2433000d-03 /
      data f(16,12, 7),f(16,12, 8) / -3.0336000d-03 ,  8.5300000d-05 /
      data f(16,12, 9),f(16,12,10) /  2.3789000d-03 ,  3.3591000d-03 /
      data f(16,12,11),f(16,12,12) /  3.3583000d-03 ,  2.9125000d-03 /
      data f(16,12,13),f(16,12,14) /  2.4364000d-03 ,  2.1850000d-03 /
      data f(16,12,15),f(16,12,16) /  2.2888000d-03 ,  2.7779000d-03 /
      data f(16,12,17),f(16,12,18) /  3.5916000d-03 ,  4.5772000d-03 /
      data f(16,12,19),f(16,12,20) /  5.5102000d-03 ,  6.1590000d-03 /
      data f(16,12,21),f(16,12,22) /  6.1590000d-03 ,  5.5102000d-03 /
      data f(16,12,23) /              4.5772000d-03 /
      data f(16,13, 1),f(16,13, 2) / -7.6981000d-03 , -3.7724000d-03 /
      data f(16,13, 3),f(16,13, 4) /  5.8082000d-03 ,  5.8082000d-03 /
      data f(16,13, 5),f(16,13, 6) / -3.7724000d-03 , -7.6981000d-03 /
      data f(16,13, 7),f(16,13, 8) / -6.2372000d-03 , -2.6237000d-03 /
      data f(16,13, 9),f(16,13,10) /  5.5080000d-04 ,  2.3238000d-03 /
      data f(16,13,11),f(16,13,12) /  2.9079000d-03 ,  2.8708000d-03 /
      data f(16,13,13),f(16,13,14) /  2.6737000d-03 ,  2.5970000d-03 /
      data f(16,13,15),f(16,13,16) /  2.7828000d-03 ,  3.2710000d-03 /
      data f(16,13,17),f(16,13,18) /  4.0115000d-03 ,  4.8684000d-03 /
      data f(16,13,19),f(16,13,20) /  5.6525000d-03 ,  6.1886000d-03 /
      data f(16,13,21),f(16,13,22) /  6.1886000d-03 ,  5.6525000d-03 /
      data f(16,13,23) /              4.8684000d-03 /
      data f(16,14, 1),f(16,14, 2) / -6.9624000d-03 , -2.3515000d-03 /
      data f(16,14, 3),f(16,14, 4) /  6.9505000d-03 ,  6.9505000d-03 /
      data f(16,14, 5),f(16,14, 6) / -2.3515000d-03 , -6.9624000d-03 /
      data f(16,14, 7),f(16,14, 8) / -6.3893000d-03 , -3.3185000d-03 /
      data f(16,14, 9),f(16,14,10) / -3.0050000d-04 ,  1.5699000d-03 /
      data f(16,14,11),f(16,14,12) /  2.3690000d-03 ,  2.5599000d-03 /
      data f(16,14,13),f(16,14,14) /  2.5499000d-03 ,  2.5908000d-03 /
      data f(16,14,15),f(16,14,16) /  2.8094000d-03 ,  3.2412000d-03 /
      data f(16,14,17),f(16,14,18) /  3.8474000d-03 ,  4.5243000d-03 /
      data f(16,14,19),f(16,14,20) /  5.1315000d-03 ,  5.5398000d-03 /
      data f(16,14,21),f(16,14,22) /  5.5398000d-03 ,  5.1315000d-03 /
      data f(16,14,23) /              4.5243000d-03 /
      data f(16,15, 1),f(16,15, 2) / -3.6540000d-03 , -1.2586000d-03 /
      data f(16,15, 3),f(16,15, 4) /  3.3001000d-03 ,  3.3001000d-03 /
      data f(16,15, 5),f(16,15, 6) / -1.2586000d-03 , -3.6540000d-03 /
      data f(16,15, 7),f(16,15, 8) / -3.1776000d-03 , -1.2826000d-03 /
      data f(16,15, 9),f(16,15,10) /  5.4180000d-04 ,  1.6845000d-03 /
      data f(16,15,11),f(16,15,12) /  2.1937000d-03 ,  2.3309000d-03 /
      data f(16,15,13),f(16,15,14) /  2.3424000d-03 ,  2.3908000d-03 /
      data f(16,15,15),f(16,15,16) /  2.5574000d-03 ,  2.8617000d-03 /
      data f(16,15,17),f(16,15,18) /  3.2732000d-03 ,  3.7231000d-03 /
      data f(16,15,19),f(16,15,20) /  4.1219000d-03 ,  4.3900000d-03 /
      data f(16,15,21),f(16,15,22) /  4.3900000d-03 ,  4.1219000d-03 /
      data f(16,15,23) /              3.7231000d-03 /
      data f(16,16, 1),f(16,16, 2) /  4.0000000d-03 ,  4.5746000d-03 /
      data f(16,16, 3),f(16,16, 4) /  4.9644000d-03 ,  4.9644000d-03 /
      data f(16,16, 5),f(16,16, 6) /  4.5746000d-03 ,  4.0000000d-03 /
      data f(16,16, 7),f(16,16, 8) /  3.1979000d-03 ,  2.8576000d-03 /
      data f(16,16, 9),f(16,16,10) /  2.7739000d-03 ,  2.7073000d-03 /
      data f(16,16,11),f(16,16,12) /  2.5833000d-03 ,  2.4268000d-03 /
      data f(16,16,13),f(16,16,14) /  2.2937000d-03 ,  2.2321000d-03 /
      data f(16,16,15),f(16,16,16) /  2.2652000d-03 ,  2.3904000d-03 /
      data f(16,16,17),f(16,16,18) /  2.5824000d-03 ,  2.8004000d-03 /
      data f(16,16,19),f(16,16,20) /  2.9976000d-03 ,  3.1325000d-03 /
      data f(16,16,21),f(16,16,22) /  3.1325000d-03 ,  2.9976000d-03 /
      data f(16,16,23) /              2.8004000d-03 /
      data f(16,17, 1),f(16,17, 2) /  9.1975000d-03 ,  1.1514900d-02 /
      data f(16,17, 3),f(16,17, 4) /  1.3570500d-02 ,  1.3570500d-02 /
      data f(16,17, 5),f(16,17, 6) /  1.1514900d-02 ,  9.1975000d-03 /
      data f(16,17, 7),f(16,17, 8) /  7.2366000d-03 ,  5.7626000d-03 /
      data f(16,17, 9),f(16,17,10) /  4.6922000d-03 ,  3.9092000d-03 /
      data f(16,17,11),f(16,17,12) /  3.3257000d-03 ,  2.8884000d-03 /
      data f(16,17,13),f(16,17,14) /  2.5690000d-03 ,  2.3510000d-03 /
      data f(16,17,15),f(16,17,16) /  2.2211000d-03 ,  2.1635000d-03 /
      data f(16,17,17),f(16,17,18) /  2.1591000d-03 ,  2.1862000d-03 /
      data f(16,17,19),f(16,17,20) /  2.2240000d-03 ,  2.2541000d-03 /
      data f(16,17,21),f(16,17,22) /  2.2541000d-03 ,  2.2240000d-03 /
      data f(16,17,23) /              2.1862000d-03 /
      data f(16,18, 1),f(16,18, 2) /  6.5172000d-03 ,  6.9929000d-03 /
      data f(16,18, 3),f(16,18, 4) /  7.3156000d-03 ,  7.3156000d-03 /
      data f(16,18, 5),f(16,18, 6) /  6.9929000d-03 ,  6.5172000d-03 /
      data f(16,18, 7),f(16,18, 8) /  5.9562000d-03 ,  5.3720000d-03 /
      data f(16,18, 9),f(16,18,10) /  4.8100000d-03 ,  4.2978000d-03 /
      data f(16,18,11),f(16,18,12) /  3.8486000d-03 ,  3.4665000d-03 /
      data f(16,18,13),f(16,18,14) /  3.1498000d-03 ,  2.8940000d-03 /
      data f(16,18,15),f(16,18,16) /  2.6932000d-03 ,  2.5402000d-03 /
      data f(16,18,17),f(16,18,18) /  2.4279000d-03 ,  2.3494000d-03 /
      data f(16,18,19),f(16,18,20) /  2.2983000d-03 ,  2.2706000d-03 /
      data f(16,18,21),f(16,18,22) /  2.2706000d-03 ,  2.2983000d-03 /
      data f(16,18,23) /              2.3494000d-03 /
      data f(16,19, 1),f(16,19, 2) /  3.7347000d-03 ,  3.7347000d-03 /
      data f(16,19, 3),f(16,19, 4) /  3.7347000d-03 ,  3.7347000d-03 /
      data f(16,19, 5),f(16,19, 6) /  3.7347000d-03 ,  3.7347000d-03 /
      data f(16,19, 7),f(16,19, 8) /  3.7347000d-03 ,  3.7347000d-03 /
      data f(16,19, 9),f(16,19,10) /  3.7347000d-03 ,  3.7347000d-03 /
      data f(16,19,11),f(16,19,12) /  3.7347000d-03 ,  3.7347000d-03 /
      data f(16,19,13),f(16,19,14) /  3.7347000d-03 ,  3.7347000d-03 /
      data f(16,19,15),f(16,19,16) /  3.7347000d-03 ,  3.7347000d-03 /
      data f(16,19,17),f(16,19,18) /  3.7347000d-03 ,  3.7347000d-03 /
      data f(16,19,19),f(16,19,20) /  3.7347000d-03 ,  3.7347000d-03 /
      data f(16,19,21),f(16,19,22) /  3.7347000d-03 ,  3.7347000d-03 /
      data f(16,19,23) /              3.7347000d-03 /
      data f(17, 1, 1),f(17, 1, 2) /  3.0689600d-02 ,  3.0689600d-02 /
      data f(17, 1, 3),f(17, 1, 4) /  3.0689600d-02 ,  3.0689600d-02 /
      data f(17, 1, 5),f(17, 1, 6) /  3.0689600d-02 ,  3.0689600d-02 /
      data f(17, 1, 7),f(17, 1, 8) /  3.0689600d-02 ,  3.0689600d-02 /
      data f(17, 1, 9),f(17, 1,10) /  3.0689600d-02 ,  3.0689600d-02 /
      data f(17, 1,11),f(17, 1,12) /  3.0689600d-02 ,  3.0689600d-02 /
      data f(17, 1,13),f(17, 1,14) /  3.0689600d-02 ,  3.0689600d-02 /
      data f(17, 1,15),f(17, 1,16) /  3.0689600d-02 ,  3.0689600d-02 /
      data f(17, 1,17),f(17, 1,18) /  3.0689600d-02 ,  3.0689600d-02 /
      data f(17, 1,19),f(17, 1,20) /  3.0689600d-02 ,  3.0689600d-02 /
      data f(17, 1,21),f(17, 1,22) /  3.0689600d-02 ,  3.0689600d-02 /
      data f(17, 1,23) /              3.0689600d-02 /
      data f(17, 2, 1),f(17, 2, 2) /  2.5273700d-02 ,  3.1517000d-02 /
      data f(17, 2, 3),f(17, 2, 4) /  3.6063100d-02 ,  3.6063100d-02 /
      data f(17, 2, 5),f(17, 2, 6) /  3.1517000d-02 ,  2.5273700d-02 /
      data f(17, 2, 7),f(17, 2, 8) /  1.8540100d-02 ,  1.2178700d-02 /
      data f(17, 2, 9),f(17, 2,10) /  6.7452000d-03 ,  2.6076000d-03 /
      data f(17, 2,11),f(17, 2,12) /  4.3100000d-05 ,  1.0743000d-03 /
      data f(17, 2,13),f(17, 2,14) /  2.1214000d-03 ,  3.0978000d-03 /
      data f(17, 2,15),f(17, 2,16) /  7.5051000d-03 ,  1.3233800d-02 /
      data f(17, 2,17),f(17, 2,18) /  1.9895800d-02 ,  2.6912900d-02 /
      data f(17, 2,19),f(17, 2,20) /  3.3384400d-02 ,  3.8082400d-02 /
      data f(17, 2,21),f(17, 2,22) /  3.8082400d-02 ,  3.3384400d-02 /
      data f(17, 2,23) /              2.6912900d-02 /
      data f(17, 3, 1),f(17, 3, 2) /  3.7294300d-02 ,  8.2983200d-02 /
      data f(17, 3, 3),f(17, 3, 4) /  1.3578100d-01 ,  1.3578100d-01 /
      data f(17, 3, 5),f(17, 3, 6) /  8.2983200d-02 ,  3.7294300d-02 /
      data f(17, 3, 7),f(17, 3, 8) /  6.5258000d-03 , -1.2377800d-02 /
      data f(17, 3, 9),f(17, 3,10) / -2.6910800d-02 , -3.7084600d-02 /
      data f(17, 3,11),f(17, 3,12) / -4.3238200d-02 , -4.5319100d-02 /
      data f(17, 3,13),f(17, 3,14) / -4.3263300d-02 , -3.7074100d-02 /
      data f(17, 3,15),f(17, 3,16) / -2.6743000d-02 , -1.1883300d-02 /
      data f(17, 3,17),f(17, 3,18) /  7.5495000d-03 ,  3.8887700d-02 /
      data f(17, 3,19),f(17, 3,20) /  8.5052400d-02 ,  1.3811370d-01 /
      data f(17, 3,21),f(17, 3,22) /  1.3811370d-01 ,  8.5052400d-02 /
      data f(17, 3,23) /              3.8887700d-02 /
      data f(17, 4, 1),f(17, 4, 2) /  2.6586100d-02 ,  7.6639200d-02 /
      data f(17, 4, 3),f(17, 4, 4) /  1.4557160d-01 ,  1.4557160d-01 /
      data f(17, 4, 5),f(17, 4, 6) /  7.6639200d-02 ,  2.6586100d-02 /
      data f(17, 4, 7),f(17, 4, 8) / -3.9361000d-03 , -2.5646800d-02 /
      data f(17, 4, 9),f(17, 4,10) / -4.1676700d-02 , -5.3076900d-02 /
      data f(17, 4,11),f(17, 4,12) / -6.0008100d-02 , -6.2505300d-02 /
      data f(17, 4,13),f(17, 4,14) / -6.0563800d-02 , -5.4105300d-02 /
      data f(17, 4,15),f(17, 4,16) / -4.3000200d-02 , -2.6965500d-02 /
      data f(17, 4,17),f(17, 4,18) / -4.7955000d-03 ,  2.6819300d-02 /
      data f(17, 4,19),f(17, 4,20) /  7.8183700d-02 ,  1.4800890d-01 /
      data f(17, 4,21),f(17, 4,22) /  1.4800890d-01 ,  7.8183700d-02 /
      data f(17, 4,23) /              2.6819300d-02 /
      data f(17, 5, 1),f(17, 5, 2) /  1.3751800d-02 ,  3.8036700d-02 /
      data f(17, 5, 3),f(17, 5, 4) /  6.4237700d-02 ,  6.4237700d-02 /
      data f(17, 5, 5),f(17, 5, 6) /  3.8036700d-02 ,  1.3751800d-02 /
      data f(17, 5, 7),f(17, 5, 8) / -6.8421000d-03 , -2.3784800d-02 /
      data f(17, 5, 9),f(17, 5,10) / -3.7093400d-02 , -4.6712700d-02 /
      data f(17, 5,11),f(17, 5,12) / -5.2676500d-02 , -5.5047000d-02 /
      data f(17, 5,13),f(17, 5,14) / -5.3819200d-02 , -4.8890700d-02 /
      data f(17, 5,15),f(17, 5,16) / -4.0088800d-02 , -2.7256200d-02 /
      data f(17, 5,17),f(17, 5,18) / -1.0293600d-02 ,  1.0996700d-02 /
      data f(17, 5,19),f(17, 5,20) /  3.6739600d-02 ,  6.4915900d-02 /
      data f(17, 5,21),f(17, 5,22) /  6.4915900d-02 ,  3.6739600d-02 /
      data f(17, 5,23) /              1.0996700d-02 /
      data f(17, 6, 1),f(17, 6, 2) /  7.9407000d-03 ,  2.0400700d-02 /
      data f(17, 6, 3),f(17, 6, 4) /  3.0766300d-02 ,  3.0766300d-02 /
      data f(17, 6, 5),f(17, 6, 6) /  2.0400700d-02 ,  7.9407000d-03 /
      data f(17, 6, 7),f(17, 6, 8) / -4.3810000d-03 , -1.5416900d-02 /
      data f(17, 6, 9),f(17, 6,10) / -2.4564000d-02 , -3.1524000d-02 /
      data f(17, 6,11),f(17, 6,12) / -3.6132900d-02 , -3.8267100d-02 /
      data f(17, 6,13),f(17, 6,14) / -3.7829500d-02 , -3.4754800d-02 /
      data f(17, 6,15),f(17, 6,16) / -2.8996700d-02 , -2.0543900d-02 /
      data f(17, 6,17),f(17, 6,18) / -9.5329000d-03 ,  3.5337000d-03 /
      data f(17, 6,19),f(17, 6,20) /  1.7422200d-02 ,  2.9394500d-02 /
      data f(17, 6,21),f(17, 6,22) /  2.9394500d-02 ,  1.7422200d-02 /
      data f(17, 6,23) /              3.5337000d-03 /
      data f(17, 7, 1),f(17, 7, 2) /  4.8918000d-03 ,  1.0082000d-02 /
      data f(17, 7, 3),f(17, 7, 4) /  1.3760900d-02 ,  1.3760900d-02 /
      data f(17, 7, 5),f(17, 7, 6) /  1.0082000d-02 ,  4.8918000d-03 /
      data f(17, 7, 7),f(17, 7, 8) / -9.8230000d-04 , -6.8939000d-03 /
      data f(17, 7, 9),f(17, 7,10) / -1.2350000d-02 , -1.6942000d-02 /
      data f(17, 7,11),f(17, 7,12) / -2.0319500d-02 , -2.2212300d-02 /
      data f(17, 7,13),f(17, 7,14) / -2.2451600d-02 , -2.0968300d-02 /
      data f(17, 7,15),f(17, 7,16) / -1.7780500d-02 , -1.2992800d-02 /
      data f(17, 7,17),f(17, 7,18) / -6.8453000d-03 ,  1.5780000d-04 /
      data f(17, 7,19),f(17, 7,20) /  7.0681000d-03 ,  1.2390900d-02 /
      data f(17, 7,21),f(17, 7,22) /  1.2390900d-02 ,  7.0681000d-03 /
      data f(17, 7,23) /              1.5780000d-04 /
      data f(17, 8, 1),f(17, 8, 2) /  4.4927000d-03 ,  6.3557000d-03 /
      data f(17, 8, 3),f(17, 8, 4) /  7.5573000d-03 ,  7.5573000d-03 /
      data f(17, 8, 5),f(17, 8, 6) /  6.3557000d-03 ,  4.4927000d-03 /
      data f(17, 8, 7),f(17, 8, 8) /  2.1024000d-03 , -6.8210000d-04 /
      data f(17, 8, 9),f(17, 8,10) / -3.6637000d-03 , -6.5410000d-03 /
      data f(17, 8,11),f(17, 8,12) / -8.9620000d-03 , -1.0618400d-02 /
      data f(17, 8,13),f(17, 8,14) / -1.1303100d-02 , -1.0923100d-02 /
      data f(17, 8,15),f(17, 8,16) / -9.4818000d-03 , -7.0773000d-03 /
      data f(17, 8,17),f(17, 8,18) / -3.9133000d-03 , -3.5110000d-04 /
      data f(17, 8,19),f(17, 8,20) /  3.0503000d-03 ,  5.5603000d-03 /
      data f(17, 8,21),f(17, 8,22) /  5.5603000d-03 ,  3.0503000d-03 /
      data f(17, 8,23) /             -3.5110000d-04 /
      data f(17, 9, 1),f(17, 9, 2) /  5.1924000d-03 ,  6.3292000d-03 /
      data f(17, 9, 3),f(17, 9, 4) /  7.4740000d-03 ,  7.4740000d-03 /
      data f(17, 9, 5),f(17, 9, 6) /  6.3292000d-03 ,  5.1924000d-03 /
      data f(17, 9, 7),f(17, 9, 8) /  4.1211000d-03 ,  2.8808000d-03 /
      data f(17, 9, 9),f(17, 9,10) /  1.3274000d-03 , -4.5260000d-04 /
      data f(17, 9,11),f(17, 9,12) / -2.1984000d-03 , -3.6131000d-03 /
      data f(17, 9,13),f(17, 9,14) / -4.4740000d-03 , -4.6657000d-03 /
      data f(17, 9,15),f(17, 9,16) / -4.1643000d-03 , -3.0251000d-03 /
      data f(17, 9,17),f(17, 9,18) / -1.3828000d-03 ,  5.2880000d-04 /
      data f(17, 9,19),f(17, 9,20) /  2.3652000d-03 ,  3.7095000d-03 /
      data f(17, 9,21),f(17, 9,22) /  3.7095000d-03 ,  2.3652000d-03 /
      data f(17, 9,23) /              5.2880000d-04 /
      data f(17,10, 1),f(17,10, 2) /  4.7866000d-03 ,  6.7649000d-03 /
      data f(17,10, 3),f(17,10, 4) /  1.0561900d-02 ,  1.0561900d-02 /
      data f(17,10, 5),f(17,10, 6) /  6.7649000d-03 ,  4.7866000d-03 /
      data f(17,10, 7),f(17,10, 8) /  4.1806000d-03 ,  3.9200000d-03 /
      data f(17,10, 9),f(17,10,10) /  3.3778000d-03 ,  2.4188000d-03 /
      data f(17,10,11),f(17,10,12) /  1.2322000d-03 ,  1.0520000d-04 /
      data f(17,10,13),f(17,10,14) / -7.2280000d-04 , -1.1063000d-03 /
      data f(17,10,15),f(17,10,16) / -9.8780000d-04 , -3.8320000d-04 /
      data f(17,10,17),f(17,10,18) /  6.1790000d-04 ,  1.8469000d-03 /
      data f(17,10,19),f(17,10,20) /  3.0499000d-03 ,  3.9219000d-03 /
      data f(17,10,21),f(17,10,22) /  3.9219000d-03 ,  3.0499000d-03 /
      data f(17,10,23) /              1.8469000d-03 /
      data f(17,11, 1),f(17,11, 2) /  1.4179000d-03 ,  3.7641000d-03 /
      data f(17,11, 3),f(17,11, 4) /  9.3057000d-03 ,  9.3057000d-03 /
      data f(17,11, 5),f(17,11, 6) /  3.7641000d-03 ,  1.4179000d-03 /
      data f(17,11, 7),f(17,11, 8) /  1.7003000d-03 ,  2.7022000d-03 /
      data f(17,11, 9),f(17,11,10) /  3.3070000d-03 ,  3.2056000d-03 /
      data f(17,11,11),f(17,11,12) /  2.5983000d-03 ,  1.8252000d-03 /
      data f(17,11,13),f(17,11,14) /  1.1695000d-03 ,  8.1500000d-04 /
      data f(17,11,15),f(17,11,16) /  8.5480000d-04 ,  1.3001000d-03 /
      data f(17,11,17),f(17,11,18) /  2.0851000d-03 ,  3.0661000d-03 /
      data f(17,11,19),f(17,11,20) /  4.0207000d-03 ,  4.6917000d-03 /
      data f(17,11,21),f(17,11,22) /  4.6917000d-03 ,  4.0207000d-03 /
      data f(17,11,23) /              3.0661000d-03 /
      data f(17,12, 1),f(17,12, 2) / -2.7487000d-03 ,  6.0130000d-04 /
      data f(17,12, 3),f(17,12, 4) /  8.9180000d-03 ,  8.9180000d-03 /
      data f(17,12, 5),f(17,12, 6) /  6.0130000d-04 , -2.7487000d-03 /
      data f(17,12, 7),f(17,12, 8) / -1.9931000d-03 ,  1.9040000d-04 /
      data f(17,12, 9),f(17,12,10) /  1.9805000d-03 ,  2.7748000d-03 /
      data f(17,12,11),f(17,12,12) /  2.7719000d-03 ,  2.3926000d-03 /
      data f(17,12,13),f(17,12,14) /  1.9823000d-03 ,  1.7640000d-03 /
      data f(17,12,15),f(17,12,16) /  1.8567000d-03 ,  2.2889000d-03 /
      data f(17,12,17),f(17,12,18) /  3.0065000d-03 ,  3.8741000d-03 /
      data f(17,12,19),f(17,12,20) /  4.6921000d-03 ,  5.2538000d-03 /
      data f(17,12,21),f(17,12,22) /  5.2538000d-03 ,  4.6921000d-03 /
      data f(17,12,23) /              3.8741000d-03 /
      data f(17,13, 1),f(17,13, 2) / -4.2601000d-03 ,  1.7164000d-03 /
      data f(17,13, 3),f(17,13, 4) /  1.5517400d-02 ,  1.5517400d-02 /
      data f(17,13, 5),f(17,13, 6) /  1.7164000d-03 , -4.2601000d-03 /
      data f(17,13, 7),f(17,13, 8) / -4.3749000d-03 , -1.9541000d-03 /
      data f(17,13, 9),f(17,13,10) /  4.7300000d-04 ,  1.8915000d-03 /
      data f(17,13,11),f(17,13,12) /  2.3718000d-03 ,  2.3420000d-03 /
      data f(17,13,13),f(17,13,14) /  2.1753000d-03 ,  2.1107000d-03 /
      data f(17,13,15),f(17,13,16) /  2.2756000d-03 ,  2.7063000d-03 /
      data f(17,13,17),f(17,13,18) /  3.3586000d-03 ,  4.1129000d-03 /
      data f(17,13,19),f(17,13,20) /  4.8023000d-03 ,  5.2711000d-03 /
      data f(17,13,21),f(17,13,22) /  5.2711000d-03 ,  4.8023000d-03 /
      data f(17,13,23) /              4.1129000d-03 /
      data f(17,14, 1),f(17,14, 2) / -3.0011000d-03 ,  3.7061000d-03 /
      data f(17,14, 3),f(17,14, 4) /  1.7262600d-02 ,  1.7262600d-02 /
      data f(17,14, 5),f(17,14, 6) /  3.7061000d-03 , -3.0011000d-03 /
      data f(17,14, 7),f(17,14, 8) / -4.0613000d-03 , -2.2994000d-03 /
      data f(17,14, 9),f(17,14,10) / -1.4960000d-04 ,  1.2768000d-03 /
      data f(17,14,11),f(17,14,12) /  1.9083000d-03 ,  2.0625000d-03 /
      data f(17,14,13),f(17,14,14) /  2.0547000d-03 ,  2.0920000d-03 /
      data f(17,14,15),f(17,14,16) /  2.2841000d-03 ,  2.6632000d-03 /
      data f(17,14,17),f(17,14,18) /  3.1953000d-03 ,  3.7897000d-03 /
      data f(17,14,19),f(17,14,20) /  4.3220000d-03 ,  4.6782000d-03 /
      data f(17,14,21),f(17,14,22) /  4.6782000d-03 ,  4.3220000d-03 /
      data f(17,14,23) /              3.7897000d-03 /
      data f(17,15, 1),f(17,15, 2) /  4.4030000d-04 ,  5.1015000d-03 /
      data f(17,15, 3),f(17,15, 4) /  1.2540300d-02 ,  1.2540300d-02 /
      data f(17,15, 5),f(17,15, 6) /  5.1015000d-03 ,  4.4030000d-04 /
      data f(17,15, 7),f(17,15, 8) / -8.9760000d-04 , -3.3000000d-04 /
      data f(17,15, 9),f(17,15,10) /  6.8530000d-04 ,  1.4274000d-03 /
      data f(17,15,11),f(17,15,12) /  1.7750000d-03 ,  1.8635000d-03 /
      data f(17,15,13),f(17,15,14) /  1.8654000d-03 ,  1.9059000d-03 /
      data f(17,15,15),f(17,15,16) /  2.0507000d-03 ,  2.3159000d-03 /
      data f(17,15,17),f(17,15,18) /  2.6750000d-03 ,  3.0679000d-03 /
      data f(17,15,19),f(17,15,20) /  3.4156000d-03 ,  3.6486000d-03 /
      data f(17,15,21),f(17,15,22) /  3.6486000d-03 ,  3.4156000d-03 /
      data f(17,15,23) /              3.0679000d-03 /
      data f(17,16, 1),f(17,16, 2) /  6.5387000d-03 ,  1.0142400d-02 /
      data f(17,16, 3),f(17,16, 4) /  1.2518500d-02 ,  1.2518500d-02 /
      data f(17,16, 5),f(17,16, 6) /  1.0142400d-02 ,  6.5387000d-03 /
      data f(17,16, 7),f(17,16, 8) /  4.1610000d-03 ,  3.0713000d-03 /
      data f(17,16, 9),f(17,16,10) /  2.5923000d-03 ,  2.3355000d-03 /
      data f(17,16,11),f(17,16,12) /  2.1345000d-03 ,  1.9562000d-03 /
      data f(17,16,13),f(17,16,14) /  1.8219000d-03 ,  1.7601000d-03 /
      data f(17,16,15),f(17,16,16) /  1.7850000d-03 ,  1.8916000d-03 /
      data f(17,16,17),f(17,16,18) /  2.0572000d-03 ,  2.2457000d-03 /
      data f(17,16,19),f(17,16,20) /  2.4163000d-03 ,  2.5329000d-03 /
      data f(17,16,21),f(17,16,22) /  2.5329000d-03 ,  2.4163000d-03 /
      data f(17,16,23) /              2.2457000d-03 /
      data f(17,17, 1),f(17,17, 2) /  8.3103000d-03 ,  1.0290500d-02 /
      data f(17,17, 3),f(17,17, 4) /  1.1958500d-02 ,  1.1958500d-02 /
      data f(17,17, 5),f(17,17, 6) /  1.0290500d-02 ,  8.3103000d-03 /
      data f(17,17, 7),f(17,17, 8) /  6.5331000d-03 ,  5.1385000d-03 /
      data f(17,17, 9),f(17,17,10) /  4.1038000d-03 ,  3.3448000d-03 /
      data f(17,17,11),f(17,17,12) /  2.7841000d-03 ,  2.3692000d-03 /
      data f(17,17,13),f(17,17,14) /  2.0694000d-03 ,  1.8660000d-03 /
      data f(17,17,15),f(17,17,16) /  1.7443000d-03 ,  1.6885000d-03 /
      data f(17,17,17),f(17,17,18) /  1.6808000d-03 ,  1.7017000d-03 /
      data f(17,17,19),f(17,17,20) /  1.7327000d-03 ,  1.7577000d-03 /
      data f(17,17,21),f(17,17,22) /  1.7577000d-03 ,  1.7327000d-03 /
      data f(17,17,23) /              1.7017000d-03 /
      data f(17,18, 1),f(17,18, 2) /  5.6258000d-03 ,  6.0456000d-03 /
      data f(17,18, 3),f(17,18, 4) /  6.3282000d-03 ,  6.3282000d-03 /
      data f(17,18, 5),f(17,18, 6) /  6.0456000d-03 ,  5.6258000d-03 /
      data f(17,18, 7),f(17,18, 8) /  5.1274000d-03 ,  4.6043000d-03 /
      data f(17,18, 9),f(17,18,10) /  4.0978000d-03 ,  3.6337000d-03 /
      data f(17,18,11),f(17,18,12) /  3.2253000d-03 ,  2.8770000d-03 /
      data f(17,18,13),f(17,18,14) /  2.5879000d-03 ,  2.3542000d-03 /
      data f(17,18,15),f(17,18,16) /  2.1705000d-03 ,  2.0304000d-03 /
      data f(17,18,17),f(17,18,18) /  1.9275000d-03 ,  1.8553000d-03 /
      data f(17,18,19),f(17,18,20) /  1.8083000d-03 ,  1.7827000d-03 /
      data f(17,18,21),f(17,18,22) /  1.7827000d-03 ,  1.8083000d-03 /
      data f(17,18,23) /              1.8553000d-03 /
      data f(17,19, 1),f(17,19, 2) /  3.1104000d-03 ,  3.1104000d-03 /
      data f(17,19, 3),f(17,19, 4) /  3.1104000d-03 ,  3.1104000d-03 /
      data f(17,19, 5),f(17,19, 6) /  3.1104000d-03 ,  3.1104000d-03 /
      data f(17,19, 7),f(17,19, 8) /  3.1104000d-03 ,  3.1104000d-03 /
      data f(17,19, 9),f(17,19,10) /  3.1104000d-03 ,  3.1104000d-03 /
      data f(17,19,11),f(17,19,12) /  3.1104000d-03 ,  3.1104000d-03 /
      data f(17,19,13),f(17,19,14) /  3.1104000d-03 ,  3.1104000d-03 /
      data f(17,19,15),f(17,19,16) /  3.1104000d-03 ,  3.1104000d-03 /
      data f(17,19,17),f(17,19,18) /  3.1104000d-03 ,  3.1104000d-03 /
      data f(17,19,19),f(17,19,20) /  3.1104000d-03 ,  3.1104000d-03 /
      data f(17,19,21),f(17,19,22) /  3.1104000d-03 ,  3.1104000d-03 /
      data f(17,19,23) /              3.1104000d-03 /
      data f(18, 1, 1),f(18, 1, 2) /  1.1565060d-01 ,  1.1565060d-01 /
      data f(18, 1, 3),f(18, 1, 4) /  1.1565060d-01 ,  1.1565060d-01 /
      data f(18, 1, 5),f(18, 1, 6) /  1.1565060d-01 ,  1.1565060d-01 /
      data f(18, 1, 7),f(18, 1, 8) /  1.1565060d-01 ,  1.1565060d-01 /
      data f(18, 1, 9),f(18, 1,10) /  1.1565060d-01 ,  1.1565060d-01 /
      data f(18, 1,11),f(18, 1,12) /  1.1565060d-01 ,  1.1565060d-01 /
      data f(18, 1,13),f(18, 1,14) /  1.1565060d-01 ,  1.1565060d-01 /
      data f(18, 1,15),f(18, 1,16) /  1.1565060d-01 ,  1.1565060d-01 /
      data f(18, 1,17),f(18, 1,18) /  1.1565060d-01 ,  1.1565060d-01 /
      data f(18, 1,19),f(18, 1,20) /  1.1565060d-01 ,  1.1565060d-01 /
      data f(18, 1,21),f(18, 1,22) /  1.1565060d-01 ,  1.1565060d-01 /
      data f(18, 1,23) /              1.1565060d-01 /
      data f(18, 2, 1),f(18, 2, 2) /  3.0409000d-02 ,  3.5393800d-02 /
      data f(18, 2, 3),f(18, 2, 4) /  3.8877300d-02 ,  3.8877300d-02 /
      data f(18, 2, 5),f(18, 2, 6) /  3.5393800d-02 ,  3.0409000d-02 /
      data f(18, 2, 7),f(18, 2, 8) /  2.4762200d-02 ,  1.9172200d-02 /
      data f(18, 2, 9),f(18, 2,10) /  1.5635000d-02 ,  1.1645600d-02 /
      data f(18, 2,11),f(18, 2,12) /  9.1269000d-03 ,  8.3153000d-03 /
      data f(18, 2,13),f(18, 2,14) /  9.2945000d-03 ,  1.1999300d-02 /
      data f(18, 2,15),f(18, 2,16) /  1.6205600d-02 ,  1.9989200d-02 /
      data f(18, 2,17),f(18, 2,18) /  2.5845000d-02 ,  3.1759900d-02 /
      data f(18, 2,19),f(18, 2,20) /  3.6974400d-02 ,  4.0618400d-02 /
      data f(18, 2,21),f(18, 2,22) /  4.0618400d-02 ,  3.6974400d-02 /
      data f(18, 2,23) /              3.1759900d-02 /
      data f(18, 3, 1),f(18, 3, 2) /  3.1493700d-02 ,  5.8841100d-02 /
      data f(18, 3, 3),f(18, 3, 4) /  8.6462100d-02 ,  8.6462100d-02 /
      data f(18, 3, 5),f(18, 3, 6) /  5.8841100d-02 ,  3.1493700d-02 /
      data f(18, 3, 7),f(18, 3, 8) /  1.1152700d-02 , -5.5117000d-03 /
      data f(18, 3, 9),f(18, 3,10) / -1.8299600d-02 , -2.7566000d-02 /
      data f(18, 3,11),f(18, 3,12) / -3.3237900d-02 , -3.5182000d-02 /
      data f(18, 3,13),f(18, 3,14) / -3.3330300d-02 , -2.7698200d-02 /
      data f(18, 3,15),f(18, 3,16) / -1.8364200d-02 , -5.3492000d-03 /
      data f(18, 3,17),f(18, 3,18) /  1.1735700d-02 ,  3.2683800d-02 /
      data f(18, 3,19),f(18, 3,20) /  6.0553400d-02 ,  8.8507400d-02 /
      data f(18, 3,21),f(18, 3,22) /  8.8507400d-02 ,  6.0553400d-02 /
      data f(18, 3,23) /              3.2683800d-02 /
      data f(18, 4, 1),f(18, 4, 2) /  2.5694400d-02 ,  5.8995700d-02 /
      data f(18, 4, 3),f(18, 4, 4) /  9.7661200d-02 ,  9.7661200d-02 /
      data f(18, 4, 5),f(18, 4, 6) /  5.8995700d-02 ,  2.5694400d-02 /
      data f(18, 4, 7),f(18, 4, 8) /  5.8320000d-04 , -1.8324100d-02 /
      data f(18, 4, 9),f(18, 4,10) / -3.2700900d-02 , -4.2974200d-02 /
      data f(18, 4,11),f(18, 4,12) / -4.9218700d-02 , -5.1483000d-02 /
      data f(18, 4,13),f(18, 4,14) / -4.9773900d-02 , -4.4012900d-02 /
      data f(18, 4,15),f(18, 4,16) / -3.4073200d-02 , -1.9787600d-02 /
      data f(18, 4,17),f(18, 4,18) / -6.1170000d-04 ,  2.5248300d-02 /
      data f(18, 4,19),f(18, 4,20) /  5.9897800d-02 ,  9.9724100d-02 /
      data f(18, 4,21),f(18, 4,22) /  9.9724100d-02 ,  5.9897800d-02 /
      data f(18, 4,23) /              2.5248300d-02 /
      data f(18, 5, 1),f(18, 5, 2) /  1.4285700d-02 ,  3.4685300d-02 /
      data f(18, 5, 3),f(18, 5, 4) /  5.5657300d-02 ,  5.5657300d-02 /
      data f(18, 5, 5),f(18, 5, 6) /  3.4685300d-02 ,  1.4285700d-02 /
      data f(18, 5, 7),f(18, 5, 8) / -3.5037000d-03 , -1.8312300d-02 /
      data f(18, 5, 9),f(18, 5,10) / -2.9976000d-02 , -3.8411500d-02 /
      data f(18, 5,11),f(18, 5,12) / -4.3650800d-02 , -4.5748100d-02 /
      data f(18, 5,13),f(18, 5,14) / -4.4695300d-02 , -4.0399500d-02 /
      data f(18, 5,15),f(18, 5,16) / -3.2706900d-02 , -2.1483500d-02 /
      data f(18, 5,17),f(18, 5,18) / -6.7020000d-03 ,  1.1577800d-02 /
      data f(18, 5,19),f(18, 5,20) /  3.2971700d-02 ,  5.5055300d-02 /
      data f(18, 5,21),f(18, 5,22) /  5.5055300d-02 ,  3.2971700d-02 /
      data f(18, 5,23) /              1.1577800d-02 /
      data f(18, 6, 1),f(18, 6, 2) /  7.2492000d-03 ,  1.7345000d-02 /
      data f(18, 6, 3),f(18, 6, 4) /  2.5373900d-02 ,  2.5373900d-02 /
      data f(18, 6, 5),f(18, 6, 6) /  1.7345000d-02 ,  7.2492000d-03 /
      data f(18, 6, 7),f(18, 6, 8) / -2.9815000d-03 , -1.2254000d-02 /
      data f(18, 6, 9),f(18, 6,10) / -1.9990900d-02 , -2.5909300d-02 /
      data f(18, 6,11),f(18, 6,12) / -2.9849500d-02 , -3.1686400d-02 /
      data f(18, 6,13),f(18, 6,14) / -3.1324100d-02 , -2.8705600d-02 /
      data f(18, 6,15),f(18, 6,16) / -2.3800900d-02 , -1.6618000d-02 /
      data f(18, 6,17),f(18, 6,18) / -7.3081000d-03 ,  3.6223000d-03 /
      data f(18, 6,19),f(18, 6,20) /  1.4989200d-02 ,  2.4418800d-02 /
      data f(18, 6,21),f(18, 6,22) /  2.4418800d-02 ,  1.4989200d-02 /
      data f(18, 6,23) /              3.6223000d-03 /
      data f(18, 7, 1),f(18, 7, 2) /  3.8817000d-03 ,  8.0224000d-03 /
      data f(18, 7, 3),f(18, 7, 4) /  1.0910500d-02 ,  1.0910500d-02 /
      data f(18, 7, 5),f(18, 7, 6) /  8.0224000d-03 ,  3.8817000d-03 /
      data f(18, 7, 7),f(18, 7, 8) / -8.6070000d-04 , -5.6685000d-03 /
      data f(18, 7, 9),f(18, 7,10) / -1.0127900d-02 , -1.3896000d-02 /
      data f(18, 7,11),f(18, 7,12) / -1.6678500d-02 , -1.8246400d-02 /
      data f(18, 7,13),f(18, 7,14) / -1.8452600d-02 , -1.7232500d-02 /
      data f(18, 7,15),f(18, 7,16) / -1.4598800d-02 , -1.0645300d-02 /
      data f(18, 7,17),f(18, 7,18) / -5.5870000d-03 ,  1.3100000d-04 /
      data f(18, 7,19),f(18, 7,20) /  5.7051000d-03 ,  9.9304000d-03 /
      data f(18, 7,21),f(18, 7,22) /  9.9304000d-03 ,  5.7051000d-03 /
      data f(18, 7,23) /              1.3100000d-04 /
      data f(18, 8, 1),f(18, 8, 2) /  3.2434000d-03 ,  4.7114000d-03 /
      data f(18, 8, 3),f(18, 8, 4) /  5.6564000d-03 ,  5.6564000d-03 /
      data f(18, 8, 5),f(18, 8, 6) /  4.7114000d-03 ,  3.2434000d-03 /
      data f(18, 8, 7),f(18, 8, 8) /  1.3585000d-03 , -8.3750000d-04 /
      data f(18, 8, 9),f(18, 8,10) / -3.1913000d-03 , -5.4687000d-03 /
      data f(18, 8,11),f(18, 8,12) / -7.3928000d-03 , -8.7164000d-03 /
      data f(18, 8,13),f(18, 8,14) / -9.2690000d-03 , -8.9708000d-03 /
      data f(18, 8,15),f(18, 8,16) / -7.8212000d-03 , -5.8952000d-03 /
      data f(18, 8,17),f(18, 8,18) / -3.3620000d-03 , -5.2130000d-04 /
      data f(18, 8,19),f(18, 8,20) /  2.1691000d-03 ,  4.1338000d-03 /
      data f(18, 8,21),f(18, 8,22) /  4.1338000d-03 ,  2.1691000d-03 /
      data f(18, 8,23) /             -5.2130000d-04 /
      data f(18, 9, 1),f(18, 9, 2) /  3.7239000d-03 ,  4.6447000d-03 /
      data f(18, 9, 3),f(18, 9, 4) /  5.5446000d-03 ,  5.5446000d-03 /
      data f(18, 9, 5),f(18, 9, 6) /  4.6447000d-03 ,  3.7239000d-03 /
      data f(18, 9, 7),f(18, 9, 8) /  2.8669000d-03 ,  1.9070000d-03 /
      data f(18, 9, 9),f(18, 9,10) /  7.1940000d-04 , -6.4500000d-04 /
      data f(18, 9,11),f(18, 9,12) / -1.9910000d-03 , -3.0891000d-03 /
      data f(18, 9,13),f(18, 9,14) / -3.7628000d-03 , -3.9194000d-03 /
      data f(18, 9,15),f(18, 9,16) / -3.5350000d-03 , -2.6489000d-03 /
      data f(18, 9,17),f(18, 9,18) / -1.3656000d-03 ,  1.2440000d-04 /
      data f(18, 9,19),f(18, 9,20) /  1.5431000d-03 ,  2.5676000d-03 /
      data f(18, 9,21),f(18, 9,22) /  2.5676000d-03 ,  1.5431000d-03 /
      data f(18, 9,23) /              1.2440000d-04 /
      data f(18,10, 1),f(18,10, 2) /  3.7027000d-03 ,  5.4818000d-03 /
      data f(18,10, 3),f(18,10, 4) /  8.2549000d-03 ,  8.2549000d-03 /
      data f(18,10, 5),f(18,10, 6) /  5.4818000d-03 ,  3.7027000d-03 /
      data f(18,10, 7),f(18,10, 8) /  3.0138000d-03 ,  2.7219000d-03 /
      data f(18,10, 9),f(18,10,10) /  2.2963000d-03 ,  1.5804000d-03 /
      data f(18,10,11),f(18,10,12) /  6.9000000d-04 , -1.6410000d-04 /
      data f(18,10,13),f(18,10,14) / -7.9910000d-04 , -1.1009000d-03 /
      data f(18,10,15),f(18,10,16) / -1.0187000d-03 , -5.5800000d-04 /
      data f(18,10,17),f(18,10,18) /  2.1340000d-04 ,  1.1580000d-03 /
      data f(18,10,19),f(18,10,20) /  2.0707000d-03 ,  2.7156000d-03 /
      data f(18,10,21),f(18,10,22) /  2.7156000d-03 ,  2.0707000d-03 /
      data f(18,10,23) /              1.1580000d-03 /
      data f(18,11, 1),f(18,11, 2) /  2.1026000d-03 ,  5.3591000d-03 /
      data f(18,11, 3),f(18,11, 4) /  1.2128200d-02 ,  1.2128200d-02 /
      data f(18,11, 5),f(18,11, 6) /  5.3591000d-03 ,  2.1026000d-03 /
      data f(18,11, 7),f(18,11, 8) /  1.4995000d-03 ,  1.9123000d-03 /
      data f(18,11, 9),f(18,11,10) /  2.2618000d-03 ,  2.1746000d-03 /
      data f(18,11,11),f(18,11,12) /  1.7302000d-03 ,  1.1566000d-03 /
      data f(18,11,13),f(18,11,14) /  6.6210000d-04 ,  3.8880000d-04 /
      data f(18,11,15),f(18,11,16) /  4.1440000d-04 ,  7.5370000d-04 /
      data f(18,11,17),f(18,11,18) /  1.3567000d-03 ,  2.1075000d-03 /
      data f(18,11,19),f(18,11,20) /  2.8282000d-03 ,  3.3172000d-03 /
      data f(18,11,21),f(18,11,22) /  3.3172000d-03 ,  2.8282000d-03 /
      data f(18,11,23) /              2.1075000d-03 /
      data f(18,12, 1),f(18,12, 2) /  4.3600000d-05 ,  5.1507000d-03 /
      data f(18,12, 3),f(18,12, 4) /  1.6426800d-02 ,  1.6426800d-02 /
      data f(18,12, 5),f(18,12, 6) /  5.1507000d-03 ,  4.3600000d-05 /
      data f(18,12, 7),f(18,12, 8) / -7.7430000d-04 ,  2.2170000d-04 /
      data f(18,12, 9),f(18,12,10) /  1.3160000d-03 ,  1.8450000d-03 /
      data f(18,12,11),f(18,12,12) /  1.8437000d-03 ,  1.5705000d-03 /
      data f(18,12,13),f(18,12,14) /  1.2669000d-03 ,  1.1021000d-03 /
      data f(18,12,15),f(18,12,16) /  1.1729000d-03 ,  1.5054000d-03 /
      data f(18,12,17),f(18,12,18) /  2.0570000d-03 ,  2.7215000d-03 /
      data f(18,12,19),f(18,12,20) /  3.3429000d-03 ,  3.7591000d-03 /
      data f(18,12,21),f(18,12,22) /  3.7591000d-03 ,  3.3429000d-03 /
      data f(18,12,23) /              2.7215000d-03 /
      data f(18,13, 1),f(18,13, 2) / -2.7230000d-04 ,  7.0104000d-03 /
      data f(18,13, 3),f(18,13, 4) /  2.1187700d-02 ,  2.1187700d-02 /
      data f(18,13, 5),f(18,13, 6) /  7.0104000d-03 , -2.7230000d-04 /
      data f(18,13, 7),f(18,13, 8) / -2.0469000d-03 , -1.1280000d-03 /
      data f(18,13, 9),f(18,13,10) /  2.8140000d-04 ,  1.1970000d-03 /
      data f(18,13,11),f(18,13,12) /  1.5281000d-03 ,  1.5118000d-03 /
      data f(18,13,13),f(18,13,14) /  1.3928000d-03 ,  1.3457000d-03 /
      data f(18,13,15),f(18,13,16) /  1.4725000d-03 ,  1.8039000d-03 /
      data f(18,13,17),f(18,13,18) /  2.3046000d-03 ,  2.8822000d-03 /
      data f(18,13,19),f(18,13,20) /  3.4082000d-03 ,  3.7621000d-03 /
      data f(18,13,21),f(18,13,22) /  3.7621000d-03 ,  3.4082000d-03 /
      data f(18,13,23) /              2.8822000d-03 /
      data f(18,14, 1),f(18,14, 2) /  1.3966000d-03 ,  9.2754000d-03 /
      data f(18,14, 3),f(18,14, 4) /  2.2872700d-02 ,  2.2872700d-02 /
      data f(18,14, 5),f(18,14, 6) /  9.2754000d-03 ,  1.3966000d-03 /
      data f(18,14, 7),f(18,14, 8) / -1.2794000d-03 , -1.0790000d-03 /
      data f(18,14, 9),f(18,14,10) / -4.3900000d-05 ,  7.8450000d-04 /
      data f(18,14,11),f(18,14,12) /  1.1837000d-03 ,  1.2878000d-03 /
      data f(18,14,13),f(18,14,14) /  1.2835000d-03 ,  1.3121000d-03 /
      data f(18,14,15),f(18,14,16) /  1.4575000d-03 ,  1.7464000d-03 /
      data f(18,14,17),f(18,14,18) /  2.1524000d-03 ,  2.6052000d-03 /
      data f(18,14,19),f(18,14,20) /  3.0088000d-03 ,  3.2754000d-03 /
      data f(18,14,21),f(18,14,22) /  3.2754000d-03 ,  3.0088000d-03 /
      data f(18,14,23) /              2.6052000d-03 /
      data f(18,15, 1),f(18,15, 2) /  4.2911000d-03 ,  1.0715100d-02 /
      data f(18,15, 3),f(18,15, 4) /  2.0248200d-02 ,  2.0248200d-02 /
      data f(18,15, 5),f(18,15, 6) /  1.0715100d-02 ,  4.2911000d-03 /
      data f(18,15, 7),f(18,15, 8) /  1.3565000d-03 ,  5.8310000d-04 /
      data f(18,15, 9),f(18,15,10) /  7.0000000d-04 ,  9.6150000d-04 /
      data f(18,15,11),f(18,15,12) /  1.1071000d-03 ,  1.1363000d-03 /
      data f(18,15,13),f(18,15,14) /  1.1278000d-03 ,  1.1546000d-03 /
      data f(18,15,15),f(18,15,16) /  1.2612000d-03 ,  1.4598000d-03 /
      data f(18,15,17),f(18,15,18) /  1.7302000d-03 ,  2.0260000d-03 /
      data f(18,15,19),f(18,15,20) /  2.2866000d-03 ,  2.4593000d-03 /
      data f(18,15,21),f(18,15,22) /  2.4593000d-03 ,  2.2866000d-03 /
      data f(18,15,23) /              2.0260000d-03 /
      data f(18,16, 1),f(18,16, 2) /  6.9719000d-03 ,  1.0878400d-02 /
      data f(18,16, 3),f(18,16, 4) /  1.5032100d-02 ,  1.5032100d-02 /
      data f(18,16, 5),f(18,16, 6) /  1.0878400d-02 ,  6.9719000d-03 /
      data f(18,16, 7),f(18,16, 8) /  4.3474000d-03 ,  2.8645000d-03 /
      data f(18,16, 9),f(18,16,10) /  2.0900000d-03 ,  1.6694000d-03 /
      data f(18,16,11),f(18,16,12) /  1.4041000d-03 ,  1.2165000d-03 /
      data f(18,16,13),f(18,16,14) /  1.0913000d-03 ,  1.0331000d-03 /
      data f(18,16,15),f(18,16,16) /  1.0450000d-03 ,  1.1203000d-03 /
      data f(18,16,17),f(18,16,18) /  1.2410000d-03 ,  1.3797000d-03 /
      data f(18,16,19),f(18,16,20) /  1.5050000d-03 ,  1.5905000d-03 /
      data f(18,16,21),f(18,16,22) /  1.5905000d-03 ,  1.5050000d-03 /
      data f(18,16,23) /              1.3797000d-03 /
      data f(18,17, 1),f(18,17, 2) /  6.5138000d-03 ,  7.9707000d-03 /
      data f(18,17, 3),f(18,17, 4) /  9.1246000d-03 ,  9.1246000d-03 /
      data f(18,17, 5),f(18,17, 6) /  7.9707000d-03 ,  6.5138000d-03 /
      data f(18,17, 7),f(18,17, 8) /  5.1129000d-03 ,  3.9488000d-03 /
      data f(18,17, 9),f(18,17,10) /  3.0537000d-03 ,  2.3882000d-03 /
      data f(18,17,11),f(18,17,12) /  1.8986000d-03 ,  1.5411000d-03 /
      data f(18,17,13),f(18,17,14) /  1.2862000d-03 ,  1.1144000d-03 /
      data f(18,17,15),f(18,17,16) /  1.0103000d-03 ,  9.5960000d-04 /
      data f(18,17,17),f(18,17,18) /  9.4740000d-04 ,  9.5860000d-04 /
      data f(18,17,19),f(18,17,20) /  9.7810000d-04 ,  9.9480000d-04 /
      data f(18,17,21),f(18,17,22) /  9.9480000d-04 ,  9.7810000d-04 /
      data f(18,17,23) /              9.5860000d-04 /
      data f(18,18, 1),f(18,18, 2) /  4.1298000d-03 ,  4.4549000d-03 /
      data f(18,18, 3),f(18,18, 4) /  4.6719000d-03 ,  4.6719000d-03 /
      data f(18,18, 5),f(18,18, 6) /  4.4549000d-03 ,  4.1298000d-03 /
      data f(18,18, 7),f(18,18, 8) /  3.7395000d-03 ,  3.3252000d-03 /
      data f(18,18, 9),f(18,18,10) /  2.9197000d-03 ,  2.5451000d-03 /
      data f(18,18,11),f(18,18,12) /  2.2135000d-03 ,  1.9295000d-03 /
      data f(18,18,13),f(18,18,14) /  1.6933000d-03 ,  1.5019000d-03 /
      data f(18,18,15),f(18,18,16) /  1.3512000d-03 ,  1.2360000d-03 /
      data f(18,18,17),f(18,18,18) /  1.1510000d-03 ,  1.0911000d-03 /
      data f(18,18,19),f(18,18,20) /  1.0519000d-03 ,  1.0305000d-03 /
      data f(18,18,21),f(18,18,22) /  1.0305000d-03 ,  1.0519000d-03 /
      data f(18,18,23) /              1.0911000d-03 /
      data f(18,19, 1),f(18,19, 2) /  2.1053000d-03 ,  2.1053000d-03 /
      data f(18,19, 3),f(18,19, 4) /  2.1053000d-03 ,  2.1053000d-03 /
      data f(18,19, 5),f(18,19, 6) /  2.1053000d-03 ,  2.1053000d-03 /
      data f(18,19, 7),f(18,19, 8) /  2.1053000d-03 ,  2.1053000d-03 /
      data f(18,19, 9),f(18,19,10) /  2.1053000d-03 ,  2.1053000d-03 /
      data f(18,19,11),f(18,19,12) /  2.1053000d-03 ,  2.1053000d-03 /
      data f(18,19,13),f(18,19,14) /  2.1053000d-03 ,  2.1053000d-03 /
      data f(18,19,15),f(18,19,16) /  2.1053000d-03 ,  2.1053000d-03 /
      data f(18,19,17),f(18,19,18) /  2.1053000d-03 ,  2.1053000d-03 /
      data f(18,19,19),f(18,19,20) /  2.1053000d-03 ,  2.1053000d-03 /
      data f(18,19,21),f(18,19,22) /  2.1053000d-03 ,  2.1053000d-03 /
      data f(18,19,23) /              2.1053000d-03 /
      data f(19, 1, 1),f(19, 1, 2) /  8.1026500d-02 ,  8.1026500d-02 /
      data f(19, 1, 3),f(19, 1, 4) /  8.1026500d-02 ,  8.1026500d-02 /
      data f(19, 1, 5),f(19, 1, 6) /  8.1026500d-02 ,  8.1026500d-02 /
      data f(19, 1, 7),f(19, 1, 8) /  8.1026500d-02 ,  8.1026500d-02 /
      data f(19, 1, 9),f(19, 1,10) /  8.1026500d-02 ,  8.1026500d-02 /
      data f(19, 1,11),f(19, 1,12) /  8.1026500d-02 ,  8.1026500d-02 /
      data f(19, 1,13),f(19, 1,14) /  8.1026500d-02 ,  8.1026500d-02 /
      data f(19, 1,15),f(19, 1,16) /  8.1026500d-02 ,  8.1026500d-02 /
      data f(19, 1,17),f(19, 1,18) /  8.1026500d-02 ,  8.1026500d-02 /
      data f(19, 1,19),f(19, 1,20) /  8.1026500d-02 ,  8.1026500d-02 /
      data f(19, 1,21),f(19, 1,22) /  8.1026500d-02 ,  8.1026500d-02 /
      data f(19, 1,23) /              8.1026500d-02 /
      data f(19, 2, 1),f(19, 2, 2) /  4.5720100d-02 ,  5.2339200d-02 /
      data f(19, 2, 3),f(19, 2, 4) /  5.3879800d-02 ,  5.3879800d-02 /
      data f(19, 2, 5),f(19, 2, 6) /  5.2339200d-02 ,  4.5720100d-02 /
      data f(19, 2, 7),f(19, 2, 8) /  3.8574400d-02 ,  3.1871700d-02 /
      data f(19, 2, 9),f(19, 2,10) /  2.6171200d-02 ,  2.1852300d-02 /
      data f(19, 2,11),f(19, 2,12) /  1.9170000d-02 ,  1.8274600d-02 /
      data f(19, 2,13),f(19, 2,14) /  1.9219600d-02 ,  2.1962000d-02 /
      data f(19, 2,15),f(19, 2,16) /  2.6361700d-02 ,  3.2174800d-02 /
      data f(19, 2,17),f(19, 2,18) /  3.9042300d-02 ,  4.6458100d-02 /
      data f(19, 2,19),f(19, 2,20) /  5.0712200d-02 ,  5.5028100d-02 /
      data f(19, 2,21),f(19, 2,22) /  5.5028100d-02 ,  5.0712200d-02 /
      data f(19, 2,23) /              4.6458100d-02 /
      data f(19, 3, 1),f(19, 3, 2) /  3.3727700d-02 ,  5.0973500d-02 /
      data f(19, 3, 3),f(19, 3, 4) /  6.4196200d-02 ,  6.4196200d-02 /
      data f(19, 3, 5),f(19, 3, 6) /  5.0973500d-02 ,  3.3727700d-02 /
      data f(19, 3, 7),f(19, 3, 8) /  1.7481700d-02 ,  3.6549000d-03 /
      data f(19, 3, 9),f(19, 3,10) / -7.3958000d-03 , -1.5471700d-02 /
      data f(19, 3,11),f(19, 3,12) / -2.0415300d-02 , -2.2132300d-02 /
      data f(19, 3,13),f(19, 3,14) / -2.0583000d-02 , -1.5769200d-02 /
      data f(19, 3,15),f(19, 3,16) / -7.7491000d-03 ,  3.3535000d-03 /
      data f(19, 3,17),f(19, 3,18) /  1.7370000d-02 ,  3.3983700d-02 /
      data f(19, 3,19),f(19, 3,20) /  5.1077700d-02 ,  6.5645600d-02 /
      data f(19, 3,21),f(19, 3,22) /  6.5645600d-02 ,  5.1077700d-02 /
      data f(19, 3,23) /              3.3983700d-02 /
      data f(19, 4, 1),f(19, 4, 2) /  2.4399300d-02 ,  4.7360900d-02 /
      data f(19, 4, 3),f(19, 4, 4) /  7.2255000d-02 ,  7.2255000d-02 /
      data f(19, 4, 5),f(19, 4, 6) /  4.7360900d-02 ,  2.4399300d-02 /
      data f(19, 4, 7),f(19, 4, 8) /  5.4036000d-03 , -9.8767000d-03 /
      data f(19, 4, 9),f(19, 4,10) / -2.1737400d-02 , -3.0232800d-02 /
      data f(19, 4,11),f(19, 4,12) / -3.5396300d-02 , -3.7287300d-02 /
      data f(19, 4,13),f(19, 4,14) / -3.5919100d-02 , -3.1219400d-02 /
      data f(19, 4,15),f(19, 4,16) / -2.3068700d-02 , -1.1373800d-02 /
      data f(19, 4,17),f(19, 4,18) /  3.9750000d-03 ,  2.3308700d-02 /
      data f(19, 4,19),f(19, 4,20) /  4.6848100d-02 ,  7.2413200d-02 /
      data f(19, 4,21),f(19, 4,22) /  7.2413200d-02 ,  4.6848100d-02 /
      data f(19, 4,23) /              2.3308700d-02 /
      data f(19, 5, 1),f(19, 5, 2) /  1.3099500d-02 ,  2.7683300d-02 /
      data f(19, 5, 3),f(19, 5, 4) /  4.0757700d-02 ,  4.0757700d-02 /
      data f(19, 5, 5),f(19, 5, 6) /  2.7683300d-02 ,  1.3099500d-02 /
      data f(19, 5, 7),f(19, 5, 8) / -4.4380000d-04 , -1.2022100d-02 /
      data f(19, 5, 9),f(19, 5,10) / -2.1235600d-02 , -2.7938500d-02 /
      data f(19, 5,11),f(19, 5,12) / -3.2127800d-02 , -3.3823600d-02 /
      data f(19, 5,13),f(19, 5,14) / -3.3005800d-02 , -2.9602900d-02 /
      data f(19, 5,15),f(19, 5,16) / -2.3506300d-02 , -1.4635500d-02 /
      data f(19, 5,17),f(19, 5,18) / -3.0581000d-03 ,  1.0887700d-02 /
      data f(19, 5,19),f(19, 5,20) /  2.6265600d-02 ,  4.0323500d-02 /
      data f(19, 5,21),f(19, 5,22) /  4.0323500d-02 ,  2.6265600d-02 /
      data f(19, 5,23) /              1.0887700d-02 /
      data f(19, 6, 1),f(19, 6, 2) /  5.8527000d-03 ,  1.3023100d-02 /
      data f(19, 6, 3),f(19, 6, 4) /  1.8463500d-02 ,  1.8463500d-02 /
      data f(19, 6, 5),f(19, 6, 6) /  1.3023100d-02 ,  5.8527000d-03 /
      data f(19, 6, 7),f(19, 6, 8) / -1.6445000d-03 , -8.5629000d-03 /
      data f(19, 6, 9),f(19, 6,10) / -1.4402300d-02 , -1.8911800d-02 /
      data f(19, 6,11),f(19, 6,12) / -2.1939700d-02 , -2.3364600d-02 /
      data f(19, 6,13),f(19, 6,14) / -2.3097000d-02 , -2.1090900d-02 /
      data f(19, 6,15),f(19, 6,16) / -1.7335900d-02 , -1.1863400d-02 /
      data f(19, 6,17),f(19, 6,18) / -4.8325000d-03 ,  3.2875000d-03 /
      data f(19, 6,19),f(19, 6,20) /  1.1483100d-02 ,  1.7983300d-02 /
      data f(19, 6,21),f(19, 6,22) /  1.7983300d-02 ,  1.1483100d-02 /
      data f(19, 6,23) /              3.2875000d-03 /
      data f(19, 7, 1),f(19, 7, 2) /  2.6134000d-03 ,  5.5207000d-03 /
      data f(19, 7, 3),f(19, 7, 4) /  7.5161000d-03 ,  7.5161000d-03 /
      data f(19, 7, 5),f(19, 7, 6) /  5.5207000d-03 ,  2.6134000d-03 /
      data f(19, 7, 7),f(19, 7, 8) / -7.5970000d-04 , -4.2094000d-03 /
      data f(19, 7, 9),f(19, 7,10) / -7.4279000d-03 , -1.0159900d-02 /
      data f(19, 7,11),f(19, 7,12) / -1.2187600d-02 , -1.3339300d-02 /
      data f(19, 7,13),f(19, 7,14) / -1.3499200d-02 , -1.2610800d-02 /
      data f(19, 7,15),f(19, 7,16) / -1.0679900d-02 , -7.7820000d-03 /
      data f(19, 7,17),f(19, 7,18) / -4.0944000d-03 ,  3.3600000d-05 /
      data f(19, 7,19),f(19, 7,20) /  3.9944000d-03 ,  6.9408000d-03 /
      data f(19, 7,21),f(19, 7,22) /  6.9408000d-03 ,  3.9944000d-03 /
      data f(19, 7,23) /              3.3600000d-05 /
      data f(19, 8, 1),f(19, 8, 2) /  1.8853000d-03 ,  2.8977000d-03 /
      data f(19, 8, 3),f(19, 8, 4) /  3.5478000d-03 ,  3.5478000d-03 /
      data f(19, 8, 5),f(19, 8, 6) /  2.8977000d-03 ,  1.8853000d-03 /
      data f(19, 8, 7),f(19, 8, 8) /  5.8470000d-04 , -9.3080000d-04 /
      data f(19, 8, 9),f(19, 8,10) / -2.5563000d-03 , -4.1327000d-03 /
      data f(19, 8,11),f(19, 8,12) / -5.4710000d-03 , -6.3982000d-03 /
      data f(19, 8,13),f(19, 8,14) / -6.7903000d-03 , -6.5858000d-03 /
      data f(19, 8,15),f(19, 8,16) / -5.7808000d-03 , -4.4267000d-03 /
      data f(19, 8,17),f(19, 8,18) / -2.6474000d-03 , -6.6090000d-04 /
      data f(19, 8,19),f(19, 8,20) /  1.2026000d-03 ,  2.5468000d-03 /
      data f(19, 8,21),f(19, 8,22) /  2.5468000d-03 ,  1.2026000d-03 /
      data f(19, 8,23) /             -6.6090000d-04 /
      data f(19, 9, 1),f(19, 9, 2) /  2.1556000d-03 ,  2.7997000d-03 /
      data f(19, 9, 3),f(19, 9, 4) /  3.4121000d-03 ,  3.4121000d-03 /
      data f(19, 9, 5),f(19, 9, 6) /  2.7997000d-03 ,  2.1556000d-03 /
      data f(19, 9, 7),f(19, 9, 8) /  1.5645000d-03 ,  9.2340000d-04 /
      data f(19, 9, 9),f(19, 9,10) /  1.3740000d-04 , -7.6930000d-04 /
      data f(19, 9,11),f(19, 9,12) / -1.6690000d-03 , -2.4083000d-03 /
      data f(19, 9,13),f(19, 9,14) / -2.8679000d-03 , -2.9817000d-03 /
      data f(19, 9,15),f(19, 9,16) / -2.7293000d-03 , -2.1321000d-03 /
      data f(19, 9,17),f(19, 9,18) / -1.2623000d-03 , -2.5410000d-04 /
      data f(19, 9,19),f(19, 9,20) /  6.9520000d-04 ,  1.3679000d-03 /
      data f(19, 9,21),f(19, 9,22) /  1.3679000d-03 ,  6.9520000d-04 /
      data f(19, 9,23) /             -2.5410000d-04 /
      data f(19,10, 1),f(19,10, 2) /  2.3207000d-03 ,  3.6224000d-03 /
      data f(19,10, 3),f(19,10, 4) /  5.3683000d-03 ,  5.3683000d-03 /
      data f(19,10, 5),f(19,10, 6) /  3.6224000d-03 ,  2.3207000d-03 /
      data f(19,10, 7),f(19,10, 8) /  1.7311000d-03 ,  1.4825000d-03 /
      data f(19,10, 9),f(19,10,10) /  1.2009000d-03 ,  7.4460000d-04 /
      data f(19,10,11),f(19,10,12) /  1.7100000d-04 , -3.8550000d-04 /
      data f(19,10,13),f(19,10,14) / -8.0640000d-04 , -1.0154000d-03 /
      data f(19,10,15),f(19,10,16) / -9.7350000d-04 , -6.7690000d-04 /
      data f(19,10,17),f(19,10,18) / -1.6740000d-04 ,  4.5720000d-04 /
      data f(19,10,19),f(19,10,20) /  1.0491000d-03 ,  1.4506000d-03 /
      data f(19,10,21),f(19,10,22) /  1.4506000d-03 ,  1.0491000d-03 /
      data f(19,10,23) /              4.5720000d-04 /
      data f(19,11, 1),f(19,11, 2) /  1.8304000d-03 ,  4.4584000d-03 /
      data f(19,11, 3),f(19,11, 4) /  8.5050000d-03 ,  8.5050000d-03 /
      data f(19,11, 5),f(19,11, 6) /  4.4584000d-03 ,  1.8304000d-03 /
      data f(19,11, 7),f(19,11, 8) /  9.8070000d-04 ,  1.0281000d-03 /
      data f(19,11, 9),f(19,11,10) /  1.1902000d-03 ,  1.1340000d-03 /
      data f(19,11,11),f(19,11,12) /  8.5920000d-04 ,  4.9670000d-04 /
      data f(19,11,13),f(19,11,14) /  1.7790000d-04 , -5.6000000d-06 /
      data f(19,11,15),f(19,11,16) /  1.7000000d-06 ,  2.1720000d-04 /
      data f(19,11,17),f(19,11,18) /  6.1140000d-04 ,  1.1025000d-03 /
      data f(19,11,19),f(19,11,20) /  1.5628000d-03 ,  1.8569000d-03 /
      data f(19,11,21),f(19,11,22) /  1.8569000d-03 ,  1.5628000d-03 /
      data f(19,11,23) /              1.1025000d-03 /
      data f(19,12, 1),f(19,12, 2) /  1.2050000d-03 ,  5.4952000d-03 /
      data f(19,12, 3),f(19,12, 4) /  1.2248100d-02 ,  1.2248100d-02 /
      data f(19,12, 5),f(19,12, 6) /  5.4952000d-03 ,  1.2050000d-03 /
      data f(19,12, 7),f(19,12, 8) / -1.4370000d-04 ,  6.8600000d-05 /
      data f(19,12, 9),f(19,12,10) /  6.0570000d-04 ,  9.0880000d-04 /
      data f(19,12,11),f(19,12,12) /  9.1520000d-04 ,  7.5160000d-04 /
      data f(19,12,13),f(19,12,14) /  5.6210000d-04 ,  4.5500000d-04 /
      data f(19,12,15),f(19,12,16) /  4.9720000d-04 ,  7.1190000d-04 /
      data f(19,12,17),f(19,12,18) /  1.0726000d-03 ,  1.5061000d-03 /
      data f(19,12,19),f(19,12,20) /  1.9052000d-03 ,  2.1610000d-03 /
      data f(19,12,21),f(19,12,22) /  2.1610000d-03 ,  1.9052000d-03 /
      data f(19,12,23) /              1.5061000d-03 /
      data f(19,13, 1),f(19,13, 2) /  1.5295000d-03 ,  7.2415000d-03 /
      data f(19,13, 3),f(19,13, 4) /  1.5545300d-02 ,  1.5545300d-02 /
      data f(19,13, 5),f(19,13, 6) /  7.2415000d-03 ,  1.5295000d-03 /
      data f(19,13, 7),f(19,13, 8) / -6.0970000d-04 , -6.2140000d-04 /
      data f(19,13, 9),f(19,13,10) /  5.0000000d-07 ,  4.9310000d-04 /
      data f(19,13,11),f(19,13,12) /  6.9480000d-04 ,  6.9430000d-04 /
      data f(19,13,13),f(19,13,14) /  6.2440000d-04 ,  5.9480000d-04 /
      data f(19,13,15),f(19,13,16) /  6.7560000d-04 ,  8.9130000d-04 /
      data f(19,13,17),f(19,13,18) /  1.2186000d-03 ,  1.5948000d-03 /
      data f(19,13,19),f(19,13,20) /  1.9346000d-03 ,  2.1585000d-03 /
      data f(19,13,21),f(19,13,22) /  2.1585000d-03 ,  1.9346000d-03 /
      data f(19,13,23) /              1.5948000d-03 /
      data f(19,14, 1),f(19,14, 2) /  2.9299000d-03 ,  8.7807000d-03 /
      data f(19,14, 3),f(19,14, 4) /  1.6345500d-02 ,  1.6345500d-02 /
      data f(19,14, 5),f(19,14, 6) /  8.7807000d-03 ,  2.9299000d-03 /
      data f(19,14, 7),f(19,14, 8) /  1.9440000d-04 , -3.9160000d-04 /
      data f(19,14, 9),f(19,14,10) / -1.1280000d-04 ,  2.5850000d-04 /
      data f(19,14,11),f(19,14,12) /  4.7150000d-04 ,  5.3640000d-04 /
      data f(19,14,13),f(19,14,14) /  5.3630000d-04 ,  5.5320000d-04 /
      data f(19,14,15),f(19,14,16) /  6.4450000d-04 ,  8.3090000d-04 /
      data f(19,14,17),f(19,14,18) /  1.0944000d-03 ,  1.3870000d-03 /
      data f(19,14,19),f(19,14,20) /  1.6448000d-03 ,  1.8114000d-03 /
      data f(19,14,21),f(19,14,22) /  1.8114000d-03 ,  1.6448000d-03 /
      data f(19,14,23) /              1.3870000d-03 /
      data f(19,15, 1),f(19,15, 2) /  4.5721000d-03 ,  9.0343000d-03 /
      data f(19,15, 3),f(19,15, 4) /  1.3996400d-02 ,  1.3996400d-02 /
      data f(19,15, 5),f(19,15, 6) /  9.0343000d-03 ,  4.5721000d-03 /
      data f(19,15, 7),f(19,15, 8) /  1.9029000d-03 ,  7.5930000d-04 /
      data f(19,15, 9),f(19,15,10) /  4.4180000d-04 ,  4.1800000d-04 /
      data f(19,15,11),f(19,15,12) /  4.3740000d-04 ,  4.3470000d-04 /
      data f(19,15,13),f(19,15,14) /  4.2300000d-04 ,  4.3480000d-04 /
      data f(19,15,15),f(19,15,16) /  4.9770000d-04 ,  6.2120000d-04 /
      data f(19,15,17),f(19,15,18) /  7.9260000d-04 ,  9.8040000d-04 /
      data f(19,15,19),f(19,15,20) /  1.1436000d-03 ,  1.2495000d-03 /
      data f(19,15,21),f(19,15,22) /  1.2495000d-03 ,  1.1436000d-03 /
      data f(19,15,23) /              9.8040000d-04 /
      data f(19,16, 1),f(19,16, 2) /  5.2379000d-03 ,  7.6899000d-03 /
      data f(19,16, 3),f(19,16, 4) /  9.9280000d-03 ,  9.9280000d-03 /
      data f(19,16, 5),f(19,16, 6) /  7.6899000d-03 ,  5.2379000d-03 /
      data f(19,16, 7),f(19,16, 8) /  3.3024000d-03 ,  2.0437000d-03 /
      data f(19,16, 9),f(19,16,10) /  1.3102000d-03 ,  8.9450000d-04 /
      data f(19,16,11),f(19,16,12) /  6.4750000d-04 ,  4.9100000d-04 /
      data f(19,16,13),f(19,16,14) /  3.9340000d-04 ,  3.4520000d-04 /
      data f(19,16,15),f(19,16,16) /  3.4380000d-04 ,  3.8450000d-04 /
      data f(19,16,17),f(19,16,18) /  4.5530000d-04 ,  5.3860000d-04 /
      data f(19,16,19),f(19,16,20) /  6.1420000d-04 ,  6.6540000d-04 /
      data f(19,16,21),f(19,16,22) /  6.6540000d-04 ,  6.1420000d-04 /
      data f(19,16,23) /              5.3860000d-04 /
      data f(19,17, 1),f(19,17, 2) /  4.2344000d-03 ,  5.1583000d-03 /
      data f(19,17, 3),f(19,17, 4) /  5.8572000d-03 ,  5.8572000d-03 /
      data f(19,17, 5),f(19,17, 6) /  5.1583000d-03 ,  4.2344000d-03 /
      data f(19,17, 7),f(19,17, 8) /  3.2966000d-03 ,  2.4784000d-03 /
      data f(19,17, 9),f(19,17,10) /  1.8265000d-03 ,  1.3334000d-03 /
      data f(19,17,11),f(19,17,12) /  9.7030000d-04 ,  7.0750000d-04 /
      data f(19,17,13),f(19,17,14) /  5.2190000d-04 ,  3.9610000d-04 /
      data f(19,17,15),f(19,17,16) /  3.1760000d-04 ,  2.7560000d-04 /
      data f(19,17,17),f(19,17,18) /  2.5990000d-04 ,  2.6070000d-04 /
      data f(19,17,19),f(19,17,20) /  2.6840000d-04 ,  2.7620000d-04 /
      data f(19,17,21),f(19,17,22) /  2.7620000d-04 ,  2.6840000d-04 /
      data f(19,17,23) /              2.6070000d-04 /
      data f(19,18, 1),f(19,18, 2) /  2.4807000d-03 ,  2.6984000d-03 /
      data f(19,18, 3),f(19,18, 4) /  2.8427000d-03 ,  2.8427000d-03 /
      data f(19,18, 5),f(19,18, 6) /  2.6984000d-03 ,  2.4807000d-03 /
      data f(19,18, 7),f(19,18, 8) /  2.2165000d-03 ,  1.9331000d-03 /
      data f(19,18, 9),f(19,18,10) /  1.6530000d-03 ,  1.3922000d-03 /
      data f(19,18,11),f(19,18,12) /  1.1600000d-03 ,  9.6040000d-04 /
      data f(19,18,13),f(19,18,14) /  7.9390000d-04 ,  6.5860000d-04 /
      data f(19,18,15),f(19,18,16) /  5.5150000d-04 ,  4.6920000d-04 /
      data f(19,18,17),f(19,18,18) /  4.0800000d-04 ,  3.6440000d-04 /
      data f(19,18,19),f(19,18,20) /  3.3590000d-04 ,  3.1980000d-04 /
      data f(19,18,21),f(19,18,22) /  3.1980000d-04 ,  3.3590000d-04 /
      data f(19,18,23) /              3.6440000d-04 /
      data f(19,19, 1),f(19,19, 2) /  1.0730000d-03 ,  1.0730000d-03 /
      data f(19,19, 3),f(19,19, 4) /  1.0730000d-03 ,  1.0730000d-03 /
      data f(19,19, 5),f(19,19, 6) /  1.0730000d-03 ,  1.0730000d-03 /
      data f(19,19, 7),f(19,19, 8) /  1.0730000d-03 ,  1.0730000d-03 /
      data f(19,19, 9),f(19,19,10) /  1.0730000d-03 ,  1.0730000d-03 /
      data f(19,19,11),f(19,19,12) /  1.0730000d-03 ,  1.0730000d-03 /
      data f(19,19,13),f(19,19,14) /  1.0730000d-03 ,  1.0730000d-03 /
      data f(19,19,15),f(19,19,16) /  1.0730000d-03 ,  1.0730000d-03 /
      data f(19,19,17),f(19,19,18) /  1.0730000d-03 ,  1.0730000d-03 /
      data f(19,19,19),f(19,19,20) /  1.0730000d-03 ,  1.0730000d-03 /
      data f(19,19,21),f(19,19,22) /  1.0730000d-03 ,  1.0730000d-03 /
      data f(19,19,23) /              1.0730000d-03 /
      data f(20, 1, 1),f(20, 1, 2) /  5.5693100d-02 ,  5.5693100d-02 /
      data f(20, 1, 3),f(20, 1, 4) /  5.5693100d-02 ,  5.5693100d-02 /
      data f(20, 1, 5),f(20, 1, 6) /  5.5693100d-02 ,  5.5693100d-02 /
      data f(20, 1, 7),f(20, 1, 8) /  5.5693100d-02 ,  5.5693100d-02 /
      data f(20, 1, 9),f(20, 1,10) /  5.5693100d-02 ,  5.5693100d-02 /
      data f(20, 1,11),f(20, 1,12) /  5.5693100d-02 ,  5.5693100d-02 /
      data f(20, 1,13),f(20, 1,14) /  5.5693100d-02 ,  5.5693100d-02 /
      data f(20, 1,15),f(20, 1,16) /  5.5693100d-02 ,  5.5693100d-02 /
      data f(20, 1,17),f(20, 1,18) /  5.5693100d-02 ,  5.5693100d-02 /
      data f(20, 1,19),f(20, 1,20) /  5.5693100d-02 ,  5.5693100d-02 /
      data f(20, 1,21),f(20, 1,22) /  5.5693100d-02 ,  5.5693100d-02 /
      data f(20, 1,23) /              5.5693100d-02 /
      data f(20, 2, 1),f(20, 2, 2) /  4.5691100d-02 ,  5.2629600d-02 /
      data f(20, 2, 3),f(20, 2, 4) /  5.8501900d-02 ,  5.8501900d-02 /
      data f(20, 2, 5),f(20, 2, 6) /  5.2629600d-02 ,  4.5691100d-02 /
      data f(20, 2, 7),f(20, 2, 8) /  3.8880400d-02 ,  3.2767300d-02 /
      data f(20, 2, 9),f(20, 2,10) /  2.7696700d-02 ,  2.3908500d-02 /
      data f(20, 2,11),f(20, 2,12) /  2.1567500d-02 ,  2.0771600d-02 /
      data f(20, 2,13),f(20, 2,14) /  2.1555700d-02 ,  2.3891300d-02 /
      data f(20, 2,15),f(20, 2,16) /  2.7685200d-02 ,  3.2775200d-02 /
      data f(20, 2,17),f(20, 2,18) /  3.8921900d-02 ,  4.5782700d-02 /
      data f(20, 2,19),f(20, 2,20) /  5.2803200d-02 ,  5.8821600d-02 /
      data f(20, 2,21),f(20, 2,22) /  5.8821600d-02 ,  5.2803200d-02 /
      data f(20, 2,23) /              4.5782700d-02 /
      data f(20, 3, 1),f(20, 3, 2) /  3.2528800d-02 ,  4.6867100d-02 /
      data f(20, 3, 3),f(20, 3, 4) /  6.0962100d-02 ,  6.0962100d-02 /
      data f(20, 3, 5),f(20, 3, 6) /  4.6867100d-02 ,  3.2528800d-02 /
      data f(20, 3, 7),f(20, 3, 8) /  1.9406300d-02 ,  8.1509000d-03 /
      data f(20, 3, 9),f(20, 3,10) / -8.8890000d-04 , -7.4945000d-03 /
      data f(20, 3,11),f(20, 3,12) / -1.1536900d-02 , -1.2956100d-02 /
      data f(20, 3,13),f(20, 3,14) / -1.1728500d-02 , -7.8491000d-03 /
      data f(20, 3,15),f(20, 3,16) / -1.3516000d-03 ,  7.6543000d-03 /
      data f(20, 3,17),f(20, 3,18) /  1.8957100d-02 ,  3.2197900d-02 /
      data f(20, 3,19),f(20, 3,20) /  4.6698500d-02 ,  6.1035000d-02 /
      data f(20, 3,21),f(20, 3,22) /  6.1035000d-02 ,  4.6698500d-02 /
      data f(20, 3,23) /              3.2197900d-02 /
      data f(20, 4, 1),f(20, 4, 2) /  2.1033700d-02 ,  3.6405500d-02 /
      data f(20, 4, 3),f(20, 4, 4) /  5.0718700d-02 ,  5.0718700d-02 /
      data f(20, 4, 5),f(20, 4, 6) /  3.6405500d-02 ,  2.1033700d-02 /
      data f(20, 4, 7),f(20, 4, 8) /  7.1086000d-03 , -4.6329000d-03 /
      data f(20, 4, 9),f(20, 4,10) / -1.3913600d-02 , -2.0602700d-02 /
      data f(20, 4,11),f(20, 4,12) / -2.4685600d-02 , -2.6197000d-02 /
      data f(20, 4,13),f(20, 4,14) / -2.5142200d-02 , -2.1464500d-02 /
      data f(20, 4,15),f(20, 4,16) / -1.5077900d-02 , -5.9505000d-03 /
      data f(20, 4,17),f(20, 4,18) /  5.8241000d-03 ,  1.9989100d-02 /
      data f(20, 4,19),f(20, 4,20) /  3.5796900d-02 ,  5.0714000d-02 /
      data f(20, 4,21),f(20, 4,22) /  5.0714000d-02 ,  3.5796900d-02 /
      data f(20, 4,23) /              1.9989100d-02 /
      data f(20, 5, 1),f(20, 5, 2) /  1.0713100d-02 ,  2.0663700d-02 /
      data f(20, 5, 3),f(20, 5, 4) /  2.8754200d-02 ,  2.8754200d-02 /
      data f(20, 5, 5),f(20, 5, 6) /  2.0663700d-02 ,  1.0713100d-02 /
      data f(20, 5, 7),f(20, 5, 8) /  9.1070000d-04 , -7.7200000d-03 /
      data f(20, 5, 9),f(20, 5,10) / -1.4691400d-02 , -1.9816400d-02 /
      data f(20, 5,11),f(20, 5,12) / -2.3050100d-02 , -2.4373300d-02 /
      data f(20, 5,13),f(20, 5,14) / -2.3752800d-02 , -2.1140700d-02 /
      data f(20, 5,15),f(20, 5,16) / -1.6478000d-02 , -9.7384000d-03 /
      data f(20, 5,17),f(20, 5,18) / -1.0491000d-03 ,  9.1394000d-03 /
      data f(20, 5,19),f(20, 5,20) /  1.9773100d-02 ,  2.8639100d-02 /
      data f(20, 5,21),f(20, 5,22) /  2.8639100d-02 ,  1.9773100d-02 /
      data f(20, 5,23) /              9.1394000d-03 /
      data f(20, 6, 1),f(20, 6, 2) /  4.3747000d-03 ,  9.3450000d-03 /
      data f(20, 6, 3),f(20, 6, 4) /  1.3002600d-02 ,  1.3002600d-02 /
      data f(20, 6, 5),f(20, 6, 6) /  9.3450000d-03 ,  4.3747000d-03 /
      data f(20, 6, 7),f(20, 6, 8) / -9.4750000d-04 , -5.9383000d-03 /
      data f(20, 6, 9),f(20, 6,10) / -1.0200700d-02 , -1.3524300d-02 /
      data f(20, 6,11),f(20, 6,12) / -1.5773200d-02 , -1.6839800d-02 /
      data f(20, 6,13),f(20, 6,14) / -1.6647600d-02 , -1.5158700d-02 /
      data f(20, 6,15),f(20, 6,16) / -1.2373700d-02 , -8.3368000d-03 /
      data f(20, 6,17),f(20, 6,18) / -3.1984000d-03 ,  2.6450000d-03 /
      data f(20, 6,19),f(20, 6,20) /  8.3979000d-03 ,  1.2812400d-02 /
      data f(20, 6,21),f(20, 6,22) /  1.2812400d-02 ,  8.3979000d-03 /
      data f(20, 6,23) /              2.6450000d-03 /
      data f(20, 7, 1),f(20, 7, 2) /  1.6350000d-03 ,  3.6407000d-03 /
      data f(20, 7, 3),f(20, 7, 4) /  5.0021000d-03 ,  5.0021000d-03 /
      data f(20, 7, 5),f(20, 7, 6) /  3.6407000d-03 ,  1.6350000d-03 /
      data f(20, 7, 7),f(20, 7, 8) / -7.1250000d-04 , -3.1278000d-03 /
      data f(20, 7, 9),f(20, 7,10) / -5.3898000d-03 , -7.3164000d-03 /
      data f(20, 7,11),f(20, 7,12) / -8.7537000d-03 , -9.5769000d-03 /
      data f(20, 7,13),f(20, 7,14) / -9.6969000d-03 , -9.0676000d-03 /
      data f(20, 7,15),f(20, 7,16) / -7.6908000d-03 , -5.6241000d-03 /
      data f(20, 7,17),f(20, 7,18) / -3.0049000d-03 , -9.8100000d-05 /
      data f(20, 7,19),f(20, 7,20) /  2.6570000d-03 ,  4.6759000d-03 /
      data f(20, 7,21),f(20, 7,22) /  4.6759000d-03 ,  2.6570000d-03 /
      data f(20, 7,23) /             -9.8100000d-05 /
      data f(20, 8, 1),f(20, 8, 2) /  9.9120000d-04 ,  1.6766000d-03 /
      data f(20, 8, 3),f(20, 8, 4) /  2.1149000d-03 ,  2.1149000d-03 /
      data f(20, 8, 5),f(20, 8, 6) /  1.6766000d-03 ,  9.9120000d-04 /
      data f(20, 8, 7),f(20, 8, 8) /  1.0970000d-04 , -9.1780000d-04 /
      data f(20, 8, 9),f(20, 8,10) / -2.0188000d-03 , -3.0883000d-03 /
      data f(20, 8,11),f(20, 8,12) / -4.0006000d-03 , -4.6378000d-03 /
      data f(20, 8,13),f(20, 8,14) / -4.9112000d-03 , -4.7741000d-03 /
      data f(20, 8,15),f(20, 8,16) / -4.2221000d-03 , -3.2910000d-03 /
      data f(20, 8,17),f(20, 8,18) / -2.0672000d-03 , -7.0670000d-04 /
      data f(20, 8,19),f(20, 8,20) /  5.5990000d-04 ,  1.4641000d-03 /
      data f(20, 8,21),f(20, 8,22) /  1.4641000d-03 ,  5.5990000d-04 /
      data f(20, 8,23) /             -7.0670000d-04 /
      data f(20, 9, 1),f(20, 9, 2) /  1.1445000d-03 ,  1.5729000d-03 /
      data f(20, 9, 3),f(20, 9, 4) /  1.9748000d-03 ,  1.9748000d-03 /
      data f(20, 9, 5),f(20, 9, 6) /  1.5729000d-03 ,  1.1445000d-03 /
      data f(20, 9, 7),f(20, 9, 8) /  7.5420000d-04 ,  3.3590000d-04 /
      data f(20, 9, 9),f(20, 9,10) / -1.7650000d-04 , -7.6930000d-04 /
      data f(20, 9,11),f(20, 9,12) / -1.3600000d-03 , -1.8500000d-03 /
      data f(20, 9,13),f(20, 9,14) / -2.1604000d-03 , -2.2437000d-03 /
      data f(20, 9,15),f(20, 9,16) / -2.0822000d-03 , -1.6882000d-03 /
      data f(20, 9,17),f(20, 9,18) / -1.1100000d-03 , -4.4200000d-04 /
      data f(20, 9,19),f(20, 9,20) /  1.8030000d-04 ,  6.1320000d-04 /
      data f(20, 9,21),f(20, 9,22) /  6.1320000d-04 ,  1.8030000d-04 /
      data f(20, 9,23) /             -4.4200000d-04 /
      data f(20,10, 1),f(20,10, 2) /  1.3136000d-03 ,  2.1931000d-03 /
      data f(20,10, 3),f(20,10, 4) /  3.2894000d-03 ,  3.2894000d-03 /
      data f(20,10, 5),f(20,10, 6) /  2.1931000d-03 ,  1.3136000d-03 /
      data f(20,10, 7),f(20,10, 8) /  8.8880000d-04 ,  7.1560000d-04 /
      data f(20,10, 9),f(20,10,10) /  5.4030000d-04 ,  2.5520000d-04 /
      data f(20,10,11),f(20,10,12) / -1.0800000d-04 , -4.6500000d-04 /
      data f(20,10,13),f(20,10,14) / -7.4090000d-04 , -8.8560000d-04 /
      data f(20,10,15),f(20,10,16) / -8.6930000d-04 , -6.8500000d-04 /
      data f(20,10,17),f(20,10,18) / -3.5800000d-04 ,  4.4500000d-05 /
      data f(20,10,19),f(20,10,20) /  4.1830000d-04 ,  6.6040000d-04 /
      data f(20,10,21),f(20,10,22) /  6.6040000d-04 ,  4.1830000d-04 /
      data f(20,10,23) /              4.4500000d-05 /
      data f(20,11, 1),f(20,11, 2) /  1.1882000d-03 ,  2.9851000d-03 /
      data f(20,11, 3),f(20,11, 4) /  5.4158000d-03 ,  5.4158000d-03 /
      data f(20,11, 5),f(20,11, 6) /  2.9851000d-03 ,  1.1882000d-03 /
      data f(20,11, 7),f(20,11, 8) /  4.9080000d-04 ,  4.4580000d-04 /
      data f(20,11, 9),f(20,11,10) /  5.3630000d-04 ,  5.0850000d-04 /
      data f(20,11,11),f(20,11,12) /  3.4240000d-04 ,  1.1780000d-04 /
      data f(20,11,13),f(20,11,14) / -8.3800000d-05 , -2.0580000d-04 /
      data f(20,11,15),f(20,11,16) / -2.1070000d-04 , -8.1600000d-05 /
      data f(20,11,17),f(20,11,18) /  1.6640000d-04 ,  4.7800000d-04 /
      data f(20,11,19),f(20,11,20) /  7.6250000d-04 ,  9.3110000d-04 /
      data f(20,11,21),f(20,11,22) /  9.3110000d-04 ,  7.6250000d-04 /
      data f(20,11,23) /              4.7800000d-04 /
      data f(20,12, 1),f(20,12, 2) /  1.0366000d-03 ,  3.9508000d-03 /
      data f(20,12, 3),f(20,12, 4) /  7.8992000d-03 ,  7.8992000d-03 /
      data f(20,12, 5),f(20,12, 6) /  3.9508000d-03 ,  1.0366000d-03 /
      data f(20,12, 7),f(20,12, 8) / -9.6300000d-05 , -1.2310000d-04 /
      data f(20,12, 9),f(20,12,10) /  1.6310000d-04 ,  3.5180000d-04 /
      data f(20,12,11),f(20,12,12) /  3.6510000d-04 ,  2.7100000d-04 /
      data f(20,12,13),f(20,12,14) /  1.5730000d-04 ,  8.9500000d-05 /
      data f(20,12,15),f(20,12,16) /  1.1080000d-04 ,  2.4070000d-04 /
      data f(20,12,17),f(20,12,18) /  4.6660000d-04 ,  7.4070000d-04 /
      data f(20,12,19),f(20,12,20) /  9.8830000d-04 ,  1.1381000d-03 /
      data f(20,12,21),f(20,12,22) /  1.1381000d-03 ,  9.8830000d-04 /
      data f(20,12,23) /              7.4070000d-04 /
      data f(20,13, 1),f(20,13, 2) /  1.4196000d-03 ,  5.1791000d-03 /
      data f(20,13, 3),f(20,13, 4) /  9.9430000d-03 ,  9.9430000d-03 /
      data f(20,13, 5),f(20,13, 6) /  5.1791000d-03 ,  1.4196000d-03 /
      data f(20,13, 7),f(20,13, 8) / -2.5700000d-04 , -4.9440000d-04 /
      data f(20,13, 9),f(20,13,10) / -2.0620000d-04 ,  7.9300000d-05 /
      data f(20,13,11),f(20,13,12) /  2.1150000d-04 ,  2.2100000d-04 /
      data f(20,13,13),f(20,13,14) /  1.8370000d-04 ,  1.6690000d-04 /
      data f(20,13,15),f(20,13,16) /  2.1530000d-04 ,  3.4790000d-04 /
      data f(20,13,17),f(20,13,18) /  5.5280000d-04 ,  7.8980000d-04 /
      data f(20,13,19),f(20,13,20) /  1.0021000d-03 ,  1.1382000d-03 /
      data f(20,13,21),f(20,13,22) /  1.1382000d-03 ,  1.0021000d-03 /
      data f(20,13,23) /              7.8980000d-04 /
      data f(20,14, 1),f(20,14, 2) /  2.3757000d-03 ,  6.1076000d-03 /
      data f(20,14, 3),f(20,14, 4) /  1.0368300d-02 ,  1.0368300d-02 /
      data f(20,14, 5),f(20,14, 6) /  6.1076000d-03 ,  2.3757000d-03 /
      data f(20,14, 7),f(20,14, 8) /  3.5650000d-04 , -2.7210000d-04 /
      data f(20,14, 9),f(20,14,10) / -2.4190000d-04 , -6.1500000d-05 /
      data f(20,14,11),f(20,14,12) /  6.5300000d-05 ,  1.1140000d-04 /
      data f(20,14,13),f(20,14,14) /  1.1510000d-04 ,  1.2570000d-04 /
      data f(20,14,15),f(20,14,16) /  1.8060000d-04 ,  2.9500000d-04 /
      data f(20,14,17),f(20,14,18) /  4.5900000d-04 ,  6.4150000d-04 /
      data f(20,14,19),f(20,14,20) /  8.0060000d-04 ,  9.0130000d-04 /
      data f(20,14,21),f(20,14,22) /  9.0130000d-04 ,  8.0060000d-04 /
      data f(20,14,23) /              6.4150000d-04 /
      data f(20,15, 1),f(20,15, 2) /  3.2840000d-03 ,  6.0562000d-03 /
      data f(20,15, 3),f(20,15, 4) /  8.8305000d-03 ,  8.8305000d-03 /
      data f(20,15, 5),f(20,15, 6) /  6.0562000d-03 ,  3.2840000d-03 /
      data f(20,15, 7),f(20,15, 8) /  1.4160000d-03 ,  4.8500000d-04 /
      data f(20,15, 9),f(20,15,10) /  1.4240000d-04 ,  5.8600000d-05 /
      data f(20,15,11),f(20,15,12) /  4.8500000d-05 ,  4.2900000d-05 /
      data f(20,15,13),f(20,15,14) /  3.3900000d-05 ,  3.7700000d-05 /
      data f(20,15,15),f(20,15,16) /  7.2200000d-05 ,  1.4490000d-04 /
      data f(20,15,17),f(20,15,18) /  2.4870000d-04 ,  3.6280000d-04 /
      data f(20,15,19),f(20,15,20) /  4.6080000d-04 ,  5.2290000d-04 /
      data f(20,15,21),f(20,15,22) /  5.2290000d-04 ,  4.6080000d-04 /
      data f(20,15,23) /              3.6280000d-04 /
      data f(20,16, 1),f(20,16, 2) /  3.4058000d-03 ,  4.9137000d-03 /
      data f(20,16, 3),f(20,16, 4) /  6.2057000d-03 ,  6.2057000d-03 /
      data f(20,16, 5),f(20,16, 6) /  4.9137000d-03 ,  3.4058000d-03 /
      data f(20,16, 7),f(20,16, 8) /  2.1261000d-03 ,  1.2351000d-03 /
      data f(20,16, 9),f(20,16,10) /  6.8790000d-04 ,  3.7200000d-04 /
      data f(20,16,11),f(20,16,12) /  1.8930000d-04 ,  7.8500000d-05 /
      data f(20,16,13),f(20,16,14) /  9.9000000d-06 , -2.7400000d-05 /
      data f(20,16,15),f(20,16,16) / -3.5600000d-05 , -1.7500000d-05 /
      data f(20,16,17),f(20,16,18) /  2.0500000d-05 ,  6.7100000d-05 /
      data f(20,16,19),f(20,16,20) /  1.0970000d-04 ,  1.3850000d-04 /
      data f(20,16,21),f(20,16,22) /  1.3850000d-04 ,  1.0970000d-04 /
      data f(20,16,23) /              6.7100000d-05 /
      data f(20,17, 1),f(20,17, 2) /  2.5725000d-03 ,  3.1544000d-03 /
      data f(20,17, 3),f(20,17, 4) /  3.5842000d-03 ,  3.5842000d-03 /
      data f(20,17, 5),f(20,17, 6) /  3.1544000d-03 ,  2.5725000d-03 /
      data f(20,17, 7),f(20,17, 8) /  1.9652000d-03 ,  1.4213000d-03 /
      data f(20,17, 9),f(20,17,10) /  9.7990000d-04 ,  6.4320000d-04 /
      data f(20,17,11),f(20,17,12) /  3.9540000d-04 ,  2.1680000d-04 /
      data f(20,17,13),f(20,17,14) /  9.0000000d-05 ,  2.6000000d-06 /
      data f(20,17,15),f(20,17,16) / -5.4600000d-05 , -8.8400000d-05 /
      data f(20,17,17),f(20,17,18) / -1.0480000d-04 , -1.1020000d-04 /
      data f(20,17,19),f(20,17,20) / -1.0980000d-04 , -1.0770000d-04 /
      data f(20,17,21),f(20,17,22) / -1.0770000d-04 , -1.0980000d-04 /
      data f(20,17,23) /             -1.1020000d-04 /
      data f(20,18, 1),f(20,18, 2) /  1.3809000d-03 ,  1.5226000d-03 /
      data f(20,18, 3),f(20,18, 4) /  1.6165000d-03 ,  1.6165000d-03 /
      data f(20,18, 5),f(20,18, 6) /  1.5226000d-03 ,  1.3809000d-03 /
      data f(20,18, 7),f(20,18, 8) /  1.2081000d-03 ,  1.0217000d-03 /
      data f(20,18, 9),f(20,18,10) /  8.3670000d-04 ,  6.6370000d-04 /
      data f(20,18,11),f(20,18,12) /  5.0920000d-04 ,  3.7600000d-04 /
      data f(20,18,13),f(20,18,14) /  2.6430000d-04 ,  1.7310000d-04 /
      data f(20,18,15),f(20,18,16) /  1.0030000d-04 ,  4.3700000d-05 /
      data f(20,18,17),f(20,18,18) /  1.1000000d-06 , -2.9700000d-05 /
      data f(20,18,19),f(20,18,20) / -5.0100000d-05 , -6.1700000d-05 /
      data f(20,18,21),f(20,18,22) / -6.1700000d-05 , -5.0100000d-05 /
      data f(20,18,23) /             -2.9700000d-05 /
      data f(20,19, 1),f(20,19, 2) /  4.4600000d-04 ,  4.4600000d-04 /
      data f(20,19, 3),f(20,19, 4) /  4.4600000d-04 ,  4.4600000d-04 /
      data f(20,19, 5),f(20,19, 6) /  4.4600000d-04 ,  4.4600000d-04 /
      data f(20,19, 7),f(20,19, 8) /  4.4600000d-04 ,  4.4600000d-04 /
      data f(20,19, 9),f(20,19,10) /  4.4600000d-04 ,  4.4600000d-04 /
      data f(20,19,11),f(20,19,12) /  4.4600000d-04 ,  4.4600000d-04 /
      data f(20,19,13),f(20,19,14) /  4.4600000d-04 ,  4.4600000d-04 /
      data f(20,19,15),f(20,19,16) /  4.4600000d-04 ,  4.4600000d-04 /
      data f(20,19,17),f(20,19,18) /  4.4600000d-04 ,  4.4600000d-04 /
      data f(20,19,19),f(20,19,20) /  4.4600000d-04 ,  4.4600000d-04 /
      data f(20,19,21),f(20,19,22) /  4.4600000d-04 ,  4.4600000d-04 /
      data f(20,19,23) /              4.4600000d-04 /
      data f(21, 1, 1),f(21, 1, 2) /  4.2938800d-02 ,  4.2938800d-02 /
      data f(21, 1, 3),f(21, 1, 4) /  4.2938800d-02 ,  4.2938800d-02 /
      data f(21, 1, 5),f(21, 1, 6) /  4.2938800d-02 ,  4.2938800d-02 /
      data f(21, 1, 7),f(21, 1, 8) /  4.2938800d-02 ,  4.2938800d-02 /
      data f(21, 1, 9),f(21, 1,10) /  4.2938800d-02 ,  4.2938800d-02 /
      data f(21, 1,11),f(21, 1,12) /  4.2938800d-02 ,  4.2938800d-02 /
      data f(21, 1,13),f(21, 1,14) /  4.2938800d-02 ,  4.2938800d-02 /
      data f(21, 1,15),f(21, 1,16) /  4.2938800d-02 ,  4.2938800d-02 /
      data f(21, 1,17),f(21, 1,18) /  4.2938800d-02 ,  4.2938800d-02 /
      data f(21, 1,19),f(21, 1,20) /  4.2938800d-02 ,  4.2938800d-02 /
      data f(21, 1,21),f(21, 1,22) /  4.2938800d-02 ,  4.2938800d-02 /
      data f(21, 1,23) /              4.2938800d-02 /
      data f(21, 2, 1),f(21, 2, 2) /  3.7992400d-02 ,  4.2449700d-02 /
      data f(21, 2, 3),f(21, 2, 4) /  4.5708600d-02 ,  4.5708600d-02 /
      data f(21, 2, 5),f(21, 2, 6) /  4.2449700d-02 ,  3.7992400d-02 /
      data f(21, 2, 7),f(21, 2, 8) /  3.3153800d-02 ,  2.8545000d-02 /
      data f(21, 2, 9),f(21, 2,10) /  2.4590600d-02 ,  2.1578800d-02 /
      data f(21, 2,11),f(21, 2,12) /  1.9696600d-02 ,  1.9050800d-02 /
      data f(21, 2,13),f(21, 2,14) /  1.9678300d-02 ,  2.1549400d-02 /
      data f(21, 2,15),f(21, 2,16) /  2.4564000d-02 ,  2.8540100d-02 /
      data f(21, 2,17),f(21, 2,18) /  3.3193300d-02 ,  3.8101400d-02 /
      data f(21, 2,19),f(21, 2,20) /  4.2649800d-02 ,  4.5999700d-02 /
      data f(21, 2,21),f(21, 2,22) /  4.5999700d-02 ,  4.2649800d-02 /
      data f(21, 2,23) /              3.8101400d-02 /
      data f(21, 3, 1),f(21, 3, 2) /  2.8332900d-02 ,  3.8975600d-02 /
      data f(21, 3, 3),f(21, 3, 4) /  4.7938500d-02 ,  4.7938500d-02 /
      data f(21, 3, 5),f(21, 3, 6) /  3.8975600d-02 ,  2.8332900d-02 /
      data f(21, 3, 7),f(21, 3, 8) /  1.7942400d-02 ,  8.7491000d-03 /
      data f(21, 3, 9),f(21, 3,10) /  1.2536000d-03 , -4.2626000d-03 /
      data f(21, 3,11),f(21, 3,12) / -7.6522000d-03 , -8.8511000d-03 /
      data f(21, 3,13),f(21, 3,14) / -7.8350000d-03 , -4.6019000d-03 /
      data f(21, 3,15),f(21, 3,16) /  8.0800000d-04 ,  8.2673000d-03 /
      data f(21, 3,17),f(21, 3,18) /  1.7506200d-02 ,  2.8028800d-02 /
      data f(21, 3,19),f(21, 3,20) /  3.8896900d-02 ,  4.8184700d-02 /
      data f(21, 3,21),f(21, 3,22) /  4.8184700d-02 ,  3.8896900d-02 /
      data f(21, 3,23) /              2.8028800d-02 /
      data f(21, 4, 1),f(21, 4, 2) /  1.7961500d-02 ,  2.9379700d-02 /
      data f(21, 4, 3),f(21, 4, 4) /  3.8994100d-02 ,  3.8994100d-02 /
      data f(21, 4, 5),f(21, 4, 6) /  2.9379700d-02 ,  1.7961500d-02 /
      data f(21, 4, 7),f(21, 4, 8) /  6.9848000d-03 , -2.5575000d-03 /
      data f(21, 4, 9),f(21, 4,10) / -1.0207200d-02 , -1.5761300d-02 /
      data f(21, 4,11),f(21, 4,12) / -1.9169200d-02 , -2.0440100d-02 /
      data f(21, 4,13),f(21, 4,14) / -1.9569700d-02 , -1.6514500d-02 /
      data f(21, 4,15),f(21, 4,16) / -1.1218300d-02 , -3.6891000d-03 /
      data f(21, 4,17),f(21, 4,18) /  5.9036000d-03 ,  1.7122700d-02 /
      data f(21, 4,19),f(21, 4,20) /  2.8969300d-02 ,  3.9118700d-02 /
      data f(21, 4,21),f(21, 4,22) /  3.9118700d-02 ,  2.8969300d-02 /
      data f(21, 4,23) /              1.7122700d-02 /
      data f(21, 5, 1),f(21, 5, 2) /  8.9503000d-03 ,  1.6564300d-02 /
      data f(21, 5, 3),f(21, 5, 4) /  2.2496300d-02 ,  2.2496300d-02 /
      data f(21, 5, 5),f(21, 5, 6) /  1.6564300d-02 ,  8.9503000d-03 /
      data f(21, 5, 7),f(21, 5, 8) /  1.2118000d-03 , -5.7257000d-03 /
      data f(21, 5, 9),f(21, 5,10) / -1.1390400d-02 , -1.5589400d-02 /
      data f(21, 5,11),f(21, 5,12) / -1.8257800d-02 , -1.9356600d-02 /
      data f(21, 5,13),f(21, 5,14) / -1.8847300d-02 , -1.6695300d-02 /
      data f(21, 5,15),f(21, 5,16) / -1.2869300d-02 , -7.3714000d-03 /
      data f(21, 5,17),f(21, 5,18) / -3.4590000d-04 ,  7.7557000d-03 /
      data f(21, 5,19),f(21, 5,20) /  1.5960200d-02 ,  2.2514500d-02 /
      data f(21, 5,21),f(21, 5,22) /  2.2514500d-02 ,  1.5960200d-02 /
      data f(21, 5,23) /              7.7557000d-03 /
      data f(21, 6, 1),f(21, 6, 2) /  3.4625000d-03 ,  7.3107000d-03 /
      data f(21, 6, 3),f(21, 6, 4) /  1.0101200d-02 ,  1.0101200d-02 /
      data f(21, 6, 5),f(21, 6, 6) /  7.3107000d-03 ,  3.4625000d-03 /
      data f(21, 6, 7),f(21, 6, 8) / -7.0950000d-04 , -4.6583000d-03 /
      data f(21, 6, 9),f(21, 6,10) / -8.0562000d-03 , -1.0721200d-02 /
      data f(21, 6,11),f(21, 6,12) / -1.2532000d-02 , -1.3394500d-02 /
      data f(21, 6,13),f(21, 6,14) / -1.3242700d-02 , -1.2043800d-02 /
      data f(21, 6,15),f(21, 6,16) / -9.8007000d-03 , -6.5603000d-03 /
      data f(21, 6,17),f(21, 6,18) / -2.4612000d-03 ,  2.1574000d-03 /
      data f(21, 6,19),f(21, 6,20) /  6.6427000d-03 ,  1.0026600d-02 /
      data f(21, 6,21),f(21, 6,22) /  1.0026600d-02 ,  6.6427000d-03 /
      data f(21, 6,23) /              2.1574000d-03 /
      data f(21, 7, 1),f(21, 7, 2) /  1.1297000d-03 ,  2.6799000d-03 /
      data f(21, 7, 3),f(21, 7, 4) /  3.7257000d-03 ,  3.7257000d-03 /
      data f(21, 7, 5),f(21, 7, 6) /  2.6799000d-03 ,  1.1297000d-03 /
      data f(21, 7, 7),f(21, 7, 8) / -6.9250000d-04 , -2.5723000d-03 /
      data f(21, 7, 9),f(21, 7,10) / -4.3358000d-03 , -5.8414000d-03 /
      data f(21, 7,11),f(21, 7,12) / -6.9690000d-03 , -7.6185000d-03 /
      data f(21, 7,13),f(21, 7,14) / -7.7158000d-03 , -7.2224000d-03 /
      data f(21, 7,15),f(21, 7,16) / -6.1394000d-03 , -4.5135000d-03 /
      data f(21, 7,17),f(21, 7,18) / -2.4570000d-03 , -1.8490000d-04 /
      data f(21, 7,19),f(21, 7,20) /  1.9537000d-03 ,  3.5077000d-03 /
      data f(21, 7,21),f(21, 7,22) /  3.5077000d-03 ,  1.9537000d-03 /
      data f(21, 7,23) /             -1.8490000d-04 /
      data f(21, 8, 1),f(21, 8, 2) /  5.8230000d-04 ,  1.1050000d-03 /
      data f(21, 8, 3),f(21, 8, 4) /  1.4382000d-03 ,  1.4382000d-03 /
      data f(21, 8, 5),f(21, 8, 6) /  1.1050000d-03 ,  5.8230000d-04 /
      data f(21, 8, 7),f(21, 8, 8) / -9.0800000d-05 , -8.7470000d-04 /
      data f(21, 8, 9),f(21, 8,10) / -1.7142000d-03 , -2.5307000d-03 /
      data f(21, 8,11),f(21, 8,12) / -3.2303000d-03 , -3.7222000d-03 /
      data f(21, 8,13),f(21, 8,14) / -3.9357000d-03 , -3.8325000d-03 /
      data f(21, 8,15),f(21, 8,16) / -3.4082000d-03 , -2.6910000d-03 /
      data f(21, 8,17),f(21, 8,18) / -1.7488000d-03 , -7.0320000d-04 /
      data f(21, 8,19),f(21, 8,20) /  2.6560000d-04 ,  9.5290000d-04 /
      data f(21, 8,21),f(21, 8,22) /  9.5290000d-04 ,  2.6560000d-04 /
      data f(21, 8,23) /             -7.0320000d-04 /
      data f(21, 9, 1),f(21, 9, 2) /  6.9150000d-04 ,  1.0096000d-03 /
      data f(21, 9, 3),f(21, 9, 4) /  1.3061000d-03 ,  1.3061000d-03 /
      data f(21, 9, 5),f(21, 9, 6) /  1.0096000d-03 ,  6.9150000d-04 /
      data f(21, 9, 7),f(21, 9, 8) /  4.0200000d-04 ,  9.1700000d-05 /
      data f(21, 9, 9),f(21, 9,10) / -2.8910000d-04 , -7.3030000d-04 /
      data f(21, 9,11),f(21, 9,12) / -1.1717000d-03 , -1.5413000d-03 /
      data f(21, 9,13),f(21, 9,14) / -1.7796000d-03 , -1.8481000d-03 /
      data f(21, 9,15),f(21, 9,16) / -1.7303000d-03 , -1.4347000d-03 /
      data f(21, 9,17),f(21, 9,18) / -9.9920000d-04 , -4.9720000d-04 /
      data f(21, 9,19),f(21, 9,20) / -3.3700000d-05 ,  2.8410000d-04 /
      data f(21, 9,21),f(21, 9,22) /  2.8410000d-04 , -3.3700000d-05 /
      data f(21, 9,23) /             -4.9720000d-04 /
      data f(21,10, 1),f(21,10, 2) /  8.3130000d-04 ,  1.4879000d-03 /
      data f(21,10, 3),f(21,10, 4) /  2.2853000d-03 ,  2.2853000d-03 /
      data f(21,10, 5),f(21,10, 6) /  1.4879000d-03 ,  8.3130000d-04 /
      data f(21,10, 7),f(21,10, 8) /  5.1020000d-04 ,  3.8430000d-04 /
      data f(21,10, 9),f(21,10,10) /  2.6100000d-04 ,  5.6100000d-05 /
      data f(21,10,11),f(21,10,12) / -2.0820000d-04 , -4.7130000d-04 /
      data f(21,10,13),f(21,10,14) / -6.7880000d-04 , -7.9230000d-04 /
      data f(21,10,15),f(21,10,16) / -7.8680000d-04 , -6.5500000d-04 /
      data f(21,10,17),f(21,10,18) / -4.1530000d-04 , -1.2000000d-04 /
      data f(21,10,19),f(21,10,20) /  1.4990000d-04 ,  3.1840000d-04 /
      data f(21,10,21),f(21,10,22) /  3.1840000d-04 ,  1.4990000d-04 /
      data f(21,10,23) /             -1.2000000d-04 /
      data f(21,11, 1),f(21,11, 2) /  7.8740000d-04 ,  2.1322000d-03 /
      data f(21,11, 3),f(21,11, 4) /  3.8655000d-03 ,  3.8655000d-03 /
      data f(21,11, 5),f(21,11, 6) /  2.1322000d-03 ,  7.8740000d-04 /
      data f(21,11, 7),f(21,11, 8) /  2.3510000d-04 ,  1.8740000d-04 /
      data f(21,11, 9),f(21,11,10) /  2.5780000d-04 ,  2.4640000d-04 /
      data f(21,11,11),f(21,11,12) /  1.2860000d-04 , -3.2200000d-05 /
      data f(21,11,13),f(21,11,14) / -1.7920000d-04 , -2.7210000d-04 /
      data f(21,11,15),f(21,11,16) / -2.8180000d-04 , -1.9330000d-04 /
      data f(21,11,17),f(21,11,18) / -1.5300000d-05 ,  2.1030000d-04 /
      data f(21,11,19),f(21,11,20) /  4.1200000d-04 ,  5.2410000d-04 /
      data f(21,11,21),f(21,11,22) /  5.2410000d-04 ,  4.1200000d-04 /
      data f(21,11,23) /              2.1030000d-04 /
      data f(21,12, 1),f(21,12, 2) /  7.4170000d-04 ,  2.9066000d-03 /
      data f(21,12, 3),f(21,12, 4) /  5.6795000d-03 ,  5.6795000d-03 /
      data f(21,12, 5),f(21,12, 6) /  2.9066000d-03 ,  7.4170000d-04 /
      data f(21,12, 7),f(21,12, 8) / -1.6350000d-04 , -2.2540000d-04 /
      data f(21,12, 9),f(21,12,10) / -2.3000000d-05 ,  1.2090000d-04 /
      data f(21,12,11),f(21,12,12) /  1.3740000d-04 ,  7.5100000d-05 /
      data f(21,12,13),f(21,12,14) / -3.5000000d-06 , -5.2700000d-05 /
      data f(21,12,15),f(21,12,16) / -4.1200000d-05 ,  4.7800000d-05 /
      data f(21,12,17),f(21,12,18) /  2.0840000d-04 ,  4.0610000d-04 /
      data f(21,12,19),f(21,12,20) /  5.8250000d-04 ,  6.8420000d-04 /
      data f(21,12,21),f(21,12,22) /  6.8420000d-04 ,  5.8250000d-04 /
      data f(21,12,23) /              4.0610000d-04 /
      data f(21,13, 1),f(21,13, 2) /  1.0679000d-03 ,  3.8211000d-03 /
      data f(21,13, 3),f(21,13, 4) /  7.1336000d-03 ,  7.1336000d-03 /
      data f(21,13, 5),f(21,13, 6) /  3.8211000d-03 ,  1.0679000d-03 /
      data f(21,13, 7),f(21,13, 8) / -2.4300000d-04 , -4.8180000d-04 /
      data f(21,13, 9),f(21,13,10) / -2.9520000d-04 , -8.6500000d-05 /
      data f(21,13,11),f(21,13,12) /  1.6600000d-05 ,  3.0500000d-05 /
      data f(21,13,13),f(21,13,14) /  8.9000000d-06 , -1.4000000d-06 /
      data f(21,13,15),f(21,13,16) /  3.1800000d-05 ,  1.2390000d-04 /
      data f(21,13,17),f(21,13,18) /  2.6930000d-04 ,  4.3950000d-04 /
      data f(21,13,19),f(21,13,20) /  5.9180000d-04 ,  6.8740000d-04 /
      data f(21,13,21),f(21,13,22) /  6.8740000d-04 ,  5.9180000d-04 /
      data f(21,13,23) /              4.3950000d-04 /
      data f(21,14, 1),f(21,14, 2) /  1.7807000d-03 ,  4.4788000d-03 /
      data f(21,14, 3),f(21,14, 4) /  7.4214000d-03 ,  7.4214000d-03 /
      data f(21,14, 5),f(21,14, 6) /  4.4788000d-03 ,  1.7807000d-03 /
      data f(21,14, 7),f(21,14, 8) /  2.3650000d-04 , -2.9560000d-04 /
      data f(21,14, 9),f(21,14,10) / -3.1210000d-04 , -1.8980000d-04 /
      data f(21,14,11),f(21,14,12) / -9.4200000d-05 , -5.5400000d-05 /
      data f(21,14,13),f(21,14,14) / -4.9000000d-05 , -4.0100000d-05 /
      data f(21,14,15),f(21,14,16) / -1.6000000d-06 ,  7.8900000d-05 /
      data f(21,14,17),f(21,14,18) /  1.9400000d-04 ,  3.2360000d-04 /
      data f(21,14,19),f(21,14,20) /  4.3660000d-04 ,  5.0730000d-04 /
      data f(21,14,21),f(21,14,22) /  5.0730000d-04 ,  4.3660000d-04 /
      data f(21,14,23) /              3.2360000d-04 /
      data f(21,15, 1),f(21,15, 2) /  2.4073000d-03 ,  4.3963000d-03 /
      data f(21,15, 3),f(21,15, 4) /  6.3130000d-03 ,  6.3130000d-03 /
      data f(21,15, 5),f(21,15, 6) /  4.3963000d-03 ,  2.4073000d-03 /
      data f(21,15, 7),f(21,15, 8) /  1.0054000d-03 ,  2.6960000d-04 /
      data f(21,15, 9),f(21,15,10) / -1.8900000d-05 , -9.5700000d-05 /
      data f(21,15,11),f(21,15,12) / -1.0560000d-04 , -1.0840000d-04 /
      data f(21,15,13),f(21,15,14) / -1.1430000d-04 , -1.1240000d-04 /
      data f(21,15,15),f(21,15,16) / -9.0000000d-05 , -4.0600000d-05 /
      data f(21,15,17),f(21,15,18) /  3.0900000d-05 ,  1.1010000d-04 /
      data f(21,15,19),f(21,15,20) /  1.7750000d-04 ,  2.1960000d-04 /
      data f(21,15,21),f(21,15,22) /  2.1960000d-04 ,  1.7750000d-04 /
      data f(21,15,23) /              1.1010000d-04 /
      data f(21,16, 1),f(21,16, 2) /  2.4245000d-03 ,  3.5082000d-03 /
      data f(21,16, 3),f(21,16, 4) /  4.4150000d-03 ,  4.4150000d-03 /
      data f(21,16, 5),f(21,16, 6) /  3.5082000d-03 ,  2.4245000d-03 /
      data f(21,16, 7),f(21,16, 8) /  1.4791000d-03 ,  8.0380000d-04 /
      data f(21,16, 9),f(21,16,10) /  3.8230000d-04 ,  1.3890000d-04 /
      data f(21,16,11),f(21,16,12) /  0.0000000d+00 , -8.3100000d-05 /
      data f(21,16,13),f(21,16,14) / -1.3540000d-04 , -1.6560000d-04 /
      data f(21,16,15),f(21,16,16) / -1.7540000d-04 , -1.6660000d-04 /
      data f(21,16,17),f(21,16,18) / -1.4330000d-04 , -1.1360000d-04 /
      data f(21,16,19),f(21,16,20) / -8.6200000d-05 , -6.7700000d-05 /
      data f(21,16,21),f(21,16,22) / -6.7700000d-05 , -8.6200000d-05 /
      data f(21,16,23) /             -1.1360000d-04 /
      data f(21,17, 1),f(21,17, 2) /  1.7683000d-03 ,  2.1917000d-03 /
      data f(21,17, 3),f(21,17, 4) /  2.5015000d-03 ,  2.5015000d-03 /
      data f(21,17, 5),f(21,17, 6) /  2.1917000d-03 ,  1.7683000d-03 /
      data f(21,17, 7),f(21,17, 8) /  1.3217000d-03 ,  9.1800000d-04 /
      data f(21,17, 9),f(21,17,10) /  5.8850000d-04 ,  3.3660000d-04 /
      data f(21,17,11),f(21,17,12) /  1.5140000d-04 ,  1.7500000d-05 /
      data f(21,17,13),f(21,17,14) / -7.8300000d-05 , -1.4560000d-04 /
      data f(21,17,15),f(21,17,16) / -1.9120000d-04 , -2.1980000d-04 /
      data f(21,17,17),f(21,17,18) / -2.3560000d-04 , -2.4300000d-04 /
      data f(21,17,19),f(21,17,20) / -2.4540000d-04 , -2.4560000d-04 /
      data f(21,17,21),f(21,17,22) / -2.4560000d-04 , -2.4540000d-04 /
      data f(21,17,23) /             -2.4300000d-04 /
      data f(21,18, 1),f(21,18, 2) /  8.7770000d-04 ,  9.8200000d-04 /
      data f(21,18, 3),f(21,18, 4) /  1.0512000d-03 ,  1.0512000d-03 /
      data f(21,18, 5),f(21,18, 6) /  9.8200000d-04 ,  8.7770000d-04 /
      data f(21,18, 7),f(21,18, 8) /  7.5020000d-04 ,  6.1250000d-04 /
      data f(21,18, 9),f(21,18,10) /  4.7540000d-04 ,  3.4700000d-04 /
      data f(21,18,11),f(21,18,12) /  2.3210000d-04 ,  1.3260000d-04 /
      data f(21,18,13),f(21,18,14) /  4.8900000d-05 , -1.9900000d-05 /
      data f(21,18,15),f(21,18,16) / -7.5300000d-05 , -1.1870000d-04 /
      data f(21,18,17),f(21,18,18) / -1.5180000d-04 , -1.7570000d-04 /
      data f(21,18,19),f(21,18,20) / -1.9190000d-04 , -2.0130000d-04 /
      data f(21,18,21),f(21,18,22) / -2.0130000d-04 , -1.9190000d-04 /
      data f(21,18,23) /             -1.7570000d-04 /
      data f(21,19, 1),f(21,19, 2) /  1.8300000d-04 ,  1.8300000d-04 /
      data f(21,19, 3),f(21,19, 4) /  1.8300000d-04 ,  1.8300000d-04 /
      data f(21,19, 5),f(21,19, 6) /  1.8300000d-04 ,  1.8300000d-04 /
      data f(21,19, 7),f(21,19, 8) /  1.8300000d-04 ,  1.8300000d-04 /
      data f(21,19, 9),f(21,19,10) /  1.8300000d-04 ,  1.8300000d-04 /
      data f(21,19,11),f(21,19,12) /  1.8300000d-04 ,  1.8300000d-04 /
      data f(21,19,13),f(21,19,14) /  1.8300000d-04 ,  1.8300000d-04 /
      data f(21,19,15),f(21,19,16) /  1.8300000d-04 ,  1.8300000d-04 /
      data f(21,19,17),f(21,19,18) /  1.8300000d-04 ,  1.8300000d-04 /
      data f(21,19,19),f(21,19,20) /  1.8300000d-04 ,  1.8300000d-04 /
      data f(21,19,21),f(21,19,22) /  1.8300000d-04 ,  1.8300000d-04 /
      data f(21,19,23) /              1.8300000d-04 /
      data f(22, 1, 1),f(22, 1, 2) /  2.1642100d-02 ,  2.1642100d-02 /
      data f(22, 1, 3),f(22, 1, 4) /  2.1642100d-02 ,  2.1642100d-02 /
      data f(22, 1, 5),f(22, 1, 6) /  2.1642100d-02 ,  2.1642100d-02 /
      data f(22, 1, 7),f(22, 1, 8) /  2.1642100d-02 ,  2.1642100d-02 /
      data f(22, 1, 9),f(22, 1,10) /  2.1642100d-02 ,  2.1642100d-02 /
      data f(22, 1,11),f(22, 1,12) /  2.1642100d-02 ,  2.1642100d-02 /
      data f(22, 1,13),f(22, 1,14) /  2.1642100d-02 ,  2.1642100d-02 /
      data f(22, 1,15),f(22, 1,16) /  2.1642100d-02 ,  2.1642100d-02 /
      data f(22, 1,17),f(22, 1,18) /  2.1642100d-02 ,  2.1642100d-02 /
      data f(22, 1,19),f(22, 1,20) /  2.1642100d-02 ,  2.1642100d-02 /
      data f(22, 1,21),f(22, 1,22) /  2.1642100d-02 ,  2.1642100d-02 /
      data f(22, 1,23) /              2.1642100d-02 /
      data f(22, 2, 1),f(22, 2, 2) /  2.0380200d-02 ,  2.2090200d-02 /
      data f(22, 2, 3),f(22, 2, 4) /  2.3242700d-02 ,  2.3242700d-02 /
      data f(22, 2, 5),f(22, 2, 6) /  2.2090200d-02 ,  2.0380200d-02 /
      data f(22, 2, 7),f(22, 2, 8) /  1.8366100d-02 ,  1.6313800d-02 /
      data f(22, 2, 9),f(22, 2,10) /  1.4462100d-02 ,  1.3001900d-02 /
      data f(22, 2,11),f(22, 2,12) /  1.2069000d-02 ,  1.1744700d-02 /
      data f(22, 2,13),f(22, 2,14) /  1.2057700d-02 ,  1.2984700d-02 /
      data f(22, 2,15),f(22, 2,16) /  1.4449200d-02 ,  1.6318200d-02 /
      data f(22, 2,17),f(22, 2,18) /  1.8400800d-02 ,  2.0454400d-02 /
      data f(22, 2,19),f(22, 2,20) /  2.2205200d-02 ,  2.3388800d-02 /
      data f(22, 2,21),f(22, 2,22) /  2.3388800d-02 ,  2.2205200d-02 /
      data f(22, 2,23) /              2.0454400d-02 /
      data f(22, 3, 1),f(22, 3, 2) /  1.6444700d-02 ,  2.1085600d-02 /
      data f(22, 3, 3),f(22, 3, 4) /  2.4414500d-02 ,  2.4414500d-02 /
      data f(22, 3, 5),f(22, 3, 6) /  2.1085600d-02 ,  1.6444700d-02 /
      data f(22, 3, 7),f(22, 3, 8) /  1.1353500d-02 ,  6.5037000d-03 /
      data f(22, 3, 9),f(22, 3,10) /  2.3706000d-03 , -7.5240000d-04 /
      data f(22, 3,11),f(22, 3,12) / -2.7037000d-03 , -3.4051000d-03 /
      data f(22, 3,13),f(22, 3,14) / -2.8276000d-03 , -9.7930000d-04 /
      data f(22, 3,15),f(22, 3,16) /  2.0813000d-03 ,  6.2079000d-03 /
      data f(22, 3,17),f(22, 3,18) /  1.1116000d-02 ,  1.6327300d-02 /
      data f(22, 3,19),f(22, 3,20) /  2.1128000d-02 ,  2.4604500d-02 /
      data f(22, 3,21),f(22, 3,22) /  2.4604500d-02 ,  2.1128000d-02 /
      data f(22, 3,23) /              1.6327300d-02 /
      data f(22, 4, 1),f(22, 4, 2) /  1.0532200d-02 ,  1.5886500d-02 /
      data f(22, 4, 3),f(22, 4, 4) /  1.9853600d-02 ,  1.9853600d-02 /
      data f(22, 4, 5),f(22, 4, 6) /  1.5886500d-02 ,  1.0532200d-02 /
      data f(22, 4, 7),f(22, 4, 8) /  4.8626000d-03 , -3.6660000d-04 /
      data f(22, 4, 9),f(22, 4,10) / -4.7068000d-03 , -7.9316000d-03 /
      data f(22, 4,11),f(22, 4,12) / -9.9457000d-03 , -1.0709300d-02 /
      data f(22, 4,13),f(22, 4,14) / -1.0199800d-02 , -8.4026000d-03 /
      data f(22, 4,15),f(22, 4,16) / -5.3221000d-03 , -1.0241000d-03 /
      data f(22, 4,17),f(22, 4,18) /  4.2844000d-03 ,  1.0154800d-02 /
      data f(22, 4,19),f(22, 4,20) /  1.5795200d-02 ,  2.0038100d-02 /
      data f(22, 4,21),f(22, 4,22) /  2.0038100d-02 ,  1.5795200d-02 /
      data f(22, 4,23) /              1.0154800d-02 /
      data f(22, 5, 1),f(22, 5, 2) /  5.0178000d-03 ,  8.8094000d-03 /
      data f(22, 5, 3),f(22, 5, 4) /  1.1587300d-02 ,  1.1587300d-02 /
      data f(22, 5, 5),f(22, 5, 6) /  8.8094000d-03 ,  5.0178000d-03 /
      data f(22, 5, 7),f(22, 5, 8) /  9.5820000d-04 , -2.8139000d-03 /
      data f(22, 5, 9),f(22, 5,10) / -5.9736000d-03 , -8.3644000d-03 /
      data f(22, 5,11),f(22, 5,12) / -9.9074000d-03 , -1.0549600d-02 /
      data f(22, 5,13),f(22, 5,14) / -1.0255700d-02 , -9.0102000d-03 /
      data f(22, 5,15),f(22, 5,16) / -6.8179000d-03 , -3.7176000d-03 /
      data f(22, 5,17),f(22, 5,18) /  1.5770000d-04 ,  4.4756000d-03 /
      data f(22, 5,19),f(22, 5,20) /  8.6226000d-03 ,  1.1726200d-02 /
      data f(22, 5,21),f(22, 5,22) /  1.1726200d-02 ,  8.6226000d-03 /
      data f(22, 5,23) /              4.4756000d-03 /
      data f(22, 6, 1),f(22, 6, 2) /  1.6613000d-03 ,  3.6186000d-03 /
      data f(22, 6, 3),f(22, 6, 4) /  5.0014000d-03 ,  5.0014000d-03 /
      data f(22, 6, 5),f(22, 6, 6) /  3.6186000d-03 ,  1.6613000d-03 /
      data f(22, 6, 7),f(22, 6, 8) / -5.0910000d-04 , -2.6037000d-03 /
      data f(22, 6, 9),f(22, 6,10) / -4.4350000d-03 , -5.8871000d-03 /
      data f(22, 6,11),f(22, 6,12) / -6.8812000d-03 , -7.3588000d-03 /
      data f(22, 6,13),f(22, 6,14) / -7.2789000d-03 , -6.6203000d-03 /
      data f(22, 6,15),f(22, 6,16) / -5.3859000d-03 , -3.6135000d-03 /
      data f(22, 6,17),f(22, 6,18) / -1.4011000d-03 ,  1.0432000d-03 /
      data f(22, 6,19),f(22, 6,20) /  3.3569000d-03 ,  5.0497000d-03 /
      data f(22, 6,21),f(22, 6,22) /  5.0497000d-03 ,  3.3569000d-03 /
      data f(22, 6,23) /              1.0432000d-03 /
      data f(22, 7, 1),f(22, 7, 2) /  2.9140000d-04 ,  1.0757000d-03 /
      data f(22, 7, 3),f(22, 7, 4) /  1.5984000d-03 ,  1.5984000d-03 /
      data f(22, 7, 5),f(22, 7, 6) /  1.0757000d-03 ,  2.9140000d-04 /
      data f(22, 7, 7),f(22, 7, 8) / -6.3710000d-04 , -1.5982000d-03 /
      data f(22, 7, 9),f(22, 7,10) / -2.5035000d-03 , -3.2832000d-03 /
      data f(22, 7,11),f(22, 7,12) / -3.8751000d-03 , -4.2209000d-03 /
      data f(22, 7,13),f(22, 7,14) / -4.2753000d-03 , -4.0169000d-03 /
      data f(22, 7,15),f(22, 7,16) / -3.4491000d-03 , -2.5982000d-03 /
      data f(22, 7,17),f(22, 7,18) / -1.5250000d-03 , -3.4680000d-04 /
      data f(22, 7,19),f(22, 7,20) /  7.4860000d-04 ,  1.5310000d-03 /
      data f(22, 7,21),f(22, 7,22) /  1.5310000d-03 ,  7.4860000d-04 /
      data f(22, 7,23) /             -3.4680000d-04 /
      data f(22, 8, 1),f(22, 8, 2) / -7.0000000d-06 ,  2.4560000d-04 /
      data f(22, 8, 3),f(22, 8, 4) /  4.0480000d-04 ,  4.0480000d-04 /
      data f(22, 8, 5),f(22, 8, 6) /  2.4560000d-04 , -7.0000000d-06 /
      data f(22, 8, 7),f(22, 8, 8) / -3.3360000d-04 , -7.1370000d-04 /
      data f(22, 8, 9),f(22, 8,10) / -1.1215000d-03 , -1.5215000d-03 /
      data f(22, 8,11),f(22, 8,12) / -1.8702000d-03 , -2.1208000d-03 /
      data f(22, 8,13),f(22, 8,14) / -2.2340000d-03 , -2.1872000d-03 /
      data f(22, 8,15),f(22, 8,16) / -1.9774000d-03 , -1.6187000d-03 /
      data f(22, 8,17),f(22, 8,18) / -1.1470000d-03 , -6.2640000d-04 /
      data f(22, 8,19),f(22, 8,20) / -1.4970000d-04 ,  1.8230000d-04 /
      data f(22, 8,21),f(22, 8,22) /  1.8230000d-04 , -1.4970000d-04 /
      data f(22, 8,23) /             -6.2640000d-04 /
      data f(22, 9, 1),f(22, 9, 2) /  5.4200000d-05 ,  1.9240000d-04 /
      data f(22, 9, 3),f(22, 9, 4) /  3.2030000d-04 ,  3.2030000d-04 /
      data f(22, 9, 5),f(22, 9, 6) /  1.9240000d-04 ,  5.4200000d-05 /
      data f(22, 9, 7),f(22, 9, 8) / -7.2500000d-05 , -2.0970000d-04 /
      data f(22, 9, 9),f(22, 9,10) / -3.8010000d-04 , -5.7980000d-04 /
      data f(22, 9,11),f(22, 9,12) / -7.8480000d-04 , -9.6350000d-04 /
      data f(22, 9,13),f(22, 9,14) / -1.0859000d-03 , -1.1286000d-03 /
      data f(22, 9,15),f(22, 9,16) / -1.0794000d-03 , -9.4090000d-04 /
      data f(22, 9,17),f(22, 9,18) / -7.3370000d-04 , -4.9820000d-04 /
      data f(22, 9,19),f(22, 9,20) / -2.8840000d-04 , -1.5220000d-04 /
      data f(22, 9,21),f(22, 9,22) / -1.5220000d-04 , -2.8840000d-04 /
      data f(22, 9,23) /             -4.9820000d-04 /
      data f(22,10, 1),f(22,10, 2) /  1.1920000d-04 ,  4.0580000d-04 /
      data f(22,10, 3),f(22,10, 4) /  7.4820000d-04 ,  7.4820000d-04 /
      data f(22,10, 5),f(22,10, 6) /  4.0580000d-04 ,  1.1920000d-04 /
      data f(22,10, 7),f(22,10, 8) / -1.6000000d-05 , -5.9100000d-05 /
      data f(22,10, 9),f(22,10,10) / -1.0120000d-04 , -1.8200000d-04 /
      data f(22,10,11),f(22,10,12) / -2.9420000d-04 , -4.1320000d-04 /
      data f(22,10,13),f(22,10,14) / -5.1450000d-04 , -5.7680000d-04 /
      data f(22,10,15),f(22,10,16) / -5.8400000d-04 , -5.3000000d-04 /
      data f(22,10,17),f(22,10,18) / -4.2460000d-04 , -2.9710000d-04 /
      data f(22,10,19),f(22,10,20) / -1.8930000d-04 , -1.3240000d-04 /
      data f(22,10,21),f(22,10,22) / -1.3240000d-04 , -1.8930000d-04 /
      data f(22,10,23) /             -2.9710000d-04 /
      data f(22,11, 1),f(22,11, 2) /  1.0200000d-04 ,  6.9920000d-04 /
      data f(22,11, 3),f(22,11, 4) /  1.4304000d-03 ,  1.4304000d-03 /
      data f(22,11, 5),f(22,11, 6) /  6.9920000d-04 ,  1.0200000d-04 /
      data f(22,11, 7),f(22,11, 8) / -1.4770000d-04 , -1.5670000d-04 /
      data f(22,11, 9),f(22,11,10) / -1.0630000d-04 , -9.6000000d-05 /
      data f(22,11,11),f(22,11,12) / -1.3610000d-04 , -2.0080000d-04 /
      data f(22,11,13),f(22,11,14) / -2.6580000d-04 , -3.1300000d-04 /
      data f(22,11,15),f(22,11,16) / -3.2710000d-04 , -2.9730000d-04 /
      data f(22,11,17),f(22,11,18) / -2.2560000d-04 , -1.3390000d-04 /
      data f(22,11,19),f(22,11,20) / -5.9800000d-05 , -3.0400000d-05 /
      data f(22,11,21),f(22,11,22) / -3.0400000d-05 , -5.9800000d-05 /
      data f(22,11,23) /             -1.3390000d-04 /
      data f(22,12, 1),f(22,12, 2) /  9.2400000d-05 ,  1.0483000d-03 /
      data f(22,12, 3),f(22,12, 4) /  2.1942000d-03 ,  2.1942000d-03 /
      data f(22,12, 5),f(22,12, 6) /  1.0483000d-03 ,  9.2400000d-05 /
      data f(22,12, 7),f(22,12, 8) / -3.3090000d-04 , -3.5700000d-04 /
      data f(22,12, 9),f(22,12,10) / -2.4830000d-04 , -1.6570000d-04 /
      data f(22,12,11),f(22,12,12) / -1.4380000d-04 , -1.5880000d-04 /
      data f(22,12,13),f(22,12,14) / -1.8560000d-04 , -2.0710000d-04 /
      data f(22,12,15),f(22,12,16) / -2.0950000d-04 , -1.8130000d-04 /
      data f(22,12,17),f(22,12,18) / -1.2070000d-04 , -4.2200000d-05 /
      data f(22,12,19),f(22,12,20) /  2.4100000d-05 ,  5.4300000d-05 /
      data f(22,12,21),f(22,12,22) /  5.4300000d-05 ,  2.4100000d-05 /
      data f(22,12,23) /             -4.2200000d-05 /
      data f(22,13, 1),f(22,13, 2) /  2.4730000d-04 ,  1.4405000d-03 /
      data f(22,13, 3),f(22,13, 4) /  2.7888000d-03 ,  2.7888000d-03 /
      data f(22,13, 5),f(22,13, 6) /  1.4405000d-03 ,  2.4730000d-04 /
      data f(22,13, 7),f(22,13, 8) / -3.5900000d-04 , -4.7700000d-04 /
      data f(22,13, 9),f(22,13,10) / -3.8290000d-04 , -2.7250000d-04 /
      data f(22,13,11),f(22,13,12) / -2.1090000d-04 , -1.9020000d-04 /
      data f(22,13,13),f(22,13,14) / -1.8820000d-04 , -1.8840000d-04 /
      data f(22,13,15),f(22,13,16) / -1.7810000d-04 , -1.4760000d-04 /
      data f(22,13,17),f(22,13,18) / -9.4500000d-05 , -2.8500000d-05 /
      data f(22,13,19),f(22,13,20) /  3.0800000d-05 ,  6.5100000d-05 /
      data f(22,13,21),f(22,13,22) /  6.5100000d-05 ,  3.0800000d-05 /
      data f(22,13,23) /             -2.8500000d-05 /
      data f(22,14, 1),f(22,14, 2) /  5.6880000d-04 ,  1.7174000d-03 /
      data f(22,14, 3),f(22,14, 4) /  2.9035000d-03 ,  2.9035000d-03 /
      data f(22,14, 5),f(22,14, 6) /  1.7174000d-03 ,  5.6880000d-04 /
      data f(22,14, 7),f(22,14, 8) / -1.2970000d-04 , -3.8390000d-04 /
      data f(22,14, 9),f(22,14,10) / -3.9060000d-04 , -3.2410000d-04 /
      data f(22,14,11),f(22,14,12) / -2.6790000d-04 , -2.3830000d-04 /
      data f(22,14,13),f(22,14,14) / -2.2540000d-04 , -2.1680000d-04 /
      data f(22,14,15),f(22,14,16) / -2.0200000d-04 , -1.7470000d-04 /
      data f(22,14,17),f(22,14,18) / -1.3410000d-04 , -8.6900000d-05 /
      data f(22,14,19),f(22,14,20) / -4.5300000d-05 , -1.9600000d-05 /
      data f(22,14,21),f(22,14,22) / -1.9600000d-05 , -4.5300000d-05 /
      data f(22,14,23) /             -8.6900000d-05 /
      data f(22,15, 1),f(22,15, 2) /  8.4030000d-04 ,  1.6788000d-03 /
      data f(22,15, 3),f(22,15, 4) /  2.4519000d-03 ,  2.4519000d-03 /
      data f(22,15, 5),f(22,15, 6) /  1.6788000d-03 ,  8.4030000d-04 /
      data f(22,15, 7),f(22,15, 8) /  2.1970000d-04 , -1.1820000d-04 /
      data f(22,15, 9),f(22,15,10) / -2.4990000d-04 , -2.7860000d-04 /
      data f(22,15,11),f(22,15,12) / -2.7450000d-04 , -2.6810000d-04 /
      data f(22,15,13),f(22,15,14) / -2.6520000d-04 , -2.6220000d-04 /
      data f(22,15,15),f(22,15,16) / -2.5450000d-04 , -2.3900000d-04 /
      data f(22,15,17),f(22,15,18) / -2.1640000d-04 , -1.9140000d-04 /
      data f(22,15,19),f(22,15,20) / -1.7090000d-04 , -1.5880000d-04 /
      data f(22,15,21),f(22,15,22) / -1.5880000d-04 , -1.7090000d-04 /
      data f(22,15,23) /             -1.9140000d-04 /
      data f(22,16, 1),f(22,16, 2) /  8.3600000d-04 ,  1.2943000d-03 /
      data f(22,16, 3),f(22,16, 4) /  1.6674000d-03 ,  1.6674000d-03 /
      data f(22,16, 5),f(22,16, 6) /  1.2943000d-03 ,  8.3600000d-04 /
      data f(22,16, 7),f(22,16, 8) /  4.2470000d-04 ,  1.2510000d-04 /
      data f(22,16, 9),f(22,16,10) / -6.2000000d-05 , -1.6770000d-04 /
      data f(22,16,11),f(22,16,12) / -2.2590000d-04 , -2.6020000d-04 /
      data f(22,16,13),f(22,16,14) / -2.8240000d-04 , -2.9680000d-04 /
      data f(22,16,15),f(22,16,16) / -3.0430000d-04 , -3.0580000d-04 /
      data f(22,16,17),f(22,16,18) / -3.0250000d-04 , -2.9710000d-04 /
      data f(22,16,19),f(22,16,20) / -2.9210000d-04 , -2.8910000d-04 /
      data f(22,16,21),f(22,16,22) / -2.8910000d-04 , -2.9210000d-04 /
      data f(22,16,23) /             -2.9710000d-04 /
      data f(22,17, 1),f(22,17, 2) /  5.4720000d-04 ,  7.2860000d-04 /
      data f(22,17, 3),f(22,17, 4) /  8.6010000d-04 ,  8.6010000d-04 /
      data f(22,17, 5),f(22,17, 6) /  7.2860000d-04 ,  5.4720000d-04 /
      data f(22,17, 7),f(22,17, 8) /  3.5400000d-04 ,  1.7810000d-04 /
      data f(22,17, 9),f(22,17,10) /  3.3900000d-05 , -7.6500000d-05 /
      data f(22,17,11),f(22,17,12) / -1.5800000d-04 , -2.1770000d-04 /
      data f(22,17,13),f(22,17,14) / -2.6170000d-04 , -2.9400000d-04 /
      data f(22,17,15),f(22,17,16) / -3.1770000d-04 , -3.3460000d-04 /
      data f(22,17,17),f(22,17,18) / -3.4630000d-04 , -3.5420000d-04 /
      data f(22,17,19),f(22,17,20) / -3.5910000d-04 , -3.6180000d-04 /
      data f(22,17,21),f(22,17,22) / -3.6180000d-04 , -3.5910000d-04 /
      data f(22,17,23) /             -3.5420000d-04 /
      data f(22,18, 1),f(22,18, 2) /  1.6060000d-04 ,  2.0630000d-04 /
      data f(22,18, 3),f(22,18, 4) /  2.3620000d-04 ,  2.3620000d-04 /
      data f(22,18, 5),f(22,18, 6) /  2.0630000d-04 ,  1.6060000d-04 /
      data f(22,18, 7),f(22,18, 8) /  1.0490000d-04 ,  4.4500000d-05 /
      data f(22,18, 9),f(22,18,10) / -1.5900000d-05 , -7.2800000d-05 /
      data f(22,18,11),f(22,18,12) / -1.2420000d-04 , -1.6920000d-04 /
      data f(22,18,13),f(22,18,14) / -2.0770000d-04 , -2.3990000d-04 /
      data f(22,18,15),f(22,18,16) / -2.6630000d-04 , -2.8760000d-04 /
      data f(22,18,17),f(22,18,18) / -3.0420000d-04 , -3.1660000d-04 /
      data f(22,18,19),f(22,18,20) / -3.2520000d-04 , -3.3020000d-04 /
      data f(22,18,21),f(22,18,22) / -3.3020000d-04 , -3.2520000d-04 /
      data f(22,18,23) /             -3.1660000d-04 /
      data f(22,19, 1),f(22,19, 2) / -1.4830000d-04 , -1.4830000d-04 /
      data f(22,19, 3),f(22,19, 4) / -1.4830000d-04 , -1.4830000d-04 /
      data f(22,19, 5),f(22,19, 6) / -1.4830000d-04 , -1.4830000d-04 /
      data f(22,19, 7),f(22,19, 8) / -1.4830000d-04 , -1.4830000d-04 /
      data f(22,19, 9),f(22,19,10) / -1.4830000d-04 , -1.4830000d-04 /
      data f(22,19,11),f(22,19,12) / -1.4830000d-04 , -1.4830000d-04 /
      data f(22,19,13),f(22,19,14) / -1.4830000d-04 , -1.4830000d-04 /
      data f(22,19,15),f(22,19,16) / -1.4830000d-04 , -1.4830000d-04 /
      data f(22,19,17),f(22,19,18) / -1.4830000d-04 , -1.4830000d-04 /
      data f(22,19,19),f(22,19,20) / -1.4830000d-04 , -1.4830000d-04 /
      data f(22,19,21),f(22,19,22) / -1.4830000d-04 , -1.4830000d-04 /
      data f(22,19,23) /             -1.4830000d-04 /
      data f(23, 1, 1),f(23, 1, 2) /  1.0239900d-02 ,  1.0239900d-02 /
      data f(23, 1, 3),f(23, 1, 4) /  1.0239900d-02 ,  1.0239900d-02 /
      data f(23, 1, 5),f(23, 1, 6) /  1.0239900d-02 ,  1.0239900d-02 /
      data f(23, 1, 7),f(23, 1, 8) /  1.0239900d-02 ,  1.0239900d-02 /
      data f(23, 1, 9),f(23, 1,10) /  1.0239900d-02 ,  1.0239900d-02 /
      data f(23, 1,11),f(23, 1,12) /  1.0239900d-02 ,  1.0239900d-02 /
      data f(23, 1,13),f(23, 1,14) /  1.0239900d-02 ,  1.0239900d-02 /
      data f(23, 1,15),f(23, 1,16) /  1.0239900d-02 ,  1.0239900d-02 /
      data f(23, 1,17),f(23, 1,18) /  1.0239900d-02 ,  1.0239900d-02 /
      data f(23, 1,19),f(23, 1,20) /  1.0239900d-02 ,  1.0239900d-02 /
      data f(23, 1,21),f(23, 1,22) /  1.0239900d-02 ,  1.0239900d-02 /
      data f(23, 1,23) /              1.0239900d-02 /
      data f(23, 2, 1),f(23, 2, 2) /  9.8465000d-03 ,  1.0589400d-02 /
      data f(23, 2, 3),f(23, 2, 4) /  1.1082000d-02 ,  1.1082000d-02 /
      data f(23, 2, 5),f(23, 2, 6) /  1.0589400d-02 ,  9.8465000d-03 /
      data f(23, 2, 7),f(23, 2, 8) /  8.9545000d-03 ,  8.0275000d-03 /
      data f(23, 2, 9),f(23, 2,10) /  7.1764000d-03 ,  6.4956000d-03 /
      data f(23, 2,11),f(23, 2,12) /  6.0563000d-03 ,  5.9023000d-03 /
      data f(23, 2,13),f(23, 2,14) /  6.0495000d-03 ,  6.4851000d-03 /
      data f(23, 2,15),f(23, 2,16) /  7.1672000d-03 ,  8.0259000d-03 /
      data f(23, 2,17),f(23, 2,18) /  8.9662000d-03 ,  9.8750000d-03 /
      data f(23, 2,19),f(23, 2,20) /  1.0634600d-02 ,  1.1139500d-02 /
      data f(23, 2,21),f(23, 2,22) /  1.1139500d-02 ,  1.0634600d-02 /
      data f(23, 2,23) /              9.8750000d-03 /
      data f(23, 3, 1),f(23, 3, 2) /  8.2467000d-03 ,  1.0326200d-02 /
      data f(23, 3, 3),f(23, 3, 4) /  1.1750400d-02 ,  1.1750400d-02 /
      data f(23, 3, 5),f(23, 3, 6) /  1.0326200d-02 ,  8.2467000d-03 /
      data f(23, 3, 7),f(23, 3, 8) /  5.8571000d-03 ,  3.4909000d-03 /
      data f(23, 3, 9),f(23, 3,10) /  1.4133000d-03 , -1.9190000d-04 /
      data f(23, 3,11),f(23, 3,12) / -1.2108000d-03 , -1.5813000d-03 /
      data f(23, 3,13),f(23, 3,14) / -1.2792000d-03 , -3.1490000d-04 /
      data f(23, 3,15),f(23, 3,16) /  1.2614000d-03 ,  3.3435000d-03 /
      data f(23, 3,17),f(23, 3,18) /  5.7491000d-03 ,  8.2059000d-03 /
      data f(23, 3,19),f(23, 3,20) /  1.0363600d-02 ,  1.1851900d-02 /
      data f(23, 3,21),f(23, 3,22) /  1.1851900d-02 ,  1.0363600d-02 /
      data f(23, 3,23) /              8.2059000d-03 /
      data f(23, 4, 1),f(23, 4, 2) /  5.2999000d-03 ,  7.7865000d-03 /
      data f(23, 4, 3),f(23, 4, 4) /  9.5321000d-03 ,  9.5321000d-03 /
      data f(23, 4, 5),f(23, 4, 6) /  7.7865000d-03 ,  5.2999000d-03 /
      data f(23, 4, 7),f(23, 4, 8) /  2.5371000d-03 , -1.0530000d-04 /
      data f(23, 4, 9),f(23, 4,10) / -2.3594000d-03 , -4.0716000d-03 /
      data f(23, 4,11),f(23, 4,12) / -5.1595000d-03 , -5.5766000d-03 /
      data f(23, 4,13),f(23, 4,14) / -5.2997000d-03 , -4.3275000d-03 /
      data f(23, 4,15),f(23, 4,16) / -2.6842000d-03 , -4.3640000d-04 /
      data f(23, 4,17),f(23, 4,18) /  2.2688000d-03 ,  5.1543000d-03 /
      data f(23, 4,19),f(23, 4,20) /  7.7933000d-03 ,  9.6688000d-03 /
      data f(23, 4,21),f(23, 4,22) /  9.6688000d-03 ,  7.7933000d-03 /
      data f(23, 4,23) /              5.1543000d-03 /
      data f(23, 5, 1),f(23, 5, 2) /  2.3523000d-03 ,  4.1730000d-03 /
      data f(23, 5, 3),f(23, 5, 4) /  5.4670000d-03 ,  5.4670000d-03 /
      data f(23, 5, 5),f(23, 5, 6) /  4.1730000d-03 ,  2.3523000d-03 /
      data f(23, 5, 7),f(23, 5, 8) /  3.4640000d-04 , -1.5650000d-03 /
      data f(23, 5, 9),f(23, 5,10) / -3.1997000d-03 , -4.4544000d-03 /
      data f(23, 5,11),f(23, 5,12) / -5.2702000d-03 , -5.6115000d-03 /
      data f(23, 5,13),f(23, 5,14) / -5.4571000d-03 , -4.7972000d-03 /
      data f(23, 5,15),f(23, 5,16) / -3.6389000d-03 , -2.0193000d-03 /
      data f(23, 5,17),f(23, 5,18) / -3.3200000d-05 ,  2.1249000d-03 /
      data f(23, 5,19),f(23, 5,20) /  4.1350000d-03 ,  5.5892000d-03 /
      data f(23, 5,21),f(23, 5,22) /  5.5892000d-03 ,  4.1350000d-03 /
      data f(23, 5,23) /              2.1249000d-03 /
      data f(23, 6, 1),f(23, 6, 2) /  5.7740000d-04 ,  1.5289000d-03 /
      data f(23, 6, 3),f(23, 6, 4) /  2.1896000d-03 ,  2.1896000d-03 /
      data f(23, 6, 5),f(23, 6, 6) /  1.5289000d-03 ,  5.7740000d-04 /
      data f(23, 6, 7),f(23, 6, 8) / -4.9310000d-04 , -1.5392000d-03 /
      data f(23, 6, 9),f(23, 6,10) / -2.4629000d-03 , -3.2017000d-03 /
      data f(23, 6,11),f(23, 6,12) / -3.7119000d-03 , -3.9593000d-03 /
      data f(23, 6,13),f(23, 6,14) / -3.9195000d-03 , -3.5818000d-03 /
      data f(23, 6,15),f(23, 6,16) / -2.9498000d-03 , -2.0460000d-03 /
      data f(23, 6,17),f(23, 6,18) / -9.2630000d-04 ,  2.9610000d-04 /
      data f(23, 6,19),f(23, 6,20) /  1.4346000d-03 ,  2.2512000d-03 /
      data f(23, 6,21),f(23, 6,22) /  2.2512000d-03 ,  1.4346000d-03 /
      data f(23, 6,23) /              2.9610000d-04 /
      data f(23, 7, 1),f(23, 7, 2) / -1.0890000d-04 ,  2.6520000d-04 /
      data f(23, 7, 3),f(23, 7, 4) /  5.1230000d-04 ,  5.1230000d-04 /
      data f(23, 7, 5),f(23, 7, 6) /  2.6520000d-04 , -1.0890000d-04 /
      data f(23, 7, 7),f(23, 7, 8) / -5.5340000d-04 , -1.0148000d-03 /
      data f(23, 7, 9),f(23, 7,10) / -1.4527000d-03 , -1.8357000d-03 /
      data f(23, 7,11),f(23, 7,12) / -2.1318000d-03 , -2.3074000d-03 /
      data f(23, 7,13),f(23, 7,14) / -2.3362000d-03 , -2.2086000d-03 /
      data f(23, 7,15),f(23, 7,16) / -1.9288000d-03 , -1.5110000d-03 /
      data f(23, 7,17),f(23, 7,18) / -9.8440000d-04 , -4.0690000d-04 /
      data f(23, 7,19),f(23, 7,20) /  1.2710000d-04 ,  5.0380000d-04 /
      data f(23, 7,21),f(23, 7,22) /  5.0380000d-04 ,  1.2710000d-04 /
      data f(23, 7,23) /             -4.0690000d-04 /
      data f(23, 8, 1),f(23, 8, 2) / -2.2850000d-04 , -1.2020000d-04 /
      data f(23, 8, 3),f(23, 8, 4) / -5.4200000d-05 , -5.4200000d-05 /
      data f(23, 8, 5),f(23, 8, 6) / -1.2020000d-04 , -2.2850000d-04 /
      data f(23, 8, 7),f(23, 8, 8) / -3.7210000d-04 , -5.4210000d-04 /
      data f(23, 8, 9),f(23, 8,10) / -7.2760000d-04 , -9.1370000d-04 /
      data f(23, 8,11),f(23, 8,12) / -1.0803000d-03 , -1.2037000d-03 /
      data f(23, 8,13),f(23, 8,14) / -1.2623000d-03 , -1.2442000d-03 /
      data f(23, 8,15),f(23, 8,16) / -1.1473000d-03 , -9.7820000d-04 /
      data f(23, 8,17),f(23, 8,18) / -7.5440000d-04 , -5.0910000d-04 /
      data f(23, 8,19),f(23, 8,20) / -2.8880000d-04 , -1.3990000d-04 /
      data f(23, 8,21),f(23, 8,22) / -1.3990000d-04 , -2.8880000d-04 /
      data f(23, 8,23) /             -5.0910000d-04 /
      data f(23, 9, 1),f(23, 9, 2) / -1.8430000d-04 , -1.3510000d-04 /
      data f(23, 9, 3),f(23, 9, 4) / -8.9200000d-05 , -8.9200000d-05 /
      data f(23, 9, 5),f(23, 9, 6) / -1.3510000d-04 , -1.8430000d-04 /
      data f(23, 9, 7),f(23, 9, 8) / -2.2870000d-04 , -2.7910000d-04 /
      data f(23, 9, 9),f(23, 9,10) / -3.4610000d-04 , -4.3000000d-04 /
      data f(23, 9,11),f(23, 9,12) / -5.2140000d-04 , -6.0590000d-04 /
      data f(23, 9,13),f(23, 9,14) / -6.6750000d-04 , -6.9290000d-04 /
      data f(23, 9,15),f(23, 9,16) / -6.7470000d-04 , -6.1310000d-04 /
      data f(23, 9,17),f(23, 9,18) / -5.1930000d-04 , -4.1580000d-04 /
      data f(23, 9,19),f(23, 9,20) / -3.3020000d-04 , -2.8110000d-04 /
      data f(23, 9,21),f(23, 9,22) / -2.8110000d-04 , -3.3020000d-04 /
      data f(23, 9,23) /             -4.1580000d-04 /
      data f(23,10, 1),f(23,10, 2) / -1.6060000d-04 , -5.3100000d-05 /
      data f(23,10, 3),f(23,10, 4) /  7.9900000d-05 ,  7.9900000d-05 /
      data f(23,10, 5),f(23,10, 6) / -5.3100000d-05 , -1.6060000d-04 /
      data f(23,10, 7),f(23,10, 8) / -2.0270000d-04 , -2.0530000d-04 /
      data f(23,10, 9),f(23,10,10) / -2.0960000d-04 , -2.3390000d-04 /
      data f(23,10,11),f(23,10,12) / -2.7720000d-04 , -3.2950000d-04 /
      data f(23,10,13),f(23,10,14) / -3.7810000d-04 , -4.1130000d-04 /
      data f(23,10,15),f(23,10,16) / -4.1950000d-04 , -3.9880000d-04 /
      data f(23,10,17),f(23,10,18) / -3.5500000d-04 , -3.0580000d-04 /
      data f(23,10,19),f(23,10,20) / -2.7280000d-04 , -2.6520000d-04 /
      data f(23,10,21),f(23,10,22) / -2.6520000d-04 , -2.7280000d-04 /
      data f(23,10,23) /             -3.0580000d-04 /
      data f(23,11, 1),f(23,11, 2) / -1.9100000d-04 ,  4.3500000d-05 /
      data f(23,11, 3),f(23,11, 4) /  3.3350000d-04 ,  3.3350000d-04 /
      data f(23,11, 5),f(23,11, 6) /  4.3500000d-05 , -1.9100000d-04 /
      data f(23,11, 7),f(23,11, 8) / -2.7690000d-04 , -2.5870000d-04 /
      data f(23,11, 9),f(23,11,10) / -2.1730000d-04 , -1.9720000d-04 /
      data f(23,11,11),f(23,11,12) / -2.0420000d-04 , -2.2700000d-04 /
      data f(23,11,13),f(23,11,14) / -2.5450000d-04 , -2.7830000d-04 /
      data f(23,11,15),f(23,11,16) / -2.9010000d-04 , -2.8290000d-04 /
      data f(23,11,17),f(23,11,18) / -2.5730000d-04 , -2.2670000d-04 /
      data f(23,11,19),f(23,11,20) / -2.1070000d-04 , -2.1670000d-04 /
      data f(23,11,21),f(23,11,22) / -2.1670000d-04 , -2.1070000d-04 /
      data f(23,11,23) /             -2.2670000d-04 /
      data f(23,12, 1),f(23,12, 2) / -2.2100000d-04 ,  1.6100000d-04 /
      data f(23,12, 3),f(23,12, 4) /  6.1720000d-04 ,  6.1720000d-04 /
      data f(23,12, 5),f(23,12, 6) /  1.6100000d-04 , -2.2100000d-04 /
      data f(23,12, 7),f(23,12, 8) / -3.7800000d-04 , -3.6270000d-04 /
      data f(23,12, 9),f(23,12,10) / -2.9170000d-04 , -2.3740000d-04 /
      data f(23,12,11),f(23,12,12) / -2.1370000d-04 , -2.0960000d-04 /
      data f(23,12,13),f(23,12,14) / -2.1530000d-04 , -2.2430000d-04 /
      data f(23,12,15),f(23,12,16) / -2.3030000d-04 , -2.2580000d-04 /
      data f(23,12,17),f(23,12,18) / -2.0780000d-04 , -1.8370000d-04 /
      data f(23,12,19),f(23,12,20) / -1.6890000d-04 , -1.7100000d-04 /
      data f(23,12,21),f(23,12,22) / -1.7100000d-04 , -1.6890000d-04 /
      data f(23,12,23) /             -1.8370000d-04 /
      data f(23,13, 1),f(23,13, 2) / -1.7160000d-04 ,  3.0650000d-04 /
      data f(23,13, 3),f(23,13, 4) /  8.4290000d-04 ,  8.4290000d-04 /
      data f(23,13, 5),f(23,13, 6) /  3.0650000d-04 , -1.7160000d-04 /
      data f(23,13, 7),f(23,13, 8) / -4.0520000d-04 , -4.2870000d-04 /
      data f(23,13, 9),f(23,13,10) / -3.6260000d-04 , -2.9440000d-04 /
      data f(23,13,11),f(23,13,12) / -2.5120000d-04 , -2.2840000d-04 /
      data f(23,13,13),f(23,13,14) / -2.1780000d-04 , -2.1460000d-04 /
      data f(23,13,15),f(23,13,16) / -2.1380000d-04 , -2.0860000d-04 /
      data f(23,13,17),f(23,13,18) / -1.9530000d-04 , -1.7660000d-04 /
      data f(23,13,19),f(23,13,20) / -1.6160000d-04 , -1.5670000d-04 /
      data f(23,13,21),f(23,13,22) / -1.5670000d-04 , -1.6160000d-04 /
      data f(23,13,23) /             -1.7660000d-04 /
      data f(23,14, 1),f(23,14, 2) / -3.5400000d-05 ,  4.2220000d-04 /
      data f(23,14, 3),f(23,14, 4) /  8.9230000d-04 ,  8.9230000d-04 /
      data f(23,14, 5),f(23,14, 6) /  4.2220000d-04 , -3.5400000d-05 /
      data f(23,14, 7),f(23,14, 8) / -3.0800000d-04 , -3.9230000d-04 /
      data f(23,14, 9),f(23,14,10) / -3.7170000d-04 , -3.2310000d-04 /
      data f(23,14,11),f(23,14,12) / -2.8220000d-04 , -2.5520000d-04 /
      data f(23,14,13),f(23,14,14) / -2.3940000d-04 , -2.3110000d-04 /
      data f(23,14,15),f(23,14,16) / -2.2650000d-04 , -2.2200000d-04 /
      data f(23,14,17),f(23,14,18) / -2.1410000d-04 , -2.0400000d-04 /
      data f(23,14,19),f(23,14,20) / -1.9540000d-04 , -1.9150000d-04 /
      data f(23,14,21),f(23,14,22) / -1.9150000d-04 , -1.9540000d-04 /
      data f(23,14,23) /             -2.0400000d-04 /
      data f(23,15, 1),f(23,15, 2) /  9.5900000d-05 ,  4.2720000d-04 /
      data f(23,15, 3),f(23,15, 4) /  7.3180000d-04 ,  7.3180000d-04 /
      data f(23,15, 5),f(23,15, 6) /  4.2720000d-04 ,  9.5900000d-05 /
      data f(23,15, 7),f(23,15, 8) / -1.4630000d-04 , -2.7040000d-04 /
      data f(23,15, 9),f(23,15,10) / -3.0810000d-04 , -3.0400000d-04 /
      data f(23,15,11),f(23,15,12) / -2.8830000d-04 , -2.7400000d-04 /
      data f(23,15,13),f(23,15,14) / -2.6410000d-04 , -2.5860000d-04 /
      data f(23,15,15),f(23,15,16) / -2.5600000d-04 , -2.5450000d-04 /
      data f(23,15,17),f(23,15,18) / -2.5310000d-04 , -2.5200000d-04 /
      data f(23,15,19),f(23,15,20) / -2.5220000d-04 , -2.5340000d-04 /
      data f(23,15,21),f(23,15,22) / -2.5340000d-04 , -2.5220000d-04 /
      data f(23,15,23) /             -2.5200000d-04 /
      data f(23,16, 1),f(23,16, 2) /  1.2160000d-04 ,  3.0120000d-04 /
      data f(23,16, 3),f(23,16, 4) /  4.4750000d-04 ,  4.4750000d-04 /
      data f(23,16, 5),f(23,16, 6) /  3.0120000d-04 ,  1.2160000d-04 /
      data f(23,16, 7),f(23,16, 8) / -3.8400000d-05 , -1.5200000d-04 /
      data f(23,16, 9),f(23,16,10) / -2.1910000d-04 , -2.5320000d-04 /
      data f(23,16,11),f(23,16,12) / -2.6860000d-04 , -2.7560000d-04 /
      data f(23,16,13),f(23,16,14) / -2.7950000d-04 , -2.8260000d-04 /
      data f(23,16,15),f(23,16,16) / -2.8600000d-04 , -2.8970000d-04 /
      data f(23,16,17),f(23,16,18) / -2.9370000d-04 , -2.9790000d-04 /
      data f(23,16,19),f(23,16,20) / -3.0190000d-04 , -3.0540000d-04 /
      data f(23,16,21),f(23,16,22) / -3.0540000d-04 , -3.0190000d-04 /
      data f(23,16,23) /             -2.9790000d-04 /
      data f(23,17, 1),f(23,17, 2) /  2.8400000d-05 ,  9.9300000d-05 /
      data f(23,17, 3),f(23,17, 4) /  1.5100000d-04 ,  1.5100000d-04 /
      data f(23,17, 5),f(23,17, 6) /  9.9300000d-05 ,  2.8400000d-05 /
      data f(23,17, 7),f(23,17, 8) / -4.6700000d-05 , -1.1450000d-04 /
      data f(23,17, 9),f(23,17,10) / -1.6930000d-04 , -2.1040000d-04 /
      data f(23,17,11),f(23,17,12) / -2.4020000d-04 , -2.6170000d-04 /
      data f(23,17,13),f(23,17,14) / -2.7760000d-04 , -2.8990000d-04 /
      data f(23,17,15),f(23,17,16) / -2.9980000d-04 , -3.0820000d-04 /
      data f(23,17,17),f(23,17,18) / -3.1550000d-04 , -3.2160000d-04 /
      data f(23,17,19),f(23,17,20) / -3.2630000d-04 , -3.2930000d-04 /
      data f(23,17,21),f(23,17,22) / -3.2930000d-04 , -3.2630000d-04 /
      data f(23,17,23) /             -3.2160000d-04 /
      data f(23,18, 1),f(23,18, 2) / -1.1480000d-04 , -9.6900000d-05 /
      data f(23,18, 3),f(23,18, 4) / -8.5100000d-05 , -8.5100000d-05 /
      data f(23,18, 5),f(23,18, 6) / -9.6900000d-05 , -1.1480000d-04 /
      data f(23,18, 7),f(23,18, 8) / -1.3680000d-04 , -1.6050000d-04 /
      data f(23,18, 9),f(23,18,10) / -1.8420000d-04 , -2.0650000d-04 /
      data f(23,18,11),f(23,18,12) / -2.2670000d-04 , -2.4450000d-04 /
      data f(23,18,13),f(23,18,14) / -2.5980000d-04 , -2.7280000d-04 /
      data f(23,18,15),f(23,18,16) / -2.8370000d-04 , -2.9280000d-04 /
      data f(23,18,17),f(23,18,18) / -3.0010000d-04 , -3.0570000d-04 /
      data f(23,18,19),f(23,18,20) / -3.0970000d-04 , -3.1220000d-04 /
      data f(23,18,21),f(23,18,22) / -3.1220000d-04 , -3.0970000d-04 /
      data f(23,18,23) /             -3.0570000d-04 /
      data f(23,19, 1),f(23,19, 2) / -2.3700000d-04 , -2.3700000d-04 /
      data f(23,19, 3),f(23,19, 4) / -2.3700000d-04 , -2.3700000d-04 /
      data f(23,19, 5),f(23,19, 6) / -2.3700000d-04 , -2.3700000d-04 /
      data f(23,19, 7),f(23,19, 8) / -2.3700000d-04 , -2.3700000d-04 /
      data f(23,19, 9),f(23,19,10) / -2.3700000d-04 , -2.3700000d-04 /
      data f(23,19,11),f(23,19,12) / -2.3700000d-04 , -2.3700000d-04 /
      data f(23,19,13),f(23,19,14) / -2.3700000d-04 , -2.3700000d-04 /
      data f(23,19,15),f(23,19,16) / -2.3700000d-04 , -2.3700000d-04 /
      data f(23,19,17),f(23,19,18) / -2.3700000d-04 , -2.3700000d-04 /
      data f(23,19,19),f(23,19,20) / -2.3700000d-04 , -2.3700000d-04 /
      data f(23,19,21),f(23,19,22) / -2.3700000d-04 , -2.3700000d-04 /
      data f(23,19,23) /             -2.3700000d-04 /
      data f(24, 1, 1),f(24, 1, 2) /  4.3889000d-03 ,  4.3889000d-03 /
      data f(24, 1, 3),f(24, 1, 4) /  4.3889000d-03 ,  4.3889000d-03 /
      data f(24, 1, 5),f(24, 1, 6) /  4.3889000d-03 ,  4.3889000d-03 /
      data f(24, 1, 7),f(24, 1, 8) /  4.3889000d-03 ,  4.3889000d-03 /
      data f(24, 1, 9),f(24, 1,10) /  4.3889000d-03 ,  4.3889000d-03 /
      data f(24, 1,11),f(24, 1,12) /  4.3889000d-03 ,  4.3889000d-03 /
      data f(24, 1,13),f(24, 1,14) /  4.3889000d-03 ,  4.3889000d-03 /
      data f(24, 1,15),f(24, 1,16) /  4.3889000d-03 ,  4.3889000d-03 /
      data f(24, 1,17),f(24, 1,18) /  4.3889000d-03 ,  4.3889000d-03 /
      data f(24, 1,19),f(24, 1,20) /  4.3889000d-03 ,  4.3889000d-03 /
      data f(24, 1,21),f(24, 1,22) /  4.3889000d-03 ,  4.3889000d-03 /
      data f(24, 1,23) /              4.3889000d-03 /
      data f(24, 2, 1),f(24, 2, 2) /  4.2880000d-03 ,  4.6207000d-03 /
      data f(24, 2, 3),f(24, 2, 4) /  4.8399000d-03 ,  4.8399000d-03 /
      data f(24, 2, 5),f(24, 2, 6) /  4.6207000d-03 ,  4.2880000d-03 /
      data f(24, 2, 7),f(24, 2, 8) /  3.8850000d-03 ,  3.4622000d-03 /
      data f(24, 2, 9),f(24, 2,10) /  3.0702000d-03 ,  2.7541000d-03 /
      data f(24, 2,11),f(24, 2,12) /  2.5485000d-03 ,  2.4757000d-03 /
      data f(24, 2,13),f(24, 2,14) /  2.5436000d-03 ,  2.7457000d-03 /
      data f(24, 2,15),f(24, 2,16) /  3.0610000d-03 ,  3.4551000d-03 /
      data f(24, 2,17),f(24, 2,18) /  3.8829000d-03 ,  4.2925000d-03 /
      data f(24, 2,19),f(24, 2,20) /  4.6318000d-03 ,  4.8558000d-03 /
      data f(24, 2,21),f(24, 2,22) /  4.8558000d-03 ,  4.6318000d-03 /
      data f(24, 2,23) /              4.2925000d-03 /
      data f(24, 3, 1),f(24, 3, 2) /  3.6509000d-03 ,  4.5806000d-03 /
      data f(24, 3, 3),f(24, 3, 4) /  5.2038000d-03 ,  5.2038000d-03 /
      data f(24, 3, 5),f(24, 3, 6) /  4.5806000d-03 ,  3.6509000d-03 /
      data f(24, 3, 7),f(24, 3, 8) /  2.5570000d-03 ,  1.4488000d-03 /
      data f(24, 3, 9),f(24, 3,10) /  4.5560000d-04 , -3.2510000d-04 /
      data f(24, 3,11),f(24, 3,12) / -8.2720000d-04 , -1.0114000d-03 /
      data f(24, 3,13),f(24, 3,14) / -8.6200000d-04 , -3.8680000d-04 /
      data f(24, 3,15),f(24, 3,16) /  3.8120000d-04 ,  1.3791000d-03 /
      data f(24, 3,17),f(24, 3,18) /  2.5090000d-03 ,  3.6365000d-03 /
      data f(24, 3,19),f(24, 3,20) /  4.6026000d-03 ,  5.2539000d-03 /
      data f(24, 3,21),f(24, 3,22) /  5.2539000d-03 ,  4.6026000d-03 /
      data f(24, 3,23) /              3.6365000d-03 /
      data f(24, 4, 1),f(24, 4, 2) /  2.2775000d-03 ,  3.4009000d-03 /
      data f(24, 4, 3),f(24, 4, 4) /  4.1662000d-03 ,  4.1662000d-03 /
      data f(24, 4, 5),f(24, 4, 6) /  3.4009000d-03 ,  2.2775000d-03 /
      data f(24, 4, 7),f(24, 4, 8) /  9.9210000d-04 , -2.6910000d-04 /
      data f(24, 4, 9),f(24, 4,10) / -1.3676000d-03 , -2.2145000d-03 /
      data f(24, 4,11),f(24, 4,12) / -2.7572000d-03 , -2.9665000d-03 /
      data f(24, 4,13),f(24, 4,14) / -2.8285000d-03 , -2.3430000d-03 /
      data f(24, 4,15),f(24, 4,16) / -1.5268000d-03 , -4.2500000d-04 /
      data f(24, 4,17),f(24, 4,18) /  8.7470000d-04 ,  2.2257000d-03 /
      data f(24, 4,19),f(24, 4,20) /  3.4241000d-03 ,  4.2479000d-03 /
      data f(24, 4,21),f(24, 4,22) /  4.2479000d-03 ,  3.4241000d-03 /
      data f(24, 4,23) /              2.2257000d-03 /
      data f(24, 5, 1),f(24, 5, 2) /  8.6390000d-04 ,  1.7073000d-03 /
      data f(24, 5, 3),f(24, 5, 4) /  2.2951000d-03 ,  2.2951000d-03 /
      data f(24, 5, 5),f(24, 5, 6) /  1.7073000d-03 ,  8.6390000d-04 /
      data f(24, 5, 7),f(24, 5, 8) / -8.2200000d-05 , -9.9870000d-04 /
      data f(24, 5, 9),f(24, 5,10) / -1.7927000d-03 , -2.4065000d-03 /
      data f(24, 5,11),f(24, 5,12) / -2.8073000d-03 , -2.9763000d-03 /
      data f(24, 5,13),f(24, 5,14) / -2.9017000d-03 , -2.5781000d-03 /
      data f(24, 5,15),f(24, 5,16) / -2.0090000d-03 , -1.2165000d-03 /
      data f(24, 5,17),f(24, 5,18) / -2.5560000d-04 ,  7.7140000d-04 /
      data f(24, 5,19),f(24, 5,20) /  1.7095000d-03 ,  2.3730000d-03 /
      data f(24, 5,21),f(24, 5,22) /  2.3730000d-03 ,  1.7095000d-03 /
      data f(24, 5,23) /              7.7140000d-04 /
      data f(24, 6, 1),f(24, 6, 2) /  3.1300000d-05 ,  4.7610000d-04 /
      data f(24, 6, 3),f(24, 6, 4) /  7.8260000d-04 ,  7.8260000d-04 /
      data f(24, 6, 5),f(24, 6, 6) /  4.7610000d-04 ,  3.1300000d-05 /
      data f(24, 6, 7),f(24, 6, 8) / -4.7130000d-04 , -9.6330000d-04 /
      data f(24, 6, 9),f(24, 6,10) / -1.4001000d-03 , -1.7536000d-03 /
      data f(24, 6,11),f(24, 6,12) / -2.0013000d-03 , -2.1230000d-03 /
      data f(24, 6,13),f(24, 6,14) / -2.1045000d-03 , -1.9419000d-03 /
      data f(24, 6,15),f(24, 6,16) / -1.6393000d-03 , -1.2082000d-03 /
      data f(24, 6,17),f(24, 6,18) / -6.7470000d-04 , -9.2900000d-05 /
      data f(24, 6,19),f(24, 6,20) /  4.4620000d-04 ,  8.2890000d-04 /
      data f(24, 6,21),f(24, 6,22) /  8.2890000d-04 ,  4.4620000d-04 /
      data f(24, 6,23) /             -9.2900000d-05 /
      data f(24, 7, 1),f(24, 7, 2) / -2.5500000d-04 , -8.9900000d-05 /
      data f(24, 7, 3),f(24, 7, 4) /  1.7500000d-05 ,  1.7500000d-05 /
      data f(24, 7, 5),f(24, 7, 6) / -8.9900000d-05 , -2.5500000d-04 /
      data f(24, 7, 7),f(24, 7, 8) / -4.5330000d-04 , -6.6110000d-04 /
      data f(24, 7, 9),f(24, 7,10) / -8.6100000d-04 , -1.0395000d-03 /
      data f(24, 7,11),f(24, 7,12) / -1.1805000d-03 , -1.2658000d-03 /
      data f(24, 7,13),f(24, 7,14) / -1.2812000d-03 , -1.2227000d-03 /
      data f(24, 7,15),f(24, 7,16) / -1.0937000d-03 , -9.0040000d-04 /
      data f(24, 7,17),f(24, 7,18) / -6.5600000d-04 , -3.8800000d-04 /
      data f(24, 7,19),f(24, 7,20) / -1.4180000d-04 ,  2.9600000d-05 /
      data f(24, 7,21),f(24, 7,22) /  2.9600000d-05 , -1.4180000d-04 /
      data f(24, 7,23) /             -3.8800000d-04 /
      data f(24, 8, 1),f(24, 8, 2) / -2.7520000d-04 , -2.3890000d-04 /
      data f(24, 8, 3),f(24, 8, 4) / -2.2010000d-04 , -2.2010000d-04 /
      data f(24, 8, 5),f(24, 8, 6) / -2.3890000d-04 , -2.7520000d-04 /
      data f(24, 8, 7),f(24, 8, 8) / -3.2920000d-04 , -3.9820000d-04 /
      data f(24, 8, 9),f(24, 8,10) / -4.7760000d-04 , -5.6100000d-04 /
      data f(24, 8,11),f(24, 8,12) / -6.3870000d-04 , -6.9780000d-04 /
      data f(24, 8,13),f(24, 8,14) / -7.2710000d-04 , -7.2100000d-04 /
      data f(24, 8,15),f(24, 8,16) / -6.7860000d-04 , -6.0260000d-04 /
      data f(24, 8,17),f(24, 8,18) / -5.0140000d-04 , -3.9220000d-04 /
      data f(24, 8,19),f(24, 8,20) / -2.9800000d-04 , -2.3820000d-04 /
      data f(24, 8,21),f(24, 8,22) / -2.3820000d-04 , -2.9800000d-04 /
      data f(24, 8,23) /             -3.9220000d-04 /
      data f(24, 9, 1),f(24, 9, 2) / -2.4150000d-04 , -2.3490000d-04 /
      data f(24, 9, 3),f(24, 9, 4) / -2.2740000d-04 , -2.2740000d-04 /
      data f(24, 9, 5),f(24, 9, 6) / -2.3490000d-04 , -2.4150000d-04 /
      data f(24, 9, 7),f(24, 9, 8) / -2.4720000d-04 , -2.5830000d-04 /
      data f(24, 9, 9),f(24, 9,10) / -2.8060000d-04 , -3.1440000d-04 /
      data f(24, 9,11),f(24, 9,12) / -3.5520000d-04 , -3.9480000d-04 /
      data f(24, 9,13),f(24, 9,14) / -4.2450000d-04 , -4.3770000d-04 /
      data f(24, 9,15),f(24, 9,16) / -4.3060000d-04 , -4.0360000d-04 /
      data f(24, 9,17),f(24, 9,18) / -3.6270000d-04 , -3.2070000d-04 /
      data f(24, 9,19),f(24, 9,20) / -2.9130000d-04 , -2.7990000d-04 /
      data f(24, 9,21),f(24, 9,22) / -2.7990000d-04 , -2.9130000d-04 /
      data f(24, 9,23) /             -3.2070000d-04 /
      data f(24,10, 1),f(24,10, 2) / -2.3820000d-04 , -2.1060000d-04 /
      data f(24,10, 3),f(24,10, 4) / -1.6890000d-04 , -1.6890000d-04 /
      data f(24,10, 5),f(24,10, 6) / -2.1060000d-04 , -2.3820000d-04 /
      data f(24,10, 7),f(24,10, 8) / -2.3840000d-04 , -2.2440000d-04 /
      data f(24,10, 9),f(24,10,10) / -2.1440000d-04 , -2.1760000d-04 /
      data f(24,10,11),f(24,10,12) / -2.3340000d-04 , -2.5640000d-04 /
      data f(24,10,13),f(24,10,14) / -2.7900000d-04 , -2.9480000d-04 /
      data f(24,10,15),f(24,10,16) / -2.9960000d-04 , -2.9140000d-04 /
      data f(24,10,17),f(24,10,18) / -2.7410000d-04 , -2.5820000d-04 /
      data f(24,10,19),f(24,10,20) / -2.5520000d-04 , -2.6520000d-04 /
      data f(24,10,21),f(24,10,22) / -2.6520000d-04 , -2.5520000d-04 /
      data f(24,10,23) /             -2.5820000d-04 /
      data f(24,11, 1),f(24,11, 2) / -2.7100000d-04 , -1.9530000d-04 /
      data f(24,11, 3),f(24,11, 4) / -9.3200000d-05 , -9.3200000d-05 /
      data f(24,11, 5),f(24,11, 6) / -1.9530000d-04 , -2.7100000d-04 /
      data f(24,11, 7),f(24,11, 8) / -2.8440000d-04 , -2.5620000d-04 /
      data f(24,11, 9),f(24,11,10) / -2.2210000d-04 , -2.0200000d-04 /
      data f(24,11,11),f(24,11,12) / -1.9830000d-04 , -2.0540000d-04 /
      data f(24,11,13),f(24,11,14) / -2.1650000d-04 , -2.2700000d-04 /
      data f(24,11,15),f(24,11,16) / -2.3350000d-04 , -2.3260000d-04 /
      data f(24,11,17),f(24,11,18) / -2.2490000d-04 , -2.1890000d-04 /
      data f(24,11,19),f(24,11,20) / -2.2510000d-04 , -2.4250000d-04 /
      data f(24,11,21),f(24,11,22) / -2.4250000d-04 , -2.2510000d-04 /
      data f(24,11,23) /             -2.1890000d-04 /
      data f(24,12, 1),f(24,12, 2) / -3.0520000d-04 , -1.7190000d-04 /
      data f(24,12, 3),f(24,12, 4) / -4.6000000d-06 , -4.6000000d-06 /
      data f(24,12, 5),f(24,12, 6) / -1.7190000d-04 , -3.0520000d-04 /
      data f(24,12, 7),f(24,12, 8) / -3.4450000d-04 , -3.1350000d-04 /
      data f(24,12, 9),f(24,12,10) / -2.6320000d-04 , -2.2520000d-04 /
      data f(24,12,11),f(24,12,12) / -2.0470000d-04 , -1.9620000d-04 /
      data f(24,12,13),f(24,12,14) / -1.9480000d-04 , -1.9720000d-04 /
      data f(24,12,15),f(24,12,16) / -2.0130000d-04 , -2.0280000d-04 /
      data f(24,12,17),f(24,12,18) / -1.9980000d-04 , -1.9710000d-04 /
      data f(24,12,19),f(24,12,20) / -2.0290000d-04 , -2.1690000d-04 /
      data f(24,12,21),f(24,12,22) / -2.1690000d-04 , -2.0290000d-04 /
      data f(24,12,23) /             -1.9710000d-04 /
      data f(24,13, 1),f(24,13, 2) / -2.9960000d-04 , -1.2720000d-04 /
      data f(24,13, 3),f(24,13, 4) /  7.2900000d-05 ,  7.2900000d-05 /
      data f(24,13, 5),f(24,13, 6) / -1.2720000d-04 , -2.9960000d-04 /
      data f(24,13, 7),f(24,13, 8) / -3.6990000d-04 , -3.5370000d-04 /
      data f(24,13, 9),f(24,13,10) / -3.0350000d-04 , -2.5690000d-04 /
      data f(24,13,11),f(24,13,12) / -2.2470000d-04 , -2.0470000d-04 /
      data f(24,13,13),f(24,13,14) / -1.9310000d-04 , -1.8890000d-04 /
      data f(24,13,15),f(24,13,16) / -1.9010000d-04 , -1.9240000d-04 /
      data f(24,13,17),f(24,13,18) / -1.9280000d-04 , -1.9260000d-04 /
      data f(24,13,19),f(24,13,20) / -1.9590000d-04 , -2.0340000d-04 /
      data f(24,13,21),f(24,13,22) / -2.0340000d-04 , -1.9590000d-04 /
      data f(24,13,23) /             -1.9260000d-04 /
      data f(24,14, 1),f(24,14, 2) / -2.4540000d-04 , -7.9100000d-05 /
      data f(24,14, 3),f(24,14, 4) /  9.6700000d-05 ,  9.6700000d-05 /
      data f(24,14, 5),f(24,14, 6) / -7.9100000d-05 , -2.4540000d-04 /
      data f(24,14, 7),f(24,14, 8) / -3.3380000d-04 , -3.4450000d-04 /
      data f(24,14, 9),f(24,14,10) / -3.1370000d-04 , -2.7450000d-04 /
      data f(24,14,11),f(24,14,12) / -2.4160000d-04 , -2.1780000d-04 /
      data f(24,14,13),f(24,14,14) / -2.0260000d-04 , -1.9540000d-04 /
      data f(24,14,15),f(24,14,16) / -1.9440000d-04 , -1.9750000d-04 /
      data f(24,14,17),f(24,14,18) / -2.0100000d-04 , -2.0490000d-04 /
      data f(24,14,19),f(24,14,20) / -2.0970000d-04 , -2.1510000d-04 /
      data f(24,14,21),f(24,14,22) / -2.1510000d-04 , -2.0970000d-04 /
      data f(24,14,23) /             -2.0490000d-04 /
      data f(24,15, 1),f(24,15, 2) / -1.7870000d-04 , -5.9600000d-05 /
      data f(24,15, 3),f(24,15, 4) /  5.3100000d-05 ,  5.3100000d-05 /
      data f(24,15, 5),f(24,15, 6) / -5.9600000d-05 , -1.7870000d-04 /
      data f(24,15, 7),f(24,15, 8) / -2.5920000d-04 , -2.9070000d-04 /
      data f(24,15, 9),f(24,15,10) / -2.8730000d-04 , -2.6850000d-04 /
      data f(24,15,11),f(24,15,12) / -2.4710000d-04 , -2.2910000d-04 /
      data f(24,15,13),f(24,15,14) / -2.1650000d-04 , -2.1000000d-04 /
      data f(24,15,15),f(24,15,16) / -2.0910000d-04 , -2.1240000d-04 /
      data f(24,15,17),f(24,15,18) / -2.1830000d-04 , -2.2570000d-04 /
      data f(24,15,19),f(24,15,20) / -2.3330000d-04 , -2.3940000d-04 /
      data f(24,15,21),f(24,15,22) / -2.3940000d-04 , -2.3330000d-04 /
      data f(24,15,23) /             -2.2570000d-04 /
      data f(24,16, 1),f(24,16, 2) / -1.4550000d-04 , -8.2700000d-05 /
      data f(24,16, 3),f(24,16, 4) / -2.9900000d-05 , -2.9900000d-05 /
      data f(24,16, 5),f(24,16, 6) / -8.2700000d-05 , -1.4550000d-04 /
      data f(24,16, 7),f(24,16, 8) / -1.9840000d-04 , -2.3130000d-04 /
      data f(24,16, 9),f(24,16,10) / -2.4530000d-04 , -2.4640000d-04 /
      data f(24,16,11),f(24,16,12) / -2.4110000d-04 , -2.3440000d-04 /
      data f(24,16,13),f(24,16,14) / -2.2890000d-04 , -2.2630000d-04 /
      data f(24,16,15),f(24,16,16) / -2.2690000d-04 , -2.2720000d-04 /
      data f(24,16,17),f(24,16,18) / -2.3630000d-04 , -2.4320000d-04 /
      data f(24,16,19),f(24,16,20) / -2.5010000d-04 , -2.5530000d-04 /
      data f(24,16,21),f(24,16,22) / -2.5530000d-04 , -2.5010000d-04 /
      data f(24,16,23) /             -2.4320000d-04 /
      data f(24,17, 1),f(24,17, 2) / -1.5840000d-04 , -1.3480000d-04 /
      data f(24,17, 3),f(24,17, 4) / -1.1710000d-04 , -1.1710000d-04 /
      data f(24,17, 5),f(24,17, 6) / -1.3480000d-04 , -1.5840000d-04 /
      data f(24,17, 7),f(24,17, 8) / -1.8240000d-04 , -2.0250000d-04 /
      data f(24,17, 9),f(24,17,10) / -2.1700000d-04 , -2.2610000d-04 /
      data f(24,17,11),f(24,17,12) / -2.3110000d-04 , -2.3370000d-04 /
      data f(24,17,13),f(24,17,14) / -2.3540000d-04 , -2.3720000d-04 /
      data f(24,17,15),f(24,17,16) / -2.3980000d-04 , -2.4320000d-04 /
      data f(24,17,17),f(24,17,18) / -2.4740000d-04 , -2.5170000d-04 /
      data f(24,17,19),f(24,17,20) / -2.5560000d-04 , -2.5840000d-04 /
      data f(24,17,21),f(24,17,22) / -2.5840000d-04 , -2.5560000d-04 /
      data f(24,17,23) /             -2.5170000d-04 /
      data f(24,18, 1),f(24,18, 2) / -1.9530000d-04 , -1.8980000d-04 /
      data f(24,18, 3),f(24,18, 4) / -1.8600000d-04 , -1.8600000d-04 /
      data f(24,18, 5),f(24,18, 6) / -1.8980000d-04 , -1.9530000d-04 /
      data f(24,18, 7),f(24,18, 8) / -2.0180000d-04 , -2.0860000d-04 /
      data f(24,18, 9),f(24,18,10) / -2.1510000d-04 , -2.2110000d-04 /
      data f(24,18,11),f(24,18,12) / -2.2630000d-04 , -2.3070000d-04 /
      data f(24,18,13),f(24,18,14) / -2.3450000d-04 , -2.3790000d-04 /
      data f(24,18,15),f(24,18,16) / -2.4090000d-04 , -2.4360000d-04 /
      data f(24,18,17),f(24,18,18) / -2.4600000d-04 , -2.4800000d-04 /
      data f(24,18,19),f(24,18,20) / -2.4960000d-04 , -2.5070000d-04 /
      data f(24,18,21),f(24,18,22) / -2.5070000d-04 , -2.4960000d-04 /
      data f(24,18,23) /             -2.4800000d-04 /
      data f(24,19, 1),f(24,19, 2) / -2.2940000d-04 , -2.2940000d-04 /
      data f(24,19, 3),f(24,19, 4) / -2.2940000d-04 , -2.2940000d-04 /
      data f(24,19, 5),f(24,19, 6) / -2.2940000d-04 , -2.2940000d-04 /
      data f(24,19, 7),f(24,19, 8) / -2.2940000d-04 , -2.2940000d-04 /
      data f(24,19, 9),f(24,19,10) / -2.2940000d-04 , -2.2940000d-04 /
      data f(24,19,11),f(24,19,12) / -2.2940000d-04 , -2.2940000d-04 /
      data f(24,19,13),f(24,19,14) / -2.2940000d-04 , -2.2940000d-04 /
      data f(24,19,15),f(24,19,16) / -2.2940000d-04 , -2.2940000d-04 /
      data f(24,19,17),f(24,19,18) / -2.2940000d-04 , -2.2940000d-04 /
      data f(24,19,19),f(24,19,20) / -2.2940000d-04 , -2.2940000d-04 /
      data f(24,19,21),f(24,19,22) / -2.2940000d-04 , -2.2940000d-04 /
      data f(24,19,23) /             -2.2940000d-04 /
      data f(25, 1, 1),f(25, 1, 2) /  3.9820000d-04 ,  3.9820000d-04 /
      data f(25, 1, 3),f(25, 1, 4) /  3.9820000d-04 ,  3.9820000d-04 /
      data f(25, 1, 5),f(25, 1, 6) /  3.9820000d-04 ,  3.9820000d-04 /
      data f(25, 1, 7),f(25, 1, 8) /  3.9820000d-04 ,  3.9820000d-04 /
      data f(25, 1, 9),f(25, 1,10) /  3.9820000d-04 ,  3.9820000d-04 /
      data f(25, 1,11),f(25, 1,12) /  3.9820000d-04 ,  3.9820000d-04 /
      data f(25, 1,13),f(25, 1,14) /  3.9820000d-04 ,  3.9820000d-04 /
      data f(25, 1,15),f(25, 1,16) /  3.9820000d-04 ,  3.9820000d-04 /
      data f(25, 1,17),f(25, 1,18) /  3.9820000d-04 ,  3.9820000d-04 /
      data f(25, 1,19),f(25, 1,20) /  3.9820000d-04 ,  3.9820000d-04 /
      data f(25, 1,21),f(25, 1,22) /  3.9820000d-04 ,  3.9820000d-04 /
      data f(25, 1,23) /              3.9820000d-04 /
      data f(25, 2, 1),f(25, 2, 2) /  4.0550000d-04 ,  4.6760000d-04 /
      data f(25, 2, 3),f(25, 2, 4) /  5.0820000d-04 ,  5.0820000d-04 /
      data f(25, 2, 5),f(25, 2, 6) /  4.6760000d-04 ,  4.0550000d-04 /
      data f(25, 2, 7),f(25, 2, 8) /  3.2970000d-04 ,  2.4930000d-04 /
      data f(25, 2, 9),f(25, 2,10) /  1.7400000d-04 ,  1.1270000d-04 /
      data f(25, 2,11),f(25, 2,12) /  7.2400000d-05 ,  5.7600000d-05 /
      data f(25, 2,13),f(25, 2,14) /  7.0200000d-05 ,  1.0870000d-04 /
      data f(25, 2,15),f(25, 2,16) /  1.6900000d-04 ,  2.4400000d-04 /
      data f(25, 2,17),f(25, 2,18) /  3.2480000d-04 ,  4.0160000d-04 /
      data f(25, 2,19),f(25, 2,20) /  4.6480000d-04 ,  5.0620000d-04 /
      data f(25, 2,21),f(25, 2,22) /  5.0620000d-04 ,  4.6480000d-04 /
      data f(25, 2,23) /              4.0160000d-04 /
      data f(25, 3, 1),f(25, 3, 2) /  3.1900000d-04 ,  4.8660000d-04 /
      data f(25, 3, 3),f(25, 3, 4) /  5.9610000d-04 ,  5.9610000d-04 /
      data f(25, 3, 5),f(25, 3, 6) /  4.8660000d-04 ,  3.1900000d-04 /
      data f(25, 3, 7),f(25, 3, 8) /  1.1570000d-04 , -9.6200000d-05 /
      data f(25, 3, 9),f(25, 3,10) / -2.9030000d-04 , -4.4530000d-04 /
      data f(25, 3,11),f(25, 3,12) / -5.4600000d-04 , -5.8350000d-04 /
      data f(25, 3,13),f(25, 3,14) / -5.5400000d-04 , -4.5930000d-04 /
      data f(25, 3,15),f(25, 3,16) / -3.0670000d-04 , -1.1050000d-04 /
      data f(25, 3,17),f(25, 3,18) /  1.0750000d-04 ,  3.1960000d-04 /
      data f(25, 3,19),f(25, 3,20) /  4.9600000d-04 ,  6.1210000d-04 /
      data f(25, 3,21),f(25, 3,22) /  6.1210000d-04 ,  4.9600000d-04 /
      data f(25, 3,23) /              3.1960000d-04 /
      data f(25, 4, 1),f(25, 4, 2) /  9.1800000d-05 ,  2.9700000d-04 /
      data f(25, 4, 3),f(25, 4, 4) /  4.3320000d-04 ,  4.3320000d-04 /
      data f(25, 4, 5),f(25, 4, 6) /  2.9700000d-04 ,  9.1800000d-05 /
      data f(25, 4, 7),f(25, 4, 8) / -1.5020000d-04 , -3.9420000d-04 /
      data f(25, 4, 9),f(25, 4,10) / -6.1110000d-04 , -7.8090000d-04 /
      data f(25, 4,11),f(25, 4,12) / -8.9110000d-04 , -9.3430000d-04 /
      data f(25, 4,13),f(25, 4,14) / -9.0730000d-04 , -8.0960000d-04 /
      data f(25, 4,15),f(25, 4,16) / -6.4550000d-04 , -4.2560000d-04 /
      data f(25, 4,17),f(25, 4,18) / -1.7040000d-04 ,  8.8500000d-05 /
      data f(25, 4,19),f(25, 4,20) /  3.1110000d-04 ,  4.5960000d-04 /
      data f(25, 4,21),f(25, 4,22) /  4.5960000d-04 ,  3.1110000d-04 /
      data f(25, 4,23) /              8.8500000d-05 /
      data f(25, 5, 1),f(25, 5, 2) / -1.3410000d-04 ,  2.6800000d-05 /
      data f(25, 5, 3),f(25, 5, 4) /  1.3810000d-04 ,  1.3810000d-04 /
      data f(25, 5, 5),f(25, 5, 6) /  2.6800000d-05 , -1.3410000d-04 /
      data f(25, 5, 7),f(25, 5, 8) / -3.1500000d-04 , -4.9010000d-04 /
      data f(25, 5, 9),f(25, 5,10) / -6.4290000d-04 , -7.6330000d-04 /
      data f(25, 5,11),f(25, 5,12) / -8.4410000d-04 , -8.7940000d-04 /
      data f(25, 5,13),f(25, 5,14) / -8.6570000d-04 , -8.0250000d-04 /
      data f(25, 5,15),f(25, 5,16) / -6.9150000d-04 , -5.3730000d-04 /
      data f(25, 5,17),f(25, 5,18) / -3.5010000d-04 , -1.4970000d-04 /
      data f(25, 5,19),f(25, 5,20) /  3.2200000d-05 ,  1.5860000d-04 /
      data f(25, 5,21),f(25, 5,22) /  1.5860000d-04 ,  3.2200000d-05 /
      data f(25, 5,23) /             -1.4970000d-04 /
      data f(25, 6, 1),f(25, 6, 2) / -2.3990000d-04 , -1.5960000d-04 /
      data f(25, 6, 3),f(25, 6, 4) / -1.0520000d-04 , -1.0520000d-04 /
      data f(25, 6, 5),f(25, 6, 6) / -1.5960000d-04 , -2.3990000d-04 /
      data f(25, 6, 7),f(25, 6, 8) / -3.3110000d-04 , -4.2050000d-04 /
      data f(25, 6, 9),f(25, 6,10) / -5.0080000d-04 , -5.6770000d-04 /
      data f(25, 6,11),f(25, 6,12) / -6.1680000d-04 , -6.4220000d-04 /
      data f(25, 6,13),f(25, 6,14) / -6.4020000d-04 , -6.1050000d-04 /
      data f(25, 6,15),f(25, 6,16) / -5.5480000d-04 , -4.7440000d-04 /
      data f(25, 6,17),f(25, 6,18) / -3.7340000d-04 , -2.6230000d-04 /
      data f(25, 6,19),f(25, 6,20) / -1.6040000d-04 , -8.9800000d-05 /
      data f(25, 6,21),f(25, 6,22) / -8.9800000d-05 , -1.6040000d-04 /
      data f(25, 6,23) /             -2.6230000d-04 /
      data f(25, 7, 1),f(25, 7, 2) / -2.3890000d-04 , -2.1970000d-04 /
      data f(25, 7, 3),f(25, 7, 4) / -2.1080000d-04 , -2.1080000d-04 /
      data f(25, 7, 5),f(25, 7, 6) / -2.1970000d-04 , -2.3890000d-04 /
      data f(25, 7, 7),f(25, 7, 8) / -2.6730000d-04 , -3.0090000d-04 /
      data f(25, 7, 9),f(25, 7,10) / -3.3640000d-04 , -3.7070000d-04 /
      data f(25, 7,11),f(25, 7,12) / -3.9970000d-04 , -4.1790000d-04 /
      data f(25, 7,13),f(25, 7,14) / -4.2180000d-04 , -4.1150000d-04 /
      data f(25, 7,15),f(25, 7,16) / -3.8820000d-04 , -3.5280000d-04 /
      data f(25, 7,17),f(25, 7,18) / -3.0790000d-04 , -2.6020000d-04 /
      data f(25, 7,19),f(25, 7,20) / -2.2000000d-04 , -1.9560000d-04 /
      data f(25, 7,21),f(25, 7,22) / -1.9560000d-04 , -2.2000000d-04 /
      data f(25, 7,23) /             -2.6020000d-04 /
      data f(25, 8, 1),f(25, 8, 2) / -2.0460000d-04 , -2.1220000d-04 /
      data f(25, 8, 3),f(25, 8, 4) / -2.2160000d-04 , -2.2160000d-04 /
      data f(25, 8, 5),f(25, 8, 6) / -2.1220000d-04 , -2.0460000d-04 /
      data f(25, 8, 7),f(25, 8, 8) / -2.0340000d-04 , -2.0960000d-04 /
      data f(25, 8, 9),f(25, 8,10) / -2.2250000d-04 , -2.3930000d-04 /
      data f(25, 8,11),f(25, 8,12) / -2.5620000d-04 , -2.6880000d-04 /
      data f(25, 8,13),f(25, 8,14) / -2.7480000d-04 , -2.7330000d-04 /
      data f(25, 8,15),f(25, 8,16) / -2.6490000d-04 , -2.5030000d-04 /
      data f(25, 8,17),f(25, 8,18) / -2.3220000d-04 , -2.1530000d-04 /
      data f(25, 8,19),f(25, 8,20) / -2.0480000d-04 , -2.0190000d-04 /
      data f(25, 8,21),f(25, 8,22) / -2.0190000d-04 , -2.0480000d-04 /
      data f(25, 8,23) /             -2.1530000d-04 /
      data f(25, 9, 1),f(25, 9, 2) / -1.8560000d-04 , -2.0060000d-04 /
      data f(25, 9, 3),f(25, 9, 4) / -2.1310000d-04 , -2.1310000d-04 /
      data f(25, 9, 5),f(25, 9, 6) / -2.0060000d-04 , -1.8560000d-04 /
      data f(25, 9, 7),f(25, 9, 8) / -1.7280000d-04 , -1.6560000d-04 /
      data f(25, 9, 9),f(25, 9,10) / -1.6530000d-04 , -1.7070000d-04 /
      data f(25, 9,11),f(25, 9,12) / -1.7890000d-04 , -1.8690000d-04 /
      data f(25, 9,13),f(25, 9,14) / -1.9250000d-04 , -1.9430000d-04 /
      data f(25, 9,15),f(25, 9,16) / -1.9210000d-04 , -1.8630000d-04 /
      data f(25, 9,17),f(25, 9,18) / -1.7920000d-04 , -1.7480000d-04 /
      data f(25, 9,19),f(25, 9,20) / -1.7620000d-04 , -1.8190000d-04 /
      data f(25, 9,21),f(25, 9,22) / -1.8190000d-04 , -1.7620000d-04 /
      data f(25, 9,23) /             -1.7480000d-04 /
      data f(25,10, 1),f(25,10, 2) / -1.9300000d-04 , -2.0910000d-04 /
      data f(25,10, 3),f(25,10, 4) / -2.1900000d-04 , -2.1900000d-04 /
      data f(25,10, 5),f(25,10, 6) / -2.0910000d-04 , -1.9300000d-04 /
      data f(25,10, 7),f(25,10, 8) / -1.7380000d-04 , -1.5710000d-04 /
      data f(25,10, 9),f(25,10,10) / -1.4660000d-04 , -1.4330000d-04 /
      data f(25,10,11),f(25,10,12) / -1.4530000d-04 , -1.4950000d-04 /
      data f(25,10,13),f(25,10,14) / -1.5320000d-04 , -1.5470000d-04 /
      data f(25,10,15),f(25,10,16) / -1.5390000d-04 , -1.5150000d-04 /
      data f(25,10,17),f(25,10,18) / -1.4920000d-04 , -1.5050000d-04 /
      data f(25,10,19),f(25,10,20) / -1.5810000d-04 , -1.6920000d-04 /
      data f(25,10,21),f(25,10,22) / -1.6920000d-04 , -1.5810000d-04 /
      data f(25,10,23) /             -1.5050000d-04 /
      data f(25,11, 1),f(25,11, 2) / -2.1570000d-04 , -2.2880000d-04 /
      data f(25,11, 3),f(25,11, 4) / -2.3260000d-04 , -2.3260000d-04 /
      data f(25,11, 5),f(25,11, 6) / -2.2880000d-04 , -2.1570000d-04 /
      data f(25,11, 7),f(25,11, 8) / -1.9370000d-04 , -1.6940000d-04 /
      data f(25,11, 9),f(25,11,10) / -1.5030000d-04 , -1.3960000d-04 /
      data f(25,11,11),f(25,11,12) / -1.3600000d-04 , -1.3630000d-04 /
      data f(25,11,13),f(25,11,14) / -1.3690000d-04 , -1.3620000d-04 /
      data f(25,11,15),f(25,11,16) / -1.3470000d-04 , -1.3310000d-04 /
      data f(25,11,17),f(25,11,18) / -1.3280000d-04 , -1.3670000d-04 /
      data f(25,11,19),f(25,11,20) / -1.4750000d-04 , -1.6150000d-04 /
      data f(25,11,21),f(25,11,22) / -1.6150000d-04 , -1.4750000d-04 /
      data f(25,11,23) /             -1.3670000d-04 /
      data f(25,12, 1),f(25,12, 2) / -2.3890000d-04 , -2.4410000d-04 /
      data f(25,12, 3),f(25,12, 4) / -2.3830000d-04 , -2.3830000d-04 /
      data f(25,12, 5),f(25,12, 6) / -2.4410000d-04 , -2.3890000d-04 /
      data f(25,12, 7),f(25,12, 8) / -2.1860000d-04 , -1.9070000d-04 /
      data f(25,12, 9),f(25,12,10) / -1.6520000d-04 , -1.4760000d-04 /
      data f(25,12,11),f(25,12,12) / -1.3760000d-04 , -1.3270000d-04 /
      data f(25,12,13),f(25,12,14) / -1.2940000d-04 , -1.2650000d-04 /
      data f(25,12,15),f(25,12,16) / -1.2440000d-04 , -1.2360000d-04 /
      data f(25,12,17),f(25,12,18) / -1.2450000d-04 , -1.2930000d-04 /
      data f(25,12,19),f(25,12,20) / -1.3970000d-04 , -1.5260000d-04 /
      data f(25,12,21),f(25,12,22) / -1.5260000d-04 , -1.3970000d-04 /
      data f(25,12,23) /             -1.2930000d-04 /
      data f(25,13, 1),f(25,13, 2) / -2.5040000d-04 , -2.4750000d-04 /
      data f(25,13, 3),f(25,13, 4) / -2.3450000d-04 , -2.3450000d-04 /
      data f(25,13, 5),f(25,13, 6) / -2.4750000d-04 , -2.5040000d-04 /
      data f(25,13, 7),f(25,13, 8) / -2.3570000d-04 , -2.0890000d-04 /
      data f(25,13, 9),f(25,13,10) / -1.8080000d-04 , -1.5810000d-04 /
      data f(25,13,11),f(25,13,12) / -1.4230000d-04 , -1.3180000d-04 /
      data f(25,13,13),f(25,13,14) / -1.2470000d-04 , -1.2020000d-04 /
      data f(25,13,15),f(25,13,16) / -1.1830000d-04 , -1.1920000d-04 /
      data f(25,13,17),f(25,13,18) / -1.2220000d-04 , -1.2790000d-04 /
      data f(25,13,19),f(25,13,20) / -1.3690000d-04 , -1.4690000d-04 /
      data f(25,13,21),f(25,13,22) / -1.4690000d-04 , -1.3690000d-04 /
      data f(25,13,23) /             -1.2790000d-04 /
      data f(25,14, 1),f(25,14, 2) / -2.4510000d-04 , -2.3970000d-04 /
      data f(25,14, 3),f(25,14, 4) / -2.2710000d-04 , -2.2710000d-04 /
      data f(25,14, 5),f(25,14, 6) / -2.3970000d-04 , -2.4510000d-04 /
      data f(25,14, 7),f(25,14, 8) / -2.3580000d-04 , -2.1440000d-04 /
      data f(25,14, 9),f(25,14,10) / -1.8860000d-04 , -1.6510000d-04 /
      data f(25,14,11),f(25,14,12) / -1.4630000d-04 , -1.3250000d-04 /
      data f(25,14,13),f(25,14,14) / -1.2300000d-04 , -1.1750000d-04 /
      data f(25,14,15),f(25,14,16) / -1.1640000d-04 , -1.1880000d-04 /
      data f(25,14,17),f(25,14,18) / -1.2370000d-04 , -1.3080000d-04 /
      data f(25,14,19),f(25,14,20) / -1.3920000d-04 , -1.4680000d-04 /
      data f(25,14,21),f(25,14,22) / -1.4680000d-04 , -1.3920000d-04 /
      data f(25,14,23) /             -1.3080000d-04 /
      data f(25,15, 1),f(25,15, 2) / -2.2750000d-04 , -2.2510000d-04 /
      data f(25,15, 3),f(25,15, 4) / -2.1870000d-04 , -2.1870000d-04 /
      data f(25,15, 5),f(25,15, 6) / -2.2510000d-04 , -2.2750000d-04 /
      data f(25,15, 7),f(25,15, 8) / -2.2100000d-04 , -2.0610000d-04 /
      data f(25,15, 9),f(25,15,10) / -1.8650000d-04 , -1.6670000d-04 /
      data f(25,15,11),f(25,15,12) / -1.4930000d-04 , -1.3540000d-04 /
      data f(25,15,13),f(25,15,14) / -1.2550000d-04 , -1.1690000d-04 /
      data f(25,15,15),f(25,15,16) / -1.1830000d-04 , -1.2080000d-04 /
      data f(25,15,17),f(25,15,18) / -1.2630000d-04 , -1.3360000d-04 /
      data f(25,15,19),f(25,15,20) / -1.4120000d-04 , -1.4720000d-04 /
      data f(25,15,21),f(25,15,22) / -1.4720000d-04 , -1.4120000d-04 /
      data f(25,15,23) /             -1.3360000d-04 /
      data f(25,16, 1),f(25,16, 2) / -2.0590000d-04 , -2.0730000d-04 /
      data f(25,16, 3),f(25,16, 4) / -2.0650000d-04 , -2.0650000d-04 /
      data f(25,16, 5),f(25,16, 6) / -2.0730000d-04 , -2.0590000d-04 /
      data f(25,16, 7),f(25,16, 8) / -2.0040000d-04 , -1.9060000d-04 /
      data f(25,16, 9),f(25,16,10) / -1.7790000d-04 , -1.6420000d-04 /
      data f(25,16,11),f(25,16,12) / -1.5110000d-04 , -1.4000000d-04 /
      data f(25,16,13),f(25,16,14) / -1.3160000d-04 , -1.2640000d-04 /
      data f(25,16,15),f(25,16,16) / -1.2450000d-04 , -1.2560000d-04 /
      data f(25,16,17),f(25,16,18) / -1.2920000d-04 , -1.3420000d-04 /
      data f(25,16,19),f(25,16,20) / -1.3940000d-04 , -1.4330000d-04 /
      data f(25,16,21),f(25,16,22) / -1.4330000d-04 , -1.3940000d-04 /
      data f(25,16,23) /             -1.3420000d-04 /
      data f(25,17, 1),f(25,17, 2) / -1.8540000d-04 , -1.8810000d-04 /
      data f(25,17, 3),f(25,17, 4) / -1.8930000d-04 , -1.8930000d-04 /
      data f(25,17, 5),f(25,17, 6) / -1.8810000d-04 , -1.8540000d-04 /
      data f(25,17, 7),f(25,17, 8) / -1.8100000d-04 , -1.7510000d-04 /
      data f(25,17, 9),f(25,17,10) / -1.6790000d-04 , -1.6000000d-04 /
      data f(25,17,11),f(25,17,12) / -1.5230000d-04 , -1.4530000d-04 /
      data f(25,17,13),f(25,17,14) / -1.3960000d-04 , -1.3560000d-04 /
      data f(25,17,15),f(25,17,16) / -1.3340000d-04 , -1.3280000d-04 /
      data f(25,17,17),f(25,17,18) / -1.3350000d-04 , -1.3520000d-04 /
      data f(25,17,19),f(25,17,20) / -1.3710000d-04 , -1.3860000d-04 /
      data f(25,17,21),f(25,17,22) / -1.3860000d-04 , -1.3710000d-04 /
      data f(25,17,23) /             -1.3520000d-04 /
      data f(25,18, 1),f(25,18, 2) / -1.6700000d-04 , -1.6860000d-04 /
      data f(25,18, 3),f(25,18, 4) / -1.6970000d-04 , -1.6970000d-04 /
      data f(25,18, 5),f(25,18, 6) / -1.6860000d-04 , -1.6700000d-04 /
      data f(25,18, 7),f(25,18, 8) / -1.6480000d-04 , -1.6220000d-04 /
      data f(25,18, 9),f(25,18,10) / -1.5920000d-04 , -1.5600000d-04 /
      data f(25,18,11),f(25,18,12) / -1.5270000d-04 , -1.4970000d-04 /
      data f(25,18,13),f(25,18,14) / -1.4700000d-04 , -1.4470000d-04 /
      data f(25,18,15),f(25,18,16) / -1.4290000d-04 , -1.4160000d-04 /
      data f(25,18,17),f(25,18,18) / -1.4080000d-04 , -1.4040000d-04 /
      data f(25,18,19),f(25,18,20) / -1.4030000d-04 , -1.4030000d-04 /
      data f(25,18,21),f(25,18,22) / -1.4030000d-04 , -1.4030000d-04 /
      data f(25,18,23) /             -1.4040000d-04 /
      data f(25,19, 1),f(25,19, 2) / -1.5170000d-04 , -1.5170000d-04 /
      data f(25,19, 3),f(25,19, 4) / -1.5170000d-04 , -1.5170000d-04 /
      data f(25,19, 5),f(25,19, 6) / -1.5170000d-04 , -1.5170000d-04 /
      data f(25,19, 7),f(25,19, 8) / -1.5170000d-04 , -1.5170000d-04 /
      data f(25,19, 9),f(25,19,10) / -1.5170000d-04 , -1.5170000d-04 /
      data f(25,19,11),f(25,19,12) / -1.5170000d-04 , -1.5170000d-04 /
      data f(25,19,13),f(25,19,14) / -1.5170000d-04 , -1.5170000d-04 /
      data f(25,19,15),f(25,19,16) / -1.5170000d-04 , -1.5170000d-04 /
      data f(25,19,17),f(25,19,18) / -1.5170000d-04 , -1.5170000d-04 /
      data f(25,19,19),f(25,19,20) / -1.5170000d-04 , -1.5170000d-04 /
      data f(25,19,21),f(25,19,22) / -1.5170000d-04 , -1.5170000d-04 /
      data f(25,19,23) /             -1.5170000d-04 /
      data f(26, 1, 1),f(26, 1, 2) / -5.2700000d-05 , -5.2700000d-05 /
      data f(26, 1, 3),f(26, 1, 4) / -5.2700000d-05 , -5.2700000d-05 /
      data f(26, 1, 5),f(26, 1, 6) / -5.2700000d-05 , -5.2700000d-05 /
      data f(26, 1, 7),f(26, 1, 8) / -5.2700000d-05 , -5.2700000d-05 /
      data f(26, 1, 9),f(26, 1,10) / -5.2700000d-05 , -5.2700000d-05 /
      data f(26, 1,11),f(26, 1,12) / -5.2700000d-05 , -5.2700000d-05 /
      data f(26, 1,13),f(26, 1,14) / -5.2700000d-05 , -5.2700000d-05 /
      data f(26, 1,15),f(26, 1,16) / -5.2700000d-05 , -5.2700000d-05 /
      data f(26, 1,17),f(26, 1,18) / -5.2700000d-05 , -5.2700000d-05 /
      data f(26, 1,19),f(26, 1,20) / -5.2700000d-05 , -5.2700000d-05 /
      data f(26, 1,21),f(26, 1,22) / -5.2700000d-05 , -5.2700000d-05 /
      data f(26, 1,23) /             -5.2700000d-05 /
      data f(26, 2, 1),f(26, 2, 2) / -4.9800000d-05 , -2.5900000d-05 /
      data f(26, 2, 3),f(26, 2, 4) / -1.0200000d-05 , -1.0200000d-05 /
      data f(26, 2, 5),f(26, 2, 6) / -2.5900000d-05 , -4.9800000d-05 /
      data f(26, 2, 7),f(26, 2, 8) / -7.9200000d-05 , -1.1050000d-04 /
      data f(26, 2, 9),f(26, 2,10) / -1.3990000d-04 , -1.6400000d-04 /
      data f(26, 2,11),f(26, 2,12) / -1.7990000d-04 , -1.8570000d-04 /
      data f(26, 2,13),f(26, 2,14) / -1.8090000d-04 , -1.6570000d-04 /
      data f(26, 2,15),f(26, 2,16) / -1.4210000d-04 , -1.1270000d-04 /
      data f(26, 2,17),f(26, 2,18) / -8.1100000d-05 , -5.1000000d-05 /
      data f(26, 2,19),f(26, 2,20) / -2.6500000d-05 , -1.0300000d-05 /
      data f(26, 2,21),f(26, 2,22) / -1.0300000d-05 , -2.6500000d-05 /
      data f(26, 2,23) /             -5.1000000d-05 /
      data f(26, 3, 1),f(26, 3, 2) / -8.0800000d-05 , -1.7200000d-05 /
      data f(26, 3, 3),f(26, 3, 4) /  2.3900000d-05 ,  2.3900000d-05 /
      data f(26, 3, 5),f(26, 3, 6) / -1.7200000d-05 , -8.0800000d-05 /
      data f(26, 3, 7),f(26, 3, 8) / -1.5870000d-04 , -2.4090000d-04 /
      data f(26, 3, 9),f(26, 3,10) / -3.1700000d-04 , -3.7840000d-04 /
      data f(26, 3,11),f(26, 3,12) / -4.1860000d-04 , -4.3370000d-04 /
      data f(26, 3,13),f(26, 3,14) / -4.2200000d-04 , -3.8410000d-04 /
      data f(26, 3,15),f(26, 3,16) / -3.2330000d-04 , -2.4560000d-04 /
      data f(26, 3,17),f(26, 3,18) / -1.5980000d-04 , -7.7100000d-05 /
      data f(26, 3,19),f(26, 3,20) / -8.7000000d-06 ,  3.5900000d-05 /
      data f(26, 3,21),f(26, 3,22) /  3.5900000d-05 , -8.7000000d-06 /
      data f(26, 3,23) /             -7.7100000d-05 /
      data f(26, 4, 1),f(26, 4, 2) / -1.5310000d-04 , -7.4300000d-05 /
      data f(26, 4, 3),f(26, 4, 4) / -2.2000000d-05 , -2.2000000d-05 /
      data f(26, 4, 5),f(26, 4, 6) / -7.4300000d-05 , -1.5310000d-04 /
      data f(26, 4, 7),f(26, 4, 8) / -2.4640000d-04 , -3.4090000d-04 /
      data f(26, 4, 9),f(26, 4,10) / -4.2560000d-04 , -4.9280000d-04 /
      data f(26, 4,11),f(26, 4,12) / -5.3690000d-04 , -5.5450000d-04 /
      data f(26, 4,13),f(26, 4,14) / -5.4400000d-04 , -5.0530000d-04 /
      data f(26, 4,15),f(26, 4,16) / -4.4040000d-04 , -3.5370000d-04 /
      data f(26, 4,17),f(26, 4,18) / -2.5320000d-04 , -1.5140000d-04 /
      data f(26, 4,19),f(26, 4,20) / -6.4000000d-05 , -5.8000000d-06 /
      data f(26, 4,21),f(26, 4,22) / -5.8000000d-06 , -6.4000000d-05 /
      data f(26, 4,23) /             -1.5140000d-04 /
      data f(26, 5, 1),f(26, 5, 2) / -2.1060000d-04 , -1.4820000d-04 /
      data f(26, 5, 3),f(26, 5, 4) / -1.0550000d-04 , -1.0550000d-04 /
      data f(26, 5, 5),f(26, 5, 6) / -1.4820000d-04 , -2.1060000d-04 /
      data f(26, 5, 7),f(26, 5, 8) / -2.8070000d-04 , -3.4850000d-04 /
      data f(26, 5, 9),f(26, 5,10) / -4.0770000d-04 , -4.5480000d-04 /
      data f(26, 5,11),f(26, 5,12) / -4.8700000d-04 , -5.0160000d-04 /
      data f(26, 5,13),f(26, 5,14) / -4.9700000d-04 , -4.7300000d-04 /
      data f(26, 5,15),f(26, 5,16) / -4.3010000d-04 , -3.7000000d-04 /
      data f(26, 5,17),f(26, 5,18) / -2.9610000d-04 , -2.1660000d-04 /
      data f(26, 5,19),f(26, 5,20) / -1.4480000d-04 , -9.5600000d-05 /
      data f(26, 5,21),f(26, 5,22) / -9.5600000d-05 , -1.4480000d-04 /
      data f(26, 5,23) /             -2.1660000d-04 /
      data f(26, 6, 1),f(26, 6, 2) / -2.1820000d-04 , -1.9060000d-04 /
      data f(26, 6, 3),f(26, 6, 4) / -1.7360000d-04 , -1.7360000d-04 /
      data f(26, 6, 5),f(26, 6, 6) / -1.9060000d-04 , -2.1820000d-04 /
      data f(26, 6, 7),f(26, 6, 8) / -2.5140000d-04 , -2.8520000d-04 /
      data f(26, 6, 9),f(26, 6,10) / -3.1630000d-04 , -3.4330000d-04 /
      data f(26, 6,11),f(26, 6,12) / -3.6400000d-04 , -3.7530000d-04 /
      data f(26, 6,13),f(26, 6,14) / -3.7490000d-04 , -3.6340000d-04 /
      data f(26, 6,15),f(26, 6,16) / -3.4160000d-04 , -3.1010000d-04 /
      data f(26, 6,17),f(26, 6,18) / -2.7040000d-04 , -2.2750000d-04 /
      data f(26, 6,19),f(26, 6,20) / -1.9000000d-04 , -1.6590000d-04 /
      data f(26, 6,21),f(26, 6,22) / -1.6590000d-04 , -1.9000000d-04 /
      data f(26, 6,23) /             -2.2750000d-04 /
      data f(26, 7, 1),f(26, 7, 2) / -1.8980000d-04 , -1.8890000d-04 /
      data f(26, 7, 3),f(26, 7, 4) / -1.9210000d-04 , -1.9210000d-04 /
      data f(26, 7, 5),f(26, 7, 6) / -1.8890000d-04 , -1.8980000d-04 /
      data f(26, 7, 7),f(26, 7, 8) / -1.9630000d-04 , -2.0750000d-04 /
      data f(26, 7, 9),f(26, 7,10) / -2.2170000d-04 , -2.3670000d-04 /
      data f(26, 7,11),f(26, 7,12) / -2.5000000d-04 , -2.5820000d-04 /
      data f(26, 7,13),f(26, 7,14) / -2.5980000d-04 , -2.5500000d-04 /
      data f(26, 7,15),f(26, 7,16) / -2.4510000d-04 , -2.3080000d-04 /
      data f(26, 7,17),f(26, 7,18) / -2.1360000d-04 , -1.9710000d-04 /
      data f(26, 7,19),f(26, 7,20) / -1.8580000d-04 , -1.8140000d-04 /
      data f(26, 7,21),f(26, 7,22) / -1.8140000d-04 , -1.8580000d-04 /
      data f(26, 7,23) /             -1.9710000d-04 /
      data f(26, 8, 1),f(26, 8, 2) / -1.5840000d-04 , -1.6840000d-04 /
      data f(26, 8, 3),f(26, 8, 4) / -1.7840000d-04 , -1.7840000d-04 /
      data f(26, 8, 5),f(26, 8, 6) / -1.6840000d-04 , -1.5840000d-04 /
      data f(26, 8, 7),f(26, 8, 8) / -1.5260000d-04 , -1.5260000d-04 /
      data f(26, 8, 9),f(26, 8,10) / -1.5730000d-04 , -1.6470000d-04 /
      data f(26, 8,11),f(26, 8,12) / -1.7200000d-04 , -1.7720000d-04 /
      data f(26, 8,13),f(26, 8,14) / -1.7940000d-04 , -1.7850000d-04 /
      data f(26, 8,15),f(26, 8,16) / -1.7470000d-04 , -1.6880000d-04 /
      data f(26, 8,17),f(26, 8,18) / -1.6220000d-04 , -1.5760000d-04 /
      data f(26, 8,19),f(26, 8,20) / -1.5730000d-04 , -1.6020000d-04 /
      data f(26, 8,21),f(26, 8,22) / -1.6020000d-04 , -1.5730000d-04 /
      data f(26, 8,23) /             -1.5760000d-04 /
      data f(26, 9, 1),f(26, 9, 2) / -1.4510000d-04 , -1.5890000d-04 /
      data f(26, 9, 3),f(26, 9, 4) / -1.7070000d-04 , -1.7070000d-04 /
      data f(26, 9, 5),f(26, 9, 6) / -1.5890000d-04 , -1.4510000d-04 /
      data f(26, 9, 7),f(26, 9, 8) / -1.3340000d-04 , -1.2640000d-04 /
      data f(26, 9, 9),f(26, 9,10) / -1.2430000d-04 , -1.2580000d-04 /
      data f(26, 9,11),f(26, 9,12) / -1.2880000d-04 , -1.3150000d-04 /
      data f(26, 9,13),f(26, 9,14) / -1.3330000d-04 , -1.3370000d-04 /
      data f(26, 9,15),f(26, 9,16) / -1.3260000d-04 , -1.3040000d-04 /
      data f(26, 9,17),f(26, 9,18) / -1.2830000d-04 , -1.2840000d-04 /
      data f(26, 9,19),f(26, 9,20) / -1.3200000d-04 , -1.3740000d-04 /
      data f(26, 9,21),f(26, 9,22) / -1.3740000d-04 , -1.3200000d-04 /
      data f(26, 9,23) /             -1.2840000d-04 /
      data f(26,10, 1),f(26,10, 2) / -1.5140000d-04 , -1.6820000d-04 /
      data f(26,10, 3),f(26,10, 4) / -1.8070000d-04 , -1.8070000d-04 /
      data f(26,10, 5),f(26,10, 6) / -1.6820000d-04 , -1.5140000d-04 /
      data f(26,10, 7),f(26,10, 8) / -1.3440000d-04 , -1.2110000d-04 /
      data f(26,10, 9),f(26,10,10) / -1.1320000d-04 , -1.1010000d-04 /
      data f(26,10,11),f(26,10,12) / -1.1020000d-04 , -1.1130000d-04 /
      data f(26,10,13),f(26,10,14) / -1.1200000d-04 , -1.1160000d-04 /
      data f(26,10,15),f(26,10,16) / -1.1040000d-04 , -1.0900000d-04 /
      data f(26,10,17),f(26,10,18) / -1.0870000d-04 , -1.1120000d-04 /
      data f(26,10,19),f(26,10,20) / -1.1770000d-04 , -1.2570000d-04 /
      data f(26,10,21),f(26,10,22) / -1.2570000d-04 , -1.1770000d-04 /
      data f(26,10,23) /             -1.1120000d-04 /
      data f(26,11, 1),f(26,11, 2) / -1.6810000d-04 , -1.8600000d-04 /
      data f(26,11, 3),f(26,11, 4) / -1.9770000d-04 , -1.9770000d-04 /
      data f(26,11, 5),f(26,11, 6) / -1.8600000d-04 , -1.6810000d-04 /
      data f(26,11, 7),f(26,11, 8) / -1.4770000d-04 , -1.2910000d-04 /
      data f(26,11, 9),f(26,11,10) / -1.1570000d-04 , -1.0850000d-04 /
      data f(26,11,11),f(26,11,12) / -1.0550000d-04 , -1.0470000d-04 /
      data f(26,11,13),f(26,11,14) / -1.0380000d-04 , -1.0170000d-04 /
      data f(26,11,15),f(26,11,16) / -9.9400000d-05 , -9.7700000d-05 /
      data f(26,11,17),f(26,11,18) / -9.7800000d-05 , -1.0140000d-04 /
      data f(26,11,19),f(26,11,20) / -1.0950000d-04 , -1.1930000d-04 /
      data f(26,11,21),f(26,11,22) / -1.1930000d-04 , -1.0950000d-04 /
      data f(26,11,23) /             -1.0140000d-04 /
      data f(26,12, 1),f(26,12, 2) / -1.8550000d-04 , -2.0080000d-04 /
      data f(26,12, 3),f(26,12, 4) / -2.0910000d-04 , -2.0910000d-04 /
      data f(26,12, 5),f(26,12, 6) / -2.0080000d-04 , -1.8550000d-04 /
      data f(26,12, 7),f(26,12, 8) / -1.6480000d-04 , -1.4160000d-04 /
      data f(26,12, 9),f(26,12,10) / -1.2540000d-04 , -1.1330000d-04 /
      data f(26,12,11),f(26,12,12) / -1.0630000d-04 , -1.0250000d-04 /
      data f(26,12,13),f(26,12,14) / -9.9300000d-05 , -9.6200000d-05 /
      data f(26,12,15),f(26,12,16) / -9.3500000d-05 , -9.2100000d-05 /
      data f(26,12,17),f(26,12,18) / -9.2700000d-05 , -9.6600000d-05 /
      data f(26,12,19),f(26,12,20) / -1.0450000d-04 , -1.1390000d-04 /
      data f(26,12,21),f(26,12,22) / -1.1390000d-04 , -1.0450000d-04 /
      data f(26,12,23) /             -9.6600000d-05 /
      data f(26,13, 1),f(26,13, 2) / -1.9600000d-04 , -2.0740000d-04 /
      data f(26,13, 3),f(26,13, 4) / -2.1190000d-04 , -2.1190000d-04 /
      data f(26,13, 5),f(26,13, 6) / -2.0740000d-04 , -1.9600000d-04 /
      data f(26,13, 7),f(26,13, 8) / -1.7750000d-04 , -1.5560000d-04 /
      data f(26,13, 9),f(26,13,10) / -1.3530000d-04 , -1.1940000d-04 /
      data f(26,13,11),f(26,13,12) / -1.0830000d-04 , -1.0080000d-04 /
      data f(26,13,13),f(26,13,14) / -9.5700000d-05 , -9.1900000d-05 /
      data f(26,13,15),f(26,13,16) / -8.9600000d-05 , -8.9400000d-05 /
      data f(26,13,17),f(26,13,18) / -9.1400000d-05 , -9.6000000d-05 /
      data f(26,13,19),f(26,13,20) / -1.0330000d-04 , -1.1090000d-04 /
      data f(26,13,21),f(26,13,22) / -1.1090000d-04 , -1.0330000d-04 /
      data f(26,13,23) /             -9.6000000d-05 /
      data f(26,14, 1),f(26,14, 2) / -1.9570000d-04 , -2.0440000d-04 /
      data f(26,14, 3),f(26,14, 4) / -2.0750000d-04 , -2.0750000d-04 /
      data f(26,14, 5),f(26,14, 6) / -2.0440000d-04 , -1.9570000d-04 /
      data f(26,14, 7),f(26,14, 8) / -1.8040000d-04 , -1.6080000d-04 /
      data f(26,14, 9),f(26,14,10) / -1.4100000d-04 , -1.2220000d-04 /
      data f(26,14,11),f(26,14,12) / -1.1020000d-04 , -1.0040000d-04 /
      data f(26,14,13),f(26,14,14) / -9.3500000d-05 , -8.9200000d-05 /
      data f(26,14,15),f(26,14,16) / -8.7800000d-05 , -8.9000000d-05 /
      data f(26,14,17),f(26,14,18) / -9.2300000d-05 , -9.7700000d-05 /
      data f(26,14,19),f(26,14,20) / -1.0430000d-04 , -1.1020000d-04 /
      data f(26,14,21),f(26,14,22) / -1.1020000d-04 , -1.0430000d-04 /
      data f(26,14,23) /             -9.7700000d-05 /
      data f(26,15, 1),f(26,15, 2) / -1.8590000d-04 , -1.9340000d-04 /
      data f(26,15, 3),f(26,15, 4) / -1.9690000d-04 , -1.9690000d-04 /
      data f(26,15, 5),f(26,15, 6) / -1.9340000d-04 , -1.8590000d-04 /
      data f(26,15, 7),f(26,15, 8) / -1.7370000d-04 , -1.5800000d-04 /
      data f(26,15, 9),f(26,15,10) / -1.4130000d-04 , -1.2560000d-04 /
      data f(26,15,11),f(26,15,12) / -1.1230000d-04 , -1.0200000d-04 /
      data f(26,15,13),f(26,15,14) / -9.4500000d-05 , -9.0000000d-05 /
      data f(26,15,15),f(26,15,16) / -8.8500000d-05 , -8.9800000d-05 /
      data f(26,15,17),f(26,15,18) / -9.3600000d-05 , -9.8700000d-05 /
      data f(26,15,19),f(26,15,20) / -1.0430000d-04 , -1.0860000d-04 /
      data f(26,15,21),f(26,15,22) / -1.0860000d-04 , -1.0430000d-04 /
      data f(26,15,23) /             -9.8700000d-05 /
      data f(26,16, 1),f(26,16, 2) / -1.7010000d-04 , -1.7650000d-04 /
      data f(26,16, 3),f(26,16, 4) / -1.8000000d-04 , -1.8000000d-04 /
      data f(26,16, 5),f(26,16, 6) / -1.7650000d-04 , -1.7010000d-04 /
      data f(26,16, 7),f(26,16, 8) / -1.6100000d-04 , -1.4980000d-04 /
      data f(26,16, 9),f(26,16,10) / -1.3760000d-04 , -1.2560000d-04 /
      data f(26,16,11),f(26,16,12) / -1.1470000d-04 , -1.0570000d-04 /
      data f(26,16,13),f(26,16,14) / -9.9000000d-05 , -9.4600000d-05 /
      data f(26,16,15),f(26,16,16) / -9.2600000d-05 , -9.3000000d-05 /
      data f(26,16,17),f(26,16,18) / -9.5200000d-05 , -9.8600000d-05 /
      data f(26,16,19),f(26,16,20) / -1.0210000d-04 , -1.0480000d-04 /
      data f(26,16,21),f(26,16,22) / -1.0480000d-04 , -1.0210000d-04 /
      data f(26,16,23) /             -9.8600000d-05 /
      data f(26,17, 1),f(26,17, 2) / -1.5170000d-04 , -1.5600000d-04 /
      data f(26,17, 3),f(26,17, 4) / -1.5850000d-04 , -1.5850000d-04 /
      data f(26,17, 5),f(26,17, 6) / -1.5600000d-04 , -1.5170000d-04 /
      data f(26,17, 7),f(26,17, 8) / -1.4600000d-04 , -1.3910000d-04 /
      data f(26,17, 9),f(26,17,10) / -1.3170000d-04 , -1.2410000d-04 /
      data f(26,17,11),f(26,17,12) / -1.1700000d-04 , -1.1070000d-04 /
      data f(26,17,13),f(26,17,14) / -1.0570000d-04 , -1.0200000d-04 /
      data f(26,17,15),f(26,17,16) / -9.9700000d-05 , -9.8700000d-05 /
      data f(26,17,17),f(26,17,18) / -9.8800000d-05 , -9.9700000d-05 /
      data f(26,17,19),f(26,17,20) / -1.0090000d-04 , -1.0180000d-04 /
      data f(26,17,21),f(26,17,22) / -1.0180000d-04 , -1.0090000d-04 /
      data f(26,17,23) /             -9.9700000d-05 /
      data f(26,18, 1),f(26,18, 2) / -1.3310000d-04 , -1.3500000d-04 /
      data f(26,18, 3),f(26,18, 4) / -1.3630000d-04 , -1.3630000d-04 /
      data f(26,18, 5),f(26,18, 6) / -1.3500000d-04 , -1.3310000d-04 /
      data f(26,18, 7),f(26,18, 8) / -1.3070000d-04 , -1.2780000d-04 /
      data f(26,18, 9),f(26,18,10) / -1.2470000d-04 , -1.2140000d-04 /
      data f(26,18,11),f(26,18,12) / -1.1820000d-04 , -1.1510000d-04 /
      data f(26,18,13),f(26,18,14) / -1.1240000d-04 , -1.1010000d-04 /
      data f(26,18,15),f(26,18,16) / -1.0830000d-04 , -1.0690000d-04 /
      data f(26,18,17),f(26,18,18) / -1.0600000d-04 , -1.0550000d-04 /
      data f(26,18,19),f(26,18,20) / -1.0520000d-04 , -1.0510000d-04 /
      data f(26,18,21),f(26,18,22) / -1.0510000d-04 , -1.0520000d-04 /
      data f(26,18,23) /             -1.0550000d-04 /
      data f(26,19, 1),f(26,19, 2) / -1.1720000d-04 , -1.1720000d-04 /
      data f(26,19, 3),f(26,19, 4) / -1.1720000d-04 , -1.1720000d-04 /
      data f(26,19, 5),f(26,19, 6) / -1.1720000d-04 , -1.1720000d-04 /
      data f(26,19, 7),f(26,19, 8) / -1.1720000d-04 , -1.1720000d-04 /
      data f(26,19, 9),f(26,19,10) / -1.1720000d-04 , -1.1720000d-04 /
      data f(26,19,11),f(26,19,12) / -1.1720000d-04 , -1.1720000d-04 /
      data f(26,19,13),f(26,19,14) / -1.1720000d-04 , -1.1720000d-04 /
      data f(26,19,15),f(26,19,16) / -1.1720000d-04 , -1.1720000d-04 /
      data f(26,19,17),f(26,19,18) / -1.1720000d-04 , -1.1720000d-04 /
      data f(26,19,19),f(26,19,20) / -1.1720000d-04 , -1.1720000d-04 /
      data f(26,19,21),f(26,19,22) / -1.1720000d-04 , -1.1720000d-04 /
      data f(26,19,23) /             -1.1720000d-04 /
      data f(27, 1, 1),f(27, 1, 2) / -1.8450000d-04 , -1.8450000d-04 /
      data f(27, 1, 3),f(27, 1, 4) / -1.8450000d-04 , -1.8450000d-04 /
      data f(27, 1, 5),f(27, 1, 6) / -1.8450000d-04 , -1.8450000d-04 /
      data f(27, 1, 7),f(27, 1, 8) / -1.8450000d-04 , -1.8450000d-04 /
      data f(27, 1, 9),f(27, 1,10) / -1.8450000d-04 , -1.8450000d-04 /
      data f(27, 1,11),f(27, 1,12) / -1.8450000d-04 , -1.8450000d-04 /
      data f(27, 1,13),f(27, 1,14) / -1.8450000d-04 , -1.8450000d-04 /
      data f(27, 1,15),f(27, 1,16) / -1.8450000d-04 , -1.8450000d-04 /
      data f(27, 1,17),f(27, 1,18) / -1.8450000d-04 , -1.8450000d-04 /
      data f(27, 1,19),f(27, 1,20) / -1.8450000d-04 , -1.8450000d-04 /
      data f(27, 1,21),f(27, 1,22) / -1.8450000d-04 , -1.8450000d-04 /
      data f(27, 1,23) /             -1.8450000d-04 /
      data f(27, 2, 1),f(27, 2, 2) / -1.8980000d-04 , -1.8840000d-04 /
      data f(27, 2, 3),f(27, 2, 4) / -1.8750000d-04 , -1.8750000d-04 /
      data f(27, 2, 5),f(27, 2, 6) / -1.8840000d-04 , -1.8980000d-04 /
      data f(27, 2, 7),f(27, 2, 8) / -1.9150000d-04 , -1.9340000d-04 /
      data f(27, 2, 9),f(27, 2,10) / -1.9530000d-04 , -1.9680000d-04 /
      data f(27, 2,11),f(27, 2,12) / -1.9780000d-04 , -1.9800000d-04 /
      data f(27, 2,13),f(27, 2,14) / -1.9750000d-04 , -1.9630000d-04 /
      data f(27, 2,15),f(27, 2,16) / -1.9450000d-04 , -1.9220000d-04 /
      data f(27, 2,17),f(27, 2,18) / -1.8990000d-04 , -1.8770000d-04 /
      data f(27, 2,19),f(27, 2,20) / -1.8590000d-04 , -1.8470000d-04 /
      data f(27, 2,21),f(27, 2,22) / -1.8470000d-04 , -1.8590000d-04 /
      data f(27, 2,23) /             -1.8770000d-04 /
      data f(27, 3, 1),f(27, 3, 2) / -1.9670000d-04 , -1.9340000d-04 /
      data f(27, 3, 3),f(27, 3, 4) / -1.9130000d-04 , -1.9130000d-04 /
      data f(27, 3, 5),f(27, 3, 6) / -1.9340000d-04 , -1.9670000d-04 /
      data f(27, 3, 7),f(27, 3, 8) / -2.0120000d-04 , -2.0640000d-04 /
      data f(27, 3, 9),f(27, 3,10) / -2.1140000d-04 , -2.1570000d-04 /
      data f(27, 3,11),f(27, 3,12) / -2.1860000d-04 , -2.1970000d-04 /
      data f(27, 3,13),f(27, 3,14) / -2.1870000d-04 , -2.1570000d-04 /
      data f(27, 3,15),f(27, 3,16) / -2.1090000d-04 , -2.0480000d-04 /
      data f(27, 3,17),f(27, 3,18) / -1.9830000d-04 , -1.9230000d-04 /
      data f(27, 3,19),f(27, 3,20) / -1.8760000d-04 , -1.8470000d-04 /
      data f(27, 3,21),f(27, 3,22) / -1.8470000d-04 , -1.8760000d-04 /
      data f(27, 3,23) /             -1.9230000d-04 /
      data f(27, 4, 1),f(27, 4, 2) / -1.8770000d-04 , -1.8270000d-04 /
      data f(27, 4, 3),f(27, 4, 4) / -1.7960000d-04 , -1.7960000d-04 /
      data f(27, 4, 5),f(27, 4, 6) / -1.8270000d-04 , -1.8770000d-04 /
      data f(27, 4, 7),f(27, 4, 8) / -1.9420000d-04 , -2.0110000d-04 /
      data f(27, 4, 9),f(27, 4,10) / -2.0750000d-04 , -2.1290000d-04 /
      data f(27, 4,11),f(27, 4,12) / -2.1660000d-04 , -2.1840000d-04 /
      data f(27, 4,13),f(27, 4,14) / -2.1780000d-04 , -2.1490000d-04 /
      data f(27, 4,15),f(27, 4,16) / -2.0960000d-04 , -2.0230000d-04 /
      data f(27, 4,17),f(27, 4,18) / -1.9350000d-04 , -1.8490000d-04 /
      data f(27, 4,19),f(27, 4,20) / -1.7810000d-04 , -1.7400000d-04 /
      data f(27, 4,21),f(27, 4,22) / -1.7400000d-04 , -1.7810000d-04 /
      data f(27, 4,23) /             -1.8490000d-04 /
      data f(27, 5, 1),f(27, 5, 2) / -1.6240000d-04 , -1.5950000d-04 /
      data f(27, 5, 3),f(27, 5, 4) / -1.5850000d-04 , -1.5850000d-04 /
      data f(27, 5, 5),f(27, 5, 6) / -1.5950000d-04 , -1.6240000d-04 /
      data f(27, 5, 7),f(27, 5, 8) / -1.6710000d-04 , -1.7260000d-04 /
      data f(27, 5, 9),f(27, 5,10) / -1.7820000d-04 , -1.8350000d-04 /
      data f(27, 5,11),f(27, 5,12) / -1.8790000d-04 , -1.9040000d-04 /
      data f(27, 5,13),f(27, 5,14) / -1.9030000d-04 , -1.8770000d-04 /
      data f(27, 5,15),f(27, 5,16) / -1.8310000d-04 , -1.7680000d-04 /
      data f(27, 5,17),f(27, 5,18) / -1.6940000d-04 , -1.6230000d-04 /
      data f(27, 5,19),f(27, 5,20) / -1.5730000d-04 , -1.5520000d-04 /
      data f(27, 5,21),f(27, 5,22) / -1.5520000d-04 , -1.5730000d-04 /
      data f(27, 5,23) /             -1.6230000d-04 /
      data f(27, 6, 1),f(27, 6, 2) / -1.3320000d-04 , -1.3580000d-04 /
      data f(27, 6, 3),f(27, 6, 4) / -1.3970000d-04 , -1.3970000d-04 /
      data f(27, 6, 5),f(27, 6, 6) / -1.3580000d-04 , -1.3320000d-04 /
      data f(27, 6, 7),f(27, 6, 8) / -1.3300000d-04 , -1.3510000d-04 /
      data f(27, 6, 9),f(27, 6,10) / -1.3880000d-04 , -1.4340000d-04 /
      data f(27, 6,11),f(27, 6,12) / -1.4770000d-04 , -1.5030000d-04 /
      data f(27, 6,13),f(27, 6,14) / -1.5030000d-04 , -1.4800000d-04 /
      data f(27, 6,15),f(27, 6,16) / -1.4430000d-04 , -1.4020000d-04 /
      data f(27, 6,17),f(27, 6,18) / -1.3630000d-04 , -1.3400000d-04 /
      data f(27, 6,19),f(27, 6,20) / -1.3430000d-04 , -1.3670000d-04 /
      data f(27, 6,21),f(27, 6,22) / -1.3670000d-04 , -1.3430000d-04 /
      data f(27, 6,23) /             -1.3400000d-04 /
      data f(27, 7, 1),f(27, 7, 2) / -1.0730000d-04 , -1.1310000d-04 /
      data f(27, 7, 3),f(27, 7, 4) / -1.1910000d-04 , -1.1910000d-04 /
      data f(27, 7, 5),f(27, 7, 6) / -1.1310000d-04 , -1.0730000d-04 /
      data f(27, 7, 7),f(27, 7, 8) / -1.0400000d-04 , -1.0350000d-04 /
      data f(27, 7, 9),f(27, 7,10) / -1.0510000d-04 , -1.0760000d-04 /
      data f(27, 7,11),f(27, 7,12) / -1.1010000d-04 , -1.1150000d-04 /
      data f(27, 7,13),f(27, 7,14) / -1.1160000d-04 , -1.1050000d-04 /
      data f(27, 7,15),f(27, 7,16) / -1.0880000d-04 , -1.0710000d-04 /
      data f(27, 7,17),f(27, 7,18) / -1.0630000d-04 , -1.0740000d-04 /
      data f(27, 7,19),f(27, 7,20) / -1.1100000d-04 , -1.1550000d-04 /
      data f(27, 7,21),f(27, 7,22) / -1.1550000d-04 , -1.1100000d-04 /
      data f(27, 7,23) /             -1.0740000d-04 /
      data f(27, 8, 1),f(27, 8, 2) / -8.9300000d-05 , -9.5800000d-05 /
      data f(27, 8, 3),f(27, 8, 4) / -1.0170000d-04 , -1.0170000d-04 /
      data f(27, 8, 5),f(27, 8, 6) / -9.5800000d-05 , -8.9300000d-05 /
      data f(27, 8, 7),f(27, 8, 8) / -8.4600000d-05 , -8.2400000d-05 /
      data f(27, 8, 9),f(27, 8,10) / -8.2000000d-05 , -8.2400000d-05 /
      data f(27, 8,11),f(27, 8,12) / -8.2800000d-05 , -8.2900000d-05 /
      data f(27, 8,13),f(27, 8,14) / -8.2900000d-05 , -8.2800000d-05 /
      data f(27, 8,15),f(27, 8,16) / -8.2700000d-05 , -8.2700000d-05 /
      data f(27, 8,17),f(27, 8,18) / -8.3600000d-05 , -8.5800000d-05 /
      data f(27, 8,19),f(27, 8,20) / -8.9700000d-05 , -9.3600000d-05 /
      data f(27, 8,21),f(27, 8,22) / -9.3600000d-05 , -8.9700000d-05 /
      data f(27, 8,23) /             -8.5800000d-05 /
      data f(27, 9, 1),f(27, 9, 2) / -8.2400000d-05 , -9.0700000d-05 /
      data f(27, 9, 3),f(27, 9, 4) / -9.7700000d-05 , -9.7700000d-05 /
      data f(27, 9, 5),f(27, 9, 6) / -9.0700000d-05 , -8.2400000d-05 /
      data f(27, 9, 7),f(27, 9, 8) / -7.5700000d-05 , -7.1400000d-05 /
      data f(27, 9, 9),f(27, 9,10) / -6.9300000d-05 , -6.8200000d-05 /
      data f(27, 9,11),f(27, 9,12) / -6.7600000d-05 , -6.7000000d-05 /
      data f(27, 9,13),f(27, 9,14) / -6.6500000d-05 , -6.6100000d-05 /
      data f(27, 9,15),f(27, 9,16) / -6.6100000d-05 , -6.6500000d-05 /
      data f(27, 9,17),f(27, 9,18) / -6.7900000d-05 , -7.0600000d-05 /
      data f(27, 9,19),f(27, 9,20) / -7.4500000d-05 , -7.8100000d-05 /
      data f(27, 9,21),f(27, 9,22) / -7.8100000d-05 , -7.4500000d-05 /
      data f(27, 9,23) /             -7.0600000d-05 /
      data f(27,10, 1),f(27,10, 2) / -8.5700000d-05 , -9.6100000d-05 /
      data f(27,10, 3),f(27,10, 4) / -1.0460000d-04 , -1.0460000d-04 /
      data f(27,10, 5),f(27,10, 6) / -9.6100000d-05 , -8.5700000d-05 /
      data f(27,10, 7),f(27,10, 8) / -7.6300000d-05 , -6.9400000d-05 /
      data f(27,10, 9),f(27,10,10) / -6.5000000d-05 , -6.2800000d-05 /
      data f(27,10,11),f(27,10,12) / -6.1400000d-05 , -6.0300000d-05 /
      data f(27,10,13),f(27,10,14) / -5.9200000d-05 , -5.8000000d-05 /
      data f(27,10,15),f(27,10,16) / -5.7200000d-05 , -5.7200000d-05 /
      data f(27,10,17),f(27,10,18) / -5.8300000d-05 , -6.1100000d-05 /
      data f(27,10,19),f(27,10,20) / -6.5400000d-05 , -6.9700000d-05 /
      data f(27,10,21),f(27,10,22) / -6.9700000d-05 , -6.5400000d-05 /
      data f(27,10,23) /             -6.1100000d-05 /
      data f(27,11, 1),f(27,11, 2) / -9.4700000d-05 , -1.0660000d-04 /
      data f(27,11, 3),f(27,11, 4) / -1.1570000d-04 , -1.1570000d-04 /
      data f(27,11, 5),f(27,11, 6) / -1.0660000d-04 , -9.4700000d-05 /
      data f(27,11, 7),f(27,11, 8) / -8.3000000d-05 , -7.3500000d-05 /
      data f(27,11, 9),f(27,11,10) / -6.6900000d-05 , -6.2800000d-05 /
      data f(27,11,11),f(27,11,12) / -5.9900000d-05 , -5.7900000d-05 /
      data f(27,11,13),f(27,11,14) / -5.6200000d-05 , -5.4500000d-05 /
      data f(27,11,15),f(27,11,16) / -5.3100000d-05 , -5.2500000d-05 /
      data f(27,11,17),f(27,11,18) / -5.3400000d-05 , -5.6100000d-05 /
      data f(27,11,19),f(27,11,20) / -6.0600000d-05 , -6.5500000d-05 /
      data f(27,11,21),f(27,11,22) / -6.5500000d-05 , -6.0600000d-05 /
      data f(27,11,23) /             -5.6100000d-05 /
      data f(27,12, 1),f(27,12, 2) / -1.0430000d-04 , -1.1620000d-04 /
      data f(27,12, 3),f(27,12, 4) / -1.2480000d-04 , -1.2480000d-04 /
      data f(27,12, 5),f(27,12, 6) / -1.1620000d-04 , -1.0430000d-04 /
      data f(27,12, 7),f(27,12, 8) / -9.1700000d-05 , -8.0400000d-05 /
      data f(27,12, 9),f(27,12,10) / -7.1200000d-05 , -6.4600000d-05 /
      data f(27,12,11),f(27,12,12) / -6.0200000d-05 , -5.7100000d-05 /
      data f(27,12,13),f(27,12,14) / -5.4400000d-05 , -5.2300000d-05 /
      data f(27,12,15),f(27,12,16) / -5.0700000d-05 , -5.0300000d-05 /
      data f(27,12,17),f(27,12,18) / -5.1300000d-05 , -5.4100000d-05 /
      data f(27,12,19),f(27,12,20) / -5.8600000d-05 , -6.3300000d-05 /
      data f(27,12,21),f(27,12,22) / -6.3300000d-05 , -5.8600000d-05 /
      data f(27,12,23) /             -5.4100000d-05 /
      data f(27,13, 1),f(27,13, 2) / -1.1030000d-04 , -1.2110000d-04 /
      data f(27,13, 3),f(27,13, 4) / -1.2860000d-04 , -1.2860000d-04 /
      data f(27,13, 5),f(27,13, 6) / -1.2110000d-04 , -1.1030000d-04 /
      data f(27,13, 7),f(27,13, 8) / -9.8000000d-05 , -8.5900000d-05 /
      data f(27,13, 9),f(27,13,10) / -7.5200000d-05 , -6.6700000d-05 /
      data f(27,13,11),f(27,13,12) / -6.0300000d-05 , -5.6000000d-05 /
      data f(27,13,13),f(27,13,14) / -5.3000000d-05 , -5.0700000d-05 /
      data f(27,13,15),f(27,13,16) / -4.9400000d-05 , -4.9300000d-05 /
      data f(27,13,17),f(27,13,18) / -5.0800000d-05 , -5.3700000d-05 /
      data f(27,13,19),f(27,13,20) / -5.7800000d-05 , -6.1700000d-05 /
      data f(27,13,21),f(27,13,22) / -6.1700000d-05 , -5.7800000d-05 /
      data f(27,13,23) /             -5.3700000d-05 /
      data f(27,14, 1),f(27,14, 2) / -1.1110000d-04 , -1.2040000d-04 /
      data f(27,14, 3),f(27,14, 4) / -1.2650000d-04 , -1.2650000d-04 /
      data f(27,14, 5),f(27,14, 6) / -1.2040000d-04 , -1.1110000d-04 /
      data f(27,14, 7),f(27,14, 8) / -1.0000000d-04 , -8.8300000d-05 /
      data f(27,14, 9),f(27,14,10) / -7.7400000d-05 , -6.8100000d-05 /
      data f(27,14,11),f(27,14,12) / -6.0900000d-05 , -5.5500000d-05 /
      data f(27,14,13),f(27,14,14) / -5.2000000d-05 , -4.9900000d-05 /
      data f(27,14,15),f(27,14,16) / -4.9000000d-05 , -4.9400000d-05 /
      data f(27,14,17),f(27,14,18) / -5.1100000d-05 , -5.3900000d-05 /
      data f(27,14,19),f(27,14,20) / -5.7300000d-05 , -6.0300000d-05 /
      data f(27,14,21),f(27,14,22) / -6.0300000d-05 , -5.7300000d-05 /
      data f(27,14,23) /             -5.3900000d-05 /
      data f(27,15, 1),f(27,15, 2) / -1.0680000d-04 , -1.1430000d-04 /
      data f(27,15, 3),f(27,15, 4) / -1.1910000d-04 , -1.1910000d-04 /
      data f(27,15, 5),f(27,15, 6) / -1.1430000d-04 , -1.0680000d-04 /
      data f(27,15, 7),f(27,15, 8) / -9.7500000d-05 , -8.7500000d-05 /
      data f(27,15, 9),f(27,15,10) / -7.7800000d-05 , -6.9100000d-05 /
      data f(27,15,11),f(27,15,12) / -6.2000000d-05 , -5.6600000d-05 /
      data f(27,15,13),f(27,15,14) / -5.2900000d-05 , -5.0700000d-05 /
      data f(27,15,15),f(27,15,16) / -5.0000000d-05 , -5.0500000d-05 /
      data f(27,15,17),f(27,15,18) / -5.2100000d-05 , -5.4500000d-05 /
      data f(27,15,19),f(27,15,20) / -5.7000000d-05 , -5.9000000d-05 /
      data f(27,15,21),f(27,15,22) / -5.9000000d-05 , -5.7000000d-05 /
      data f(27,15,23) /             -5.4500000d-05 /
      data f(27,16, 1),f(27,16, 2) / -9.8300000d-05 , -1.0370000d-04 /
      data f(27,16, 3),f(27,16, 4) / -1.0720000d-04 , -1.0720000d-04 /
      data f(27,16, 5),f(27,16, 6) / -1.0370000d-04 , -9.8300000d-05 /
      data f(27,16, 7),f(27,16, 8) / -9.1600000d-05 , -8.4200000d-05 /
      data f(27,16, 9),f(27,16,10) / -7.6700000d-05 , -6.9800000d-05 /
      data f(27,16,11),f(27,16,12) / -6.3800000d-05 , -5.9100000d-05 /
      data f(27,16,13),f(27,16,14) / -5.5700000d-05 , -5.3700000d-05 /
      data f(27,16,15),f(27,16,16) / -5.2800000d-05 , -5.3000000d-05 /
      data f(27,16,17),f(27,16,18) / -5.3900000d-05 , -5.5300000d-05 /
      data f(27,16,19),f(27,16,20) / -5.6800000d-05 , -5.7900000d-05 /
      data f(27,16,21),f(27,16,22) / -5.7900000d-05 , -5.6800000d-05 /
      data f(27,16,23) /             -5.5300000d-05 /
      data f(27,17, 1),f(27,17, 2) / -8.7400000d-05 , -9.0500000d-05 /
      data f(27,17, 3),f(27,17, 4) / -9.2700000d-05 , -9.2700000d-05 /
      data f(27,17, 5),f(27,17, 6) / -9.0500000d-05 , -8.7400000d-05 /
      data f(27,17, 7),f(27,17, 8) / -8.3400000d-05 , -7.9000000d-05 /
      data f(27,17, 9),f(27,17,10) / -7.4300000d-05 , -6.9900000d-05 /
      data f(27,17,11),f(27,17,12) / -6.5900000d-05 , -6.2500000d-05 /
      data f(27,17,13),f(27,17,14) / -6.0000000d-05 , -5.8200000d-05 /
      data f(27,17,15),f(27,17,16) / -5.7100000d-05 , -5.6700000d-05 /
      data f(27,17,17),f(27,17,18) / -5.6800000d-05 , -5.7100000d-05 /
      data f(27,17,19),f(27,17,20) / -5.7600000d-05 , -5.7900000d-05 /
      data f(27,17,21),f(27,17,22) / -5.7900000d-05 , -5.7600000d-05 /
      data f(27,17,23) /             -5.7100000d-05 /
      data f(27,18, 1),f(27,18, 2) / -7.6400000d-05 , -7.7600000d-05 /
      data f(27,18, 3),f(27,18, 4) / -7.8400000d-05 , -7.8400000d-05 /
      data f(27,18, 5),f(27,18, 6) / -7.7600000d-05 , -7.6400000d-05 /
      data f(27,18, 7),f(27,18, 8) / -7.4800000d-05 , -7.3000000d-05 /
      data f(27,18, 9),f(27,18,10) / -7.1100000d-05 , -6.9200000d-05 /
      data f(27,18,11),f(27,18,12) / -6.7400000d-05 , -6.5700000d-05 /
      data f(27,18,13),f(27,18,14) / -6.4300000d-05 , -6.3100000d-05 /
      data f(27,18,15),f(27,18,16) / -6.2200000d-05 , -6.1500000d-05 /
      data f(27,18,17),f(27,18,18) / -6.1000000d-05 , -6.0700000d-05 /
      data f(27,18,19),f(27,18,20) / -6.0600000d-05 , -6.0500000d-05 /
      data f(27,18,21),f(27,18,22) / -6.0500000d-05 , -6.0600000d-05 /
      data f(27,18,23) /             -6.0700000d-05 /
      data f(27,19, 1),f(27,19, 2) / -6.7100000d-05 , -6.7100000d-05 /
      data f(27,19, 3),f(27,19, 4) / -6.7100000d-05 , -6.7100000d-05 /
      data f(27,19, 5),f(27,19, 6) / -6.7100000d-05 , -6.7100000d-05 /
      data f(27,19, 7),f(27,19, 8) / -6.7100000d-05 , -6.7100000d-05 /
      data f(27,19, 9),f(27,19,10) / -6.7100000d-05 , -6.7100000d-05 /
      data f(27,19,11),f(27,19,12) / -6.7100000d-05 , -6.7100000d-05 /
      data f(27,19,13),f(27,19,14) / -6.7100000d-05 , -6.7100000d-05 /
      data f(27,19,15),f(27,19,16) / -6.7100000d-05 , -6.7100000d-05 /
      data f(27,19,17),f(27,19,18) / -6.7100000d-05 , -6.7100000d-05 /
      data f(27,19,19),f(27,19,20) / -6.7100000d-05 , -6.7100000d-05 /
      data f(27,19,21),f(27,19,22) / -6.7100000d-05 , -6.7100000d-05 /
      data f(27,19,23) /             -6.7100000d-05 /
      data f(28, 1, 1),f(28, 1, 2) / -1.1890000d-04 , -1.1890000d-04 /
      data f(28, 1, 3),f(28, 1, 4) / -1.1890000d-04 , -1.1890000d-04 /
      data f(28, 1, 5),f(28, 1, 6) / -1.1890000d-04 , -1.1890000d-04 /
      data f(28, 1, 7),f(28, 1, 8) / -1.1890000d-04 , -1.1890000d-04 /
      data f(28, 1, 9),f(28, 1,10) / -1.1890000d-04 , -1.1890000d-04 /
      data f(28, 1,11),f(28, 1,12) / -1.1890000d-04 , -1.1890000d-04 /
      data f(28, 1,13),f(28, 1,14) / -1.1890000d-04 , -1.1890000d-04 /
      data f(28, 1,15),f(28, 1,16) / -1.1890000d-04 , -1.1890000d-04 /
      data f(28, 1,17),f(28, 1,18) / -1.1890000d-04 , -1.1890000d-04 /
      data f(28, 1,19),f(28, 1,20) / -1.1890000d-04 , -1.1890000d-04 /
      data f(28, 1,21),f(28, 1,22) / -1.1890000d-04 , -1.1890000d-04 /
      data f(28, 1,23) /             -1.1890000d-04 /
      data f(28, 2, 1),f(28, 2, 2) / -1.2200000d-04 , -1.2290000d-04 /
      data f(28, 2, 3),f(28, 2, 4) / -1.2340000d-04 , -1.2340000d-04 /
      data f(28, 2, 5),f(28, 2, 6) / -1.2290000d-04 , -1.2200000d-04 /
      data f(28, 2, 7),f(28, 2, 8) / -1.2090000d-04 , -1.1970000d-04 /
      data f(28, 2, 9),f(28, 2,10) / -1.1860000d-04 , -1.1780000d-04 /
      data f(28, 2,11),f(28, 2,12) / -1.1720000d-04 , -1.1700000d-04 /
      data f(28, 2,13),f(28, 2,14) / -1.1730000d-04 , -1.1780000d-04 /
      data f(28, 2,15),f(28, 2,16) / -1.1870000d-04 , -1.1980000d-04 /
      data f(28, 2,17),f(28, 2,18) / -1.2100000d-04 , -1.2210000d-04 /
      data f(28, 2,19),f(28, 2,20) / -1.2300000d-04 , -1.2350000d-04 /
      data f(28, 2,21),f(28, 2,22) / -1.2350000d-04 , -1.2300000d-04 /
      data f(28, 2,23) /             -1.2210000d-04 /
      data f(28, 3, 1),f(28, 3, 2) / -1.2200000d-04 , -1.2450000d-04 /
      data f(28, 3, 3),f(28, 3, 4) / -1.2610000d-04 , -1.2610000d-04 /
      data f(28, 3, 5),f(28, 3, 6) / -1.2450000d-04 , -1.2200000d-04 /
      data f(28, 3, 7),f(28, 3, 8) / -1.1920000d-04 , -1.1650000d-04 /
      data f(28, 3, 9),f(28, 3,10) / -1.1430000d-04 , -1.1270000d-04 /
      data f(28, 3,11),f(28, 3,12) / -1.1180000d-04 , -1.1150000d-04 /
      data f(28, 3,13),f(28, 3,14) / -1.1200000d-04 , -1.1310000d-04 /
      data f(28, 3,15),f(28, 3,16) / -1.1480000d-04 , -1.1690000d-04 /
      data f(28, 3,17),f(28, 3,18) / -1.1950000d-04 , -1.2220000d-04 /
      data f(28, 3,19),f(28, 3,20) / -1.2460000d-04 , -1.2630000d-04 /
      data f(28, 3,21),f(28, 3,22) / -1.2630000d-04 , -1.2460000d-04 /
      data f(28, 3,23) /             -1.2220000d-04 /
      data f(28, 4, 1),f(28, 4, 2) / -1.0950000d-04 , -1.1280000d-04 /
      data f(28, 4, 3),f(28, 4, 4) / -1.1530000d-04 , -1.1530000d-04 /
      data f(28, 4, 5),f(28, 4, 6) / -1.1280000d-04 , -1.0950000d-04 /
      data f(28, 4, 7),f(28, 4, 8) / -1.0630000d-04 , -1.0380000d-04 /
      data f(28, 4, 9),f(28, 4,10) / -1.0210000d-04 , -1.0130000d-04 /
      data f(28, 4,11),f(28, 4,12) / -1.0120000d-04 , -1.0150000d-04 /
      data f(28, 4,13),f(28, 4,14) / -1.0180000d-04 , -1.0240000d-04 /
      data f(28, 4,15),f(28, 4,16) / -1.0330000d-04 , -1.0480000d-04 /
      data f(28, 4,17),f(28, 4,18) / -1.0690000d-04 , -1.0970000d-04 /
      data f(28, 4,19),f(28, 4,20) / -1.1280000d-04 , -1.1530000d-04 /
      data f(28, 4,21),f(28, 4,22) / -1.1530000d-04 , -1.1280000d-04 /
      data f(28, 4,23) /             -1.0970000d-04 /
      data f(28, 5, 1),f(28, 5, 2) / -9.1000000d-05 , -9.5100000d-05 /
      data f(28, 5, 3),f(28, 5, 4) / -9.8700000d-05 , -9.8700000d-05 /
      data f(28, 5, 5),f(28, 5, 6) / -9.5100000d-05 , -9.1000000d-05 /
      data f(28, 5, 7),f(28, 5, 8) / -8.7700000d-05 , -8.5700000d-05 /
      data f(28, 5, 9),f(28, 5,10) / -8.5000000d-05 , -8.5300000d-05 /
      data f(28, 5,11),f(28, 5,12) / -8.6100000d-05 , -8.6800000d-05 /
      data f(28, 5,13),f(28, 5,14) / -8.6900000d-05 , -8.6800000d-05 /
      data f(28, 5,15),f(28, 5,16) / -8.6600000d-05 , -8.7000000d-05 /
      data f(28, 5,17),f(28, 5,18) / -8.8200000d-05 , -9.0600000d-05 /
      data f(28, 5,19),f(28, 5,20) / -9.3800000d-05 , -9.6900000d-05 /
      data f(28, 5,21),f(28, 5,22) / -9.6900000d-05 , -9.3800000d-05 /
      data f(28, 5,23) /             -9.0600000d-05 /
      data f(28, 6, 1),f(28, 6, 2) / -7.3900000d-05 , -7.8300000d-05 /
      data f(28, 6, 3),f(28, 6, 4) / -8.2200000d-05 , -8.2200000d-05 /
      data f(28, 6, 5),f(28, 6, 6) / -7.8300000d-05 , -7.3900000d-05 /
      data f(28, 6, 7),f(28, 6, 8) / -7.0600000d-05 , -6.8700000d-05 /
      data f(28, 6, 9),f(28, 6,10) / -6.8200000d-05 , -6.8500000d-05 /
      data f(28, 6,11),f(28, 6,12) / -6.9100000d-05 , -6.9600000d-05 /
      data f(28, 6,13),f(28, 6,14) / -6.9700000d-05 , -6.9600000d-05 /
      data f(28, 6,15),f(28, 6,16) / -6.9400000d-05 , -6.9600000d-05 /
      data f(28, 6,17),f(28, 6,18) / -7.0800000d-05 , -7.3200000d-05 /
      data f(28, 6,19),f(28, 6,20) / -7.6600000d-05 , -8.0000000d-05 /
      data f(28, 6,21),f(28, 6,22) / -8.0000000d-05 , -7.6600000d-05 /
      data f(28, 6,23) /             -7.3200000d-05 /
      data f(28, 7, 1),f(28, 7, 2) / -5.9400000d-05 , -6.3100000d-05 /
      data f(28, 7, 3),f(28, 7, 4) / -6.6500000d-05 , -6.6500000d-05 /
      data f(28, 7, 5),f(28, 7, 6) / -6.3100000d-05 , -5.9400000d-05 /
      data f(28, 7, 7),f(28, 7, 8) / -5.6600000d-05 , -5.4900000d-05 /
      data f(28, 7, 9),f(28, 7,10) / -5.4200000d-05 , -5.4000000d-05 /
      data f(28, 7,11),f(28, 7,12) / -5.4000000d-05 , -5.4000000d-05 /
      data f(28, 7,13),f(28, 7,14) / -5.4000000d-05 , -5.4100000d-05 /
      data f(28, 7,15),f(28, 7,16) / -5.4400000d-05 , -5.5000000d-05 /
      data f(28, 7,17),f(28, 7,18) / -5.6500000d-05 , -5.9000000d-05 /
      data f(28, 7,19),f(28, 7,20) / -6.2300000d-05 , -6.5400000d-05 /
      data f(28, 7,21),f(28, 7,22) / -6.5400000d-05 , -6.2300000d-05 /
      data f(28, 7,23) /             -5.9000000d-05 /
      data f(28, 8, 1),f(28, 8, 2) / -4.9300000d-05 , -5.2800000d-05 /
      data f(28, 8, 3),f(28, 8, 4) / -5.6000000d-05 , -5.6000000d-05 /
      data f(28, 8, 5),f(28, 8, 6) / -5.2800000d-05 , -4.9300000d-05 /
      data f(28, 8, 7),f(28, 8, 8) / -4.6600000d-05 , -4.4900000d-05 /
      data f(28, 8, 9),f(28, 8,10) / -4.4000000d-05 , -4.3600000d-05 /
      data f(28, 8,11),f(28, 8,12) / -4.3100000d-05 , -4.2800000d-05 /
      data f(28, 8,13),f(28, 8,14) / -4.2500000d-05 , -4.2500000d-05 /
      data f(28, 8,15),f(28, 8,16) / -4.2800000d-05 , -4.3500000d-05 /
      data f(28, 8,17),f(28, 8,18) / -4.5100000d-05 , -4.7500000d-05 /
      data f(28, 8,19),f(28, 8,20) / -5.0500000d-05 , -5.3200000d-05 /
      data f(28, 8,21),f(28, 8,22) / -5.3200000d-05 , -5.0500000d-05 /
      data f(28, 8,23) /             -4.7500000d-05 /
      data f(28, 9, 1),f(28, 9, 2) / -4.5700000d-05 , -5.0000000d-05 /
      data f(28, 9, 3),f(28, 9, 4) / -5.3600000d-05 , -5.3600000d-05 /
      data f(28, 9, 5),f(28, 9, 6) / -5.0000000d-05 , -4.5700000d-05 /
      data f(28, 9, 7),f(28, 9, 8) / -4.2100000d-05 , -3.9700000d-05 /
      data f(28, 9, 9),f(28, 9,10) / -3.8400000d-05 , -3.7600000d-05 /
      data f(28, 9,11),f(28, 9,12) / -3.6900000d-05 , -3.6300000d-05 /
      data f(28, 9,13),f(28, 9,14) / -3.5700000d-05 , -3.5300000d-05 /
      data f(28, 9,15),f(28, 9,16) / -3.5200000d-05 , -3.5700000d-05 /
      data f(28, 9,17),f(28, 9,18) / -3.7100000d-05 , -3.9400000d-05 /
      data f(28, 9,19),f(28, 9,20) / -4.2300000d-05 , -4.5000000d-05 /
      data f(28, 9,21),f(28, 9,22) / -4.5000000d-05 , -4.2300000d-05 /
      data f(28, 9,23) /             -3.9400000d-05 /
      data f(28,10, 1),f(28,10, 2) / -4.7800000d-05 , -5.3100000d-05 /
      data f(28,10, 3),f(28,10, 4) / -5.7400000d-05 , -5.7400000d-05 /
      data f(28,10, 5),f(28,10, 6) / -5.3100000d-05 , -4.7800000d-05 /
      data f(28,10, 7),f(28,10, 8) / -4.3200000d-05 , -3.9600000d-05 /
      data f(28,10, 9),f(28,10,10) / -3.7000000d-05 , -3.5400000d-05 /
      data f(28,10,11),f(28,10,12) / -3.4100000d-05 , -3.3100000d-05 /
      data f(28,10,13),f(28,10,14) / -3.2200000d-05 , -3.1500000d-05 /
      data f(28,10,15),f(28,10,16) / -3.1100000d-05 , -3.1300000d-05 /
      data f(28,10,17),f(28,10,18) / -3.2500000d-05 , -3.4800000d-05 /
      data f(28,10,19),f(28,10,20) / -3.7900000d-05 , -4.0800000d-05 /
      data f(28,10,21),f(28,10,22) / -4.0800000d-05 , -3.7900000d-05 /
      data f(28,10,23) /             -3.4800000d-05 /
      data f(28,11, 1),f(28,11, 2) / -5.2900000d-05 , -5.8900000d-05 /
      data f(28,11, 3),f(28,11, 4) / -6.3700000d-05 , -6.3700000d-05 /
      data f(28,11, 5),f(28,11, 6) / -5.8900000d-05 , -5.2900000d-05 /
      data f(28,11, 7),f(28,11, 8) / -4.7000000d-05 , -4.2200000d-05 /
      data f(28,11, 9),f(28,11,10) / -3.8600000d-05 , -3.5800000d-05 /
      data f(28,11,11),f(28,11,12) / -3.3600000d-05 , -3.1900000d-05 /
      data f(28,11,13),f(28,11,14) / -3.0500000d-05 , -2.9500000d-05 /
      data f(28,11,15),f(28,11,16) / -2.9000000d-05 , -2.9200000d-05 /
      data f(28,11,17),f(28,11,18) / -3.0400000d-05 , -3.2900000d-05 /
      data f(28,11,19),f(28,11,20) / -3.6200000d-05 , -3.9300000d-05 /
      data f(28,11,21),f(28,11,22) / -3.9300000d-05 , -3.6200000d-05 /
      data f(28,11,23) /             -3.2900000d-05 /
      data f(28,12, 1),f(28,12, 2) / -5.8100000d-05 , -6.4200000d-05 /
      data f(28,12, 3),f(28,12, 4) / -6.8900000d-05 , -6.8900000d-05 /
      data f(28,12, 5),f(28,12, 6) / -6.4200000d-05 , -5.8100000d-05 /
      data f(28,12, 7),f(28,12, 8) / -5.1600000d-05 , -4.5600000d-05 /
      data f(28,12, 9),f(28,12,10) / -4.0600000d-05 , -3.6700000d-05 /
      data f(28,12,11),f(28,12,12) / -3.3800000d-05 , -3.1500000d-05 /
      data f(28,12,13),f(28,12,14) / -2.9700000d-05 , -2.8400000d-05 /
      data f(28,12,15),f(28,12,16) / -2.7800000d-05 , -2.8000000d-05 /
      data f(28,12,17),f(28,12,18) / -2.9400000d-05 , -3.1800000d-05 /
      data f(28,12,19),f(28,12,20) / -3.5100000d-05 , -3.8100000d-05 /
      data f(28,12,21),f(28,12,22) / -3.8100000d-05 , -3.5100000d-05 /
      data f(28,12,23) /             -3.1800000d-05 /
      data f(28,13, 1),f(28,13, 2) / -6.1100000d-05 , -6.6800000d-05 /
      data f(28,13, 3),f(28,13, 4) / -7.0900000d-05 , -7.0900000d-05 /
      data f(28,13, 5),f(28,13, 6) / -6.6800000d-05 , -6.1100000d-05 /
      data f(28,13, 7),f(28,13, 8) / -5.4600000d-05 , -4.8100000d-05 /
      data f(28,13, 9),f(28,13,10) / -4.2300000d-05 , -3.7500000d-05 /
      data f(28,13,11),f(28,13,12) / -3.3800000d-05 , -3.1100000d-05 /
      data f(28,13,13),f(28,13,14) / -2.9100000d-05 , -2.7800000d-05 /
      data f(28,13,15),f(28,13,16) / -2.7200000d-05 , -2.7400000d-05 /
      data f(28,13,17),f(28,13,18) / -2.8700000d-05 , -3.1000000d-05 /
      data f(28,13,19),f(28,13,20) / -3.3800000d-05 , -3.6300000d-05 /
      data f(28,13,21),f(28,13,22) / -3.6300000d-05 , -3.3800000d-05 /
      data f(28,13,23) /             -3.1000000d-05 /
      data f(28,14, 1),f(28,14, 2) / -6.1100000d-05 , -6.6100000d-05 /
      data f(28,14, 3),f(28,14, 4) / -6.9700000d-05 , -6.9700000d-05 /
      data f(28,14, 5),f(28,14, 6) / -6.6100000d-05 , -6.1100000d-05 /
      data f(28,14, 7),f(28,14, 8) / -5.5100000d-05 , -4.8900000d-05 /
      data f(28,14, 9),f(28,14,10) / -4.3100000d-05 , -3.8000000d-05 /
      data f(28,14,11),f(28,14,12) / -3.4000000d-05 , -3.1100000d-05 /
      data f(28,14,13),f(28,14,14) / -2.9000000d-05 , -2.7700000d-05 /
      data f(28,14,15),f(28,14,16) / -2.7200000d-05 , -2.7500000d-05 /
      data f(28,14,17),f(28,14,18) / -2.8700000d-05 , -3.0500000d-05 /
      data f(28,14,19),f(28,14,20) / -3.2600000d-05 , -3.4400000d-05 /
      data f(28,14,21),f(28,14,22) / -3.4400000d-05 , -3.2600000d-05 /
      data f(28,14,23) /             -3.0500000d-05 /
      data f(28,15, 1),f(28,15, 2) / -5.8500000d-05 , -6.2600000d-05 /
      data f(28,15, 3),f(28,15, 4) / -6.5500000d-05 , -6.5500000d-05 /
      data f(28,15, 5),f(28,15, 6) / -6.2600000d-05 , -5.8500000d-05 /
      data f(28,15, 7),f(28,15, 8) / -5.3500000d-05 , -4.8200000d-05 /
      data f(28,15, 9),f(28,15,10) / -4.3100000d-05 , -3.8500000d-05 /
      data f(28,15,11),f(28,15,12) / -3.4700000d-05 , -3.1900000d-05 /
      data f(28,15,13),f(28,15,14) / -2.9900000d-05 , -2.8800000d-05 /
      data f(28,15,15),f(28,15,16) / -2.8300000d-05 , -2.8600000d-05 /
      data f(28,15,17),f(28,15,18) / -2.9500000d-05 , -3.0800000d-05 /
      data f(28,15,19),f(28,15,20) / -3.2200000d-05 , -3.3300000d-05 /
      data f(28,15,21),f(28,15,22) / -3.3300000d-05 , -3.2200000d-05 /
      data f(28,15,23) /             -3.0800000d-05 /
      data f(28,16, 1),f(28,16, 2) / -5.3900000d-05 , -5.6900000d-05 /
      data f(28,16, 3),f(28,16, 4) / -5.8900000d-05 , -5.8900000d-05 /
      data f(28,16, 5),f(28,16, 6) / -5.6900000d-05 , -5.3900000d-05 /
      data f(28,16, 7),f(28,16, 8) / -5.0200000d-05 , -4.6300000d-05 /
      data f(28,16, 9),f(28,16,10) / -4.2400000d-05 , -3.8900000d-05 /
      data f(28,16,11),f(28,16,12) / -3.5900000d-05 , -3.3600000d-05 /
      data f(28,16,13),f(28,16,14) / -3.1900000d-05 , -3.0900000d-05 /
      data f(28,16,15),f(28,16,16) / -3.0500000d-05 , -3.0600000d-05 /
      data f(28,16,17),f(28,16,18) / -3.1100000d-05 , -3.1800000d-05 /
      data f(28,16,19),f(28,16,20) / -3.2500000d-05 , -3.3100000d-05 /
      data f(28,16,21),f(28,16,22) / -3.3100000d-05 , -3.2500000d-05 /
      data f(28,16,23) /             -3.1800000d-05 /
      data f(28,17, 1),f(28,17, 2) / -4.8200000d-05 , -4.9900000d-05 /
      data f(28,17, 3),f(28,17, 4) / -5.1000000d-05 , -5.1000000d-05 /
      data f(28,17, 5),f(28,17, 6) / -4.9900000d-05 , -4.8200000d-05 /
      data f(28,17, 7),f(28,17, 8) / -4.6100000d-05 , -4.3800000d-05 /
      data f(28,17, 9),f(28,17,10) / -4.1500000d-05 , -3.9300000d-05 /
      data f(28,17,11),f(28,17,12) / -3.7300000d-05 , -3.5700000d-05 /
      data f(28,17,13),f(28,17,14) / -3.4500000d-05 , -3.3700000d-05 /
      data f(28,17,15),f(28,17,16) / -3.3300000d-05 , -3.3100000d-05 /
      data f(28,17,17),f(28,17,18) / -3.3200000d-05 , -3.3400000d-05 /
      data f(28,17,19),f(28,17,20) / -3.3600000d-05 , -3.3800000d-05 /
      data f(28,17,21),f(28,17,22) / -3.3800000d-05 , -3.3600000d-05 /
      data f(28,17,23) /             -3.3400000d-05 /
      data f(28,18, 1),f(28,18, 2) / -4.2800000d-05 , -4.3400000d-05 /
      data f(28,18, 3),f(28,18, 4) / -4.3700000d-05 , -4.3700000d-05 /
      data f(28,18, 5),f(28,18, 6) / -4.3400000d-05 , -4.2800000d-05 /
      data f(28,18, 7),f(28,18, 8) / -4.2000000d-05 , -4.1100000d-05 /
      data f(28,18, 9),f(28,18,10) / -4.0200000d-05 , -3.9300000d-05 /
      data f(28,18,11),f(28,18,12) / -3.8400000d-05 , -3.7700000d-05 /
      data f(28,18,13),f(28,18,14) / -3.7000000d-05 , -3.6500000d-05 /
      data f(28,18,15),f(28,18,16) / -3.6100000d-05 , -3.5800000d-05 /
      data f(28,18,17),f(28,18,18) / -3.5600000d-05 , -3.5500000d-05 /
      data f(28,18,19),f(28,18,20) / -3.5400000d-05 , -3.5400000d-05 /
      data f(28,18,21),f(28,18,22) / -3.5400000d-05 , -3.5400000d-05 /
      data f(28,18,23) /             -3.5500000d-05 /
      data f(28,19, 1),f(28,19, 2) / -3.8400000d-05 , -3.8400000d-05 /
      data f(28,19, 3),f(28,19, 4) / -3.8400000d-05 , -3.8400000d-05 /
      data f(28,19, 5),f(28,19, 6) / -3.8400000d-05 , -3.8400000d-05 /
      data f(28,19, 7),f(28,19, 8) / -3.8400000d-05 , -3.8400000d-05 /
      data f(28,19, 9),f(28,19,10) / -3.8400000d-05 , -3.8400000d-05 /
      data f(28,19,11),f(28,19,12) / -3.8400000d-05 , -3.8400000d-05 /
      data f(28,19,13),f(28,19,14) / -3.8400000d-05 , -3.8400000d-05 /
      data f(28,19,15),f(28,19,16) / -3.8400000d-05 , -3.8400000d-05 /
      data f(28,19,17),f(28,19,18) / -3.8400000d-05 , -3.8400000d-05 /
      data f(28,19,19),f(28,19,20) / -3.8400000d-05 , -3.8400000d-05 /
      data f(28,19,21),f(28,19,22) / -3.8400000d-05 , -3.8400000d-05 /
      data f(28,19,23) /             -3.8400000d-05 /
      data f(29, 1, 1),f(29, 1, 2) / -7.2600000d-05 , -7.2600000d-05 /
      data f(29, 1, 3),f(29, 1, 4) / -7.2600000d-05 , -7.2600000d-05 /
      data f(29, 1, 5),f(29, 1, 6) / -7.2600000d-05 , -7.2600000d-05 /
      data f(29, 1, 7),f(29, 1, 8) / -7.2600000d-05 , -7.2600000d-05 /
      data f(29, 1, 9),f(29, 1,10) / -7.2600000d-05 , -7.2600000d-05 /
      data f(29, 1,11),f(29, 1,12) / -7.2600000d-05 , -7.2600000d-05 /
      data f(29, 1,13),f(29, 1,14) / -7.2600000d-05 , -7.2600000d-05 /
      data f(29, 1,15),f(29, 1,16) / -7.2600000d-05 , -7.2600000d-05 /
      data f(29, 1,17),f(29, 1,18) / -7.2600000d-05 , -7.2600000d-05 /
      data f(29, 1,19),f(29, 1,20) / -7.2600000d-05 , -7.2600000d-05 /
      data f(29, 1,21),f(29, 1,22) / -7.2600000d-05 , -7.2600000d-05 /
      data f(29, 1,23) /             -7.2600000d-05 /
      data f(29, 2, 1),f(29, 2, 2) / -7.0500000d-05 , -7.0900000d-05 /
      data f(29, 2, 3),f(29, 2, 4) / -7.1200000d-05 , -7.1200000d-05 /
      data f(29, 2, 5),f(29, 2, 6) / -7.0900000d-05 , -7.0500000d-05 /
      data f(29, 2, 7),f(29, 2, 8) / -7.0100000d-05 , -6.9700000d-05 /
      data f(29, 2, 9),f(29, 2,10) / -6.9400000d-05 , -6.9300000d-05 /
      data f(29, 2,11),f(29, 2,12) / -6.9300000d-05 , -6.9400000d-05 /
      data f(29, 2,13),f(29, 2,14) / -6.9800000d-05 , -7.0300000d-05 /
      data f(29, 2,15),f(29, 2,16) / -7.0900000d-05 , -7.1600000d-05 /
      data f(29, 2,17),f(29, 2,18) / -7.2300000d-05 , -7.3000000d-05 /
      data f(29, 2,19),f(29, 2,20) / -7.3600000d-05 , -7.4100000d-05 /
      data f(29, 2,21),f(29, 2,22) / -7.4100000d-05 , -7.3600000d-05 /
      data f(29, 2,23) /             -7.3000000d-05 /
      data f(29, 3, 1),f(29, 3, 2) / -6.6500000d-05 , -6.7900000d-05 /
      data f(29, 3, 3),f(29, 3, 4) / -6.8900000d-05 , -6.8900000d-05 /
      data f(29, 3, 5),f(29, 3, 6) / -6.7900000d-05 , -6.6500000d-05 /
      data f(29, 3, 7),f(29, 3, 8) / -6.5100000d-05 , -6.3700000d-05 /
      data f(29, 3, 9),f(29, 3,10) / -6.2700000d-05 , -6.2100000d-05 /
      data f(29, 3,11),f(29, 3,12) / -6.1900000d-05 , -6.2100000d-05 /
      data f(29, 3,13),f(29, 3,14) / -6.2600000d-05 , -6.3500000d-05 /
      data f(29, 3,15),f(29, 3,16) / -6.4700000d-05 , -6.6200000d-05 /
      data f(29, 3,17),f(29, 3,18) / -6.7900000d-05 , -6.9800000d-05 /
      data f(29, 3,19),f(29, 3,20) / -7.1400000d-05 , -7.2600000d-05 /
      data f(29, 3,21),f(29, 3,22) / -7.2600000d-05 , -7.1400000d-05 /
      data f(29, 3,23) /             -6.9800000d-05 /
      data f(29, 4, 1),f(29, 4, 2) / -5.9600000d-05 , -6.2100000d-05 /
      data f(29, 4, 3),f(29, 4, 4) / -6.4000000d-05 , -6.4000000d-05 /
      data f(29, 4, 5),f(29, 4, 6) / -6.2100000d-05 , -5.9600000d-05 /
      data f(29, 4, 7),f(29, 4, 8) / -5.7100000d-05 , -5.5100000d-05 /
      data f(29, 4, 9),f(29, 4,10) / -5.3800000d-05 , -5.3000000d-05 /
      data f(29, 4,11),f(29, 4,12) / -5.2900000d-05 , -5.3000000d-05 /
      data f(29, 4,13),f(29, 4,14) / -5.3500000d-05 , -5.4200000d-05 /
      data f(29, 4,15),f(29, 4,16) / -5.5300000d-05 , -5.6900000d-05 /
      data f(29, 4,17),f(29, 4,18) / -5.9000000d-05 , -6.1500000d-05 /
      data f(29, 4,19),f(29, 4,20) / -6.4000000d-05 , -6.6000000d-05 /
      data f(29, 4,21),f(29, 4,22) / -6.6000000d-05 , -6.4000000d-05 /
      data f(29, 4,23) /             -6.1500000d-05 /
      data f(29, 5, 1),f(29, 5, 2) / -5.1100000d-05 , -5.4300000d-05 /
      data f(29, 5, 3),f(29, 5, 4) / -5.7000000d-05 , -5.7000000d-05 /
      data f(29, 5, 5),f(29, 5, 6) / -5.4300000d-05 , -5.1100000d-05 /
      data f(29, 5, 7),f(29, 5, 8) / -4.8200000d-05 , -4.6000000d-05 /
      data f(29, 5, 9),f(29, 5,10) / -4.4600000d-05 , -4.3900000d-05 /
      data f(29, 5,11),f(29, 5,12) / -4.3800000d-05 , -4.3900000d-05 /
      data f(29, 5,13),f(29, 5,14) / -4.4200000d-05 , -4.4600000d-05 /
      data f(29, 5,15),f(29, 5,16) / -4.5400000d-05 , -4.6700000d-05 /
      data f(29, 5,17),f(29, 5,18) / -4.8600000d-05 , -5.1100000d-05 /
      data f(29, 5,19),f(29, 5,20) / -5.3800000d-05 , -5.6200000d-05 /
      data f(29, 5,21),f(29, 5,22) / -5.6200000d-05 , -5.3800000d-05 /
      data f(29, 5,23) /             -5.1100000d-05 /
      data f(29, 6, 1),f(29, 6, 2) / -4.1800000d-05 , -4.4900000d-05 /
      data f(29, 6, 3),f(29, 6, 4) / -4.7700000d-05 , -4.7700000d-05 /
      data f(29, 6, 5),f(29, 6, 6) / -4.4900000d-05 , -4.1800000d-05 /
      data f(29, 6, 7),f(29, 6, 8) / -3.9200000d-05 , -3.7300000d-05 /
      data f(29, 6, 9),f(29, 6,10) / -3.6300000d-05 , -3.5800000d-05 /
      data f(29, 6,11),f(29, 6,12) / -3.5600000d-05 , -3.5600000d-05 /
      data f(29, 6,13),f(29, 6,14) / -3.5700000d-05 , -3.5900000d-05 /
      data f(29, 6,15),f(29, 6,16) / -3.6500000d-05 , -3.7500000d-05 /
      data f(29, 6,17),f(29, 6,18) / -3.9100000d-05 , -4.1400000d-05 /
      data f(29, 6,19),f(29, 6,20) / -4.4000000d-05 , -4.6300000d-05 /
      data f(29, 6,21),f(29, 6,22) / -4.6300000d-05 , -4.4000000d-05 /
      data f(29, 6,23) /             -4.1400000d-05 /
      data f(29, 7, 1),f(29, 7, 2) / -3.3100000d-05 , -3.5700000d-05 /
      data f(29, 7, 3),f(29, 7, 4) / -3.8000000d-05 , -3.8000000d-05 /
      data f(29, 7, 5),f(29, 7, 6) / -3.5700000d-05 , -3.3100000d-05 /
      data f(29, 7, 7),f(29, 7, 8) / -3.1100000d-05 , -2.9900000d-05 /
      data f(29, 7, 9),f(29, 7,10) / -2.9200000d-05 , -2.9000000d-05 /
      data f(29, 7,11),f(29, 7,12) / -2.8800000d-05 , -2.8700000d-05 /
      data f(29, 7,13),f(29, 7,14) / -2.8700000d-05 , -2.8700000d-05 /
      data f(29, 7,15),f(29, 7,16) / -2.9000000d-05 , -2.9700000d-05 /
      data f(29, 7,17),f(29, 7,18) / -3.1100000d-05 , -3.3100000d-05 /
      data f(29, 7,19),f(29, 7,20) / -3.5500000d-05 , -3.7700000d-05 /
      data f(29, 7,21),f(29, 7,22) / -3.7700000d-05 , -3.5500000d-05 /
      data f(29, 7,23) /             -3.3100000d-05 /
      data f(29, 8, 1),f(29, 8, 2) / -2.7500000d-05 , -2.9800000d-05 /
      data f(29, 8, 3),f(29, 8, 4) / -3.1800000d-05 , -3.1800000d-05 /
      data f(29, 8, 5),f(29, 8, 6) / -2.9800000d-05 , -2.7500000d-05 /
      data f(29, 8, 7),f(29, 8, 8) / -2.5700000d-05 , -2.4600000d-05 /
      data f(29, 8, 9),f(29, 8,10) / -2.4100000d-05 , -2.3900000d-05 /
      data f(29, 8,11),f(29, 8,12) / -2.3800000d-05 , -2.3600000d-05 /
      data f(29, 8,13),f(29, 8,14) / -2.3400000d-05 , -2.3200000d-05 /
      data f(29, 8,15),f(29, 8,16) / -2.3300000d-05 , -2.3800000d-05 /
      data f(29, 8,17),f(29, 8,18) / -2.5000000d-05 , -2.6700000d-05 /
      data f(29, 8,19),f(29, 8,20) / -2.8900000d-05 , -3.0900000d-05 /
      data f(29, 8,21),f(29, 8,22) / -3.0900000d-05 , -2.8900000d-05 /
      data f(29, 8,23) /             -2.6700000d-05 /
      data f(29, 9, 1),f(29, 9, 2) / -2.6000000d-05 , -2.8400000d-05 /
      data f(29, 9, 3),f(29, 9, 4) / -3.0500000d-05 , -3.0500000d-05 /
      data f(29, 9, 5),f(29, 9, 6) / -2.8400000d-05 , -2.6000000d-05 /
      data f(29, 9, 7),f(29, 9, 8) / -2.3900000d-05 , -2.2400000d-05 /
      data f(29, 9, 9),f(29, 9,10) / -2.1500000d-05 , -2.1100000d-05 /
      data f(29, 9,11),f(29, 9,12) / -2.0700000d-05 , -2.0300000d-05 /
      data f(29, 9,13),f(29, 9,14) / -2.0000000d-05 , -1.9700000d-05 /
      data f(29, 9,15),f(29, 9,16) / -1.9700000d-05 , -2.0100000d-05 /
      data f(29, 9,17),f(29, 9,18) / -2.1100000d-05 , -2.2800000d-05 /
      data f(29, 9,19),f(29, 9,20) / -2.4900000d-05 , -2.6700000d-05 /
      data f(29, 9,21),f(29, 9,22) / -2.6700000d-05 , -2.4900000d-05 /
      data f(29, 9,23) /             -2.2800000d-05 /
      data f(29,10, 1),f(29,10, 2) / -2.7600000d-05 , -3.0400000d-05 /
      data f(29,10, 3),f(29,10, 4) / -3.2700000d-05 , -3.2700000d-05 /
      data f(29,10, 5),f(29,10, 6) / -3.0400000d-05 , -2.7600000d-05 /
      data f(29,10, 7),f(29,10, 8) / -2.4900000d-05 , -2.2900000d-05 /
      data f(29,10, 9),f(29,10,10) / -2.1300000d-05 , -2.0300000d-05 /
      data f(29,10,11),f(29,10,12) / -1.9400000d-05 , -1.8800000d-05 /
      data f(29,10,13),f(29,10,14) / -1.8200000d-05 , -1.7800000d-05 /
      data f(29,10,15),f(29,10,16) / -1.7700000d-05 , -1.8100000d-05 /
      data f(29,10,17),f(29,10,18) / -1.9200000d-05 , -2.0900000d-05 /
      data f(29,10,19),f(29,10,20) / -2.3100000d-05 , -2.5100000d-05 /
      data f(29,10,21),f(29,10,22) / -2.5100000d-05 , -2.3100000d-05 /
      data f(29,10,23) /             -2.0900000d-05 /
      data f(29,11, 1),f(29,11, 2) / -3.0500000d-05 , -3.3700000d-05 /
      data f(29,11, 3),f(29,11, 4) / -3.6200000d-05 , -3.6200000d-05 /
      data f(29,11, 5),f(29,11, 6) / -3.3700000d-05 , -3.0500000d-05 /
      data f(29,11, 7),f(29,11, 8) / -2.7300000d-05 , -2.4500000d-05 /
      data f(29,11, 9),f(29,11,10) / -2.2300000d-05 , -2.0600000d-05 /
      data f(29,11,11),f(29,11,12) / -1.9300000d-05 , -1.8200000d-05 /
      data f(29,11,13),f(29,11,14) / -1.7400000d-05 , -1.6800000d-05 /
      data f(29,11,15),f(29,11,16) / -1.6700000d-05 , -1.7100000d-05 /
      data f(29,11,17),f(29,11,18) / -1.8200000d-05 , -2.0200000d-05 /
      data f(29,11,19),f(29,11,20) / -2.2600000d-05 , -2.4600000d-05 /
      data f(29,11,21),f(29,11,22) / -2.4600000d-05 , -2.2600000d-05 /
      data f(29,11,23) /             -2.0200000d-05 /
      data f(29,12, 1),f(29,12, 2) / -3.3300000d-05 , -3.6600000d-05 /
      data f(29,12, 3),f(29,12, 4) / -3.9000000d-05 , -3.9000000d-05 /
      data f(29,12, 5),f(29,12, 6) / -3.6600000d-05 , -3.3300000d-05 /
      data f(29,12, 7),f(29,12, 8) / -2.9700000d-05 , -2.6400000d-05 /
      data f(29,12, 9),f(29,12,10) / -2.3500000d-05 , -2.1200000d-05 /
      data f(29,12,11),f(29,12,12) / -1.9400000d-05 , -1.8000000d-05 /
      data f(29,12,13),f(29,12,14) / -1.6900000d-05 , -1.6200000d-05 /
      data f(29,12,15),f(29,12,16) / -1.6000000d-05 , -1.6400000d-05 /
      data f(29,12,17),f(29,12,18) / -1.7600000d-05 , -1.9600000d-05 /
      data f(29,12,19),f(29,12,20) / -2.2000000d-05 , -2.4000000d-05 /
      data f(29,12,21),f(29,12,22) / -2.4000000d-05 , -2.2000000d-05 /
      data f(29,12,23) /             -1.9600000d-05 /
      data f(29,13, 1),f(29,13, 2) / -3.4700000d-05 , -3.7900000d-05 /
      data f(29,13, 3),f(29,13, 4) / -4.0100000d-05 , -4.0100000d-05 /
      data f(29,13, 5),f(29,13, 6) / -3.7900000d-05 , -3.4700000d-05 /
      data f(29,13, 7),f(29,13, 8) / -3.1200000d-05 , -2.7700000d-05 /
      data f(29,13, 9),f(29,13,10) / -2.4500000d-05 , -2.1700000d-05 /
      data f(29,13,11),f(29,13,12) / -1.9500000d-05 , -1.7900000d-05 /
      data f(29,13,13),f(29,13,14) / -1.6600000d-05 , -1.5800000d-05 /
      data f(29,13,15),f(29,13,16) / -1.5600000d-05 , -1.6000000d-05 /
      data f(29,13,17),f(29,13,18) / -1.7000000d-05 , -1.8800000d-05 /
      data f(29,13,19),f(29,13,20) / -2.0800000d-05 , -2.2600000d-05 /
      data f(29,13,21),f(29,13,22) / -2.2600000d-05 , -2.0800000d-05 /
      data f(29,13,23) /             -1.8800000d-05 /
      data f(29,14, 1),f(29,14, 2) / -3.4600000d-05 , -3.7400000d-05 /
      data f(29,14, 3),f(29,14, 4) / -3.9300000d-05 , -3.9300000d-05 /
      data f(29,14, 5),f(29,14, 6) / -3.7400000d-05 , -3.4600000d-05 /
      data f(29,14, 7),f(29,14, 8) / -3.1400000d-05 , -2.8100000d-05 /
      data f(29,14, 9),f(29,14,10) / -2.4900000d-05 , -2.2100000d-05 /
      data f(29,14,11),f(29,14,12) / -1.9800000d-05 , -1.8000000d-05 /
      data f(29,14,13),f(29,14,14) / -1.6800000d-05 , -1.6000000d-05 /
      data f(29,14,15),f(29,14,16) / -1.5700000d-05 , -1.6000000d-05 /
      data f(29,14,17),f(29,14,18) / -1.6800000d-05 , -1.8100000d-05 /
      data f(29,14,19),f(29,14,20) / -1.9600000d-05 , -2.0800000d-05 /
      data f(29,14,21),f(29,14,22) / -2.0800000d-05 , -1.9600000d-05 /
      data f(29,14,23) /             -1.8100000d-05 /
      data f(29,15, 1),f(29,15, 2) / -3.3200000d-05 , -3.5400000d-05 /
      data f(29,15, 3),f(29,15, 4) / -3.6900000d-05 , -3.6900000d-05 /
      data f(29,15, 5),f(29,15, 6) / -3.5400000d-05 , -3.3200000d-05 /
      data f(29,15, 7),f(29,15, 8) / -3.0500000d-05 , -2.7600000d-05 /
      data f(29,15, 9),f(29,15,10) / -2.4900000d-05 , -2.2400000d-05 /
      data f(29,15,11),f(29,15,12) / -2.0300000d-05 , -1.8700000d-05 /
      data f(29,15,13),f(29,15,14) / -1.7500000d-05 , -1.6800000d-05 /
      data f(29,15,15),f(29,15,16) / -1.6500000d-05 , -1.6700000d-05 /
      data f(29,15,17),f(29,15,18) / -1.7200000d-05 , -1.8000000d-05 /
      data f(29,15,19),f(29,15,20) / -1.8900000d-05 , -1.9700000d-05 /
      data f(29,15,21),f(29,15,22) / -1.9700000d-05 , -1.8900000d-05 /
      data f(29,15,23) /             -1.8000000d-05 /
      data f(29,16, 1),f(29,16, 2) / -3.0700000d-05 , -3.2200000d-05 /
      data f(29,16, 3),f(29,16, 4) / -3.3300000d-05 , -3.3300000d-05 /
      data f(29,16, 5),f(29,16, 6) / -3.2200000d-05 , -3.0700000d-05 /
      data f(29,16, 7),f(29,16, 8) / -2.8800000d-05 , -2.6700000d-05 /
      data f(29,16, 9),f(29,16,10) / -2.4700000d-05 , -2.2800000d-05 /
      data f(29,16,11),f(29,16,12) / -2.1200000d-05 , -1.9900000d-05 /
      data f(29,16,13),f(29,16,14) / -1.8900000d-05 , -1.8300000d-05 /
      data f(29,16,15),f(29,16,16) / -1.8000000d-05 , -1.8000000d-05 /
      data f(29,16,17),f(29,16,18) / -1.8300000d-05 , -1.8700000d-05 /
      data f(29,16,19),f(29,16,20) / -1.9100000d-05 , -1.9400000d-05 /
      data f(29,16,21),f(29,16,22) / -1.9400000d-05 , -1.9100000d-05 /
      data f(29,16,23) /             -1.8700000d-05 /
      data f(29,17, 1),f(29,17, 2) / -2.7800000d-05 , -2.8600000d-05 /
      data f(29,17, 3),f(29,17, 4) / -2.9200000d-05 , -2.9200000d-05 /
      data f(29,17, 5),f(29,17, 6) / -2.8600000d-05 , -2.7800000d-05 /
      data f(29,17, 7),f(29,17, 8) / -2.6700000d-05 , -2.5500000d-05 /
      data f(29,17, 9),f(29,17,10) / -2.4300000d-05 , -2.3200000d-05 /
      data f(29,17,11),f(29,17,12) / -2.2200000d-05 , -2.1300000d-05 /
      data f(29,17,13),f(29,17,14) / -2.0600000d-05 , -2.0200000d-05 /
      data f(29,17,15),f(29,17,16) / -1.9900000d-05 , -1.9700000d-05 /
      data f(29,17,17),f(29,17,18) / -1.9700000d-05 , -1.9800000d-05 /
      data f(29,17,19),f(29,17,20) / -1.9900000d-05 , -2.0000000d-05 /
      data f(29,17,21),f(29,17,22) / -2.0000000d-05 , -1.9900000d-05 /
      data f(29,17,23) /             -1.9800000d-05 /
      data f(29,18, 1),f(29,18, 2) / -2.5100000d-05 , -2.5400000d-05 /
      data f(29,18, 3),f(29,18, 4) / -2.5600000d-05 , -2.5600000d-05 /
      data f(29,18, 5),f(29,18, 6) / -2.5400000d-05 , -2.5100000d-05 /
      data f(29,18, 7),f(29,18, 8) / -2.4700000d-05 , -2.4200000d-05 /
      data f(29,18, 9),f(29,18,10) / -2.3800000d-05 , -2.3300000d-05 /
      data f(29,18,11),f(29,18,12) / -2.2900000d-05 , -2.2400000d-05 /
      data f(29,18,13),f(29,18,14) / -2.2100000d-05 , -2.1800000d-05 /
      data f(29,18,15),f(29,18,16) / -2.1600000d-05 , -2.1400000d-05 /
      data f(29,18,17),f(29,18,18) / -2.1300000d-05 , -2.1200000d-05 /
      data f(29,18,19),f(29,18,20) / -2.1200000d-05 , -2.1200000d-05 /
      data f(29,18,21),f(29,18,22) / -2.1200000d-05 , -2.1200000d-05 /
      data f(29,18,23) /             -2.1200000d-05 /
      data f(29,19, 1),f(29,19, 2) / -2.2900000d-05 , -2.2900000d-05 /
      data f(29,19, 3),f(29,19, 4) / -2.2900000d-05 , -2.2900000d-05 /
      data f(29,19, 5),f(29,19, 6) / -2.2900000d-05 , -2.2900000d-05 /
      data f(29,19, 7),f(29,19, 8) / -2.2900000d-05 , -2.2900000d-05 /
      data f(29,19, 9),f(29,19,10) / -2.2900000d-05 , -2.2900000d-05 /
      data f(29,19,11),f(29,19,12) / -2.2900000d-05 , -2.2900000d-05 /
      data f(29,19,13),f(29,19,14) / -2.2900000d-05 , -2.2900000d-05 /
      data f(29,19,15),f(29,19,16) / -2.2900000d-05 , -2.2900000d-05 /
      data f(29,19,17),f(29,19,18) / -2.2900000d-05 , -2.2900000d-05 /
      data f(29,19,19),f(29,19,20) / -2.2900000d-05 , -2.2900000d-05 /
      data f(29,19,21),f(29,19,22) / -2.2900000d-05 , -2.2900000d-05 /
      data f(29,19,23) /             -2.2900000d-05 /
      data f(30, 1, 1),f(30, 1, 2) / -1.6800000d-05 , -1.6800000d-05 /
      data f(30, 1, 3),f(30, 1, 4) / -1.6800000d-05 , -1.6800000d-05 /
      data f(30, 1, 5),f(30, 1, 6) / -1.6800000d-05 , -1.6800000d-05 /
      data f(30, 1, 7),f(30, 1, 8) / -1.6800000d-05 , -1.6800000d-05 /
      data f(30, 1, 9),f(30, 1,10) / -1.6800000d-05 , -1.6800000d-05 /
      data f(30, 1,11),f(30, 1,12) / -1.6800000d-05 , -1.6800000d-05 /
      data f(30, 1,13),f(30, 1,14) / -1.6800000d-05 , -1.6800000d-05 /
      data f(30, 1,15),f(30, 1,16) / -1.6800000d-05 , -1.6800000d-05 /
      data f(30, 1,17),f(30, 1,18) / -1.6800000d-05 , -1.6800000d-05 /
      data f(30, 1,19),f(30, 1,20) / -1.6800000d-05 , -1.6800000d-05 /
      data f(30, 1,21),f(30, 1,22) / -1.6800000d-05 , -1.6800000d-05 /
      data f(30, 1,23) /             -1.6800000d-05 /
      data f(30, 2, 1),f(30, 2, 2) / -1.6000000d-05 , -1.6100000d-05 /
      data f(30, 2, 3),f(30, 2, 4) / -1.6200000d-05 , -1.6200000d-05 /
      data f(30, 2, 5),f(30, 2, 6) / -1.6100000d-05 , -1.6000000d-05 /
      data f(30, 2, 7),f(30, 2, 8) / -1.5900000d-05 , -1.5800000d-05 /
      data f(30, 2, 9),f(30, 2,10) / -1.5700000d-05 , -1.5700000d-05 /
      data f(30, 2,11),f(30, 2,12) / -1.5700000d-05 , -1.5800000d-05 /
      data f(30, 2,13),f(30, 2,14) / -1.5900000d-05 , -1.6100000d-05 /
      data f(30, 2,15),f(30, 2,16) / -1.6300000d-05 , -1.6600000d-05 /
      data f(30, 2,17),f(30, 2,18) / -1.6900000d-05 , -1.7100000d-05 /
      data f(30, 2,19),f(30, 2,20) / -1.7300000d-05 , -1.7500000d-05 /
      data f(30, 2,21),f(30, 2,22) / -1.7500000d-05 , -1.7300000d-05 /
      data f(30, 2,23) /             -1.7100000d-05 /
      data f(30, 3, 1),f(30, 3, 2) / -1.5000000d-05 , -1.5400000d-05 /
      data f(30, 3, 3),f(30, 3, 4) / -1.5700000d-05 , -1.5700000d-05 /
      data f(30, 3, 5),f(30, 3, 6) / -1.5400000d-05 , -1.5000000d-05 /
      data f(30, 3, 7),f(30, 3, 8) / -1.4400000d-05 , -1.4000000d-05 /
      data f(30, 3, 9),f(30, 3,10) / -1.3600000d-05 , -1.3300000d-05 /
      data f(30, 3,11),f(30, 3,12) / -1.3200000d-05 , -1.3300000d-05 /
      data f(30, 3,13),f(30, 3,14) / -1.3500000d-05 , -1.3900000d-05 /
      data f(30, 3,15),f(30, 3,16) / -1.4400000d-05 , -1.5100000d-05 /
      data f(30, 3,17),f(30, 3,18) / -1.5900000d-05 , -1.6600000d-05 /
      data f(30, 3,19),f(30, 3,20) / -1.7200000d-05 , -1.7700000d-05 /
      data f(30, 3,21),f(30, 3,22) / -1.7700000d-05 , -1.7200000d-05 /
      data f(30, 3,23) /             -1.6600000d-05 /
      data f(30, 4, 1),f(30, 4, 2) / -1.3700000d-05 , -1.4700000d-05 /
      data f(30, 4, 3),f(30, 4, 4) / -1.5400000d-05 , -1.5400000d-05 /
      data f(30, 4, 5),f(30, 4, 6) / -1.4700000d-05 , -1.3700000d-05 /
      data f(30, 4, 7),f(30, 4, 8) / -1.2700000d-05 , -1.1800000d-05 /
      data f(30, 4, 9),f(30, 4,10) / -1.1200000d-05 , -1.0700000d-05 /
      data f(30, 4,11),f(30, 4,12) / -1.0500000d-05 , -1.0500000d-05 /
      data f(30, 4,13),f(30, 4,14) / -1.0700000d-05 , -1.1200000d-05 /
      data f(30, 4,15),f(30, 4,16) / -1.1900000d-05 , -1.2800000d-05 /
      data f(30, 4,17),f(30, 4,18) / -1.3900000d-05 , -1.5100000d-05 /
      data f(30, 4,19),f(30, 4,20) / -1.6300000d-05 , -1.7100000d-05 /
      data f(30, 4,21),f(30, 4,22) / -1.7100000d-05 , -1.6300000d-05 /
      data f(30, 4,23) /             -1.5100000d-05 /
      data f(30, 5, 1),f(30, 5, 2) / -1.2100000d-05 , -1.3400000d-05 /
      data f(30, 5, 3),f(30, 5, 4) / -1.4400000d-05 , -1.4400000d-05 /
      data f(30, 5, 5),f(30, 5, 6) / -1.3400000d-05 , -1.2100000d-05 /
      data f(30, 5, 7),f(30, 5, 8) / -1.0800000d-05 , -9.7000000d-06 /
      data f(30, 5, 9),f(30, 5,10) / -9.0000000d-06 , -8.5000000d-06 /
      data f(30, 5,11),f(30, 5,12) / -8.3000000d-06 , -8.2000000d-06 /
      data f(30, 5,13),f(30, 5,14) / -8.4000000d-06 , -8.7000000d-06 /
      data f(30, 5,15),f(30, 5,16) / -9.4000000d-06 , -1.0300000d-05 /
      data f(30, 5,17),f(30, 5,18) / -1.1500000d-05 , -1.3000000d-05 /
      data f(30, 5,19),f(30, 5,20) / -1.4400000d-05 , -1.5400000d-05 /
      data f(30, 5,21),f(30, 5,22) / -1.5400000d-05 , -1.4400000d-05 /
      data f(30, 5,23) /             -1.3000000d-05 /
      data f(30, 6, 1),f(30, 6, 2) / -1.0100000d-05 , -1.1400000d-05 /
      data f(30, 6, 3),f(30, 6, 4) / -1.2400000d-05 , -1.2400000d-05 /
      data f(30, 6, 5),f(30, 6, 6) / -1.1400000d-05 , -1.0100000d-05 /
      data f(30, 6, 7),f(30, 6, 8) / -8.8000000d-06 , -7.8000000d-06 /
      data f(30, 6, 9),f(30, 6,10) / -7.1000000d-06 , -6.7000000d-06 /
      data f(30, 6,11),f(30, 6,12) / -6.6000000d-06 , -6.5000000d-06 /
      data f(30, 6,13),f(30, 6,14) / -6.6000000d-06 , -6.8000000d-06 /
      data f(30, 6,15),f(30, 6,16) / -7.3000000d-06 , -8.1000000d-06 /
      data f(30, 6,17),f(30, 6,18) / -9.1000000d-06 , -1.0500000d-05 /
      data f(30, 6,19),f(30, 6,20) / -1.1800000d-05 , -1.2800000d-05 /
      data f(30, 6,21),f(30, 6,22) / -1.2800000d-05 , -1.1800000d-05 /
      data f(30, 6,23) /             -1.0500000d-05 /
      data f(30, 7, 1),f(30, 7, 2) / -8.0000000d-06 , -9.1000000d-06 /
      data f(30, 7, 3),f(30, 7, 4) / -9.9000000d-06 , -9.9000000d-06 /
      data f(30, 7, 5),f(30, 7, 6) / -9.1000000d-06 , -8.0000000d-06 /
      data f(30, 7, 7),f(30, 7, 8) / -7.0000000d-06 , -6.2000000d-06 /
      data f(30, 7, 9),f(30, 7,10) / -5.7000000d-06 , -5.5000000d-06 /
      data f(30, 7,11),f(30, 7,12) / -5.3000000d-06 , -5.3000000d-06 /
      data f(30, 7,13),f(30, 7,14) / -5.3000000d-06 , -5.5000000d-06 /
      data f(30, 7,15),f(30, 7,16) / -5.8000000d-06 , -6.3000000d-06 /
      data f(30, 7,17),f(30, 7,18) / -7.1000000d-06 , -8.2000000d-06 /
      data f(30, 7,19),f(30, 7,20) / -9.2000000d-06 , -1.0000000d-05 /
      data f(30, 7,21),f(30, 7,22) / -1.0000000d-05 , -9.2000000d-06 /
      data f(30, 7,23) /             -8.2000000d-06 /
      data f(30, 8, 1),f(30, 8, 2) / -6.5000000d-06 , -7.3000000d-06 /
      data f(30, 8, 3),f(30, 8, 4) / -7.9000000d-06 , -7.9000000d-06 /
      data f(30, 8, 5),f(30, 8, 6) / -7.3000000d-06 , -6.5000000d-06 /
      data f(30, 8, 7),f(30, 8, 8) / -5.8000000d-06 , -5.2000000d-06 /
      data f(30, 8, 9),f(30, 8,10) / -4.8000000d-06 , -4.6000000d-06 /
      data f(30, 8,11),f(30, 8,12) / -4.5000000d-06 , -4.4000000d-06 /
      data f(30, 8,13),f(30, 8,14) / -4.4000000d-06 , -4.5000000d-06 /
      data f(30, 8,15),f(30, 8,16) / -4.7000000d-06 , -5.1000000d-06 /
      data f(30, 8,17),f(30, 8,18) / -5.6000000d-06 , -6.4000000d-06 /
      data f(30, 8,19),f(30, 8,20) / -7.2000000d-06 , -7.8000000d-06 /
      data f(30, 8,21),f(30, 8,22) / -7.8000000d-06 , -7.2000000d-06 /
      data f(30, 8,23) /             -6.4000000d-06 /
      data f(30, 9, 1),f(30, 9, 2) / -5.9000000d-06 , -6.5000000d-06 /
      data f(30, 9, 3),f(30, 9, 4) / -7.0000000d-06 , -7.0000000d-06 /
      data f(30, 9, 5),f(30, 9, 6) / -6.5000000d-06 , -5.9000000d-06 /
      data f(30, 9, 7),f(30, 9, 8) / -5.2000000d-06 , -4.7000000d-06 /
      data f(30, 9, 9),f(30, 9,10) / -4.4000000d-06 , -4.2000000d-06 /
      data f(30, 9,11),f(30, 9,12) / -4.0000000d-06 , -3.9000000d-06 /
      data f(30, 9,13),f(30, 9,14) / -3.8000000d-06 , -3.8000000d-06 /
      data f(30, 9,15),f(30, 9,16) / -4.0000000d-06 , -4.3000000d-06 /
      data f(30, 9,17),f(30, 9,18) / -4.7000000d-06 , -5.4000000d-06 /
      data f(30, 9,19),f(30, 9,20) / -6.0000000d-06 , -6.5000000d-06 /
      data f(30, 9,21),f(30, 9,22) / -6.5000000d-06 , -6.0000000d-06 /
      data f(30, 9,23) /             -5.4000000d-06 /
      data f(30,10, 1),f(30,10, 2) / -5.9000000d-06 , -6.5000000d-06 /
      data f(30,10, 3),f(30,10, 4) / -7.0000000d-06 , -7.0000000d-06 /
      data f(30,10, 5),f(30,10, 6) / -6.5000000d-06 , -5.9000000d-06 /
      data f(30,10, 7),f(30,10, 8) / -5.3000000d-06 , -4.8000000d-06 /
      data f(30,10, 9),f(30,10,10) / -4.3000000d-06 , -4.0000000d-06 /
      data f(30,10,11),f(30,10,12) / -3.8000000d-06 , -3.6000000d-06 /
      data f(30,10,13),f(30,10,14) / -3.5000000d-06 , -3.5000000d-06 /
      data f(30,10,15),f(30,10,16) / -3.6000000d-06 , -3.9000000d-06 /
      data f(30,10,17),f(30,10,18) / -4.3000000d-06 , -5.0000000d-06 /
      data f(30,10,19),f(30,10,20) / -5.6000000d-06 , -6.1000000d-06 /
      data f(30,10,21),f(30,10,22) / -6.1000000d-06 , -5.6000000d-06 /
      data f(30,10,23) /             -5.0000000d-06 /
      data f(30,11, 1),f(30,11, 2) / -6.4000000d-06 , -7.0000000d-06 /
      data f(30,11, 3),f(30,11, 4) / -7.4000000d-06 , -7.4000000d-06 /
      data f(30,11, 5),f(30,11, 6) / -7.0000000d-06 , -6.4000000d-06 /
      data f(30,11, 7),f(30,11, 8) / -5.7000000d-06 , -5.1000000d-06 /
      data f(30,11, 9),f(30,11,10) / -4.5000000d-06 , -4.1000000d-06 /
      data f(30,11,11),f(30,11,12) / -3.7000000d-06 , -3.5000000d-06 /
      data f(30,11,13),f(30,11,14) / -3.3000000d-06 , -3.3000000d-06 /
      data f(30,11,15),f(30,11,16) / -3.4000000d-06 , -3.7000000d-06 /
      data f(30,11,17),f(30,11,18) / -4.2000000d-06 , -4.9000000d-06 /
      data f(30,11,19),f(30,11,20) / -5.6000000d-06 , -6.1000000d-06 /
      data f(30,11,21),f(30,11,22) / -6.1000000d-06 , -5.6000000d-06 /
      data f(30,11,23) /             -4.9000000d-06 /
      data f(30,12, 1),f(30,12, 2) / -6.8000000d-06 , -7.4000000d-06 /
      data f(30,12, 3),f(30,12, 4) / -7.9000000d-06 , -7.9000000d-06 /
      data f(30,12, 5),f(30,12, 6) / -7.4000000d-06 , -6.8000000d-06 /
      data f(30,12, 7),f(30,12, 8) / -6.1000000d-06 , -5.4000000d-06 /
      data f(30,12, 9),f(30,12,10) / -4.8000000d-06 , -4.2000000d-06 /
      data f(30,12,11),f(30,12,12) / -3.8000000d-06 , -3.4000000d-06 /
      data f(30,12,13),f(30,12,14) / -3.2000000d-06 , -3.2000000d-06 /
      data f(30,12,15),f(30,12,16) / -3.3000000d-06 , -3.6000000d-06 /
      data f(30,12,17),f(30,12,18) / -4.1000000d-06 , -4.8000000d-06 /
      data f(30,12,19),f(30,12,20) / -5.5000000d-06 , -6.1000000d-06 /
      data f(30,12,21),f(30,12,22) / -6.1000000d-06 , -5.5000000d-06 /
      data f(30,12,23) /             -4.8000000d-06 /
      data f(30,13, 1),f(30,13, 2) / -7.1000000d-06 , -7.6000000d-06 /
      data f(30,13, 3),f(30,13, 4) / -8.0000000d-06 , -8.0000000d-06 /
      data f(30,13, 5),f(30,13, 6) / -7.6000000d-06 , -7.1000000d-06 /
      data f(30,13, 7),f(30,13, 8) / -6.4000000d-06 , -5.7000000d-06 /
      data f(30,13, 9),f(30,13,10) / -5.0000000d-06 , -4.4000000d-06 /
      data f(30,13,11),f(30,13,12) / -3.9000000d-06 , -3.5000000d-06 /
      data f(30,13,13),f(30,13,14) / -3.2000000d-06 , -3.1000000d-06 /
      data f(30,13,15),f(30,13,16) / -3.2000000d-06 , -3.5000000d-06 /
      data f(30,13,17),f(30,13,18) / -4.0000000d-06 , -4.6000000d-06 /
      data f(30,13,19),f(30,13,20) / -5.2000000d-06 , -5.7000000d-06 /
      data f(30,13,21),f(30,13,22) / -5.7000000d-06 , -5.2000000d-06 /
      data f(30,13,23) /             -4.6000000d-06 /
      data f(30,14, 1),f(30,14, 2) / -7.0000000d-06 , -7.5000000d-06 /
      data f(30,14, 3),f(30,14, 4) / -7.9000000d-06 , -7.9000000d-06 /
      data f(30,14, 5),f(30,14, 6) / -7.5000000d-06 , -7.0000000d-06 /
      data f(30,14, 7),f(30,14, 8) / -6.4000000d-06 , -5.8000000d-06 /
      data f(30,14, 9),f(30,14,10) / -5.1000000d-06 , -4.5000000d-06 /
      data f(30,14,11),f(30,14,12) / -4.0000000d-06 , -3.6000000d-06 /
      data f(30,14,13),f(30,14,14) / -3.4000000d-06 , -3.3000000d-06 /
      data f(30,14,15),f(30,14,16) / -3.3000000d-06 , -3.5000000d-06 /
      data f(30,14,17),f(30,14,18) / -3.9000000d-06 , -4.3000000d-06 /
      data f(30,14,19),f(30,14,20) / -4.8000000d-06 , -5.2000000d-06 /
      data f(30,14,21),f(30,14,22) / -5.2000000d-06 , -4.8000000d-06 /
      data f(30,14,23) /             -4.3000000d-06 /
      data f(30,15, 1),f(30,15, 2) / -6.7000000d-06 , -7.1000000d-06 /
      data f(30,15, 3),f(30,15, 4) / -7.4000000d-06 , -7.4000000d-06 /
      data f(30,15, 5),f(30,15, 6) / -7.1000000d-06 , -6.7000000d-06 /
      data f(30,15, 7),f(30,15, 8) / -6.2000000d-06 , -5.7000000d-06 /
      data f(30,15, 9),f(30,15,10) / -5.2000000d-06 , -4.7000000d-06 /
      data f(30,15,11),f(30,15,12) / -4.2000000d-06 , -3.9000000d-06 /
      data f(30,15,13),f(30,15,14) / -3.7000000d-06 , -3.5000000d-06 /
      data f(30,15,15),f(30,15,16) / -3.5000000d-06 , -3.6000000d-06 /
      data f(30,15,17),f(30,15,18) / -3.9000000d-06 , -4.1000000d-06 /
      data f(30,15,19),f(30,15,20) / -4.4000000d-06 , -4.6000000d-06 /
      data f(30,15,21),f(30,15,22) / -4.6000000d-06 , -4.4000000d-06 /
      data f(30,15,23) /             -4.1000000d-06 /
      data f(30,16, 1),f(30,16, 2) / -6.3000000d-06 , -6.5000000d-06 /
      data f(30,16, 3),f(30,16, 4) / -6.7000000d-06 , -6.7000000d-06 /
      data f(30,16, 5),f(30,16, 6) / -6.5000000d-06 , -6.3000000d-06 /
      data f(30,16, 7),f(30,16, 8) / -5.9000000d-06 , -5.6000000d-06 /
      data f(30,16, 9),f(30,16,10) / -5.2000000d-06 , -4.8000000d-06 /
      data f(30,16,11),f(30,16,12) / -4.5000000d-06 , -4.2000000d-06 /
      data f(30,16,13),f(30,16,14) / -4.0000000d-06 , -3.9000000d-06 /
      data f(30,16,15),f(30,16,16) / -3.9000000d-06 , -3.9000000d-06 /
      data f(30,16,17),f(30,16,18) / -4.0000000d-06 , -4.1000000d-06 /
      data f(30,16,19),f(30,16,20) / -4.2000000d-06 , -4.3000000d-06 /
      data f(30,16,21),f(30,16,22) / -4.3000000d-06 , -4.2000000d-06 /
      data f(30,16,23) /             -4.1000000d-06 /
      data f(30,17, 1),f(30,17, 2) / -5.8000000d-06 , -5.9000000d-06 /
      data f(30,17, 3),f(30,17, 4) / -6.0000000d-06 , -6.0000000d-06 /
      data f(30,17, 5),f(30,17, 6) / -5.9000000d-06 , -5.8000000d-06 /
      data f(30,17, 7),f(30,17, 8) / -5.6000000d-06 , -5.4000000d-06 /
      data f(30,17, 9),f(30,17,10) / -5.1000000d-06 , -4.9000000d-06 /
      data f(30,17,11),f(30,17,12) / -4.7000000d-06 , -4.6000000d-06 /
      data f(30,17,13),f(30,17,14) / -4.4000000d-06 , -4.3000000d-06 /
      data f(30,17,15),f(30,17,16) / -4.3000000d-06 , -4.2000000d-06 /
      data f(30,17,17),f(30,17,18) / -4.2000000d-06 , -4.3000000d-06 /
      data f(30,17,19),f(30,17,20) / -4.3000000d-06 , -4.3000000d-06 /
      data f(30,17,21),f(30,17,22) / -4.3000000d-06 , -4.3000000d-06 /
      data f(30,17,23) /             -4.3000000d-06 /
      data f(30,18, 1),f(30,18, 2) / -5.3000000d-06 , -5.3000000d-06 /
      data f(30,18, 3),f(30,18, 4) / -5.4000000d-06 , -5.4000000d-06 /
      data f(30,18, 5),f(30,18, 6) / -5.3000000d-06 , -5.3000000d-06 /
      data f(30,18, 7),f(30,18, 8) / -5.2000000d-06 , -5.1000000d-06 /
      data f(30,18, 9),f(30,18,10) / -5.1000000d-06 , -5.0000000d-06 /
      data f(30,18,11),f(30,18,12) / -4.9000000d-06 , -4.8000000d-06 /
      data f(30,18,13),f(30,18,14) / -4.7000000d-06 , -4.7000000d-06 /
      data f(30,18,15),f(30,18,16) / -4.6000000d-06 , -4.6000000d-06 /
      data f(30,18,17),f(30,18,18) / -4.6000000d-06 , -4.5000000d-06 /
      data f(30,18,19),f(30,18,20) / -4.5000000d-06 , -4.5000000d-06 /
      data f(30,18,21),f(30,18,22) / -4.5000000d-06 , -4.5000000d-06 /
      data f(30,18,23) /             -4.5000000d-06 /
      data f(30,19, 1),f(30,19, 2) / -4.9000000d-06 , -4.9000000d-06 /
      data f(30,19, 3),f(30,19, 4) / -4.9000000d-06 , -4.9000000d-06 /
      data f(30,19, 5),f(30,19, 6) / -4.9000000d-06 , -4.9000000d-06 /
      data f(30,19, 7),f(30,19, 8) / -4.9000000d-06 , -4.9000000d-06 /
      data f(30,19, 9),f(30,19,10) / -4.9000000d-06 , -4.9000000d-06 /
      data f(30,19,11),f(30,19,12) / -4.9000000d-06 , -4.9000000d-06 /
      data f(30,19,13),f(30,19,14) / -4.9000000d-06 , -4.9000000d-06 /
      data f(30,19,15),f(30,19,16) / -4.9000000d-06 , -4.9000000d-06 /
      data f(30,19,17),f(30,19,18) / -4.9000000d-06 , -4.9000000d-06 /
      data f(30,19,19),f(30,19,20) / -4.9000000d-06 , -4.9000000d-06 /
      data f(30,19,21),f(30,19,22) / -4.9000000d-06 , -4.9000000d-06 /
      data f(30,19,23) /             -4.9000000d-06 /
 
      data fpp( 1, 1, 1,1),fpp( 1, 1, 1,2),fpp( 1, 1, 1,3)/
     x 2.8840185d+00, 6.0007063d-04, 2.5822571d-18 /
      data fpp( 1, 1, 2,1),fpp( 1, 1, 2,2),fpp( 1, 1, 2,3)/
     x 2.8840185d+00, 1.9660857d-04, 9.4227393d-19 /
      data fpp( 1, 1, 3,1),fpp( 1, 1, 3,2),fpp( 1, 1, 3,3)/
     x 2.8840185d+00, 1.5226654d-04,-9.6407178d-19 /
      data fpp( 1, 1, 4,1),fpp( 1, 1, 4,2),fpp( 1, 1, 4,3)/
     x 2.8840185d+00, 1.5226654d-04, 6.6027958d-19 /
      data fpp( 1, 1, 5,1),fpp( 1, 1, 5,2),fpp( 1, 1, 5,3)/
     x 2.8840185d+00, 1.9660857d-04, 4.5124984d-19 /
      data fpp( 1, 1, 6,1),fpp( 1, 1, 6,2),fpp( 1, 1, 6,3)/
     x 2.8840185d+00, 6.0007063d-04,-1.4060008d-18 /
      data fpp( 1, 1, 7,1),fpp( 1, 1, 7,2),fpp( 1, 1, 7,3)/
     x 2.8840185d+00, 9.0635872d-04,-1.3417583d-18 /
      data fpp( 1, 1, 8,1),fpp( 1, 1, 8,2),fpp( 1, 1, 8,3)/
     x 2.8840185d+00, 1.1491667d-03,-4.4757320d-19 /
      data fpp( 1, 1, 9,1),fpp( 1, 1, 9,2),fpp( 1, 1, 9,3)/
     x 2.8840185d+00, 1.3349084d-03,-6.1330745d-19 /
      data fpp( 1, 1,10,1),fpp( 1, 1,10,2),fpp( 1, 1,10,3)/
     x 2.8840185d+00, 1.4593379d-03, 1.3579269d-18 /
      data fpp( 1, 1,11,1),fpp( 1, 1,11,2),fpp( 1, 1,11,3)/
     x 2.8840185d+00, 1.5563540d-03,-1.0124435d-18 /
      data fpp( 1, 1,12,1),fpp( 1, 1,12,2),fpp( 1, 1,12,3)/
     x 2.8840185d+00, 1.5858159d-03, 6.3145220d-19 /
      data fpp( 1, 1,13,1),fpp( 1, 1,13,2),fpp( 1, 1,13,3)/
     x 2.8840185d+00, 1.5587420d-03, 1.3611732d-18 /
      data fpp( 1, 1,14,1),fpp( 1, 1,14,2),fpp( 1, 1,14,3)/
     x 2.8840185d+00, 1.4774065d-03,-1.4413755d-19 /
      data fpp( 1, 1,15,1),fpp( 1, 1,15,2),fpp( 1, 1,15,3)/
     x 2.8840185d+00, 1.3395265d-03, 5.7530548d-19 /
      data fpp( 1, 1,16,1),fpp( 1, 1,16,2),fpp( 1, 1,16,3)/
     x 2.8840185d+00, 1.1355735d-03,-7.8246702d-19 /
      data fpp( 1, 1,17,1),fpp( 1, 1,17,2),fpp( 1, 1,17,3)/
     x 2.8840185d+00, 8.9878495d-04, 9.0415697d-19 /
      data fpp( 1, 1,18,1),fpp( 1, 1,18,2),fpp( 1, 1,18,3)/
     x 2.8840185d+00, 5.8033043d-04,-1.5628892d-18 /
      data fpp( 1, 1,19,1),fpp( 1, 1,19,2),fpp( 1, 1,19,3)/
     x 2.8840185d+00, 1.6116730d-04,-2.0469323d-18 /
      data fpp( 1, 1,20,1),fpp( 1, 1,20,2),fpp( 1, 1,20,3)/
     x 2.8840185d+00, 1.3332750d-04, 7.9704997d-19 /
      data fpp( 1, 1,21,1),fpp( 1, 1,21,2),fpp( 1, 1,21,3)/
     x 2.8840185d+00, 1.3332750d-04,-9.0246507d-19 /
      data fpp( 1, 1,22,1),fpp( 1, 1,22,2),fpp( 1, 1,22,3)/
     x 2.8840185d+00, 1.6116730d-04, 1.7132377d-18 /
      data fpp( 1, 1,23,1),fpp( 1, 1,23,2),fpp( 1, 1,23,3)/
     x 2.8840185d+00, 5.8033043d-04, 6.5225750d-18 /
      data fpp( 1, 2, 1,1),fpp( 1, 2, 1,2),fpp( 1, 2, 1,3)/
     x 9.1173127d-01, 3.0178974d-04,-7.2016348d-06 /
      data fpp( 1, 2, 2,1),fpp( 1, 2, 2,2),fpp( 1, 2, 2,3)/
     x 8.9257998d-01, 7.7953864d-05,-7.2842305d-06 /
      data fpp( 1, 2, 3,1),fpp( 1, 2, 3,2),fpp( 1, 2, 3,3)/
     x 8.6679005d-01, 6.8228925d-05,-7.7314434d-06 /
      data fpp( 1, 2, 4,1),fpp( 1, 2, 4,2),fpp( 1, 2, 4,3)/
     x 8.6679005d-01, 6.8228925d-05,-7.2585546d-06 /
      data fpp( 1, 2, 5,1),fpp( 1, 2, 5,2),fpp( 1, 2, 5,3)/
     x 8.9257998d-01, 7.7953864d-05,-9.1757858d-06 /
      data fpp( 1, 2, 6,1),fpp( 1, 2, 6,2),fpp( 1, 2, 6,3)/
     x 9.1173127d-01, 3.0178974d-04,-1.0830214d-07 /
      data fpp( 1, 2, 7,1),fpp( 1, 2, 7,2),fpp( 1, 2, 7,3)/
     x 8.8512254d-01, 4.5899456d-04, 1.5329944d-06 /
      data fpp( 1, 2, 8,1),fpp( 1, 2, 8,2),fpp( 1, 2, 8,3)/
     x 8.6394457d-01, 5.6626759d-04, 1.0863246d-06 /
      data fpp( 1, 2, 9,1),fpp( 1, 2, 9,2),fpp( 1, 2, 9,3)/
     x 8.6305267d-01, 6.5403319d-04, 1.1767707d-05 /
      data fpp( 1, 2,10,1),fpp( 1, 2,10,2),fpp( 1, 2,10,3)/
     x 8.8749872d-01, 7.0681428d-04,-7.4231541d-06 /
      data fpp( 1, 2,11,1),fpp( 1, 2,11,2),fpp( 1, 2,11,3)/
     x 8.6182603d-01, 7.4908899d-04, 1.2668909d-05 /
      data fpp( 1, 2,12,1),fpp( 1, 2,12,2),fpp( 1, 2,12,3)/
     x 8.6211908d-01, 7.6004021d-04, 2.9055181d-06 /
      data fpp( 1, 2,13,1),fpp( 1, 2,13,2),fpp( 1, 2,13,3)/
     x 8.6243165d-01, 7.4850806d-04, 5.8890188d-06 /
      data fpp( 1, 2,14,1),fpp( 1, 2,14,2),fpp( 1, 2,14,3)/
     x 8.4321547d-01, 7.1222807d-04, 2.9084069d-06 /
      data fpp( 1, 2,15,1),fpp( 1, 2,15,2),fpp( 1, 2,15,3)/
     x 8.6313797d-01, 6.5221806d-04, 1.0983354d-05 /
      data fpp( 1, 2,16,1),fpp( 1, 2,16,2),fpp( 1, 2,16,3)/
     x 9.1403244d-01, 5.6109808d-04,-7.8178218d-06 /
      data fpp( 1, 2,17,1),fpp( 1, 2,17,2),fpp( 1, 2,17,3)/
     x 8.6592673d-01, 4.5198611d-04, 8.3839334d-06 /
      data fpp( 1, 2,18,1),fpp( 1, 2,18,2),fpp( 1, 2,18,3)/
     x 7.9371897d-01, 2.9316914d-04,-3.0499116d-06 /
      data fpp( 1, 2,19,1),fpp( 1, 2,19,2),fpp( 1, 2,19,3)/
     x 9.0874292d-01, 6.2782401d-05,-4.1042868d-06 /
      data fpp( 1, 2,20,1),fpp( 1, 2,20,2),fpp( 1, 2,20,3)/
     x 9.1314593d-01, 7.7228009d-05,-1.0286941d-05 /
      data fpp( 1, 2,21,1),fpp( 1, 2,21,2),fpp( 1, 2,21,3)/
     x 9.1314593d-01, 7.7228009d-05,-1.0200033d-05 /
      data fpp( 1, 2,22,1),fpp( 1, 2,22,2),fpp( 1, 2,22,3)/
     x 9.0874292d-01, 6.2782401d-05,-4.4519191d-06 /
      data fpp( 1, 2,23,1),fpp( 1, 2,23,2),fpp( 1, 2,23,3)/
     x 7.9371897d-01, 2.9316914d-04,-1.7462904d-06 /
      data fpp( 1, 3, 1,1),fpp( 1, 3, 1,2),fpp( 1, 3, 1,3)/
     x 1.9497018d-01,-3.0884358d-04, 2.1796104d-05 /
      data fpp( 1, 3, 2,1),fpp( 1, 3, 2,2),fpp( 1, 3, 2,3)/
     x 2.5589671d-01, 1.1653060d-03,-7.5708594d-08 /
      data fpp( 1, 3, 3,1),fpp( 1, 3, 3,2),fpp( 1, 3, 3,3)/
     x 2.9462444d-01, 1.4868018d-03,-4.6723270d-05 /
      data fpp( 1, 3, 4,1),fpp( 1, 3, 4,2),fpp( 1, 3, 4,3)/
     x 2.9462444d-01, 1.4868018d-03,-4.7109336d-05 /
      data fpp( 1, 3, 5,1),fpp( 1, 3, 5,2),fpp( 1, 3, 5,3)/
     x 2.5589671d-01, 1.1653060d-03, 1.4685555d-06 /
      data fpp( 1, 3, 6,1),fpp( 1, 3, 6,2),fpp( 1, 3, 6,3)/
     x 1.9497018d-01,-3.0884358d-04, 1.6005114d-05 /
      data fpp( 1, 3, 7,1),fpp( 1, 3, 7,2),fpp( 1, 3, 7,3)/
     x 2.3779416d-01,-1.3237809d-03, 1.3872988d-05 /
      data fpp( 1, 3, 8,1),fpp( 1, 3, 8,2),fpp( 1, 3, 8,3)/
     x 3.0306309d+00,-2.0070031d-03, 1.1230932d-05 /
      data fpp( 1, 3, 9,1),fpp( 1, 3, 9,2),fpp( 1, 3, 9,3)/
     x-7.4436426d-01,-2.5229092d-03, 8.7152821d-06 /
      data fpp( 1, 3,10,1),fpp( 1, 3,10,2),fpp( 1, 3,10,3)/
     x-5.8612656d+00,-2.8648230d-03, 8.1179391d-06 /
      data fpp( 1, 3,11,1),fpp( 1, 3,11,2),fpp( 1, 3,11,3)/
     x-8.7867150d+00,-3.0781800d-03, 7.4189614d-06 /
      data fpp( 1, 3,12,1),fpp( 1, 3,12,2),fpp( 1, 3,12,3)/
     x-9.7304001d+00,-3.1456448d-03, 7.5662153d-06 /
      data fpp( 1, 3,13,1),fpp( 1, 3,13,2),fpp( 1, 3,13,3)/
     x-8.7583653d+00,-3.0819822d-03, 7.3341773d-06 /
      data fpp( 1, 3,14,1),fpp( 1, 3,14,2),fpp( 1, 3,14,3)/
     x-5.7863563d+00,-2.8786808d-03, 8.2230757d-06 /
      data fpp( 1, 3,15,1),fpp( 1, 3,15,2),fpp( 1, 3,15,3)/
     x-5.9480639d-01,-2.5316247d-03, 9.0755201d-06 /
      data fpp( 1, 3,16,1),fpp( 1, 3,16,2),fpp( 1, 3,16,3)/
     x 2.9479202d+00,-2.0162678d-03, 1.1310844d-05 /
      data fpp( 1, 3,17,1),fpp( 1, 3,17,2),fpp( 1, 3,17,3)/
     x 2.2302226d-01,-1.3034254d-03, 1.4555104d-05 /
      data fpp( 1, 3,18,1),fpp( 1, 3,18,2),fpp( 1, 3,18,3)/
     x 1.9499961d-01,-2.7164300d-04, 1.4258739d-05 /
      data fpp( 1, 3,19,1),fpp( 1, 3,19,2),fpp( 1, 3,19,3)/
     x 2.5296422d-01, 1.2414891d-03, 6.9319411d-06 /
      data fpp( 1, 3,20,1),fpp( 1, 3,20,2),fpp( 1, 3,20,3)/
     x 3.4627383d-01, 1.4348905d-03,-5.0572503d-05 /
      data fpp( 1, 3,21,1),fpp( 1, 3,21,2),fpp( 1, 3,21,3)/
     x 3.4627383d-01, 1.4348905d-03,-4.9646461d-05 /
      data fpp( 1, 3,22,1),fpp( 1, 3,22,2),fpp( 1, 3,22,3)/
     x 2.5296422d-01, 1.2414891d-03, 3.2277747d-06 /
      data fpp( 1, 3,23,1),fpp( 1, 3,23,2),fpp( 1, 3,23,3)/
     x 1.9499961d-01,-2.7164300d-04, 2.8149363d-05 /
      data fpp( 1, 4, 1,1),fpp( 1, 4, 1,2),fpp( 1, 4, 1,3)/
     x 8.6721108d-01, 1.7375658d-04,-6.2871715d-04 /
      data fpp( 1, 4, 2,1),fpp( 1, 4, 2,2),fpp( 1, 4, 2,3)/
     x 6.8232007d-01,-1.9683658d-03,-4.6520170d-04 /
      data fpp( 1, 4, 3,1),fpp( 1, 4, 3,2),fpp( 1, 4, 3,3)/
     x 1.9415657d-01,-2.3537620d-03,-1.5664405d-04 /
      data fpp( 1, 4, 4,1),fpp( 1, 4, 4,2),fpp( 1, 4, 4,3)/
     x 1.9415657d-01,-2.3537620d-03,-8.3436994d-05 /
      data fpp( 1, 4, 5,1),fpp( 1, 4, 5,2),fpp( 1, 4, 5,3)/
     x 6.8232007d-01,-1.9683658d-03,-7.5802993d-04 /
      data fpp( 1, 4, 6,1),fpp( 1, 4, 6,2),fpp( 1, 4, 6,3)/
     x 8.6721108d-01, 1.7375658d-04, 4.6938871d-04 /
      data fpp( 1, 4, 7,1),fpp( 1, 4, 7,2),fpp( 1, 4, 7,3)/
     x 2.7676099d-01, 1.5673832d-03, 6.8997073d-05 /
      data fpp( 1, 4, 8,1),fpp( 1, 4, 8,2),fpp( 1, 4, 8,3)/
     x 2.8882822d-01, 2.3860267d-03, 1.1491499d-04 /
      data fpp( 1, 4, 9,1),fpp( 1, 4, 9,2),fpp( 1, 4, 9,3)/
     x 3.2224906d-01, 3.0363835d-03, 7.0190949d-05 /
      data fpp( 1, 4,10,1),fpp( 1, 4,10,2),fpp( 1, 4,10,3)/
     x 3.1219466d-01, 3.4304377d-03, 7.6689209d-05 /
      data fpp( 1, 4,11,1),fpp( 1, 4,11,2),fpp( 1, 4,11,3)/
     x 3.2416516d-01, 3.6645648d-03, 6.9314214d-05 /
      data fpp( 1, 4,12,1),fpp( 1, 4,12,2),fpp( 1, 4,12,3)/
     x 1.5457575d+00, 3.7283528d-03, 7.2521935d-05 /
      data fpp( 1, 4,13,1),fpp( 1, 4,13,2),fpp( 1, 4,13,3)/
     x 3.3021179d-01, 3.6584248d-03, 6.8764047d-05 /
      data fpp( 1, 4,14,1),fpp( 1, 4,14,2),fpp( 1, 4,14,3)/
     x 3.1222368d-01, 3.4204669d-03, 7.9081877d-05 /
      data fpp( 1, 4,15,1),fpp( 1, 4,15,2),fpp( 1, 4,15,3)/
     x 3.0780441d-01, 3.0224028d-03, 7.6188443d-05 /
      data fpp( 1, 4,16,1),fpp( 1, 4,16,2),fpp( 1, 4,16,3)/
     x 2.8954677d-01, 2.4164830d-03, 1.2305035d-04 /
      data fpp( 1, 4,17,1),fpp( 1, 4,17,2),fpp( 1, 4,17,3)/
     x 3.0618055d-01, 1.5213074d-03, 6.3956161d-05 /
      data fpp( 1, 4,18,1),fpp( 1, 4,18,2),fpp( 1, 4,18,3)/
     x 8.7075415d-01, 1.3532285d-04, 5.0128301d-04 /
      data fpp( 1, 4,19,1),fpp( 1, 4,19,2),fpp( 1, 4,19,3)/
     x-1.1818906d-01,-2.0496248d-03,-8.4925819d-04 /
      data fpp( 1, 4,20,1),fpp( 1, 4,20,2),fpp( 1, 4,20,3)/
     x 2.4393050d-01,-2.1556139d-03,-4.6800242d-05 /
      data fpp( 1, 4,21,1),fpp( 1, 4,21,2),fpp( 1, 4,21,3)/
     x 2.4393050d-01,-2.1556139d-03,-1.2868418d-04 /
      data fpp( 1, 4,22,1),fpp( 1, 4,22,2),fpp( 1, 4,22,3)/
     x-1.1818906d-01,-2.0496248d-03,-5.2172245d-04 /
      data fpp( 1, 4,23,1),fpp( 1, 4,23,2),fpp( 1, 4,23,3)/
     x 8.7075415d-01, 1.3532285d-04,-7.2697603d-04 /
      data fpp( 1, 5, 1,1),fpp( 1, 5, 1,2),fpp( 1, 5, 1,3)/
     x 5.4156370d-01, 1.3718172d-03, 4.7596528d-06 /
      data fpp( 1, 5, 2,1),fpp( 1, 5, 2,2),fpp( 1, 5, 2,3)/
     x 5.7831087d-01, 2.3319491d-03,-5.4202806d-05 /
      data fpp( 1, 5, 3,1),fpp( 1, 5, 3,2),fpp( 1, 5, 3,3)/
     x 2.3060923d-01, 2.2903461d-03,-1.8253843d-04 /
      data fpp( 1, 5, 4,1),fpp( 1, 5, 4,2),fpp( 1, 5, 4,3)/
     x 2.3060923d-01, 2.2903461d-03,-1.7906031d-04 /
      data fpp( 1, 5, 5,1),fpp( 1, 5, 5,2),fpp( 1, 5, 5,3)/
     x 5.7831087d-01, 2.3319491d-03,-6.8115300d-05 /
      data fpp( 1, 5, 6,1),fpp( 1, 5, 6,2),fpp( 1, 5, 6,3)/
     x 5.4156370d-01, 1.3718172d-03, 5.6931505d-05 /
      data fpp( 1, 5, 7,1),fpp( 1, 5, 7,2),fpp( 1, 5, 7,3)/
     x 1.5088148d-01, 7.6721402d-04,-4.1170721d-05 /
      data fpp( 1, 5, 8,1),fpp( 1, 5, 8,2),fpp( 1, 5, 8,3)/
     x-3.3520789d-01, 5.4191423d-04, 1.5669338d-04 /
      data fpp( 1, 5, 9,1),fpp( 1, 5, 9,2),fpp( 1, 5, 9,3)/
     x 1.1606792d-01, 2.6614333d-04,-1.1720792d-05 /
      data fpp( 1, 5,10,1),fpp( 1, 5,10,2),fpp( 1, 5,10,3)/
     x 1.2133856d-01, 1.4892637d-04, 8.8051791d-05 /
      data fpp( 1, 5,11,1),fpp( 1, 5,11,2),fpp( 1, 5,11,3)/
     x 1.9245419d-01, 7.9642586d-05, 4.0213627d-05 /
      data fpp( 1, 5,12,1),fpp( 1, 5,12,2),fpp( 1, 5,12,3)/
     x 1.2634485d-01, 6.9447589d-05, 8.2293699d-05 /
      data fpp( 1, 5,13,1),fpp( 1, 5,13,2),fpp( 1, 5,13,3)/
     x 1.8247358d-01, 6.9430948d-05, 4.8367577d-05 /
      data fpp( 1, 5,14,1),fpp( 1, 5,14,2),fpp( 1, 5,14,3)/
     x 1.2282132d-01, 1.4321901d-04, 7.3753994d-05 /
      data fpp( 1, 5,15,1),fpp( 1, 5,15,2),fpp( 1, 5,15,3)/
     x 1.1715557d-01, 2.4453142d-04, 6.0728448d-05 /
      data fpp( 1, 5,16,1),fpp( 1, 5,16,2),fpp( 1, 5,16,3)/
     x 9.0756921d-02, 4.3283369d-04, 6.5136213d-05 /
      data fpp( 1, 5,17,1),fpp( 1, 5,17,2),fpp( 1, 5,17,3)/
     x 1.3034850d-01, 7.5483383d-04, 4.8704700d-05 /
      data fpp( 1, 5,18,1),fpp( 1, 5,18,2),fpp( 1, 5,18,3)/
     x 1.2537006d-01, 1.3331376d-03, 2.8578987d-05 /
      data fpp( 1, 5,19,1),fpp( 1, 5,19,2),fpp( 1, 5,19,3)/
     x 5.2222024d-01, 2.4253481d-03,-2.4786475d-06 /
      data fpp( 1, 5,20,1),fpp( 1, 5,20,2),fpp( 1, 5,20,3)/
     x 6.5077910d-01, 2.1783211d-03,-2.3831240d-04 /
      data fpp( 1, 5,21,1),fpp( 1, 5,21,2),fpp( 1, 5,21,3)/
     x 6.5077910d-01, 2.1783211d-03,-2.3456249d-04 /
      data fpp( 1, 5,22,1),fpp( 1, 5,22,2),fpp( 1, 5,22,3)/
     x 5.2222024d-01, 2.4253481d-03,-1.7478290d-05 /
      data fpp( 1, 5,23,1),fpp( 1, 5,23,2),fpp( 1, 5,23,3)/
     x 1.2537006d-01, 1.3331376d-03, 8.4827645d-05 /
      data fpp( 1, 6, 1,1),fpp( 1, 6, 1,2),fpp( 1, 6, 1,3)/
     x 2.8681596d-02,-2.0075555d-04,-6.9642671d-05 /
      data fpp( 1, 6, 2,1),fpp( 1, 6, 2,2),fpp( 1, 6, 2,3)/
     x 5.1635466d-01,-2.4663455d-04,-7.5118157d-05 /
      data fpp( 1, 6, 3,1),fpp( 1, 6, 3,2),fpp( 1, 6, 3,3)/
     x 3.7902713d-01,-3.5840256d-04,-8.8998699d-05 /
      data fpp( 1, 6, 4,1),fpp( 1, 6, 4,2),fpp( 1, 6, 4,3)/
     x 3.7902713d-01,-3.5840256d-04,-8.5240824d-05 /
      data fpp( 1, 6, 5,1),fpp( 1, 6, 5,2),fpp( 1, 6, 5,3)/
     x 5.1635466d-01,-2.4663455d-04,-9.0149660d-05 /
      data fpp( 1, 6, 6,1),fpp( 1, 6, 6,2),fpp( 1, 6, 6,3)/
     x 2.8681596d-02,-2.0075555d-04,-1.3274537d-05 /
      data fpp( 1, 6, 7,1),fpp( 1, 6, 7,2),fpp( 1, 6, 7,3)/
     x 3.4225386d-02,-1.0299328d-05, 9.8018093d-06 /
      data fpp( 1, 6, 8,1),fpp( 1, 6, 8,2),fpp( 1, 6, 8,3)/
     x 4.1712375d-02, 5.8870374d-05, 3.2603300d-05 /
      data fpp( 1, 6, 9,1),fpp( 1, 6, 9,2),fpp( 1, 6, 9,3)/
     x 4.8321415d-02, 1.3340521d-04, 4.3894990d-05 /
      data fpp( 1, 6,10,1),fpp( 1, 6,10,2),fpp( 1, 6,10,3)/
     x 5.3654627d-02, 1.6518688d-04, 5.0332739d-05 /
      data fpp( 1, 6,11,1),fpp( 1, 6,11,2),fpp( 1, 6,11,3)/
     x 5.6578406d-02, 1.4910081d-04, 5.3850053d-05 /
      data fpp( 1, 6,12,1),fpp( 1, 6,12,2),fpp( 1, 6,12,3)/
     x 5.8355526d-02, 1.5216885d-04, 5.5369049d-05 /
      data fpp( 1, 6,13,1),fpp( 1, 6,13,2),fpp( 1, 6,13,3)/
     x 5.6699044d-02, 1.7239939d-04, 5.6179749d-05 /
      data fpp( 1, 6,14,1),fpp( 1, 6,14,2),fpp( 1, 6,14,3)/
     x 5.6663571d-02, 1.2943702d-04, 5.6283953d-05 /
      data fpp( 1, 6,15,1),fpp( 1, 6,15,2),fpp( 1, 6,15,3)/
     x 5.2260050d-02, 1.2664951d-04, 5.5794439d-05 /
      data fpp( 1, 6,16,1),fpp( 1, 6,16,2),fpp( 1, 6,16,3)/
     x 9.0769362d-01, 5.8368214d-05, 5.1870290d-05 /
      data fpp( 1, 6,17,1),fpp( 1, 6,17,2),fpp( 1, 6,17,3)/
     x 3.8918615d-02,-5.5150720d-05, 4.4632402d-05 /
      data fpp( 1, 6,18,1),fpp( 1, 6,18,2),fpp( 1, 6,18,3)/
     x 2.9491712d-02,-1.5227531d-04, 1.7310101d-05 /
      data fpp( 1, 6,19,1),fpp( 1, 6,19,2),fpp( 1, 6,19,3)/
     x 2.0709832d-02,-4.8717343d-04, 6.2711925d-06 /
      data fpp( 1, 6,20,1),fpp( 1, 6,20,2),fpp( 1, 6,20,3)/
     x 7.8293333d-01,-2.0695240d-04,-2.0201287d-04 /
      data fpp( 1, 6,21,1),fpp( 1, 6,21,2),fpp( 1, 6,21,3)/
     x 7.8293333d-01,-2.0695240d-04,-1.9792298d-04 /
      data fpp( 1, 6,22,1),fpp( 1, 6,22,2),fpp( 1, 6,22,3)/
     x 2.0709832d-02,-4.8717343d-04,-1.0088362d-05 /
      data fpp( 1, 6,23,1),fpp( 1, 6,23,2),fpp( 1, 6,23,3)/
     x 2.9491712d-02,-1.5227531d-04, 7.8658431d-05 /
      data fpp( 1, 7, 1,1),fpp( 1, 7, 1,2),fpp( 1, 7, 1,3)/
     x-3.7318660d-01, 4.5946959d-05,-3.4007937d-04 /
      data fpp( 1, 7, 2,1),fpp( 1, 7, 2,2),fpp( 1, 7, 2,3)/
     x 1.0959931d+00,-3.7819888d-04,-2.1181877d-04 /
      data fpp( 1, 7, 3,1),fpp( 1, 7, 3,2),fpp( 1, 7, 3,3)/
     x-9.4464467d-02,-1.5516189d-04, 4.5608440d-05 /
      data fpp( 1, 7, 4,1),fpp( 1, 7, 4,2),fpp( 1, 7, 4,3)/
     x-9.4464467d-02,-1.5516189d-04, 7.6088066d-05 /
      data fpp( 1, 7, 5,1),fpp( 1, 7, 5,2),fpp( 1, 7, 5,3)/
     x 1.0959931d+00,-3.7819888d-04,-3.3373727d-04 /
      data fpp( 1, 7, 6,1),fpp( 1, 7, 6,2),fpp( 1, 7, 6,3)/
     x-3.7318660d-01, 4.5946959d-05, 1.1711502d-04 /
      data fpp( 1, 7, 7,1),fpp( 1, 7, 7,2),fpp( 1, 7, 7,3)/
     x-1.0527962d-02,-2.1694711d-05,-7.8004827d-05 /
      data fpp( 1, 7, 8,1),fpp( 1, 7, 8,2),fpp( 1, 7, 8,3)/
     x 2.2520999d-03,-1.9268973d-04, 5.3838282d-05 /
      data fpp( 1, 7, 9,1),fpp( 1, 7, 9,2),fpp( 1, 7, 9,3)/
     x 1.8357136d-01,-6.4021812d-06,-1.4738303d-05 /
      data fpp( 1, 7,10,1),fpp( 1, 7,10,2),fpp( 1, 7,10,3)/
     x 1.7174966d-02,-7.0017869d-05, 6.1922929d-05 /
      data fpp( 1, 7,11,1),fpp( 1, 7,11,2),fpp( 1, 7,11,3)/
     x 2.1332584d-02, 7.3276155d-05, 4.7870586d-05 /
      data fpp( 1, 7,12,1),fpp( 1, 7,12,2),fpp( 1, 7,12,3)/
     x 9.7637996d-02, 5.7302999d-05, 3.4036725d-05 /
      data fpp( 1, 7,13,1),fpp( 1, 7,13,2),fpp( 1, 7,13,3)/
     x 2.4240074d-02,-4.6990515d-05, 5.1746513d-05 /
      data fpp( 1, 7,14,1),fpp( 1, 7,14,2),fpp( 1, 7,14,3)/
     x 2.4296533d-02, 1.1782924d-05, 6.6303225d-05 /
      data fpp( 1, 7,15,1),fpp( 1, 7,15,2),fpp( 1, 7,15,3)/
     x 1.8812545d-01,-5.6077438d-05, 1.4738589d-05 /
      data fpp( 1, 7,16,1),fpp( 1, 7,16,2),fpp( 1, 7,16,3)/
     x 1.9352271d-02,-5.9958546d-05, 4.4596421d-05 /
      data fpp( 1, 7,17,1),fpp( 1, 7,17,2),fpp( 1, 7,17,3)/
     x 1.4204834d-02, 4.0599045d-05, 1.0989973d-04 /
      data fpp( 1, 7,18,1),fpp( 1, 7,18,2),fpp( 1, 7,18,3)/
     x 4.9028912d-01,-2.1196380d-05,-1.1778133d-04 /
      data fpp( 1, 7,19,1),fpp( 1, 7,19,2),fpp( 1, 7,19,3)/
     x-5.7300081d-03, 1.4168765d-04, 2.2846360d-04 /
      data fpp( 1, 7,20,1),fpp( 1, 7,20,2),fpp( 1, 7,20,3)/
     x 1.0054715d+00,-1.8725548d-04,-2.6624908d-04 /
      data fpp( 1, 7,21,1),fpp( 1, 7,21,2),fpp( 1, 7,21,3)/
     x 1.0054715d+00,-1.8725548d-04,-2.3885457d-04 /
      data fpp( 1, 7,22,1),fpp( 1, 7,22,2),fpp( 1, 7,22,3)/
     x-5.7300081d-03, 1.4168765d-04, 1.1888559d-04 /
      data fpp( 1, 7,23,1),fpp( 1, 7,23,2),fpp( 1, 7,23,3)/
     x 4.9028912d-01,-2.1196380d-05, 2.9313620d-04 /
      data fpp( 1, 8, 1,1),fpp( 1, 8, 1,2),fpp( 1, 8, 1,3)/
     x 4.4510647d-01,-5.1197429d-04, 2.1182374d-05 /
      data fpp( 1, 8, 2,1),fpp( 1, 8, 2,2),fpp( 1, 8, 2,3)/
     x 1.1957394d-02,-1.6875393d-04, 3.3676753d-05 /
      data fpp( 1, 8, 3,1),fpp( 1, 8, 3,2),fpp( 1, 8, 3,3)/
     x 5.0228978d-01,-2.9877589d-04, 6.9332616d-05 /
      data fpp( 1, 8, 4,1),fpp( 1, 8, 4,2),fpp( 1, 8, 4,3)/
     x 5.0228978d-01,-2.9877589d-04, 5.3788775d-05 /
      data fpp( 1, 8, 5,1),fpp( 1, 8, 5,2),fpp( 1, 8, 5,3)/
     x 1.1957394d-02,-1.6875393d-04, 9.5852116d-05 /
      data fpp( 1, 8, 6,1),fpp( 1, 8, 6,2),fpp( 1, 8, 6,3)/
     x 4.4510647d-01,-5.1197429d-04,-2.1197524d-04 /
      data fpp( 1, 8, 7,1),fpp( 1, 8, 7,2),fpp( 1, 8, 7,3)/
     x-1.1175376d-01,-1.4850783d-04,-1.1695516d-04 /
      data fpp( 1, 8, 8,1),fpp( 1, 8, 8,2),fpp( 1, 8, 8,3)/
     x-3.8713654d-02, 5.3091653d-04, 1.2038587d-04 /
      data fpp( 1, 8, 9,1),fpp( 1, 8, 9,2),fpp( 1, 8, 9,3)/
     x 8.1299193d-01,-1.2322249d-04,-2.0254633d-04 /
      data fpp( 1, 8,10,1),fpp( 1, 8,10,2),fpp( 1, 8,10,3)/
     x-1.1741213d-02,-5.5647401d-05, 2.2424745d-04 /
      data fpp( 1, 8,11,1),fpp( 1, 8,11,2),fpp( 1, 8,11,3)/
     x 6.7009158d-01,-4.1910543d-04,-8.3133467d-05 /
      data fpp( 1, 8,12,1),fpp( 1, 8,12,2),fpp( 1, 8,12,3)/
     x 6.3819396d-01,-4.2651885d-04, 1.0019842d-04 /
      data fpp( 1, 8,13,1),fpp( 1, 8,13,2),fpp( 1, 8,13,3)/
     x 6.4330597d-01, 7.3066670d-06,-7.2518209d-05 /
      data fpp( 1, 8,14,1),fpp( 1, 8,14,2),fpp( 1, 8,14,3)/
     x 4.7492910d-03,-3.8769671d-04, 2.2840042d-04 /
      data fpp( 1, 8,15,1),fpp( 1, 8,15,2),fpp( 1, 8,15,3)/
     x 7.7059822d-01, 1.1956246d-05,-1.8650146d-04 /
      data fpp( 1, 8,16,1),fpp( 1, 8,16,2),fpp( 1, 8,16,3)/
     x 5.4533261d-03,-4.9702028d-05, 2.5509342d-04 /
      data fpp( 1, 8,17,1),fpp( 1, 8,17,2),fpp( 1, 8,17,3)/
     x 1.0375096d+00,-5.0797459d-05,-1.0265221d-04 /
      data fpp( 1, 8,18,1),fpp( 1, 8,18,2),fpp( 1, 8,18,3)/
     x 1.2305182d+00,-1.4933173d-05, 4.4575423d-05 /
      data fpp( 1, 8,19,1),fpp( 1, 8,19,2),fpp( 1, 8,19,3)/
     x 1.5214074d+00,-1.2974317d-04, 4.8952519d-05 /
      data fpp( 1, 8,20,1),fpp( 1, 8,20,2),fpp( 1, 8,20,3)/
     x 2.1901342d+00,-2.3807688d-05,-1.5256350d-04 /
      data fpp( 1, 8,21,1),fpp( 1, 8,21,2),fpp( 1, 8,21,3)/
     x 2.1901342d+00,-2.3807688d-05,-1.4789176d-04 /
      data fpp( 1, 8,22,1),fpp( 1, 8,22,2),fpp( 1, 8,22,3)/
     x 1.5214074d+00,-1.2974317d-04, 3.0265575d-05 /
      data fpp( 1, 8,23,1),fpp( 1, 8,23,2),fpp( 1, 8,23,3)/
     x 1.2305182d+00,-1.4933173d-05, 1.1465146d-04 /
      data fpp( 1, 9, 1,1),fpp( 1, 9, 1,2),fpp( 1, 9, 1,3)/
     x 2.0189962d-01,-8.2197812d-05, 3.4990803d-05 /
      data fpp( 1, 9, 2,1),fpp( 1, 9, 2,2),fpp( 1, 9, 2,3)/
     x 4.0371959d-01,-5.9431411d-05, 6.4551894d-05 /
      data fpp( 1, 9, 3,1),fpp( 1, 9, 3,2),fpp( 1, 9, 3,3)/
     x 3.2818767d-01, 4.0273449d-05, 1.3014362d-04 /
      data fpp( 1, 9, 4,1),fpp( 1, 9, 4,2),fpp( 1, 9, 4,3)/
     x 3.2818767d-01, 4.0273449d-05, 1.2621219d-04 /
      data fpp( 1, 9, 5,1),fpp( 1, 9, 5,2),fpp( 1, 9, 5,3)/
     x 4.0371959d-01,-5.9431411d-05, 8.0277614d-05 /
      data fpp( 1, 9, 6,1),fpp( 1, 9, 6,2),fpp( 1, 9, 6,3)/
     x 2.0189962d-01,-8.2197812d-05,-2.3980647d-05 /
      data fpp( 1, 9, 7,1),fpp( 1, 9, 7,2),fpp( 1, 9, 7,3)/
     x-8.2264120d-02,-4.7927998d-04, 1.8156297d-04 /
      data fpp( 1, 9, 8,1),fpp( 1, 9, 8,2),fpp( 1, 9, 8,3)/
     x 3.2524360d+00,-1.1250864d-03,-7.6827125d-04 /
      data fpp( 1, 9, 9,1),fpp( 1, 9, 9,2),fpp( 1, 9, 9,3)/
     x 1.6207438d+00, 2.2796613d-04, 1.1488401d-04 /
      data fpp( 1, 9,10,1),fpp( 1, 9,10,2),fpp( 1, 9,10,3)/
     x-4.3100098d-02,-7.9050528d-05, 2.9770722d-04 /
      data fpp( 1, 9,11,1),fpp( 1, 9,11,2),fpp( 1, 9,11,3)/
     x 1.5683132d+00, 1.2947456d-03,-2.0032687d-04 /
      data fpp( 1, 9,12,1),fpp( 1, 9,12,2),fpp( 1, 9,12,3)/
     x 1.4913968d+00, 1.3575144d-03, 1.5386626d-04 /
      data fpp( 1, 9,13,1),fpp( 1, 9,13,2),fpp( 1, 9,13,3)/
     x 1.4602487d+00,-3.0221615d-04,-2.0648218d-04 /
      data fpp( 1, 9,14,1),fpp( 1, 9,14,2),fpp( 1, 9,14,3)/
     x-8.4620273d-03, 1.1746119d-03, 4.2609847d-04 /
      data fpp( 1, 9,15,1),fpp( 1, 9,15,2),fpp( 1, 9,15,3)/
     x 1.5060087d+00,-2.8455355d-04,-4.0444769d-04 /
      data fpp( 1, 9,16,1),fpp( 1, 9,16,2),fpp( 1, 9,16,3)/
     x-5.3583879d-03,-3.5425342d-05, 4.2384229d-04 /
      data fpp( 1, 9,17,1),fpp( 1, 9,17,2),fpp( 1, 9,17,3)/
     x 1.5414403d+00,-2.1917121d-04,-2.1768948d-04 /
      data fpp( 1, 9,18,1),fpp( 1, 9,18,2),fpp( 1, 9,18,3)/
     x 1.4793595d+00,-1.7665093d-04, 7.0373613d-05 /
      data fpp( 1, 9,19,1),fpp( 1, 9,19,2),fpp( 1, 9,19,3)/
     x 1.3398394d+00,-6.3360960d-05, 1.0913024d-05 /
      data fpp( 1, 9,20,1),fpp( 1, 9,20,2),fpp( 1, 9,20,3)/
     x 1.1785208d+00, 4.1160229d-05,-8.5819707d-05 /
      data fpp( 1, 9,21,1),fpp( 1, 9,21,2),fpp( 1, 9,21,3)/
     x 1.1785208d+00, 4.1160229d-05,-8.6499390d-05 /
      data fpp( 1, 9,22,1),fpp( 1, 9,22,2),fpp( 1, 9,22,3)/
     x 1.3398394d+00,-6.3360960d-05, 1.3631754d-05 /
      data fpp( 1, 9,23,1),fpp( 1, 9,23,2),fpp( 1, 9,23,3)/
     x 1.4793595d+00,-1.7665093d-04, 6.0178373d-05 /
      data fpp( 1,10, 1,1),fpp( 1,10, 1,2),fpp( 1,10, 1,3)/
     x 3.9235008d-01,-1.1664649d-06, 5.1932961d-05 /
      data fpp( 1,10, 2,1),fpp( 1,10, 2,2),fpp( 1,10, 2,3)/
     x 6.6503473d-01, 9.8691570d-05, 8.0971078d-05 /
      data fpp( 1,10, 3,1),fpp( 1,10, 3,2),fpp( 1,10, 3,3)/
     x 2.2664496d-01, 2.5798810d-04, 1.3959473d-04 /
      data fpp( 1,10, 4,1),fpp( 1,10, 4,2),fpp( 1,10, 4,3)/
     x 2.2664496d-01, 2.5798810d-04, 1.4589628d-04 /
      data fpp( 1,10, 5,1),fpp( 1,10, 5,2),fpp( 1,10, 5,3)/
     x 6.6503473d-01, 9.8691570d-05, 5.5764843d-05 /
      data fpp( 1,10, 6,1),fpp( 1,10, 6,2),fpp( 1,10, 6,3)/
     x 3.9235008d-01,-1.1664649d-06, 1.4645634d-04 /
      data fpp( 1,10, 7,1),fpp( 1,10, 7,2),fpp( 1,10, 7,3)/
     x 3.6250753d-01,-7.0482442d-06,-1.3735022d-04 /
      data fpp( 1,10, 8,1),fpp( 1,10, 8,2),fpp( 1,10, 8,3)/
     x-5.2051550d-02, 1.4822099d-04, 3.1256652d-04 /
      data fpp( 1,10, 9,1),fpp( 1,10, 9,2),fpp( 1,10, 9,3)/
     x 2.9006225d+00,-9.1233203d-04,-1.3821839d-03 /
      data fpp( 1,10,10,1),fpp( 1,10,10,2),fpp( 1,10,10,3)/
     x-8.2303221d-02,-2.2864872d-06, 1.7117009d-03 /
      data fpp( 1,10,11,1),fpp( 1,10,11,2),fpp( 1,10,11,3)/
     x 1.1394526d+01,-2.4231349d-03,-9.0383375d-04 /
      data fpp( 1,10,12,1),fpp( 1,10,12,2),fpp( 1,10,12,3)/
     x 1.1730192d+01,-2.5160168d-03,-1.3478439d-03 /
      data fpp( 1,10,13,1),fpp( 1,10,13,2),fpp( 1,10,13,3)/
     x-1.9916794d-02, 1.3572395d-04, 2.7632433d-03 /
      data fpp( 1,10,14,1),fpp( 1,10,14,2),fpp( 1,10,14,3)/
     x 1.0607722d+01,-1.3806690d-03,-2.6863113d-03 /
      data fpp( 1,10,15,1),fpp( 1,10,15,2),fpp( 1,10,15,3)/
     x-1.4775974d-02, 1.5810994d-04, 1.6202017d-03 /
      data fpp( 1,10,16,1),fpp( 1,10,16,2),fpp( 1,10,16,3)/
     x-1.4911775d-02,-1.7840605d-05,-4.1054973d-04 /
      data fpp( 1,10,17,1),fpp( 1,10,17,2),fpp( 1,10,17,3)/
     x-1.6910710d-02, 1.7376230d-04, 1.3386117d-04 /
      data fpp( 1,10,18,1),fpp( 1,10,18,2),fpp( 1,10,18,3)/
     x-2.0286512d-02, 1.7245889d-04,-1.7920964d-05 /
      data fpp( 1,10,19,1),fpp( 1,10,19,2),fpp( 1,10,19,3)/
     x-2.8570226d-02, 1.4702701d-04, 7.0932681d-05 /
      data fpp( 1,10,20,1),fpp( 1,10,20,2),fpp( 1,10,20,3)/
     x-1.9246544d-02, 1.3438677d-04,-9.8757761d-05 /
      data fpp( 1,10,21,1),fpp( 1,10,21,2),fpp( 1,10,21,3)/
     x-1.9246544d-02, 1.3438677d-04,-9.0781059d-05 /
      data fpp( 1,10,22,1),fpp( 1,10,22,2),fpp( 1,10,22,3)/
     x-2.8570226d-02, 1.4702701d-04, 3.9025874d-05 /
      data fpp( 1,10,23,1),fpp( 1,10,23,2),fpp( 1,10,23,3)/
     x-2.0286512d-02, 1.7245889d-04, 1.0172956d-04 /
      data fpp( 1,11, 1,1),fpp( 1,11, 1,2),fpp( 1,11, 1,3)/
     x 1.5376631d-01, 2.7496967d-04, 3.8397393d-04 /
      data fpp( 1,11, 2,1),fpp( 1,11, 2,2),fpp( 1,11, 2,3)/
     x 3.2154643d-01, 6.5876913d-04, 2.4346364d-04 /
      data fpp( 1,11, 3,1),fpp( 1,11, 3,2),fpp( 1,11, 3,3)/
     x 5.5846597d-01, 1.4281722d-03,-5.0050507d-05 /
      data fpp( 1,11, 4,1),fpp( 1,11, 4,2),fpp( 1,11, 4,3)/
     x 5.5846597d-01, 1.4281722d-03,-6.3314300d-05 /
      data fpp( 1,11, 5,1),fpp( 1,11, 5,2),fpp( 1,11, 5,3)/
     x 3.2154643d-01, 6.5876913d-04, 2.9651882d-04 /
      data fpp( 1,11, 6,1),fpp( 1,11, 6,2),fpp( 1,11, 6,3)/
     x 1.5376631d-01, 2.7496967d-04, 1.8501704d-04 /
      data fpp( 1,11, 7,1),fpp( 1,11, 7,2),fpp( 1,11, 7,3)/
     x 5.8093543d-02, 1.1272096d-04, 2.9115030d-05 /
      data fpp( 1,11, 8,1),fpp( 1,11, 8,2),fpp( 1,11, 8,3)/
     x-2.2755125d-02,-2.1483598d-05, 7.6908430d-06 /
      data fpp( 1,11, 9,1),fpp( 1,11, 9,2),fpp( 1,11, 9,3)/
     x-2.7524892d-01, 2.2592400d-04,-3.0459440d-04 /
      data fpp( 1,11,10,1),fpp( 1,11,10,2),fpp( 1,11,10,3)/
     x-3.7049459d-02,-2.6981752d-04,-3.0804524d-04 /
      data fpp( 1,11,11,1),fpp( 1,11,11,2),fpp( 1,11,11,3)/
     x-5.7980048d-02, 1.5262760d-03, 2.0203335d-04 /
      data fpp( 1,11,12,1),fpp( 1,11,12,2),fpp( 1,11,12,3)/
     x-3.9700698d-02, 1.6311547d-03,-3.4368616d-04 /
      data fpp( 1,11,13,1),fpp( 1,11,13,2),fpp( 1,11,13,3)/
     x-2.6943845d-02,-8.5621631d-05, 1.3344593d-03 /
      data fpp( 1,11,14,1),fpp( 1,11,14,2),fpp( 1,11,14,3)/
     x 9.1582083d+00, 4.0534404d-04,-2.0387850d-03 /
      data fpp( 1,11,15,1),fpp( 1,11,15,2),fpp( 1,11,15,3)/
     x-1.9345917d-02,-6.8316197d-05, 1.3236845d-03 /
      data fpp( 1,11,16,1),fpp( 1,11,16,2),fpp( 1,11,16,3)/
     x-2.2815378d-02,-7.0202398d-06,-3.3587918d-04 /
      data fpp( 1,11,17,1),fpp( 1,11,17,2),fpp( 1,11,17,3)/
     x-3.0177564d-02,-4.4183974d-05, 1.0920818d-04 /
      data fpp( 1,11,18,1),fpp( 1,11,18,2),fpp( 1,11,18,3)/
     x-4.3208096d-02,-3.1216630d-05,-5.6915593d-06 /
      data fpp( 1,11,19,1),fpp( 1,11,19,2),fpp( 1,11,19,3)/
     x-1.0354396d-01,-3.0149088d-05, 6.7416053d-05 /
      data fpp( 1,11,20,1),fpp( 1,11,20,2),fpp( 1,11,20,3)/
     x 4.8154840d+00,-2.0020931d-04,-8.6804651d-05 /
      data fpp( 1,11,21,1),fpp( 1,11,21,2),fpp( 1,11,21,3)/
     x 4.8154840d+00,-2.0020931d-04,-7.9918072d-05 /
      data fpp( 1,11,22,1),fpp( 1,11,22,2),fpp( 1,11,22,3)/
     x-1.0354396d-01,-3.0149088d-05, 3.9869735d-05 /
      data fpp( 1,11,23,1),fpp( 1,11,23,2),fpp( 1,11,23,3)/
     x-4.3208096d-02,-3.1216630d-05, 9.7607133d-05 /
      data fpp( 1,12, 1,1),fpp( 1,12, 1,2),fpp( 1,12, 1,3)/
     x 3.4439265d-01, 3.3201778d-04, 1.3197140d-03 /
      data fpp( 1,12, 2,1),fpp( 1,12, 2,2),fpp( 1,12, 2,3)/
     x 8.7782194d-01, 8.2954791d-04, 6.7122602d-04 /
      data fpp( 1,12, 3,1),fpp( 1,12, 3,2),fpp( 1,12, 3,3)/
     x 1.8859689d+00, 9.4402924d-04,-6.8567005d-04 /
      data fpp( 1,12, 4,1),fpp( 1,12, 4,2),fpp( 1,12, 4,3)/
     x 1.8859689d+00, 9.4402924d-04,-7.4293184d-04 /
      data fpp( 1,12, 5,1),fpp( 1,12, 5,2),fpp( 1,12, 5,3)/
     x 8.7782194d-01, 8.2954791d-04, 9.0027317d-04 /
      data fpp( 1,12, 6,1),fpp( 1,12, 6,2),fpp( 1,12, 6,3)/
     x 3.4439265d-01, 3.3201778d-04, 4.6078717d-04 /
      data fpp( 1,12, 7,1),fpp( 1,12, 7,2),fpp( 1,12, 7,3)/
     x 1.2978840d-01, 1.4198041d-04, 1.7141416d-04 /
      data fpp( 1,12, 8,1),fpp( 1,12, 8,2),fpp( 1,12, 8,3)/
     x 3.1456691d-02, 8.5631397d-05,-3.0713804d-05 /
      data fpp( 1,12, 9,1),fpp( 1,12, 9,2),fpp( 1,12, 9,3)/
     x-6.4957143d-02,-3.1251983d-05,-1.8630943d-05 /
      data fpp( 1,12,10,1),fpp( 1,12,10,2),fpp( 1,12,10,3)/
     x-1.8363925d-01,-1.3394142d-04,-4.1556242d-04 /
      data fpp( 1,12,11,1),fpp( 1,12,11,2),fpp( 1,12,11,3)/
     x 1.2284193d-02,-5.1170109d-04, 1.1986635d-05 /
      data fpp( 1,12,12,1),fpp( 1,12,12,2),fpp( 1,12,12,3)/
     x-1.9077377d-02,-6.7030985d-04,-2.8584412d-04 /
      data fpp( 1,12,13,1),fpp( 1,12,13,2),fpp( 1,12,13,3)/
     x-1.5594355d-02,-1.6725420d-05, 1.2570478d-03 /
      data fpp( 1,12,14,1),fpp( 1,12,14,2),fpp( 1,12,14,3)/
     x 8.7158189d+00,-1.1180916d-04,-1.9362672d-03 /
      data fpp( 1,12,15,1),fpp( 1,12,15,2),fpp( 1,12,15,3)/
     x-1.3802014d-02,-3.7291487d-06, 1.2556610d-03 /
      data fpp( 1,12,16,1),fpp( 1,12,16,2),fpp( 1,12,16,3)/
     x-2.1477857d-02,-9.1104364d-06,-3.1854084d-04 /
      data fpp( 1,12,17,1),fpp( 1,12,17,2),fpp( 1,12,17,3)/
     x-3.6107715d-02, 1.5981600d-05, 8.9578345d-05 /
      data fpp( 1,12,18,1),fpp( 1,12,18,2),fpp( 1,12,18,3)/
     x-6.7250200d-02, 3.2945629d-05, 4.3267458d-05 /
      data fpp( 1,12,19,1),fpp( 1,12,19,2),fpp( 1,12,19,3)/
     x-2.6767989d-01, 7.4135339d-05,-1.3554418d-04 /
      data fpp( 1,12,20,1),fpp( 1,12,20,2),fpp( 1,12,20,3)/
     x-2.5266451d-01, 1.3450249d-04, 3.3651245d-05 /
      data fpp( 1,12,21,1),fpp( 1,12,21,2),fpp( 1,12,21,3)/
     x-2.5266451d-01, 1.3450249d-04, 2.1415352d-05 /
      data fpp( 1,12,22,1),fpp( 1,12,22,2),fpp( 1,12,22,3)/
     x-2.6767989d-01, 7.4135339d-05,-8.6600600d-05 /
      data fpp( 1,12,23,1),fpp( 1,12,23,2),fpp( 1,12,23,3)/
     x-6.7250200d-02, 3.2945629d-05,-1.4027095d-04 /
      data fpp( 1,13, 1,1),fpp( 1,13, 1,2),fpp( 1,13, 1,3)/
     x 6.6667575d-01,-5.7296785d-05, 1.7427481d-03 /
      data fpp( 1,13, 2,1),fpp( 1,13, 2,2),fpp( 1,13, 2,3)/
     x 1.9060278d+00,-8.1052075d-04, 7.7415024d-04 /
      data fpp( 1,13, 3,1),fpp( 1,13, 3,2),fpp( 1,13, 3,3)/
     x-5.8374987d+00,-2.1848251d-03,-1.2769031d-03 /
      data fpp( 1,13, 4,1),fpp( 1,13, 4,2),fpp( 1,13, 4,3)/
     x-5.8374987d+00,-2.1848251d-03,-1.3198018d-03 /
      data fpp( 1,13, 5,1),fpp( 1,13, 5,2),fpp( 1,13, 5,3)/
     x 1.9060278d+00,-8.1052075d-04, 9.4574523d-04 /
      data fpp( 1,13, 6,1),fpp( 1,13, 6,2),fpp( 1,13, 6,3)/
     x 6.6667575d-01,-5.7296785d-05, 1.0992669d-03 /
      data fpp( 1,13, 7,1),fpp( 1,13, 7,2),fpp( 1,13, 7,3)/
     x 2.2158877d-01, 1.0892141d-04, 2.8567310d-04 /
      data fpp( 1,13, 8,1),fpp( 1,13, 8,2),fpp( 1,13, 8,3)/
     x 7.6847879d-02, 9.1302011d-05, 5.9292687d-05 /
      data fpp( 1,13, 9,1),fpp( 1,13, 9,2),fpp( 1,13, 9,3)/
     x-3.1467554d-03, 1.0212993d-04,-5.0349846d-05 /
      data fpp( 1,13,10,1),fpp( 1,13,10,2),fpp( 1,13,10,3)/
     x-1.0899271d-01, 5.3453203d-05,-1.2663930d-04 /
      data fpp( 1,13,11,1),fpp( 1,13,11,2),fpp( 1,13,11,3)/
     x 3.3288208d-02,-7.7776237d-06,-2.6713894d-04 /
      data fpp( 1,13,12,1),fpp( 1,13,12,2),fpp( 1,13,12,3)/
     x 3.3902286d-02, 8.0334074d-04,-2.1038892d-04 /
      data fpp( 1,13,13,1),fpp( 1,13,13,2),fpp( 1,13,13,3)/
     x 1.5732772d-02,-3.5024687d-05, 9.7589663d-04 /
      data fpp( 1,13,14,1),fpp( 1,13,14,2),fpp( 1,13,14,3)/
     x 6.8262542d+00,-5.5725538d-04,-1.5071996d-03 /
      data fpp( 1,13,15,1),fpp( 1,13,15,2),fpp( 1,13,15,3)/
     x 8.6539614d-03,-3.1451208d-05, 9.8124177d-04 /
      data fpp( 1,13,16,1),fpp( 1,13,16,2),fpp( 1,13,16,3)/
     x 1.4936211d-03,-2.8076015d-05,-2.4348748d-04 /
      data fpp( 1,13,17,1),fpp( 1,13,17,2),fpp( 1,13,17,3)/
     x-1.1158823d-02,-3.2246426d-05, 6.1372151d-05 /
      data fpp( 1,13,18,1),fpp( 1,13,18,2),fpp( 1,13,18,3)/
     x-3.7531751d-02,-3.7037885d-05, 8.5814877d-05 /
      data fpp( 1,13,19,1),fpp( 1,13,19,2),fpp( 1,13,19,3)/
     x-1.6339908d-01,-6.6724269d-05,-2.4417366d-04 /
      data fpp( 1,13,20,1),fpp( 1,13,20,2),fpp( 1,13,20,3)/
     x-1.8450930d-02, 3.0023337d-04, 8.5421751d-05 /
      data fpp( 1,13,21,1),fpp( 1,13,21,2),fpp( 1,13,21,3)/
     x-1.8450930d-02, 3.0023337d-04, 6.2456575d-05 /
      data fpp( 1,13,22,1),fpp( 1,13,22,2),fpp( 1,13,22,3)/
     x-1.6339908d-01,-6.6724269d-05,-1.5231295d-04 /
      data fpp( 1,13,23,1),fpp( 1,13,23,2),fpp( 1,13,23,3)/
     x-3.7531751d-02,-3.7037885d-05,-2.5866278d-04 /
      data fpp( 1,14, 1,1),fpp( 1,14, 1,2),fpp( 1,14, 1,3)/
     x 7.6455842d-01,-3.6518064d-04, 1.1281714d-03 /
      data fpp( 1,14, 2,1),fpp( 1,14, 2,2),fpp( 1,14, 2,3)/
     x 2.1679071d+00,-1.4545849d-03, 4.1864726d-04 /
      data fpp( 1,14, 3,1),fpp( 1,14, 3,2),fpp( 1,14, 3,3)/
     x-7.9950846d+00,-1.7851867d-03,-1.1053844d-03 /
      data fpp( 1,14, 4,1),fpp( 1,14, 4,2),fpp( 1,14, 4,3)/
     x-7.9950846d+00,-1.7851867d-03,-1.0990444d-03 /
      data fpp( 1,14, 5,1),fpp( 1,14, 5,2),fpp( 1,14, 5,3)/
     x 2.1679071d+00,-1.4545849d-03, 3.9328717d-04 /
      data fpp( 1,14, 6,1),fpp( 1,14, 6,2),fpp( 1,14, 6,3)/
     x 7.6455842d-01,-3.6518064d-04, 1.2232717d-03 /
      data fpp( 1,14, 7,1),fpp( 1,14, 7,2),fpp( 1,14, 7,3)/
     x 2.8583381d-01, 1.4443949d-05, 3.0545194d-04 /
      data fpp( 1,14, 8,1),fpp( 1,14, 8,2),fpp( 1,14, 8,3)/
     x 1.1198250d-01, 9.6378560d-05, 1.4234252d-04 /
      data fpp( 1,14, 9,1),fpp( 1,14, 9,2),fpp( 1,14, 9,3)/
     x 2.8566239d-01, 5.2254273d-05,-3.2566021d-05 /
      data fpp( 1,14,10,1),fpp( 1,14,10,2),fpp( 1,14,10,3)/
     x-3.6492555d-02, 3.9666606d-05,-2.2105844d-04 /
      data fpp( 1,14,11,1),fpp( 1,14,11,2),fpp( 1,14,11,3)/
     x-1.4881796d-01,-2.9504412d-05, 5.5573177d-04 /
      data fpp( 1,14,12,1),fpp( 1,14,12,2),fpp( 1,14,12,3)/
     x 5.7879256d+00,-1.0356431d-03,-1.3879966d-03 /
      data fpp( 1,14,13,1),fpp( 1,14,13,2),fpp( 1,14,13,3)/
     x 4.9535590d-02,-2.0349831d-05, 8.4069074d-04 /
      data fpp( 1,14,14,1),fpp( 1,14,14,2),fpp( 1,14,14,3)/
     x 4.1824119d-02, 6.7884269d-04,-2.0908033d-04 /
      data fpp( 1,14,15,1),fpp( 1,14,15,2),fpp( 1,14,15,3)/
     x 3.9168771d-02,-2.9694017d-05, 7.2244578d-05 /
      data fpp( 1,14,16,1),fpp( 1,14,16,2),fpp( 1,14,16,3)/
     x 3.8000030d-02,-4.1989505d-05,-6.1099828d-06 /
      data fpp( 1,14,17,1),fpp( 1,14,17,2),fpp( 1,14,17,3)/
     x 3.9368103d-02,-5.6993897d-05, 1.6029353d-05 /
      data fpp( 1,14,18,1),fpp( 1,14,18,2),fpp( 1,14,18,3)/
     x 4.9217455d-02,-8.0418089d-05, 1.5552570d-05 /
      data fpp( 1,14,19,1),fpp( 1,14,19,2),fpp( 1,14,19,3)/
     x 7.9545889d-02,-1.1263226d-04, 3.1428368d-05 /
      data fpp( 1,14,20,1),fpp( 1,14,20,2),fpp( 1,14,20,3)/
     x 1.5787276d-01,-5.2331795d-04,-5.9642041d-05 /
      data fpp( 1,14,21,1),fpp( 1,14,21,2),fpp( 1,14,21,3)/
     x 1.5787276d-01,-5.2331795d-04,-5.6871061d-05 /
      data fpp( 1,14,22,1),fpp( 1,14,22,2),fpp( 1,14,22,3)/
     x 7.9545889d-02,-1.1263226d-04, 2.0344446d-05 /
      data fpp( 1,14,23,1),fpp( 1,14,23,2),fpp( 1,14,23,3)/
     x 4.9217455d-02,-8.0418089d-05, 5.7117277d-05 /
      data fpp( 1,15, 1,1),fpp( 1,15, 1,2),fpp( 1,15, 1,3)/
     x 5.7047764d-01, 1.1185933d-04, 8.1145412d-04 /
      data fpp( 1,15, 2,1),fpp( 1,15, 2,2),fpp( 1,15, 2,3)/
     x 1.1796057d+00, 5.6230831d-04, 3.5934376d-04 /
      data fpp( 1,15, 3,1),fpp( 1,15, 3,2),fpp( 1,15, 3,3)/
     x 2.1388177d+00, 4.1897410d-04,-5.9617718d-04 /
      data fpp( 1,15, 4,1),fpp( 1,15, 4,2),fpp( 1,15, 4,3)/
     x 2.1388177d+00, 4.1897410d-04,-6.1942935d-04 /
      data fpp( 1,15, 5,1),fpp( 1,15, 5,2),fpp( 1,15, 5,3)/
     x 1.1796057d+00, 5.6230831d-04, 4.5235246d-04 /
      data fpp( 1,15, 6,1),fpp( 1,15, 6,2),fpp( 1,15, 6,3)/
     x 5.7047764d-01, 1.1185933d-04, 4.6267150d-04 /
      data fpp( 1,15, 7,1),fpp( 1,15, 7,2),fpp( 1,15, 7,3)/
     x 2.6305626d-01, 7.8636793d-05, 2.4322954d-04 /
      data fpp( 1,15, 8,1),fpp( 1,15, 8,2),fpp( 1,15, 8,3)/
     x 1.2260143d-01, 1.0142175d-04, 1.1941234d-04 /
      data fpp( 1,15, 9,1),fpp( 1,15, 9,2),fpp( 1,15, 9,3)/
     x 2.7536461d-01, 8.1630982d-05,-2.7224914d-05 /
      data fpp( 1,15,10,1),fpp( 1,15,10,2),fpp( 1,15,10,3)/
     x 1.2251806d-03, 6.8710371d-05,-8.6214689d-05 /
      data fpp( 1,15,11,1),fpp( 1,15,11,2),fpp( 1,15,11,3)/
     x-9.6714320d-02, 3.3581271d-05, 2.1289767d-04 /
      data fpp( 1,15,12,1),fpp( 1,15,12,2),fpp( 1,15,12,3)/
     x 2.1528916d+00, 2.9376975d-04,-7.1225198d-04 /
      data fpp( 1,15,13,1),fpp( 1,15,13,2),fpp( 1,15,13,3)/
     x 6.2742177d-02,-1.4009987d-05, 3.2605627d-04 /
      data fpp( 1,15,14,1),fpp( 1,15,14,2),fpp( 1,15,14,3)/
     x 5.9481239d-02,-2.0834937d-04,-8.1427088d-05 /
      data fpp( 1,15,15,1),fpp( 1,15,15,2),fpp( 1,15,15,3)/
     x 5.7492621d-02,-1.2174722d-05, 3.2172084d-05 /
      data fpp( 1,15,16,1),fpp( 1,15,16,2),fpp( 1,15,16,3)/
     x 5.8468883d-02,-4.3059670d-06, 2.6475026d-07 /
      data fpp( 1,15,17,1),fpp( 1,15,17,2),fpp( 1,15,17,3)/
     x 6.2462552d-02, 2.9720138d-06, 6.8009145d-06 /
      data fpp( 1,15,18,1),fpp( 1,15,18,2),fpp( 1,15,18,3)/
     x 7.1995473d-02, 1.5570242d-05, 2.8555918d-06 /
      data fpp( 1,15,19,1),fpp( 1,15,19,2),fpp( 1,15,19,3)/
     x 8.9086266d-02, 4.6289319d-05,-1.2792815d-06 /
      data fpp( 1,15,20,1),fpp( 1,15,20,2),fpp( 1,15,20,3)/
     x 1.0962311d-01, 2.0395644d-04,-1.9326466d-05 /
      data fpp( 1,15,21,1),fpp( 1,15,21,2),fpp( 1,15,21,3)/
     x 1.0962311d-01, 2.0395644d-04,-1.9122962d-05 /
      data fpp( 1,15,22,1),fpp( 1,15,22,2),fpp( 1,15,22,3)/
     x 8.9086266d-02, 4.6289319d-05,-2.0932966d-06 /
      data fpp( 1,15,23,1),fpp( 1,15,23,2),fpp( 1,15,23,3)/
     x 7.1995473d-02, 1.5570242d-05, 5.9081483d-06 /
      data fpp( 1,16, 1,1),fpp( 1,16, 1,2),fpp( 1,16, 1,3)/
     x 2.9646452d-01, 3.7623330d-04, 1.5449675d-04 /
      data fpp( 1,16, 2,1),fpp( 1,16, 2,2),fpp( 1,16, 2,3)/
     x 4.0413682d-01, 7.9952766d-04, 8.3821004d-05 /
      data fpp( 1,16, 3,1),fpp( 1,16, 3,2),fpp( 1,16, 3,3)/
     x 1.1252355d+00, 1.6544464d-03,-6.6558764d-05 /
      data fpp( 1,16, 4,1),fpp( 1,16, 4,2),fpp( 1,16, 4,3)/
     x 1.1252355d+00, 1.6544464d-03,-6.8428209d-05 /
      data fpp( 1,16, 5,1),fpp( 1,16, 5,2),fpp( 1,16, 5,3)/
     x 4.0413682d-01, 7.9952766d-04, 9.1298785d-05 /
      data fpp( 1,16, 6,1),fpp( 1,16, 6,2),fpp( 1,16, 6,3)/
     x 2.9646452d-01, 3.7623330d-04, 1.2645507d-04 /
      data fpp( 1,16, 7,1),fpp( 1,16, 7,2),fpp( 1,16, 7,3)/
     x 1.7926132d-01, 1.9050088d-04, 1.0027894d-04 /
      data fpp( 1,16, 8,1),fpp( 1,16, 8,2),fpp( 1,16, 8,3)/
     x 1.0433803d-01, 1.3250645d-04, 4.9089168d-05 /
      data fpp( 1,16, 9,1),fpp( 1,16, 9,2),fpp( 1,16, 9,3)/
     x 5.5758300d-02, 1.3378980d-04, 1.1332387d-05 /
      data fpp( 1,16,10,1),fpp( 1,16,10,2),fpp( 1,16,10,3)/
     x 1.9324476d-02, 8.9051911d-05,-2.3846714d-05 /
      data fpp( 1,16,11,1),fpp( 1,16,11,2),fpp( 1,16,11,3)/
     x-5.3793299d-03, 5.5565330d-05,-7.4155297d-06 /
      data fpp( 1,16,12,1),fpp( 1,16,12,2),fpp( 1,16,12,3)/
     x-1.1032847d-01, 6.3634107d-05,-1.6825717d-04 /
      data fpp( 1,16,13,1),fpp( 1,16,13,2),fpp( 1,16,13,3)/
     x 5.0357353d-02, 2.1333780d-05,-8.4909802d-05 /
      data fpp( 1,16,14,1),fpp( 1,16,14,2),fpp( 1,16,14,3)/
     x 6.4952236d-02, 9.3312790d-05, 1.5242374d-05 /
      data fpp( 1,16,15,1),fpp( 1,16,15,2),fpp( 1,16,15,3)/
     x 6.4908131d-02,-1.5990952d-06,-1.9769560d-07 /
      data fpp( 1,16,16,1),fpp( 1,16,16,2),fpp( 1,16,16,3)/
     x 6.4900981d-02,-4.1910627d-05, 4.4304080d-06 /
      data fpp( 1,16,17,1),fpp( 1,16,17,2),fpp( 1,16,17,3)/
     x 6.6038513d-02,-7.4564158d-05, 1.2920634d-06 /
      data fpp( 1,16,18,1),fpp( 1,16,18,2),fpp( 1,16,18,3)/
     x 6.8535433d-02,-9.8052879d-05,-4.8466167d-07 /
      data fpp( 1,16,19,1),fpp( 1,16,19,2),fpp( 1,16,19,3)/
     x 7.2144496d-02,-1.1314501d-04,-3.0434167d-06 /
      data fpp( 1,16,20,1),fpp( 1,16,20,2),fpp( 1,16,20,3)/
     x 7.5652605d-02,-1.5156782d-04,-6.1516714d-06 /
      data fpp( 1,16,21,1),fpp( 1,16,21,2),fpp( 1,16,21,3)/
     x 7.5652605d-02,-1.5156782d-04,-6.2042775d-06 /
      data fpp( 1,16,22,1),fpp( 1,16,22,2),fpp( 1,16,22,3)/
     x 7.2144496d-02,-1.1314501d-04,-2.8329921d-06 /
      data fpp( 1,16,23,1),fpp( 1,16,23,2),fpp( 1,16,23,3)/
     x 6.8535433d-02,-9.8052879d-05,-1.2737539d-06 /
      data fpp( 1,17, 1,1),fpp( 1,17, 1,2),fpp( 1,17, 1,3)/
     x 1.3312797d-01, 1.8444946d-04, 4.2373734d-05 /
      data fpp( 1,17, 2,1),fpp( 1,17, 2,2),fpp( 1,17, 2,3)/
     x 1.6540323d-01, 2.6760905d-04, 3.8851533d-05 /
      data fpp( 1,17, 3,1),fpp( 1,17, 3,2),fpp( 1,17, 3,3)/
     x 1.9064837d-01, 2.5342648d-04, 3.1384136d-05 /
      data fpp( 1,17, 4,1),fpp( 1,17, 4,2),fpp( 1,17, 4,3)/
     x 1.9064837d-01, 2.5342648d-04, 3.1243827d-05 /
      data fpp( 1,17, 5,1),fpp( 1,17, 5,2),fpp( 1,17, 5,3)/
     x 1.6540323d-01, 2.6760905d-04, 3.9412767d-05 /
      data fpp( 1,17, 6,1),fpp( 1,17, 6,2),fpp( 1,17, 6,3)/
     x 1.3312797d-01, 1.8444946d-04, 4.0269106d-05 /
      data fpp( 1,17, 7,1),fpp( 1,17, 7,2),fpp( 1,17, 7,3)/
     x 1.0073446d-01, 1.1944969d-04, 3.3672811d-05 /
      data fpp( 1,17, 8,1),fpp( 1,17, 8,2),fpp( 1,17, 8,3)/
     x 7.2133616d-02, 8.5924456d-05, 2.1791651d-05 /
      data fpp( 1,17, 9,1),fpp( 1,17, 9,2),fpp( 1,17, 9,3)/
     x 4.6705121d-02, 6.4293823d-05, 7.8725842d-06 /
      data fpp( 1,17,10,1),fpp( 1,17,10,2),fpp( 1,17,10,3)/
     x 2.4253694d-02, 5.6323986d-05, 1.0012130d-08 /
      data fpp( 1,17,11,1),fpp( 1,17,11,2),fpp( 1,17,11,3)/
     x 4.1706463d-03, 3.5067411d-05,-2.2156633d-05 /
      data fpp( 1,17,12,1),fpp( 1,17,12,2),fpp( 1,17,12,3)/
     x 5.9388779d-02,-1.8458183d-05, 2.1230519d-05 /
      data fpp( 1,17,13,1),fpp( 1,17,13,2),fpp( 1,17,13,3)/
     x-1.5224594d+00,-1.9785913d-04,-1.7873944d-04 /
      data fpp( 1,17,14,1),fpp( 1,17,14,2),fpp( 1,17,14,3)/
     x 5.9885528d-02,-1.5504979d-04,-9.3587524d-06 /
      data fpp( 1,17,15,1),fpp( 1,17,15,2),fpp( 1,17,15,3)/
     x 6.7205758d-02, 3.0061103d-05, 6.3045130d-07 /
      data fpp( 1,17,16,1),fpp( 1,17,16,2),fpp( 1,17,16,3)/
     x 6.8128797d-02, 1.8906048d-04, 1.0589473d-06 /
      data fpp( 1,17,17,1),fpp( 1,17,17,2),fpp( 1,17,17,3)/
     x 6.8296716d-02, 3.2608262d-04, 7.9775970d-07 /
      data fpp( 1,17,18,1),fpp( 1,17,18,2),fpp( 1,17,18,3)/
     x 6.8466843d-02, 4.3737928d-04,-9.1986038d-08 /
      data fpp( 1,17,19,1),fpp( 1,17,19,2),fpp( 1,17,19,3)/
     x 6.8804404d-02, 5.2083073d-04,-8.9181554d-07 /
      data fpp( 1,17,20,1),fpp( 1,17,20,2),fpp( 1,17,20,3)/
     x 6.8752736d-02, 5.8142084d-04,-1.6087518d-06 /
      data fpp( 1,17,21,1),fpp( 1,17,21,2),fpp( 1,17,21,3)/
     x 6.8752736d-02, 5.8142084d-04,-1.6308369d-06 /
      data fpp( 1,17,22,1),fpp( 1,17,22,2),fpp( 1,17,22,3)/
     x 6.8804404d-02, 5.2083073d-04,-8.0347518d-07 /
      data fpp( 1,17,23,1),fpp( 1,17,23,2),fpp( 1,17,23,3)/
     x 6.8466843d-02, 4.3737928d-04,-4.2326241d-07 /
      data fpp( 1,18, 1,1),fpp( 1,18, 1,2),fpp( 1,18, 1,3)/
     x 5.4986660d-02, 1.6641687d-04, 1.7407702d-05 /
      data fpp( 1,18, 2,1),fpp( 1,18, 2,2),fpp( 1,18, 2,3)/
     x 6.1031758d-02, 1.8927213d-04, 1.8209597d-05 /
      data fpp( 1,18, 3,1),fpp( 1,18, 3,2),fpp( 1,18, 3,3)/
     x 6.4937189d-02, 2.4497372d-04, 1.9961911d-05 /
      data fpp( 1,18, 4,1),fpp( 1,18, 4,2),fpp( 1,18, 4,3)/
     x 6.4937189d-02, 2.4497372d-04, 1.9902469d-05 /
      data fpp( 1,18, 5,1),fpp( 1,18, 5,2),fpp( 1,18, 5,3)/
     x 6.1031758d-02, 1.8927213d-04, 1.8447365d-05 /
      data fpp( 1,18, 6,1),fpp( 1,18, 6,2),fpp( 1,18, 6,3)/
     x 5.4986660d-02, 1.6641687d-04, 1.6516069d-05 /
      data fpp( 1,18, 7,1),fpp( 1,18, 7,2),fpp( 1,18, 7,3)/
     x 4.8076727d-02, 1.6033638d-04, 1.3390357d-05 /
      data fpp( 1,18, 8,1),fpp( 1,18, 8,2),fpp( 1,18, 8,3)/
     x 3.9113987d-02, 1.6388773d-04, 1.0034503d-05 /
      data fpp( 1,18, 9,1),fpp( 1,18, 9,2),fpp( 1,18, 9,3)/
     x 2.7309266d-02, 1.7083891d-04, 6.1836320d-06 /
      data fpp( 1,18,10,1),fpp( 1,18,10,2),fpp( 1,18,10,3)/
     x 1.8643183d-02, 1.7041015d-04, 2.4849691d-06 /
      data fpp( 1,18,11,1),fpp( 1,18,11,2),fpp( 1,18,11,3)/
     x 1.1447161d-02, 1.6406903d-04,-9.4950851d-07 /
      data fpp( 1,18,12,1),fpp( 1,18,12,2),fpp( 1,18,12,3)/
     x-2.1618394d-03, 1.5305862d-04,-3.8829351d-06 /
      data fpp( 1,18,13,1),fpp( 1,18,13,2),fpp( 1,18,13,3)/
     x 2.4889368d-01, 1.3977875d-04,-6.2527512d-06 /
      data fpp( 1,18,14,1),fpp( 1,18,14,2),fpp( 1,18,14,3)/
     x 8.3999847d-01,-9.9631561d-08,-8.1020602d-06 /
      data fpp( 1,18,15,1),fpp( 1,18,15,2),fpp( 1,18,15,3)/
     x 1.3669903d+00,-1.8343932d-04,-9.4350079d-06 /
      data fpp( 1,18,16,1),fpp( 1,18,16,2),fpp( 1,18,16,3)/
     x 1.8177247d+00,-3.4275728d-04,-1.0419908d-05 /
      data fpp( 1,18,17,1),fpp( 1,18,17,2),fpp( 1,18,17,3)/
     x 2.1978250d+00,-4.7668232d-04,-1.1231359d-05 /
      data fpp( 1,18,18,1),fpp( 1,18,18,2),fpp( 1,18,18,3)/
     x 2.5186580d+00,-5.8331422d-04,-1.1896656d-05 /
      data fpp( 1,18,19,1),fpp( 1,18,19,2),fpp( 1,18,19,3)/
     x 2.7822612d+00,-6.6164992d-04,-1.3104019d-05 /
      data fpp( 1,18,20,1),fpp( 1,18,20,2),fpp( 1,18,20,3)/
     x 2.9554475d+00,-7.1222752d-04,-1.4431270d-05 /
      data fpp( 1,18,21,1),fpp( 1,18,21,2),fpp( 1,18,21,3)/
     x 2.9554475d+00,-7.1222752d-04,-1.4459180d-05 /
      data fpp( 1,18,22,1),fpp( 1,18,22,2),fpp( 1,18,22,3)/
     x 2.7822612d+00,-6.6164992d-04,-1.2992377d-05 /
      data fpp( 1,18,23,1),fpp( 1,18,23,2),fpp( 1,18,23,3)/
     x 2.5186580d+00,-5.8331422d-04,-1.2315311d-05 /
      data fpp( 1,19, 1,1),fpp( 1,19, 1,2),fpp( 1,19, 1,3)/
     x-4.6899503d+00, 9.8741065d-05, 4.1658333d-21 /
      data fpp( 1,19, 2,1),fpp( 1,19, 2,2),fpp( 1,19, 2,3)/
     x-4.6899503d+00,-1.8659564d-05,-1.4525053d-20 /
      data fpp( 1,19, 3,1),fpp( 1,19, 3,2),fpp( 1,19, 3,3)/
     x-4.6899503d+00,-1.6135536d-04,-4.8802014d-20 /
      data fpp( 1,19, 4,1),fpp( 1,19, 4,2),fpp( 1,19, 4,3)/
     x-4.6899503d+00,-1.6135536d-04, 2.6530548d-20 /
      data fpp( 1,19, 5,1),fpp( 1,19, 5,2),fpp( 1,19, 5,3)/
     x-4.6899503d+00,-1.8659564d-05,-1.5933766d-20 /
      data fpp( 1,19, 6,1),fpp( 1,19, 6,2),fpp( 1,19, 6,3)/
     x-4.6899503d+00, 9.8741065d-05, 7.1151939d-21 /
      data fpp( 1,19, 7,1),fpp( 1,19, 7,2),fpp( 1,19, 7,3)/
     x-4.6899503d+00, 1.6924081d-04,-7.2992865d-20 /
      data fpp( 1,19, 8,1),fpp( 1,19, 8,2),fpp( 1,19, 8,3)/
     x-4.6899503d+00, 2.0626664d-04,-2.5912622d-20 /
      data fpp( 1,19, 9,1),fpp( 1,19, 9,2),fpp( 1,19, 9,3)/
     x-4.6899503d+00, 2.2708655d-04, 4.6138867d-20 /
      data fpp( 1,19,10,1),fpp( 1,19,10,2),fpp( 1,19,10,3)/
     x-4.6899503d+00, 2.4254943d-04, 9.1749708d-20 /
      data fpp( 1,19,11,1),fpp( 1,19,11,2),fpp( 1,19,11,3)/
     x-4.6899503d+00, 2.5035649d-04,-5.0542188d-20 /
      data fpp( 1,19,12,1),fpp( 1,19,12,2),fpp( 1,19,12,3)/
     x-4.6899503d+00, 2.5211569d-04, 5.6171972d-20 /
      data fpp( 1,19,13,1),fpp( 1,19,13,2),fpp( 1,19,13,3)/
     x-4.6899503d+00, 3.1832212d-04, 1.2304176d-20 /
      data fpp( 1,19,14,1),fpp( 1,19,14,2),fpp( 1,19,14,3)/
     x-4.6899503d+00, 3.9618316d-05, 1.8376411d-20 /
      data fpp( 1,19,15,1),fpp( 1,19,15,2),fpp( 1,19,15,3)/
     x-4.6899503d+00,-3.2689384d-04, 1.2400135d-20 /
      data fpp( 1,19,16,1),fpp( 1,19,16,2),fpp( 1,19,16,3)/
     x-4.6899503d+00,-6.5663536d-04,-1.8416762d-20 /
      data fpp( 1,19,17,1),fpp( 1,19,17,2),fpp( 1,19,17,3)/
     x-4.6899503d+00,-9.3561534d-04, 4.4446213d-20 /
      data fpp( 1,19,18,1),fpp( 1,19,18,2),fpp( 1,19,18,3)/
     x-4.6899503d+00,-1.1594004d-03,-1.0675493d-20 /
      data fpp( 1,19,19,1),fpp( 1,19,19,2),fpp( 1,19,19,3)/
     x-4.6899503d+00,-1.3251430d-03,-3.8879635d-20 /
      data fpp( 1,19,20,1),fpp( 1,19,20,2),fpp( 1,19,20,3)/
     x-4.6899503d+00,-1.4268367d-03, 5.7548406d-20 /
      data fpp( 1,19,21,1),fpp( 1,19,21,2),fpp( 1,19,21,3)/
     x-4.6899503d+00,-1.4268367d-03,-1.9086138d-20 /
      data fpp( 1,19,22,1),fpp( 1,19,22,2),fpp( 1,19,22,3)/
     x-4.6899503d+00,-1.3251430d-03, 5.6945440d-20 /
      data fpp( 1,19,23,1),fpp( 1,19,23,2),fpp( 1,19,23,3)/
     x-4.6899503d+00,-1.1594004d-03, 1.7272423d-19 /
      data fpp( 2, 1, 1,1),fpp( 2, 1, 1,2),fpp( 2, 1, 1,3)/
     x 2.2123329d+00, 5.6317466d-04, 2.9590887d-19 /
      data fpp( 2, 1, 2,1),fpp( 2, 1, 2,2),fpp( 2, 1, 2,3)/
     x 2.2123329d+00, 9.0443783d-05, 6.6112269d-19 /
      data fpp( 2, 1, 3,1),fpp( 2, 1, 3,2),fpp( 2, 1, 3,3)/
     x 2.2123329d+00, 1.8062042d-04,-5.3074663d-19 /
      data fpp( 2, 1, 4,1),fpp( 2, 1, 4,2),fpp( 2, 1, 4,3)/
     x 2.2123329d+00, 1.8062042d-04, 4.9092899d-19 /
      data fpp( 2, 1, 5,1),fpp( 2, 1, 5,2),fpp( 2, 1, 5,3)/
     x 2.2123329d+00, 9.0443783d-05, 8.8833422d-19 /
      data fpp( 2, 1, 6,1),fpp( 2, 1, 6,2),fpp( 2, 1, 6,3)/
     x 2.2123329d+00, 5.6317466d-04,-5.9634318d-19 /
      data fpp( 2, 1, 7,1),fpp( 2, 1, 7,2),fpp( 2, 1, 7,3)/
     x 2.2123329d+00, 8.6112212d-04,-1.7371466d-18 /
      data fpp( 2, 1, 8,1),fpp( 2, 1, 8,2),fpp( 2, 1, 8,3)/
     x 2.2123329d+00, 1.1025139d-03,-3.7878776d-19 /
      data fpp( 2, 1, 9,1),fpp( 2, 1, 9,2),fpp( 2, 1, 9,3)/
     x 2.2123329d+00, 1.2892379d-03,-3.1743682d-20 /
      data fpp( 2, 1,10,1),fpp( 2, 1,10,2),fpp( 2, 1,10,3)/
     x 2.2123329d+00, 1.4125768d-03, 7.8396781d-19 /
      data fpp( 2, 1,11,1),fpp( 2, 1,11,2),fpp( 2, 1,11,3)/
     x 2.2123329d+00, 1.5079370d-03,-1.1717904d-18 /
      data fpp( 2, 1,12,1),fpp( 2, 1,12,2),fpp( 2, 1,12,3)/
     x 2.2123329d+00, 1.5559964d-03, 9.0727906d-19 /
      data fpp( 2, 1,13,1),fpp( 2, 1,13,2),fpp( 2, 1,13,3)/
     x 2.2123329d+00, 1.5109828d-03, 7.4859072d-19 /
      data fpp( 2, 1,14,1),fpp( 2, 1,14,2),fpp( 2, 1,14,3)/
     x 2.2123329d+00, 1.4299689d-03, 3.4521808d-19 /
      data fpp( 2, 1,15,1),fpp( 2, 1,15,2),fpp( 2, 1,15,3)/
     x 2.2123329d+00, 1.2940135d-03,-4.4418240d-19 /
      data fpp( 2, 1,16,1),fpp( 2, 1,16,2),fpp( 2, 1,16,3)/
     x 2.2123329d+00, 1.1040207d-03,-2.9993270d-19 /
      data fpp( 2, 1,17,1),fpp( 2, 1,17,2),fpp( 2, 1,17,3)/
     x 2.2123329d+00, 8.5494660d-04, 1.7437211d-18 /
      data fpp( 2, 1,18,1),fpp( 2, 1,18,2),fpp( 2, 1,18,3)/
     x 2.2123329d+00, 5.3024043d-04,-1.0617512d-18 /
      data fpp( 2, 1,19,1),fpp( 2, 1,19,2),fpp( 2, 1,19,3)/
     x 2.2123329d+00, 5.8507964d-05,-5.1731282d-19 /
      data fpp( 2, 1,20,1),fpp( 2, 1,20,2),fpp( 2, 1,20,3)/
     x 2.2123329d+00, 1.6975770d-04, 1.1258455d-18 /
      data fpp( 2, 1,21,1),fpp( 2, 1,21,2),fpp( 2, 1,21,3)/
     x 2.2123329d+00, 1.6975770d-04,-9.9883150d-19 /
      data fpp( 2, 1,22,1),fpp( 2, 1,22,2),fpp( 2, 1,22,3)/
     x 2.2123329d+00, 5.8507964d-05, 1.0702235d-18 /
      data fpp( 2, 1,23,1),fpp( 2, 1,23,2),fpp( 2, 1,23,3)/
     x 2.2123329d+00, 5.3024043d-04, 5.0077485d-18 /
      data fpp( 2, 2, 1,1),fpp( 2, 2, 1,2),fpp( 2, 2, 1,3)/
     x 7.5290745d-01, 2.0421368d-04,-2.0204709d-06 /
      data fpp( 2, 2, 2,1),fpp( 2, 2, 2,2),fpp( 2, 2, 2,3)/
     x 7.4850005d-01,-7.3647565d-05,-4.4765582d-06 /
      data fpp( 2, 2, 3,1),fpp( 2, 2, 3,2),fpp( 2, 2, 3,3)/
     x 7.2974990d-01,-6.6683152d-07,-9.9712962d-06 /
      data fpp( 2, 2, 4,1),fpp( 2, 2, 4,2),fpp( 2, 2, 4,3)/
     x 7.2974990d-01,-6.6683152d-07,-9.5658324d-06 /
      data fpp( 2, 2, 5,1),fpp( 2, 2, 5,2),fpp( 2, 2, 5,3)/
     x 7.4850005d-01,-7.3647565d-05,-6.0984135d-06 /
      data fpp( 2, 2, 6,1),fpp( 2, 2, 6,2),fpp( 2, 2, 6,3)/
     x 7.5290745d-01, 2.0421368d-04, 4.0614864d-06 /
      data fpp( 2, 2, 7,1),fpp( 2, 2, 7,2),fpp( 2, 2, 7,3)/
     x 7.3270492d-01, 3.6669675d-04,-3.4155321d-06 /
      data fpp( 2, 2, 8,1),fpp( 2, 2, 8,2),fpp( 2, 2, 8,3)/
     x 7.2489087d-01, 4.8234911d-04, 2.7186419d-06 /
      data fpp( 2, 2, 9,1),fpp( 2, 2, 9,2),fpp( 2, 2, 9,3)/
     x 7.2780467d-01, 5.6578217d-04, 1.0912964d-05 /
      data fpp( 2, 2,10,1),fpp( 2, 2,10,2),fpp( 2, 2,10,3)/
     x 7.4025256d-01, 6.1823734d-04,-6.5004995d-06 /
      data fpp( 2, 2,11,1),fpp( 2, 2,11,2),fpp( 2, 2,11,3)/
     x 7.3258794d-01, 6.5917904d-04, 1.1981034d-05 /
      data fpp( 2, 2,12,1),fpp( 2, 2,12,2),fpp( 2, 2,12,3)/
     x 7.3330184d-01, 6.8317115d-04, 3.0903651d-06 /
      data fpp( 2, 2,13,1),fpp( 2, 2,13,2),fpp( 2, 2,13,3)/
     x 7.3314671d-01, 6.5890033d-04, 5.3995060d-06 /
      data fpp( 2, 2,14,1),fpp( 2, 2,14,2),fpp( 2, 2,14,3)/
     x 7.1728907d-01, 6.2338718d-04, 4.6216110d-06 /
      data fpp( 2, 2,15,1),fpp( 2, 2,15,2),fpp( 2, 2,15,3)/
     x 7.2746405d-01, 5.6372800d-04, 4.1700499d-06 /
      data fpp( 2, 2,16,1),fpp( 2, 2,16,2),fpp( 2, 2,16,3)/
     x 7.5078511d-01, 4.7857759d-04, 2.9501892d-06 /
      data fpp( 2, 2,17,1),fpp( 2, 2,17,2),fpp( 2, 2,17,3)/
     x 7.2054654d-01, 3.6070379d-04, 2.8751931d-06 /
      data fpp( 2, 2,18,1),fpp( 2, 2,18,2),fpp( 2, 2,18,3)/
     x 6.9558206d-01, 1.9455614d-04,-6.2849616d-06 /
      data fpp( 2, 2,19,1),fpp( 2, 2,19,2),fpp( 2, 2,19,3)/
     x 7.5309416d-01,-8.6175927d-05, 1.0665329d-07 /
      data fpp( 2, 2,20,1),fpp( 2, 2,20,2),fpp( 2, 2,20,3)/
     x 7.5576813d-01, 5.0116042d-06,-1.0857652d-05 /
      data fpp( 2, 2,21,1),fpp( 2, 2,21,2),fpp( 2, 2,21,3)/
     x 7.5576813d-01, 5.0116042d-06,-1.0311372d-05 /
      data fpp( 2, 2,22,1),fpp( 2, 2,22,2),fpp( 2, 2,22,3)/
     x 7.5309416d-01,-8.6175927d-05,-2.0784652d-06 /
      data fpp( 2, 2,23,1),fpp( 2, 2,23,2),fpp( 2, 2,23,3)/
     x 6.9558206d-01, 1.9455614d-04, 1.9092326d-06 /
      data fpp( 2, 3, 1,1),fpp( 2, 3, 1,2),fpp( 2, 3, 1,3)/
     x 1.5563964d-01,-7.5749939d-04, 5.3438610d-05 /
      data fpp( 2, 3, 2,1),fpp( 2, 3, 2,2),fpp( 2, 3, 2,3)/
     x 2.1112659d-01, 1.1072785d-03, 1.3962280d-05 /
      data fpp( 2, 3, 3,1),fpp( 2, 3, 3,2),fpp( 2, 3, 3,3)/
     x 3.0866113d-01, 1.1051709d-03,-6.9693730d-05 /
      data fpp( 2, 3, 4,1),fpp( 2, 3, 4,2),fpp( 2, 3, 4,3)/
     x 3.0866113d-01, 1.1051709d-03,-7.1331950d-05 /
      data fpp( 2, 3, 5,1),fpp( 2, 3, 5,2),fpp( 2, 3, 5,3)/
     x 2.1112659d-01, 1.1072785d-03, 2.0515158d-05 /
      data fpp( 2, 3, 6,1),fpp( 2, 3, 6,2),fpp( 2, 3, 6,3)/
     x 1.5563964d-01,-7.5749939d-04, 2.8865318d-05 /
      data fpp( 2, 3, 7,1),fpp( 2, 3, 7,2),fpp( 2, 3, 7,3)/
     x-1.0728832d-01,-1.8494631d-03, 1.4005571d-05 /
      data fpp( 2, 3, 8,1),fpp( 2, 3, 8,2),fpp( 2, 3, 8,3)/
     x 6.5911818d-01,-2.5845924d-03, 1.4304399d-05 /
      data fpp( 2, 3, 9,1),fpp( 2, 3, 9,2),fpp( 2, 3, 9,3)/
     x-1.0934115d+00,-3.0923946d-03, 9.3028345d-06 /
      data fpp( 2, 3,10,1),fpp( 2, 3,10,2),fpp( 2, 3,10,3)/
     x-3.3490788d+00,-3.4328562d-03, 8.2682635d-06 /
      data fpp( 2, 3,11,1),fpp( 2, 3,11,2),fpp( 2, 3,11,3)/
     x-4.6395999d+00,-3.6431791d-03, 7.5141116d-06 /
      data fpp( 2, 3,12,1),fpp( 2, 3,12,2),fpp( 2, 3,12,3)/
     x-5.0718498d+00,-3.7816690d-03, 7.4372900d-06 /
      data fpp( 2, 3,13,1),fpp( 2, 3,13,2),fpp( 2, 3,13,3)/
     x-4.6256193d+00,-3.6486562d-03, 7.5987285d-06 /
      data fpp( 2, 3,14,1),fpp( 2, 3,14,2),fpp( 2, 3,14,3)/
     x-3.3154273d+00,-3.4470876d-03, 8.3737960d-06 /
      data fpp( 2, 3,15,1),fpp( 2, 3,15,2),fpp( 2, 3,15,3)/
     x-1.0261572d+00,-3.0995555d-03, 9.4560873d-06 /
      data fpp( 2, 3,16,1),fpp( 2, 3,16,2),fpp( 2, 3,16,3)/
     x 6.2795959d-01,-2.5837691d-03, 1.4557855d-05 /
      data fpp( 2, 3,17,1),fpp( 2, 3,17,2),fpp( 2, 3,17,3)/
     x-7.5394524d-02,-1.8338358d-03, 1.4176494d-05 /
      data fpp( 2, 3,18,1),fpp( 2, 3,18,2),fpp( 2, 3,18,3)/
     x 1.5576079d-01,-7.3134300d-04, 2.8900168d-05 /
      data fpp( 2, 3,19,1),fpp( 2, 3,19,2),fpp( 2, 3,19,3)/
     x 2.0943155d-01, 1.1709197d-03, 2.0312832d-05 /
      data fpp( 2, 3,20,1),fpp( 2, 3,20,2),fpp( 2, 3,20,3)/
     x 3.3716233d-01, 1.0743179d-03,-7.1787497d-05 /
      data fpp( 2, 3,21,1),fpp( 2, 3,21,2),fpp( 2, 3,21,3)/
     x 3.3716233d-01, 1.0743179d-03,-7.0154926d-05 /
      data fpp( 2, 3,22,1),fpp( 2, 3,22,2),fpp( 2, 3,22,3)/
     x 2.0943155d-01, 1.1709197d-03, 1.3782550d-05 /
      data fpp( 2, 3,23,1),fpp( 2, 3,23,2),fpp( 2, 3,23,3)/
     x 1.5576079d-01,-7.3134300d-04, 5.3388725d-05 /
      data fpp( 2, 4, 1,1),fpp( 2, 4, 1,2),fpp( 2, 4, 1,3)/
     x 5.6379784d-01, 3.9041989d-04,-1.0621003d-03 /
      data fpp( 2, 4, 2,1),fpp( 2, 4, 2,2),fpp( 2, 4, 2,3)/
     x 1.2898986d-01,-2.4193563d-03,-7.3006192d-04 /
      data fpp( 2, 4, 3,1),fpp( 2, 4, 3,2),fpp( 2, 4, 3,3)/
     x 2.0559687d-01,-2.2939288d-03,-9.0062028d-05 /
      data fpp( 2, 4, 4,1),fpp( 2, 4, 4,2),fpp( 2, 4, 4,3)/
     x 2.0559687d-01,-2.2939288d-03, 3.5082045d-05 /
      data fpp( 2, 4, 5,1),fpp( 2, 4, 5,2),fpp( 2, 4, 5,3)/
     x 1.2898986d-01,-2.4193563d-03,-1.2306382d-03 /
      data fpp( 2, 4, 6,1),fpp( 2, 4, 6,2),fpp( 2, 4, 6,3)/
     x 5.6379784d-01, 3.9041989d-04, 8.1506081d-04 /
      data fpp( 2, 4, 7,1),fpp( 2, 4, 7,2),fpp( 2, 4, 7,3)/
     x 2.4771802d-01, 1.9604478d-03,-2.4304143d-07 /
      data fpp( 2, 4, 8,1),fpp( 2, 4, 8,2),fpp( 2, 4, 8,3)/
     x 2.6824356d-01, 2.9121844d-03, 1.5339335d-04 /
      data fpp( 2, 4, 9,1),fpp( 2, 4, 9,2),fpp( 2, 4, 9,3)/
     x 2.8345187d-01, 3.5209522d-03, 6.3469635d-05 /
      data fpp( 2, 4,10,1),fpp( 2, 4,10,2),fpp( 2, 4,10,3)/
     x 2.9558068d-01, 3.9146895d-03, 9.5780109d-05 /
      data fpp( 2, 4,11,1),fpp( 2, 4,11,2),fpp( 2, 4,11,3)/
     x 3.0565969d-01, 4.1420635d-03,-1.0240710d-06 /
      data fpp( 2, 4,12,1),fpp( 2, 4,12,2),fpp( 2, 4,12,3)/
     x 8.8845504d-01, 4.3255429d-03, 1.8181417d-04 /
      data fpp( 2, 4,13,1),fpp( 2, 4,13,2),fpp( 2, 4,13,3)/
     x 3.1074641d-01, 4.1379463d-03, 4.2137156d-07 /
      data fpp( 2, 4,14,1),fpp( 2, 4,14,2),fpp( 2, 4,14,3)/
     x 2.9695264d-01, 3.9060634d-03, 9.8296339d-05 /
      data fpp( 2, 4,15,1),fpp( 2, 4,15,2),fpp( 2, 4,15,3)/
     x 2.7617118d-01, 3.5026541d-03, 6.7619273d-05 /
      data fpp( 2, 4,16,1),fpp( 2, 4,16,2),fpp( 2, 4,16,3)/
     x 2.6908646d-01, 2.8830467d-03, 1.5981457d-04 /
      data fpp( 2, 4,17,1),fpp( 2, 4,17,2),fpp( 2, 4,17,3)/
     x 2.6728890d-01, 1.9226633d-03, 1.0924480d-06 /
      data fpp( 2, 4,18,1),fpp( 2, 4,18,2),fpp( 2, 4,18,3)/
     x 5.6560170d-01, 4.0850985d-04, 8.3617164d-04 /
      data fpp( 2, 4,19,1),fpp( 2, 4,19,2),fpp( 2, 4,19,3)/
     x-2.1793187d-01,-2.4782131d-03,-1.3115150d-03 /
      data fpp( 2, 4,20,1),fpp( 2, 4,20,2),fpp( 2, 4,20,3)/
     x 2.3313900d-01,-2.1755591d-03, 6.9170363d-05 /
      data fpp( 2, 4,21,1),fpp( 2, 4,21,2),fpp( 2, 4,21,3)/
     x 2.3313900d-01,-2.1755591d-03,-6.3361590d-05 /
      data fpp( 2, 4,22,1),fpp( 2, 4,22,2),fpp( 2, 4,22,3)/
     x-2.1793187d-01,-2.4782131d-03,-7.8138719d-04 /
      data fpp( 2, 4,23,1),fpp( 2, 4,23,2),fpp( 2, 4,23,3)/
     x 5.6560170d-01, 4.0850985d-04,-1.1518077d-03 /
      data fpp( 2, 5, 1,1),fpp( 2, 5, 1,2),fpp( 2, 5, 1,3)/
     x 3.2448260d-01, 1.3012798d-03, 9.0473370d-05 /
      data fpp( 2, 5, 2,1),fpp( 2, 5, 2,2),fpp( 2, 5, 2,3)/
     x 3.3438825d-01, 2.6474149d-03,-1.0738239d-05 /
      data fpp( 2, 5, 3,1),fpp( 2, 5, 3,2),fpp( 2, 5, 3,3)/
     x 1.3303154d-01, 2.1242803d-03,-2.2727441d-04 /
      data fpp( 2, 5, 4,1),fpp( 2, 5, 4,2),fpp( 2, 5, 4,3)/
     x 1.3303154d-01, 2.1242803d-03,-2.2787964d-04 /
      data fpp( 2, 5, 5,1),fpp( 2, 5, 5,2),fpp( 2, 5, 5,3)/
     x 3.3438825d-01, 2.6474149d-03,-8.3173307d-06 /
      data fpp( 2, 5, 6,1),fpp( 2, 5, 6,2),fpp( 2, 5, 6,3)/
     x 3.2448260d-01, 1.3012798d-03, 8.1394963d-05 /
      data fpp( 2, 5, 7,1),fpp( 2, 5, 7,2),fpp( 2, 5, 7,3)/
     x 1.1399703d-01, 5.4226600d-04,-7.5785229d-06 /
      data fpp( 2, 5, 8,1),fpp( 2, 5, 8,2),fpp( 2, 5, 8,3)/
     x-1.4945422d-01, 1.7751088d-04, 6.2619128d-05 /
      data fpp( 2, 5, 9,1),fpp( 2, 5, 9,2),fpp( 2, 5, 9,3)/
     x 1.0338415d-01,-2.0096081d-05, 5.2776011d-05 /
      data fpp( 2, 5,10,1),fpp( 2, 5,10,2),fpp( 2, 5,10,3)/
     x 1.0855288d-01,-1.3657964d-04, 6.0938829d-05 /
      data fpp( 2, 5,11,1),fpp( 2, 5,11,2),fpp( 2, 5,11,3)/
     x 1.4920163d-01,-2.0107295d-04, 6.1386675d-05 /
      data fpp( 2, 5,12,1),fpp( 2, 5,12,2),fpp( 2, 5,12,3)/
     x 1.1315030d-01,-2.9387472d-04, 6.2694473d-05 /
      data fpp( 2, 5,13,1),fpp( 2, 5,13,2),fpp( 2, 5,13,3)/
     x 1.4389285d-01,-2.0667300d-04, 6.3483433d-05 /
      data fpp( 2, 5,14,1),fpp( 2, 5,14,2),fpp( 2, 5,14,3)/
     x 1.0984736d-01,-1.4765780d-04, 6.3981795d-05 /
      data fpp( 2, 5,15,1),fpp( 2, 5,15,2),fpp( 2, 5,15,3)/
     x 1.0453886d-01,-3.6000716d-05, 6.4991386d-05 /
      data fpp( 2, 5,16,1),fpp( 2, 5,16,2),fpp( 2, 5,16,3)/
     x 1.3120616d-01, 1.5828039d-04, 5.8558660d-05 /
      data fpp( 2, 5,17,1),fpp( 2, 5,17,2),fpp( 2, 5,17,3)/
     x 1.0289300d-01, 5.1707856d-04, 7.0409973d-05 /
      data fpp( 2, 5,18,1),fpp( 2, 5,18,2),fpp( 2, 5,18,3)/
     x 8.4039872d-02, 1.1750796d-03,-2.9685527d-06 /
      data fpp( 2, 5,19,1),fpp( 2, 5,19,2),fpp( 2, 5,19,3)/
     x 3.0141951d-01, 2.7194145d-03, 5.5728238d-05 /
      data fpp( 2, 5,20,1),fpp( 2, 5,20,2),fpp( 2, 5,20,3)/
     x 3.6697180d-01, 2.1769847d-03,-2.6786640d-04 /
      data fpp( 2, 5,21,1),fpp( 2, 5,21,2),fpp( 2, 5,21,3)/
     x 3.6697180d-01, 2.1769847d-03,-2.5791192d-04 /
      data fpp( 2, 5,22,1),fpp( 2, 5,22,2),fpp( 2, 5,22,3)/
     x 3.0141951d-01, 2.7194145d-03, 1.5910335d-05 /
      data fpp( 2, 5,23,1),fpp( 2, 5,23,2),fpp( 2, 5,23,3)/
     x 8.4039872d-02, 1.1750796d-03, 1.4634858d-04 /
      data fpp( 2, 6, 1,1),fpp( 2, 6, 1,2),fpp( 2, 6, 1,3)/
     x 2.0726809d-02,-2.3491722d-04,-1.1765304d-05 /
      data fpp( 2, 6, 2,1),fpp( 2, 6, 2,2),fpp( 2, 6, 2,3)/
     x 2.9246068d-01,-4.4579529d-04,-4.0177391d-05 /
      data fpp( 2, 6, 3,1),fpp( 2, 6, 3,2),fpp( 2, 6, 3,3)/
     x 2.1821573d-01,-9.9200506d-05,-9.9025131d-05 /
      data fpp( 2, 6, 4,1),fpp( 2, 6, 4,2),fpp( 2, 6, 4,3)/
     x 2.1821573d-01,-9.9200506d-05,-1.0258691d-04 /
      data fpp( 2, 6, 5,1),fpp( 2, 6, 5,2),fpp( 2, 6, 5,3)/
     x 2.9246068d-01,-4.4579529d-04,-2.5930269d-05 /
      data fpp( 2, 6, 6,1),fpp( 2, 6, 6,2),fpp( 2, 6, 6,3)/
     x 2.0726809d-02,-2.3491722d-04,-6.5192013d-05 /
      data fpp( 2, 6, 7,1),fpp( 2, 6, 7,2),fpp( 2, 6, 7,3)/
     x 2.7029228d-02, 1.7046228d-05, 2.6526322d-05 /
      data fpp( 2, 6, 8,1),fpp( 2, 6, 8,2),fpp( 2, 6, 8,3)/
     x 3.4465250d-02, 1.2052412d-04, 2.9262725d-05 /
      data fpp( 2, 6, 9,1),fpp( 2, 6, 9,2),fpp( 2, 6, 9,3)/
     x 4.0767171d-02, 1.7200816d-04, 4.4600779d-05 /
      data fpp( 2, 6,10,1),fpp( 2, 6,10,2),fpp( 2, 6,10,3)/
     x 4.5570745d-02, 2.0470112d-04, 4.9278161d-05 /
      data fpp( 2, 6,11,1),fpp( 2, 6,11,2),fpp( 2, 6,11,3)/
     x 4.8373188d-02, 2.1991627d-04, 5.2676577d-05 /
      data fpp( 2, 6,12,1),fpp( 2, 6,12,2),fpp( 2, 6,12,3)/
     x 4.9998948d-02, 2.4163596d-04, 5.4253529d-05 /
      data fpp( 2, 6,13,1),fpp( 2, 6,13,2),fpp( 2, 6,13,3)/
     x 4.9121913d-02, 2.1430970d-04, 5.4843306d-05 /
      data fpp( 2, 6,14,1),fpp( 2, 6,14,2),fpp( 2, 6,14,3)/
     x 4.8952857d-02, 1.9352983d-04, 5.5311246d-05 /
      data fpp( 2, 6,15,1),fpp( 2, 6,15,2),fpp( 2, 6,15,3)/
     x 4.4529901d-02, 1.5704281d-04, 5.4823709d-05 /
      data fpp( 2, 6,16,1),fpp( 2, 6,16,2),fpp( 2, 6,16,3)/
     x 4.0947276d-01, 9.6389760d-05, 5.1949919d-05 /
      data fpp( 2, 6,17,1),fpp( 2, 6,17,2),fpp( 2, 6,17,3)/
     x 3.1952771d-02,-6.9355379d-06, 4.3298615d-05 /
      data fpp( 2, 6,18,1),fpp( 2, 6,18,2),fpp( 2, 6,18,3)/
     x 2.2606577d-02,-1.7598828d-04, 2.6273620d-05 /
      data fpp( 2, 6,19,1),fpp( 2, 6,19,2),fpp( 2, 6,19,3)/
     x 1.2550336d-02,-5.7708280d-04,-1.3405096d-05 /
      data fpp( 2, 6,20,1),fpp( 2, 6,20,2),fpp( 2, 6,20,3)/
     x 3.8455334d-01,-2.8375765d-04,-1.9104124d-04 /
      data fpp( 2, 6,21,1),fpp( 2, 6,21,2),fpp( 2, 6,21,3)/
     x 3.8455334d-01,-2.8375765d-04,-1.8898974d-04 /
      data fpp( 2, 6,22,1),fpp( 2, 6,22,2),fpp( 2, 6,22,3)/
     x 1.2550336d-02,-5.7708280d-04,-2.1611074d-05 /
      data fpp( 2, 6,23,1),fpp( 2, 6,23,2),fpp( 2, 6,23,3)/
     x 2.2606577d-02,-1.7598828d-04, 5.7046037d-05 /
      data fpp( 2, 7, 1,1),fpp( 2, 7, 1,2),fpp( 2, 7, 1,3)/
     x-2.1874680d-01, 1.1879106d-04,-1.7637433d-06 /
      data fpp( 2, 7, 2,1),fpp( 2, 7, 2,2),fpp( 2, 7, 2,3)/
     x 6.0291372d-01,-8.7665762d-05,-1.7030513d-05 /
      data fpp( 2, 7, 3,1),fpp( 2, 7, 3,2),fpp( 2, 7, 3,3)/
     x-3.4701066d-02,-4.0633831d-04,-4.4954203d-05 /
      data fpp( 2, 7, 4,1),fpp( 2, 7, 4,2),fpp( 2, 7, 4,3)/
     x-3.4701066d-02,-4.0633831d-04,-5.3338134d-05 /
      data fpp( 2, 7, 5,1),fpp( 2, 7, 5,2),fpp( 2, 7, 5,3)/
     x 6.0291372d-01,-8.7665762d-05, 1.6505211d-05 /
      data fpp( 2, 7, 6,1),fpp( 2, 7, 6,2),fpp( 2, 7, 6,3)/
     x-2.1874680d-01, 1.1879106d-04,-1.2752271d-04 /
      data fpp( 2, 7, 7,1),fpp( 2, 7, 7,2),fpp( 2, 7, 7,3)/
     x-1.0374076d-02,-6.2998911d-05, 2.6773627d-05 /
      data fpp( 2, 7, 8,1),fpp( 2, 7, 8,2),fpp( 2, 7, 8,3)/
     x 9.4580018d-04,-8.7327353d-05, 4.8582013d-06 /
      data fpp( 2, 7, 9,1),fpp( 2, 7, 9,2),fpp( 2, 7, 9,3)/
     x 1.0387728d-01,-7.5832544d-05, 2.9471568d-05 /
      data fpp( 2, 7,10,1),fpp( 2, 7,10,2),fpp( 2, 7,10,3)/
     x 1.3670068d-02,-8.9880818d-05, 3.6897527d-05 /
      data fpp( 2, 7,11,1),fpp( 2, 7,11,2),fpp( 2, 7,11,3)/
     x 1.7164832d-02,-9.6640124d-05, 4.3168323d-05 /
      data fpp( 2, 7,12,1),fpp( 2, 7,12,2),fpp( 2, 7,12,3)/
     x 6.0094009d-02,-1.0533312d-04, 4.5501179d-05 /
      data fpp( 2, 7,13,1),fpp( 2, 7,13,2),fpp( 2, 7,13,3)/
     x 1.9819852d-02,-1.0026382d-04, 4.5828961d-05 /
      data fpp( 2, 7,14,1),fpp( 2, 7,14,2),fpp( 2, 7,14,3)/
     x 1.9836934d-02,-9.6301513d-05, 4.5340977d-05 /
      data fpp( 2, 7,15,1),fpp( 2, 7,15,2),fpp( 2, 7,15,3)/
     x 1.1003910d-01,-8.8368508d-05, 4.4013130d-05 /
      data fpp( 2, 7,16,1),fpp( 2, 7,16,2),fpp( 2, 7,16,3)/
     x 1.5935458d-02,-7.5425435d-05, 4.0182503d-05 /
      data fpp( 2, 7,17,1),fpp( 2, 7,17,2),fpp( 2, 7,17,3)/
     x 1.1840331d-02,-5.5608407d-05, 3.8166856d-05 /
      data fpp( 2, 7,18,1),fpp( 2, 7,18,2),fpp( 2, 7,18,3)/
     x 2.7330175d-01,-2.9460488d-05, 1.5380071d-05 /
      data fpp( 2, 7,19,1),fpp( 2, 7,19,2),fpp( 2, 7,19,3)/
     x-2.8499839d-03, 3.1326747d-05, 4.8830859d-05 /
      data fpp( 2, 7,20,1),fpp( 2, 7,20,2),fpp( 2, 7,20,3)/
     x 5.5924710d-01,-1.8487210d-04,-1.8562951d-04 /
      data fpp( 2, 7,21,1),fpp( 2, 7,21,2),fpp( 2, 7,21,3)/
     x 5.5924710d-01,-1.8487210d-04,-1.7884791d-04 /
      data fpp( 2, 7,22,1),fpp( 2, 7,22,2),fpp( 2, 7,22,3)/
     x-2.8499839d-03, 3.1326747d-05, 2.1704474d-05 /
      data fpp( 2, 7,23,1),fpp( 2, 7,23,2),fpp( 2, 7,23,3)/
     x 2.7330175d-01,-2.9460488d-05, 1.1710401d-04 /
      data fpp( 2, 8, 1,1),fpp( 2, 8, 1,2),fpp( 2, 8, 1,3)/
     x 2.1777056d-02,-6.2392300d-04, 2.0200665d-07 /
      data fpp( 2, 8, 2,1),fpp( 2, 8, 2,2),fpp( 2, 8, 2,3)/
     x-1.6247875d-03,-3.9109767d-04, 2.4728987d-05 /
      data fpp( 2, 8, 3,1),fpp( 2, 8, 3,2),fpp( 2, 8, 3,3)/
     x 2.7899044d-01,-1.1795027d-04, 9.1634047d-05 /
      data fpp( 2, 8, 4,1),fpp( 2, 8, 4,2),fpp( 2, 8, 4,3)/
     x 2.7899044d-01,-1.1795027d-04, 6.6526367d-05 /
      data fpp( 2, 8, 5,1),fpp( 2, 8, 5,2),fpp( 2, 8, 5,3)/
     x-1.6247875d-03,-3.9109767d-04, 1.2515971d-04 /
      data fpp( 2, 8, 6,1),fpp( 2, 8, 6,2),fpp( 2, 8, 6,3)/
     x 2.1777056d-02,-6.2392300d-04,-3.7641319d-04 /
      data fpp( 2, 8, 7,1),fpp( 2, 8, 7,2),fpp( 2, 8, 7,3)/
     x-7.6792478d-02,-3.9585856d-06, 4.7929047d-05 /
      data fpp( 2, 8, 8,1),fpp( 2, 8, 8,2),fpp( 2, 8, 8,3)/
     x-3.0032691d-02, 2.0633293d-05,-3.0630998d-05 /
      data fpp( 2, 8, 9,1),fpp( 2, 8, 9,2),fpp( 2, 8, 9,3)/
     x 4.4390615d-01,-7.0295980d-05, 1.3550946d-05 /
      data fpp( 2, 8,10,1),fpp( 2, 8,10,2),fpp( 2, 8,10,3)/
     x-1.0017574d-02,-5.5753842d-05, 2.3275215d-05 /
      data fpp( 2, 8,11,1),fpp( 2, 8,11,2),fpp( 2, 8,11,3)/
     x 3.6847684d-01,-5.7911772d-05, 3.4396196d-05 /
      data fpp( 2, 8,12,1),fpp( 2, 8,12,2),fpp( 2, 8,12,3)/
     x 3.5210208d-01,-5.6481499d-05, 3.7404002d-05 /
      data fpp( 2, 8,13,1),fpp( 2, 8,13,2),fpp( 2, 8,13,3)/
     x 3.5576806d-01,-5.6854436d-05, 3.7657796d-05 /
      data fpp( 2, 8,14,1),fpp( 2, 8,14,2),fpp( 2, 8,14,3)/
     x 3.4514179d-03,-5.4959775d-05, 3.5728815d-05 /
      data fpp( 2, 8,15,1),fpp( 2, 8,15,2),fpp( 2, 8,15,3)/
     x 4.2735356d-01,-5.1296772d-05, 3.2870944d-05 /
      data fpp( 2, 8,16,1),fpp( 2, 8,16,2),fpp( 2, 8,16,3)/
     x 4.7633477d-03,-4.4594022d-05, 2.8297410d-05 /
      data fpp( 2, 8,17,1),fpp( 2, 8,17,2),fpp( 2, 8,17,3)/
     x 5.7595080d-01,-3.2800835d-05, 2.3751417d-05 /
      data fpp( 2, 8,18,1),fpp( 2, 8,18,2),fpp( 2, 8,18,3)/
     x 6.8367363d-01,-1.1869769d-05, 1.0472921d-05 /
      data fpp( 2, 8,19,1),fpp( 2, 8,19,2),fpp( 2, 8,19,3)/
     x 8.4712521d-01, 1.7651816d-05, 1.1510899d-05 /
      data fpp( 2, 8,20,1),fpp( 2, 8,20,2),fpp( 2, 8,20,3)/
     x 1.2246016d+00, 1.3932606d-04,-1.0935252d-04 /
      data fpp( 2, 8,21,1),fpp( 2, 8,21,2),fpp( 2, 8,21,3)/
     x 1.2246016d+00, 1.3932606d-04,-1.0662589d-04 /
      data fpp( 2, 8,22,1),fpp( 2, 8,22,2),fpp( 2, 8,22,3)/
     x 8.4712521d-01, 1.7651816d-05, 6.0439812d-07 /
      data fpp( 2, 8,23,1),fpp( 2, 8,23,2),fpp( 2, 8,23,3)/
     x 6.8367363d-01,-1.1869769d-05, 5.1372301d-05 /
      data fpp( 2, 9, 1,1),fpp( 2, 9, 1,2),fpp( 2, 9, 1,3)/
     x 1.0459076d-01,-3.0773060d-05, 5.8432949d-05 /
      data fpp( 2, 9, 2,1),fpp( 2, 9, 2,2),fpp( 2, 9, 2,3)/
     x 2.2879082d-01,-9.6555747d-06, 7.9456603d-05 /
      data fpp( 2, 9, 3,1),fpp( 2, 9, 3,2),fpp( 2, 9, 3,3)/
     x 1.9441467d-01,-3.6332609d-05, 1.2136264d-04 /
      data fpp( 2, 9, 4,1),fpp( 2, 9, 4,2),fpp( 2, 9, 4,3)/
     x 1.9441467d-01,-3.6332609d-05, 1.2686578d-04 /
      data fpp( 2, 9, 5,1),fpp( 2, 9, 5,2),fpp( 2, 9, 5,3)/
     x 2.2879082d-01,-9.6555747d-06, 5.7444047d-05 /
      data fpp( 2, 9, 6,1),fpp( 2, 9, 6,2),fpp( 2, 9, 6,3)/
     x 1.0459076d-01,-3.0773060d-05, 1.4098003d-04 /
      data fpp( 2, 9, 7,1),fpp( 2, 9, 7,2),fpp( 2, 9, 7,3)/
     x-2.4191176d-01,-6.6128475d-04,-4.0616218d-04 /
      data fpp( 2, 9, 8,1),fpp( 2, 9, 8,2),fpp( 2, 9, 8,3)/
     x 1.7826080d+00,-2.3926782d-04,-1.0291733d-04 /
      data fpp( 2, 9, 9,1),fpp( 2, 9, 9,2),fpp( 2, 9, 9,3)/
     x 8.8431232d-01, 1.0918463d-05, 2.1973478d-05 /
      data fpp( 2, 9,10,1),fpp( 2, 9,10,2),fpp( 2, 9,10,3)/
     x-3.3099805d-02,-7.4565814d-05, 9.7494126d-06 /
      data fpp( 2, 9,11,1),fpp( 2, 9,11,2),fpp( 2, 9,11,3)/
     x 8.6032370d-01,-7.2932787d-05, 2.8500871d-05 /
      data fpp( 2, 9,12,1),fpp( 2, 9,12,2),fpp( 2, 9,12,3)/
     x 8.1971637d-01,-7.0794889d-05, 3.0627102d-05 /
      data fpp( 2, 9,13,1),fpp( 2, 9,13,2),fpp( 2, 9,13,3)/
     x 8.0393265d-01,-6.5528438d-05, 3.1006720d-05 /
      data fpp( 2, 9,14,1),fpp( 2, 9,14,2),fpp( 2, 9,14,3)/
     x-6.9759454d-03,-5.8619385d-05, 2.8322019d-05 /
      data fpp( 2, 9,15,1),fpp( 2, 9,15,2),fpp( 2, 9,15,3)/
     x 8.3131265d-01,-4.8942403d-05, 2.5199204d-05 /
      data fpp( 2, 9,16,1),fpp( 2, 9,16,2),fpp( 2, 9,16,3)/
     x-3.4632241d-03,-3.5698478d-05, 2.1061166d-05 /
      data fpp( 2, 9,17,1),fpp( 2, 9,17,2),fpp( 2, 9,17,3)/
     x 8.5258931d-01,-1.8568254d-05, 1.8392133d-05 /
      data fpp( 2, 9,18,1),fpp( 2, 9,18,2),fpp( 2, 9,18,3)/
     x 8.1960105d-01, 1.6215646d-06, 1.0634300d-05 /
      data fpp( 2, 9,19,1),fpp( 2, 9,19,2),fpp( 2, 9,19,3)/
     x 7.4572129d-01, 2.6651990d-05, 1.8702665d-05 /
      data fpp( 2, 9,20,1),fpp( 2, 9,20,2),fpp( 2, 9,20,3)/
     x 6.6622845d-01, 9.4349853d-05,-8.1898960d-05 /
      data fpp( 2, 9,21,1),fpp( 2, 9,21,2),fpp( 2, 9,21,3)/
     x 6.6622845d-01, 9.4349853d-05,-7.9287451d-05 /
      data fpp( 2, 9,22,1),fpp( 2, 9,22,2),fpp( 2, 9,22,3)/
     x 7.4572129d-01, 2.6651990d-05, 8.2566290d-06 /
      data fpp( 2, 9,23,1),fpp( 2, 9,23,2),fpp( 2, 9,23,3)/
     x 8.1960105d-01, 1.6215646d-06, 4.9806936d-05 /
      data fpp( 2,10, 1,1),fpp( 2,10, 1,2),fpp( 2,10, 1,3)/
     x 2.2508984d-01, 1.8339237d-05, 1.1006123d-04 /
      data fpp( 2,10, 2,1),fpp( 2,10, 2,2),fpp( 2,10, 2,3)/
     x 3.9525054d-01, 1.1587196d-04, 1.1425503d-04 /
      data fpp( 2,10, 3,1),fpp( 2,10, 3,2),fpp( 2,10, 3,3)/
     x 1.7041008d-01, 2.5269071d-04, 1.2584063d-04 /
      data fpp( 2,10, 4,1),fpp( 2,10, 4,2),fpp( 2,10, 4,3)/
     x 1.7041008d-01, 2.5269071d-04, 1.2129259d-04 /
      data fpp( 2,10, 5,1),fpp( 2,10, 5,2),fpp( 2,10, 5,3)/
     x 3.9525054d-01, 1.1587196d-04, 1.3244720d-04 /
      data fpp( 2,10, 6,1),fpp( 2,10, 6,2),fpp( 2,10, 6,3)/
     x 2.2508984d-01, 1.8339237d-05, 4.1840601d-05 /
      data fpp( 2,10, 7,1),fpp( 2,10, 7,2),fpp( 2,10, 7,3)/
     x 1.8367495d-01, 1.2387157d-04, 8.1436395d-05 /
      data fpp( 2,10, 8,1),fpp( 2,10, 8,2),fpp( 2,10, 8,3)/
     x-1.5280690d-01,-4.4052002d-04,-3.8061218d-04 /
      data fpp( 2,10, 9,1),fpp( 2,10, 9,2),fpp( 2,10, 9,3)/
     x 1.6048649d+00,-3.1943387d-04,-2.0702567d-04 /
      data fpp( 2,10,10,1),fpp( 2,10,10,2),fpp( 2,10,10,3)/
     x-5.4223559d-02,-4.3608903d-05, 6.8846863d-05 /
      data fpp( 2,10,11,1),fpp( 2,10,11,2),fpp( 2,10,11,3)/
     x 6.2919385d+00,-5.9767079d-05, 9.3202193d-06 /
      data fpp( 2,10,12,1),fpp( 2,10,12,2),fpp( 2,10,12,3)/
     x 6.4795559d+00,-5.5528946d-05, 3.0372260d-05 /
      data fpp( 2,10,13,1),fpp( 2,10,13,2),fpp( 2,10,13,3)/
     x-1.5416413d-02,-4.8837810d-05, 2.4716740d-05 /
      data fpp( 2,10,14,1),fpp( 2,10,14,2),fpp( 2,10,14,3)/
     x 5.8619767d+00,-4.0238683d-05, 2.3694778d-05 /
      data fpp( 2,10,15,1),fpp( 2,10,15,2),fpp( 2,10,15,3)/
     x-1.0608051d-02,-2.9905617d-05, 2.0622147d-05 /
      data fpp( 2,10,16,1),fpp( 2,10,16,2),fpp( 2,10,16,3)/
     x-1.0436450d-02,-1.8364068d-05, 1.7182634d-05 /
      data fpp( 2,10,17,1),fpp( 2,10,17,2),fpp( 2,10,17,3)/
     x-1.1538580d-02,-7.1121480d-06, 1.6853317d-05 /
      data fpp( 2,10,18,1),fpp( 2,10,18,2),fpp( 2,10,18,3)/
     x-1.3146976d-02, 3.1755110d-06, 1.2568098d-05 /
      data fpp( 2,10,19,1),fpp( 2,10,19,2),fpp( 2,10,19,3)/
     x-1.5229549d-02, 1.3314226d-05, 4.2788290d-05 /
      data fpp( 2,10,20,1),fpp( 2,10,20,2),fpp( 2,10,20,3)/
     x 3.1630880d-03,-1.9550348d-04,-7.9927258d-05 /
      data fpp( 2,10,21,1),fpp( 2,10,21,2),fpp( 2,10,21,3)/
     x 3.1630880d-03,-1.9550348d-04,-7.5774372d-05 /
      data fpp( 2,10,22,1),fpp( 2,10,22,2),fpp( 2,10,22,3)/
     x-1.5229549d-02, 1.3314226d-05, 2.6176749d-05 /
      data fpp( 2,10,23,1),fpp( 2,10,23,2),fpp( 2,10,23,3)/
     x-1.3146976d-02, 3.1755110d-06, 7.4861375d-05 /
      data fpp( 2,11, 1,1),fpp( 2,11, 1,2),fpp( 2,11, 1,3)/
     x 1.2114738d-01, 1.9829211d-04, 3.0490375d-04 /
      data fpp( 2,11, 2,1),fpp( 2,11, 2,2),fpp( 2,11, 2,3)/
     x 2.6461713d-01, 4.7686972d-04, 2.0741899d-04 /
      data fpp( 2,11, 3,1),fpp( 2,11, 3,2),fpp( 2,11, 3,3)/
     x 4.6146806d-01, 8.9681377d-04, 4.3582735d-06 /
      data fpp( 2,11, 4,1),fpp( 2,11, 4,2),fpp( 2,11, 4,3)/
     x 4.6146806d-01, 8.9681377d-04,-5.8533171d-06 /
      data fpp( 2,11, 5,1),fpp( 2,11, 5,2),fpp( 2,11, 5,3)/
     x 2.6461713d-01, 4.7686972d-04, 2.4826536d-04 /
      data fpp( 2,11, 6,1),fpp( 2,11, 6,2),fpp( 2,11, 6,3)/
     x 1.2114738d-01, 1.9829211d-04, 1.5172989d-04 /
      data fpp( 2,11, 7,1),fpp( 2,11, 7,2),fpp( 2,11, 7,3)/
     x 3.5672913d-02, 3.7896457d-05, 1.3153067d-05 /
      data fpp( 2,11, 8,1),fpp( 2,11, 8,2),fpp( 2,11, 8,3)/
     x-4.3509750d-02, 1.4077790d-04,-7.6981617d-06 /
      data fpp( 2,11, 9,1),fpp( 2,11, 9,2),fpp( 2,11, 9,3)/
     x-1.9827216d-01,-2.0926098d-04,-3.6541842d-04 /
      data fpp( 2,11,10,1),fpp( 2,11,10,2),fpp( 2,11,10,3)/
     x-5.7210830d-03,-1.8673057d-04,-1.4923616d-04 /
      data fpp( 2,11,11,1),fpp( 2,11,11,2),fpp( 2,11,11,3)/
     x-3.3369903d-02,-5.7154896d-05, 5.4485053d-05 /
      data fpp( 2,11,12,1),fpp( 2,11,12,2),fpp( 2,11,12,3)/
     x-2.4948603d-02,-4.5069326d-05, 1.4515947d-05 /
      data fpp( 2,11,13,1),fpp( 2,11,13,2),fpp( 2,11,13,3)/
     x-1.7042309d-02,-3.7746320d-05, 2.4665159d-05 /
      data fpp( 2,11,14,1),fpp( 2,11,14,2),fpp( 2,11,14,3)/
     x 5.0622434d+00,-2.9461881d-05, 1.9951416d-05 /
      data fpp( 2,11,15,1),fpp( 2,11,15,2),fpp( 2,11,15,3)/
     x-1.2168166d-02,-2.0111130d-05, 1.7041177d-05 /
      data fpp( 2,11,16,1),fpp( 2,11,16,2),fpp( 2,11,16,3)/
     x-1.4999244d-02,-1.0059252d-05, 1.7537875d-05 /
      data fpp( 2,11,17,1),fpp( 2,11,17,2),fpp( 2,11,17,3)/
     x-2.0724871d-02, 1.9284631d-07, 3.1132280d-07 /
      data fpp( 2,11,18,1),fpp( 2,11,18,2),fpp( 2,11,18,3)/
     x-2.9673808d-02, 1.0054392d-05, 6.9092834d-05 /
      data fpp( 2,11,19,1),fpp( 2,11,19,2),fpp( 2,11,19,3)/
     x-6.3992087d-02, 1.5671107d-05,-1.3648666d-04 /
      data fpp( 2,11,20,1),fpp( 2,11,20,2),fpp( 2,11,20,3)/
     x 2.3170020d+00, 1.9882605d-04, 2.5275799d-05 /
      data fpp( 2,11,21,1),fpp( 2,11,21,2),fpp( 2,11,21,3)/
     x 2.3170020d+00, 1.9882605d-04, 1.1933933d-05 /
      data fpp( 2,11,22,1),fpp( 2,11,22,2),fpp( 2,11,22,3)/
     x-6.3992087d-02, 1.5671107d-05,-8.3119195d-05 /
      data fpp( 2,11,23,1),fpp( 2,11,23,2),fpp( 2,11,23,3)/
     x-2.9673808d-02, 1.0054392d-05,-1.3103515d-04 /
      data fpp( 2,12, 1,1),fpp( 2,12, 1,2),fpp( 2,12, 1,3)/
     x 2.8231470d-01, 2.8180632d-04, 9.6506325d-04 /
      data fpp( 2,12, 2,1),fpp( 2,12, 2,2),fpp( 2,12, 2,3)/
     x 7.2607612d-01, 6.3664717d-04, 5.0685550d-04 /
      data fpp( 2,12, 3,1),fpp( 2,12, 3,2),fpp( 2,12, 3,3)/
     x 1.5469821d+00, 1.3421462d-03,-4.5212126d-04 /
      data fpp( 2,12, 4,1),fpp( 2,12, 4,2),fpp( 2,12, 4,3)/
     x 1.5469821d+00, 1.3421462d-03,-4.9219098d-04 /
      data fpp( 2,12, 5,1),fpp( 2,12, 5,2),fpp( 2,12, 5,3)/
     x 7.2607612d-01, 6.3664717d-04, 6.6713440d-04 /
      data fpp( 2,12, 6,1),fpp( 2,12, 6,2),fpp( 2,12, 6,3)/
     x 2.8231470d-01, 2.8180632d-04, 3.6401737d-04 /
      data fpp( 2,12, 7,1),fpp( 2,12, 7,2),fpp( 2,12, 7,3)/
     x 9.8833202d-02, 1.4229260d-04, 1.2334613d-04 /
      data fpp( 2,12, 8,1),fpp( 2,12, 8,2),fpp( 2,12, 8,3)/
     x 1.0146619d-02, 3.6156405d-05,-3.4525879d-05 /
      data fpp( 2,12, 9,1),fpp( 2,12, 9,2),fpp( 2,12, 9,3)/
     x-7.2085715d-02, 7.8541775d-05,-8.1002610d-05 /
      data fpp( 2,12,10,1),fpp( 2,12,10,2),fpp( 2,12,10,3)/
     x-1.0521151d-01,-1.3052880d-04,-3.4525168d-04 /
      data fpp( 2,12,11,1),fpp( 2,12,11,2),fpp( 2,12,11,3)/
     x 2.2981614d-02,-7.4103336d-05,-2.9734672d-05 /
      data fpp( 2,12,12,1),fpp( 2,12,12,2),fpp( 2,12,12,3)/
     x-4.5152467d-03,-3.9845748d-05, 2.2398368d-05 /
      data fpp( 2,12,13,1),fpp( 2,12,13,2),fpp( 2,12,13,3)/
     x-4.7512892d-03,-2.9814911d-05, 1.8219201d-05 /
      data fpp( 2,12,14,1),fpp( 2,12,14,2),fpp( 2,12,14,3)/
     x 4.8224922d+00,-2.4559792d-05, 1.9024830d-05 /
      data fpp( 2,12,15,1),fpp( 2,12,15,2),fpp( 2,12,15,3)/
     x-5.0259716d-03,-1.9447862d-05, 1.4443480d-05 /
      data fpp( 2,12,16,1),fpp( 2,12,16,2),fpp( 2,12,16,3)/
     x-1.1054285d-02,-1.3494926d-05, 1.5997252d-05 /
      data fpp( 2,12,17,1),fpp( 2,12,17,2),fpp( 2,12,17,3)/
     x-2.1934570d-02,-5.0112372d-06,-6.5884862d-06 /
      data fpp( 2,12,18,1),fpp( 2,12,18,2),fpp( 2,12,18,3)/
     x-4.2299600d-02, 6.2869229d-06, 8.9232693d-05 /
      data fpp( 2,12,19,1),fpp( 2,12,19,2),fpp( 2,12,19,3)/
     x-1.5899023d-01, 1.8141345d-05,-1.9643629d-04 /
      data fpp( 2,12,20,1),fpp( 2,12,20,2),fpp( 2,12,20,3)/
     x-7.7530974d-02,-9.0046731d-05, 6.0716450d-05 /
      data fpp( 2,12,21,1),fpp( 2,12,21,2),fpp( 2,12,21,3)/
     x-7.7530974d-02,-9.0046731d-05, 4.1459792d-05 /
      data fpp( 2,12,22,1),fpp( 2,12,22,2),fpp( 2,12,22,3)/
     x-1.5899023d-01, 1.8141345d-05,-1.1940965d-04 /
      data fpp( 2,12,23,1),fpp( 2,12,23,2),fpp( 2,12,23,3)/
     x-4.2299600d-02, 6.2869229d-06,-1.9961717d-04 /
      data fpp( 2,13, 1,1),fpp( 2,13, 1,2),fpp( 2,13, 1,3)/
     x 5.3994851d-01,-9.9033825d-06, 2.0010330d-03 /
      data fpp( 2,13, 2,1),fpp( 2,13, 2,2),fpp( 2,13, 2,3)/
     x 1.5385045d+00,-5.5489641d-04, 9.7615703d-04 /
      data fpp( 2,13, 3,1),fpp( 2,13, 3,2),fpp( 2,13, 3,3)/
     x-2.1217126d+00,-1.8482585d-03,-1.1682411d-03 /
      data fpp( 2,13, 4,1),fpp( 2,13, 4,2),fpp( 2,13, 4,3)/
     x-2.1217126d+00,-1.8482585d-03,-1.2588292d-03 /
      data fpp( 2,13, 5,1),fpp( 2,13, 5,2),fpp( 2,13, 5,3)/
     x 1.5385045d+00,-5.5489641d-04, 1.3385094d-03 /
      data fpp( 2,13, 6,1),fpp( 2,13, 6,2),fpp( 2,13, 6,3)/
     x 5.3994851d-01,-9.9033825d-06, 6.4221158d-04 /
      data fpp( 2,13, 7,1),fpp( 2,13, 7,2),fpp( 2,13, 7,3)/
     x 1.7771246d-01, 1.0465314d-04, 2.6646027d-04 /
      data fpp( 2,13, 8,1),fpp( 2,13, 8,2),fpp( 2,13, 8,3)/
     x 5.2114242d-02, 9.8416476d-05, 1.7049353d-05 /
      data fpp( 2,13, 9,1),fpp( 2,13, 9,2),fpp( 2,13, 9,3)/
     x-1.9746489d-02, 4.0377876d-05,-5.3755677d-05 /
      data fpp( 2,13,10,1),fpp( 2,13,10,2),fpp( 2,13,10,3)/
     x-9.2594572d-02, 2.8481768d-05,-1.7810664d-04 /
      data fpp( 2,13,11,1),fpp( 2,13,11,2),fpp( 2,13,11,3)/
     x 3.8113584d-02,-6.6689759d-05,-2.2367375d-04 /
      data fpp( 2,13,12,1),fpp( 2,13,12,2),fpp( 2,13,12,3)/
     x 3.5695429d-02,-3.4947682d-05, 2.6749641d-05 /
      data fpp( 2,13,13,1),fpp( 2,13,13,2),fpp( 2,13,13,3)/
     x 2.1014455d-02,-2.9498037d-05, 7.6551836d-06 /
      data fpp( 2,13,14,1),fpp( 2,13,14,2),fpp( 2,13,14,3)/
     x 3.7850615d+00,-2.5718952d-05, 1.8289624d-05 /
      data fpp( 2,13,15,1),fpp( 2,13,15,2),fpp( 2,13,15,3)/
     x 1.4572077d-02,-2.5481421d-05, 1.2150320d-05 /
      data fpp( 2,13,16,1),fpp( 2,13,16,2),fpp( 2,13,16,3)/
     x 9.3527577d-03,-2.6609046d-05, 1.5747094d-05 /
      data fpp( 2,13,17,1),fpp( 2,13,17,2),fpp( 2,13,17,3)/
     x 9.8764532d-04,-2.8795897d-05,-9.6906976d-06 /
      data fpp( 2,13,18,1),fpp( 2,13,18,2),fpp( 2,13,18,3)/
     x-1.3396499d-02,-3.5838083d-05, 9.8903696d-05 /
      data fpp( 2,13,19,1),fpp( 2,13,19,2),fpp( 2,13,19,3)/
     x-7.8191838d-02,-6.1854487d-05,-2.3930209d-04 /
      data fpp( 2,13,20,1),fpp( 2,13,20,2),fpp( 2,13,20,3)/
     x 4.5218598d-03, 2.6086487d-04, 8.4394653d-05 /
      data fpp( 2,13,21,1),fpp( 2,13,21,2),fpp( 2,13,21,3)/
     x 4.5218598d-03, 2.6086487d-04, 6.1170084d-05 /
      data fpp( 2,13,22,1),fpp( 2,13,22,2),fpp( 2,13,22,3)/
     x-7.8191838d-02,-6.1854487d-05,-1.4640381d-04 /
      data fpp( 2,13,23,1),fpp( 2,13,23,2),fpp( 2,13,23,3)/
     x-1.3396499d-02,-3.5838083d-05,-2.4946485d-04 /
      data fpp( 2,14, 1,1),fpp( 2,14, 1,2),fpp( 2,14, 1,3)/
     x 6.3314316d-01,-2.2853679d-04, 1.7448410d-03 /
      data fpp( 2,14, 2,1),fpp( 2,14, 2,2),fpp( 2,14, 2,3)/
     x 1.7457159d+00,-9.8789354d-04, 8.1984009d-04 /
      data fpp( 2,14, 3,1),fpp( 2,14, 3,2),fpp( 2,14, 3,3)/
     x-3.2738307d+00,-2.1362800d-03,-1.1215733d-03 /
      data fpp( 2,14, 4,1),fpp( 2,14, 4,2),fpp( 2,14, 4,3)/
     x-3.2738307d+00,-2.1362800d-03,-1.1928531d-03 /
      data fpp( 2,14, 5,1),fpp( 2,14, 5,2),fpp( 2,14, 5,3)/
     x 1.7457159d+00,-9.8789354d-04, 1.1049595d-03 /
      data fpp( 2,14, 6,1),fpp( 2,14, 6,2),fpp( 2,14, 6,3)/
     x 6.3314316d-01,-2.2853679d-04, 6.7564334d-04 /
      data fpp( 2,14, 7,1),fpp( 2,14, 7,2),fpp( 2,14, 7,3)/
     x 2.3275238d-01, 4.6180823d-05, 3.0249119d-04 /
      data fpp( 2,14, 8,1),fpp( 2,14, 8,2),fpp( 2,14, 8,3)/
     x 8.4024997d-02, 9.6143690d-05, 6.7169909d-05 /
      data fpp( 2,14, 9,1),fpp( 2,14, 9,2),fpp( 2,14, 9,3)/
     x 1.5301523d-01, 8.2650721d-05,-3.5748823d-05 /
      data fpp( 2,14,10,1),fpp( 2,14,10,2),fpp( 2,14,10,3)/
     x-4.7584890d-02, 3.7307725d-05,-7.1282618d-05 /
      data fpp( 2,14,11,1),fpp( 2,14,11,2),fpp( 2,14,11,3)/
     x-9.2524081d-02,-1.9821626d-05,-2.4648071d-04 /
      data fpp( 2,14,12,1),fpp( 2,14,12,2),fpp( 2,14,12,3)/
     x 3.2215289d+00,-1.5867523d-05,-4.6536554d-05 /
      data fpp( 2,14,13,1),fpp( 2,14,13,2),fpp( 2,14,13,3)/
     x 4.6398819d-02,-8.2409404d-06, 1.0784924d-05 /
      data fpp( 2,14,14,1),fpp( 2,14,14,2),fpp( 2,14,14,3)/
     x 4.0521762d-02,-1.8784401d-05, 1.0788857d-05 /
      data fpp( 2,14,15,1),fpp( 2,14,15,2),fpp( 2,14,15,3)/
     x 3.8522457d-02,-2.6544455d-05, 1.1699649d-05 /
      data fpp( 2,14,16,1),fpp( 2,14,16,2),fpp( 2,14,16,3)/
     x 3.7869941d-02,-3.5882891d-05, 8.6945459d-06 /
      data fpp( 2,14,17,1),fpp( 2,14,17,2),fpp( 2,14,17,3)/
     x 3.9603795d-02,-4.7547173d-05, 8.5421670d-06 /
      data fpp( 2,14,18,1),fpp( 2,14,18,2),fpp( 2,14,18,3)/
     x 4.8985091d-02,-6.1342591d-05, 1.1298786d-05 /
      data fpp( 2,14,19,1),fpp( 2,14,19,2),fpp( 2,14,19,3)/
     x 7.6288222d-02,-6.9271396d-05, 1.6126689d-05 /
      data fpp( 2,14,20,1),fpp( 2,14,20,2),fpp( 2,14,20,3)/
     x 1.3804449d-01,-4.0636276d-04,-4.2091540d-05 /
      data fpp( 2,14,21,1),fpp( 2,14,21,2),fpp( 2,14,21,3)/
     x 1.3804449d-01,-4.0636276d-04,-4.0572723d-05 /
      data fpp( 2,14,22,1),fpp( 2,14,22,2),fpp( 2,14,22,3)/
     x 7.6288222d-02,-6.9271396d-05, 1.0051421d-05 /
      data fpp( 2,14,23,1),fpp( 2,14,23,2),fpp( 2,14,23,3)/
     x 4.8985091d-02,-6.1342591d-05, 3.4081040d-05 /
      data fpp( 2,15, 1,1),fpp( 2,15, 1,2),fpp( 2,15, 1,3)/
     x 4.7151472d-01, 1.1795053d-04, 5.8330825d-04 /
      data fpp( 2,15, 2,1),fpp( 2,15, 2,2),fpp( 2,15, 2,3)/
     x 9.7447854d-01, 4.2600858d-04, 2.6803849d-04 /
      data fpp( 2,15, 3,1),fpp( 2,15, 3,2),fpp( 2,15, 3,3)/
     x 1.7168545d+00, 1.2271666d-03,-3.9901422d-04 /
      data fpp( 2,15, 4,1),fpp( 2,15, 4,2),fpp( 2,15, 4,3)/
     x 1.7168545d+00, 1.2271666d-03,-4.1393358d-04 /
      data fpp( 2,15, 5,1),fpp( 2,15, 5,2),fpp( 2,15, 5,3)/
     x 9.7447854d-01, 4.2600858d-04, 3.2771595d-04 /
      data fpp( 2,15, 6,1),fpp( 2,15, 6,2),fpp( 2,15, 6,3)/
     x 4.7151472d-01, 1.1795053d-04, 3.5951780d-04 /
      data fpp( 2,15, 7,1),fpp( 2,15, 7,2),fpp( 2,15, 7,3)/
     x 2.1433748d-01, 9.1113564d-05, 1.9267286d-04 /
      data fpp( 2,15, 8,1),fpp( 2,15, 8,2),fpp( 2,15, 8,3)/
     x 9.4457135d-02, 1.0316676d-04, 6.9322743d-05 /
      data fpp( 2,15, 9,1),fpp( 2,15, 9,2),fpp( 2,15, 9,3)/
     x 1.5558077d-01, 8.8679241d-05,-1.2187838d-05 /
      data fpp( 2,15,10,1),fpp( 2,15,10,2),fpp( 2,15,10,3)/
     x-1.5910361d-02, 6.0373333d-05,-3.3783393d-05 /
      data fpp( 2,15,11,1),fpp( 2,15,11,2),fpp( 2,15,11,3)/
     x-8.9601360d-02, 1.2554264d-05,-1.4747659d-04 /
      data fpp( 2,15,12,1),fpp( 2,15,12,2),fpp( 2,15,12,3)/
     x 1.2045168d+00,-1.8690224d-05,-1.4992025d-04 /
      data fpp( 2,15,13,1),fpp( 2,15,13,2),fpp( 2,15,13,3)/
     x 5.6335646d-02,-3.6634201d-05, 1.4191572d-05 /
      data fpp( 2,15,14,1),fpp( 2,15,14,2),fpp( 2,15,14,3)/
     x 5.3907522d-02,-1.1007445d-05, 1.4979585d-06 /
      data fpp( 2,15,15,1),fpp( 2,15,15,2),fpp( 2,15,15,3)/
     x 5.2544758d-02,-2.4587593d-06, 8.6465943d-06 /
      data fpp( 2,15,16,1),fpp( 2,15,16,2),fpp( 2,15,16,3)/
     x 5.3402234d-02, 5.2966088d-06, 5.3696643d-06 /
      data fpp( 2,15,17,1),fpp( 2,15,17,2),fpp( 2,15,17,3)/
     x 5.6654896d-02, 1.2722591d-05, 3.7747487d-06 /
      data fpp( 2,15,18,1),fpp( 2,15,18,2),fpp( 2,15,18,3)/
     x 6.4249055d-02, 2.3004446d-05, 1.4433411d-06 /
      data fpp( 2,15,19,1),fpp( 2,15,19,2),fpp( 2,15,19,3)/
     x 7.7727467d-02, 4.2672073d-05,-2.5641130d-06 /
      data fpp( 2,15,20,1),fpp( 2,15,20,2),fpp( 2,15,20,3)/
     x 9.3743779d-02, 1.6522217d-04,-1.4880889d-05 /
      data fpp( 2,15,21,1),fpp( 2,15,21,2),fpp( 2,15,21,3)/
     x 9.3743779d-02, 1.6522217d-04,-1.4798276d-05 /
      data fpp( 2,15,22,1),fpp( 2,15,22,2),fpp( 2,15,22,3)/
     x 7.7727467d-02, 4.2672073d-05,-2.8945639d-06 /
      data fpp( 2,15,23,1),fpp( 2,15,23,2),fpp( 2,15,23,3)/
     x 6.4249055d-02, 2.3004446d-05, 2.6825320d-06 /
      data fpp( 2,16, 1,1),fpp( 2,16, 1,2),fpp( 2,16, 1,3)/
     x 2.4350097d-01, 3.2897265d-04, 9.1340538d-05 /
      data fpp( 2,16, 2,1),fpp( 2,16, 2,2),fpp( 2,16, 2,3)/
     x 3.4558637d-01, 6.3298923d-04, 5.7000425d-05 /
      data fpp( 2,16, 3,1),fpp( 2,16, 3,2),fpp( 2,16, 3,3)/
     x 7.5950904d-01, 1.0449935d-03,-1.7716237d-05 /
      data fpp( 2,16, 4,1),fpp( 2,16, 4,2),fpp( 2,16, 4,3)/
     x 7.5950904d-01, 1.0449935d-03,-1.5737502d-05 /
      data fpp( 2,16, 5,1),fpp( 2,16, 5,2),fpp( 2,16, 5,3)/
     x 3.4558637d-01, 6.3298923d-04, 4.9085483d-05 /
      data fpp( 2,16, 6,1),fpp( 2,16, 6,2),fpp( 2,16, 6,3)/
     x 2.4350097d-01, 3.2897265d-04, 1.2102157d-04 /
      data fpp( 2,16, 7,1),fpp( 2,16, 7,2),fpp( 2,16, 7,3)/
     x 1.4426736d-01, 1.8858492d-04, 7.7598239d-05 /
      data fpp( 2,16, 8,1),fpp( 2,16, 8,2),fpp( 2,16, 8,3)/
     x 8.0043936d-02, 1.4173326d-04, 3.9213474d-05 /
      data fpp( 2,16, 9,1),fpp( 2,16, 9,2),fpp( 2,16, 9,3)/
     x 3.7373400d-02, 1.2191632d-04, 3.0938666d-06 /
      data fpp( 2,16,10,1),fpp( 2,16,10,2),fpp( 2,16,10,3)/
     x 3.1510486d-03, 9.7626942d-05,-2.2500940d-05 /
      data fpp( 2,16,11,1),fpp( 2,16,11,2),fpp( 2,16,11,3)/
     x-4.5251340d-02, 6.2070568d-05,-3.6432106d-05 /
      data fpp( 2,16,12,1),fpp( 2,16,12,2),fpp( 2,16,12,3)/
     x-9.0813062d-02,-6.9495790d-06,-1.8133063d-04 /
      data fpp( 2,16,13,1),fpp( 2,16,13,2),fpp( 2,16,13,3)/
     x 4.8285295d-02, 1.2570774d-04,-2.3783355d-05 /
      data fpp( 2,16,14,1),fpp( 2,16,14,2),fpp( 2,16,14,3)/
     x 5.8295528d-02, 1.8942181d-05, 2.4500548d-06 /
      data fpp( 2,16,15,1),fpp( 2,16,15,2),fpp( 2,16,15,3)/
     x 5.8283738d-02,-2.5276508d-05, 3.0211359d-06 /
      data fpp( 2,16,16,1),fpp( 2,16,16,2),fpp( 2,16,16,3)/
     x 5.8368039d-02,-6.3789545d-05, 3.0454017d-06 /
      data fpp( 2,16,17,1),fpp( 2,16,17,2),fpp( 2,16,17,3)/
     x 5.9362975d-02,-9.5029189d-05, 1.2072574d-06 /
      data fpp( 2,16,18,1),fpp( 2,16,18,2),fpp( 2,16,18,3)/
     x 6.1399135d-02,-1.1807719d-04,-7.2843111d-07 /
      data fpp( 2,16,19,1),fpp( 2,16,19,2),fpp( 2,16,19,3)/
     x 6.4271008d-02,-1.3317490d-04,-2.8295329d-06 /
      data fpp( 2,16,20,1),fpp( 2,16,20,2),fpp( 2,16,20,3)/
     x 6.7014790d-02,-1.6681792d-04,-5.2334372d-06 /
      data fpp( 2,16,21,1),fpp( 2,16,21,2),fpp( 2,16,21,3)/
     x 6.7014790d-02,-1.6681792d-04,-5.2799220d-06 /
      data fpp( 2,16,22,1),fpp( 2,16,22,2),fpp( 2,16,22,3)/
     x 6.4271008d-02,-1.3317490d-04,-2.6435937d-06 /
      data fpp( 2,16,23,1),fpp( 2,16,23,2),fpp( 2,16,23,3)/
     x 6.1399135d-02,-1.1807719d-04,-1.4257031d-06 /
      data fpp( 2,17, 1,1),fpp( 2,17, 1,2),fpp( 2,17, 1,3)/
     x 1.0598406d-01, 1.0509286d-04, 4.0321341d-05 /
      data fpp( 2,17, 2,1),fpp( 2,17, 2,2),fpp( 2,17, 2,3)/
     x 1.3341354d-01, 1.7380052d-04, 3.8548817d-05 /
      data fpp( 2,17, 3,1),fpp( 2,17, 3,2),fpp( 2,17, 3,3)/
     x 1.5476326d-01, 2.0001520d-04, 3.4845390d-05 /
      data fpp( 2,17, 4,1),fpp( 2,17, 4,2),fpp( 2,17, 4,3)/
     x 1.5476326d-01, 2.0001520d-04, 3.4679422d-05 /
      data fpp( 2,17, 5,1),fpp( 2,17, 5,2),fpp( 2,17, 5,3)/
     x 1.3341354d-01, 1.7380052d-04, 3.9212688d-05 /
      data fpp( 2,17, 6,1),fpp( 2,17, 6,2),fpp( 2,17, 6,3)/
     x 1.0598406d-01, 1.0509286d-04, 3.7831825d-05 /
      data fpp( 2,17, 7,1),fpp( 2,17, 7,2),fpp( 2,17, 7,3)/
     x 7.8191082d-02, 5.8392752d-05, 3.0284012d-05 /
      data fpp( 2,17, 8,1),fpp( 2,17, 8,2),fpp( 2,17, 8,3)/
     x 5.3262768d-02, 3.4612199d-05, 1.8710125d-05 /
      data fpp( 2,17, 9,1),fpp( 2,17, 9,2),fpp( 2,17, 9,3)/
     x 3.1159757d-02, 2.2335492d-05, 5.2934858d-06 /
      data fpp( 2,17,10,1),fpp( 2,17,10,2),fpp( 2,17,10,3)/
     x 1.1092611d-02, 8.8749004d-06,-1.3880687d-06 /
      data fpp( 2,17,11,1),fpp( 2,17,11,2),fpp( 2,17,11,3)/
     x-1.0021293d-02,-1.4308538d-05,-2.5931211d-05 /
      data fpp( 2,17,12,1),fpp( 2,17,12,2),fpp( 2,17,12,3)/
     x-7.9077557d-02,-7.5551459d-05, 2.4262913d-05 /
      data fpp( 2,17,13,1),fpp( 2,17,13,2),fpp( 2,17,13,3)/
     x-7.5607116d-01,-2.9982278d-04,-2.5224844d-04 /
      data fpp( 2,17,14,1),fpp( 2,17,14,2),fpp( 2,17,14,3)/
     x 5.5258944d-02,-4.5483280d-05, 9.2848856d-05 /
      data fpp( 2,17,15,1),fpp( 2,17,15,2),fpp( 2,17,15,3)/
     x 6.0338484d-02, 1.2037079d-04,-2.5276980d-05 /
      data fpp( 2,17,16,1),fpp( 2,17,16,2),fpp( 2,17,16,3)/
     x 6.1012407d-02, 2.7036957d-04, 8.1390651d-06 /
      data fpp( 2,17,17,1),fpp( 2,17,17,2),fpp( 2,17,17,3)/
     x 6.1156567d-02, 3.9881017d-04,-1.1532804d-06 /
      data fpp( 2,17,18,1),fpp( 2,17,18,2),fpp( 2,17,18,3)/
     x 6.1336315d-02, 5.0318432d-04, 4.1005648d-07 /
      data fpp( 2,17,19,1),fpp( 2,17,19,2),fpp( 2,17,19,3)/
     x 6.1621193d-02, 5.8200151d-04,-9.1294551d-07 /
      data fpp( 2,17,20,1),fpp( 2,17,20,2),fpp( 2,17,20,3)/
     x 6.1684529d-02, 6.3831552d-04,-1.4262744d-06 /
      data fpp( 2,17,21,1),fpp( 2,17,21,2),fpp( 2,17,21,3)/
     x 6.1684529d-02, 6.3831552d-04,-1.4777039d-06 /
      data fpp( 2,17,22,1),fpp( 2,17,22,2),fpp( 2,17,22,3)/
     x 6.1621193d-02, 5.8200151d-04,-7.0722744d-07 /
      data fpp( 2,17,23,1),fpp( 2,17,23,2),fpp( 2,17,23,3)/
     x 6.1336315d-02, 5.0318432d-04,-3.6138628d-07 /
      data fpp( 2,18, 1,1),fpp( 2,18, 1,2),fpp( 2,18, 1,3)/
     x 3.9486681d-02, 3.1509190d-04, 1.6862114d-05 /
      data fpp( 2,18, 2,1),fpp( 2,18, 2,2),fpp( 2,18, 2,3)/
     x 4.4756484d-02, 3.2639871d-04, 1.7719271d-05 /
      data fpp( 2,18, 3,1),fpp( 2,18, 3,2),fpp( 2,18, 3,3)/
     x 4.8155622d-02, 3.4992566d-04, 1.9594801d-05 /
      data fpp( 2,18, 4,1),fpp( 2,18, 4,2),fpp( 2,18, 4,3)/
     x 4.8155622d-02, 3.4992566d-04, 1.9526961d-05 /
      data fpp( 2,18, 5,1),fpp( 2,18, 5,2),fpp( 2,18, 5,3)/
     x 4.4756484d-02, 3.2639871d-04, 1.7990632d-05 /
      data fpp( 2,18, 6,1),fpp( 2,18, 6,2),fpp( 2,18, 6,3)/
     x 3.9486681d-02, 3.1509190d-04, 1.5844509d-05 /
      data fpp( 2,18, 7,1),fpp( 2,18, 7,2),fpp( 2,18, 7,3)/
     x 3.3226545d-02, 3.1544207d-04, 1.2825330d-05 /
      data fpp( 2,18, 8,1),fpp( 2,18, 8,2),fpp( 2,18, 8,3)/
     x 2.5642027d-02, 3.2245794d-04, 9.4621690d-06 /
      data fpp( 2,18, 9,1),fpp( 2,18, 9,2),fpp( 2,18, 9,3)/
     x 1.6451467d-02, 3.2932972d-04, 5.5219936d-06 /
      data fpp( 2,18,10,1),fpp( 2,18,10,2),fpp( 2,18,10,3)/
     x 9.2836343d-03, 3.3108146d-04, 2.0258565d-06 /
      data fpp( 2,18,11,1),fpp( 2,18,11,2),fpp( 2,18,11,3)/
     x-4.9943214d-03, 3.2434758d-04,-1.3074198d-06 /
      data fpp( 2,18,12,1),fpp( 2,18,12,2),fpp( 2,18,12,3)/
     x-6.5563212d-03, 3.0815342d-04,-4.0981774d-06 /
      data fpp( 2,18,13,1),fpp( 2,18,13,2),fpp( 2,18,13,3)/
     x-9.9273509d-03, 2.9506536d-04,-6.3478706d-06 /
      data fpp( 2,18,14,1),fpp( 2,18,14,2),fpp( 2,18,14,3)/
     x 2.2071305d-01, 7.9194937d-05,-8.0223401d-06 /
      data fpp( 2,18,15,1),fpp( 2,18,15,2),fpp( 2,18,15,3)/
     x 4.2764937d-01,-9.1604654d-05,-9.1847688d-06 /
      data fpp( 2,18,16,1),fpp( 2,18,16,2),fpp( 2,18,16,3)/
     x 6.0524067d-01,-2.4145073d-04,-9.8205845d-06 /
      data fpp( 2,18,17,1),fpp( 2,18,17,2),fpp( 2,18,17,3)/
     x 7.5531997d-01,-3.6708748d-04,-1.0440893d-05 /
      data fpp( 2,18,18,1),fpp( 2,18,18,2),fpp( 2,18,18,3)/
     x 8.8220396d-01,-4.6748209d-04,-1.0521844d-05 /
      data fpp( 2,18,19,1),fpp( 2,18,19,2),fpp( 2,18,19,3)/
     x 9.8615753d-01,-5.4225715d-04,-1.2445733d-05 /
      data fpp( 2,18,20,1),fpp( 2,18,20,2),fpp( 2,18,20,3)/
     x 1.0544250d+00,-5.9057215d-04,-1.3849225d-05 /
      data fpp( 2,18,21,1),fpp( 2,18,21,2),fpp( 2,18,21,3)/
     x 1.0544250d+00,-5.9057215d-04,-1.3909459d-05 /
      data fpp( 2,18,22,1),fpp( 2,18,22,2),fpp( 2,18,22,3)/
     x 9.8615753d-01,-5.4225715d-04,-1.2204797d-05 /
      data fpp( 2,18,23,1),fpp( 2,18,23,2),fpp( 2,18,23,3)/
     x 8.8220396d-01,-4.6748209d-04,-1.1425351d-05 /
      data fpp( 2,19, 1,1),fpp( 2,19, 1,2),fpp( 2,19, 1,3)/
     x-2.5679695d+00, 4.0112555d-04,-3.7186113d-20 /
      data fpp( 2,19, 2,1),fpp( 2,19, 2,2),fpp( 2,19, 2,3)/
     x-2.5679695d+00, 3.0420065d-04, 9.9235026d-21 /
      data fpp( 2,19, 3,1),fpp( 2,19, 3,2),fpp( 2,19, 3,3)/
     x-2.5679695d+00, 2.1558217d-04, 1.5404510d-21 /
      data fpp( 2,19, 4,1),fpp( 2,19, 4,2),fpp( 2,19, 4,3)/
     x-2.5679695d+00, 2.1558217d-04, 1.9413166d-20 /
      data fpp( 2,19, 5,1),fpp( 2,19, 5,2),fpp( 2,19, 5,3)/
     x-2.5679695d+00, 3.0420065d-04,-2.1921418d-20 /
      data fpp( 2,19, 6,1),fpp( 2,19, 6,2),fpp( 2,19, 6,3)/
     x-2.5679695d+00, 4.0112555d-04,-9.5713629d-20 /
      data fpp( 2,19, 7,1),fpp( 2,19, 7,2),fpp( 2,19, 7,3)/
     x-2.5679695d+00, 4.6185096d-04,-2.0187867d-19 /
      data fpp( 2,19, 8,1),fpp( 2,19, 8,2),fpp( 2,19, 8,3)/
     x-2.5679695d+00, 4.9745603d-04,-3.3634145d-21 /
      data fpp( 2,19, 9,1),fpp( 2,19, 9,2),fpp( 2,19, 9,3)/
     x-2.5679695d+00, 5.2015964d-04, 7.6377420d-20 /
      data fpp( 2,19,10,1),fpp( 2,19,10,2),fpp( 2,19,10,3)/
     x-2.5679695d+00, 5.3587127d-04, 1.3237311d-19 /
      data fpp( 2,19,11,1),fpp( 2,19,11,2),fpp( 2,19,11,3)/
     x-2.5679695d+00, 5.4442221d-04,-7.3135742d-20 /
      data fpp( 2,19,12,1),fpp( 2,19,12,2),fpp( 2,19,12,3)/
     x-2.5679695d+00, 5.6262779d-04, 1.0207311d-19 /
      data fpp( 2,19,13,1),fpp( 2,19,13,2),fpp( 2,19,13,3)/
     x-2.5679695d+00, 5.9840532d-04, 9.9827824d-21 /
      data fpp( 2,19,14,1),fpp( 2,19,14,2),fpp( 2,19,14,3)/
     x-2.5679695d+00, 1.4984353d-04,-5.7546162d-20 /
      data fpp( 2,19,15,1),fpp( 2,19,15,2),fpp( 2,19,15,3)/
     x-2.5679695d+00,-2.0140217d-04, 4.9859554d-20 /
      data fpp( 2,19,16,1),fpp( 2,19,16,2),fpp( 2,19,16,3)/
     x-2.5679695d+00,-5.1156263d-04,-1.0428348d-19 /
      data fpp( 2,19,17,1),fpp( 2,19,17,2),fpp( 2,19,17,3)/
     x-2.5679695d+00,-7.7306026d-04, 1.0044506d-19 /
      data fpp( 2,19,18,1),fpp( 2,19,18,2),fpp( 2,19,18,3)/
     x-2.5679695d+00,-9.8331195d-04,-1.2313461d-19 /
      data fpp( 2,19,19,1),fpp( 2,19,19,2),fpp( 2,19,19,3)/
     x-2.5679695d+00,-1.1409629d-03,-1.0729805d-19 /
      data fpp( 2,19,20,1),fpp( 2,19,20,2),fpp( 2,19,20,3)/
     x-2.5679695d+00,-1.2383109d-03, 1.5305125d-19 /
      data fpp( 2,19,21,1),fpp( 2,19,21,2),fpp( 2,19,21,3)/
     x-2.5679695d+00,-1.2383109d-03,-1.2484852d-19 /
      data fpp( 2,19,22,1),fpp( 2,19,22,2),fpp( 2,19,22,3)/
     x-2.5679695d+00,-1.1409629d-03, 1.2052263d-19 /
      data fpp( 2,19,23,1),fpp( 2,19,23,2),fpp( 2,19,23,3)/
     x-2.5679695d+00,-9.8331195d-04, 3.0582037d-19 /
      data fpp( 3, 1, 1,1),fpp( 3, 1, 1,2),fpp( 3, 1, 1,3)/
     x 1.4319098d+00, 6.0690505d-04, 7.1043001d-19 /
      data fpp( 3, 1, 2,1),fpp( 3, 1, 2,2),fpp( 3, 1, 2,3)/
     x 1.4319098d+00, 1.2814502d-04, 7.4351313d-20 /
      data fpp( 3, 1, 3,1),fpp( 3, 1, 3,2),fpp( 3, 1, 3,3)/
     x 1.4319098d+00, 3.8618190d-04,-2.8633706d-19 /
      data fpp( 3, 1, 4,1),fpp( 3, 1, 4,2),fpp( 3, 1, 4,3)/
     x 1.4319098d+00, 3.8618190d-04, 5.6760706d-19 /
      data fpp( 3, 1, 5,1),fpp( 3, 1, 5,2),fpp( 3, 1, 5,3)/
     x 1.4319098d+00, 1.2814502d-04, 8.0055439d-19 /
      data fpp( 3, 1, 6,1),fpp( 3, 1, 6,2),fpp( 3, 1, 6,3)/
     x 1.4319098d+00, 6.0690505d-04,-8.4712198d-19 /
      data fpp( 3, 1, 7,1),fpp( 3, 1, 7,2),fpp( 3, 1, 7,3)/
     x 1.4319098d+00, 9.1868960d-04,-1.9061896d-18 /
      data fpp( 3, 1, 8,1),fpp( 3, 1, 8,2),fpp( 3, 1, 8,3)/
     x 1.4319098d+00, 1.1591103d-03,-1.2743398d-18 /
      data fpp( 3, 1, 9,1),fpp( 3, 1, 9,2),fpp( 3, 1, 9,3)/
     x 1.4319098d+00, 7.2759793d-04,-6.3329259d-20 /
      data fpp( 3, 1,10,1),fpp( 3, 1,10,2),fpp( 3, 1,10,3)/
     x 1.4319098d+00, 1.8749076d-04, 1.4935602d-18 /
      data fpp( 3, 1,11,1),fpp( 3, 1,11,2),fpp( 3, 1,11,3)/
     x 1.4319098d+00,-9.5808601d-05,-7.5064519d-19 /
      data fpp( 3, 1,12,1),fpp( 3, 1,12,2),fpp( 3, 1,12,3)/
     x 1.4319098d+00,-1.8943992d-04, 8.8225857d-19 /
      data fpp( 3, 1,13,1),fpp( 3, 1,13,2),fpp( 3, 1,13,3)/
     x 1.4319098d+00,-8.8742587d-05, 2.0359772d-19 /
      data fpp( 3, 1,14,1),fpp( 3, 1,14,2),fpp( 3, 1,14,3)/
     x 1.4319098d+00, 2.1506078d-04, 1.9603992d-19 /
      data fpp( 3, 1,15,1),fpp( 3, 1,15,2),fpp( 3, 1,15,3)/
     x 1.4319098d+00, 7.5274726d-04, 1.5528689d-19 /
      data fpp( 3, 1,16,1),fpp( 3, 1,16,2),fpp( 3, 1,16,3)/
     x 1.4319098d+00, 1.1618403d-03,-8.8680981d-19 /
      data fpp( 3, 1,17,1),fpp( 3, 1,17,2),fpp( 3, 1,17,3)/
     x 1.4319098d+00, 9.1314076d-04, 7.0620895d-19 /
      data fpp( 3, 1,18,1),fpp( 3, 1,18,2),fpp( 3, 1,18,3)/
     x 1.4319098d+00, 5.8643727d-04,-8.7266387d-19 /
      data fpp( 3, 1,19,1),fpp( 3, 1,19,2),fpp( 3, 1,19,3)/
     x 1.4319098d+00, 1.2032093d-04,-2.1536200d-19 /
      data fpp( 3, 1,20,1),fpp( 3, 1,20,2),fpp( 3, 1,20,3)/
     x 1.4319098d+00, 3.7711650d-04, 7.6882500d-19 /
      data fpp( 3, 1,21,1),fpp( 3, 1,21,2),fpp( 3, 1,21,3)/
     x 1.4319098d+00, 3.7711650d-04,-6.1860394d-20 /
      data fpp( 3, 1,22,1),fpp( 3, 1,22,2),fpp( 3, 1,22,3)/
     x 1.4319098d+00, 1.2032093d-04, 8.4105009d-19 /
      data fpp( 3, 1,23,1),fpp( 3, 1,23,2),fpp( 3, 1,23,3)/
     x 1.4319098d+00, 5.8643727d-04, 2.0702698d-18 /
      data fpp( 3, 2, 1,1),fpp( 3, 2, 1,2),fpp( 3, 2, 1,3)/
     x 5.7897891d-01, 1.7156590d-04,-2.0395509d-06 /
      data fpp( 3, 2, 2,1),fpp( 3, 2, 2,2),fpp( 3, 2, 2,3)/
     x 6.2385984d-01,-1.2375004d-04,-4.5423983d-06 /
      data fpp( 3, 2, 3,1),fpp( 3, 2, 3,2),fpp( 3, 2, 3,3)/
     x 5.8647034d-01, 3.6978195d-05,-1.0144856d-05 /
      data fpp( 3, 2, 4,1),fpp( 3, 2, 4,2),fpp( 3, 2, 4,3)/
     x 5.8647034d-01, 3.6978195d-05,-9.7262327d-06 /
      data fpp( 3, 2, 5,1),fpp( 3, 2, 5,2),fpp( 3, 2, 5,3)/
     x 6.2385984d-01,-1.2375004d-04,-6.2168919d-06 /
      data fpp( 3, 2, 6,1),fpp( 3, 2, 6,2),fpp( 3, 2, 6,3)/
     x 5.7897891d-01, 1.7156590d-04, 4.2398004d-06 /
      data fpp( 3, 2, 7,1),fpp( 3, 2, 7,2),fpp( 3, 2, 7,3)/
     x 5.3783778d-01, 3.4974180d-04,-3.2483096d-06 /
      data fpp( 3, 2, 8,1),fpp( 3, 2, 8,2),fpp( 3, 2, 8,3)/
     x 5.9189196d-01, 4.6746934d-04, 2.8974379d-06 /
      data fpp( 3, 2, 9,1),fpp( 3, 2, 9,2),fpp( 3, 2, 9,3)/
     x 5.8442866d-01, 2.8580114d-04, 1.0924558d-05 /
      data fpp( 3, 2,10,1),fpp( 3, 2,10,2),fpp( 3, 2,10,3)/
     x 5.2435103d-01, 5.3188479d-05,-6.5036702d-06 /
      data fpp( 3, 2,11,1),fpp( 3, 2,11,2),fpp( 3, 2,11,3)/
     x 5.7210223d-01,-6.8665797d-05, 1.1856123d-05 /
      data fpp( 3, 2,12,1),fpp( 3, 2,12,2),fpp( 3, 2,12,3)/
     x 5.7087357d-01,-1.0974615d-04, 2.9991799d-06 /
      data fpp( 3, 2,13,1),fpp( 3, 2,13,2),fpp( 3, 2,13,3)/
     x 5.7136152d-01,-6.7198826d-05, 5.2771577d-06 /
      data fpp( 3, 2,14,1),fpp( 3, 2,14,2),fpp( 3, 2,14,3)/
     x 6.4938827d-01, 6.2646430d-05, 4.6621894d-06 /
      data fpp( 3, 2,15,1),fpp( 3, 2,15,2),fpp( 3, 2,15,3)/
     x 5.8528581d-01, 2.9239049d-04, 3.7940848d-06 /
      data fpp( 3, 2,16,1),fpp( 3, 2,16,2),fpp( 3, 2,16,3)/
     x 5.8948710d-01, 4.6245141d-04, 4.8274716d-06 /
      data fpp( 3, 2,17,1),fpp( 3, 2,17,2),fpp( 3, 2,17,3)/
     x 6.0548710d-01, 3.4373647d-04,-3.6519710d-06 /
      data fpp( 3, 2,18,1),fpp( 3, 2,18,2),fpp( 3, 2,18,3)/
     x 6.3307278d-01, 1.6815645d-04, 4.3024124d-06 /
      data fpp( 3, 2,19,1),fpp( 3, 2,19,2),fpp( 3, 2,19,3)/
     x 5.7936042d-01,-1.2077787d-04,-6.3696788d-06 /
      data fpp( 3, 2,20,1),fpp( 3, 2,20,2),fpp( 3, 2,20,3)/
     x 5.8118153d-01, 4.1379997d-05,-9.9456974d-06 /
      data fpp( 3, 2,21,1),fpp( 3, 2,21,2),fpp( 3, 2,21,3)/
     x 5.8118153d-01, 4.1379997d-05,-1.0373068d-05 /
      data fpp( 3, 2,22,1),fpp( 3, 2,22,2),fpp( 3, 2,22,3)/
     x 5.7936042d-01,-1.2077787d-04,-4.6601947d-06 /
      data fpp( 3, 2,23,1),fpp( 3, 2,23,2),fpp( 3, 2,23,3)/
     x 6.3307278d-01, 1.6815645d-04,-2.1081526d-06 /
      data fpp( 3, 3, 1,1),fpp( 3, 3, 1,2),fpp( 3, 3, 1,3)/
     x 1.0599126d-01,-1.0380847d-03, 9.7234299d-05 /
      data fpp( 3, 3, 2,1),fpp( 3, 3, 2,2),fpp( 3, 3, 2,3)/
     x 1.6271695d-01, 1.0401392d-03, 3.3449402d-05 /
      data fpp( 3, 3, 3,1),fpp( 3, 3, 3,2),fpp( 3, 3, 3,3)/
     x 3.3631105d-01, 7.4880132d-04,-1.0032791d-04 /
      data fpp( 3, 3, 4,1),fpp( 3, 3, 4,2),fpp( 3, 3, 4,3)/
     x 3.3631105d-01, 7.4880132d-04,-1.0541098d-04 /
      data fpp( 3, 3, 5,1),fpp( 3, 3, 5,2),fpp( 3, 3, 5,3)/
     x 1.6271695d-01, 1.0401392d-03, 5.3781673d-05 /
      data fpp( 3, 3, 6,1),fpp( 3, 3, 6,2),fpp( 3, 3, 6,3)/
     x 1.0599126d-01,-1.0380847d-03, 2.0988285d-05 /
      data fpp( 3, 3, 7,1),fpp( 3, 3, 7,2),fpp( 3, 3, 7,3)/
     x 8.8483913d-01,-2.2642028d-03, 9.3823186d-05 /
      data fpp( 3, 3, 8,1),fpp( 3, 3, 8,2),fpp( 3, 3, 8,3)/
     x-4.9785436d+00,-3.0272837d-03,-2.5811303d-04 /
      data fpp( 3, 3, 9,1),fpp( 3, 3, 9,2),fpp( 3, 3, 9,3)/
     x-4.1515098d+00,-2.8611565d-03, 3.6852931d-05 /
      data fpp( 3, 3,10,1),fpp( 3, 3,10,2),fpp( 3, 3,10,3)/
     x-7.1935934d-01,-2.4724167d-03, 1.0112530d-04 /
      data fpp( 3, 3,11,1),fpp( 3, 3,11,2),fpp( 3, 3,11,3)/
     x 1.2641347d+00,-2.2655382d-03, 7.0157851d-05 /
      data fpp( 3, 3,12,1),fpp( 3, 3,12,2),fpp( 3, 3,12,3)/
     x 1.9564593d+00,-2.2007315d-03, 7.6775291d-05 /
      data fpp( 3, 3,13,1),fpp( 3, 3,13,2),fpp( 3, 3,13,3)/
     x 1.2429827d+00,-2.2759341d-03, 6.9830985d-05 /
      data fpp( 3, 3,14,1),fpp( 3, 3,14,2),fpp( 3, 3,14,3)/
     x-7.6789436d-01,-2.4978465d-03, 1.0702877d-04 /
      data fpp( 3, 3,15,1),fpp( 3, 3,15,2),fpp( 3, 3,15,3)/
     x-4.2513047d+00,-2.8905472d-03, 2.0183942d-05 /
      data fpp( 3, 3,16,1),fpp( 3, 3,16,2),fpp( 3, 3,16,3)/
     x-4.7713186d+00,-3.0221819d-03,-2.4469254d-04 /
      data fpp( 3, 3,17,1),fpp( 3, 3,17,2),fpp( 3, 3,17,3)/
     x 7.7485584d-01,-2.2481027d-03, 9.0308210d-05 /
      data fpp( 3, 3,18,1),fpp( 3, 3,18,2),fpp( 3, 3,18,3)/
     x 1.0667725d-01,-1.0190091d-03, 2.2053700d-05 /
      data fpp( 3, 3,19,1),fpp( 3, 3,19,2),fpp( 3, 3,19,3)/
     x 1.6342956d-01, 1.0202945d-03, 5.3232992d-05 /
      data fpp( 3, 3,20,1),fpp( 3, 3,20,2),fpp( 3, 3,20,3)/
     x 3.2809684d-01, 7.2382551d-04,-1.0572167d-04 /
      data fpp( 3, 3,21,1),fpp( 3, 3,21,2),fpp( 3, 3,21,3)/
     x 3.2809684d-01, 7.2382551d-04,-1.0072049d-04 /
      data fpp( 3, 3,22,1),fpp( 3, 3,22,2),fpp( 3, 3,22,3)/
     x 1.6342956d-01, 1.0202945d-03, 3.3228283d-05 /
      data fpp( 3, 3,23,1),fpp( 3, 3,23,2),fpp( 3, 3,23,3)/
     x 1.0667725d-01,-1.0190091d-03, 9.7071358d-05 /
      data fpp( 3, 4, 1,1),fpp( 3, 4, 1,2),fpp( 3, 4, 1,3)/
     x 1.4711756d-01, 4.6235471d-04,-1.3483446d-03 /
      data fpp( 3, 4, 2,1),fpp( 3, 4, 2,2),fpp( 3, 4, 2,3)/
     x-1.3406595d+00,-2.7512166d-03,-9.0603730d-04 /
      data fpp( 3, 4, 3,1),fpp( 3, 4, 3,2),fpp( 3, 4, 3,3)/
     x 2.2947596d-01,-2.2529695d-03,-4.6128212d-05 /
      data fpp( 3, 4, 4,1),fpp( 3, 4, 4,2),fpp( 3, 4, 4,3)/
     x 2.2947596d-01,-2.2529695d-03, 1.0768328d-04 /
      data fpp( 3, 4, 5,1),fpp( 3, 4, 5,2),fpp( 3, 4, 5,3)/
     x-1.3406595d+00,-2.7512166d-03,-1.5212833d-03 /
      data fpp( 3, 4, 6,1),fpp( 3, 4, 6,2),fpp( 3, 4, 6,3)/
     x 1.4711756d-01, 4.6235471d-04, 9.5882783d-04 /
      data fpp( 3, 4, 7,1),fpp( 3, 4, 7,2),fpp( 3, 4, 7,3)/
     x 2.1496692d-01, 2.2793414d-03, 3.6291972d-05 /
      data fpp( 3, 4, 8,1),fpp( 3, 4, 8,2),fpp( 3, 4, 8,3)/
     x 2.5135755d-01, 3.2888554d-03, 1.6242429d-04 /
      data fpp( 3, 4, 9,1),fpp( 3, 4, 9,2),fpp( 3, 4, 9,3)/
     x 3.0212345d-01, 3.4599488d-03, 7.0208888d-05 /
      data fpp( 3, 4,10,1),fpp( 3, 4,10,2),fpp( 3, 4,10,3)/
     x 2.7890260d-01, 3.3715382d-03, 7.7498164d-05 /
      data fpp( 3, 4,11,1),fpp( 3, 4,11,2),fpp( 3, 4,11,3)/
     x 2.7401609d-01, 3.3216426d-03, 6.7884456d-05 /
      data fpp( 3, 4,12,1),fpp( 3, 4,12,2),fpp( 3, 4,12,3)/
     x-2.4119765d-01, 3.3056600d-03, 7.0508012d-05 /
      data fpp( 3, 4,13,1),fpp( 3, 4,13,2),fpp( 3, 4,13,3)/
     x 2.7402255d-01, 3.3213073d-03, 7.0353498d-05 /
      data fpp( 3, 4,14,1),fpp( 3, 4,14,2),fpp( 3, 4,14,3)/
     x 2.7596575d-01, 3.3699356d-03, 7.9003997d-05 /
      data fpp( 3, 4,15,1),fpp( 3, 4,15,2),fpp( 3, 4,15,3)/
     x 3.0327089d-01, 3.4555483d-03, 7.5900513d-05 /
      data fpp( 3, 4,16,1),fpp( 3, 4,16,2),fpp( 3, 4,16,3)/
     x 2.5110739d-01, 3.2415403d-03, 1.6383195d-04 /
      data fpp( 3, 4,17,1),fpp( 3, 4,17,2),fpp( 3, 4,17,3)/
     x 1.9816384d-01, 2.2385802d-03, 5.7891682d-05 /
      data fpp( 3, 4,18,1),fpp( 3, 4,18,2),fpp( 3, 4,18,3)/
     x 1.4289904d-01, 4.8492191d-04, 8.9976132d-04 /
      data fpp( 3, 4,19,1),fpp( 3, 4,19,2),fpp( 3, 4,19,3)/
     x-7.5530345d-01,-2.6762323d-03,-1.4806230d-03 /
      data fpp( 3, 4,20,1),fpp( 3, 4,20,2),fpp( 3, 4,20,3)/
     x 2.2259349d-01,-2.1573660d-03, 1.0040253d-04 /
      data fpp( 3, 4,21,1),fpp( 3, 4,21,2),fpp( 3, 4,21,3)/
     x 2.2259349d-01,-2.1573660d-03,-4.7613111d-05 /
      data fpp( 3, 4,22,1),fpp( 3, 4,22,2),fpp( 3, 4,22,3)/
     x-7.5530345d-01,-2.6762323d-03,-8.8856040d-04 /
      data fpp( 3, 4,23,1),fpp( 3, 4,23,2),fpp( 3, 4,23,3)/
     x 1.4289904d-01, 4.8492191d-04,-1.3204733d-03 /
      data fpp( 3, 5, 1,1),fpp( 3, 5, 1,2),fpp( 3, 5, 1,3)/
     x-1.5674086d-02, 1.2624158d-03, 1.3535534d-04 /
      data fpp( 3, 5, 2,1),fpp( 3, 5, 2,2),fpp( 3, 5, 2,3)/
     x-4.9203881d-02, 2.8369251d-03, 1.0339820d-05 /
      data fpp( 3, 5, 3,1),fpp( 3, 5, 3,2),fpp( 3, 5, 3,3)/
     x 3.8846226d-03, 2.0224645d-03,-2.5592062d-04 /
      data fpp( 3, 5, 4,1),fpp( 3, 5, 4,2),fpp( 3, 5, 4,3)/
     x 3.8846226d-03, 2.0224645d-03,-2.5877305d-04 /
      data fpp( 3, 5, 5,1),fpp( 3, 5, 5,2),fpp( 3, 5, 5,3)/
     x-4.9203881d-02, 2.8369251d-03, 2.1749535d-05 /
      data fpp( 3, 5, 6,1),fpp( 3, 5, 6,2),fpp( 3, 5, 6,3)/
     x-1.5674086d-02, 1.2624158d-03, 9.2568907d-05 /
      data fpp( 3, 5, 7,1),fpp( 3, 5, 7,2),fpp( 3, 5, 7,3)/
     x 6.5490380d-02, 3.4312336d-04,-1.9591645d-06 /
      data fpp( 3, 5, 8,1),fpp( 3, 5, 8,2),fpp( 3, 5, 8,3)/
     x 1.4888478d-01,-5.6034041d-05, 6.3221751d-05 /
      data fpp( 3, 5, 9,1),fpp( 3, 5, 9,2),fpp( 3, 5, 9,3)/
     x 9.0795469d-02,-1.4131871d-04, 5.2642162d-05 /
      data fpp( 3, 5,10,1),fpp( 3, 5,10,2),fpp( 3, 5,10,3)/
     x 9.6229933d-02,-1.2814623d-04, 6.0355602d-05 /
      data fpp( 3, 5,11,1),fpp( 3, 5,11,2),fpp( 3, 5,11,3)/
     x 8.9199299d-02,-1.1716632d-04, 6.0601430d-05 /
      data fpp( 3, 5,12,1),fpp( 3, 5,12,2),fpp( 3, 5,12,3)/
     x 1.0025395d-01,-1.1575662d-04, 6.1804678d-05 /
      data fpp( 3, 5,13,1),fpp( 3, 5,13,2),fpp( 3, 5,13,3)/
     x 9.1195041d-02,-1.2383694d-04, 6.2649856d-05 /
      data fpp( 3, 5,14,1),fpp( 3, 5,14,2),fpp( 3, 5,14,3)/
     x 9.6889242d-02,-1.4017187d-04, 6.3279896d-05 /
      data fpp( 3, 5,15,1),fpp( 3, 5,15,2),fpp( 3, 5,15,3)/
     x 9.2228976d-02,-1.5951612d-04, 6.4780560d-05 /
      data fpp( 3, 5,16,1),fpp( 3, 5,16,2),fpp( 3, 5,16,3)/
     x-3.7901553d-02,-9.8692831d-06, 5.8975863d-05 /
      data fpp( 3, 5,17,1),fpp( 3, 5,17,2),fpp( 3, 5,17,3)/
     x 6.7019494d-02, 3.2076004d-04, 7.6721989d-05 /
      data fpp( 3, 5,18,1),fpp( 3, 5,18,2),fpp( 3, 5,18,3)/
     x 6.3830447d-02, 1.1218834d-03, 8.5781829d-06 /
      data fpp( 3, 5,19,1),fpp( 3, 5,19,2),fpp( 3, 5,19,3)/
     x-2.5098292d-02, 2.8159966d-03, 8.3053280d-05 /
      data fpp( 3, 5,20,1),fpp( 3, 5,20,2),fpp( 3, 5,20,3)/
     x-4.0566295d-02, 2.1433106d-03,-2.9720130d-04 /
      data fpp( 3, 5,21,1),fpp( 3, 5,21,2),fpp( 3, 5,21,3)/
     x-4.0566295d-02, 2.1433106d-03,-2.8524273d-04 /
      data fpp( 3, 5,22,1),fpp( 3, 5,22,2),fpp( 3, 5,22,3)/
     x-2.5098292d-02, 2.8159966d-03, 3.5218995d-05 /
      data fpp( 3, 5,23,1),fpp( 3, 5,23,2),fpp( 3, 5,23,3)/
     x 6.3830447d-02, 1.1218834d-03, 1.8795675d-04 /
      data fpp( 3, 6, 1,1),fpp( 3, 6, 1,2),fpp( 3, 6, 1,3)/
     x 1.2791169d-02,-2.7641795d-04,-1.1510126d-05 /
      data fpp( 3, 6, 2,1),fpp( 3, 6, 2,2),fpp( 3, 6, 2,3)/
     x-5.4017395d-02,-4.8461589d-04,-4.0686249d-05 /
      data fpp( 3, 6, 3,1),fpp( 3, 6, 3,2),fpp( 3, 6, 3,3)/
     x-2.9990063d-02, 1.5343374d-05,-1.0143888d-04 /
      data fpp( 3, 6, 4,1),fpp( 3, 6, 4,2),fpp( 3, 6, 4,3)/
     x-2.9990063d-02, 1.5343374d-05,-1.0453224d-04 /
      data fpp( 3, 6, 5,1),fpp( 3, 6, 5,2),fpp( 3, 6, 5,3)/
     x-5.4017395d-02,-4.8461589d-04,-2.8312818d-05 /
      data fpp( 3, 6, 6,1),fpp( 3, 6, 6,2),fpp( 3, 6, 6,3)/
     x 1.2791169d-02,-2.7641795d-04,-5.7910489d-05 /
      data fpp( 3, 6, 7,1),fpp( 3, 6, 7,2),fpp( 3, 6, 7,3)/
     x 1.9777702d-02, 4.5341203d-05, 2.7610776d-05 /
      data fpp( 3, 6, 8,1),fpp( 3, 6, 8,2),fpp( 3, 6, 8,3)/
     x 2.7126625d-02, 1.4704473d-04, 2.9967386d-05 /
      data fpp( 3, 6, 9,1),fpp( 3, 6, 9,2),fpp( 3, 6, 9,3)/
     x 3.3109903d-02, 1.7230404d-04, 4.4087679d-05 /
      data fpp( 3, 6,10,1),fpp( 3, 6,10,2),fpp( 3, 6,10,3)/
     x 3.7542391d-02, 1.7019468d-04, 4.8171898d-05 /
      data fpp( 3, 6,11,1),fpp( 3, 6,11,2),fpp( 3, 6,11,3)/
     x 4.0388840d-02, 1.6559866d-04, 5.1728728d-05 /
      data fpp( 3, 6,12,1),fpp( 3, 6,12,2),fpp( 3, 6,12,3)/
     x 4.1468683d-02, 1.6239446d-04, 5.1525189d-05 /
      data fpp( 3, 6,13,1),fpp( 3, 6,13,2),fpp( 3, 6,13,3)/
     x 4.2013305d-02, 1.6101451d-04, 5.8334514d-05 /
      data fpp( 3, 6,14,1),fpp( 3, 6,14,2),fpp( 3, 6,14,3)/
     x 3.6604999d-02, 1.6058388d-04, 3.6490754d-05 /
      data fpp( 3, 6,15,1),fpp( 3, 6,15,2),fpp( 3, 6,15,3)/
     x 3.6680348d-02, 1.5950013d-04, 1.1882647d-04 /
      data fpp( 3, 6,16,1),fpp( 3, 6,16,2),fpp( 3, 6,16,3)/
     x-9.1526467d-01, 2.6062830d-05,-5.1488635d-05 /
      data fpp( 3, 6,17,1),fpp( 3, 6,17,2),fpp( 3, 6,17,3)/
     x 2.4850302d-02, 1.5691671d-05, 1.1086407d-04 /
      data fpp( 3, 6,18,1),fpp( 3, 6,18,2),fpp( 3, 6,18,3)/
     x 1.5621981d-02,-1.8628571d-04, 1.4283540d-06 /
      data fpp( 3, 6,19,1),fpp( 3, 6,19,2),fpp( 3, 6,19,3)/
     x 4.5088234d-03,-6.1516430d-04, 3.2846514d-05 /
      data fpp( 3, 6,20,1),fpp( 3, 6,20,2),fpp( 3, 6,20,3)/
     x-3.4426670d-01,-3.4737445d-04,-2.1381441d-04 /
      data fpp( 3, 6,21,1),fpp( 3, 6,21,2),fpp( 3, 6,21,3)/
     x-3.4426670d-01,-3.4737445d-04,-2.0685903d-04 /
      data fpp( 3, 6,22,1),fpp( 3, 6,22,2),fpp( 3, 6,22,3)/
     x 4.5088234d-03,-6.1516430d-04, 5.0250092d-06 /
      data fpp( 3, 6,23,1),fpp( 3, 6,23,2),fpp( 3, 6,23,3)/
     x 1.5621981d-02,-1.8628571d-04, 1.0575900d-04 /
      data fpp( 3, 7, 1,1),fpp( 3, 7, 1,2),fpp( 3, 7, 1,3)/
     x 2.1653805d-02, 2.2417198d-04,-6.9424804d-06 /
      data fpp( 3, 7, 2,1),fpp( 3, 7, 2,2),fpp( 3, 7, 2,3)/
     x 5.2063199d-01,-4.9479571d-05,-2.2807039d-05 /
      data fpp( 3, 7, 3,1),fpp( 3, 7, 3,2),fpp( 3, 7, 3,3)/
     x-1.1214713d+00,-4.4632402d-04,-5.3545362d-05 /
      data fpp( 3, 7, 4,1),fpp( 3, 7, 4,2),fpp( 3, 7, 4,3)/
     x-1.1214713d+00,-4.4632402d-04,-5.9245393d-05 /
      data fpp( 3, 7, 5,1),fpp( 3, 7, 5,2),fpp( 3, 7, 5,3)/
     x 5.2063199d-01,-4.9479571d-05,-6.9175599d-09 /
      data fpp( 3, 7, 6,1),fpp( 3, 7, 6,2),fpp( 3, 7, 6,3)/
     x 2.1653805d-02, 2.2417198d-04,-9.2442937d-05 /
      data fpp( 3, 7, 7,1),fpp( 3, 7, 7,2),fpp( 3, 7, 7,3)/
     x-1.0435735d-02,-1.0534017d-04, 2.1322665d-05 /
      data fpp( 3, 7, 8,1),fpp( 3, 7, 8,2),fpp( 3, 7, 8,3)/
     x-4.5530063d-04,-9.1486878d-05, 7.4762771d-06 /
      data fpp( 3, 7, 9,1),fpp( 3, 7, 9,2),fpp( 3, 7, 9,3)/
     x-1.9720493d-02,-8.5975435d-05, 2.8092227d-05 /
      data fpp( 3, 7,10,1),fpp( 3, 7,10,2),fpp( 3, 7,10,3)/
     x 1.0104762d-02,-8.8922498d-05, 3.5512816d-05 /
      data fpp( 3, 7,11,1),fpp( 3, 7,11,2),fpp( 3, 7,11,3)/
     x 1.2908087d-02,-9.0602313d-05, 4.1326511d-05 /
      data fpp( 3, 7,12,1),fpp( 3, 7,12,2),fpp( 3, 7,12,3)/
     x 3.6859692d-03,-9.2449213d-05, 4.3669141d-05 /
      data fpp( 3, 7,13,1),fpp( 3, 7,13,2),fpp( 3, 7,13,3)/
     x 1.4920517d-02,-9.3927091d-05, 4.4030925d-05 /
      data fpp( 3, 7,14,1),fpp( 3, 7,14,2),fpp( 3, 7,14,3)/
     x 1.5335730d-02,-9.4601634d-05, 4.3577159d-05 /
      data fpp( 3, 7,15,1),fpp( 3, 7,15,2),fpp( 3, 7,15,3)/
     x-1.0221835d-02,-9.4784423d-05, 4.2228437d-05 /
      data fpp( 3, 7,16,1),fpp( 3, 7,16,2),fpp( 3, 7,16,3)/
     x 1.2425895d-02,-2.2646036d-05, 3.8645092d-05 /
      data fpp( 3, 7,17,1),fpp( 3, 7,17,2),fpp( 3, 7,17,3)/
     x 9.4138400d-03,-6.1224729d-05, 3.5787196d-05 /
      data fpp( 3, 7,18,1),fpp( 3, 7,18,2),fpp( 3, 7,18,3)/
     x-6.6576128d-02,-1.9128617d-05, 1.5300123d-05 /
      data fpp( 3, 7,19,1),fpp( 3, 7,19,2),fpp( 3, 7,19,3)/
     x 3.8994364d-04, 6.4660535d-05, 3.4850310d-05 /
      data fpp( 3, 7,20,1),fpp( 3, 7,20,2),fpp( 3, 7,20,3)/
     x-1.4387985d-01,-8.0612808d-05,-1.6947937d-04 /
      data fpp( 3, 7,21,1),fpp( 3, 7,21,2),fpp( 3, 7,21,3)/
     x-1.4387985d-01,-8.0612808d-05,-1.6402506d-04 /
      data fpp( 3, 7,22,1),fpp( 3, 7,22,2),fpp( 3, 7,22,3)/
     x 3.8994364d-04, 6.4660535d-05, 1.3033088d-05 /
      data fpp( 3, 7,23,1),fpp( 3, 7,23,2),fpp( 3, 7,23,3)/
     x-6.6576128d-02,-1.9128617d-05, 9.7114706d-05 /
      data fpp( 3, 8, 1,1),fpp( 3, 8, 1,2),fpp( 3, 8, 1,3)/
     x-1.5573147d+00,-7.0344796d-04, 5.5657204d-06 /
      data fpp( 3, 8, 2,1),fpp( 3, 8, 2,2),fpp( 3, 8, 2,3)/
     x 1.8017562d-03,-4.0610583d-04, 2.7313059d-05 /
      data fpp( 3, 8, 3,1),fpp( 3, 8, 3,2),fpp( 3, 8, 3,3)/
     x-6.5751543d-02,-8.8841300d-05, 9.2752043d-05 /
      data fpp( 3, 8, 4,1),fpp( 3, 8, 4,2),fpp( 3, 8, 4,3)/
     x-6.5751543d-02,-8.8841300d-05, 5.9786342d-05 /
      data fpp( 3, 8, 5,1),fpp( 3, 8, 5,2),fpp( 3, 8, 5,3)/
     x 1.8017562d-03,-4.0610583d-04, 1.5917586d-04 /
      data fpp( 3, 8, 6,1),fpp( 3, 8, 6,2),fpp( 3, 8, 6,3)/
     x-1.5573147d+00,-7.0344796d-04,-4.8891979d-04 /
      data fpp( 3, 8, 7,1),fpp( 3, 8, 7,2),fpp( 3, 8, 7,3)/
     x-3.0716326d-02, 1.2752948d-04, 1.6116130d-04 /
      data fpp( 3, 8, 8,1),fpp( 3, 8, 8,2),fpp( 3, 8, 8,3)/
     x-2.0435580d-02,-1.4803217d-05,-5.7481403d-05 /
      data fpp( 3, 8, 9,1),fpp( 3, 8, 9,2),fpp( 3, 8, 9,3)/
     x-1.3671652d-01,-6.2444295d-05, 2.0716314d-05 /
      data fpp( 3, 8,10,1),fpp( 3, 8,10,2),fpp( 3, 8,10,3)/
     x-7.8284912d-03,-6.0132688d-05, 1.9592145d-05 /
      data fpp( 3, 8,11,1),fpp( 3, 8,11,2),fpp( 3, 8,11,3)/
     x-1.0459895d-01,-6.2995409d-05, 3.2759104d-05 /
      data fpp( 3, 8,12,1),fpp( 3, 8,12,2),fpp( 3, 8,12,3)/
     x-9.5942294d-02,-6.3107607d-05, 3.5209440d-05 /
      data fpp( 3, 8,13,1),fpp( 3, 8,13,2),fpp( 3, 8,13,3)/
     x-9.4058223d-02,-6.1186146d-05, 3.5641138d-05 /
      data fpp( 3, 8,14,1),fpp( 3, 8,14,2),fpp( 3, 8,14,3)/
     x 2.3850372d-03,-5.7115340d-05, 3.3924010d-05 /
      data fpp( 3, 8,15,1),fpp( 3, 8,15,2),fpp( 3, 8,15,3)/
     x-1.1019247d-01,-5.0038445d-05, 3.0994822d-05 /
      data fpp( 3, 8,16,1),fpp( 3, 8,16,2),fpp( 3, 8,16,3)/
     x 4.1132830d-03,-5.7332685d-05, 2.6620703d-05 /
      data fpp( 3, 8,17,1),fpp( 3, 8,17,2),fpp( 3, 8,17,3)/
     x-1.4781279d-01,-2.7268757d-05, 2.1534367d-05 /
      data fpp( 3, 8,18,1),fpp( 3, 8,18,2),fpp( 3, 8,18,3)/
     x-1.7435272d-01,-7.3498232d-06, 8.9818293d-06 /
      data fpp( 3, 8,19,1),fpp( 3, 8,19,2),fpp( 3, 8,19,3)/
     x-2.1130824d-01, 1.9190156d-05, 3.2823158d-06 /
      data fpp( 3, 8,20,1),fpp( 3, 8,20,2),fpp( 3, 8,20,3)/
     x-2.8952043d-01, 1.3964169d-04,-9.6337093d-05 /
      data fpp( 3, 8,21,1),fpp( 3, 8,21,2),fpp( 3, 8,21,3)/
     x-2.8952043d-01, 1.3964169d-04,-9.4400880d-05 /
      data fpp( 3, 8,22,1),fpp( 3, 8,22,2),fpp( 3, 8,22,3)/
     x-2.1130824d-01, 1.9190156d-05,-4.4625343d-06 /
      data fpp( 3, 8,23,1),fpp( 3, 8,23,2),fpp( 3, 8,23,3)/
     x-1.7435272d-01,-7.3498232d-06, 3.8025017d-05 /
      data fpp( 3, 9, 1,1),fpp( 3, 9, 1,2),fpp( 3, 9, 1,3)/
     x-4.0842653d-02,-1.2701383d-06, 5.5779349d-05 /
      data fpp( 3, 9, 2,1),fpp( 3, 9, 2,2),fpp( 3, 9, 2,3)/
     x-3.8062870d-02,-7.4171080d-06, 7.7271802d-05 /
      data fpp( 3, 9, 3,1),fpp( 3, 9, 3,2),fpp( 3, 9, 3,3)/
     x-6.9463370d-03,-5.3346780d-05, 1.1870344d-04 /
      data fpp( 3, 9, 4,1),fpp( 3, 9, 4,2),fpp( 3, 9, 4,3)/
     x-6.9463370d-03,-5.3346780d-05, 1.2679477d-04 /
      data fpp( 3, 9, 5,1),fpp( 3, 9, 5,2),fpp( 3, 9, 5,3)/
     x-3.8062870d-02,-7.4171080d-06, 4.4906510d-05 /
      data fpp( 3, 9, 6,1),fpp( 3, 9, 6,2),fpp( 3, 9, 6,3)/
     x-4.0842653d-02,-1.2701383d-06, 1.7714919d-04 /
      data fpp( 3, 9, 7,1),fpp( 3, 9, 7,2),fpp( 3, 9, 7,3)/
     x 4.0815116d-01,-7.7050175d-04,-5.4099529d-04 /
      data fpp( 3, 9, 8,1),fpp( 3, 9, 8,2),fpp( 3, 9, 8,3)/
     x-5.4034812d-01,-1.2264825d-04, 5.0205957d-05 /
      data fpp( 3, 9, 9,1),fpp( 3, 9, 9,2),fpp( 3, 9, 9,3)/
     x-2.8011312d-01,-2.9773384d-05,-1.9798540d-05 /
      data fpp( 3, 9,10,1),fpp( 3, 9,10,2),fpp( 3, 9,10,3)/
     x-2.2980683d-02,-7.3536748d-05, 1.8296204d-05 /
      data fpp( 3, 9,11,1),fpp( 3, 9,11,2),fpp( 3, 9,11,3)/
     x-2.5286794d-01,-7.3372052d-05, 2.3329726d-05 /
      data fpp( 3, 9,12,1),fpp( 3, 9,12,2),fpp( 3, 9,12,3)/
     x-2.3504231d-01,-7.0410361d-05, 2.9204893d-05 /
      data fpp( 3, 9,13,1),fpp( 3, 9,13,2),fpp( 3, 9,13,3)/
     x-2.2607928d-01,-6.5398327d-05, 2.8846703d-05 /
      data fpp( 3, 9,14,1),fpp( 3, 9,14,2),fpp( 3, 9,14,3)/
     x-5.2741911d-03,-5.8519005d-05, 2.6702296d-05 /
      data fpp( 3, 9,15,1),fpp( 3, 9,15,2),fpp( 3, 9,15,3)/
     x-2.2667927d-01,-4.8951799d-05, 2.3644112d-05 /
      data fpp( 3, 9,16,1),fpp( 3, 9,16,2),fpp( 3, 9,16,3)/
     x-1.1887156d-03,-3.1043226d-05, 1.9811254d-05 /
      data fpp( 3, 9,17,1),fpp( 3, 9,17,2),fpp( 3, 9,17,3)/
     x-2.2865760d-01,-1.7986245d-05, 1.6402870d-05 /
      data fpp( 3, 9,18,1),fpp( 3, 9,18,2),fpp( 3, 9,18,3)/
     x-2.1648366d-01, 3.1199099d-06, 9.1072652d-06 /
      data fpp( 3, 9,19,1),fpp( 3, 9,19,2),fpp( 3, 9,19,3)/
     x-1.8800453d-01, 2.8474840d-05, 9.2440690d-06 /
      data fpp( 3, 9,20,1),fpp( 3, 9,20,2),fpp( 3, 9,20,3)/
     x-1.3753456d-01, 1.7580066d-05,-6.9423541d-05 /
      data fpp( 3, 9,21,1),fpp( 3, 9,21,2),fpp( 3, 9,21,3)/
     x-1.3753456d-01, 1.7580066d-05,-6.7674411d-05 /
      data fpp( 3, 9,22,1),fpp( 3, 9,22,2),fpp( 3, 9,22,3)/
     x-1.8800453d-01, 2.8474840d-05, 2.2475459d-06 /
      data fpp( 3, 9,23,1),fpp( 3, 9,23,2),fpp( 3, 9,23,3)/
     x-2.1648366d-01, 3.1199099d-06, 3.5344227d-05 /
      data fpp( 3,10, 1,1),fpp( 3,10, 1,2),fpp( 3,10, 1,3)/
     x-2.6769428d-02, 1.3085127d-06, 9.6506339d-05 /
      data fpp( 3,10, 2,1),fpp( 3,10, 2,2),fpp( 3,10, 2,3)/
     x-1.4396882d-02, 8.3592262d-05, 1.0629982d-04 /
      data fpp( 3,10, 3,1),fpp( 3,10, 3,2),fpp( 3,10, 3,3)/
     x 9.9594724d-02, 1.9700042d-04, 1.2978037d-04 /
      data fpp( 3,10, 4,1),fpp( 3,10, 4,2),fpp( 3,10, 4,3)/
     x 9.9594724d-02, 1.9700042d-04, 1.2541497d-04 /
      data fpp( 3,10, 5,1),fpp( 3,10, 5,2),fpp( 3,10, 5,3)/
     x-1.4396882d-02, 8.3592262d-05, 1.2376143d-04 /
      data fpp( 3,10, 6,1),fpp( 3,10, 6,2),fpp( 3,10, 6,3)/
     x-2.6769428d-02, 1.3085127d-06, 3.1025309d-05 /
      data fpp( 3,10, 7,1),fpp( 3,10, 7,2),fpp( 3,10, 7,3)/
     x-8.4947318d-02, 1.6131551d-04, 8.1591333d-05 /
      data fpp( 3,10, 8,1),fpp( 3,10, 8,2),fpp( 3,10, 8,3)/
     x-3.1358085d-01,-5.1142976d-04,-4.6660864d-04 /
      data fpp( 3,10, 9,1),fpp( 3,10, 9,2),fpp( 3,10, 9,3)/
     x-4.4482218d-01,-2.2974417d-04,-5.7840763d-05 /
      data fpp( 3,10,10,1),fpp( 3,10,10,2),fpp( 3,10,10,3)/
     x-2.1982544d-02,-6.5222318d-05, 1.7847695d-05 /
      data fpp( 3,10,11,1),fpp( 3,10,11,2),fpp( 3,10,11,3)/
     x-1.7162597d+00,-6.1884382d-05, 1.7391982d-05 /
      data fpp( 3,10,12,1),fpp( 3,10,12,2),fpp( 3,10,12,3)/
     x-1.7580958d+00,-5.6098951d-05, 2.4772378d-05 /
      data fpp( 3,10,13,1),fpp( 3,10,13,2),fpp( 3,10,13,3)/
     x-1.1237555d-02,-4.9028548d-05, 2.3792505d-05 /
      data fpp( 3,10,14,1),fpp( 3,10,14,2),fpp( 3,10,14,3)/
     x-1.5818284d+00,-4.0440639d-05, 2.2083602d-05 /
      data fpp( 3,10,15,1),fpp( 3,10,15,2),fpp( 3,10,15,3)/
     x-6.0318211d-03,-3.0208359d-05, 1.9543087d-05 /
      data fpp( 3,10,16,1),fpp( 3,10,16,2),fpp( 3,10,16,3)/
     x-5.5024233d-03,-2.0028413d-05, 1.6342050d-05 /
      data fpp( 3,10,17,1),fpp( 3,10,17,2),fpp( 3,10,17,3)/
     x-5.6949694d-03,-7.5922645d-06, 1.4868714d-05 /
      data fpp( 3,10,18,1),fpp( 3,10,18,2),fpp( 3,10,18,3)/
     x-5.2455857d-03, 2.5501834d-06, 1.1261095d-05 /
      data fpp( 3,10,19,1),fpp( 3,10,19,2),fpp( 3,10,19,3)/
     x 5.0842062d-04, 1.2236482d-05, 2.6654904d-05 /
      data fpp( 3,10,20,1),fpp( 3,10,20,2),fpp( 3,10,20,3)/
     x 3.3654192d-02, 9.8690050d-05,-6.4654713d-05 /
      data fpp( 3,10,21,1),fpp( 3,10,21,2),fpp( 3,10,21,3)/
     x 3.3654192d-02, 9.8690050d-05,-6.1901313d-05 /
      data fpp( 3,10,22,1),fpp( 3,10,22,2),fpp( 3,10,22,3)/
     x 5.0842062d-04, 1.2236482d-05, 1.5641304d-05 /
      data fpp( 3,10,23,1),fpp( 3,10,23,2),fpp( 3,10,23,3)/
     x-5.2455857d-03, 2.5501834d-06, 5.2562098d-05 /
      data fpp( 3,11, 1,1),fpp( 3,11, 1,2),fpp( 3,11, 1,3)/
     x 8.7644156d-02, 1.6703609d-04, 2.4429434d-04 /
      data fpp( 3,11, 2,1),fpp( 3,11, 2,2),fpp( 3,11, 2,3)/
     x 2.0548504d-01, 3.8065206d-04, 1.7884083d-04 /
      data fpp( 3,11, 3,1),fpp( 3,11, 3,2),fpp( 3,11, 3,3)/
     x 3.6862178d-01, 6.9304509d-04, 4.3236350d-05 /
      data fpp( 3,11, 4,1),fpp( 3,11, 4,2),fpp( 3,11, 4,3)/
     x 3.6862178d-01, 6.9304509d-04, 3.5093535d-05 /
      data fpp( 3,11, 5,1),fpp( 3,11, 5,2),fpp( 3,11, 5,3)/
     x 2.0548504d-01, 3.8065206d-04, 2.1141209d-04 /
      data fpp( 3,11, 6,1),fpp( 3,11, 6,2),fpp( 3,11, 6,3)/
     x 8.7644156d-02, 1.6703609d-04, 1.2215212d-04 /
      data fpp( 3,11, 7,1),fpp( 3,11, 7,2),fpp( 3,11, 7,3)/
     x 1.2814803d-02, 1.8919713d-05, 5.6634463d-06 /
      data fpp( 3,11, 8,1),fpp( 3,11, 8,2),fpp( 3,11, 8,3)/
     x-6.5885875d-02, 1.5426931d-04,-5.7073902d-05 /
      data fpp( 3,11, 9,1),fpp( 3,11, 9,2),fpp( 3,11, 9,3)/
     x-1.2668245d-01,-2.1473394d-04,-3.4437384d-04 /
      data fpp( 3,11,10,1),fpp( 3,11,10,2),fpp( 3,11,10,3)/
     x 3.8213790d-02,-1.3680798d-04,-7.3350745d-05 /
      data fpp( 3,11,11,1),fpp( 3,11,11,2),fpp( 3,11,11,3)/
     x-4.0803381d-03,-5.8968418d-05, 2.2050820d-05 /
      data fpp( 3,11,12,1),fpp( 3,11,12,2),fpp( 3,11,12,3)/
     x-8.1648888d-03,-4.5063835d-05, 1.7355466d-05 /
      data fpp( 3,11,13,1),fpp( 3,11,13,2),fpp( 3,11,13,3)/
     x-5.8669169d-03,-3.7341480d-05, 2.1087314d-05 /
      data fpp( 3,11,14,1),fpp( 3,11,14,2),fpp( 3,11,14,3)/
     x-1.3639020d+00,-2.9666440d-05, 1.8943276d-05 /
      data fpp( 3,11,15,1),fpp( 3,11,15,2),fpp( 3,11,15,3)/
     x-4.1014198d-03,-2.1242766d-05, 1.7193582d-05 /
      data fpp( 3,11,16,1),fpp( 3,11,16,2),fpp( 3,11,16,3)/
     x-6.2876464d-03,-1.1981121d-05, 1.3358395d-05 /
      data fpp( 3,11,17,1),fpp( 3,11,17,2),fpp( 3,11,17,3)/
     x-1.0282950d-02,-3.2566974d-06, 1.3276837d-05 /
      data fpp( 3,11,18,1),fpp( 3,11,18,2),fpp( 3,11,18,3)/
     x-1.4796671d-02, 5.5493564d-06, 1.2116258d-05 /
      data fpp( 3,11,19,1),fpp( 3,11,19,2),fpp( 3,11,19,3)/
     x-1.5727696d-02, 1.2885231d-05, 5.0272133d-05 /
      data fpp( 3,11,20,1),fpp( 3,11,20,2),fpp( 3,11,20,3)/
     x-2.4349120d+00,-2.3847826d-04,-7.1292789d-05 /
      data fpp( 3,11,21,1),fpp( 3,11,21,2),fpp( 3,11,21,3)/
     x-2.4349120d+00,-2.3847826d-04,-6.6788699d-05 /
      data fpp( 3,11,22,1),fpp( 3,11,22,2),fpp( 3,11,22,3)/
     x-1.5727696d-02, 1.2885231d-05, 3.2255771d-05 /
      data fpp( 3,11,23,1),fpp( 3,11,23,2),fpp( 3,11,23,3)/
     x-1.4796671d-02, 5.5493564d-06, 7.9677614d-05 /
      data fpp( 3,12, 1,1),fpp( 3,12, 1,2),fpp( 3,12, 1,3)/
     x 2.1762853d-01, 2.3696714d-04, 7.1048431d-04 /
      data fpp( 3,12, 2,1),fpp( 3,12, 2,2),fpp( 3,12, 2,3)/
     x 5.6559358d-01, 4.9131550d-04, 3.8897138d-04 /
      data fpp( 3,12, 3,1),fpp( 3,12, 3,2),fpp( 3,12, 3,3)/
     x 1.1377825d+00, 9.4766121d-04,-2.8383782d-04 /
      data fpp( 3,12, 4,1),fpp( 3,12, 4,2),fpp( 3,12, 4,3)/
     x 1.1377825d+00, 9.4766121d-04,-3.1209523d-04 /
      data fpp( 3,12, 5,1),fpp( 3,12, 5,2),fpp( 3,12, 5,3)/
     x 5.6559358d-01, 4.9131550d-04, 5.0200101d-04 /
      data fpp( 3,12, 6,1),fpp( 3,12, 6,2),fpp( 3,12, 6,3)/
     x 2.1762853d-01, 2.3696714d-04, 2.8662317d-04 /
      data fpp( 3,12, 7,1),fpp( 3,12, 7,2),fpp( 3,12, 7,3)/
     x 6.7018791d-02, 1.3040964d-04, 8.5500296d-05 /
      data fpp( 3,12, 8,1),fpp( 3,12, 8,2),fpp( 3,12, 8,3)/
     x-1.1803166d-02, 2.4804530d-05,-4.1878355d-05 /
      data fpp( 3,12, 9,1),fpp( 3,12, 9,2),fpp( 3,12, 9,3)/
     x-8.5779998d-02, 5.5317931d-05,-1.3617687d-04 /
      data fpp( 3,12,10,1),fpp( 3,12,10,2),fpp( 3,12,10,3)/
     x-5.6547164d-03,-1.0295577d-04,-2.6736415d-04 /
      data fpp( 3,12,11,1),fpp( 3,12,11,2),fpp( 3,12,11,3)/
     x 3.8529351d-02,-5.9505945d-05,-1.6566542d-05 /
      data fpp( 3,12,12,1),fpp( 3,12,12,2),fpp( 3,12,12,3)/
     x 1.3438363d-02,-3.7047710d-05, 1.1574314d-05 /
      data fpp( 3,12,13,1),fpp( 3,12,13,2),fpp( 3,12,13,3)/
     x 8.1995122d-03,-2.9119530d-05, 1.7141287d-05 /
      data fpp( 3,12,14,1),fpp( 3,12,14,2),fpp( 3,12,14,3)/
     x-1.2859276d+00,-2.4373601d-05, 1.7276539d-05 /
      data fpp( 3,12,15,1),fpp( 3,12,15,2),fpp( 3,12,15,3)/
     x 5.2859005d-03,-2.0294577d-05, 1.4162558d-05 /
      data fpp( 3,12,16,1),fpp( 3,12,16,2),fpp( 3,12,16,3)/
     x 1.0749977d-03,-1.6065102d-05, 1.5077230d-05 /
      data fpp( 3,12,17,1),fpp( 3,12,17,2),fpp( 3,12,17,3)/
     x-5.5740047d-03,-1.0238946d-05,-4.7394789d-06 /
      data fpp( 3,12,18,1),fpp( 3,12,18,2),fpp( 3,12,18,3)/
     x-1.3151401d-02,-3.3576089d-06, 7.3054685d-05 /
      data fpp( 3,12,19,1),fpp( 3,12,19,2),fpp( 3,12,19,3)/
     x-1.6939202d-02,-1.9714060d-06,-1.6185126d-04 /
      data fpp( 3,12,20,1),fpp( 3,12,20,2),fpp( 3,12,20,3)/
     x 1.7587084d+00, 1.9926101d-04, 4.6764366d-05 /
      data fpp( 3,12,21,1),fpp( 3,12,21,2),fpp( 3,12,21,3)/
     x 1.7587084d+00, 1.9926101d-04, 3.0992535d-05 /
      data fpp( 3,12,22,1),fpp( 3,12,22,2),fpp( 3,12,22,3)/
     x-1.6939202d-02,-1.9714060d-06,-9.8763938d-05 /
      data fpp( 3,12,23,1),fpp( 3,12,23,2),fpp( 3,12,23,3)/
     x-1.3151401d-02,-3.3576089d-06,-1.6352278d-04 /
      data fpp( 3,13, 1,1),fpp( 3,13, 1,2),fpp( 3,13, 1,3)/
     x 3.5473023d-01, 2.3043361d-05, 1.3905009d-03 /
      data fpp( 3,13, 2,1),fpp( 3,13, 2,2),fpp( 3,13, 2,3)/
     x 1.1356744d+00,-3.6665206d-04, 6.9022720d-04 /
      data fpp( 3,13, 3,1),fpp( 3,13, 3,2),fpp( 3,13, 3,3)/
     x 4.1620890d+00,-1.2501399d-03,-7.7626569d-04 /
      data fpp( 3,13, 4,1),fpp( 3,13, 4,2),fpp( 3,13, 4,3)/
     x 4.1620890d+00,-1.2501399d-03,-8.3592952d-04 /
      data fpp( 3,13, 5,1),fpp( 3,13, 5,2),fpp( 3,13, 5,3)/
     x 1.1356744d+00,-3.6665206d-04, 9.2888250d-04 /
      data fpp( 3,13, 6,1),fpp( 3,13, 6,2),fpp( 3,13, 6,3)/
     x 3.5473023d-01, 2.3043361d-05, 4.9554351d-04 /
      data fpp( 3,13, 7,1),fpp( 3,13, 7,2),fpp( 3,13, 7,3)/
     x 1.3226138d-01, 1.0271972d-04, 1.9789146d-04 /
      data fpp( 3,13, 8,1),fpp( 3,13, 8,2),fpp( 3,13, 8,3)/
     x 2.6755154d-02, 9.4698571d-05,-1.7713539d-06 /
      data fpp( 3,13, 9,1),fpp( 3,13, 9,2),fpp( 3,13, 9,3)/
     x-3.7747288d-02, 3.7310218d-05,-6.9426045d-05 /
      data fpp( 3,13,10,1),fpp( 3,13,10,2),fpp( 3,13,10,3)/
     x-8.1508997d-02, 3.8010518d-06,-2.0484446d-04 /
      data fpp( 3,13,11,1),fpp( 3,13,11,2),fpp( 3,13,11,3)/
     x 4.7237456d-02,-4.0021801d-05,-1.4337610d-04 /
      data fpp( 3,13,12,1),fpp( 3,13,12,2),fpp( 3,13,12,3)/
     x 3.8956000d-02,-2.7263324d-05, 1.0708857d-05 /
      data fpp( 3,13,13,1),fpp( 3,13,13,2),fpp( 3,13,13,3)/
     x 2.8129406d-02,-2.3666400d-05, 8.2606716d-06 /
      data fpp( 3,13,14,1),fpp( 3,13,14,2),fpp( 3,13,14,3)/
     x-9.8516038d-01,-2.2041155d-05, 1.5684457d-05 /
      data fpp( 3,13,15,1),fpp( 3,13,15,2),fpp( 3,13,15,3)/
     x 2.2097730d-02,-2.2246925d-05, 1.2017500d-05 /
      data fpp( 3,13,16,1),fpp( 3,13,16,2),fpp( 3,13,16,3)/
     x 1.9175348d-02,-2.3694472d-05, 1.3375542d-05 /
      data fpp( 3,13,17,1),fpp( 3,13,17,2),fpp( 3,13,17,3)/
     x 1.6148241d-02,-2.6137519d-05,-5.1056674d-06 /
      data fpp( 3,13,18,1),fpp( 3,13,18,2),fpp( 3,13,18,3)/
     x 1.7677746d-02,-3.2012921d-05, 6.7683128d-05 /
      data fpp( 3,13,19,1),fpp( 3,13,19,2),fpp( 3,13,19,3)/
     x 3.8946435d-02,-4.9033607d-05,-1.6098084d-04 /
      data fpp( 3,13,20,1),fpp( 3,13,20,2),fpp( 3,13,20,3)/
     x 1.3581635d+00, 6.3862229d-05, 4.9758249d-05 /
      data fpp( 3,13,21,1),fpp( 3,13,21,2),fpp( 3,13,21,3)/
     x 1.3581635d+00, 6.3862229d-05, 3.4235675d-05 /
      data fpp( 3,13,22,1),fpp( 3,13,22,2),fpp( 3,13,22,3)/
     x 3.8946435d-02,-4.9033607d-05,-9.8890550d-05 /
      data fpp( 3,13,23,1),fpp( 3,13,23,2),fpp( 3,13,23,3)/
     x 1.7677746d-02,-3.2012921d-05,-1.6515547d-04 /
      data fpp( 3,14, 1,1),fpp( 3,14, 1,2),fpp( 3,14, 1,3)/
     x 4.9342895d-01,-1.2753458d-04, 1.2029684d-03 /
      data fpp( 3,14, 2,1),fpp( 3,14, 2,2),fpp( 3,14, 2,3)/
     x 1.2708094d+00,-6.6146528d-04, 5.7439827d-04 /
      data fpp( 3,14, 3,1),fpp( 3,14, 3,2),fpp( 3,14, 3,3)/
     x 4.6058876d+00,-1.4358115d-03,-7.4639344d-04 /
      data fpp( 3,14, 4,1),fpp( 3,14, 4,2),fpp( 3,14, 4,3)/
     x 4.6058876d+00,-1.4358115d-03,-7.9214581d-04 /
      data fpp( 3,14, 5,1),fpp( 3,14, 5,2),fpp( 3,14, 5,3)/
     x 1.2708094d+00,-6.6146528d-04, 7.5740772d-04 /
      data fpp( 3,14, 6,1),fpp( 3,14, 6,2),fpp( 3,14, 6,3)/
     x 4.9342895d-01,-1.2753458d-04, 5.1668292d-04 /
      data fpp( 3,14, 7,1),fpp( 3,14, 7,2),fpp( 3,14, 7,3)/
     x 1.7755668d-01, 6.6487470d-05, 2.2756858d-04 /
      data fpp( 3,14, 8,1),fpp( 3,14, 8,2),fpp( 3,14, 8,3)/
     x 5.5257511d-02, 9.5061184d-05, 4.1686754d-05 /
      data fpp( 3,14, 9,1),fpp( 3,14, 9,2),fpp( 3,14, 9,3)/
     x-4.4643291d-02, 7.6703199d-05,-4.1647597d-05 /
      data fpp( 3,14,10,1),fpp( 3,14,10,2),fpp( 3,14,10,3)/
     x-6.1467886d-02, 3.1957561d-05,-1.0944437d-04 /
      data fpp( 3,14,11,1),fpp( 3,14,11,2),fpp( 3,14,11,3)/
     x-2.4805717d-02,-1.6152852d-05,-2.0563094d-04 /
      data fpp( 3,14,12,1),fpp( 3,14,12,2),fpp( 3,14,12,3)/
     x-7.9944115d-01,-1.0354993d-05,-2.2013881d-05 /
      data fpp( 3,14,13,1),fpp( 3,14,13,2),fpp( 3,14,13,3)/
     x 4.3569132d-02,-1.1490869d-05, 4.1444635d-06 /
      data fpp( 3,14,14,1),fpp( 3,14,14,2),fpp( 3,14,14,3)/
     x 3.9868834d-02,-1.7817779d-05, 1.0632028d-05 /
      data fpp( 3,14,15,1),fpp( 3,14,15,2),fpp( 3,14,15,3)/
     x 3.8581399d-02,-2.4811723d-05, 1.0291426d-05 /
      data fpp( 3,14,16,1),fpp( 3,14,16,2),fpp( 3,14,16,3)/
     x 3.8580207d-02,-3.2653009d-05, 7.7942668d-06 /
      data fpp( 3,14,17,1),fpp( 3,14,17,2),fpp( 3,14,17,3)/
     x 4.1016719d-02,-4.1546978d-05, 6.1895065d-06 /
      data fpp( 3,14,18,1),fpp( 3,14,18,2),fpp( 3,14,18,3)/
     x 5.0642182d-02,-5.0474707d-05, 6.8377072d-06 /
      data fpp( 3,14,19,1),fpp( 3,14,19,2),fpp( 3,14,19,3)/
     x 7.6581224d-02,-5.2082166d-05, 7.3676647d-06 /
      data fpp( 3,14,20,1),fpp( 3,14,20,2),fpp( 3,14,20,3)/
     x 1.2052930d-01,-2.4163792d-04,-3.0122366d-05 /
      data fpp( 3,14,21,1),fpp( 3,14,21,2),fpp( 3,14,21,3)/
     x 1.2052930d-01,-2.4163792d-04,-2.9266734d-05 /
      data fpp( 3,14,22,1),fpp( 3,14,22,2),fpp( 3,14,22,3)/
     x 7.6581224d-02,-5.2082166d-05, 3.9451384d-06 /
      data fpp( 3,14,23,1),fpp( 3,14,23,2),fpp( 3,14,23,3)/
     x 5.0642182d-02,-5.0474707d-05, 1.9672181d-05 /
      data fpp( 3,15, 1,1),fpp( 3,15, 1,2),fpp( 3,15, 1,3)/
     x 3.7288348d-01, 1.2400497d-04, 4.2895434d-04 /
      data fpp( 3,15, 2,1),fpp( 3,15, 2,2),fpp( 3,15, 2,3)/
     x 7.4926013d-01, 3.3607516d-04, 2.0794831d-04 /
      data fpp( 3,15, 3,1),fpp( 3,15, 3,2),fpp( 3,15, 3,3)/
     x 1.2234642d+00, 8.7120803d-04,-2.5994759d-04 /
      data fpp( 3,15, 4,1),fpp( 3,15, 4,2),fpp( 3,15, 4,3)/
     x 1.2234642d+00, 8.7120803d-04,-2.6990238d-04 /
      data fpp( 3,15, 5,1),fpp( 3,15, 5,2),fpp( 3,15, 5,3)/
     x 7.4926013d-01, 3.3607516d-04, 2.4776747d-04 /
      data fpp( 3,15, 6,1),fpp( 3,15, 6,2),fpp( 3,15, 6,3)/
     x 3.7288348d-01, 1.2400497d-04, 2.7963249d-04 /
      data fpp( 3,15, 7,1),fpp( 3,15, 7,2),fpp( 3,15, 7,3)/
     x 1.6365382d-01, 1.0297240d-04, 1.4955456d-04 /
      data fpp( 3,15, 8,1),fpp( 3,15, 8,2),fpp( 3,15, 8,3)/
     x 6.5370029d-02, 1.0625269d-04, 4.8921282d-05 /
      data fpp( 3,15, 9,1),fpp( 3,15, 9,2),fpp( 3,15, 9,3)/
     x-2.1507704d-02, 8.7432988d-05,-2.0477684d-05 /
      data fpp( 3,15,10,1),fpp( 3,15,10,2),fpp( 3,15,10,3)/
     x-3.3223736d-02, 5.5718703d-05,-4.5952546d-05 /
      data fpp( 3,15,11,1),fpp( 3,15,11,2),fpp( 3,15,11,3)/
     x-9.7420240d-02, 6.7912090d-06,-1.7463013d-04 /
      data fpp( 3,15,12,1),fpp( 3,15,12,2),fpp( 3,15,12,3)/
     x-2.8539891d-01,-4.8707035d-06,-8.6370920d-05 /
      data fpp( 3,15,13,1),fpp( 3,15,13,2),fpp( 3,15,13,3)/
     x 4.9715237d-02,-7.2961235d-06, 5.6498146d-06 /
      data fpp( 3,15,14,1),fpp( 3,15,14,2),fpp( 3,15,14,3)/
     x 4.8228672d-02, 1.5302694d-06, 3.2436620d-06 /
      data fpp( 3,15,15,1),fpp( 3,15,15,2),fpp( 3,15,15,3)/
     x 4.7628345d-02, 9.7258181d-06, 7.1575374d-06 /
      data fpp( 3,15,16,1),fpp( 3,15,16,2),fpp( 3,15,16,3)/
     x 4.8322181d-02, 1.7194508d-05, 4.8221883d-06 /
      data fpp( 3,15,17,1),fpp( 3,15,17,2),fpp( 3,15,17,3)/
     x 5.0757862d-02, 2.4169431d-05, 2.7557094d-06 /
      data fpp( 3,15,18,1),fpp( 3,15,18,2),fpp( 3,15,18,3)/
     x 5.6208308d-02, 3.2659750d-05, 2.4697411d-07 /
      data fpp( 3,15,19,1),fpp( 3,15,19,2),fpp( 3,15,19,3)/
     x 6.5723865d-02, 4.6384271d-05,-3.2036058d-06 /
      data fpp( 3,15,20,1),fpp( 3,15,20,2),fpp( 3,15,20,3)/
     x 7.6701775d-02, 1.1883747d-04,-1.1726551d-05 /
      data fpp( 3,15,21,1),fpp( 3,15,21,2),fpp( 3,15,21,3)/
     x 7.6701775d-02, 1.1883747d-04,-1.1701545d-05 /
      data fpp( 3,15,22,1),fpp( 3,15,22,2),fpp( 3,15,22,3)/
     x 6.5723865d-02, 4.6384271d-05,-3.3036301d-06 /
      data fpp( 3,15,23,1),fpp( 3,15,23,2),fpp( 3,15,23,3)/
     x 5.6208308d-02, 3.2659750d-05, 6.2206504d-07 /
      data fpp( 3,16, 1,1),fpp( 3,16, 1,2),fpp( 3,16, 1,3)/
     x 1.8843161d-01, 2.7656271d-04, 9.4800237d-05 /
      data fpp( 3,16, 2,1),fpp( 3,16, 2,2),fpp( 3,16, 2,3)/
     x 2.4475771d-01, 5.0117464d-04, 6.4529526d-05 /
      data fpp( 3,16, 3,1),fpp( 3,16, 3,2),fpp( 3,16, 3,3)/
     x 1.6440838d-01, 7.7895942d-04,-4.7834089d-07 /
      data fpp( 3,16, 4,1),fpp( 3,16, 4,2),fpp( 3,16, 4,3)/
     x 1.6440838d-01, 7.7895942d-04,-2.2974032d-07 /
      data fpp( 3,16, 5,1),fpp( 3,16, 5,2),fpp( 3,16, 5,3)/
     x 2.4475771d-01, 5.0117464d-04, 6.3535124d-05 /
      data fpp( 3,16, 6,1),fpp( 3,16, 6,2),fpp( 3,16, 6,3)/
     x 1.8843161d-01, 2.7656271d-04, 9.8529246d-05 /
      data fpp( 3,16, 7,1),fpp( 3,16, 7,2),fpp( 3,16, 7,3)/
     x 1.0784925d-01, 1.6961693d-04, 6.4251894d-05 /
      data fpp( 3,16, 8,1),fpp( 3,16, 8,2),fpp( 3,16, 8,3)/
     x 5.4886223d-02, 1.3155805d-04, 3.0053179d-05 /
      data fpp( 3,16, 9,1),fpp( 3,16, 9,2),fpp( 3,16, 9,3)/
     x 1.8488101d-02, 1.1201085d-04,-4.4286091d-06 /
      data fpp( 3,16,10,1),fpp( 3,16,10,2),fpp( 3,16,10,3)/
     x-1.2608670d-02, 8.6693626d-05,-1.9610742d-05 /
      data fpp( 3,16,11,1),fpp( 3,16,11,2),fpp( 3,16,11,3)/
     x-5.9555309d-02, 4.5076016d-05,-7.8426421d-05 /
      data fpp( 3,16,12,1),fpp( 3,16,12,2),fpp( 3,16,12,3)/
     x-1.1891928d-01, 2.2709807d-05,-1.5216757d-04 /
      data fpp( 3,16,13,1),fpp( 3,16,13,2),fpp( 3,16,13,3)/
     x 4.7261468d-02, 2.6977363d-05, 4.3567137d-06 /
      data fpp( 3,16,14,1),fpp( 3,16,14,2),fpp( 3,16,14,3)/
     x 5.1425652d-02,-2.0139299d-05,-3.0792818d-06 /
      data fpp( 3,16,15,1),fpp( 3,16,15,2),fpp( 3,16,15,3)/
     x 5.1396918d-02,-6.2343549d-05, 4.2824133d-06 /
      data fpp( 3,16,16,1),fpp( 3,16,16,2),fpp( 3,16,16,3)/
     x 5.1606864d-02,-9.8249023d-05, 2.2936284d-06 /
      data fpp( 3,16,17,1),fpp( 3,16,17,2),fpp( 3,16,17,3)/
     x 5.2429589d-02,-1.2732874d-04, 1.0870729d-06 /
      data fpp( 3,16,18,1),fpp( 3,16,18,2),fpp( 3,16,18,3)/
     x 5.3968029d-02,-1.4942829d-04,-8.3992018d-07 /
      data fpp( 3,16,19,1),fpp( 3,16,19,2),fpp( 3,16,19,3)/
     x 5.5971472d-02,-1.6484692d-04,-2.6173922d-06 /
      data fpp( 3,16,20,1),fpp( 3,16,20,2),fpp( 3,16,20,3)/
     x 5.7808236d-02,-1.8828595d-04,-4.5185109d-06 /
      data fpp( 3,16,21,1),fpp( 3,16,21,2),fpp( 3,16,21,3)/
     x 5.7808236d-02,-1.8828595d-04,-4.5607712d-06 /
      data fpp( 3,16,22,1),fpp( 3,16,22,2),fpp( 3,16,22,3)/
     x 5.5971472d-02,-1.6484692d-04,-2.4483511d-06 /
      data fpp( 3,16,23,1),fpp( 3,16,23,2),fpp( 3,16,23,3)/
     x 5.3968029d-02,-1.4942829d-04,-1.4738245d-06 /
      data fpp( 3,17, 1,1),fpp( 3,17, 1,2),fpp( 3,17, 1,3)/
     x 7.7735797d-02, 1.0101219d-04, 3.8172314d-05 /
      data fpp( 3,17, 2,1),fpp( 3,17, 2,2),fpp( 3,17, 2,3)/
     x 1.0050260d-01, 1.5111629d-04, 3.7698372d-05 /
      data fpp( 3,17, 3,1),fpp( 3,17, 3,2),fpp( 3,17, 3,3)/
     x 1.1657861d-01, 1.8714231d-04, 3.6790199d-05 /
      data fpp( 3,17, 4,1),fpp( 3,17, 4,2),fpp( 3,17, 4,3)/
     x 1.1657861d-01, 1.8714231d-04, 3.6602216d-05 /
      data fpp( 3,17, 5,1),fpp( 3,17, 5,2),fpp( 3,17, 5,3)/
     x 1.0050260d-01, 1.5111629d-04, 3.8450303d-05 /
      data fpp( 3,17, 6,1),fpp( 3,17, 6,2),fpp( 3,17, 6,3)/
     x 7.7735797d-02, 1.0101219d-04, 3.5352571d-05 /
      data fpp( 3,17, 7,1),fpp( 3,17, 7,2),fpp( 3,17, 7,3)/
     x 5.4741212d-02, 6.8555864d-05, 2.7445413d-05 /
      data fpp( 3,17, 8,1),fpp( 3,17, 8,2),fpp( 3,17, 8,3)/
     x 3.2875313d-02, 5.2073101d-05, 1.5107776d-05 /
      data fpp( 3,17, 9,1),fpp( 3,17, 9,2),fpp( 3,17, 9,3)/
     x 1.4955850d-02, 4.2299618d-05, 6.0894811d-06 /
      data fpp( 3,17,10,1),fpp( 3,17,10,2),fpp( 3,17,10,3)/
     x-2.6241390d-03, 2.8948793d-05,-1.4619701d-05 /
      data fpp( 3,17,11,1),fpp( 3,17,11,2),fpp( 3,17,11,3)/
     x-2.1685476d-02, 3.2247264d-06, 1.3923322d-05 /
      data fpp( 3,17,12,1),fpp( 3,17,12,2),fpp( 3,17,12,3)/
     x-4.7854979d-04,-9.8580525d-05,-1.4300759d-04 /
      data fpp( 3,17,13,1),fpp( 3,17,13,2),fpp( 3,17,13,3)/
     x 6.0600408d-01,-5.9777328d-05,-3.6528972d-05 /
      data fpp( 3,17,14,1),fpp( 3,17,14,2),fpp( 3,17,14,3)/
     x 5.1058695d-02, 1.0335093d-04, 4.0514756d-06 /
      data fpp( 3,17,15,1),fpp( 3,17,15,2),fpp( 3,17,15,3)/
     x 5.3300305d-02, 2.5959838d-04,-6.7693034d-07 /
      data fpp( 3,17,16,1),fpp( 3,17,16,2),fpp( 3,17,16,3)/
     x 5.3641576d-02, 3.9833158d-04, 1.6022458d-06 /
      data fpp( 3,17,17,1),fpp( 3,17,17,2),fpp( 3,17,17,3)/
     x 5.3737015d-02, 5.1664555d-04, 5.4394728d-07 /
      data fpp( 3,17,18,1),fpp( 3,17,18,2),fpp( 3,17,18,3)/
     x 5.3927898d-02, 6.1374943d-04,-4.0034903d-08 /
      data fpp( 3,17,19,1),fpp( 3,17,19,2),fpp( 3,17,19,3)/
     x 5.4130826d-02, 6.8888540d-04,-7.1380767d-07 /
      data fpp( 3,17,20,1),fpp( 3,17,20,2),fpp( 3,17,20,3)/
     x 5.4409150d-02, 7.4054833d-04,-1.2927344d-06 /
      data fpp( 3,17,21,1),fpp( 3,17,21,2),fpp( 3,17,21,3)/
     x 5.4409150d-02, 7.4054833d-04,-1.3118930d-06 /
      data fpp( 3,17,22,1),fpp( 3,17,22,2),fpp( 3,17,22,3)/
     x 5.4130826d-02, 6.8888540d-04,-6.3717344d-07 /
      data fpp( 3,17,23,1),fpp( 3,17,23,2),fpp( 3,17,23,3)/
     x 5.3927898d-02, 6.1374943d-04,-3.2741328d-07 /
      data fpp( 3,18, 1,1),fpp( 3,18, 1,2),fpp( 3,18, 1,3)/
     x 2.3226618d-02, 2.1035852d-04, 1.6157299d-05 /
      data fpp( 3,18, 2,1),fpp( 3,18, 2,2),fpp( 3,18, 2,3)/
     x 2.7782306d-02, 2.1430020d-04, 1.7046903d-05 /
      data fpp( 3,18, 3,1),fpp( 3,18, 3,2),fpp( 3,18, 3,3)/
     x 3.0740322d-02, 2.2564734d-04, 1.8993091d-05 /
      data fpp( 3,18, 4,1),fpp( 3,18, 4,2),fpp( 3,18, 4,3)/
     x 3.0740322d-02, 2.2564734d-04, 1.8923277d-05 /
      data fpp( 3,18, 5,1),fpp( 3,18, 5,2),fpp( 3,18, 5,3)/
     x 2.7782306d-02, 2.1430020d-04, 1.7326157d-05 /
      data fpp( 3,18, 6,1),fpp( 3,18, 6,2),fpp( 3,18, 6,3)/
     x 2.3226618d-02, 2.1035852d-04, 1.5110096d-05 /
      data fpp( 3,18, 7,1),fpp( 3,18, 7,2),fpp( 3,18, 7,3)/
     x 1.7617092d-02, 2.1534961d-04, 1.2131458d-05 /
      data fpp( 3,18, 8,1),fpp( 3,18, 8,2),fpp( 3,18, 8,3)/
     x 1.1017907d-02, 2.2493554d-04, 8.6340726d-06 /
      data fpp( 3,18, 9,1),fpp( 3,18, 9,2),fpp( 3,18, 9,3)/
     x 4.9848643d-03, 2.3308668d-04, 5.1422519d-06 /
      data fpp( 3,18,10,1),fpp( 3,18,10,2),fpp( 3,18,10,3)/
     x-5.3177202d-03, 2.3494720d-04, 1.3909199d-06 /
      data fpp( 3,18,11,1),fpp( 3,18,11,2),fpp( 3,18,11,3)/
     x 7.5701248d-03, 2.2731908d-04,-1.6219316d-06 /
      data fpp( 3,18,12,1),fpp( 3,18,12,2),fpp( 3,18,12,3)/
     x-2.4172876d-02, 2.1372229d-04,-4.3291936d-06 /
      data fpp( 3,18,13,1),fpp( 3,18,13,2),fpp( 3,18,13,3)/
     x-3.1346427d-01, 9.2215951d-05,-6.4352941d-06 /
      data fpp( 3,18,14,1),fpp( 3,18,14,2),fpp( 3,18,14,3)/
     x-1.8785507d+00,-8.0880408d-05,-7.9276301d-06 /
      data fpp( 3,18,15,1),fpp( 3,18,15,2),fpp( 3,18,15,3)/
     x-3.2848878d+00,-2.4020997d-04,-9.0201857d-06 /
      data fpp( 3,18,16,1),fpp( 3,18,16,2),fpp( 3,18,16,3)/
     x-4.4991474d+00,-3.7838731d-04,-9.0496272d-06 /
      data fpp( 3,18,17,1),fpp( 3,18,17,2),fpp( 3,18,17,3)/
     x-5.5214449d+00,-4.9406344d-04,-9.1233055d-06 /
      data fpp( 3,18,18,1),fpp( 3,18,18,2),fpp( 3,18,18,3)/
     x-6.3631939d+00,-5.8767341d-04,-8.5771507d-06 /
      data fpp( 3,18,19,1),fpp( 3,18,19,2),fpp( 3,18,19,3)/
     x-7.0274913d+00,-6.5949869d-04,-1.1744092d-05 /
      data fpp( 3,18,20,1),fpp( 3,18,20,2),fpp( 3,18,20,3)/
     x-7.4537075d+00,-7.0593538d-04,-1.3518483d-05 /
      data fpp( 3,18,21,1),fpp( 3,18,21,2),fpp( 3,18,21,3)/
     x-7.4537075d+00,-7.0593538d-04,-1.3629506d-05 /
      data fpp( 3,18,22,1),fpp( 3,18,22,2),fpp( 3,18,22,3)/
     x-7.0274913d+00,-6.5949869d-04,-1.1299998d-05 /
      data fpp( 3,18,23,1),fpp( 3,18,23,2),fpp( 3,18,23,3)/
     x-6.3631939d+00,-5.8767341d-04,-1.0242501d-05 /
      data fpp( 3,19, 1,1),fpp( 3,19, 1,2),fpp( 3,19, 1,3)/
     x 7.6372820d-01, 2.3830574d-04, 1.5954277d-19 /
      data fpp( 3,19, 2,1),fpp( 3,19, 2,2),fpp( 3,19, 2,3)/
     x 7.6372820d-01, 1.5941490d-04, 1.4336967d-20 /
      data fpp( 3,19, 3,1),fpp( 3,19, 3,2),fpp( 3,19, 3,3)/
     x 7.6372820d-01, 8.4060330d-05,-1.0090976d-19 /
      data fpp( 3,19, 4,1),fpp( 3,19, 4,2),fpp( 3,19, 4,3)/
     x 7.6372820d-01, 8.4060330d-05, 7.1293356d-20 /
      data fpp( 3,19, 5,1),fpp( 3,19, 5,2),fpp( 3,19, 5,3)/
     x 7.6372820d-01, 1.5941490d-04, 3.6766151d-21 /
      data fpp( 3,19, 6,1),fpp( 3,19, 6,2),fpp( 3,19, 6,3)/
     x 7.6372820d-01, 2.3830574d-04,-1.0336694d-20 /
      data fpp( 3,19, 7,1),fpp( 3,19, 7,2),fpp( 3,19, 7,3)/
     x 7.6372820d-01, 2.9132769d-04,-1.6865458d-19 /
      data fpp( 3,19, 8,1),fpp( 3,19, 8,2),fpp( 3,19, 8,3)/
     x 7.6372820d-01, 3.2569873d-04, 1.9781430d-20 /
      data fpp( 3,19, 9,1),fpp( 3,19, 9,2),fpp( 3,19, 9,3)/
     x 7.6372820d-01, 3.4944566d-04,-2.1747271d-20 /
      data fpp( 3,19,10,1),fpp( 3,19,10,2),fpp( 3,19,10,3)/
     x 7.6372820d-01, 3.6559040d-04, 1.9136105d-19 /
      data fpp( 3,19,11,1),fpp( 3,19,11,2),fpp( 3,19,11,3)/
     x 7.6372820d-01, 3.7542896d-04,-5.9257157d-20 /
      data fpp( 3,19,12,1),fpp( 3,19,12,2),fpp( 3,19,12,3)/
     x 7.6372820d-01, 4.0214135d-04, 6.6127743d-20 /
      data fpp( 3,19,13,1),fpp( 3,19,13,2),fpp( 3,19,13,3)/
     x 7.6372820d-01, 1.7599552d-04,-5.0643680d-20 /
      data fpp( 3,19,14,1),fpp( 3,19,14,2),fpp( 3,19,14,3)/
     x 7.6372820d-01,-1.7719130d-04, 2.6486269d-20 /
      data fpp( 3,19,15,1),fpp( 3,19,15,2),fpp( 3,19,15,3)/
     x 7.6372820d-01,-5.0523252d-04, 1.3193397d-20 /
      data fpp( 3,19,16,1),fpp( 3,19,16,2),fpp( 3,19,16,3)/
     x 7.6372820d-01,-7.9130635d-04, 2.1055253d-20 /
      data fpp( 3,19,17,1),fpp( 3,19,17,2),fpp( 3,19,17,3)/
     x 7.6372820d-01,-1.0320058d-03, 9.8410214d-20 /
      data fpp( 3,19,18,1),fpp( 3,19,18,2),fpp( 3,19,18,3)/
     x 7.6372820d-01,-1.2277818d-03,-1.2890520d-19 /
      data fpp( 3,19,19,1),fpp( 3,19,19,2),fpp( 3,19,19,3)/
     x 7.6372820d-01,-1.3787067d-03,-3.5625577d-20 /
      data fpp( 3,19,20,1),fpp( 3,19,20,2),fpp( 3,19,20,3)/
     x 7.6372820d-01,-1.4737568d-03, 8.1601471d-20 /
      data fpp( 3,19,21,1),fpp( 3,19,21,2),fpp( 3,19,21,3)/
     x 7.6372820d-01,-1.4737568d-03,-9.2607648d-20 /
      data fpp( 3,19,22,1),fpp( 3,19,22,2),fpp( 3,19,22,3)/
     x 7.6372820d-01,-1.3787067d-03, 1.3005058d-19 /
      data fpp( 3,19,23,1),fpp( 3,19,23,2),fpp( 3,19,23,3)/
     x 7.6372820d-01,-1.2277818d-03, 3.7905919d-19 /
      data fpp( 4, 1, 1,1),fpp( 4, 1, 1,2),fpp( 4, 1, 1,3)/
     x 1.0320680d+00, 6.8467958d-04,-4.5511745d-19 /
      data fpp( 4, 1, 2,1),fpp( 4, 1, 2,2),fpp( 4, 1, 2,3)/
     x 1.0320680d+00, 2.8468468d-04, 3.6070297d-19 /
      data fpp( 4, 1, 3,1),fpp( 4, 1, 3,2),fpp( 4, 1, 3,3)/
     x 1.0320680d+00, 7.0501766d-04,-6.6780484d-19 /
      data fpp( 4, 1, 4,1),fpp( 4, 1, 4,2),fpp( 4, 1, 4,3)/
     x 1.0320680d+00, 7.0501766d-04, 5.6295337d-19 /
      data fpp( 4, 1, 5,1),fpp( 4, 1, 5,2),fpp( 4, 1, 5,3)/
     x 1.0320680d+00, 2.8468468d-04,-5.9553481d-20 /
      data fpp( 4, 1, 6,1),fpp( 4, 1, 6,2),fpp( 4, 1, 6,3)/
     x 1.0320680d+00, 6.8467958d-04, 2.1752103d-19 /
      data fpp( 4, 1, 7,1),fpp( 4, 1, 7,2),fpp( 4, 1, 7,3)/
     x 1.0320680d+00, 1.0194924d-03,-5.4924335d-19 /
      data fpp( 4, 1, 8,1),fpp( 4, 1, 8,2),fpp( 4, 1, 8,3)/
     x 1.0320680d+00, 6.6864195d-05,-1.1276024d-18 /
      data fpp( 4, 1, 9,1),fpp( 4, 1, 9,2),fpp( 4, 1, 9,3)/
     x 1.0320680d+00,-7.9884562d-04, 1.1777615d-20 /
      data fpp( 4, 1,10,1),fpp( 4, 1,10,2),fpp( 4, 1,10,3)/
     x 1.0320680d+00,-1.3307620d-03, 1.3684666d-18 /
      data fpp( 4, 1,11,1),fpp( 4, 1,11,2),fpp( 4, 1,11,3)/
     x 1.0320680d+00,-1.6249377d-03,-6.5972916d-19 /
      data fpp( 4, 1,12,1),fpp( 4, 1,12,2),fpp( 4, 1,12,3)/
     x 1.0320680d+00,-1.7177165d-03, 9.4134972d-19 /
      data fpp( 4, 1,13,1),fpp( 4, 1,13,2),fpp( 4, 1,13,3)/
     x 1.0320680d+00,-1.6173786d-03, 1.1591260d-18 /
      data fpp( 4, 1,14,1),fpp( 4, 1,14,2),fpp( 4, 1,14,3)/
     x 1.0320680d+00,-1.3268475d-03, 1.1432177d-19 /
      data fpp( 4, 1,15,1),fpp( 4, 1,15,2),fpp( 4, 1,15,3)/
     x 1.0320680d+00,-7.7197167d-04, 2.5844645d-19 /
      data fpp( 4, 1,16,1),fpp( 4, 1,16,2),fpp( 4, 1,16,3)/
     x 1.0320680d+00, 1.0583766d-04,-9.7255115d-19 /
      data fpp( 4, 1,17,1),fpp( 4, 1,17,2),fpp( 4, 1,17,3)/
     x 1.0320680d+00, 1.0025252d-03, 8.5984528d-19 /
      data fpp( 4, 1,18,1),fpp( 4, 1,18,2),fpp( 4, 1,18,3)/
     x 1.0320680d+00, 6.6535771d-04,-2.7021082d-19 /
      data fpp( 4, 1,19,1),fpp( 4, 1,19,2),fpp( 4, 1,19,3)/
     x 1.0320680d+00, 2.8891759d-04,-8.8668756d-19 /
      data fpp( 4, 1,20,1),fpp( 4, 1,20,2),fpp( 4, 1,20,3)/
     x 1.0320680d+00, 6.9614793d-04, 4.2018486d-19 /
      data fpp( 4, 1,21,1),fpp( 4, 1,21,2),fpp( 4, 1,21,3)/
     x 1.0320680d+00, 6.9614793d-04,-4.3501146d-19 /
      data fpp( 4, 1,22,1),fpp( 4, 1,22,2),fpp( 4, 1,22,3)/
     x 1.0320680d+00, 2.8891759d-04, 1.3260546d-18 /
      data fpp( 4, 1,23,1),fpp( 4, 1,23,2),fpp( 4, 1,23,3)/
     x 1.0320680d+00, 6.6535771d-04, 9.2257749d-19 /
      data fpp( 4, 2, 1,1),fpp( 4, 2, 1,2),fpp( 4, 2, 1,3)/
     x 4.5791691d-01, 1.7132283d-04,-1.1105154d-05 /
      data fpp( 4, 2, 2,1),fpp( 4, 2, 2,2),fpp( 4, 2, 2,3)/
     x 4.3118059d-01,-8.9299361d-05,-9.9691912d-06 /
      data fpp( 4, 2, 3,1),fpp( 4, 2, 3,2),fpp( 4, 2, 3,3)/
     x 4.6502873d-01, 1.3870168d-04,-8.1120808d-06 /
      data fpp( 4, 2, 4,1),fpp( 4, 2, 4,2),fpp( 4, 2, 4,3)/
     x 4.6502873d-01, 1.3870168d-04,-7.1021619d-06 /
      data fpp( 4, 2, 5,1),fpp( 4, 2, 5,2),fpp( 4, 2, 5,3)/
     x 4.3118059d-01,-8.9299361d-05,-1.4008867d-05 /
      data fpp( 4, 2, 6,1),fpp( 4, 2, 6,2),fpp( 4, 2, 6,3)/
     x 4.5791691d-01, 1.7132283d-04, 4.0436295d-06 /
      data fpp( 4, 2, 7,1),fpp( 4, 2, 7,2),fpp( 4, 2, 7,3)/
     x 4.9154394d-01, 3.6976021d-04, 5.8143489d-06 /
      data fpp( 4, 2, 8,1),fpp( 4, 2, 8,2),fpp( 4, 2, 8,3)/
     x 4.3770131d-01,-2.3888389d-05,-1.5610251d-06 /
      data fpp( 4, 2, 9,1),fpp( 4, 2, 9,2),fpp( 4, 2, 9,3)/
     x 4.6950070d-01,-3.9173377d-04, 5.6197515d-06 /
      data fpp( 4, 2,10,1),fpp( 4, 2,10,2),fpp( 4, 2,10,3)/
     x 5.4874333d-01,-6.2005290d-04, 4.0480189d-06 /
      data fpp( 4, 2,11,1),fpp( 4, 2,11,2),fpp( 4, 2,11,3)/
     x 5.2098316d-01,-7.4730967d-04, 5.2481728d-06 /
      data fpp( 4, 2,12,1),fpp( 4, 2,12,2),fpp( 4, 2,12,3)/
     x 5.2608388d-01,-7.8806700d-04, 2.8172900d-06 /
      data fpp( 4, 2,13,1),fpp( 4, 2,13,2),fpp( 4, 2,13,3)/
     x 5.2332720d-01,-7.4564886d-04, 1.1814667d-05 /
      data fpp( 4, 2,14,1),fpp( 4, 2,14,2),fpp( 4, 2,14,3)/
     x 3.7839786d-01,-6.2225409d-04,-6.6179583d-06 /
      data fpp( 4, 2,15,1),fpp( 4, 2,15,2),fpp( 4, 2,15,3)/
     x 4.6587269d-01,-3.8450066d-04, 1.1033166d-05 /
      data fpp( 4, 2,16,1),fpp( 4, 2,16,2),fpp( 4, 2,16,3)/
     x 4.2136649d-01,-1.1857322d-05, 3.0032940d-06 /
      data fpp( 4, 2,17,1),fpp( 4, 2,17,2),fpp( 4, 2,17,3)/
     x 3.8430504d-01, 3.5785859d-04,-2.8803420d-06 /
      data fpp( 4, 2,18,1),fpp( 4, 2,18,2),fpp( 4, 2,18,3)/
     x 4.4586682d-01, 1.6811558d-04, 4.4200739d-06 /
      data fpp( 4, 2,19,1),fpp( 4, 2,19,2),fpp( 4, 2,19,3)/
     x 4.6892414d-01,-8.0782180d-05,-6.3879538d-06 /
      data fpp( 4, 2,20,1),fpp( 4, 2,20,2),fpp( 4, 2,20,3)/
     x 4.6682574d-01, 1.4338214d-04,-1.0182259d-05 /
      data fpp( 4, 2,21,1),fpp( 4, 2,21,2),fpp( 4, 2,21,3)/
     x 4.6682574d-01, 1.4338214d-04,-1.0611247d-05 /
      data fpp( 4, 2,22,1),fpp( 4, 2,22,2),fpp( 4, 2,22,3)/
     x 4.6892414d-01,-8.0782180d-05,-4.6720009d-06 /
      data fpp( 4, 2,23,1),fpp( 4, 2,23,2),fpp( 4, 2,23,3)/
     x 4.4586682d-01, 1.6811558d-04,-2.0147496d-06 /
      data fpp( 4, 3, 1,1),fpp( 4, 3, 1,2),fpp( 4, 3, 1,3)/
     x 9.2455329d-02,-1.2232709d-03, 1.6695365d-04 /
      data fpp( 4, 3, 2,1),fpp( 4, 3, 2,2),fpp( 4, 3, 2,3)/
     x 1.2704561d-01, 7.7703276d-04, 6.7257191d-05 /
      data fpp( 4, 3, 3,1),fpp( 4, 3, 3,2),fpp( 4, 3, 3,3)/
     x 3.1631467d-01, 4.0893761d-04,-1.4774842d-04 /
      data fpp( 4, 3, 4,1),fpp( 4, 3, 4,2),fpp( 4, 3, 4,3)/
     x 3.1631467d-01, 4.0893761d-04,-1.4535034d-04 /
      data fpp( 4, 3, 5,1),fpp( 4, 3, 5,2),fpp( 4, 3, 5,3)/
     x 1.2704561d-01, 7.7703276d-04, 5.7664857d-05 /
      data fpp( 4, 3, 6,1),fpp( 4, 3, 6,2),fpp( 4, 3, 6,3)/
     x 9.2455329d-02,-1.2232709d-03, 2.0292491d-04 /
      data fpp( 4, 3, 7,1),fpp( 4, 3, 7,2),fpp( 4, 3, 7,3)/
     x-2.8032682d+00,-2.5851072d-03,-5.2885848d-04 /
      data fpp( 4, 3, 8,1),fpp( 4, 3, 8,2),fpp( 4, 3, 8,3)/
     x 8.1531634d-01,-2.0680226d-03, 1.8712503d-04 /
      data fpp( 4, 3, 9,1),fpp( 4, 3, 9,2),fpp( 4, 3, 9,3)/
     x 2.2720706d+00,-1.4274373d-03, 1.0437037d-04 /
      data fpp( 4, 3,10,1),fpp( 4, 3,10,2),fpp( 4, 3,10,3)/
     x 1.4989961d+00,-1.0388683d-03, 8.5207491d-05 /
      data fpp( 4, 3,11,1),fpp( 4, 3,11,2),fpp( 4, 3,11,3)/
     x 1.0197011d+00,-8.2684567d-04, 7.4363665d-05 /
      data fpp( 4, 3,12,1),fpp( 4, 3,12,2),fpp( 4, 3,12,3)/
     x 6.9061254d-01,-7.6225148d-04, 7.3019851d-05 /
      data fpp( 4, 3,13,1),fpp( 4, 3,13,2),fpp( 4, 3,13,3)/
     x 1.0360887d+00,-8.3783799d-04, 7.5858933d-05 /
      data fpp( 4, 3,14,1),fpp( 4, 3,14,2),fpp( 4, 3,14,3)/
     x 1.5115248d+00,-1.0539582d-03, 8.4026416d-05 /
      data fpp( 4, 3,15,1),fpp( 4, 3,15,2),fpp( 4, 3,15,3)/
     x 2.3018361d+00,-1.4585177d-03, 1.1412740d-04 /
      data fpp( 4, 3,16,1),fpp( 4, 3,16,2),fpp( 4, 3,16,3)/
     x 6.0701466d-01,-2.1078884d-03, 1.5818197d-04 /
      data fpp( 4, 3,17,1),fpp( 4, 3,17,2),fpp( 4, 3,17,3)/
     x-2.3952288d+00,-2.5631936d-03,-5.0528929d-04 /
      data fpp( 4, 3,18,1),fpp( 4, 3,18,2),fpp( 4, 3,18,3)/
     x 9.2050209d-02,-1.2049260d-03, 1.9666119d-04 /
      data fpp( 4, 3,19,1),fpp( 4, 3,19,2),fpp( 4, 3,19,3)/
     x 1.2607019d-01, 7.5272913d-04, 5.8964533d-05 /
      data fpp( 4, 3,20,1),fpp( 4, 3,20,2),fpp( 4, 3,20,3)/
     x 3.1887031d-01, 3.8370751d-04,-1.4590532d-04 /
      data fpp( 4, 3,21,1),fpp( 4, 3,21,2),fpp( 4, 3,21,3)/
     x 3.1887031d-01, 3.8370751d-04,-1.4790330d-04 /
      data fpp( 4, 3,22,1),fpp( 4, 3,22,2),fpp( 4, 3,22,3)/
     x 1.2607019d-01, 7.5272913d-04, 6.6956443d-05 /
      data fpp( 4, 3,23,1),fpp( 4, 3,23,2),fpp( 4, 3,23,3)/
     x 9.2050209d-02,-1.2049260d-03, 1.6669153d-04 /
      data fpp( 4, 4, 1,1),fpp( 4, 4, 1,2),fpp( 4, 4, 1,3)/
     x 1.2687193d-01, 4.6646485d-04,-1.2383537d-03 /
      data fpp( 4, 4, 2,1),fpp( 4, 4, 2,2),fpp( 4, 4, 2,3)/
     x 3.9680817d-01,-2.6977417d-03,-8.5018654d-04 /
      data fpp( 4, 4, 3,1),fpp( 4, 4, 3,2),fpp( 4, 4, 3,3)/
     x 2.0981930d-01,-2.2487581d-03,-9.7120120d-05 /
      data fpp( 4, 4, 4,1),fpp( 4, 4, 4,2),fpp( 4, 4, 4,3)/
     x 2.0981930d-01,-2.2487581d-03, 4.0640628d-05 /
      data fpp( 4, 4, 5,1),fpp( 4, 4, 5,2),fpp( 4, 4, 5,3)/
     x 3.9680817d-01,-2.6977417d-03,-1.4012295d-03 /
      data fpp( 4, 4, 6,1),fpp( 4, 4, 6,2),fpp( 4, 4, 6,3)/
     x 1.2687193d-01, 4.6646485d-04, 8.2805748d-04 /
      data fpp( 4, 4, 7,1),fpp( 4, 4, 7,2),fpp( 4, 4, 7,3)/
     x 1.9519428d-01, 2.5279987d-03, 1.5104361d-04 /
      data fpp( 4, 4, 8,1),fpp( 4, 4, 8,2),fpp( 4, 4, 8,3)/
     x 2.2152624d-01, 2.7246789d-03, 1.5000407d-04 /
      data fpp( 4, 4, 9,1),fpp( 4, 4, 9,2),fpp( 4, 4, 9,3)/
     x 1.1965432d-01, 2.5867130d-03, 7.6934095d-05 /
      data fpp( 4, 4,10,1),fpp( 4, 4,10,2),fpp( 4, 4,10,3)/
     x 2.6244890d-01, 2.4956523d-03, 7.5287548d-05 /
      data fpp( 4, 4,11,1),fpp( 4, 4,11,2),fpp( 4, 4,11,3)/
     x 2.8835595d-01, 2.4436923d-03, 6.7961713d-05 /
      data fpp( 4, 4,12,1),fpp( 4, 4,12,2),fpp( 4, 4,12,3)/
     x 2.8237556d-01, 2.4269829d-03, 6.8407601d-05 /
      data fpp( 4, 4,13,1),fpp( 4, 4,13,2),fpp( 4, 4,13,3)/
     x 2.9770339d-01, 2.4436888d-03, 7.0547884d-05 /
      data fpp( 4, 4,14,1),fpp( 4, 4,14,2),fpp( 4, 4,14,3)/
     x 2.7498436d-01, 2.4913788d-03, 7.6732862d-05 /
      data fpp( 4, 4,15,1),fpp( 4, 4,15,2),fpp( 4, 4,15,3)/
     x 1.2480528d-01, 2.5826734d-03, 8.2534668d-05 /
      data fpp( 4, 4,16,1),fpp( 4, 4,16,2),fpp( 4, 4,16,3)/
     x 2.2444399d-01, 2.7202568d-03, 1.5198047d-04 /
      data fpp( 4, 4,17,1),fpp( 4, 4,17,2),fpp( 4, 4,17,3)/
     x 2.3485574d-01, 2.4831037d-03, 1.7110746d-04 /
      data fpp( 4, 4,18,1),fpp( 4, 4,18,2),fpp( 4, 4,18,3)/
     x 1.3162215d-01, 4.8733048d-04, 7.7127169d-04 /
      data fpp( 4, 4,19,1),fpp( 4, 4,19,2),fpp( 4, 4,19,3)/
     x 2.3902568d-01,-2.6249983d-03,-1.3621262d-03 /
      data fpp( 4, 4,20,1),fpp( 4, 4,20,2),fpp( 4, 4,20,3)/
     x 2.1118705d-01,-2.1517862d-03, 3.3671138d-05 /
      data fpp( 4, 4,21,1),fpp( 4, 4,21,2),fpp( 4, 4,21,3)/
     x 2.1118705d-01,-2.1517862d-03,-9.8517311d-05 /
      data fpp( 4, 4,22,1),fpp( 4, 4,22,2),fpp( 4, 4,22,3)/
     x 2.3902568d-01,-2.6249983d-03,-8.3337241d-04 /
      data fpp( 4, 4,23,1),fpp( 4, 4,23,2),fpp( 4, 4,23,3)/
     x 1.3162215d-01, 4.8733048d-04,-1.2115550d-03 /
      data fpp( 4, 5, 1,1),fpp( 4, 5, 1,2),fpp( 4, 5, 1,3)/
     x 7.4933749d-02, 1.2445015d-03, 1.8213649d-04 /
      data fpp( 4, 5, 2,1),fpp( 4, 5, 2,2),fpp( 4, 5, 2,3)/
     x 5.6047272d-02, 2.7666960d-03, 3.2868513d-05 /
      data fpp( 4, 5, 3,1),fpp( 4, 5, 3,2),fpp( 4, 5, 3,3)/
     x-1.4770027d-02, 1.9948729d-03,-2.8394054d-04 /
      data fpp( 4, 5, 4,1),fpp( 4, 5, 4,2),fpp( 4, 5, 4,3)/
     x-1.4770027d-02, 1.9948729d-03,-2.8927962d-04 /
      data fpp( 4, 5, 5,1),fpp( 4, 5, 5,2),fpp( 4, 5, 5,3)/
     x 5.6047272d-02, 2.7666960d-03, 5.4224826d-05 /
      data fpp( 4, 5, 6,1),fpp( 4, 5, 6,2),fpp( 4, 5, 6,3)/
     x 7.4933749d-02, 1.2445015d-03, 1.0205032d-04 /
      data fpp( 4, 5, 7,1),fpp( 4, 5, 7,2),fpp( 4, 5, 7,3)/
     x 5.7661444d-02, 1.7677653d-04, 3.4018947d-06 /
      data fpp( 4, 5, 8,1),fpp( 4, 5, 8,2),fpp( 4, 5, 8,3)/
     x 5.3175107d-02,-2.1229113d-05, 6.3424101d-05 /
      data fpp( 4, 5, 9,1),fpp( 4, 5, 9,2),fpp( 4, 5, 9,3)/
     x 7.7873972d-02,-2.6706834d-05, 5.2321700d-05 /
      data fpp( 4, 5,10,1),fpp( 4, 5,10,2),fpp( 4, 5,10,3)/
     x 8.2287393d-02,-1.1786842d-05, 5.9533098d-05 /
      data fpp( 4, 5,11,1),fpp( 4, 5,11,2),fpp( 4, 5,11,3)/
     x 8.7821174d-02, 8.3629450d-07, 5.9633907d-05 /
      data fpp( 4, 5,12,1),fpp( 4, 5,12,2),fpp( 4, 5,12,3)/
     x 8.6313889d-02, 3.2957283d-06, 6.0743274d-05 /
      data fpp( 4, 5,13,1),fpp( 4, 5,13,2),fpp( 4, 5,13,3)/
     x 8.7906991d-02,-5.4672474d-06, 6.1628997d-05 /
      data fpp( 4, 5,14,1),fpp( 4, 5,14,2),fpp( 4, 5,14,3)/
     x 8.3875673d-02,-2.2197110d-05, 6.2358736d-05 /
      data fpp( 4, 5,15,1),fpp( 4, 5,15,2),fpp( 4, 5,15,3)/
     x 7.8845233d-02,-4.3511767d-05, 6.4266057d-05 /
      data fpp( 4, 5,16,1),fpp( 4, 5,16,2),fpp( 4, 5,16,3)/
     x 5.2644005d-01,-4.5634876d-05, 5.9099035d-05 /
      data fpp( 4, 5,17,1),fpp( 4, 5,17,2),fpp( 4, 5,17,3)/
     x 6.0609021d-02, 1.5791682d-04, 8.1693804d-05 /
      data fpp( 4, 5,18,1),fpp( 4, 5,18,2),fpp( 4, 5,18,3)/
     x-3.0301660d-02, 1.1075461d-03, 2.0973749d-05 /
      data fpp( 4, 5,19,1),fpp( 4, 5,19,2),fpp( 4, 5,19,3)/
     x 1.8393657d-02, 2.7533942d-03, 1.1161120d-04 /
      data fpp( 4, 5,20,1),fpp( 4, 5,20,2),fpp( 4, 5,20,3)/
     x-1.5046620d-02, 2.0985832d-03,-3.2632855d-04 /
      data fpp( 4, 5,21,1),fpp( 4, 5,21,2),fpp( 4, 5,21,3)/
     x-1.5046620d-02, 2.0985832d-03,-3.1232494d-04 /
      data fpp( 4, 5,22,1),fpp( 4, 5,22,2),fpp( 4, 5,22,3)/
     x 1.8393657d-02, 2.7533942d-03, 5.5596770d-05 /
      data fpp( 4, 5,23,1),fpp( 4, 5,23,2),fpp( 4, 5,23,3)/
     x-3.0301660d-02, 1.1075461d-03, 2.3102787d-04 /
      data fpp( 4, 6, 1,1),fpp( 4, 6, 1,2),fpp( 4, 6, 1,3)/
     x 4.7885167d-03,-2.6565498d-04,-1.1303086d-05 /
      data fpp( 4, 6, 2,1),fpp( 4, 6, 2,2),fpp( 4, 6, 2,3)/
     x 2.8548895d-02,-3.8172826d-04,-4.1293327d-05 /
      data fpp( 4, 6, 3,1),fpp( 4, 6, 3,2),fpp( 4, 6, 3,3)/
     x 2.7684518d-02,-1.1095497d-05,-1.0413760d-04 /
      data fpp( 4, 6, 4,1),fpp( 4, 6, 4,2),fpp( 4, 6, 4,3)/
     x 2.7684518d-02,-1.1095497d-05,-1.0662352d-04 /
      data fpp( 4, 6, 5,1),fpp( 4, 6, 5,2),fpp( 4, 6, 5,3)/
     x 2.8548895d-02,-3.8172826d-04,-3.1349656d-05 /
      data fpp( 4, 6, 6,1),fpp( 4, 6, 6,2),fpp( 4, 6, 6,3)/
     x 4.7885167d-03,-2.6565498d-04,-4.8591854d-05 /
      data fpp( 4, 6, 7,1),fpp( 4, 6, 7,2),fpp( 4, 6, 7,3)/
     x 1.2719964d-02, 6.8129218d-05, 2.8245070d-05 /
      data fpp( 4, 6, 8,1),fpp( 4, 6, 8,2),fpp( 4, 6, 8,3)/
     x 2.0108248d-02, 1.0698952d-04, 3.0639572d-05 /
      data fpp( 4, 6, 9,1),fpp( 4, 6, 9,2),fpp( 4, 6, 9,3)/
     x 2.5813218d-02, 1.1366830d-04, 4.3326642d-05 /
      data fpp( 4, 6,10,1),fpp( 4, 6,10,2),fpp( 4, 6,10,3)/
     x 2.9319690d-02, 1.1143707d-04, 4.7099861d-05 /
      data fpp( 4, 6,11,1),fpp( 4, 6,11,2),fpp( 4, 6,11,3)/
     x 3.1631450d-02, 1.0682648d-04, 4.9937915d-05 /
      data fpp( 4, 6,12,1),fpp( 4, 6,12,2),fpp( 4, 6,12,3)/
     x 3.3546320d-02, 1.0366015d-04, 5.1270480d-05 /
      data fpp( 4, 6,13,1),fpp( 4, 6,13,2),fpp( 4, 6,13,3)/
     x 3.3264867d-02, 1.0274618d-04, 5.2090164d-05 /
      data fpp( 4, 6,14,1),fpp( 4, 6,14,2),fpp( 4, 6,14,3)/
     x 4.0487145d-02, 1.0302162d-04, 5.2578862d-05 /
      data fpp( 4, 6,15,1),fpp( 4, 6,15,2),fpp( 4, 6,15,3)/
     x 2.9248709d-02, 1.0264371d-04, 5.2852388d-05 /
      data fpp( 4, 6,16,1),fpp( 4, 6,16,2),fpp( 4, 6,16,3)/
     x 6.5280592d-01, 9.4686692d-05, 4.9679586d-05 /
      data fpp( 4, 6,17,1),fpp( 4, 6,17,2),fpp( 4, 6,17,3)/
     x 1.8226020d-02, 3.3933021d-05, 4.6743269d-05 /
      data fpp( 4, 6,18,1),fpp( 4, 6,18,2),fpp( 4, 6,18,3)/
     x 8.9855009d-03,-2.0353688d-04, 1.8335340d-05 /
      data fpp( 4, 6,19,1),fpp( 4, 6,19,2),fpp( 4, 6,19,3)/
     x-3.9456297d-03,-6.0699264d-04, 4.2581372d-05 /
      data fpp( 4, 6,20,1),fpp( 4, 6,20,2),fpp( 4, 6,20,3)/
     x 8.3453465d-02,-3.4953270d-04,-2.1909883d-04 /
      data fpp( 4, 6,21,1),fpp( 4, 6,21,2),fpp( 4, 6,21,3)/
     x 8.3453465d-02,-3.4953270d-04,-2.1215120d-04 /
      data fpp( 4, 6,22,1),fpp( 4, 6,22,2),fpp( 4, 6,22,3)/
     x-3.9456297d-03,-6.0699264d-04, 1.4790842d-05 /
      data fpp( 4, 6,23,1),fpp( 4, 6,23,2),fpp( 4, 6,23,3)/
     x 8.9855009d-03,-2.0353688d-04, 1.2254983d-04 /
      data fpp( 4, 7, 1,1),fpp( 4, 7, 1,2),fpp( 4, 7, 1,3)/
     x-3.8808420d-02, 1.0079037d-04,-2.2363163d-04 /
      data fpp( 4, 7, 2,1),fpp( 4, 7, 2,2),fpp( 4, 7, 2,3)/
     x-9.9944168d-01,-1.5141296d-04,-1.4834624d-04 /
      data fpp( 4, 7, 3,1),fpp( 4, 7, 3,2),fpp( 4, 7, 3,3)/
     x 1.8046261d+00,-2.8000692d-04, 2.5345847d-06 /
      data fpp( 4, 7, 4,1),fpp( 4, 7, 4,2),fpp( 4, 7, 4,3)/
     x 1.8046261d+00,-2.8000692d-04, 2.0813365d-05 /
      data fpp( 4, 7, 5,1),fpp( 4, 7, 5,2),fpp( 4, 7, 5,3)/
     x-9.9944168d-01,-1.5141296d-04,-2.2146136d-04 /
      data fpp( 4, 7, 6,1),fpp( 4, 7, 6,2),fpp( 4, 7, 6,3)/
     x-3.8808420d-02, 1.0079037d-04, 5.0550077d-05 /
      data fpp( 4, 7, 7,1),fpp( 4, 7, 7,2),fpp( 4, 7, 7,3)/
     x-9.7429859d-03,-1.4504540d-04,-1.4236946d-05 /
      data fpp( 4, 7, 8,1),fpp( 4, 7, 8,2),fpp( 4, 7, 8,3)/
     x-1.5245977d-03,-8.0622948d-05, 1.7653709d-05 /
      data fpp( 4, 7, 9,1),fpp( 4, 7, 9,2),fpp( 4, 7, 9,3)/
     x 1.0344689d-02,-7.8052362d-05, 2.4412111d-05 /
      data fpp( 4, 7,10,1),fpp( 4, 7,10,2),fpp( 4, 7,10,3)/
     x 6.7508841d-03,-8.0237437d-05, 3.4547848d-05 /
      data fpp( 4, 7,11,1),fpp( 4, 7,11,2),fpp( 4, 7,11,3)/
     x 8.9628199d-03,-8.1996208d-05, 3.9248498d-05 /
      data fpp( 4, 7,12,1),fpp( 4, 7,12,2),fpp( 4, 7,12,3)/
     x 1.3302114d-02,-8.3550321d-05, 4.1708161d-05 /
      data fpp( 4, 7,13,1),fpp( 4, 7,13,2),fpp( 4, 7,13,3)/
     x 1.1698079d-02,-8.4541477d-05, 4.2252858d-05 /
      data fpp( 4, 7,14,1),fpp( 4, 7,14,2),fpp( 4, 7,14,3)/
     x 1.0980147d-02,-8.4753356d-05, 4.1652407d-05 /
      data fpp( 4, 7,15,1),fpp( 4, 7,15,2),fpp( 4, 7,15,3)/
     x 1.7128243d-02,-8.3707061d-05, 4.0383514d-05 /
      data fpp( 4, 7,16,1),fpp( 4, 7,16,2),fpp( 4, 7,16,3)/
     x 9.2409599d-03,-8.0205891d-05, 3.6957537d-05 /
      data fpp( 4, 7,17,1),fpp( 4, 7,17,2),fpp( 4, 7,17,3)/
     x 7.2043085d-03,-6.3860909d-05, 3.3390338d-05 /
      data fpp( 4, 7,18,1),fpp( 4, 7,18,2),fpp( 4, 7,18,3)/
     x 2.3662760d-02,-4.6845759d-06, 1.4653110d-05 /
      data fpp( 4, 7,19,1),fpp( 4, 7,19,2),fpp( 4, 7,19,3)/
     x 2.3702093d-03, 8.8888331d-05, 2.2801221d-05 /
      data fpp( 4, 7,20,1),fpp( 4, 7,20,2),fpp( 4, 7,20,3)/
     x 5.2152298d-02,-6.7684392d-06,-1.5404999d-04 /
      data fpp( 4, 7,21,1),fpp( 4, 7,21,2),fpp( 4, 7,21,3)/
     x 5.2152298d-02,-6.7684392d-06,-1.4974563d-04 /
      data fpp( 4, 7,22,1),fpp( 4, 7,22,2),fpp( 4, 7,22,3)/
     x 2.3702093d-03, 8.8888331d-05, 5.5837505d-06 /
      data fpp( 4, 7,23,1),fpp( 4, 7,23,2),fpp( 4, 7,23,3)/
     x 2.3662760d-02,-4.6845759d-06, 7.9218625d-05 /
      data fpp( 4, 8, 1,1),fpp( 4, 8, 1,2),fpp( 4, 8, 1,3)/
     x 9.0876173d-01,-4.0820251d-04,-1.3577144d-04 /
      data fpp( 4, 8, 2,1),fpp( 4, 8, 2,2),fpp( 4, 8, 2,3)/
     x-5.4302237d-02,-3.3392189d-04,-6.3185614d-05 /
      data fpp( 4, 8, 3,1),fpp( 4, 8, 3,2),fpp( 4, 8, 3,3)/
     x 1.4555733d-02,-1.8512083d-04, 9.5827899d-05 /
      data fpp( 4, 8, 4,1),fpp( 4, 8, 4,2),fpp( 4, 8, 4,3)/
     x 1.4555733d-02,-1.8512083d-04, 8.9751110d-05 /
      data fpp( 4, 8, 5,1),fpp( 4, 8, 5,2),fpp( 4, 8, 5,3)/
     x-5.4302237d-02,-3.3392189d-04,-3.8878457d-05 /
      data fpp( 4, 8, 6,1),fpp( 4, 8, 6,2),fpp( 4, 8, 6,3)/
     x 9.0876173d-01,-4.0820251d-04,-2.2692328d-04 /
      data fpp( 4, 8, 7,1),fpp( 4, 8, 7,2),fpp( 4, 8, 7,3)/
     x-2.3542216d-02, 2.5591838d-04, 4.1003578d-05 /
      data fpp( 4, 8, 8,1),fpp( 4, 8, 8,2),fpp( 4, 8, 8,3)/
     x-1.4044989d-02,-3.9551723d-05,-2.3089032d-05 /
      data fpp( 4, 8, 9,1),fpp( 4, 8, 9,2),fpp( 4, 8, 9,3)/
     x 2.3039932d-02,-6.3082849d-05, 1.1152551d-05 /
      data fpp( 4, 8,10,1),fpp( 4, 8,10,2),fpp( 4, 8,10,3)/
     x-7.2684613d-03,-6.5689323d-05, 2.0124828d-05 /
      data fpp( 4, 8,11,1),fpp( 4, 8,11,2),fpp( 4, 8,11,3)/
     x 2.2438942d-02,-6.8041648d-05, 2.9968138d-05 /
      data fpp( 4, 8,12,1),fpp( 4, 8,12,2),fpp( 4, 8,12,3)/
     x 2.2847093d-02,-6.7868865d-05, 3.3168619d-05 /
      data fpp( 4, 8,13,1),fpp( 4, 8,13,2),fpp( 4, 8,13,3)/
     x 2.4124827d-02,-6.5570274d-05, 3.3545387d-05 /
      data fpp( 4, 8,14,1),fpp( 4, 8,14,2),fpp( 4, 8,14,3)/
     x 5.0843313d-04,-6.0744193d-05, 3.2017833d-05 /
      data fpp( 4, 8,15,1),fpp( 4, 8,15,2),fpp( 4, 8,15,3)/
     x 3.2316313d-02,-5.2755463d-05, 2.9159280d-05 /
      data fpp( 4, 8,16,1),fpp( 4, 8,16,2),fpp( 4, 8,16,3)/
     x 3.3235202d-03,-4.0065127d-05, 2.4907045d-05 /
      data fpp( 4, 8,17,1),fpp( 4, 8,17,2),fpp( 4, 8,17,3)/
     x 4.6140356d-02,-2.2569386d-05, 1.9490538d-05 /
      data fpp( 4, 8,18,1),fpp( 4, 8,18,2),fpp( 4, 8,18,3)/
     x 5.6757253d-02,-4.7468152d-06, 7.4228017d-06 /
      data fpp( 4, 8,19,1),fpp( 4, 8,19,2),fpp( 4, 8,19,3)/
     x 7.4787744d-02, 2.1015321d-05,-2.6997450d-06 /
      data fpp( 4, 8,20,1),fpp( 4, 8,20,2),fpp( 4, 8,20,3)/
     x 1.1642018d-01, 1.2037045d-04,-8.4979822d-05 /
      data fpp( 4, 8,21,1),fpp( 4, 8,21,2),fpp( 4, 8,21,3)/
     x 1.1642018d-01, 1.2037045d-04,-8.3637662d-05 /
      data fpp( 4, 8,22,1),fpp( 4, 8,22,2),fpp( 4, 8,22,3)/
     x 7.4787744d-02, 2.1015321d-05,-8.0683822d-06 /
      data fpp( 4, 8,23,1),fpp( 4, 8,23,2),fpp( 4, 8,23,3)/
     x 5.6757253d-02,-4.7468152d-06, 2.7555191d-05 /
      data fpp( 4, 9, 1,1),fpp( 4, 9, 1,2),fpp( 4, 9, 1,3)/
     x-1.7840144d-02,-2.0709832d-04, 5.1990331d-05 /
      data fpp( 4, 9, 2,1),fpp( 4, 9, 2,2),fpp( 4, 9, 2,3)/
     x 1.6820659d-02,-2.6147470d-05, 7.3915339d-05 /
      data fpp( 4, 9, 3,1),fpp( 4, 9, 3,2),fpp( 4, 9, 3,3)/
     x 2.8250680d-02,-3.3325743d-05, 1.1502032d-04 /
      data fpp( 4, 9, 4,1),fpp( 4, 9, 4,2),fpp( 4, 9, 4,3)/
     x 2.8250680d-02,-3.3325743d-05, 1.2530539d-04 /
      data fpp( 4, 9, 5,1),fpp( 4, 9, 5,2),fpp( 4, 9, 5,3)/
     x 1.6820659d-02,-2.6147470d-05, 3.2775059d-05 /
      data fpp( 4, 9, 6,1),fpp( 4, 9, 6,2),fpp( 4, 9, 6,3)/
     x-1.7840144d-02,-2.0709832d-04, 2.0626638d-04 /
      data fpp( 4, 9, 7,1),fpp( 4, 9, 7,2),fpp( 4, 9, 7,3)/
     x-1.7757729d+00,-8.7001213d-04,-6.6187457d-04 /
      data fpp( 4, 9, 8,1),fpp( 4, 9, 8,2),fpp( 4, 9, 8,3)/
     x 1.2264443d-01,-6.4494160d-05, 1.9830591d-04 /
      data fpp( 4, 9, 9,1),fpp( 4, 9, 9,2),fpp( 4, 9, 9,3)/
     x 5.3440144d-02,-5.3322240d-05,-6.0981072d-05 /
      data fpp( 4, 9,10,1),fpp( 4, 9,10,2),fpp( 4, 9,10,3)/
     x-1.3277463d-02,-7.3549271d-05, 2.6604376d-05 /
      data fpp( 4, 9,11,1),fpp( 4, 9,11,2),fpp( 4, 9,11,3)/
     x 5.2148044d-02,-7.3157200d-05, 1.8013567d-05 /
      data fpp( 4, 9,12,1),fpp( 4, 9,12,2),fpp( 4, 9,12,3)/
     x 5.0972855d-02,-6.9870218d-05, 2.7623357d-05 /
      data fpp( 4, 9,13,1),fpp( 4, 9,13,2),fpp( 4, 9,13,3)/
     x 5.1844451d-02,-6.4573426d-05, 2.6611003d-05 /
      data fpp( 4, 9,14,1),fpp( 4, 9,14,2),fpp( 4, 9,14,3)/
     x-4.3272902d-03,-5.7397871d-05, 2.5064629d-05 /
      data fpp( 4, 9,15,1),fpp( 4, 9,15,2),fpp( 4, 9,15,3)/
     x 5.6864427d-02,-4.7559087d-05, 2.2008482d-05 /
      data fpp( 4, 9,16,1),fpp( 4, 9,16,2),fpp( 4, 9,16,3)/
     x-2.4191362d-04,-3.4339600d-05, 1.8523444d-05 /
      data fpp( 4, 9,17,1),fpp( 4, 9,17,2),fpp( 4, 9,17,3)/
     x 6.3481087d-02,-1.7407546d-05, 1.4627744d-05 /
      data fpp( 4, 9,18,1),fpp( 4, 9,18,2),fpp( 4, 9,18,3)/
     x 6.4573596d-02, 4.4598368d-06, 7.4515818d-06 /
      data fpp( 4, 9,19,1),fpp( 4, 9,19,2),fpp( 4, 9,19,3)/
     x 6.6896825d-02, 2.9088385d-05, 2.6419290d-06 /
      data fpp( 4, 9,20,1),fpp( 4, 9,20,2),fpp( 4, 9,20,3)/
     x 7.8849788d-02, 3.6066632d-05,-5.9047298d-05 /
      data fpp( 4, 9,21,1),fpp( 4, 9,21,2),fpp( 4, 9,21,3)/
     x 7.8849788d-02, 3.6066632d-05,-5.7909071d-05 /
      data fpp( 4, 9,22,1),fpp( 4, 9,22,2),fpp( 4, 9,22,3)/
     x 6.6896825d-02, 2.9088385d-05,-1.9109798d-06 /
      data fpp( 4, 9,23,1),fpp( 4, 9,23,2),fpp( 4, 9,23,3)/
     x 6.4573596d-02, 4.4598368d-06, 2.4524990d-05 /
      data fpp( 4,10, 1,1),fpp( 4,10, 1,2),fpp( 4,10, 1,3)/
     x 1.7467877d-02, 4.9831802d-05, 8.4185974d-05 /
      data fpp( 4,10, 2,1),fpp( 4,10, 2,2),fpp( 4,10, 2,3)/
     x 6.5476992d-02, 6.4765771d-05, 9.8301551d-05 /
      data fpp( 4,10, 3,1),fpp( 4,10, 3,2),fpp( 4,10, 3,3)/
     x 7.9811025d-02, 1.4749581d-04, 1.3043782d-04 /
      data fpp( 4,10, 4,1),fpp( 4,10, 4,2),fpp( 4,10, 4,3)/
     x 7.9811025d-02, 1.4749581d-04, 1.2713276d-04 /
      data fpp( 4,10, 5,1),fpp( 4,10, 5,2),fpp( 4,10, 5,3)/
     x 6.5476992d-02, 6.4765771d-05, 1.1152179d-04 /
      data fpp( 4,10, 6,1),fpp( 4,10, 6,2),fpp( 4,10, 6,3)/
     x 1.7467877d-02, 4.9831802d-05, 3.4610097d-05 /
      data fpp( 4,10, 7,1),fpp( 4,10, 7,2),fpp( 4,10, 7,3)/
     x-3.9305676d-02, 1.9818613d-04, 2.1375828d-05 /
      data fpp( 4,10, 8,1),fpp( 4,10, 8,2),fpp( 4,10, 8,3)/
     x-2.6428970d-01,-4.8766164d-04,-4.4003341d-04 /
      data fpp( 4,10, 9,1),fpp( 4,10, 9,2),fpp( 4,10, 9,3)/
     x 1.4424383d-01,-1.7460619d-04, 1.3151802d-05 /
      data fpp( 4,10,10,1),fpp( 4,10,10,2),fpp( 4,10,10,3)/
     x-4.3062670d-03,-7.3337594d-05,-8.7058006d-06 /
      data fpp( 4,10,11,1),fpp( 4,10,11,2),fpp( 4,10,11,3)/
     x 4.4518045d-01,-6.2395551d-05, 1.9355401d-05 /
      data fpp( 4,10,12,1),fpp( 4,10,12,2),fpp( 4,10,12,3)/
     x 4.5880716d-01,-5.5544261d-05, 2.0696198d-05 /
      data fpp( 4,10,13,1),fpp( 4,10,13,2),fpp( 4,10,13,3)/
     x-5.9333688d-03,-4.8502021d-05, 2.2263806d-05 /
      data fpp( 4,10,14,1),fpp( 4,10,14,2),fpp( 4,10,14,3)/
     x 4.1757693d-01,-4.0198324d-05, 2.0448578d-05 /
      data fpp( 4,10,15,1),fpp( 4,10,15,2),fpp( 4,10,15,3)/
     x-2.8846643d-03,-3.0308188d-05, 1.8323880d-05 /
      data fpp( 4,10,16,1),fpp( 4,10,16,2),fpp( 4,10,16,3)/
     x-2.1738561d-03,-1.9208473d-05, 1.5371900d-05 /
      data fpp( 4,10,17,1),fpp( 4,10,17,2),fpp( 4,10,17,3)/
     x-1.5015422d-03,-8.0124306d-06, 1.3122519d-05 /
      data fpp( 4,10,18,1),fpp( 4,10,18,2),fpp( 4,10,18,3)/
     x-1.0681643d-05, 1.7154681d-06, 9.4180255d-06 /
      data fpp( 4,10,19,1),fpp( 4,10,19,2),fpp( 4,10,19,3)/
     x 7.8558663d-03, 1.0723139d-05, 1.5139379d-05 /
      data fpp( 4,10,20,1),fpp( 4,10,20,2),fpp( 4,10,20,3)/
     x 3.5860144d-02, 2.8115018d-05,-5.2299543d-05 /
      data fpp( 4,10,21,1),fpp( 4,10,21,2),fpp( 4,10,21,3)/
     x 3.5860144d-02, 2.8115018d-05,-5.0534060d-05 /
      data fpp( 4,10,22,1),fpp( 4,10,22,2),fpp( 4,10,22,3)/
     x 7.8558663d-03, 1.0723139d-05, 8.0774457d-06 /
      data fpp( 4,10,23,1),fpp( 4,10,23,2),fpp( 4,10,23,3)/
     x-1.0681643d-05, 1.7154681d-06, 3.5900277d-05 /
      data fpp( 4,11, 1,1),fpp( 4,11, 1,2),fpp( 4,11, 1,3)/
     x 5.7235994d-02, 1.2703311d-04, 1.9800744d-04 /
      data fpp( 4,11, 2,1),fpp( 4,11, 2,2),fpp( 4,11, 2,3)/
     x 1.5406270d-01, 3.0436039d-04, 1.5592962d-04 /
      data fpp( 4,11, 3,1),fpp( 4,11, 3,2),fpp( 4,11, 3,3)/
     x 2.6124482d-01, 5.3698651d-04, 6.9616092d-05 /
      data fpp( 4,11, 4,1),fpp( 4,11, 4,2),fpp( 4,11, 4,3)/
     x 2.6124482d-01, 5.3698651d-04, 6.2872916d-05 /
      data fpp( 4,11, 5,1),fpp( 4,11, 5,2),fpp( 4,11, 5,3)/
     x 1.5406270d-01, 3.0436039d-04, 1.8290232d-04 /
      data fpp( 4,11, 6,1),fpp( 4,11, 6,2),fpp( 4,11, 6,3)/
     x 5.7235994d-02, 1.2703311d-04, 9.6859797d-05 /
      data fpp( 4,11, 7,1),fpp( 4,11, 7,2),fpp( 4,11, 7,3)/
     x-8.5121261d-03, 9.4760020d-07,-1.1995093d-06 /
      data fpp( 4,11, 8,1),fpp( 4,11, 8,2),fpp( 4,11, 8,3)/
     x-8.2586751d-02, 1.1722071d-04,-1.1499376d-04 /
      data fpp( 4,11, 9,1),fpp( 4,11, 9,2),fpp( 4,11, 9,3)/
     x-3.6238042d-02,-1.8550099d-04,-2.7813345d-04 /
      data fpp( 4,11,10,1),fpp( 4,11,10,2),fpp( 4,11,10,3)/
     x 3.8025921d-02,-1.0585835d-04,-4.1904432d-05 /
      data fpp( 4,11,11,1),fpp( 4,11,11,2),fpp( 4,11,11,3)/
     x 8.8312557d-03,-5.6262596d-05, 6.9351799d-06 /
      data fpp( 4,11,12,1),fpp( 4,11,12,2),fpp( 4,11,12,3)/
     x 1.5081586d-03,-4.3466738d-05, 1.6437712d-05 /
      data fpp( 4,11,13,1),fpp( 4,11,13,2),fpp( 4,11,13,3)/
     x 8.4997694d-04,-3.6060489d-05, 1.8387971d-05 /
      data fpp( 4,11,14,1),fpp( 4,11,14,2),fpp( 4,11,14,3)/
     x 3.6558455d-01,-2.9134833d-05, 1.7722405d-05 /
      data fpp( 4,11,15,1),fpp( 4,11,15,2),fpp( 4,11,15,3)/
     x 8.5384489d-04,-2.1690161d-05, 1.6136409d-05 /
      data fpp( 4,11,16,1),fpp( 4,11,16,2),fpp( 4,11,16,3)/
     x-7.1017052d-04,-1.3896509d-05, 1.2909960d-05 /
      data fpp( 4,11,17,1),fpp( 4,11,17,2),fpp( 4,11,17,3)/
     x-3.3033290d-03,-6.1507319d-06, 1.1411750d-05 /
      data fpp( 4,11,18,1),fpp( 4,11,18,2),fpp( 4,11,18,3)/
     x-4.6195060d-03, 1.3442910d-06, 1.0329041d-05 /
      data fpp( 4,11,19,1),fpp( 4,11,19,2),fpp( 4,11,19,3)/
     x 2.0428718d-03, 7.6930608d-06, 3.0798086d-05 /
      data fpp( 4,11,20,1),fpp( 4,11,20,2),fpp( 4,11,20,3)/
     x 7.0018609d-01, 5.5529409d-07,-5.4741384d-05 /
      data fpp( 4,11,21,1),fpp( 4,11,21,2),fpp( 4,11,21,3)/
     x 7.0018609d-01, 5.5529409d-07,-5.1874891d-05 /
      data fpp( 4,11,22,1),fpp( 4,11,22,2),fpp( 4,11,22,3)/
     x 2.0428718d-03, 7.6930608d-06, 1.9332112d-05 /
      data fpp( 4,11,23,1),fpp( 4,11,23,2),fpp( 4,11,23,3)/
     x-4.6195060d-03, 1.3442910d-06, 5.3326444d-05 /
      data fpp( 4,12, 1,1),fpp( 4,12, 1,2),fpp( 4,12, 1,3)/
     x 1.6207116d-01, 2.0080775d-04, 5.2765783d-04 /
      data fpp( 4,12, 2,1),fpp( 4,12, 2,2),fpp( 4,12, 2,3)/
     x 4.3568955d-01, 3.8743069d-04, 3.0381683d-04 /
      data fpp( 4,12, 3,1),fpp( 4,12, 3,2),fpp( 4,12, 3,3)/
     x 9.7432777d-01, 6.8881415d-04,-1.6431916d-04 /
      data fpp( 4,12, 4,1),fpp( 4,12, 4,2),fpp( 4,12, 4,3)/
     x 9.7432777d-01, 6.8881415d-04,-1.8448494d-04 /
      data fpp( 4,12, 5,1),fpp( 4,12, 5,2),fpp( 4,12, 5,3)/
     x 4.3568955d-01, 3.8743069d-04, 3.8447998d-04 /
      data fpp( 4,12, 6,1),fpp( 4,12, 6,2),fpp( 4,12, 6,3)/
     x 1.6207116d-01, 2.0080775d-04, 2.2517104d-04 /
      data fpp( 4,12, 7,1),fpp( 4,12, 7,2),fpp( 4,12, 7,3)/
     x 3.8211632d-02, 1.2036747d-04, 5.6219881d-05 /
      data fpp( 4,12, 8,1),fpp( 4,12, 8,2),fpp( 4,12, 8,3)/
     x-3.1513954d-02, 2.4862798d-05,-5.5826560d-05 /
      data fpp( 4,12, 9,1),fpp( 4,12, 9,2),fpp( 4,12, 9,3)/
     x-7.6494292d-02, 2.3882165d-05,-1.6847564d-04 /
      data fpp( 4,12,10,1),fpp( 4,12,10,2),fpp( 4,12,10,3)/
     x 1.9950375d-02,-7.5454990d-05,-1.9368888d-04 /
      data fpp( 4,12,11,1),fpp( 4,12,11,2),fpp( 4,12,11,3)/
     x 3.7100984d-02,-4.7792064d-05,-1.5598831d-05 /
      data fpp( 4,12,12,1),fpp( 4,12,12,2),fpp( 4,12,12,3)/
     x 1.9521793d-02,-3.3046788d-05, 7.0122076d-06 /
      data fpp( 4,12,13,1),fpp( 4,12,13,2),fpp( 4,12,13,3)/
     x 1.3773240d-02,-2.7162023d-05, 1.5066001d-05 /
      data fpp( 4,12,14,1),fpp( 4,12,14,2),fpp( 4,12,14,3)/
     x 3.5847827d-01,-2.3070344d-05, 1.5493789d-05 /
      data fpp( 4,12,15,1),fpp( 4,12,15,2),fpp( 4,12,15,3)/
     x 1.0222370d-02,-1.9665169d-05, 1.4380843d-05 /
      data fpp( 4,12,16,1),fpp( 4,12,16,2),fpp( 4,12,16,3)/
     x 7.2342942d-03,-1.6387491d-05, 1.0700838d-05 /
      data fpp( 4,12,17,1),fpp( 4,12,17,2),fpp( 4,12,17,3)/
     x 3.1305890d-03,-1.2408642d-05, 8.8638039d-06 /
      data fpp( 4,12,18,1),fpp( 4,12,18,2),fpp( 4,12,18,3)/
     x 1.3052053d-03,-8.0706319d-06, 1.2223946d-05 /
      data fpp( 4,12,19,1),fpp( 4,12,19,2),fpp( 4,12,19,3)/
     x 8.3470362d-03,-9.4253816d-06, 3.2360411d-05 /
      data fpp( 4,12,20,1),fpp( 4,12,20,2),fpp( 4,12,20,3)/
     x-2.2189227d+00,-1.6320195d-05,-5.2883592d-05 /
      data fpp( 4,12,21,1),fpp( 4,12,21,2),fpp( 4,12,21,3)/
     x-2.2189227d+00,-1.6320195d-05,-5.0039430d-05 /
      data fpp( 4,12,22,1),fpp( 4,12,22,2),fpp( 4,12,22,3)/
     x 8.3470362d-03,-9.4253816d-06, 2.0983766d-05 /
      data fpp( 4,12,23,1),fpp( 4,12,23,2),fpp( 4,12,23,3)/
     x 1.3052053d-03,-8.0706319d-06, 5.4886367d-05 /
      data fpp( 4,13, 1,1),fpp( 4,13, 1,2),fpp( 4,13, 1,3)/
     x 3.7423058d-01, 5.3243905d-05, 9.7561290d-04 /
      data fpp( 4,13, 2,1),fpp( 4,13, 2,2),fpp( 4,13, 2,3)/
     x 8.5641805d-01,-2.3112513d-04, 4.9696570d-04 /
      data fpp( 4,13, 3,1),fpp( 4,13, 3,2),fpp( 4,13, 3,3)/
     x 1.4578366d+00,-8.3860311d-04,-5.0637371d-04 /
      data fpp( 4,13, 4,1),fpp( 4,13, 4,2),fpp( 4,13, 4,3)/
     x 1.4578366d+00,-8.3860311d-04,-5.4545672d-04 /
      data fpp( 4,13, 5,1),fpp( 4,13, 5,2),fpp( 4,13, 5,3)/
     x 8.5641805d-01,-2.3112513d-04, 6.5329773d-04 /
      data fpp( 4,13, 6,1),fpp( 4,13, 6,2),fpp( 4,13, 6,3)/
     x 3.7423058d-01, 5.3243905d-05, 3.8936782d-04 /
      data fpp( 4,13, 7,1),fpp( 4,13, 7,2),fpp( 4,13, 7,3)/
     x 9.2322029d-02, 9.9144531d-05, 1.4036101d-04 /
      data fpp( 4,13, 8,1),fpp( 4,13, 8,2),fpp( 4,13, 8,3)/
     x 3.5851432d-03, 8.6904099d-05,-1.5471860d-05 /
      data fpp( 4,13, 9,1),fpp( 4,13, 9,2),fpp( 4,13, 9,3)/
     x-5.0844360d-02, 3.4442334d-05,-9.1409572d-05 /
      data fpp( 4,13,10,1),fpp( 4,13,10,2),fpp( 4,13,10,3)/
     x-5.1829440d-02,-8.5716842d-06,-1.9790785d-04 /
      data fpp( 4,13,11,1),fpp( 4,13,11,2),fpp( 4,13,11,3)/
     x 4.1316593d-02,-2.6427147d-05,-9.2691024d-05 /
      data fpp( 4,13,12,1),fpp( 4,13,12,2),fpp( 4,13,12,3)/
     x 3.7080571d-02,-2.2484111d-05, 1.5819472d-06 /
      data fpp( 4,13,13,1),fpp( 4,13,13,2),fpp( 4,13,13,3)/
     x 2.8827921d-02,-1.9853417d-05, 8.1772353d-06 /
      data fpp( 4,13,14,1),fpp( 4,13,14,2),fpp( 4,13,14,3)/
     x 2.9621997d-01,-1.9733791d-05, 1.3373112d-05 /
      data fpp( 4,13,15,1),fpp( 4,13,15,2),fpp( 4,13,15,3)/
     x 2.3997003d-02,-2.0945162d-05, 1.2202318d-05 /
      data fpp( 4,13,16,1),fpp( 4,13,16,2),fpp( 4,13,16,3)/
     x 2.2125850d-02,-2.3141528d-05, 8.9296158d-06 /
      data fpp( 4,13,17,1),fpp( 4,13,17,2),fpp( 4,13,17,3)/
     x 2.0759389d-02,-2.5928701d-05, 7.1532188d-06 /
      data fpp( 4,13,18,1),fpp( 4,13,18,2),fpp( 4,13,18,3)/
     x 2.4465516d-02,-3.0663763d-05, 9.5695090d-06 /
      data fpp( 4,13,19,1),fpp( 4,13,19,2),fpp( 4,13,19,3)/
     x 4.4326100d-02,-4.1055534d-05, 2.1708745d-05 /
      data fpp( 4,13,20,1),fpp( 4,13,20,2),fpp( 4,13,20,3)/
     x-1.9455358d+00,-6.0680515d-05,-4.2500490d-05 /
      data fpp( 4,13,21,1),fpp( 4,13,21,2),fpp( 4,13,21,3)/
     x-1.9455358d+00,-6.0680515d-05,-4.0501904d-05 /
      data fpp( 4,13,22,1),fpp( 4,13,22,2),fpp( 4,13,22,3)/
     x 4.4326100d-02,-4.1055534d-05, 1.3714401d-05 /
      data fpp( 4,13,23,1),fpp( 4,13,23,2),fpp( 4,13,23,3)/
     x 2.4465516d-02,-3.0663763d-05, 3.9548299d-05 /
      data fpp( 4,14, 1,1),fpp( 4,14, 1,2),fpp( 4,14, 1,3)/
     x 3.8276104d-01,-6.0395364d-05, 8.4072273d-04 /
      data fpp( 4,14, 2,1),fpp( 4,14, 2,2),fpp( 4,14, 2,3)/
     x 9.8040648d-01,-4.2978818d-04, 4.1226153d-04 /
      data fpp( 4,14, 3,1),fpp( 4,14, 3,2),fpp( 4,14, 3,3)/
     x 1.4309803d+00,-9.5623570d-04,-4.8890086d-04 /
      data fpp( 4,14, 4,1),fpp( 4,14, 4,2),fpp( 4,14, 4,3)/
     x 1.4309803d+00,-9.5623570d-04,-5.1859620d-04 /
      data fpp( 4,14, 5,1),fpp( 4,14, 5,2),fpp( 4,14, 5,3)/
     x 9.8040648d-01,-4.2978818d-04, 5.3104289d-04 /
      data fpp( 4,14, 6,1),fpp( 4,14, 6,2),fpp( 4,14, 6,3)/
     x 3.8276104d-01,-6.0395364d-05, 3.9529264d-04 /
      data fpp( 4,14, 7,1),fpp( 4,14, 7,2),fpp( 4,14, 7,3)/
     x 1.2976090d-01, 7.9490408d-05, 1.7146457d-04 /
      data fpp( 4,14, 8,1),fpp( 4,14, 8,2),fpp( 4,14, 8,3)/
     x 2.9324958d-02, 9.2910807d-05, 2.1211097d-05 /
      data fpp( 4,14, 9,1),fpp( 4,14, 9,2),fpp( 4,14, 9,3)/
     x-1.4762064d-02, 6.9282499d-05,-5.0028954d-05 /
      data fpp( 4,14,10,1),fpp( 4,14,10,2),fpp( 4,14,10,3)/
     x-6.5583567d-02, 2.4847727d-05,-1.3708528d-04 /
      data fpp( 4,14,11,1),fpp( 4,14,11,2),fpp( 4,14,11,3)/
     x 2.9269496d-03,-8.4453477d-06,-1.5548792d-04 /
      data fpp( 4,14,12,1),fpp( 4,14,12,2),fpp( 4,14,12,3)/
     x 2.7059569d-01,-3.8327674d-06,-1.3889041d-05 /
      data fpp( 4,14,13,1),fpp( 4,14,13,2),fpp( 4,14,13,3)/
     x 3.9664653d-02,-1.0184307d-05, 2.0820835d-06 /
      data fpp( 4,14,14,1),fpp( 4,14,14,2),fpp( 4,14,14,3)/
     x 3.6942902d-02,-1.3194490d-05, 9.6227072d-06 /
      data fpp( 4,14,15,1),fpp( 4,14,15,2),fpp( 4,14,15,3)/
     x 3.6171946d-02,-1.6680184d-05, 9.2630878d-06 /
      data fpp( 4,14,16,1),fpp( 4,14,16,2),fpp( 4,14,16,3)/
     x 3.6349233d-02,-2.0958398d-05, 6.9709416d-06 /
      data fpp( 4,14,17,1),fpp( 4,14,17,2),fpp( 4,14,17,3)/
     x 3.8309330d-02,-2.5986555d-05, 4.5411458d-06 /
      data fpp( 4,14,18,1),fpp( 4,14,18,2),fpp( 4,14,18,3)/
     x 4.5686183d-02,-3.0626314d-05, 3.6644752d-06 /
      data fpp( 4,14,19,1),fpp( 4,14,19,2),fpp( 4,14,19,3)/
     x 6.4446882d-02,-2.9698482d-05, 2.2089533d-06 /
      data fpp( 4,14,20,1),fpp( 4,14,20,2),fpp( 4,14,20,3)/
     x 9.4918317d-02,-1.4845744d-05,-2.2022288d-05 /
      data fpp( 4,14,21,1),fpp( 4,14,21,2),fpp( 4,14,21,3)/
     x 9.4918317d-02,-1.4845744d-05,-2.1554612d-05 /
      data fpp( 4,14,22,1),fpp( 4,14,22,2),fpp( 4,14,22,3)/
     x 6.4446882d-02,-2.9698482d-05, 3.3824616d-07 /
      data fpp( 4,14,23,1),fpp( 4,14,23,2),fpp( 4,14,23,3)/
     x 4.5686183d-02,-3.0626314d-05, 1.0679627d-05 /
      data fpp( 4,15, 1,1),fpp( 4,15, 1,2),fpp( 4,15, 1,3)/
     x 2.7309137d-01, 1.2725755d-04, 3.1763292d-04 /
      data fpp( 4,15, 2,1),fpp( 4,15, 2,2),fpp( 4,15, 2,3)/
     x 5.9436096d-01, 2.6634184d-04, 1.6434515d-04 /
      data fpp( 4,15, 3,1),fpp( 4,15, 3,2),fpp( 4,15, 3,3)/
     x 9.8006870d-01, 6.2678791d-04,-1.6034553d-04 /
      data fpp( 4,15, 4,1),fpp( 4,15, 4,2),fpp( 4,15, 4,3)/
     x 9.8006870d-01, 6.2678791d-04,-1.6696598d-04 /
      data fpp( 4,15, 5,1),fpp( 4,15, 5,2),fpp( 4,15, 5,3)/
     x 5.9436096d-01, 2.6634184d-04, 1.9082693d-04 /
      data fpp( 4,15, 6,1),fpp( 4,15, 6,2),fpp( 4,15, 6,3)/
     x 2.7309137d-01, 1.2725755d-04, 2.1832627d-04 /
      data fpp( 4,15, 7,1),fpp( 4,15, 7,2),fpp( 4,15, 7,3)/
     x 1.1984723d-01, 1.0992784d-04, 1.1735198d-04 /
      data fpp( 4,15, 8,1),fpp( 4,15, 8,2),fpp( 4,15, 8,3)/
     x 3.9582749d-02, 1.0663467d-04, 3.1683815d-05 /
      data fpp( 4,15, 9,1),fpp( 4,15, 9,2),fpp( 4,15, 9,3)/
     x 1.9700444d-03, 8.4937670d-05,-2.5411239d-05 /
      data fpp( 4,15,10,1),fpp( 4,15,10,2),fpp( 4,15,10,3)/
     x-4.9914695d-02, 5.0684775d-05,-6.9334860d-05 /
      data fpp( 4,15,11,1),fpp( 4,15,11,2),fpp( 4,15,11,3)/
     x-5.2977680d-02, 9.3225379d-06,-1.6661732d-04 /
      data fpp( 4,15,12,1),fpp( 4,15,12,2),fpp( 4,15,12,3)/
     x 1.2007882d-01,-9.8968192d-06,-4.7393857d-05 /
      data fpp( 4,15,13,1),fpp( 4,15,13,2),fpp( 4,15,13,3)/
     x 4.3843404d-02,-9.3354170d-08, 3.0875015d-07 /
      data fpp( 4,15,14,1),fpp( 4,15,14,2),fpp( 4,15,14,3)/
     x 4.2917789d-02,-3.5382471d-06, 4.2248568d-06 /
      data fpp( 4,15,15,1),fpp( 4,15,15,2),fpp( 4,15,15,3)/
     x 4.2601860d-02,-6.2941027d-06, 6.0478227d-06 /
      data fpp( 4,15,16,1),fpp( 4,15,16,2),fpp( 4,15,16,3)/
     x 4.3289042d-02,-8.2968795d-06, 4.3618525d-06 /
      data fpp( 4,15,17,1),fpp( 4,15,17,2),fpp( 4,15,17,3)/
     x 4.5173654d-02,-9.4510777d-06, 2.0647674d-06 /
      data fpp( 4,15,18,1),fpp( 4,15,18,2),fpp( 4,15,18,3)/
     x 4.9197712d-02,-8.5729793d-06,-4.9492221d-07 /
      data fpp( 4,15,19,1),fpp( 4,15,19,2),fpp( 4,15,19,3)/
     x 5.5977073d-02,-3.3985395d-06,-3.4990786d-06 /
      data fpp( 4,15,20,1),fpp( 4,15,20,2),fpp( 4,15,20,3)/
     x 6.3729121d-02, 4.2994922d-06,-9.4667635d-06 /
      data fpp( 4,15,21,1),fpp( 4,15,21,2),fpp( 4,15,21,3)/
     x 6.3729121d-02, 4.2994922d-06,-9.4771703d-06 /
      data fpp( 4,15,22,1),fpp( 4,15,22,2),fpp( 4,15,22,3)/
     x 5.5977073d-02,-3.3985395d-06,-3.4574513d-06 /
      data fpp( 4,15,23,1),fpp( 4,15,23,2),fpp( 4,15,23,3)/
     x 4.9197712d-02,-8.5729793d-06,-6.5102433d-07 /
      data fpp( 4,16, 1,1),fpp( 4,16, 1,2),fpp( 4,16, 1,3)/
     x 1.4073258d-01, 2.3475316d-04, 9.0936179d-05 /
      data fpp( 4,16, 2,1),fpp( 4,16, 2,2),fpp( 4,16, 2,3)/
     x 2.9190277d-01, 4.1272283d-04, 6.6648642d-05 /
      data fpp( 4,16, 3,1),fpp( 4,16, 3,2),fpp( 4,16, 3,3)/
     x 3.7211746d-01, 6.0650404d-04, 1.5141253d-05 /
      data fpp( 4,16, 4,1),fpp( 4,16, 4,2),fpp( 4,16, 4,3)/
     x 3.7211746d-01, 6.0650404d-04, 1.4200921d-05 /
      data fpp( 4,16, 5,1),fpp( 4,16, 5,2),fpp( 4,16, 5,3)/
     x 2.9190277d-01, 4.1272283d-04, 7.0409971d-05 /
      data fpp( 4,16, 6,1),fpp( 4,16, 6,2),fpp( 4,16, 6,3)/
     x 1.4073258d-01, 2.3475316d-04, 7.6831194d-05 /
      data fpp( 4,16, 7,1),fpp( 4,16, 7,2),fpp( 4,16, 7,3)/
     x 7.6415656d-02, 1.5228824d-04, 5.4571251d-05 /
      data fpp( 4,16, 8,1),fpp( 4,16, 8,2),fpp( 4,16, 8,3)/
     x 3.2751170d-02, 1.2083450d-04, 2.2049800d-05 /
      data fpp( 4,16, 9,1),fpp( 4,16, 9,2),fpp( 4,16, 9,3)/
     x 1.3541956d-03, 1.0150682d-04,-1.0236453d-05 /
      data fpp( 4,16,10,1),fpp( 4,16,10,2),fpp( 4,16,10,3)/
     x-2.9816368d-02, 7.5167174d-05,-2.1747988d-05 /
      data fpp( 4,16,11,1),fpp( 4,16,11,2),fpp( 4,16,11,3)/
     x-1.6334742d-01, 3.3753196d-05,-1.2001959d-04 /
      data fpp( 4,16,12,1),fpp( 4,16,12,2),fpp( 4,16,12,3)/
     x 1.9650195d-02, 6.4894044d-05,-9.2611633d-05 /
      data fpp( 4,16,13,1),fpp( 4,16,13,2),fpp( 4,16,13,3)/
     x 4.2568832d-02, 6.4477238d-06, 3.2001256d-06 /
      data fpp( 4,16,14,1),fpp( 4,16,14,2),fpp( 4,16,14,3)/
     x 4.5301864d-02, 4.2234786d-06,-1.5488696d-06 /
      data fpp( 4,16,15,1),fpp( 4,16,15,2),fpp( 4,16,15,3)/
     x 4.5428590d-02, 3.7085945d-06, 3.6613528d-06 /
      data fpp( 4,16,16,1),fpp( 4,16,16,2),fpp( 4,16,16,3)/
     x 4.5644507d-02, 4.2859162d-06, 2.1254585d-06 /
      data fpp( 4,16,17,1),fpp( 4,16,17,2),fpp( 4,16,17,3)/
     x 4.6398669d-02, 5.8548662d-06, 9.0481310d-07 /
      data fpp( 4,16,18,1),fpp( 4,16,18,2),fpp( 4,16,18,3)/
     x 4.7568749d-02, 8.3442316d-06,-8.5471092d-07 /
      data fpp( 4,16,19,1),fpp( 4,16,19,2),fpp( 4,16,19,3)/
     x 4.9163105d-02, 1.1384639d-05,-2.4179694d-06 /
      data fpp( 4,16,20,1),fpp( 4,16,20,2),fpp( 4,16,20,3)/
     x 5.0592266d-02, 1.4327775d-05,-3.9454114d-06 /
      data fpp( 4,16,21,1),fpp( 4,16,21,2),fpp( 4,16,21,3)/
     x 5.0592266d-02, 1.4327775d-05,-3.9857810d-06 /
      data fpp( 4,16,22,1),fpp( 4,16,22,2),fpp( 4,16,22,3)/
     x 4.9163105d-02, 1.1384639d-05,-2.2564911d-06 /
      data fpp( 4,16,23,1),fpp( 4,16,23,2),fpp( 4,16,23,3)/
     x 4.7568749d-02, 8.3442316d-06,-1.4602544d-06 /
      data fpp( 4,17, 1,1),fpp( 4,17, 1,2),fpp( 4,17, 1,3)/
     x 5.3352753d-02, 1.0038180d-04, 3.5824624d-05 /
      data fpp( 4,17, 2,1),fpp( 4,17, 2,2),fpp( 4,17, 2,3)/
     x 7.0816043d-02, 1.2868885d-04, 3.6332252d-05 /
      data fpp( 4,17, 3,1),fpp( 4,17, 3,2),fpp( 4,17, 3,3)/
     x 8.6442324d-02, 1.6039391d-04, 3.7528369d-05 /
      data fpp( 4,17, 4,1),fpp( 4,17, 4,2),fpp( 4,17, 4,3)/
     x 8.6442324d-02, 1.6039391d-04, 3.7338768d-05 /
      data fpp( 4,17, 5,1),fpp( 4,17, 5,2),fpp( 4,17, 5,3)/
     x 7.0816043d-02, 1.2868885d-04, 3.7090657d-05 /
      data fpp( 4,17, 6,1),fpp( 4,17, 6,2),fpp( 4,17, 6,3)/
     x 5.3352753d-02, 1.0038180d-04, 3.2980605d-05 /
      data fpp( 4,17, 7,1),fpp( 4,17, 7,2),fpp( 4,17, 7,3)/
     x 3.4464069d-02, 7.8691205d-05, 2.4504922d-05 /
      data fpp( 4,17, 8,1),fpp( 4,17, 8,2),fpp( 4,17, 8,3)/
     x 1.7795982d-02, 6.7771327d-05, 1.2765708d-05 /
      data fpp( 4,17, 9,1),fpp( 4,17, 9,2),fpp( 4,17, 9,3)/
     x 1.0568446d-03, 5.9727048d-05, 3.8002476d-06 /
      data fpp( 4,17,10,1),fpp( 4,17,10,2),fpp( 4,17,10,3)/
     x-1.4396055d-02, 4.5942530d-05,-1.6302698d-05 /
      data fpp( 4,17,11,1),fpp( 4,17,11,2),fpp( 4,17,11,3)/
     x-4.2196803d-02, 1.2018678d-05, 8.7365454d-06 /
      data fpp( 4,17,12,1),fpp( 4,17,12,2),fpp( 4,17,12,3)/
     x-6.8160824d-01,-1.0145536d-04,-1.9150948d-04 /
      data fpp( 4,17,13,1),fpp( 4,17,13,2),fpp( 4,17,13,3)/
     x-1.1682514d-01, 1.8636459d-05, 4.2893387d-05 /
      data fpp( 4,17,14,1),fpp( 4,17,14,2),fpp( 4,17,14,3)/
     x 4.5366275d-02, 1.3614333d-05,-1.4324066d-05 /
      data fpp( 4,17,15,1),fpp( 4,17,15,2),fpp( 4,17,15,3)/
     x 4.6860295d-02, 1.3299725d-05, 4.7128770d-06 /
      data fpp( 4,17,16,1),fpp( 4,17,16,2),fpp( 4,17,16,3)/
     x 4.7161291d-02, 1.4889215d-05, 1.6455790d-07 /
      data fpp( 4,17,17,1),fpp( 4,17,17,2),fpp( 4,17,17,3)/
     x 4.7295374d-02, 1.7345613d-05, 8.8689133d-07 /
      data fpp( 4,17,18,1),fpp( 4,17,18,2),fpp( 4,17,18,3)/
     x 4.7492094d-02, 2.0022053d-05,-1.2412324d-07 /
      data fpp( 4,17,19,1),fpp( 4,17,19,2),fpp( 4,17,19,3)/
     x 4.7715503d-02, 2.2431982d-05,-6.0639836d-07 /
      data fpp( 4,17,20,1),fpp( 4,17,20,2),fpp( 4,17,20,3)/
     x 4.7858873d-02, 2.3985407d-05,-1.1582833d-06 /
      data fpp( 4,17,21,1),fpp( 4,17,21,2),fpp( 4,17,21,3)/
     x 4.7858873d-02, 2.3985407d-05,-1.1689508d-06 /
      data fpp( 4,17,22,1),fpp( 4,17,22,2),fpp( 4,17,22,3)/
     x 4.7715503d-02, 2.2431982d-05,-5.6372833d-07 /
      data fpp( 4,17,23,1),fpp( 4,17,23,2),fpp( 4,17,23,3)/
     x 4.7492094d-02, 2.0022053d-05,-2.8413583d-07 /
      data fpp( 4,18, 1,1),fpp( 4,18, 1,2),fpp( 4,18, 1,3)/
     x 9.6268479d-03, 1.1516563d-04, 1.5316473d-05 /
      data fpp( 4,18, 2,1),fpp( 4,18, 2,2),fpp( 4,18, 2,3)/
     x 1.3254292d-02, 1.1512976d-04, 1.6218555d-05 /
      data fpp( 4,18, 3,1),fpp( 4,18, 3,2),fpp( 4,18, 3,3)/
     x 1.5543088d-02, 1.1938031d-04, 1.8191309d-05 /
      data fpp( 4,18, 4,1),fpp( 4,18, 4,2),fpp( 4,18, 4,3)/
     x 1.5543088d-02, 1.1938031d-04, 1.8121796d-05 /
      data fpp( 4,18, 5,1),fpp( 4,18, 5,2),fpp( 4,18, 5,3)/
     x 1.3254292d-02, 1.1512976d-04, 1.6496609d-05 /
      data fpp( 4,18, 6,1),fpp( 4,18, 6,2),fpp( 4,18, 6,3)/
     x 9.6268479d-03, 1.1516563d-04, 1.4273770d-05 /
      data fpp( 4,18, 7,1),fpp( 4,18, 7,2),fpp( 4,18, 7,3)/
     x 4.6650862d-03, 1.2344894d-04, 1.1356312d-05 /
      data fpp( 4,18, 8,1),fpp( 4,18, 8,2),fpp( 4,18, 8,3)/
     x 4.2634592d-04, 1.3474819d-04, 7.7769822d-06 /
      data fpp( 4,18, 9,1),fpp( 4,18, 9,2),fpp( 4,18, 9,3)/
     x-4.3509247d-03, 1.4365299d-04, 4.9717594d-06 /
      data fpp( 4,18,10,1),fpp( 4,18,10,2),fpp( 4,18,10,3)/
     x-1.5727535d-03, 1.4542071d-04,-8.0201964d-07 /
      data fpp( 4,18,11,1),fpp( 4,18,11,2),fpp( 4,18,11,3)/
     x-8.1386178d-02, 1.3707609d-04, 4.3923192d-06 /
      data fpp( 4,18,12,1),fpp( 4,18,12,2),fpp( 4,18,12,3)/
     x 4.4878249d-03, 1.1410939d-04,-2.8329257d-05 /
      data fpp( 4,18,13,1),fpp( 4,18,13,2),fpp( 4,18,13,3)/
     x-4.6049556d-01, 3.0304403d-06,-7.6061291d-05 /
      data fpp( 4,18,14,1),fpp( 4,18,14,2),fpp( 4,18,14,3)/
     x 1.2021097d+00, 1.0703191d-05, 1.9932420d-05 /
      data fpp( 4,18,15,1),fpp( 4,18,15,2),fpp( 4,18,15,3)/
     x 2.7087618d+00, 1.6706507d-05,-4.8443899d-06 /
      data fpp( 4,18,16,1),fpp( 4,18,16,2),fpp( 4,18,16,3)/
     x 4.0181288d+00, 2.2473224d-05, 2.0791393d-06 /
      data fpp( 4,18,17,1),fpp( 4,18,17,2),fpp( 4,18,17,3)/
     x 5.1216995d+00, 2.8010682d-05, 2.0583281d-07 /
      data fpp( 4,18,18,1),fpp( 4,18,18,2),fpp( 4,18,18,3)/
     x 6.0227115d+00, 3.2971556d-05, 6.0752950d-07 /
      data fpp( 4,18,19,1),fpp( 4,18,19,2),fpp( 4,18,19,3)/
     x 6.7202678d+00, 3.6911434d-05, 3.2804919d-07 /
      data fpp( 4,18,20,1),fpp( 4,18,20,2),fpp( 4,18,20,3)/
     x 7.1630450d+00, 3.9514598d-05, 2.7627374d-07 /
      data fpp( 4,18,21,1),fpp( 4,18,21,2),fpp( 4,18,21,3)/
     x 7.1630450d+00, 3.9514598d-05, 2.6415419d-07 /
      data fpp( 4,18,22,1),fpp( 4,18,22,2),fpp( 4,18,22,3)/
     x 6.7202678d+00, 3.6911434d-05, 3.7652737d-07 /
      data fpp( 4,18,23,1),fpp( 4,18,23,2),fpp( 4,18,23,3)/
     x 6.0227115d+00, 3.2971556d-05, 4.2573631d-07 /
      data fpp( 4,19, 1,1),fpp( 4,19, 1,2),fpp( 4,19, 1,3)/
     x-1.3858331d-01, 8.7333686d-05, 9.2595402d-20 /
      data fpp( 4,19, 2,1),fpp( 4,19, 2,2),fpp( 4,19, 2,3)/
     x-1.3858331d-01, 2.4292122d-05,-3.9930278d-20 /
      data fpp( 4,19, 3,1),fpp( 4,19, 3,2),fpp( 4,19, 3,3)/
     x-1.3858331d-01,-3.7375156d-05,-6.9445860d-20 /
      data fpp( 4,19, 4,1),fpp( 4,19, 4,2),fpp( 4,19, 4,3)/
     x-1.3858331d-01,-3.7375156d-05, 5.8938829d-20 /
      data fpp( 4,19, 5,1),fpp( 4,19, 5,2),fpp( 4,19, 5,3)/
     x-1.3858331d-01, 2.4292122d-05, 3.8023529d-20 /
      data fpp( 4,19, 6,1),fpp( 4,19, 6,2),fpp( 4,19, 6,3)/
     x-1.3858331d-01, 8.7333686d-05,-3.9245119d-20 /
      data fpp( 4,19, 7,1),fpp( 4,19, 7,2),fpp( 4,19, 7,3)/
     x-1.3858331d-01, 1.3439103d-04,-1.2506748d-19 /
      data fpp( 4,19, 8,1),fpp( 4,19, 8,2),fpp( 4,19, 8,3)/
     x-1.3858331d-01, 1.6742790d-04,-4.0100142d-20 /
      data fpp( 4,19, 9,1),fpp( 4,19, 9,2),fpp( 4,19, 9,3)/
     x-1.3858331d-01, 1.9166301d-04, 4.1233140d-20 /
      data fpp( 4,19,10,1),fpp( 4,19,10,2),fpp( 4,19,10,3)/
     x-1.3858331d-01, 2.0812665d-04,-3.1970457d-21 /
      data fpp( 4,19,11,1),fpp( 4,19,11,2),fpp( 4,19,11,3)/
     x-1.3858331d-01, 2.2019295d-04, 3.4664727d-20 /
      data fpp( 4,19,12,1),fpp( 4,19,12,2),fpp( 4,19,12,3)/
     x-1.3858331d-01, 2.2055581d-04,-3.4164733d-20 /
      data fpp( 4,19,13,1),fpp( 4,19,13,2),fpp( 4,19,13,3)/
     x-1.3858331d-01,-4.6342201d-06, 7.6886386d-20 /
      data fpp( 4,19,14,1),fpp( 4,19,14,2),fpp( 4,19,14,3)/
     x-1.3858331d-01, 1.1306905d-05,-3.9053958d-21 /
      data fpp( 4,19,15,1),fpp( 4,19,15,2),fpp( 4,19,15,3)/
     x-1.3858331d-01, 2.1880246d-05, 1.1194390d-19 /
      data fpp( 4,19,16,1),fpp( 4,19,16,2),fpp( 4,19,16,3)/
     x-1.3858331d-01, 3.0919888d-05,-3.9349730d-20 /
      data fpp( 4,19,17,1),fpp( 4,19,17,2),fpp( 4,19,17,3)/
     x-1.3858331d-01, 3.8911659d-05,-7.7728764d-21 /
      data fpp( 4,19,18,1),fpp( 4,19,18,2),fpp( 4,19,18,3)/
     x-1.3858331d-01, 4.5557722d-05,-1.1462140d-19 /
      data fpp( 4,19,19,1),fpp( 4,19,19,2),fpp( 4,19,19,3)/
     x-1.3858331d-01, 5.0410283d-05,-4.5819261d-20 /
      data fpp( 4,19,20,1),fpp( 4,19,20,2),fpp( 4,19,20,3)/
     x-1.3858331d-01, 5.3366201d-05, 3.3147702d-20 /
      data fpp( 4,19,21,1),fpp( 4,19,21,2),fpp( 4,19,21,3)/
     x-1.3858331d-01, 5.3366201d-05,-3.3802445d-20 /
      data fpp( 4,19,22,1),fpp( 4,19,22,2),fpp( 4,19,22,3)/
     x-1.3858331d-01, 5.0410283d-05, 1.3849563d-19 /
      data fpp( 4,19,23,1),fpp( 4,19,23,2),fpp( 4,19,23,3)/
     x-1.3858331d-01, 4.5557722d-05, 3.7065574d-19 /
      data fpp( 5, 1, 1,1),fpp( 5, 1, 1,2),fpp( 5, 1, 1,3)/
     x 7.2319809d-01, 7.6741060d-04,-1.6429999d-18 /
      data fpp( 5, 1, 2,1),fpp( 5, 1, 2,2),fpp( 5, 1, 2,3)/
     x 7.2319809d-01, 4.7759430d-04, 2.4787051d-19 /
      data fpp( 5, 1, 3,1),fpp( 5, 1, 3,2),fpp( 5, 1, 3,3)/
     x 7.2319809d-01, 1.1015780d-03,-3.9080992d-19 /
      data fpp( 5, 1, 4,1),fpp( 5, 1, 4,2),fpp( 5, 1, 4,3)/
     x 7.2319809d-01, 1.1015780d-03, 6.7175476d-19 /
      data fpp( 5, 1, 5,1),fpp( 5, 1, 5,2),fpp( 5, 1, 5,3)/
     x 7.2319809d-01, 4.7759430d-04,-8.6133531d-20 /
      data fpp( 5, 1, 6,1),fpp( 5, 1, 6,2),fpp( 5, 1, 6,3)/
     x 7.2319809d-01, 7.6741060d-04,-4.5341860d-20 /
      data fpp( 5, 1, 7,1),fpp( 5, 1, 7,2),fpp( 5, 1, 7,3)/
     x 7.2319809d-01, 4.1094145d-04,-1.1167528d-18 /
      data fpp( 5, 1, 8,1),fpp( 5, 1, 8,2),fpp( 5, 1, 8,3)/
     x 7.2319809d-01,-1.1162536d-03, 2.7299794d-19 /
      data fpp( 5, 1, 9,1),fpp( 5, 1, 9,2),fpp( 5, 1, 9,3)/
     x 7.2319809d-01,-2.0193989d-03,-1.8840668d-19 /
      data fpp( 5, 1,10,1),fpp( 5, 1,10,2),fpp( 5, 1,10,3)/
     x 7.2319809d-01,-2.5300194d-03, 1.0086115d-18 /
      data fpp( 5, 1,11,1),fpp( 5, 1,11,2),fpp( 5, 1,11,3)/
     x 7.2319809d-01,-2.8195355d-03,-4.0609703d-19 /
      data fpp( 5, 1,12,1),fpp( 5, 1,12,2),fpp( 5, 1,12,3)/
     x 7.2319809d-01,-2.9272025d-03, 4.8144585d-19 /
      data fpp( 5, 1,13,1),fpp( 5, 1,13,2),fpp( 5, 1,13,3)/
     x 7.2319809d-01,-2.8119272d-03, 4.6082074d-19 /
      data fpp( 5, 1,14,1),fpp( 5, 1,14,2),fpp( 5, 1,14,3)/
     x 7.2319809d-01,-2.5132356d-03,-2.4651616d-19 /
      data fpp( 5, 1,15,1),fpp( 5, 1,15,2),fpp( 5, 1,15,3)/
     x 7.2319809d-01,-1.9906450d-03,-6.0182860d-20 /
      data fpp( 5, 1,16,1),fpp( 5, 1,16,2),fpp( 5, 1,16,3)/
     x 7.2319809d-01,-1.0779164d-03, 2.5889650d-19 /
      data fpp( 5, 1,17,1),fpp( 5, 1,17,2),fpp( 5, 1,17,3)/
     x 7.2319809d-01, 4.6626380d-04, 6.1353890d-19 /
      data fpp( 5, 1,18,1),fpp( 5, 1,18,2),fpp( 5, 1,18,3)/
     x 7.2319809d-01, 7.4912407d-04,-9.2471379d-19 /
      data fpp( 5, 1,19,1),fpp( 5, 1,19,2),fpp( 5, 1,19,3)/
     x 7.2319809d-01, 4.8173613d-04,-4.9882105d-19 /
      data fpp( 5, 1,20,1),fpp( 5, 1,20,2),fpp( 5, 1,20,3)/
     x 7.2319809d-01, 1.0933876d-03, 5.3409243d-19 /
      data fpp( 5, 1,21,1),fpp( 5, 1,21,2),fpp( 5, 1,21,3)/
     x 7.2319809d-01, 1.0933876d-03,-6.1060356d-19 /
      data fpp( 5, 1,22,1),fpp( 5, 1,22,2),fpp( 5, 1,22,3)/
     x 7.2319809d-01, 4.8173613d-04, 8.0297865d-19 /
      data fpp( 5, 1,23,1),fpp( 5, 1,23,2),fpp( 5, 1,23,3)/
     x 7.2319809d-01, 7.4912407d-04, 3.3100681d-18 /
      data fpp( 5, 2, 1,1),fpp( 5, 2, 1,2),fpp( 5, 2, 1,3)/
     x 3.7125343d-01, 1.8466479d-04,-1.0713620d-05 /
      data fpp( 5, 2, 2,1),fpp( 5, 2, 2,2),fpp( 5, 2, 2,3)/
     x 2.8937778d-01,-2.7192598d-05,-9.8252609d-06 /
      data fpp( 5, 2, 3,1),fpp( 5, 2, 3,2),fpp( 5, 2, 3,3)/
     x 3.4071475d-01, 2.8358809d-04,-8.4913367d-06 /
      data fpp( 5, 2, 4,1),fpp( 5, 2, 4,2),fpp( 5, 2, 4,3)/
     x 3.4071475d-01, 2.8358809d-04,-7.4943594d-06 /
      data fpp( 5, 2, 5,1),fpp( 5, 2, 5,2),fpp( 5, 2, 5,3)/
     x 2.8937778d-01,-2.7192598d-05,-1.3813170d-05 /
      data fpp( 5, 2, 6,1),fpp( 5, 2, 6,2),fpp( 5, 2, 6,3)/
     x 3.7125343d-01, 1.8466479d-04, 4.2410409d-06 /
      data fpp( 5, 2, 7,1),fpp( 5, 2, 7,2),fpp( 5, 2, 7,3)/
     x 4.3172644d-01, 9.4623092d-05, 6.3050069d-06 /
      data fpp( 5, 2, 8,1),fpp( 5, 2, 8,2),fpp( 5, 2, 8,3)/
     x 4.5228281d-01,-5.4412476d-04,-1.5850683d-06 /
      data fpp( 5, 2, 9,1),fpp( 5, 2, 9,2),fpp( 5, 2, 9,3)/
     x 3.3734853d-01,-9.2682326d-04, 5.7052664d-06 /
      data fpp( 5, 2,10,1),fpp( 5, 2,10,2),fpp( 5, 2,10,3)/
     x 2.3933564d-01,-1.1470272d-03, 4.0120028d-06 /
      data fpp( 5, 2,11,1),fpp( 5, 2,11,2),fpp( 5, 2,11,3)/
     x 1.5166515d-01,-1.2722440d-03, 4.6167224d-06 /
      data fpp( 5, 2,12,1),fpp( 5, 2,12,2),fpp( 5, 2,12,3)/
     x 1.3357092d-01,-1.3185030d-03, 4.5211077d-06 /
      data fpp( 5, 2,13,1),fpp( 5, 2,13,2),fpp( 5, 2,13,3)/
     x 1.4320968d-01,-1.2706505d-03, 4.6348467d-06 /
      data fpp( 5, 2,14,1),fpp( 5, 2,14,2),fpp( 5, 2,14,3)/
     x 3.3362030d-01,-1.1431279d-03, 4.0475053d-06 /
      data fpp( 5, 2,15,1),fpp( 5, 2,15,2),fpp( 5, 2,15,3)/
     x 3.5244343d-01,-9.1891200d-04, 5.7971320d-06 /
      data fpp( 5, 2,16,1),fpp( 5, 2,16,2),fpp( 5, 2,16,3)/
     x 5.1954695d-01,-5.2671226d-04,-2.0000335d-06 /
      data fpp( 5, 2,17,1),fpp( 5, 2,17,2),fpp( 5, 2,17,3)/
     x 4.9399273d-01, 1.1437140d-04, 7.9750019d-06 /
      data fpp( 5, 2,18,1),fpp( 5, 2,18,2),fpp( 5, 2,18,3)/
     x 3.6727994d-01, 1.8069086d-04,-2.1259740d-06 /
      data fpp( 5, 2,19,1),fpp( 5, 2,19,2),fpp( 5, 2,19,3)/
     x 3.2948302d-01,-1.8414254d-05,-4.4751058d-06 /
      data fpp( 5, 2,20,1),fpp( 5, 2,20,2),fpp( 5, 2,20,3)/
     x 3.4295552d-01, 2.8713670d-04,-1.0861603d-05 /
      data fpp( 5, 2,21,1),fpp( 5, 2,21,2),fpp( 5, 2,21,3)/
     x 3.4295552d-01, 2.8713670d-04,-1.0831639d-05 /
      data fpp( 5, 2,22,1),fpp( 5, 2,22,2),fpp( 5, 2,22,3)/
     x 3.2948302d-01,-1.8414254d-05,-4.5949603d-06 /
      data fpp( 5, 2,23,1),fpp( 5, 2,23,2),fpp( 5, 2,23,3)/
     x 3.6727994d-01, 1.8069086d-04,-1.6765199d-06 /
      data fpp( 5, 3, 1,1),fpp( 5, 3, 1,2),fpp( 5, 3, 1,3)/
     x 4.3007428d-02,-1.3439138d-03, 2.7131853d-04 /
      data fpp( 5, 3, 2,1),fpp( 5, 3, 2,2),fpp( 5, 3, 2,3)/
     x 5.3000626d-02, 5.4006809d-04, 1.1615193d-04 /
      data fpp( 5, 3, 3,1),fpp( 5, 3, 3,2),fpp( 5, 3, 3,3)/
     x 2.1061028d-01, 7.0793673d-05,-2.0184226d-04 /
      data fpp( 5, 3, 4,1),fpp( 5, 3, 4,2),fpp( 5, 3, 4,3)/
     x 2.1061028d-01, 7.0793673d-05,-2.2722719d-04 /
      data fpp( 5, 3, 5,1),fpp( 5, 3, 5,2),fpp( 5, 3, 5,3)/
     x 5.3000626d-02, 5.4006809d-04, 2.1769165d-04 /
      data fpp( 5, 3, 6,1),fpp( 5, 3, 6,2),fpp( 5, 3, 6,3)/
     x 4.3007428d-02,-1.3439138d-03,-1.0945542d-04 /
      data fpp( 5, 3, 7,1),fpp( 5, 3, 7,2),fpp( 5, 3, 7,3)/
     x-4.3264633d-01,-2.0509338d-03,-4.3787799d-04 /
      data fpp( 5, 3, 8,1),fpp( 5, 3, 8,2),fpp( 5, 3, 8,3)/
     x 8.4589829d-01,-9.2017132d-04, 3.8895137d-04 /
      data fpp( 5, 3, 9,1),fpp( 5, 3, 9,2),fpp( 5, 3, 9,3)/
     x 5.7884721d-01,-2.4944610d-04, 8.1622525d-05 /
      data fpp( 5, 3,10,1),fpp( 5, 3,10,2),fpp( 5, 3,10,3)/
     x 7.4491486d-01, 1.2937619d-04, 8.5654533d-05 /
      data fpp( 5, 3,11,1),fpp( 5, 3,11,2),fpp( 5, 3,11,3)/
     x 7.3416104d-01, 3.3698554d-04, 5.8339341d-05 /
      data fpp( 5, 3,12,1),fpp( 5, 3,12,2),fpp( 5, 3,12,3)/
     x 1.0365905d+00, 4.0803035d-04, 9.6104101d-05 /
      data fpp( 5, 3,13,1),fpp( 5, 3,13,2),fpp( 5, 3,13,3)/
     x 6.8862251d-01, 3.2673539d-04, 5.8964254d-05 /
      data fpp( 5, 3,14,1),fpp( 5, 3,14,2),fpp( 5, 3,14,3)/
     x 7.4075532d-01, 1.0921703d-04, 8.8128882d-05 /
      data fpp( 5, 3,15,1),fpp( 5, 3,15,2),fpp( 5, 3,15,3)/
     x 5.6708019d-01,-2.8204700d-04, 7.8690218d-05 /
      data fpp( 5, 3,16,1),fpp( 5, 3,16,2),fpp( 5, 3,16,3)/
     x 9.0205991d-01,-9.7834060d-04, 4.0462624d-04 /
      data fpp( 5, 3,17,1),fpp( 5, 3,17,2),fpp( 5, 3,17,3)/
     x-9.8786056d-01,-2.1005954d-03,-4.8462520d-04 /
      data fpp( 5, 3,18,1),fpp( 5, 3,18,2),fpp( 5, 3,18,3)/
     x 4.1421914d-02,-1.3229495d-03,-7.1053460d-05 /
      data fpp( 5, 3,19,1),fpp( 5, 3,19,2),fpp( 5, 3,19,3)/
     x 5.4509674d-02, 5.1510489d-04, 2.0729304d-04 /
      data fpp( 5, 3,20,1),fpp( 5, 3,20,2),fpp( 5, 3,20,3)/
     x 2.1094194d-01, 4.9873540d-05,-2.2551668d-04 /
      data fpp( 5, 3,21,1),fpp( 5, 3,21,2),fpp( 5, 3,21,3)/
     x 2.1094194d-01, 4.9873540d-05,-2.0271647d-04 /
      data fpp( 5, 3,22,1),fpp( 5, 3,22,2),fpp( 5, 3,22,3)/
     x 5.4509674d-02, 5.1510489d-04, 1.1609221d-04 /
      data fpp( 5, 3,23,1),fpp( 5, 3,23,2),fpp( 5, 3,23,3)/
     x 4.1421914d-02,-1.3229495d-03, 2.7094965d-04 /
      data fpp( 5, 4, 1,1),fpp( 5, 4, 1,2),fpp( 5, 4, 1,3)/
     x-7.8052690d-03, 4.3792229d-04,-1.0755727d-03 /
      data fpp( 5, 4, 2,1),fpp( 5, 4, 2,2),fpp( 5, 4, 2,3)/
     x-1.2021317d-01,-2.6448378d-03,-7.6419864d-04 /
      data fpp( 5, 4, 3,1),fpp( 5, 4, 3,2),fpp( 5, 4, 3,3)/
     x 1.1234684d-01,-2.2601848d-03,-1.6393277d-04 /
      data fpp( 5, 4, 4,1),fpp( 5, 4, 4,2),fpp( 5, 4, 4,3)/
     x 1.1234684d-01,-2.2601848d-03,-4.6745361d-05 /
      data fpp( 5, 4, 5,1),fpp( 5, 4, 5,2),fpp( 5, 4, 5,3)/
     x-1.2021317d-01,-2.6448378d-03,-1.2329483d-03 /
      data fpp( 5, 4, 6,1),fpp( 5, 4, 6,2),fpp( 5, 4, 6,3)/
     x-7.8052690d-03, 4.3792229d-04, 6.8223851d-04 /
      data fpp( 5, 4, 7,1),fpp( 5, 4, 7,2),fpp( 5, 4, 7,3)/
     x 9.0195948d-02, 2.2058442d-03, 2.6963225d-04 /
      data fpp( 5, 4, 8,1),fpp( 5, 4, 8,2),fpp( 5, 4, 8,3)/
     x 1.9855747d-01, 2.0223961d-03, 1.1837848d-04 /
      data fpp( 5, 4, 9,1),fpp( 5, 4, 9,2),fpp( 5, 4, 9,3)/
     x 3.2253926d-01, 1.8811257d-03, 1.0836182d-04 /
      data fpp( 5, 4,10,1),fpp( 5, 4,10,2),fpp( 5, 4,10,3)/
     x 1.9698178d-01, 1.7788404d-03, 5.8986256d-05 /
      data fpp( 5, 4,11,1),fpp( 5, 4,11,2),fpp( 5, 4,11,3)/
     x 9.8600092d-02, 1.7294319d-03, 5.7495160d-05 /
      data fpp( 5, 4,12,1),fpp( 5, 4,12,2),fpp( 5, 4,12,3)/
     x 3.0323541d-01, 1.7221456d-03, 8.9087105d-05 /
      data fpp( 5, 4,13,1),fpp( 5, 4,13,2),fpp( 5, 4,13,3)/
     x 8.9463877d-02, 1.7277390d-03, 5.9892419d-05 /
      data fpp( 5, 4,14,1),fpp( 5, 4,14,2),fpp( 5, 4,14,3)/
     x 1.8625680d-01, 1.7737317d-03, 5.9591220d-05 /
      data fpp( 5, 4,15,1),fpp( 5, 4,15,2),fpp( 5, 4,15,3)/
     x 3.1554800d-01, 1.8768560d-03, 1.1430270d-04 /
      data fpp( 5, 4,16,1),fpp( 5, 4,16,2),fpp( 5, 4,16,3)/
     x 1.8863663d-01, 2.0799447d-03, 1.2082397d-04 /
      data fpp( 5, 4,17,1),fpp( 5, 4,17,2),fpp( 5, 4,17,3)/
     x-5.4946784d-02, 2.2051982d-03, 2.8897342d-04 /
      data fpp( 5, 4,18,1),fpp( 5, 4,18,2),fpp( 5, 4,18,3)/
     x-9.7476534d-03, 4.4663513d-04, 6.2667434d-04 /
      data fpp( 5, 4,19,1),fpp( 5, 4,19,2),fpp( 5, 4,19,3)/
     x-7.4079276d-02,-2.5692193d-03,-1.1948408d-03 /
      data fpp( 5, 4,20,1),fpp( 5, 4,20,2),fpp( 5, 4,20,3)/
     x 1.1273832d-01,-2.1788469d-03,-5.3479241d-05 /
      data fpp( 5, 4,21,1),fpp( 5, 4,21,2),fpp( 5, 4,21,3)/
     x 1.1273832d-01,-2.1788469d-03,-1.6522689d-04 /
      data fpp( 5, 4,22,1),fpp( 5, 4,22,2),fpp( 5, 4,22,3)/
     x-7.4079276d-02,-2.5692193d-03,-7.4785017d-04 /
      data fpp( 5, 4,23,1),fpp( 5, 4,23,2),fpp( 5, 4,23,3)/
     x-9.7476534d-03, 4.4663513d-04,-1.0495404d-03 /
      data fpp( 5, 5, 1,1),fpp( 5, 5, 1,2),fpp( 5, 5, 1,3)/
     x 2.9790910d-03, 1.2438806d-03, 2.2322191d-04 /
      data fpp( 5, 5, 2,1),fpp( 5, 5, 2,2),fpp( 5, 5, 2,3)/
     x-4.7545209d-02, 2.7324710d-03, 5.2771180d-05 /
      data fpp( 5, 5, 3,1),fpp( 5, 5, 3,2),fpp( 5, 5, 3,3)/
     x-1.0086452d-01, 1.9575055d-03,-3.0815063d-04 /
      data fpp( 5, 5, 4,1),fpp( 5, 5, 4,2),fpp( 5, 5, 4,3)/
     x-1.0086452d-01, 1.9575055d-03,-3.1572770d-04 /
      data fpp( 5, 5, 5,1),fpp( 5, 5, 5,2),fpp( 5, 5, 5,3)/
     x-4.7545209d-02, 2.7324710d-03, 8.3079441d-05 /
      data fpp( 5, 5, 6,1),fpp( 5, 5, 6,2),fpp( 5, 5, 6,3)/
     x 2.9790910d-03, 1.2438806d-03, 1.0956593d-04 /
      data fpp( 5, 5, 7,1),fpp( 5, 5, 7,2),fpp( 5, 5, 7,3)/
     x 4.8923843d-02, 1.7982905d-04, 1.0088835d-05 /
      data fpp( 5, 5, 8,1),fpp( 5, 5, 8,2),fpp( 5, 5, 8,3)/
     x 6.2374792d-02, 6.5465076d-05, 6.2376730d-05 /
      data fpp( 5, 5, 9,1),fpp( 5, 5, 9,2),fpp( 5, 5, 9,3)/
     x 6.4028641d-02, 5.0577441d-05, 5.2020246d-05 /
      data fpp( 5, 5,10,1),fpp( 5, 5,10,2),fpp( 5, 5,10,3)/
     x 6.8480494d-02, 7.9984022d-05, 5.8402284d-05 /
      data fpp( 5, 5,11,1),fpp( 5, 5,11,2),fpp( 5, 5,11,3)/
     x 7.0416006d-02, 9.2533049d-05, 5.8830616d-05 /
      data fpp( 5, 5,12,1),fpp( 5, 5,12,2),fpp( 5, 5,12,3)/
     x 7.2110491d-02, 8.4191442d-05, 5.8301251d-05 /
      data fpp( 5, 5,13,1),fpp( 5, 5,13,2),fpp( 5, 5,13,3)/
     x 7.1076995d-02, 8.7876634d-05, 6.4922379d-05 /
      data fpp( 5, 5,14,1),fpp( 5, 5,14,2),fpp( 5, 5,14,3)/
     x 6.8548067d-02, 7.2410001d-05, 4.4637234d-05 /
      data fpp( 5, 5,15,1),fpp( 5, 5,15,2),fpp( 5, 5,15,3)/
     x 6.5430091d-02, 3.5829014d-05, 1.2514469d-04 /
      data fpp( 5, 5,16,1),fpp( 5, 5,16,2),fpp( 5, 5,16,3)/
     x-2.9833866d-01,-5.5212017d-05,-3.7111979d-05 /
      data fpp( 5, 5,17,1),fpp( 5, 5,17,2),fpp( 5, 5,17,3)/
     x 4.6284423d-02, 1.4675471d-04, 1.3958323d-04 /
      data fpp( 5, 5,18,1),fpp( 5, 5,18,2),fpp( 5, 5,18,3)/
     x 1.0189619d-01, 1.1218850d-03, 2.8289055d-05 /
      data fpp( 5, 5,19,1),fpp( 5, 5,19,2),fpp( 5, 5,19,3)/
     x-3.3116336d-02, 2.6910843d-03, 1.3577855d-04 /
      data fpp( 5, 5,20,1),fpp( 5, 5,20,2),fpp( 5, 5,20,3)/
     x-1.0588722d-01, 2.1029059d-03,-3.5209725d-04 /
      data fpp( 5, 5,21,1),fpp( 5, 5,21,2),fpp( 5, 5,21,3)/
     x-1.0588722d-01, 2.1029059d-03,-3.3618753d-04 /
      data fpp( 5, 5,22,1),fpp( 5, 5,22,2),fpp( 5, 5,22,3)/
     x-3.3116336d-02, 2.6910843d-03, 7.2139650d-05 /
      data fpp( 5, 5,23,1),fpp( 5, 5,23,2),fpp( 5, 5,23,3)/
     x 1.0189619d-01, 1.1218850d-03, 2.6693492d-04 /
      data fpp( 5, 6, 1,1),fpp( 5, 6, 1,2),fpp( 5, 6, 1,3)/
     x-3.0852353d-03,-2.8125471d-04,-1.1152609d-05 /
      data fpp( 5, 6, 2,1),fpp( 5, 6, 2,2),fpp( 5, 6, 2,3)/
     x 2.4018140d-03,-4.2888028d-04,-4.2017283d-05 /
      data fpp( 5, 6, 3,1),fpp( 5, 6, 3,2),fpp( 5, 6, 3,3)/
     x 6.9119911d-03, 1.7529489d-04,-1.0717626d-04 /
      data fpp( 5, 6, 4,1),fpp( 5, 6, 4,2),fpp( 5, 6, 4,3)/
     x 6.9119911d-03, 1.7529489d-04,-1.0889058d-04 /
      data fpp( 5, 6, 5,1),fpp( 5, 6, 5,2),fpp( 5, 6, 5,3)/
     x 2.4018140d-03,-4.2888028d-04,-3.5160026d-05 /
      data fpp( 5, 6, 6,1),fpp( 5, 6, 6,2),fpp( 5, 6, 6,3)/
     x-3.0852353d-03,-2.8125471d-04,-3.6867319d-05 /
      data fpp( 5, 6, 7,1),fpp( 5, 6, 7,2),fpp( 5, 6, 7,3)/
     x 6.1424411d-03, 3.1393605d-05, 2.8195303d-05 /
      data fpp( 5, 6, 8,1),fpp( 5, 6, 8,2),fpp( 5, 6, 8,3)/
     x 1.3520381d-02, 5.8401636d-05, 3.1276106d-05 /
      data fpp( 5, 6, 9,1),fpp( 5, 6, 9,2),fpp( 5, 6, 9,3)/
     x 1.8857227d-02, 6.9280572d-05, 4.2378273d-05 /
      data fpp( 5, 6,10,1),fpp( 5, 6,10,2),fpp( 5, 6,10,3)/
     x 2.4338849d-02, 6.3671465d-05, 4.5792801d-05 /
      data fpp( 5, 6,11,1),fpp( 5, 6,11,2),fpp( 5, 6,11,3)/
     x 2.7485360d-02, 5.9451952d-05, 4.8404522d-05 /
      data fpp( 5, 6,12,1),fpp( 5, 6,12,2),fpp( 5, 6,12,3)/
     x 2.5946037d-02, 5.9502682d-05, 4.9417109d-05 /
      data fpp( 5, 6,13,1),fpp( 5, 6,13,2),fpp( 5, 6,13,3)/
     x 2.5987228d-02, 5.5668468d-05, 5.1209041d-05 /
      data fpp( 5, 6,14,1),fpp( 5, 6,14,2),fpp( 5, 6,14,3)/
     x 1.2226421d-02, 5.5126254d-05, 4.9838728d-05 /
      data fpp( 5, 6,15,1),fpp( 5, 6,15,2),fpp( 5, 6,15,3)/
     x 2.2184816d-02, 6.0165950d-05, 5.2364048d-05 /
      data fpp( 5, 6,16,1),fpp( 5, 6,16,2),fpp( 5, 6,16,3)/
     x-1.5059903d-01, 1.1196941d-04, 4.8175081d-05 /
      data fpp( 5, 6,17,1),fpp( 5, 6,17,2),fpp( 5, 6,17,3)/
     x 1.1865619d-02, 1.5957001d-05, 4.7303628d-05 /
      data fpp( 5, 6,18,1),fpp( 5, 6,18,2),fpp( 5, 6,18,3)/
     x 2.7960160d-03,-2.2989308d-04, 1.7238408d-05 /
      data fpp( 5, 6,19,1),fpp( 5, 6,19,2),fpp( 5, 6,19,3)/
     x-1.2066305d-02,-5.9726998d-04, 5.7406739d-05 /
      data fpp( 5, 6,20,1),fpp( 5, 6,20,2),fpp( 5, 6,20,3)/
     x-6.9347158d-02,-3.6389481d-04,-2.2461737d-04 /
      data fpp( 5, 6,21,1),fpp( 5, 6,21,2),fpp( 5, 6,21,3)/
     x-6.9347158d-02,-3.6389481d-04,-2.1646327d-04 /
      data fpp( 5, 6,22,1),fpp( 5, 6,22,2),fpp( 5, 6,22,3)/
     x-1.2066305d-02,-5.9726998d-04, 2.4790363d-05 /
      data fpp( 5, 6,23,1),fpp( 5, 6,23,2),fpp( 5, 6,23,3)/
     x 2.7960160d-03,-2.2989308d-04, 1.3954982d-04 /
      data fpp( 5, 7, 1,1),fpp( 5, 7, 1,2),fpp( 5, 7, 1,3)/
     x-1.7440127d-02, 7.3396240d-05,-4.9859433d-05 /
      data fpp( 5, 7, 2,1),fpp( 5, 7, 2,2),fpp( 5, 7, 2,3)/
     x 2.0287471d-01,-1.6389908d-05,-5.3595635d-05 /
      data fpp( 5, 7, 3,1),fpp( 5, 7, 3,2),fpp( 5, 7, 3,3)/
     x-1.0043533d+00,-4.7910105d-04,-6.3988028d-05 /
      data fpp( 5, 7, 4,1),fpp( 5, 7, 4,2),fpp( 5, 7, 4,3)/
     x-1.0043533d+00,-4.7910105d-04,-5.9812099d-05 /
      data fpp( 5, 7, 5,1),fpp( 5, 7, 5,2),fpp( 5, 7, 5,3)/
     x 2.0287471d-01,-1.6389908d-05,-7.0299353d-05 /
      data fpp( 5, 7, 6,1),fpp( 5, 7, 6,2),fpp( 5, 7, 6,3)/
     x-1.7440127d-02, 7.3396240d-05, 1.2779509d-05 /
      data fpp( 5, 7, 7,1),fpp( 5, 7, 7,2),fpp( 5, 7, 7,3)/
     x-8.8523218d-03,-1.0273547d-04,-2.4066848d-06 /
      data fpp( 5, 7, 8,1),fpp( 5, 7, 8,2),fpp( 5, 7, 8,3)/
     x-2.4463087d-03,-7.0237618d-05, 1.4685230d-05 /
      data fpp( 5, 7, 9,1),fpp( 5, 7, 9,2),fpp( 5, 7, 9,3)/
     x-5.3826096d-04,-7.2093729d-05, 2.4011766d-05 /
      data fpp( 5, 7,10,1),fpp( 5, 7,10,2),fpp( 5, 7,10,3)/
     x 3.6917018d-03,-7.3297880d-05, 3.2565707d-05 /
      data fpp( 5, 7,11,1),fpp( 5, 7,11,2),fpp( 5, 7,11,3)/
     x 5.3006333d-03,-7.5058857d-05, 3.7317405d-05 /
      data fpp( 5, 7,12,1),fpp( 5, 7,12,2),fpp( 5, 7,12,3)/
     x 5.6255730d-03,-7.7108170d-05, 3.9696673d-05 /
      data fpp( 5, 7,13,1),fpp( 5, 7,13,2),fpp( 5, 7,13,3)/
     x 6.9271669d-03,-7.6850507d-05, 4.0295903d-05 /
      data fpp( 5, 7,14,1),fpp( 5, 7,14,2),fpp( 5, 7,14,3)/
     x 7.9436816d-03,-7.5547017d-05, 3.9737717d-05 /
      data fpp( 5, 7,15,1),fpp( 5, 7,15,2),fpp( 5, 7,15,3)/
     x 5.2488610d-03,-7.4994812d-05, 3.8455231d-05 /
      data fpp( 5, 7,16,1),fpp( 5, 7,16,2),fpp( 5, 7,16,3)/
     x 6.2902649d-03,-8.5141635d-05, 3.5173360d-05 /
      data fpp( 5, 7,17,1),fpp( 5, 7,17,2),fpp( 5, 7,17,3)/
     x 5.0889258d-03,-5.5326710d-05, 3.1013330d-05 /
      data fpp( 5, 7,18,1),fpp( 5, 7,18,2),fpp( 5, 7,18,3)/
     x-1.4949126d-03, 1.3741314d-05, 1.3585320d-05 /
      data fpp( 5, 7,19,1),fpp( 5, 7,19,2),fpp( 5, 7,19,3)/
     x 3.8092190d-03, 1.1419161d-04, 1.2799390d-05 /
      data fpp( 5, 7,20,1),fpp( 5, 7,20,2),fpp( 5, 7,20,3)/
     x 3.8506557d-03, 6.8995316d-05,-1.3960888d-04 /
      data fpp( 5, 7,21,1),fpp( 5, 7,21,2),fpp( 5, 7,21,3)/
     x 3.8506557d-03, 6.8995316d-05,-1.3627005d-04 /
      data fpp( 5, 7,22,1),fpp( 5, 7,22,2),fpp( 5, 7,22,3)/
     x 3.8092190d-03, 1.1419161d-04,-5.5591302d-07 /
      data fpp( 5, 7,23,1),fpp( 5, 7,23,2),fpp( 5, 7,23,3)/
     x-1.4949126d-03, 1.3741314d-05, 6.3667707d-05 /
      data fpp( 5, 8, 1,1),fpp( 5, 8, 1,2),fpp( 5, 8, 1,3)/
     x-2.8181222d-01,-2.5786225d-04,-2.2047652d-04 /
      data fpp( 5, 8, 2,1),fpp( 5, 8, 2,2),fpp( 5, 8, 2,3)/
     x 1.2000719d-01,-4.0795409d-04,-1.1813097d-04 /
      data fpp( 5, 8, 3,1),fpp( 5, 8, 3,2),fpp( 5, 8, 3,3)/
     x-1.1851388d-02,-4.4292713d-05, 9.6792389d-05 /
      data fpp( 5, 8, 4,1),fpp( 5, 8, 4,2),fpp( 5, 8, 4,3)/
     x-1.1851388d-02,-4.4292713d-05, 1.0447232d-04 /
      data fpp( 5, 8, 5,1),fpp( 5, 8, 5,2),fpp( 5, 8, 5,3)/
     x 1.2000719d-01,-4.0795409d-04,-1.4885068d-04 /
      data fpp( 5, 8, 6,1),fpp( 5, 8, 6,2),fpp( 5, 8, 6,3)/
     x-2.8181222d-01,-2.5786225d-04,-1.0527760d-04 /
      data fpp( 5, 8, 7,1),fpp( 5, 8, 7,2),fpp( 5, 8, 7,3)/
     x-1.1434808d-02, 1.2147027d-04, 1.1811083d-05 /
      data fpp( 5, 8, 8,1),fpp( 5, 8, 8,2),fpp( 5, 8, 8,3)/
     x-7.5644633d-03,-4.8363165d-05,-1.3768731d-05 /
      data fpp( 5, 8, 9,1),fpp( 5, 8, 9,2),fpp( 5, 8, 9,3)/
     x-1.5323207d-02,-6.4801654d-05, 8.1278419d-06 /
      data fpp( 5, 8,10,1),fpp( 5, 8,10,2),fpp( 5, 8,10,3)/
     x-5.5776637d-03,-6.9747944d-05, 1.8883363d-05 /
      data fpp( 5, 8,11,1),fpp( 5, 8,11,2),fpp( 5, 8,11,3)/
     x-1.1796823d-02,-7.1846525d-05, 2.7578704d-05 /
      data fpp( 5, 8,12,1),fpp( 5, 8,12,2),fpp( 5, 8,12,3)/
     x-1.0026079d-02,-7.1182001d-05, 3.0917820d-05 /
      data fpp( 5, 8,13,1),fpp( 5, 8,13,2),fpp( 5, 8,13,3)/
     x-8.3810839d-03,-6.8582439d-05, 3.1546017d-05 /
      data fpp( 5, 8,14,1),fpp( 5, 8,14,2),fpp( 5, 8,14,3)/
     x-6.9876974d-04,-6.3462185d-05, 3.0038114d-05 /
      data fpp( 5, 8,15,1),fpp( 5, 8,15,2),fpp( 5, 8,15,3)/
     x-7.4327846d-03,-5.4348703d-05, 2.7347527d-05 /
      data fpp( 5, 8,16,1),fpp( 5, 8,16,2),fpp( 5, 8,16,3)/
     x 2.5126361d-03,-3.6560874d-05, 2.3207778d-05 /
      data fpp( 5, 8,17,1),fpp( 5, 8,17,2),fpp( 5, 8,17,3)/
     x-6.2086347d-03,-2.0982161d-05, 1.7599362d-05 /
      data fpp( 5, 8,18,1),fpp( 5, 8,18,2),fpp( 5, 8,18,3)/
     x-4.6762902d-03,-4.0461793d-06, 5.9227754d-06 /
      data fpp( 5, 8,19,1),fpp( 5, 8,19,2),fpp( 5, 8,19,3)/
     x-9.0273833d-04, 2.0611532d-05,-6.9224634d-06 /
      data fpp( 5, 8,20,1),fpp( 5, 8,20,2),fpp( 5, 8,20,3)/
     x 6.1797288d-03, 1.0216354d-04,-7.5072922d-05 /
      data fpp( 5, 8,21,1),fpp( 5, 8,21,2),fpp( 5, 8,21,3)/
     x 6.1797288d-03, 1.0216354d-04,-7.4173002d-05 /
      data fpp( 5, 8,22,1),fpp( 5, 8,22,2),fpp( 5, 8,22,3)/
     x-9.0273833d-04, 2.0611532d-05,-1.0522142d-05 /
      data fpp( 5, 8,23,1),fpp( 5, 8,23,2),fpp( 5, 8,23,3)/
     x-4.6762902d-03,-4.0461793d-06, 1.9421571d-05 /
      data fpp( 5, 9, 1,1),fpp( 5, 9, 1,2),fpp( 5, 9, 1,3)/
     x-3.4016769d-02,-3.1820124d-04, 4.7538134d-05 /
      data fpp( 5, 9, 2,1),fpp( 5, 9, 2,2),fpp( 5, 9, 2,3)/
     x-1.2659766d-02,-3.6597253d-06, 6.8080732d-05 /
      data fpp( 5, 9, 3,1),fpp( 5, 9, 3,2),fpp( 5, 9, 3,3)/
     x 2.1836164d-03,-7.2356104d-05, 1.1480294d-04 /
      data fpp( 5, 9, 4,1),fpp( 5, 9, 4,2),fpp( 5, 9, 4,3)/
     x 2.1836164d-03,-7.2356104d-05, 1.1007382d-04 /
      data fpp( 5, 9, 5,1),fpp( 5, 9, 5,2),fpp( 5, 9, 5,3)/
     x-1.2659766d-02,-3.6597253d-06, 8.6997222d-05 /
      data fpp( 5, 9, 6,1),fpp( 5, 9, 6,2),fpp( 5, 9, 6,3)/
     x-3.4016769d-02,-3.1820124d-04,-2.3398704d-05 /
      data fpp( 5, 9, 7,1),fpp( 5, 9, 7,2),fpp( 5, 9, 7,3)/
     x 8.6714033d-01,-5.6153162d-04,-3.6585840d-04 /
      data fpp( 5, 9, 8,1),fpp( 5, 9, 8,2),fpp( 5, 9, 8,3)/
     x-3.1109621d-02,-6.1761723d-05, 8.0456322d-05 /
      data fpp( 5, 9, 9,1),fpp( 5, 9, 9,2),fpp( 5, 9, 9,3)/
     x-2.1547461d-02,-6.5287653d-05,-3.0654883d-05 /
      data fpp( 5, 9,10,1),fpp( 5, 9,10,2),fpp( 5, 9,10,3)/
     x-7.0694641d-03,-7.3548345d-05, 1.6003212d-05 /
      data fpp( 5, 9,11,1),fpp( 5, 9,11,2),fpp( 5, 9,11,3)/
     x-2.4544242d-02,-7.2387042d-05, 1.7786036d-05 /
      data fpp( 5, 9,12,1),fpp( 5, 9,12,2),fpp( 5, 9,12,3)/
     x-2.2609114d-02,-6.8873826d-05, 2.4668643d-05 /
      data fpp( 5, 9,13,1),fpp( 5, 9,13,2),fpp( 5, 9,13,3)/
     x-2.0418529d-02,-6.3401738d-05, 2.4737390d-05 /
      data fpp( 5, 9,14,1),fpp( 5, 9,14,2),fpp( 5, 9,14,3)/
     x-3.3966482d-03,-5.5900243d-05, 2.3201796d-05 /
      data fpp( 5, 9,15,1),fpp( 5, 9,15,2),fpp( 5, 9,15,3)/
     x-1.6918438d-02,-4.5884375d-05, 2.0581427d-05 /
      data fpp( 5, 9,16,1),fpp( 5, 9,16,2),fpp( 5, 9,16,3)/
     x 6.5637003d-04,-3.3772868d-05, 1.7106498d-05 /
      data fpp( 5, 9,17,1),fpp( 5, 9,17,2),fpp( 5, 9,17,3)/
     x-1.3146748d-02,-1.6114647d-05, 1.3058583d-05 /
      data fpp( 5, 9,18,1),fpp( 5, 9,18,2),fpp( 5, 9,18,3)/
     x-8.5107239d-03, 5.8154035d-06, 5.8571719d-06 /
      data fpp( 5, 9,19,1),fpp( 5, 9,19,2),fpp( 5, 9,19,3)/
     x 9.9722993d-04, 2.9580258d-05,-1.8012704d-06 /
      data fpp( 5, 9,20,1),fpp( 5, 9,20,2),fpp( 5, 9,20,3)/
     x 1.9235405d-02, 3.8476513d-05,-5.0444090d-05 /
      data fpp( 5, 9,21,1),fpp( 5, 9,21,2),fpp( 5, 9,21,3)/
     x 1.9235405d-02, 3.8476513d-05,-4.9730093d-05 /
      data fpp( 5, 9,22,1),fpp( 5, 9,22,2),fpp( 5, 9,22,3)/
     x 9.9722993d-04, 2.9580258d-05,-4.6572590d-06 /
      data fpp( 5, 9,23,1),fpp( 5, 9,23,2),fpp( 5, 9,23,3)/
     x-8.5107239d-03, 5.8154035d-06, 1.6567130d-05 /
      data fpp( 5,10, 1,1),fpp( 5,10, 1,2),fpp( 5,10, 1,3)/
     x-1.6522080d-02, 7.5853203d-05, 7.2491321d-05 /
      data fpp( 5,10, 2,1),fpp( 5,10, 2,2),fpp( 5,10, 2,3)/
     x 1.7268915d-02, 4.0908993d-05, 8.9980358d-05 /
      data fpp( 5,10, 3,1),fpp( 5,10, 3,2),fpp( 5,10, 3,3)/
     x 5.0961177d-02, 1.2048313d-04, 1.2844325d-04 /
      data fpp( 5,10, 4,1),fpp( 5,10, 4,2),fpp( 5,10, 4,3)/
     x 5.0961177d-02, 1.2048313d-04, 1.2671708d-04 /
      data fpp( 5,10, 5,1),fpp( 5,10, 5,2),fpp( 5,10, 5,3)/
     x 1.7268915d-02, 4.0908993d-05, 9.6885004d-05 /
      data fpp( 5,10, 6,1),fpp( 5,10, 6,2),fpp( 5,10, 6,3)/
     x-1.6522080d-02, 7.5853203d-05, 4.6598900d-05 /
      data fpp( 5,10, 7,1),fpp( 5,10, 7,2),fpp( 5,10, 7,3)/
     x-8.0689979d-02,-1.4427778d-05,-8.1182604d-05 /
      data fpp( 5,10, 8,1),fpp( 5,10, 8,2),fpp( 5,10, 8,3)/
     x 4.5996485d-03,-3.8699994d-04,-3.2187448d-04 /
      data fpp( 5,10, 9,1),fpp( 5,10, 9,2),fpp( 5,10, 9,3)/
     x-1.0531239d-03,-1.4001973d-04, 1.4204536d-05 /
      data fpp( 5,10,10,1),fpp( 5,10,10,2),fpp( 5,10,10,3)/
     x 7.3476115d-03,-7.3806676d-05,-1.3103660d-05 /
      data fpp( 5,10,11,1),fpp( 5,10,11,2),fpp( 5,10,11,3)/
     x-1.2302208d-01,-6.1125306d-05, 1.6262106d-05 /
      data fpp( 5,10,12,1),fpp( 5,10,12,2),fpp( 5,10,12,3)/
     x-1.2795287d-01,-5.4050697d-05, 1.8135236d-05 /
      data fpp( 5,10,13,1),fpp( 5,10,13,2),fpp( 5,10,13,3)/
     x-2.4689702d-03,-4.7248610d-05, 2.0294949d-05 /
      data fpp( 5,10,14,1),fpp( 5,10,14,2),fpp( 5,10,14,3)/
     x-1.1451930d-01,-3.9408842d-05, 1.8860968d-05 /
      data fpp( 5,10,15,1),fpp( 5,10,15,2),fpp( 5,10,15,3)/
     x-4.2952152d-04,-3.0067796d-05, 1.7019180d-05 /
      data fpp( 5,10,16,1),fpp( 5,10,16,2),fpp( 5,10,16,3)/
     x 6.9784790d-04,-1.9135655d-05, 1.4342312d-05 /
      data fpp( 5,10,17,1),fpp( 5,10,17,2),fpp( 5,10,17,3)/
     x 1.2611382d-03,-8.5912497d-06, 1.1555571d-05 /
      data fpp( 5,10,18,1),fpp( 5,10,18,2),fpp( 5,10,18,3)/
     x 3.8483123d-03, 7.1656522d-07, 7.5114035d-06 /
      data fpp( 5,10,19,1),fpp( 5,10,19,2),fpp( 5,10,19,3)/
     x 1.2348114d-02, 8.9314368d-06, 7.3708149d-06 /
      data fpp( 5,10,20,1),fpp( 5,10,20,2),fpp( 5,10,20,3)/
     x 3.5605231d-02, 2.0866407d-05,-4.2598663d-05 /
      data fpp( 5,10,21,1),fpp( 5,10,21,2),fpp( 5,10,21,3)/
     x 3.5605231d-02, 2.0866407d-05,-4.1498418d-05 /
      data fpp( 5,10,22,1),fpp( 5,10,22,2),fpp( 5,10,22,3)/
     x 1.2348114d-02, 8.9314368d-06, 2.9698337d-06 /
      data fpp( 5,10,23,1),fpp( 5,10,23,2),fpp( 5,10,23,3)/
     x 3.8483123d-03, 7.1656522d-07, 2.4015083d-05 /
      data fpp( 5,11, 1,1),fpp( 5,11, 1,2),fpp( 5,11, 1,3)/
     x 3.1231870d-02, 9.7156424d-05, 1.6000559d-04 /
      data fpp( 5,11, 2,1),fpp( 5,11, 2,2),fpp( 5,11, 2,3)/
     x 1.0928414d-01, 2.4877375d-04, 1.3579882d-04 /
      data fpp( 5,11, 3,1),fpp( 5,11, 3,2),fpp( 5,11, 3,3)/
     x 2.0567894d-01, 4.2880359d-04, 8.7095122d-05 /
      data fpp( 5,11, 4,1),fpp( 5,11, 4,2),fpp( 5,11, 4,3)/
     x 2.0567894d-01, 4.2880359d-04, 8.1551223d-05 /
      data fpp( 5,11, 5,1),fpp( 5,11, 5,2),fpp( 5,11, 5,3)/
     x 1.0928414d-01, 2.4877375d-04, 1.5797442d-04 /
      data fpp( 5,11, 6,1),fpp( 5,11, 6,2),fpp( 5,11, 6,3)/
     x 3.1231870d-02, 9.7156424d-05, 7.6847095d-05 /
      data fpp( 5,11, 7,1),fpp( 5,11, 7,2),fpp( 5,11, 7,3)/
     x-2.9106299d-02, 4.9680735d-05,-1.4258802d-05 /
      data fpp( 5,11, 8,1),fpp( 5,11, 8,2),fpp( 5,11, 8,3)/
     x-8.9587120d-02, 4.4577498d-05,-1.5713989d-04 /
      data fpp( 5,11, 9,1),fpp( 5,11, 9,2),fpp( 5,11, 9,3)/
     x 3.1346177d-03,-1.4750541d-04,-2.0351165d-04 /
      data fpp( 5,11,10,1),fpp( 5,11,10,2),fpp( 5,11,10,3)/
     x 3.8162524d-02,-8.4602951d-05,-3.1791523d-05 /
      data fpp( 5,11,11,1),fpp( 5,11,11,2),fpp( 5,11,11,3)/
     x 1.6395315d-02,-5.1643733d-05, 9.8974051d-07 /
      data fpp( 5,11,12,1),fpp( 5,11,12,2),fpp( 5,11,12,3)/
     x 7.8922545d-03,-4.0717388d-05, 1.4068561d-05 /
      data fpp( 5,11,13,1),fpp( 5,11,13,2),fpp( 5,11,13,3)/
     x 5.5270091d-03,-3.4151823d-05, 1.6242014d-05 /
      data fpp( 5,11,14,1),fpp( 5,11,14,2),fpp( 5,11,14,3)/
     x-9.2796205d-02,-2.7994390d-05, 1.6267381d-05 /
      data fpp( 5,11,15,1),fpp( 5,11,15,2),fpp( 5,11,15,3)/
     x 4.3460402d-03,-2.1428441d-05, 1.5006460d-05 /
      data fpp( 5,11,16,1),fpp( 5,11,16,2),fpp( 5,11,16,3)/
     x 3.3083285d-03,-1.4718511d-05, 1.2236779d-05 /
      data fpp( 5,11,17,1),fpp( 5,11,17,2),fpp( 5,11,17,3)/
     x 1.8362657d-03,-7.9903536d-06, 9.8824251d-06 /
      data fpp( 5,11,18,1),fpp( 5,11,18,2),fpp( 5,11,18,3)/
     x 2.2546953d-03,-1.7036644d-06, 8.0715207d-06 /
      data fpp( 5,11,19,1),fpp( 5,11,19,2),fpp( 5,11,19,3)/
     x 1.2116209d-02, 3.3939952d-06, 1.7363492d-05 /
      data fpp( 5,11,20,1),fpp( 5,11,20,2),fpp( 5,11,20,3)/
     x-1.2697233d-01, 3.4158596d-06,-4.2005489d-05 /
      data fpp( 5,11,21,1),fpp( 5,11,21,2),fpp( 5,11,21,3)/
     x-1.2697233d-01, 3.4158596d-06,-4.0249279d-05 /
      data fpp( 5,11,22,1),fpp( 5,11,22,2),fpp( 5,11,22,3)/
     x 1.2116209d-02, 3.3939952d-06, 1.0338651d-05 /
      data fpp( 5,11,23,1),fpp( 5,11,23,2),fpp( 5,11,23,3)/
     x 2.2546953d-03,-1.7036644d-06, 3.4414674d-05 /
      data fpp( 5,12, 1,1),fpp( 5,12, 1,2),fpp( 5,12, 1,3)/
     x 1.1292681d-01, 1.7762310d-04, 4.0439331d-04 /
      data fpp( 5,12, 2,1),fpp( 5,12, 2,2),fpp( 5,12, 2,3)/
     x 3.2528823d-01, 3.0939399d-04, 2.4610539d-04 /
      data fpp( 5,12, 3,1),fpp( 5,12, 3,2),fpp( 5,12, 3,3)/
     x 5.5138639d-01, 4.9774453d-04,-8.4330849d-05 /
      data fpp( 5,12, 4,1),fpp( 5,12, 4,2),fpp( 5,12, 4,3)/
     x 5.5138639d-01, 4.9774453d-04,-9.9647145d-05 /
      data fpp( 5,12, 5,1),fpp( 5,12, 5,2),fpp( 5,12, 5,3)/
     x 3.2528823d-01, 3.0939399d-04, 3.0737057d-04 /
      data fpp( 5,12, 6,1),fpp( 5,12, 6,2),fpp( 5,12, 6,3)/
     x 1.1292681d-01, 1.7762310d-04, 1.7464887d-04 /
      data fpp( 5,12, 7,1),fpp( 5,12, 7,2),fpp( 5,12, 7,3)/
     x 1.1614680d-02, 9.3918837d-05, 3.3551942d-05 /
      data fpp( 5,12, 8,1),fpp( 5,12, 8,2),fpp( 5,12, 8,3)/
     x-4.8561020d-02, 3.2313952d-05,-7.4208642d-05 /
      data fpp( 5,12, 9,1),fpp( 5,12, 9,2),fpp( 5,12, 9,3)/
     x-6.3582832d-02,-7.7662192d-07,-1.7475338d-04 /
      data fpp( 5,12,10,1),fpp( 5,12,10,2),fpp( 5,12,10,3)/
     x 2.8693215d-02,-5.5421520d-05,-1.3695386d-04 /
      data fpp( 5,12,11,1),fpp( 5,12,11,2),fpp( 5,12,11,3)/
     x 3.5846715d-02,-3.8617761d-05,-1.6715203d-05 /
      data fpp( 5,12,12,1),fpp( 5,12,12,2),fpp( 5,12,12,3)/
     x 2.2594463d-02,-2.9415750d-05, 4.8666662d-06 /
      data fpp( 5,12,13,1),fpp( 5,12,13,2),fpp( 5,12,13,3)/
     x 1.6987527d-02,-2.4770099d-05, 1.2890538d-05 /
      data fpp( 5,12,14,1),fpp( 5,12,14,2),fpp( 5,12,14,3)/
     x-7.8085463d-02,-2.1491597d-05, 1.4041183d-05 /
      data fpp( 5,12,15,1),fpp( 5,12,15,2),fpp( 5,12,15,3)/
     x 1.3224621d-02,-1.8804438d-05, 1.3366731d-05 /
      data fpp( 5,12,16,1),fpp( 5,12,16,2),fpp( 5,12,16,3)/
     x 1.1207825d-02,-1.6400302d-05, 1.0155892d-05 /
      data fpp( 5,12,17,1),fpp( 5,12,17,2),fpp( 5,12,17,3)/
     x 8.8316487d-03,-1.3771336d-05, 7.6477000d-06 /
      data fpp( 5,12,18,1),fpp( 5,12,18,2),fpp( 5,12,18,3)/
     x 9.3105802d-03,-1.1049908d-05, 7.9433077d-06 /
      data fpp( 5,12,19,1),fpp( 5,12,19,2),fpp( 5,12,19,3)/
     x 2.4231057d-02,-1.2589418d-05, 2.0561069d-05 /
      data fpp( 5,12,20,1),fpp( 5,12,20,2),fpp( 5,12,20,3)/
     x 6.4268225d-01,-2.4467845d-05,-4.0465584d-05 /
      data fpp( 5,12,21,1),fpp( 5,12,21,2),fpp( 5,12,21,3)/
     x 6.4268225d-01,-2.4467845d-05,-3.8514783d-05 /
      data fpp( 5,12,22,1),fpp( 5,12,22,2),fpp( 5,12,22,3)/
     x 2.4231057d-02,-1.2589418d-05, 1.2757867d-05 /
      data fpp( 5,12,23,1),fpp( 5,12,23,2),fpp( 5,12,23,3)/
     x 9.3105802d-03,-1.1049908d-05, 3.7205317d-05 /
      data fpp( 5,13, 1,1),fpp( 5,13, 1,2),fpp( 5,13, 1,3)/
     x 1.8786745d-01, 6.4385179d-05, 6.9951046d-04 /
      data fpp( 5,13, 2,1),fpp( 5,13, 2,2),fpp( 5,13, 2,3)/
     x 6.5583342d-01,-1.3160373d-04, 3.6960409d-04 /
      data fpp( 5,13, 3,1),fpp( 5,13, 3,2),fpp( 5,13, 3,3)/
     x 1.5706046d+00,-5.4501570d-04,-3.2194681d-04 /
      data fpp( 5,13, 4,1),fpp( 5,13, 4,2),fpp( 5,13, 4,3)/
     x 1.5706046d+00,-5.4501570d-04,-3.4888162d-04 /
      data fpp( 5,13, 5,1),fpp( 5,13, 5,2),fpp( 5,13, 5,3)/
     x 6.5583342d-01,-1.3160373d-04, 4.7734332d-04 /
      data fpp( 5,13, 6,1),fpp( 5,13, 6,2),fpp( 5,13, 6,3)/
     x 1.8786745d-01, 6.4385179d-05, 2.9548832d-04 /
      data fpp( 5,13, 7,1),fpp( 5,13, 7,2),fpp( 5,13, 7,3)/
     x 5.6210506d-02, 9.8935918d-05, 1.0360540d-04 /
      data fpp( 5,13, 8,1),fpp( 5,13, 8,2),fpp( 5,13, 8,3)/
     x-1.7995727d-02, 7.6144694d-05,-2.9857914d-05 /
      data fpp( 5,13, 9,1),fpp( 5,13, 9,2),fpp( 5,13, 9,3)/
     x-5.8815273d-02, 2.9927899d-05,-1.1026374d-04 /
      data fpp( 5,13,10,1),fpp( 5,13,10,2),fpp( 5,13,10,3)/
     x-2.6473242d-02,-1.0630969d-05,-1.7203512d-04 /
      data fpp( 5,13,11,1),fpp( 5,13,11,2),fpp( 5,13,11,3)/
     x 3.7696173d-02,-1.9359224d-05,-6.2793775d-05 /
      data fpp( 5,13,12,1),fpp( 5,13,12,2),fpp( 5,13,12,3)/
     x 3.4361714d-02,-1.7461610d-05,-2.7357806d-06 /
      data fpp( 5,13,13,1),fpp( 5,13,13,2),fpp( 5,13,13,3)/
     x 2.8278910d-02,-1.6983781d-05, 7.5088970d-06 /
      data fpp( 5,13,14,1),fpp( 5,13,14,2),fpp( 5,13,14,3)/
     x-4.6839517d-02,-1.7265221d-05, 1.1700193d-05 /
      data fpp( 5,13,15,1),fpp( 5,13,15,2),fpp( 5,13,15,3)/
     x 2.4294258d-02,-1.8553805d-05, 1.1252333d-05 /
      data fpp( 5,13,16,1),fpp( 5,13,16,2),fpp( 5,13,16,3)/
     x 2.3241251d-02,-2.0654281d-05, 8.2884760d-06 /
      data fpp( 5,13,17,1),fpp( 5,13,17,2),fpp( 5,13,17,3)/
     x 2.2914202d-02,-2.3114303d-05, 5.5917632d-06 /
      data fpp( 5,13,18,1),fpp( 5,13,18,2),fpp( 5,13,18,3)/
     x 2.7380189d-02,-2.6492705d-05, 5.8964713d-06 /
      data fpp( 5,13,19,1),fpp( 5,13,19,2),fpp( 5,13,19,3)/
     x 4.7689167d-02,-3.2416324d-05, 1.0476352d-05 /
      data fpp( 5,13,20,1),fpp( 5,13,20,2),fpp( 5,13,20,3)/
     x 6.4075980d-01,-3.8360479d-05,-3.0329878d-05 /
      data fpp( 5,13,21,1),fpp( 5,13,21,2),fpp( 5,13,21,3)/
     x 6.4075980d-01,-3.8360479d-05,-2.9208543d-05 /
      data fpp( 5,13,22,1),fpp( 5,13,22,2),fpp( 5,13,22,3)/
     x 4.7689167d-02,-3.2416324d-05, 5.9910122d-06 /
      data fpp( 5,13,23,1),fpp( 5,13,23,2),fpp( 5,13,23,3)/
     x 2.7380189d-02,-2.6492705d-05, 2.2716494d-05 /
      data fpp( 5,14, 1,1),fpp( 5,14, 1,2),fpp( 5,14, 1,3)/
     x 2.7310689d-01,-1.0255816d-05, 5.9643165d-04 /
      data fpp( 5,14, 2,1),fpp( 5,14, 2,2),fpp( 5,14, 2,3)/
     x 6.8234466d-01,-2.7253108d-04, 3.0361469d-04 /
      data fpp( 5,14, 3,1),fpp( 5,14, 3,2),fpp( 5,14, 3,3)/
     x 1.6288510d+00,-6.3093373d-04,-3.1265443d-04 /
      data fpp( 5,14, 4,1),fpp( 5,14, 4,2),fpp( 5,14, 4,3)/
     x 1.6288510d+00,-6.3093373d-04,-3.3224706d-04 /
      data fpp( 5,14, 5,1),fpp( 5,14, 5,2),fpp( 5,14, 5,3)/
     x 6.8234466d-01,-2.7253108d-04, 3.8198524d-04 /
      data fpp( 5,14, 6,1),fpp( 5,14, 6,2),fpp( 5,14, 6,3)/
     x 2.7310689d-01,-1.0255816d-05, 3.0254209d-04 /
      data fpp( 5,14, 7,1),fpp( 5,14, 7,2),fpp( 5,14, 7,3)/
     x 8.7179706d-02, 8.5407491d-05, 1.2983439d-04 /
      data fpp( 5,14, 8,1),fpp( 5,14, 8,2),fpp( 5,14, 8,3)/
     x 5.2226553d-03, 8.9743273d-05, 4.9803373d-06 /
      data fpp( 5,14, 9,1),fpp( 5,14, 9,2),fpp( 5,14, 9,3)/
     x-4.3368454d-02, 6.1419027d-05,-6.1747742d-05 /
      data fpp( 5,14,10,1),fpp( 5,14,10,2),fpp( 5,14,10,3)/
     x-5.9777848d-02, 1.8937397d-05,-1.4678937d-04 /
      data fpp( 5,14,11,1),fpp( 5,14,11,2),fpp( 5,14,11,3)/
     x 1.5077919d-02, 3.4465741d-07,-1.1154678d-04 /
      data fpp( 5,14,12,1),fpp( 5,14,12,2),fpp( 5,14,12,3)/
     x-2.2841601d-02,-4.8198099d-06,-1.1637504d-05 /
      data fpp( 5,14,13,1),fpp( 5,14,13,2),fpp( 5,14,13,3)/
     x 3.5612255d-02,-8.0707774d-06, 1.6767982d-06 /
      data fpp( 5,14,14,1),fpp( 5,14,14,2),fpp( 5,14,14,3)/
     x 3.3819558d-02,-1.0931520d-05, 8.4463114d-06 /
      data fpp( 5,14,15,1),fpp( 5,14,15,2),fpp( 5,14,15,3)/
     x 3.3330817d-02,-1.4014340d-05, 8.3979564d-06 /
      data fpp( 5,14,16,1),fpp( 5,14,16,2),fpp( 5,14,16,3)/
     x 3.3642862d-02,-1.7610575d-05, 6.2498631d-06 /
      data fpp( 5,14,17,1),fpp( 5,14,17,2),fpp( 5,14,17,3)/
     x 3.5365963d-02,-2.1535452d-05, 3.4185910d-06 /
      data fpp( 5,14,18,1),fpp( 5,14,18,2),fpp( 5,14,18,3)/
     x 4.0933088d-02,-2.4813272d-05, 1.5557727d-06 /
      data fpp( 5,14,19,1),fpp( 5,14,19,2),fpp( 5,14,19,3)/
     x 5.4371246d-02,-2.4095285d-05,-7.6168169d-07 /
      data fpp( 5,14,20,1),fpp( 5,14,20,2),fpp( 5,14,20,3)/
     x 7.4717431d-02,-1.6232240d-05,-1.6563046d-05 /
      data fpp( 5,14,21,1),fpp( 5,14,21,2),fpp( 5,14,21,3)/
     x 7.4717431d-02,-1.6232240d-05,-1.6323021d-05 /
      data fpp( 5,14,22,1),fpp( 5,14,22,2),fpp( 5,14,22,3)/
     x 5.4371246d-02,-2.4095285d-05,-1.7217796d-06 /
      data fpp( 5,14,23,1),fpp( 5,14,23,2),fpp( 5,14,23,3)/
     x 4.0933088d-02,-2.4813272d-05, 5.1561398d-06 /
      data fpp( 5,15, 1,1),fpp( 5,15, 1,2),fpp( 5,15, 1,3)/
     x 1.9969106d-01, 1.2849809d-04, 2.3950543d-04 /
      data fpp( 5,15, 2,1),fpp( 5,15, 2,2),fpp( 5,15, 2,3)/
     x 3.5233605d-01, 2.2496006d-04, 1.3341814d-04 /
      data fpp( 5,15, 3,1),fpp( 5,15, 3,2),fpp( 5,15, 3,3)/
     x 6.8208101d-01, 4.6466660d-04,-9.1373994d-05 /
      data fpp( 5,15, 4,1),fpp( 5,15, 4,2),fpp( 5,15, 4,3)/
     x 6.8208101d-01, 4.6466660d-04,-9.5815087d-05 /
      data fpp( 5,15, 5,1),fpp( 5,15, 5,2),fpp( 5,15, 5,3)/
     x 3.5233605d-01, 2.2496006d-04, 1.5118251d-04 /
      data fpp( 5,15, 6,1),fpp( 5,15, 6,2),fpp( 5,15, 6,3)/
     x 1.9969106d-01, 1.2849809d-04, 1.7288904d-04 /
      data fpp( 5,15, 7,1),fpp( 5,15, 7,2),fpp( 5,15, 7,3)/
     x 8.0977256d-02, 1.1328212d-04, 9.1695332d-05 /
      data fpp( 5,15, 8,1),fpp( 5,15, 8,2),fpp( 5,15, 8,3)/
     x 1.5758976d-02, 1.0475021d-04, 1.8029634d-05 /
      data fpp( 5,15, 9,1),fpp( 5,15, 9,2),fpp( 5,15, 9,3)/
     x-2.6992473d-02, 8.1215993d-05,-3.0775867d-05 /
      data fpp( 5,15,10,1),fpp( 5,15,10,2),fpp( 5,15,10,3)/
     x-6.3877484d-02, 4.6049383d-05,-9.2182166d-05 /
      data fpp( 5,15,11,1),fpp( 5,15,11,2),fpp( 5,15,11,3)/
     x-3.4289038d-02, 4.3125946d-06,-1.3938547d-04 /
      data fpp( 5,15,12,1),fpp( 5,15,12,2),fpp( 5,15,12,3)/
     x 1.0403615d-02, 5.5468496d-06,-2.6247956d-05 /
      data fpp( 5,15,13,1),fpp( 5,15,13,2),fpp( 5,15,13,3)/
     x 3.8551147d-02, 7.9289064d-07,-1.9887078d-06 /
      data fpp( 5,15,14,1),fpp( 5,15,14,2),fpp( 5,15,14,3)/
     x 3.8040172d-02,-2.5366976d-06, 4.4607868d-06 /
      data fpp( 5,15,15,1),fpp( 5,15,15,2),fpp( 5,15,15,3)/
     x 3.8044215d-02,-5.0148343d-06, 5.2595606d-06 /
      data fpp( 5,15,16,1),fpp( 5,15,16,2),fpp( 5,15,16,3)/
     x 3.8621652d-02,-6.7574206d-06, 3.9489707d-06 /
      data fpp( 5,15,17,1),fpp( 5,15,17,2),fpp( 5,15,17,3)/
     x 4.0107522d-02,-7.7978900d-06, 1.6065567d-06 /
      data fpp( 5,15,18,1),fpp( 5,15,18,2),fpp( 5,15,18,3)/
     x 4.2920844d-02,-7.4662061d-06,-9.2519763d-07 /
      data fpp( 5,15,19,1),fpp( 5,15,19,2),fpp( 5,15,19,3)/
     x 4.7687841d-02,-4.3425370d-06,-3.5697662d-06 /
      data fpp( 5,15,20,1),fpp( 5,15,20,2),fpp( 5,15,20,3)/
     x 5.2981740d-02, 7.6743712d-07,-7.8297375d-06 /
      data fpp( 5,15,21,1),fpp( 5,15,21,2),fpp( 5,15,21,3)/
     x 5.2981740d-02, 7.6743712d-07,-7.8609044d-06 /
      data fpp( 5,15,22,1),fpp( 5,15,22,2),fpp( 5,15,22,3)/
     x 4.7687841d-02,-4.3425370d-06,-3.4450988d-06 /
      data fpp( 5,15,23,1),fpp( 5,15,23,2),fpp( 5,15,23,3)/
     x 4.2920844d-02,-7.4662061d-06,-1.3927006d-06 /
      data fpp( 5,16, 1,1),fpp( 5,16, 1,2),fpp( 5,16, 1,3)/
     x 1.0015808d-01, 1.9991347d-04, 7.7933251d-05 /
      data fpp( 5,16, 2,1),fpp( 5,16, 2,2),fpp( 5,16, 2,3)/
     x 1.4907119d-01, 3.3309883d-04, 6.1741498d-05 /
      data fpp( 5,16, 3,1),fpp( 5,16, 3,2),fpp( 5,16, 3,3)/
     x 2.1336180d-01, 4.7645331d-04, 2.7492758d-05 /
      data fpp( 5,16, 4,1),fpp( 5,16, 4,2),fpp( 5,16, 4,3)/
     x 2.1336180d-01, 4.7645331d-04, 2.6708977d-05 /
      data fpp( 5,16, 5,1),fpp( 5,16, 5,2),fpp( 5,16, 5,3)/
     x 1.4907119d-01, 3.3309883d-04, 6.4876625d-05 /
      data fpp( 5,16, 6,1),fpp( 5,16, 6,2),fpp( 5,16, 6,3)/
     x 1.0015808d-01, 1.9991347d-04, 6.6176525d-05 /
      data fpp( 5,16, 7,1),fpp( 5,16, 7,2),fpp( 5,16, 7,3)/
     x 4.8248129d-02, 1.3620004d-04, 4.5141274d-05 /
      data fpp( 5,16, 8,1),fpp( 5,16, 8,2),fpp( 5,16, 8,3)/
     x 1.2409095d-02, 1.0990987d-04, 1.4630380d-05 /
      data fpp( 5,16, 9,1),fpp( 5,16, 9,2),fpp( 5,16, 9,3)/
     x-1.4964883d-02, 9.0663002d-05,-1.1220792d-05 /
      data fpp( 5,16,10,1),fpp( 5,16,10,2),fpp( 5,16,10,3)/
     x-4.8725859d-02, 6.3781073d-05,-4.3781212d-05 /
      data fpp( 5,16,11,1),fpp( 5,16,11,2),fpp( 5,16,11,3)/
     x-5.1499929d-04, 4.9088964d-05,-1.2118436d-04 /
      data fpp( 5,16,12,1),fpp( 5,16,12,2),fpp( 5,16,12,3)/
     x 1.3978505d-02, 1.5020411d-05,-5.2875350d-05 /
      data fpp( 5,16,13,1),fpp( 5,16,13,2),fpp( 5,16,13,3)/
     x 3.8003204d-02, 6.9872149d-06, 3.6975822d-07 /
      data fpp( 5,16,14,1),fpp( 5,16,14,2),fpp( 5,16,14,3)/
     x 3.9766890d-02, 4.4643107d-06,-5.6832190d-09 /
      data fpp( 5,16,15,1),fpp( 5,16,15,2),fpp( 5,16,15,3)/
     x 3.9948724d-02, 3.7796772d-06, 3.0429747d-06 /
      data fpp( 5,16,16,1),fpp( 5,16,16,2),fpp( 5,16,16,3)/
     x 4.0375110d-02, 4.2422571d-06, 2.0177846d-06 /
      data fpp( 5,16,17,1),fpp( 5,16,17,2),fpp( 5,16,17,3)/
     x 4.0915735d-02, 5.5970118d-06, 7.6588693d-07 /
      data fpp( 5,16,18,1),fpp( 5,16,18,2),fpp( 5,16,18,3)/
     x 4.1896974d-02, 7.6560965d-06,-8.2133233d-07 /
      data fpp( 5,16,19,1),fpp( 5,16,19,2),fpp( 5,16,19,3)/
     x 4.2996109d-02, 1.0013433d-05,-2.2265576d-06 /
      data fpp( 5,16,20,1),fpp( 5,16,20,2),fpp( 5,16,20,3)/
     x 4.4022700d-02, 1.2088491d-05,-3.4784372d-06 /
      data fpp( 5,16,21,1),fpp( 5,16,21,2),fpp( 5,16,21,3)/
     x 4.4022700d-02, 1.2088491d-05,-3.5174095d-06 /
      data fpp( 5,16,22,1),fpp( 5,16,22,2),fpp( 5,16,22,3)/
     x 4.2996109d-02, 1.0013433d-05,-2.0706687d-06 /
      data fpp( 5,16,23,1),fpp( 5,16,23,2),fpp( 5,16,23,3)/
     x 4.1896974d-02, 7.6560965d-06,-1.4059156d-06 /
      data fpp( 5,17, 1,1),fpp( 5,17, 1,2),fpp( 5,17, 1,3)/
     x 3.1833193d-02, 1.0237203d-04, 3.3612208d-05 /
      data fpp( 5,17, 2,1),fpp( 5,17, 2,2),fpp( 5,17, 2,3)/
     x 4.7273226d-02, 1.2131862d-04, 3.4714583d-05 /
      data fpp( 5,17, 3,1),fpp( 5,17, 3,2),fpp( 5,17, 3,3)/
     x 5.7312099d-02, 1.4302815d-04, 3.7193459d-05 /
      data fpp( 5,17, 4,1),fpp( 5,17, 4,2),fpp( 5,17, 4,3)/
     x 5.7312099d-02, 1.4302815d-04, 3.6989331d-05 /
      data fpp( 5,17, 5,1),fpp( 5,17, 5,2),fpp( 5,17, 5,3)/
     x 4.7273226d-02, 1.2131862d-04, 3.5531097d-05 /
      data fpp( 5,17, 6,1),fpp( 5,17, 6,2),fpp( 5,17, 6,3)/
     x 3.1833193d-02, 1.0237203d-04, 3.0550282d-05 /
      data fpp( 5,17, 7,1),fpp( 5,17, 7,2),fpp( 5,17, 7,3)/
     x 1.6202510d-02, 8.8395720d-05, 2.1385774d-05 /
      data fpp( 5,17, 8,1),fpp( 5,17, 8,2),fpp( 5,17, 8,3)/
     x 1.1807594d-03, 8.1350304d-05, 1.2258621d-05 /
      data fpp( 5,17, 9,1),fpp( 5,17, 9,2),fpp( 5,17, 9,3)/
     x-1.2523228d-02, 7.4555999d-05,-5.1522585d-06 /
      data fpp( 5,17,10,1),fpp( 5,17,10,2),fpp( 5,17,10,3)/
     x-3.0031641d-02, 5.9396327d-05, 7.0004130d-06 /
      data fpp( 5,17,11,1),fpp( 5,17,11,2),fpp( 5,17,11,3)/
     x-6.3927311d-02, 4.6095481d-06,-9.6457393d-05 /
      data fpp( 5,17,12,1),fpp( 5,17,12,2),fpp( 5,17,12,3)/
     x 3.0033152d-01, 2.6573505d-05,-6.5770840d-05 /
      data fpp( 5,17,13,1),fpp( 5,17,13,2),fpp( 5,17,13,3)/
     x 7.6216501d-02, 1.5838250d-05, 6.7287523d-06 /
      data fpp( 5,17,14,1),fpp( 5,17,14,2),fpp( 5,17,14,3)/
     x 4.0056204d-02, 1.2867455d-05,-2.9761693d-06 /
      data fpp( 5,17,15,1),fpp( 5,17,15,2),fpp( 5,17,15,3)/
     x 4.1018516d-02, 1.2798125d-05, 1.9479250d-06 /
      data fpp( 5,17,16,1),fpp( 5,17,16,2),fpp( 5,17,16,3)/
     x 4.1273261d-02, 1.4184392d-05, 8.8446914d-07 /
      data fpp( 5,17,17,1),fpp( 5,17,17,2),fpp( 5,17,17,3)/
     x 4.1481491d-02, 1.6345843d-05, 6.5819838d-07 /
      data fpp( 5,17,18,1),fpp( 5,17,18,2),fpp( 5,17,18,3)/
     x 4.1643725d-02, 1.8715820d-05,-4.9262680d-08 /
      data fpp( 5,17,19,1),fpp( 5,17,19,2),fpp( 5,17,19,3)/
     x 4.1867162d-02, 2.0844807d-05,-5.4514766d-07 /
      data fpp( 5,17,20,1),fpp( 5,17,20,2),fpp( 5,17,20,3)/
     x 4.2035358d-02, 2.2236599d-05,-1.0281467d-06 /
      data fpp( 5,17,21,1),fpp( 5,17,21,2),fpp( 5,17,21,3)/
     x 4.2035358d-02, 2.2236599d-05,-1.0409862d-06 /
      data fpp( 5,17,22,1),fpp( 5,17,22,2),fpp( 5,17,22,3)/
     x 4.1867162d-02, 2.0844807d-05,-4.9378967d-07 /
      data fpp( 5,17,23,1),fpp( 5,17,23,2),fpp( 5,17,23,3)/
     x 4.1643725d-02, 1.8715820d-05,-2.4185517d-07 /
      data fpp( 5,18, 1,1),fpp( 5,18, 1,2),fpp( 5,18, 1,3)/
     x-2.8140095d-03, 2.8968421d-05, 1.4366752d-05 /
      data fpp( 5,18, 2,1),fpp( 5,18, 2,2),fpp( 5,18, 2,3)/
     x 8.0524583d-05, 2.4926679d-05, 1.5264496d-05 /
      data fpp( 5,18, 3,1),fpp( 5,18, 3,2),fpp( 5,18, 3,3)/
     x 2.1873258d-03, 2.5380101d-05, 1.7227265d-05 /
      data fpp( 5,18, 4,1),fpp( 5,18, 4,2),fpp( 5,18, 4,3)/
     x 2.1873258d-03, 2.5380101d-05, 1.7158957d-05 /
      data fpp( 5,18, 5,1),fpp( 5,18, 5,2),fpp( 5,18, 5,3)/
     x 8.0524583d-05, 2.4926679d-05, 1.5537728d-05 /
      data fpp( 5,18, 6,1),fpp( 5,18, 6,2),fpp( 5,18, 6,3)/
     x-2.8140095d-03, 2.8968421d-05, 1.3342130d-05 /
      data fpp( 5,18, 7,1),fpp( 5,18, 7,2),fpp( 5,18, 7,3)/
     x-5.3174368d-03, 3.9543080d-05, 1.0491753d-05 /
      data fpp( 5,18, 8,1),fpp( 5,18, 8,2),fpp( 5,18, 8,3)/
     x-1.3443291d-02, 5.1948913d-05, 7.0008579d-06 /
      data fpp( 5,18, 9,1),fpp( 5,18, 9,2),fpp( 5,18, 9,3)/
     x-2.1781165d-02, 6.1095000d-05, 4.3868151d-06 /
      data fpp( 5,18,10,1),fpp( 5,18,10,2),fpp( 5,18,10,3)/
     x-6.1771266d-02, 6.2563621d-05,-1.9881185d-06 /
      data fpp( 5,18,11,1),fpp( 5,18,11,2),fpp( 5,18,11,3)/
     x 2.1525459d-01, 5.4248843d-05, 7.7776589d-06 /
      data fpp( 5,18,12,1),fpp( 5,18,12,2),fpp( 5,18,12,3)/
     x-7.7869842d-01,-1.2870430d-05,-1.0810652d-04 /
      data fpp( 5,18,13,1),fpp( 5,18,13,2),fpp( 5,18,13,3)/
     x 1.6956652d-01, 1.6057858d-06, 2.8174409d-05 /
      data fpp( 5,18,14,1),fpp( 5,18,14,2),fpp( 5,18,14,3)/
     x-2.6990799d-01, 9.1718701d-06,-7.1951200d-06 /
      data fpp( 5,18,15,1),fpp( 5,18,15,2),fpp( 5,18,15,3)/
     x-6.7145946d-01, 1.5239821d-05, 2.7060707d-06 /
      data fpp( 5,18,16,1),fpp( 5,18,16,2),fpp( 5,18,16,3)/
     x-1.0214677d+00, 2.0896174d-05, 1.4483735d-07 /
      data fpp( 5,18,17,1),fpp( 5,18,17,2),fpp( 5,18,17,3)/
     x-1.3169133d+00, 2.6183616d-05, 7.4657995d-07 /
      data fpp( 5,18,18,1),fpp( 5,18,18,2),fpp( 5,18,18,3)/
     x-1.5582520d+00, 3.0838623d-05, 4.5084285d-07 /
      data fpp( 5,18,19,1),fpp( 5,18,19,2),fpp( 5,18,19,3)/
     x-1.7451000d+00, 3.4497341d-05, 3.6604866d-07 /
      data fpp( 5,18,20,1),fpp( 5,18,20,2),fpp( 5,18,20,3)/
     x-1.8637124d+00, 3.6881115d-05, 2.6896252d-07 /
      data fpp( 5,18,21,1),fpp( 5,18,21,2),fpp( 5,18,21,3)/
     x-1.8637124d+00, 3.6881115d-05, 2.6708812d-07 /
      data fpp( 5,18,22,1),fpp( 5,18,22,2),fpp( 5,18,22,3)/
     x-1.7451000d+00, 3.4497341d-05, 3.7354625d-07 /
      data fpp( 5,18,23,1),fpp( 5,18,23,2),fpp( 5,18,23,3)/
     x-1.5582520d+00, 3.0838623d-05, 4.2272687d-07 /
      data fpp( 5,19, 1,1),fpp( 5,19, 1,2),fpp( 5,19, 1,3)/
     x 9.4565035d-02,-5.1331710d-05,-9.5503839d-21 /
      data fpp( 5,19, 2,1),fpp( 5,19, 2,2),fpp( 5,19, 2,3)/
     x 9.4565035d-02,-1.0443334d-04,-3.7303239d-20 /
      data fpp( 5,19, 3,1),fpp( 5,19, 3,2),fpp( 5,19, 3,3)/
     x 9.4565035d-02,-1.5391855d-04,-3.7770088d-20 /
      data fpp( 5,19, 4,1),fpp( 5,19, 4,2),fpp( 5,19, 4,3)/
     x 9.4565035d-02,-1.5391855d-04, 5.8692428d-20 /
      data fpp( 5,19, 5,1),fpp( 5,19, 5,2),fpp( 5,19, 5,3)/
     x 9.4565035d-02,-1.0443334d-04,-9.6024583d-24 /
      data fpp( 5,19, 6,1),fpp( 5,19, 6,2),fpp( 5,19, 6,3)/
     x 9.4565035d-02,-5.1331710d-05,-5.8280174d-20 /
      data fpp( 5,19, 7,1),fpp( 5,19, 7,2),fpp( 5,19, 7,3)/
     x 9.4565035d-02,-9.0100400d-06,-1.4298807d-19 /
      data fpp( 5,19, 8,1),fpp( 5,19, 8,2),fpp( 5,19, 8,3)/
     x 9.4565035d-02, 2.2788043d-05, 4.2421038d-21 /
      data fpp( 5,19, 9,1),fpp( 5,19, 9,2),fpp( 5,19, 9,3)/
     x 9.4565035d-02, 4.6878000d-05, 1.8179463d-20 /
      data fpp( 5,19,10,1),fpp( 5,19,10,2),fpp( 5,19,10,3)/
     x 9.4565035d-02, 6.3573190d-05, 5.9212346d-20 /
      data fpp( 5,19,11,1),fpp( 5,19,11,2),fpp( 5,19,11,3)/
     x 9.4565035d-02, 7.6997078d-05,-4.7083920d-20 /
      data fpp( 5,19,12,1),fpp( 5,19,12,2),fpp( 5,19,12,3)/
     x 9.4565035d-02,-3.7743785d-05, 7.6301865d-20 /
      data fpp( 5,19,13,1),fpp( 5,19,13,2),fpp( 5,19,13,3)/
     x 9.4565035d-02,-6.0313929d-06, 4.7949633d-20 /
      data fpp( 5,19,14,1),fpp( 5,19,14,2),fpp( 5,19,14,3)/
     x 9.4565035d-02, 8.9330650d-06,-4.3066592d-20 /
      data fpp( 5,19,15,1),fpp( 5,19,15,2),fpp( 5,19,15,3)/
     x 9.4565035d-02, 1.9560589d-05,-1.5354626d-20 /
      data fpp( 5,19,16,1),fpp( 5,19,16,2),fpp( 5,19,16,3)/
     x 9.4565035d-02, 2.8530913d-05,-3.5531097d-20 /
      data fpp( 5,19,17,1),fpp( 5,19,17,2),fpp( 5,19,17,3)/
     x 9.4565035d-02, 3.6281692d-05, 1.0462972d-19 /
      data fpp( 5,19,18,1),fpp( 5,19,18,2),fpp( 5,19,18,3)/
     x 9.4565035d-02, 4.2657689d-05,-5.9889414d-20 /
      data fpp( 5,19,19,1),fpp( 5,19,19,2),fpp( 5,19,19,3)/
     x 9.4565035d-02, 4.7343830d-05,-6.5729188d-20 /
      data fpp( 5,19,20,1),fpp( 5,19,20,2),fpp( 5,19,20,3)/
     x 9.4565035d-02, 5.0240943d-05, 4.3414834d-20 /
      data fpp( 5,19,21,1),fpp( 5,19,21,2),fpp( 5,19,21,3)/
     x 9.4565035d-02, 5.0240943d-05,-4.8536015d-20 /
      data fpp( 5,19,22,1),fpp( 5,19,22,2),fpp( 5,19,22,3)/
     x 9.4565035d-02, 4.7343830d-05, 1.0569211d-19 /
      data fpp( 5,19,23,1),fpp( 5,19,23,2),fpp( 5,19,23,3)/
     x 9.4565035d-02, 4.2657689d-05, 2.2855529d-19 /
      data fpp( 6, 1, 1,1),fpp( 6, 1, 1,2),fpp( 6, 1, 1,3)/
     x 5.5569959d-01, 8.4345551d-04, 9.3978072d-19 /
      data fpp( 6, 1, 2,1),fpp( 6, 1, 2,2),fpp( 6, 1, 2,3)/
     x 5.5569959d-01, 6.7591472d-04,-3.8791241d-19 /
      data fpp( 6, 1, 3,1),fpp( 6, 1, 3,2),fpp( 6, 1, 3,3)/
     x 5.5569959d-01, 1.5360430d-03,-4.1771828d-19 /
      data fpp( 6, 1, 4,1),fpp( 6, 1, 4,2),fpp( 6, 1, 4,3)/
     x 5.5569959d-01, 1.5360430d-03, 2.2764367d-19 /
      data fpp( 6, 1, 5,1),fpp( 6, 1, 5,2),fpp( 6, 1, 5,3)/
     x 5.5569959d-01, 6.7591472d-04, 5.9334708d-19 /
      data fpp( 6, 1, 6,1),fpp( 6, 1, 6,2),fpp( 6, 1, 6,3)/
     x 5.5569959d-01, 8.4345551d-04,-9.4472682d-19 /
      data fpp( 6, 1, 7,1),fpp( 6, 1, 7,2),fpp( 6, 1, 7,3)/
     x 5.5569959d-01,-4.7325562d-04,-1.0904031d-18 /
      data fpp( 6, 1, 8,1),fpp( 6, 1, 8,2),fpp( 6, 1, 8,3)/
     x 5.5569959d-01,-2.0302422d-03,-7.8756448d-19 /
      data fpp( 6, 1, 9,1),fpp( 6, 1, 9,2),fpp( 6, 1, 9,3)/
     x 5.5569959d-01,-2.9501491d-03,-1.9933701d-19 /
      data fpp( 6, 1,10,1),fpp( 6, 1,10,2),fpp( 6, 1,10,3)/
     x 5.5569959d-01,-3.4515265d-03, 8.4921644d-19 /
      data fpp( 6, 1,11,1),fpp( 6, 1,11,2),fpp( 6, 1,11,3)/
     x 5.5569959d-01,-3.7485765d-03,-8.6791061d-19 /
      data fpp( 6, 1,12,1),fpp( 6, 1,12,2),fpp( 6, 1,12,3)/
     x 5.5569959d-01,-3.8398268d-03, 8.6160122d-19 /
      data fpp( 6, 1,13,1),fpp( 6, 1,13,2),fpp( 6, 1,13,3)/
     x 5.5569959d-01,-3.7399537d-03, 1.0751343d-19 /
      data fpp( 6, 1,14,1),fpp( 6, 1,14,2),fpp( 6, 1,14,3)/
     x 5.5569959d-01,-3.4340451d-03,-1.9940405d-19 /
      data fpp( 6, 1,15,1),fpp( 6, 1,15,2),fpp( 6, 1,15,3)/
     x 5.5569959d-01,-2.9203780d-03,-3.0634892d-19 /
      data fpp( 6, 1,16,1),fpp( 6, 1,16,2),fpp( 6, 1,16,3)/
     x 5.5569959d-01,-2.0032078d-03,-6.1748112d-19 /
      data fpp( 6, 1,17,1),fpp( 6, 1,17,2),fpp( 6, 1,17,3)/
     x 5.5569959d-01,-4.1896214d-04, 3.8914537d-19 /
      data fpp( 6, 1,18,1),fpp( 6, 1,18,2),fpp( 6, 1,18,3)/
     x 5.5569959d-01, 8.2578088d-04,-1.1909817d-18 /
      data fpp( 6, 1,19,1),fpp( 6, 1,19,2),fpp( 6, 1,19,3)/
     x 5.5569959d-01, 6.6871922d-04,-7.3828133d-19 /
      data fpp( 6, 1,20,1),fpp( 6, 1,20,2),fpp( 6, 1,20,3)/
     x 5.5569959d-01, 1.5281017d-03, 4.6757140d-19 /
      data fpp( 6, 1,21,1),fpp( 6, 1,21,2),fpp( 6, 1,21,3)/
     x 5.5569959d-01, 1.5281017d-03,-5.7650512d-19 /
      data fpp( 6, 1,22,1),fpp( 6, 1,22,2),fpp( 6, 1,22,3)/
     x 5.5569959d-01, 6.6871922d-04, 5.8819327d-19 /
      data fpp( 6, 1,23,1),fpp( 6, 1,23,2),fpp( 6, 1,23,3)/
     x 5.5569959d-01, 8.2578088d-04, 1.2651578d-18 /
      data fpp( 6, 2, 1,1),fpp( 6, 2, 1,2),fpp( 6, 2, 1,3)/
     x 2.1370935d-01, 2.0360899d-04,-1.2086644d-06 /
      data fpp( 6, 2, 2,1),fpp( 6, 2, 2,2),fpp( 6, 2, 2,3)/
     x 4.1920827d-01, 4.5309552d-05,-4.3116712d-06 /
      data fpp( 6, 2, 3,1),fpp( 6, 2, 3,2),fpp( 6, 2, 3,3)/
     x 3.1573229d-01, 4.4784709d-04,-1.1016651d-05 /
      data fpp( 6, 2, 4,1),fpp( 6, 2, 4,2),fpp( 6, 2, 4,3)/
     x 3.1573229d-01, 4.4784709d-04,-1.0919212d-05 /
      data fpp( 6, 2, 5,1),fpp( 6, 2, 5,2),fpp( 6, 2, 5,3)/
     x 4.1920827d-01, 4.5309552d-05,-4.7014243d-06 /
      data fpp( 6, 2, 6,1),fpp( 6, 2, 6,2),fpp( 6, 2, 6,3)/
     x 2.1370935d-01, 2.0360899d-04, 2.5290972d-07 /
      data fpp( 6, 2, 7,1),fpp( 6, 2, 7,2),fpp( 6, 2, 7,3)/
     x-4.8069692d-02,-2.9108677d-04, 1.1217855d-06 /
      data fpp( 6, 2, 8,1),fpp( 6, 2, 8,2),fpp( 6, 2, 8,3)/
     x-2.2327254d-01,-9.4193067d-04, 9.2159484d-06 /
      data fpp( 6, 2, 9,1),fpp( 6, 2, 9,2),fpp( 6, 2, 9,3)/
     x 3.6816518d-01,-1.3326069d-03,-8.0357912d-07 /
      data fpp( 6, 2,10,1),fpp( 6, 2,10,2),fpp( 6, 2,10,3)/
     x 6.8511409d-01,-1.5488180d-03, 3.5923681d-06 /
      data fpp( 6, 2,11,1),fpp( 6, 2,11,2),fpp( 6, 2,11,3)/
     x 1.0234163d+00,-1.6763610d-03, 7.6861069d-06 /
      data fpp( 6, 2,12,1),fpp( 6, 2,12,2),fpp( 6, 2,12,3)/
     x 1.1361124d+00,-1.7167063d-03, 3.6120430d-07 /
      data fpp( 6, 2,13,1),fpp( 6, 2,13,2),fpp( 6, 2,13,3)/
     x 1.0554341d+00,-1.6743446d-03, 8.1790759d-06 /
      data fpp( 6, 2,14,1),fpp( 6, 2,14,2),fpp( 6, 2,14,3)/
     x 6.3372096d-01,-1.5446038d-03, 1.6684922d-06 /
      data fpp( 6, 2,15,1),fpp( 6, 2,15,2),fpp( 6, 2,15,3)/
     x 3.1111361d-01,-1.3243270d-03, 6.5309553d-06 /
      data fpp( 6, 2,16,1),fpp( 6, 2,16,2),fpp( 6, 2,16,3)/
     x-3.1759429d-01,-9.3024345d-04,-2.3343133d-06 /
      data fpp( 6, 2,17,1),fpp( 6, 2,17,2),fpp( 6, 2,17,3)/
     x-4.0375974d-02,-2.7198871d-04, 8.4582978d-06 /
      data fpp( 6, 2,18,1),fpp( 6, 2,18,2),fpp( 6, 2,18,3)/
     x 2.4321341d-01, 1.9972624d-04,-1.8168780d-06 /
      data fpp( 6, 2,19,1),fpp( 6, 2,19,2),fpp( 6, 2,19,3)/
     x 3.6306377d-01, 4.9111554d-05,-4.2687857d-06 /
      data fpp( 6, 2,20,1),fpp( 6, 2,20,2),fpp( 6, 2,20,3)/
     x 3.0707217d-01, 4.5119156d-04,-1.1161979d-05 /
      data fpp( 6, 2,21,1),fpp( 6, 2,21,2),fpp( 6, 2,21,3)/
     x 3.0707217d-01, 4.5119156d-04,-1.1125670d-05 /
      data fpp( 6, 2,22,1),fpp( 6, 2,22,2),fpp( 6, 2,22,3)/
     x 3.6306377d-01, 4.9111554d-05,-4.4140229d-06 /
      data fpp( 6, 2,23,1),fpp( 6, 2,23,2),fpp( 6, 2,23,3)/
     x 2.4321341d-01, 1.9972624d-04,-1.2722385d-06 /
      data fpp( 6, 3, 1,1),fpp( 6, 3, 1,2),fpp( 6, 3, 1,3)/
     x 6.8394961d-02,-1.4302635d-03, 4.0690874d-04 /
      data fpp( 6, 3, 2,1),fpp( 6, 3, 2,2),fpp( 6, 3, 2,3)/
     x-3.7908111d-02, 3.3270107d-04, 1.8054103d-04 /
      data fpp( 6, 3, 3,1),fpp( 6, 3, 3,2),fpp( 6, 3, 3,3)/
     x-3.3275788d-02,-2.5086533d-04,-2.6353085d-04 /
      data fpp( 6, 3, 4,1),fpp( 6, 3, 4,2),fpp( 6, 3, 4,3)/
     x-3.3275788d-02,-2.5086533d-04,-3.3528398d-04 /
      data fpp( 6, 3, 5,1),fpp( 6, 3, 5,2),fpp( 6, 3, 5,3)/
     x-3.7908111d-02, 3.3270107d-04, 4.6755356d-04 /
      data fpp( 6, 3, 6,1),fpp( 6, 3, 6,2),fpp( 6, 3, 6,3)/
     x 6.8394961d-02,-1.4302635d-03,-6.6938826d-04 /
      data fpp( 6, 3, 7,1),fpp( 6, 3, 7,2),fpp( 6, 3, 7,3)/
     x 6.1915352d-01,-1.1763133d-03, 1.2554547d-04 /
      data fpp( 6, 3, 8,1),fpp( 6, 3, 8,2),fpp( 6, 3, 8,3)/
     x 6.7255052d-01,-6.8114140d-07, 2.5193237d-04 /
      data fpp( 6, 3, 9,1),fpp( 6, 3, 9,2),fpp( 6, 3, 9,3)/
     x 9.3458051d-01, 6.8436660d-04, 1.2825505d-04 /
      data fpp( 6, 3,10,1),fpp( 6, 3,10,2),fpp( 6, 3,10,3)/
     x 7.8106446d-01, 1.0549246d-03, 5.6135442d-05 /
      data fpp( 6, 3,11,1),fpp( 6, 3,11,2),fpp( 6, 3,11,3)/
     x 1.0071548d+00, 1.2661844d-03, 8.9409186d-05 /
      data fpp( 6, 3,12,1),fpp( 6, 3,12,2),fpp( 6, 3,12,3)/
     x 8.2990543d-01, 1.3279681d-03, 6.0737814d-05 /
      data fpp( 6, 3,13,1),fpp( 6, 3,13,2),fpp( 6, 3,13,3)/
     x 1.1847412d+00, 1.2548240d-03, 8.9283558d-05 /
      data fpp( 6, 3,14,1),fpp( 6, 3,14,2),fpp( 6, 3,14,3)/
     x 7.8127397d-01, 1.0335402d-03, 5.9031954d-05 /
      data fpp( 6, 3,15,1),fpp( 6, 3,15,2),fpp( 6, 3,15,3)/
     x 9.3454311d-01, 6.5067201d-04, 1.2567463d-04 /
      data fpp( 6, 3,16,1),fpp( 6, 3,16,2),fpp( 6, 3,16,3)/
     x 6.5044569d-01,-5.4316417d-05, 2.6579554d-04 /
      data fpp( 6, 3,17,1),fpp( 6, 3,17,2),fpp( 6, 3,17,3)/
     x 1.4379511d+00,-1.2243370d-03, 8.1175196d-05 /
      data fpp( 6, 3,18,1),fpp( 6, 3,18,2),fpp( 6, 3,18,3)/
     x 7.6522135d-02,-1.4098618d-03,-6.3229833d-04 /
      data fpp( 6, 3,19,1),fpp( 6, 3,19,2),fpp( 6, 3,19,3)/
     x-3.8648887d-02, 3.1130256d-04, 4.5742812d-04 /
      data fpp( 6, 3,20,1),fpp( 6, 3,20,2),fpp( 6, 3,20,3)/
     x-3.3378047d-02,-2.7079795d-04,-3.3356414d-04 /
      data fpp( 6, 3,21,1),fpp( 6, 3,21,2),fpp( 6, 3,21,3)/
     x-3.3378047d-02,-2.7079795d-04,-2.6431464d-04 /
      data fpp( 6, 3,22,1),fpp( 6, 3,22,2),fpp( 6, 3,22,3)/
     x-3.8648887d-02, 3.1130256d-04, 1.8043011d-04 /
      data fpp( 6, 3,23,1),fpp( 6, 3,23,2),fpp( 6, 3,23,3)/
     x 7.6522135d-02,-1.4098618d-03, 4.0644419d-04 /
      data fpp( 6, 4, 1,1),fpp( 6, 4, 1,2),fpp( 6, 4, 1,3)/
     x-1.0303085d-01, 4.1495483d-04,-8.8501740d-04 /
      data fpp( 6, 4, 2,1),fpp( 6, 4, 2,2),fpp( 6, 4, 2,3)/
     x-4.3335503d-02,-2.5928958d-03,-6.6276870d-04 /
      data fpp( 6, 4, 3,1),fpp( 6, 4, 3,2),fpp( 6, 4, 3,3)/
     x-1.1032667d-01,-2.3127698d-03,-2.4066179d-04 /
      data fpp( 6, 4, 4,1),fpp( 6, 4, 4,2),fpp( 6, 4, 4,3)/
     x-1.1032667d-01,-2.3127698d-03,-1.4591629d-04 /
      data fpp( 6, 4, 5,1),fpp( 6, 4, 5,2),fpp( 6, 4, 5,3)/
     x-4.3335503d-02,-2.5928958d-03,-1.0417507d-03 /
      data fpp( 6, 4, 6,1),fpp( 6, 4, 6,2),fpp( 6, 4, 6,3)/
     x-1.0303085d-01, 4.1495483d-04, 5.3616513d-04 /
      data fpp( 6, 4, 7,1),fpp( 6, 4, 7,2),fpp( 6, 4, 7,3)/
     x-1.3705807d-01, 1.6743440d-03, 3.9695219d-04 /
      data fpp( 6, 4, 8,1),fpp( 6, 4, 8,2),fpp( 6, 4, 8,3)/
     x 1.4518386d-01, 1.4552852d-03, 8.3654103d-05 /
      data fpp( 6, 4, 9,1),fpp( 6, 4, 9,2),fpp( 6, 4, 9,3)/
     x 2.5104864d-01, 1.3033305d-03, 1.1924340d-04 /
      data fpp( 6, 4,10,1),fpp( 6, 4,10,2),fpp( 6, 4,10,3)/
     x 2.5204397d-01, 1.2050478d-03, 4.2132313d-05 /
      data fpp( 6, 4,11,1),fpp( 6, 4,11,2),fpp( 6, 4,11,3)/
     x 3.9010368d-01, 1.1625753d-03, 8.2673351d-05 /
      data fpp( 6, 4,12,1),fpp( 6, 4,12,2),fpp( 6, 4,12,3)/
     x 2.4948278d-01, 1.1472040d-03, 5.7890282d-05 /
      data fpp( 6, 4,13,1),fpp( 6, 4,13,2),fpp( 6, 4,13,3)/
     x 3.9462110d-01, 1.1615345d-03, 8.4441522d-05 /
      data fpp( 6, 4,14,1),fpp( 6, 4,14,2),fpp( 6, 4,14,3)/
     x 2.3632844d-01, 1.2012251d-03, 4.3585629d-05 /
      data fpp( 6, 4,15,1),fpp( 6, 4,15,2),fpp( 6, 4,15,3)/
     x 2.5868272d-01, 1.2993530d-03, 1.2463996d-04 /
      data fpp( 6, 4,16,1),fpp( 6, 4,16,2),fpp( 6, 4,16,3)/
     x 1.7882947d-01, 1.5112411d-03, 8.6534529d-05 /
      data fpp( 6, 4,17,1),fpp( 6, 4,17,2),fpp( 6, 4,17,3)/
     x 4.0175140d-01, 1.6709407d-03, 4.1548792d-04 /
      data fpp( 6, 4,18,1),fpp( 6, 4,18,2),fpp( 6, 4,18,3)/
     x-1.0349154d-01, 4.2291709d-04, 4.8194778d-04 /
      data fpp( 6, 4,19,1),fpp( 6, 4,19,2),fpp( 6, 4,19,3)/
     x-7.0868577d-02,-2.5128018d-03,-1.0046490d-03 /
      data fpp( 6, 4,20,1),fpp( 6, 4,20,2),fpp( 6, 4,20,3)/
     x-1.1086031d-01,-2.2350098d-03,-1.5245159d-04 /
      data fpp( 6, 4,21,1),fpp( 6, 4,21,2),fpp( 6, 4,21,3)/
     x-1.1086031d-01,-2.2350098d-03,-2.4189569d-04 /
      data fpp( 6, 4,22,1),fpp( 6, 4,22,2),fpp( 6, 4,22,3)/
     x-7.0868577d-02,-2.5128018d-03,-6.4687266d-04 /
      data fpp( 6, 4,23,1),fpp( 6, 4,23,2),fpp( 6, 4,23,3)/
     x-1.0349154d-01, 4.2291709d-04,-8.5971367d-04 /
      data fpp( 6, 5, 1,1),fpp( 6, 5, 1,2),fpp( 6, 5, 1,3)/
     x 4.0589887d-02, 1.2341741d-03, 2.5889291d-04 /
      data fpp( 6, 5, 2,1),fpp( 6, 5, 2,2),fpp( 6, 5, 2,3)/
     x-4.6646437d-02, 2.7100082d-03, 7.0643685d-05 /
      data fpp( 6, 5, 3,1),fpp( 6, 5, 3,2),fpp( 6, 5, 3,3)/
     x-1.5501191d-01, 2.0137344d-03,-3.2724965d-04 /
      data fpp( 6, 5, 4,1),fpp( 6, 5, 4,2),fpp( 6, 5, 4,3)/
     x-1.5501191d-01, 2.0137344d-03,-3.3687090d-04 /
      data fpp( 6, 5, 5,1),fpp( 6, 5, 5,2),fpp( 6, 5, 5,3)/
     x-4.6646437d-02, 2.7100082d-03, 1.0912869d-04 /
      data fpp( 6, 5, 6,1),fpp( 6, 5, 6,2),fpp( 6, 5, 6,3)/
     x 4.0589887d-02, 1.2341741d-03, 1.1457415d-04 /
      data fpp( 6, 5, 7,1),fpp( 6, 5, 7,2),fpp( 6, 5, 7,3)/
     x 3.4643183d-02, 2.3336334d-04, 1.4844713d-05 /
      data fpp( 6, 5, 8,1),fpp( 6, 5, 8,2),fpp( 6, 5, 8,3)/
     x 4.4125726d-02, 1.2947018d-04, 6.1384999d-05 /
      data fpp( 6, 5, 9,1),fpp( 6, 5, 9,2),fpp( 6, 5, 9,3)/
     x 5.1391462d-02, 1.1944152d-04, 5.1405293d-05 /
      data fpp( 6, 5,10,1),fpp( 6, 5,10,2),fpp( 6, 5,10,3)/
     x 5.5270631d-02, 1.4901036d-04, 5.7221831d-05 /
      data fpp( 6, 5,11,1),fpp( 6, 5,11,2),fpp( 6, 5,11,3)/
     x 5.7954802d-02, 1.5376822d-04, 5.7525382d-05 /
      data fpp( 6, 5,12,1),fpp( 6, 5,12,2),fpp( 6, 5,12,3)/
     x 5.8804147d-02, 1.5693189d-04, 5.6932639d-05 /
      data fpp( 6, 5,13,1),fpp( 6, 5,13,2),fpp( 6, 5,13,3)/
     x 5.8405029d-02, 1.4928181d-04, 6.3518062d-05 /
      data fpp( 6, 5,14,1),fpp( 6, 5,14,2),fpp( 6, 5,14,3)/
     x 5.6652059d-02, 1.4109328d-04, 4.3337113d-05 /
      data fpp( 6, 5,15,1),fpp( 6, 5,15,2),fpp( 6, 5,15,3)/
     x 5.2374401d-02, 1.0629218d-04, 1.2444748d-04 /
      data fpp( 6, 5,16,1),fpp( 6, 5,16,2),fpp( 6, 5,16,3)/
     x-3.1606541d-01, 1.1007941d-05,-3.8855052d-05 /
      data fpp( 6, 5,17,1),fpp( 6, 5,17,2),fpp( 6, 5,17,3)/
     x 3.5353286d-02, 2.0121402d-04, 1.4517672d-04 /
      data fpp( 6, 5,18,1),fpp( 6, 5,18,2),fpp( 6, 5,18,3)/
     x-9.0031084d-03, 1.1096295d-03, 3.2630156d-05 /
      data fpp( 6, 5,19,1),fpp( 6, 5,19,2),fpp( 6, 5,19,3)/
     x-5.0868314d-02, 2.6320826d-03, 1.6209865d-04 /
      data fpp( 6, 5,20,1),fpp( 6, 5,20,2),fpp( 6, 5,20,3)/
     x-1.5300448d-01, 2.1539850d-03,-3.7284676d-04 /
      data fpp( 6, 5,21,1),fpp( 6, 5,21,2),fpp( 6, 5,21,3)/
     x-1.5300448d-01, 2.1539850d-03,-3.5485105d-04 /
      data fpp( 6, 5,22,1),fpp( 6, 5,22,2),fpp( 6, 5,22,3)/
     x-5.0868314d-02, 2.6320826d-03, 9.0115799d-05 /
      data fpp( 6, 5,23,1),fpp( 6, 5,23,2),fpp( 6, 5,23,3)/
     x-9.0031084d-03, 1.1096295d-03, 3.0256585d-04 /
      data fpp( 6, 6, 1,1),fpp( 6, 6, 1,2),fpp( 6, 6, 1,3)/
     x-1.0387575d-02,-2.9410741d-04,-1.1167784d-05 /
      data fpp( 6, 6, 2,1),fpp( 6, 6, 2,2),fpp( 6, 6, 2,3)/
     x-1.6196151d-02,-4.9650502d-04,-4.2932932d-05 /
      data fpp( 6, 6, 3,1),fpp( 6, 6, 3,2),fpp( 6, 6, 3,3)/
     x-6.4324821d-03, 2.0288399d-04,-1.1057849d-04 /
      data fpp( 6, 6, 4,1),fpp( 6, 6, 4,2),fpp( 6, 6, 4,3)/
     x-6.4324821d-03, 2.0288399d-04,-1.1131807d-04 /
      data fpp( 6, 6, 5,1),fpp( 6, 6, 5,2),fpp( 6, 6, 5,3)/
     x-1.6196151d-02,-4.9650502d-04,-3.9974585d-05 /
      data fpp( 6, 6, 6,1),fpp( 6, 6, 6,2),fpp( 6, 6, 6,3)/
     x-1.0387575d-02,-2.9410741d-04,-2.2261588d-05 /
      data fpp( 6, 6, 7,1),fpp( 6, 6, 7,2),fpp( 6, 6, 7,3)/
     x 1.5027142d-04,-9.8873471d-06, 2.7152935d-05 /
      data fpp( 6, 6, 8,1),fpp( 6, 6, 8,2),fpp( 6, 6, 8,3)/
     x 7.4702271d-03, 2.0298027d-05, 3.1885849d-05 /
      data fpp( 6, 6, 9,1),fpp( 6, 6, 9,2),fpp( 6, 6, 9,3)/
     x 1.2457876d-02, 3.1161459d-05, 4.1311671d-05 /
      data fpp( 6, 6,10,1),fpp( 6, 6,10,2),fpp( 6, 6,10,3)/
     x 1.2944915d-02, 2.5772783d-05, 4.4373467d-05 /
      data fpp( 6, 6,11,1),fpp( 6, 6,11,2),fpp( 6, 6,11,3)/
     x 1.3647111d-02, 2.3839758d-05, 4.6406463d-05 /
      data fpp( 6, 6,12,1),fpp( 6, 6,12,2),fpp( 6, 6,12,3)/
     x 1.8849531d-02, 2.1456427d-05, 4.8070683d-05 /
      data fpp( 6, 6,13,1),fpp( 6, 6,13,2),fpp( 6, 6,13,3)/
     x 1.8846222d-02, 2.1100199d-05, 4.8656806d-05 /
      data fpp( 6, 6,14,1),fpp( 6, 6,14,2),fpp( 6, 6,14,3)/
     x 2.7367171d-02, 2.0151733d-05, 4.9358092d-05 /
      data fpp( 6, 6,15,1),fpp( 6, 6,15,2),fpp( 6, 6,15,3)/
     x 1.5692027d-02, 2.4232321d-05, 5.0130826d-05 /
      data fpp( 6, 6,16,1),fpp( 6, 6,16,2),fpp( 6, 6,16,3)/
     x 5.6870183d-02, 7.7561118d-05, 4.7058605d-05 /
      data fpp( 6, 6,17,1),fpp( 6, 6,17,2),fpp( 6, 6,17,3)/
     x 6.9115031d-03,-1.5430841d-05, 4.7228756d-05 /
      data fpp( 6, 6,18,1),fpp( 6, 6,18,2),fpp( 6, 6,18,3)/
     x-2.5895648d-03,-2.3983294d-04, 1.6260372d-05 /
      data fpp( 6, 6,19,1),fpp( 6, 6,19,2),fpp( 6, 6,19,3)/
     x-1.9069152d-02,-5.8837473d-04, 6.9007758d-05 /
      data fpp( 6, 6,20,1),fpp( 6, 6,20,2),fpp( 6, 6,20,3)/
     x-6.5684834d-02,-3.8869440d-04,-2.2730540d-04 /
      data fpp( 6, 6,21,1),fpp( 6, 6,21,2),fpp( 6, 6,21,3)/
     x-6.5684834d-02,-3.8869440d-04,-2.1823767d-04 /
      data fpp( 6, 6,22,1),fpp( 6, 6,22,2),fpp( 6, 6,22,3)/
     x-1.9069152d-02,-5.8837473d-04, 3.2736835d-05 /
      data fpp( 6, 6,23,1),fpp( 6, 6,23,2),fpp( 6, 6,23,3)/
     x-2.5895648d-03,-2.3983294d-04, 1.5227633d-04 /
      data fpp( 6, 7, 1,1),fpp( 6, 7, 1,2),fpp( 6, 7, 1,3)/
     x-1.7791072d-02, 4.7795501d-05, 4.1780313d-05 /
      data fpp( 6, 7, 2,1),fpp( 6, 7, 2,2),fpp( 6, 7, 2,3)/
     x-1.0167718d-01, 1.3732988d-04,-2.8526270d-06 /
      data fpp( 6, 7, 3,1),fpp( 6, 7, 3,2),fpp( 6, 7, 3,3)/
     x-4.8247291d-01,-4.7321639d-04,-9.6585806d-05 /
      data fpp( 6, 7, 4,1),fpp( 6, 7, 4,2),fpp( 6, 7, 4,3)/
     x-4.8247291d-01,-4.7321639d-04,-9.9926270d-05 /
      data fpp( 6, 7, 5,1),fpp( 6, 7, 5,2),fpp( 6, 7, 5,3)/
     x-1.0167718d-01, 1.3732988d-04, 1.0509229d-05 /
      data fpp( 6, 7, 6,1),fpp( 6, 7, 6,2),fpp( 6, 7, 6,3)/
     x-1.7791072d-02, 4.7795501d-05,-8.3266452d-06 /
      data fpp( 6, 7, 7,1),fpp( 6, 7, 7,2),fpp( 6, 7, 7,3)/
     x-7.8877270d-03,-7.6717951d-05, 4.1253520d-06 /
      data fpp( 6, 7, 8,1),fpp( 6, 7, 8,2),fpp( 6, 7, 8,3)/
     x-3.2701674d-03,-6.2210290d-05, 1.2759237d-05 /
      data fpp( 6, 7, 9,1),fpp( 6, 7, 9,2),fpp( 6, 7, 9,3)/
     x-2.7164466d-04,-6.6199352d-05, 2.3143699d-05 /
      data fpp( 6, 7,10,1),fpp( 6, 7,10,2),fpp( 6, 7,10,3)/
     x 8.0230883d-04,-6.7625494d-05, 3.0601966d-05 /
      data fpp( 6, 7,11,1),fpp( 6, 7,11,2),fpp( 6, 7,11,3)/
     x 1.9346467d-03,-6.9799259d-05, 3.5318436d-05 /
      data fpp( 6, 7,12,1),fpp( 6, 7,12,2),fpp( 6, 7,12,3)/
     x 3.0155937d-03,-7.0953597d-05, 3.7632290d-05 /
      data fpp( 6, 7,13,1),fpp( 6, 7,13,2),fpp( 6, 7,13,3)/
     x 3.4932535d-03,-7.1118611d-05, 3.8354404d-05 /
      data fpp( 6, 7,14,1),fpp( 6, 7,14,2),fpp( 6, 7,14,3)/
     x 2.7851263d-03,-6.9426215d-05, 3.7670093d-05 /
      data fpp( 6, 7,15,1),fpp( 6, 7,15,2),fpp( 6, 7,15,3)/
     x 4.3563127d-03,-6.6775466d-05, 3.6553224d-05 /
      data fpp( 6, 7,16,1),fpp( 6, 7,16,2),fpp( 6, 7,16,3)/
     x 3.6379803d-03,-7.5060413d-05, 3.3299010d-05 /
      data fpp( 6, 7,17,1),fpp( 6, 7,17,2),fpp( 6, 7,17,3)/
     x 3.2199882d-03,-4.2098658d-05, 2.8688734d-05 /
      data fpp( 6, 7,18,1),fpp( 6, 7,18,2),fpp( 6, 7,18,3)/
     x 4.3368903d-03, 2.8610281d-05, 1.2248053d-05 /
      data fpp( 6, 7,19,1),fpp( 6, 7,19,2),fpp( 6, 7,19,3)/
     x 4.7129146d-03, 1.3949028d-04, 4.7290555d-06 /
      data fpp( 6, 7,20,1),fpp( 6, 7,20,2),fpp( 6, 7,20,3)/
     x 1.8785079d-02, 1.4115056d-04,-1.2625227d-04 /
      data fpp( 6, 7,21,1),fpp( 6, 7,21,2),fpp( 6, 7,21,3)/
     x 1.8785079d-02, 1.4115056d-04,-1.2370770d-04 /
      data fpp( 6, 7,22,1),fpp( 6, 7,22,2),fpp( 6, 7,22,3)/
     x 4.7129146d-03, 1.3949028d-04,-5.4492275d-06 /
      data fpp( 6, 7,23,1),fpp( 6, 7,23,2),fpp( 6, 7,23,3)/
     x 4.3368903d-03, 2.8610281d-05, 5.0416614d-05 /
      data fpp( 6, 8, 1,1),fpp( 6, 8, 1,2),fpp( 6, 8, 1,3)/
     x 6.0447164d-02,-1.0976859d-04,-3.0336173d-04 /
      data fpp( 6, 8, 2,1),fpp( 6, 8, 2,2),fpp( 6, 8, 2,3)/
     x-5.5856653d-01,-4.8946449d-04,-1.7214354d-04 /
      data fpp( 6, 8, 3,1),fpp( 6, 8, 3,2),fpp( 6, 8, 3,3)/
     x-2.9490182d-02,-2.6870419d-05, 9.6735900d-05 /
      data fpp( 6, 8, 4,1),fpp( 6, 8, 4,2),fpp( 6, 8, 4,3)/
     x-2.9490182d-02,-2.6870419d-05, 1.1826507d-04 /
      data fpp( 6, 8, 5,1),fpp( 6, 8, 5,2),fpp( 6, 8, 5,3)/
     x-5.5856653d-01,-4.8946449d-04,-2.5826023d-04 /
      data fpp( 6, 8, 6,1),fpp( 6, 8, 6,2),fpp( 6, 8, 6,3)/
     x 6.0447164d-02,-1.0976859d-04, 1.9575853d-05 /
      data fpp( 6, 8, 7,1),fpp( 6, 8, 7,2),fpp( 6, 8, 7,3)/
     x-3.4985512d-03, 6.3811149d-05,-1.9729181d-05 /
      data fpp( 6, 8, 8,1),fpp( 6, 8, 8,2),fpp( 6, 8, 8,3)/
     x-3.3371575d-03,-5.1908867d-05,-4.2771278d-06 /
      data fpp( 6, 8, 9,1),fpp( 6, 8, 9,2),fpp( 6, 8, 9,3)/
     x-1.8871040d-03,-6.6760050d-05, 5.0016926d-06 /
      data fpp( 6, 8,10,1),fpp( 6, 8,10,2),fpp( 6, 8,10,3)/
     x-4.8608839d-03,-7.2550807d-05, 1.7696357d-05 /
      data fpp( 6, 8,11,1),fpp( 6, 8,11,2),fpp( 6, 8,11,3)/
     x-2.9116517d-03,-7.4366723d-05, 2.5180877d-05 /
      data fpp( 6, 8,12,1),fpp( 6, 8,12,2),fpp( 6, 8,12,3)/
     x-2.7827761d-03,-7.3606037d-05, 2.8730133d-05 /
      data fpp( 6, 8,13,1),fpp( 6, 8,13,2),fpp( 6, 8,13,3)/
     x-1.5204911d-03,-7.0333755d-05, 2.9452592d-05 /
      data fpp( 6, 8,14,1),fpp( 6, 8,14,2),fpp( 6, 8,14,3)/
     x-1.9733542d-03,-6.4616875d-05, 2.8125501d-05 /
      data fpp( 6, 8,15,1),fpp( 6, 8,15,2),fpp( 6, 8,15,3)/
     x 1.7948252d-03,-5.5204457d-05, 2.5559404d-05 /
      data fpp( 6, 8,16,1),fpp( 6, 8,16,2),fpp( 6, 8,16,3)/
     x 1.5659352d-03,-3.6819464d-05, 2.1538884d-05 /
      data fpp( 6, 8,17,1),fpp( 6, 8,17,2),fpp( 6, 8,17,3)/
     x 7.1941833d-03,-2.0804527d-05, 1.5863062d-05 /
      data fpp( 6, 8,18,1),fpp( 6, 8,18,2),fpp( 6, 8,18,3)/
     x 1.1627908d-02,-3.2121888d-06, 4.5348703d-06 /
      data fpp( 6, 8,19,1),fpp( 6, 8,19,2),fpp( 6, 8,19,3)/
     x 1.9363209d-02, 1.8515613d-05,-9.7805427d-06 /
      data fpp( 6, 8,20,1),fpp( 6, 8,20,2),fpp( 6, 8,20,3)/
     x 3.3460909d-02, 8.3058144d-05,-6.6416699d-05 /
      data fpp( 6, 8,21,1),fpp( 6, 8,21,2),fpp( 6, 8,21,3)/
     x 3.3460909d-02, 8.3058144d-05,-6.5841630d-05 /
      data fpp( 6, 8,22,1),fpp( 6, 8,22,2),fpp( 6, 8,22,3)/
     x 1.9363209d-02, 1.8515613d-05,-1.2080820d-05 /
      data fpp( 6, 8,23,1),fpp( 6, 8,23,2),fpp( 6, 8,23,3)/
     x 1.1627908d-02,-3.2121888d-06, 1.3160910d-05 /
      data fpp( 6, 9, 1,1),fpp( 6, 9, 1,2),fpp( 6, 9, 1,3)/
     x-5.6752779d-02,-4.2420513d-04, 4.1385944d-05 /
      data fpp( 6, 9, 2,1),fpp( 6, 9, 2,2),fpp( 6, 9, 2,3)/
     x-1.7841596d-02, 2.2484067d-05, 6.1360612d-05 /
      data fpp( 6, 9, 3,1),fpp( 6, 9, 3,2),fpp( 6, 9, 3,3)/
     x-5.3051457d-03,-7.6631934d-05, 1.1226161d-04 /
      data fpp( 6, 9, 4,1),fpp( 6, 9, 4,2),fpp( 6, 9, 4,3)/
     x-5.3051457d-03,-7.6631934d-05, 9.8089872d-05 /
      data fpp( 6, 9, 5,1),fpp( 6, 9, 5,2),fpp( 6, 9, 5,3)/
     x-1.7841596d-02, 2.2484067d-05, 1.1804755d-04 /
      data fpp( 6, 9, 6,1),fpp( 6, 9, 6,2),fpp( 6, 9, 6,3)/
     x-5.6752779d-02,-4.2420513d-04,-1.7119008d-04 /
      data fpp( 6, 9, 7,1),fpp( 6, 9, 7,2),fpp( 6, 9, 7,3)/
     x-1.9464844d-01,-3.8484865d-04,-1.8738522d-04 /
      data fpp( 6, 9, 8,1),fpp( 6, 9, 8,2),fpp( 6, 9, 8,3)/
     x 2.2734048d-02,-6.7570240d-05, 3.2304967d-05 /
      data fpp( 6, 9, 9,1),fpp( 6, 9, 9,2),fpp( 6, 9, 9,3)/
     x 8.2096981d-03,-6.9864448d-05,-1.8406646d-05 /
      data fpp( 6, 9,10,1),fpp( 6, 9,10,2),fpp( 6, 9,10,3)/
     x-2.1246804d-03,-7.2551277d-05, 1.0649616d-05 /
      data fpp( 6, 9,11,1),fpp( 6, 9,11,2),fpp( 6, 9,11,3)/
     x 1.2892527d-04,-7.0925848d-05, 1.6338183d-05 /
      data fpp( 6, 9,12,1),fpp( 6, 9,12,2),fpp( 6, 9,12,3)/
     x-5.5640070d-04,-6.7258255d-05, 2.2157653d-05 /
      data fpp( 6, 9,13,1),fpp( 6, 9,13,2),fpp( 6, 9,13,3)/
     x-3.5033501d-04,-6.1858370d-05, 2.2705206d-05 /
      data fpp( 6, 9,14,1),fpp( 6, 9,14,2),fpp( 6, 9,14,3)/
     x-2.8461171d-03,-5.4240286d-05, 2.1487525d-05 /
      data fpp( 6, 9,15,1),fpp( 6, 9,15,2),fpp( 6, 9,15,3)/
     x 2.8893253d-03,-4.4086705d-05, 1.9060696d-05 /
      data fpp( 6, 9,16,1),fpp( 6, 9,16,2),fpp( 6, 9,16,3)/
     x 1.2164335d-03,-3.1995729d-05, 1.5783690d-05 /
      data fpp( 6, 9,17,1),fpp( 6, 9,17,2),fpp( 6, 9,17,3)/
     x 8.3659031d-03,-1.4573235d-05, 1.1620542d-05 /
      data fpp( 6, 9,18,1),fpp( 6, 9,18,2),fpp( 6, 9,18,3)/
     x 1.2309300d-02, 6.7444741d-06, 4.4361414d-06 /
      data fpp( 6, 9,19,1),fpp( 6, 9,19,2),fpp( 6, 9,19,3)/
     x 1.9534255d-02, 3.0011268d-05,-4.6691076d-06 /
      data fpp( 6, 9,20,1),fpp( 6, 9,20,2),fpp( 6, 9,20,3)/
     x 3.2428592d-02, 4.0624861d-05,-4.3293711d-05 /
      data fpp( 6, 9,21,1),fpp( 6, 9,21,2),fpp( 6, 9,21,3)/
     x 3.2428592d-02, 4.0624861d-05,-4.2870314d-05 /
      data fpp( 6, 9,22,1),fpp( 6, 9,22,2),fpp( 6, 9,22,3)/
     x 1.9534255d-02, 3.0011268d-05,-6.3626961d-06 /
      data fpp( 6, 9,23,1),fpp( 6, 9,23,2),fpp( 6, 9,23,3)/
     x 1.2309300d-02, 6.7444741d-06, 1.0787098d-05 /
      data fpp( 6,10, 1,1),fpp( 6,10, 1,2),fpp( 6,10, 1,3)/
     x-2.6739558d-02, 1.0251711d-04, 6.0893452d-05 /
      data fpp( 6,10, 2,1),fpp( 6,10, 2,2),fpp( 6,10, 2,3)/
     x 6.2673492d-03, 2.1036220d-05, 8.1004095d-05 /
      data fpp( 6,10, 3,1),fpp( 6,10, 3,2),fpp( 6,10, 3,3)/
     x 2.9004266d-02, 9.6554153d-05, 1.2453817d-04 /
      data fpp( 6,10, 4,1),fpp( 6,10, 4,2),fpp( 6,10, 4,3)/
     x 2.9004266d-02, 9.6554153d-05, 1.2376845d-04 /
      data fpp( 6,10, 5,1),fpp( 6,10, 5,2),fpp( 6,10, 5,3)/
     x 6.2673492d-03, 2.1036220d-05, 8.4082946d-05 /
      data fpp( 6,10, 6,1),fpp( 6,10, 6,2),fpp( 6,10, 6,3)/
     x-2.6739558d-02, 1.0251711d-04, 4.9347762d-05 /
      data fpp( 6,10, 7,1),fpp( 6,10, 7,2),fpp( 6,10, 7,3)/
     x-1.0827441d-01,-1.3058056d-04,-1.6649599d-04 /
      data fpp( 6,10, 8,1),fpp( 6,10, 8,2),fpp( 6,10, 8,3)/
     x 1.7591105d-02,-2.8922217d-04,-1.9975379d-04 /
      data fpp( 6,10, 9,1),fpp( 6,10, 9,2),fpp( 6,10, 9,3)/
     x 4.0208669d-02,-1.1583016d-04,-1.1848616d-06 /
      data fpp( 6,10,10,1),fpp( 6,10,10,2),fpp( 6,10,10,3)/
     x 1.2535821d-02,-7.0462085d-05,-1.0810767d-05 /
      data fpp( 6,10,11,1),fpp( 6,10,11,2),fpp( 6,10,11,3)/
     x 3.6887851d-02,-5.8491887d-05, 1.2345931d-05 /
      data fpp( 6,10,12,1),fpp( 6,10,12,2),fpp( 6,10,12,3)/
     x 3.4404312d-02,-5.1782944d-05, 1.6081044d-05 /
      data fpp( 6,10,13,1),fpp( 6,10,13,2),fpp( 6,10,13,3)/
     x 8.9249733d-05,-4.5370767d-05, 1.8267895d-05 /
      data fpp( 6,10,14,1),fpp( 6,10,14,2),fpp( 6,10,14,3)/
     x 3.0660268d-02,-3.8089980d-05, 1.7299378d-05 /
      data fpp( 6,10,15,1),fpp( 6,10,15,2),fpp( 6,10,15,3)/
     x 1.1827504d-03,-2.9376721d-05, 1.5722592d-05 /
      data fpp( 6,10,16,1),fpp( 6,10,16,2),fpp( 6,10,16,3)/
     x 1.9624645d-03,-1.9109620d-05, 1.3212253d-05 /
      data fpp( 6,10,17,1),fpp( 6,10,17,2),fpp( 6,10,17,3)/
     x 3.5369893d-03,-9.0485322d-06, 1.0232397d-05 /
      data fpp( 6,10,18,1),fpp( 6,10,18,2),fpp( 6,10,18,3)/
     x 6.3374325d-03,-1.3770755d-07, 5.7441604d-06 /
      data fpp( 6,10,19,1),fpp( 6,10,19,2),fpp( 6,10,19,3)/
     x 1.4391677d-02, 7.2093146d-06, 2.3289616d-06 /
      data fpp( 6,10,20,1),fpp( 6,10,20,2),fpp( 6,10,20,3)/
     x 3.2378930d-02, 1.6444413d-05,-3.5034007d-05 /
      data fpp( 6,10,21,1),fpp( 6,10,21,2),fpp( 6,10,21,3)/
     x 3.2378930d-02, 1.6444413d-05,-3.4368460d-05 /
      data fpp( 6,10,22,1),fpp( 6,10,22,2),fpp( 6,10,22,3)/
     x 1.4391677d-02, 7.2093146d-06,-3.3322569d-07 /
      data fpp( 6,10,23,1),fpp( 6,10,23,2),fpp( 6,10,23,3)/
     x 6.3374325d-03,-1.3770755d-07, 1.5727363d-05 /
      data fpp( 6,11, 1,1),fpp( 6,11, 1,2),fpp( 6,11, 1,3)/
     x 6.0565281d-03, 7.2438693d-05, 1.2910942d-04 /
      data fpp( 6,11, 2,1),fpp( 6,11, 2,2),fpp( 6,11, 2,3)/
     x 7.0900734d-02, 2.0647505d-04, 1.1812717d-04 /
      data fpp( 6,11, 3,1),fpp( 6,11, 3,2),fpp( 6,11, 3,3)/
     x 1.4771943d-01, 3.3733532d-04, 9.7201906d-05 /
      data fpp( 6,11, 4,1),fpp( 6,11, 4,2),fpp( 6,11, 4,3)/
     x 1.4771943d-01, 3.3733532d-04, 9.2637698d-05 /
      data fpp( 6,11, 5,1),fpp( 6,11, 5,2),fpp( 6,11, 5,3)/
     x 7.0900734d-02, 2.0647505d-04, 1.3638400d-04 /
      data fpp( 6,11, 6,1),fpp( 6,11, 6,2),fpp( 6,11, 6,3)/
     x 6.0565281d-03, 7.2438693d-05, 6.0646308d-05 /
      data fpp( 6,11, 7,1),fpp( 6,11, 7,2),fpp( 6,11, 7,3)/
     x-4.8282679d-02, 7.0926898d-05,-3.4659230d-05 /
      data fpp( 6,11, 8,1),fpp( 6,11, 8,2),fpp( 6,11, 8,3)/
     x-8.3284769d-02,-1.2657076d-05,-1.7268939d-04 /
      data fpp( 6,11, 9,1),fpp( 6,11, 9,2),fpp( 6,11, 9,3)/
     x 1.8119571d-02,-1.1437093d-04,-1.4097122d-04 /
      data fpp( 6,11,10,1),fpp( 6,11,10,2),fpp( 6,11,10,3)/
     x 3.4923983d-02,-6.8930384d-05,-2.8695743d-05 /
      data fpp( 6,11,11,1),fpp( 6,11,11,2),fpp( 6,11,11,3)/
     x 1.9367483d-02,-4.6376606d-05,-1.1058094d-06 /
      data fpp( 6,11,12,1),fpp( 6,11,12,2),fpp( 6,11,12,3)/
     x 1.1382823d-02,-3.7519969d-05, 1.1566981d-05 /
      data fpp( 6,11,13,1),fpp( 6,11,13,2),fpp( 6,11,13,3)/
     x 8.2419866d-03,-3.1866562d-05, 1.4381885d-05 /
      data fpp( 6,11,14,1),fpp( 6,11,14,2),fpp( 6,11,14,3)/
     x 3.3200268d-02,-2.6481794d-05, 1.4767477d-05 /
      data fpp( 6,11,15,1),fpp( 6,11,15,2),fpp( 6,11,15,3)/
     x 6.4219942d-03,-2.0734410d-05, 1.3836206d-05 /
      data fpp( 6,11,16,1),fpp( 6,11,16,2),fpp( 6,11,16,3)/
     x 5.8368566d-03,-1.4883789d-05, 1.1433701d-05 /
      data fpp( 6,11,17,1),fpp( 6,11,17,2),fpp( 6,11,17,3)/
     x 5.1982661d-03,-9.1306361d-06, 8.6309916d-06 /
      data fpp( 6,11,18,1),fpp( 6,11,18,2),fpp( 6,11,18,3)/
     x 6.3407247d-03,-3.8896439d-06, 5.8943327d-06 /
      data fpp( 6,11,19,1),fpp( 6,11,19,2),fpp( 6,11,19,3)/
     x 1.6092292d-02, 2.5147366d-07, 8.7656776d-06 /
      data fpp( 6,11,20,1),fpp( 6,11,20,2),fpp( 6,11,20,3)/
     x 9.0363221d-02, 1.8748591d-07,-3.2677043d-05 /
      data fpp( 6,11,21,1),fpp( 6,11,21,2),fpp( 6,11,21,3)/
     x 9.0363221d-02, 1.8748591d-07,-3.1622710d-05 /
      data fpp( 6,11,22,1),fpp( 6,11,22,2),fpp( 6,11,22,3)/
     x 1.6092292d-02, 2.5147366d-07, 4.5483457d-06 /
      data fpp( 6,11,23,1),fpp( 6,11,23,2),fpp( 6,11,23,3)/
     x 6.3407247d-03,-3.8896439d-06, 2.1709327d-05 /
      data fpp( 6,12, 1,1),fpp( 6,12, 1,2),fpp( 6,12, 1,3)/
     x 7.0521577d-02, 1.5641012d-04, 3.0661325d-04 /
      data fpp( 6,12, 2,1),fpp( 6,12, 2,2),fpp( 6,12, 2,3)/
     x 2.3445753d-01, 2.5301356d-04, 1.9844749d-04 /
      data fpp( 6,12, 3,1),fpp( 6,12, 3,2),fpp( 6,12, 3,3)/
     x 5.1012668d-01, 3.9066256d-04,-2.6871228d-05 /
      data fpp( 6,12, 4,1),fpp( 6,12, 4,2),fpp( 6,12, 4,3)/
     x 5.1012668d-01, 3.9066256d-04,-3.8185064d-05 /
      data fpp( 6,12, 5,1),fpp( 6,12, 5,2),fpp( 6,12, 5,3)/
     x 2.3445753d-01, 2.5301356d-04, 2.4370284d-04 /
      data fpp( 6,12, 6,1),fpp( 6,12, 6,2),fpp( 6,12, 6,3)/
     x 7.0521577d-02, 1.5641012d-04, 1.3690572d-04 /
      data fpp( 6,12, 7,1),fpp( 6,12, 7,2),fpp( 6,12, 7,3)/
     x-1.2970350d-02, 7.5736971d-05, 1.3766295d-05 /
      data fpp( 6,12, 8,1),fpp( 6,12, 8,2),fpp( 6,12, 8,3)/
     x-6.1161968d-02, 3.4336475d-05,-9.1500896d-05 /
      data fpp( 6,12, 9,1),fpp( 6,12, 9,2),fpp( 6,12, 9,3)/
     x-4.4594379d-02,-1.3996141d-05,-1.6126071d-04 /
      data fpp( 6,12,10,1),fpp( 6,12,10,2),fpp( 6,12,10,3)/
     x 2.9016764d-02,-4.1854378d-05,-9.7624258d-05 /
      data fpp( 6,12,11,1),fpp( 6,12,11,2),fpp( 6,12,11,3)/
     x 3.2752156d-02,-3.1833688d-05,-1.6946258d-05 /
      data fpp( 6,12,12,1),fpp( 6,12,12,2),fpp( 6,12,12,3)/
     x 2.3060354d-02,-2.5807180d-05, 3.6072888d-06 /
      data fpp( 6,12,13,1),fpp( 6,12,13,2),fpp( 6,12,13,3)/
     x 1.7996652d-02,-2.2348983d-05, 1.0989103d-05 /
      data fpp( 6,12,14,1),fpp( 6,12,14,2),fpp( 6,12,14,3)/
     x 4.0623582d-02,-1.9758845d-05, 1.2634301d-05 /
      data fpp( 6,12,15,1),fpp( 6,12,15,2),fpp( 6,12,15,3)/
     x 1.4459146d-02,-1.7639638d-05, 1.2273695d-05 /
      data fpp( 6,12,16,1),fpp( 6,12,16,2),fpp( 6,12,16,3)/
     x 1.3154404d-02,-1.5885222d-05, 9.5629192d-06 /
      data fpp( 6,12,17,1),fpp( 6,12,17,2),fpp( 6,12,17,3)/
     x 1.1882816d-02,-1.4158923d-05, 6.4506280d-06 /
      data fpp( 6,12,18,1),fpp( 6,12,18,2),fpp( 6,12,18,3)/
     x 1.3412474d-02,-1.2401717d-05, 5.2845687d-06 /
      data fpp( 6,12,19,1),fpp( 6,12,19,2),fpp( 6,12,19,3)/
     x 2.6428734d-02,-1.3435209d-05, 1.0067097d-05 /
      data fpp( 6,12,20,1),fpp( 6,12,20,2),fpp( 6,12,20,3)/
     x-8.9966352d-02,-2.0368357d-05,-2.9850957d-05 /
      data fpp( 6,12,21,1),fpp( 6,12,21,2),fpp( 6,12,21,3)/
     x-8.9966352d-02,-2.0368357d-05,-2.8739678d-05 /
      data fpp( 6,12,22,1),fpp( 6,12,22,2),fpp( 6,12,22,3)/
     x 2.6428734d-02,-1.3435209d-05, 5.6219793d-06 /
      data fpp( 6,12,23,1),fpp( 6,12,23,2),fpp( 6,12,23,3)/
     x 1.3412474d-02,-1.2401717d-05, 2.1953760d-05 /
      data fpp( 6,13, 1,1),fpp( 6,13, 1,2),fpp( 6,13, 1,3)/
     x 1.6963964d-01, 7.3976825d-05, 5.1569924d-04 /
      data fpp( 6,13, 2,1),fpp( 6,13, 2,2),fpp( 6,13, 2,3)/
     x 4.6050827d-01,-6.6019309d-05, 2.8457852d-04 /
      data fpp( 6,13, 3,1),fpp( 6,13, 3,2),fpp( 6,13, 3,3)/
     x 8.3950515d-01,-3.6094958d-04,-1.9969732d-04 /
      data fpp( 6,13, 4,1),fpp( 6,13, 4,2),fpp( 6,13, 4,3)/
     x 8.3950515d-01,-3.6094958d-04,-2.1891731d-04 /
      data fpp( 6,13, 5,1),fpp( 6,13, 5,2),fpp( 6,13, 5,3)/
     x 4.6050827d-01,-6.6019309d-05, 3.6145847d-04 /
      data fpp( 6,13, 6,1),fpp( 6,13, 6,2),fpp( 6,13, 6,3)/
     x 1.6963964d-01, 7.3976825d-05, 2.2739944d-04 /
      data fpp( 6,13, 7,1),fpp( 6,13, 7,2),fpp( 6,13, 7,3)/
     x 2.4055948d-02, 9.5607218d-05, 7.2697787d-05 /
      data fpp( 6,13, 8,1),fpp( 6,13, 8,2),fpp( 6,13, 8,3)/
     x-3.7142236d-02, 6.6099177d-05,-4.2690585d-05 /
      data fpp( 6,13, 9,1),fpp( 6,13, 9,2),fpp( 6,13, 9,3)/
     x-6.0214549d-02, 2.4411489d-05,-1.2058145d-04 /
      data fpp( 6,13,10,1),fpp( 6,13,10,2),fpp( 6,13,10,3)/
     x-9.0775926d-03,-8.1101034d-06,-1.3983162d-04 /
      data fpp( 6,13,11,1),fpp( 6,13,11,2),fpp( 6,13,11,3)/
     x 3.3438716d-02,-1.4094641d-05,-4.5474054d-05 /
      data fpp( 6,13,12,1),fpp( 6,13,12,2),fpp( 6,13,12,3)/
     x 3.1212572d-02,-1.4369312d-05,-4.2881585d-06 /
      data fpp( 6,13,13,1),fpp( 6,13,13,2),fpp( 6,13,13,3)/
     x 2.6596438d-02,-1.4577505d-05, 6.6166881d-06 /
      data fpp( 6,13,14,1),fpp( 6,13,14,2),fpp( 6,13,14,3)/
     x 4.3778095d-02,-1.5112825d-05, 1.0287406d-05 /
      data fpp( 6,13,15,1),fpp( 6,13,15,2),fpp( 6,13,15,3)/
     x 2.3425965d-02,-1.6401040d-05, 1.0271688d-05 /
      data fpp( 6,13,16,1),fpp( 6,13,16,2),fpp( 6,13,16,3)/
     x 2.2849145d-02,-1.8349321d-05, 7.6478409d-06 /
      data fpp( 6,13,17,1),fpp( 6,13,17,2),fpp( 6,13,17,3)/
     x 2.3003803d-02,-2.0501670d-05, 4.4729481d-06 /
      data fpp( 6,13,18,1),fpp( 6,13,18,2),fpp( 6,13,18,3)/
     x 2.6813727d-02,-2.2931489d-05, 3.2423665d-06 /
      data fpp( 6,13,19,1),fpp( 6,13,19,2),fpp( 6,13,19,3)/
     x 4.1277232d-02,-2.6250637d-05, 3.7435858d-06 /
      data fpp( 6,13,20,1),fpp( 6,13,20,2),fpp( 6,13,20,3)/
     x-7.5163375d-02,-2.8808058d-05,-2.2134710d-05 /
      data fpp( 6,13,21,1),fpp( 6,13,21,2),fpp( 6,13,21,3)/
     x-7.5163375d-02,-2.8808058d-05,-2.1537664d-05 /
      data fpp( 6,13,22,1),fpp( 6,13,22,2),fpp( 6,13,22,3)/
     x 4.1277232d-02,-2.6250637d-05, 1.3554040d-06 /
      data fpp( 6,13,23,1),fpp( 6,13,23,2),fpp( 6,13,23,3)/
     x 2.6813727d-02,-2.2931489d-05, 1.2198048d-05 /
      data fpp( 6,14, 1,1),fpp( 6,14, 1,2),fpp( 6,14, 1,3)/
     x 1.9017140d-01, 2.0008578d-05, 4.4376459d-04 /
      data fpp( 6,14, 2,1),fpp( 6,14, 2,2),fpp( 6,14, 2,3)/
     x 5.4367488d-01,-1.6675833d-04, 2.3706431d-04 /
      data fpp( 6,14, 3,1),fpp( 6,14, 3,2),fpp( 6,14, 3,3)/
     x 8.8291550d-01,-4.1555626d-04,-1.9764385d-04 /
      data fpp( 6,14, 4,1),fpp( 6,14, 4,2),fpp( 6,14, 4,3)/
     x 8.8291550d-01,-4.1555626d-04,-2.1203060d-04 /
      data fpp( 6,14, 5,1),fpp( 6,14, 5,2),fpp( 6,14, 5,3)/
     x 5.4367488d-01,-1.6675833d-04, 2.9461133d-04 /
      data fpp( 6,14, 6,1),fpp( 6,14, 6,2),fpp( 6,14, 6,3)/
     x 1.9017140d-01, 2.0008578d-05, 2.2796328d-04 /
      data fpp( 6,14, 7,1),fpp( 6,14, 7,2),fpp( 6,14, 7,3)/
     x 4.9940274d-02, 8.7306156d-05, 9.8949545d-05 /
      data fpp( 6,14, 8,1),fpp( 6,14, 8,2),fpp( 6,14, 8,3)/
     x-1.6795579d-02, 8.4906819d-05,-8.2094596d-06 /
      data fpp( 6,14, 9,1),fpp( 6,14, 9,2),fpp( 6,14, 9,3)/
     x-5.2424119d-02, 5.3780183d-05,-7.4283706d-05 /
      data fpp( 6,14,10,1),fpp( 6,14,10,2),fpp( 6,14,10,3)/
     x-4.6725041d-02, 1.5764792d-05,-1.3993372d-04 /
      data fpp( 6,14,11,1),fpp( 6,14,11,2),fpp( 6,14,11,3)/
     x 1.9141375d-02, 3.1922517d-06,-7.8571430d-05 /
      data fpp( 6,14,12,1),fpp( 6,14,12,2),fpp( 6,14,12,3)/
     x 4.9850719d-02,-3.0075722d-06,-1.0792563d-05 /
      data fpp( 6,14,13,1),fpp( 6,14,13,2),fpp( 6,14,13,3)/
     x 3.1966327d-02,-6.4609956d-06, 1.6936807d-06 /
      data fpp( 6,14,14,1),fpp( 6,14,14,2),fpp( 6,14,14,3)/
     x 3.0518864d-02,-9.1358544d-06, 7.3538399d-06 /
      data fpp( 6,14,15,1),fpp( 6,14,15,2),fpp( 6,14,15,3)/
     x 3.0244788d-02,-1.1886204d-05, 7.6089596d-06 /
      data fpp( 6,14,16,1),fpp( 6,14,16,2),fpp( 6,14,16,3)/
     x 3.0679320d-02,-1.4967494d-05, 5.6263218d-06 /
      data fpp( 6,14,17,1),fpp( 6,14,17,2),fpp( 6,14,17,3)/
     x 3.2026820d-02,-1.8122396d-05, 2.6637533d-06 /
      data fpp( 6,14,18,1),fpp( 6,14,18,2),fpp( 6,14,18,3)/
     x 3.6041465d-02,-2.0606329d-05, 2.2466501d-07 /
      data fpp( 6,14,19,1),fpp( 6,14,19,2),fpp( 6,14,19,3)/
     x 4.5308133d-02,-2.0294244d-05,-2.3984133d-06 /
      data fpp( 6,14,20,1),fpp( 6,14,20,2),fpp( 6,14,20,3)/
     x 5.8791958d-02,-1.5821411d-05,-1.2861012d-05 /
      data fpp( 6,14,21,1),fpp( 6,14,21,2),fpp( 6,14,21,3)/
     x 5.8791958d-02,-1.5821411d-05,-1.2753758d-05 /
      data fpp( 6,14,22,1),fpp( 6,14,22,2),fpp( 6,14,22,3)/
     x 4.5308133d-02,-2.0294244d-05,-2.8274262d-06 /
      data fpp( 6,14,23,1),fpp( 6,14,23,2),fpp( 6,14,23,3)/
     x 3.6041465d-02,-2.0606329d-05, 1.8334631d-06 /
      data fpp( 6,15, 1,1),fpp( 6,15, 1,2),fpp( 6,15, 1,3)/
     x 1.4854441d-01, 1.2929086d-04, 1.9454538d-04 /
      data fpp( 6,15, 2,1),fpp( 6,15, 2,2),fpp( 6,15, 2,3)/
     x 3.8909485d-01, 2.0606662d-04, 1.1700475d-04 /
      data fpp( 6,15, 3,1),fpp( 6,15, 3,2),fpp( 6,15, 3,3)/
     x 5.2562725d-01, 3.6728262d-04,-4.6742363d-05 /
      data fpp( 6,15, 4,1),fpp( 6,15, 4,2),fpp( 6,15, 4,3)/
     x 5.2562725d-01, 3.6728262d-04,-5.0962284d-05 /
      data fpp( 6,15, 5,1),fpp( 6,15, 5,2),fpp( 6,15, 5,3)/
     x 3.8909485d-01, 2.0606662d-04, 1.3388443d-04 /
      data fpp( 6,15, 6,1),fpp( 6,15, 6,2),fpp( 6,15, 6,3)/
     x 1.4854441d-01, 1.2929086d-04, 1.3124657d-04 /
      data fpp( 6,15, 7,1),fpp( 6,15, 7,2),fpp( 6,15, 7,3)/
     x 4.7103747d-02, 1.1335416d-04, 7.2799310d-05 /
      data fpp( 6,15, 8,1),fpp( 6,15, 8,2),fpp( 6,15, 8,3)/
     x-5.9586532d-03, 1.0125555d-04, 7.0721954d-06 /
      data fpp( 6,15, 9,1),fpp( 6,15, 9,2),fpp( 6,15, 9,3)/
     x-4.0700151d-02, 7.6427777d-05,-3.8604091d-05 /
      data fpp( 6,15,10,1),fpp( 6,15,10,2),fpp( 6,15,10,3)/
     x-6.6935369d-02, 4.2250937d-05,-1.0610183d-04 /
      data fpp( 6,15,11,1),fpp( 6,15,11,2),fpp( 6,15,11,3)/
     x-1.2066166d-02, 1.0733634d-05,-1.0581859d-04 /
      data fpp( 6,15,12,1),fpp( 6,15,12,2),fpp( 6,15,12,3)/
     x 3.6426715d-02, 6.2936008d-06,-1.6353812d-05 /
      data fpp( 6,15,13,1),fpp( 6,15,13,2),fpp( 6,15,13,3)/
     x 3.3792007d-02, 1.3794878d-06,-2.2741615d-06 /
      data fpp( 6,15,14,1),fpp( 6,15,14,2),fpp( 6,15,14,3)/
     x 3.3581522d-02,-1.7677572d-06, 4.2104581d-06 /
      data fpp( 6,15,15,1),fpp( 6,15,15,2),fpp( 6,15,15,3)/
     x 3.3521279d-02,-4.0041442d-06, 4.6863291d-06 /
      data fpp( 6,15,16,1),fpp( 6,15,16,2),fpp( 6,15,16,3)/
     x 3.4304352d-02,-5.5347048d-06, 3.5762254d-06 /
      data fpp( 6,15,17,1),fpp( 6,15,17,2),fpp( 6,15,17,3)/
     x 3.5476258d-02,-6.5007446d-06, 1.2947691d-06 /
      data fpp( 6,15,18,1),fpp( 6,15,18,2),fpp( 6,15,18,3)/
     x 3.7658913d-02,-6.4831964d-06,-1.1353018d-06 /
      data fpp( 6,15,19,1),fpp( 6,15,19,2),fpp( 6,15,19,3)/
     x 4.0911561d-02,-4.6523877d-06,-3.5035619d-06 /
      data fpp( 6,15,20,1),fpp( 6,15,20,2),fpp( 6,15,20,3)/
     x 4.4503918d-02,-1.4522988d-06,-6.6184506d-06 /
      data fpp( 6,15,21,1),fpp( 6,15,21,2),fpp( 6,15,21,3)/
     x 4.4503918d-02,-1.4522988d-06,-6.6618673d-06 /
      data fpp( 6,15,22,1),fpp( 6,15,22,2),fpp( 6,15,22,3)/
     x 4.0911561d-02,-4.6523877d-06,-3.3298951d-06 /
      data fpp( 6,15,23,1),fpp( 6,15,23,2),fpp( 6,15,23,3)/
     x 3.7658913d-02,-6.4831964d-06,-1.7865525d-06 /
      data fpp( 6,16, 1,1),fpp( 6,16, 1,2),fpp( 6,16, 1,3)/
     x 6.4275112d-02, 1.6975998d-04, 6.7395549d-05 /
      data fpp( 6,16, 2,1),fpp( 6,16, 2,2),fpp( 6,16, 2,3)/
     x 1.2089247d-01, 2.6269984d-04, 5.6972402d-05 /
      data fpp( 6,16, 3,1),fpp( 6,16, 3,2),fpp( 6,16, 3,3)/
     x 1.6889534d-01, 3.7294978d-04, 3.5020845d-05 /
      data fpp( 6,16, 4,1),fpp( 6,16, 4,2),fpp( 6,16, 4,3)/
     x 1.6889534d-01, 3.7294978d-04, 3.4349265d-05 /
      data fpp( 6,16, 5,1),fpp( 6,16, 5,2),fpp( 6,16, 5,3)/
     x 1.2089247d-01, 2.6269984d-04, 5.9658720d-05 /
      data fpp( 6,16, 6,1),fpp( 6,16, 6,2),fpp( 6,16, 6,3)/
     x 6.4275112d-02, 1.6975998d-04, 5.7321857d-05 /
      data fpp( 6,16, 7,1),fpp( 6,16, 7,2),fpp( 6,16, 7,3)/
     x 2.3571829d-02, 1.2122722d-04, 3.7273854d-05 /
      data fpp( 6,16, 8,1),fpp( 6,16, 8,2),fpp( 6,16, 8,3)/
     x-6.0075494d-03, 9.8742987d-05, 8.7667290d-06 /
      data fpp( 6,16, 9,1),fpp( 6,16, 9,2),fpp( 6,16, 9,3)/
     x-3.1734662d-02, 8.0110709d-05,-1.4992770d-05 /
      data fpp( 6,16,10,1),fpp( 6,16,10,2),fpp( 6,16,10,3)/
     x-8.2420198d-02, 5.4925460d-05,-6.1247650d-05 /
      data fpp( 6,16,11,1),fpp( 6,16,11,2),fpp( 6,16,11,3)/
     x-1.0927258d-01, 4.5853211d-05,-1.1289263d-04 /
      data fpp( 6,16,12,1),fpp( 6,16,12,2),fpp( 6,16,12,3)/
     x 2.3495786d-02, 1.4325169d-05,-2.1403830d-05 /
      data fpp( 6,16,13,1),fpp( 6,16,13,2),fpp( 6,16,13,3)/
     x 3.3478352d-02, 7.0750445d-06,-3.3320489d-06 /
      data fpp( 6,16,14,1),fpp( 6,16,14,2),fpp( 6,16,14,3)/
     x 3.4790574d-02, 4.5608834d-06, 1.4980259d-06 /
      data fpp( 6,16,15,1),fpp( 6,16,15,2),fpp( 6,16,15,3)/
     x 3.5076516d-02, 3.8067809d-06, 2.4579452d-06 /
      data fpp( 6,16,16,1),fpp( 6,16,16,2),fpp( 6,16,16,3)/
     x 3.5375054d-02, 4.1663126d-06, 1.9241935d-06 /
      data fpp( 6,16,17,1),fpp( 6,16,17,2),fpp( 6,16,17,3)/
     x 3.6058392d-02, 5.3773748d-06, 6.7528103d-07 /
      data fpp( 6,16,18,1),fpp( 6,16,18,2),fpp( 6,16,18,3)/
     x 3.6783354d-02, 7.1011145d-06,-7.7331757d-07 /
      data fpp( 6,16,19,1),fpp( 6,16,19,2),fpp( 6,16,19,3)/
     x 3.7692458d-02, 8.9877946d-06,-2.0340107d-06 /
      data fpp( 6,16,20,1),fpp( 6,16,20,2),fpp( 6,16,20,3)/
     x 3.8456933d-02, 1.0542606d-05,-3.0906395d-06 /
      data fpp( 6,16,21,1),fpp( 6,16,21,2),fpp( 6,16,21,3)/
     x 3.8456933d-02, 1.0542606d-05,-3.1270762d-06 /
      data fpp( 6,16,22,1),fpp( 6,16,22,2),fpp( 6,16,22,3)/
     x 3.7692458d-02, 8.9877946d-06,-1.8882639d-06 /
      data fpp( 6,16,23,1),fpp( 6,16,23,2),fpp( 6,16,23,3)/
     x 3.6783354d-02, 7.1011145d-06,-1.3198680d-06 /
      data fpp( 6,17, 1,1),fpp( 6,17, 1,2),fpp( 6,17, 1,3)/
     x 1.1734477d-02, 1.0621924d-04, 3.1144534d-05 /
      data fpp( 6,17, 2,1),fpp( 6,17, 2,2),fpp( 6,17, 2,3)/
     x 2.4191055d-02, 1.2043400d-04, 3.2682431d-05 /
      data fpp( 6,17, 3,1),fpp( 6,17, 3,2),fpp( 6,17, 3,3)/
     x 3.3329282d-02, 1.3414825d-04, 3.6095741d-05 /
      data fpp( 6,17, 4,1),fpp( 6,17, 4,2),fpp( 6,17, 4,3)/
     x 3.3329282d-02, 1.3414825d-04, 3.5889562d-05 /
      data fpp( 6,17, 5,1),fpp( 6,17, 5,2),fpp( 6,17, 5,3)/
     x 2.4191055d-02, 1.2043400d-04, 3.3507147d-05 /
      data fpp( 6,17, 6,1),fpp( 6,17, 6,2),fpp( 6,17, 6,3)/
     x 1.1734477d-02, 1.0621924d-04, 2.8051849d-05 /
      data fpp( 6,17, 7,1),fpp( 6,17, 7,2),fpp( 6,17, 7,3)/
     x-9.4110125d-05, 9.7328980d-05, 1.8847458d-05 /
      data fpp( 6,17, 8,1),fpp( 6,17, 8,2),fpp( 6,17, 8,3)/
     x-1.1359020d-02, 9.3014504d-05, 1.0018318d-05 /
      data fpp( 6,17, 9,1),fpp( 6,17, 9,2),fpp( 6,17, 9,3)/
     x-2.2603933d-02, 8.5499386d-05,-7.2307319d-06 /
      data fpp( 6,17,10,1),fpp( 6,17,10,2),fpp( 6,17,10,3)/
     x-3.6237381d-02, 6.9007222d-05, 2.9086092d-06 /
      data fpp( 6,17,11,1),fpp( 6,17,11,2),fpp( 6,17,11,3)/
     x-3.8105395d-01, 2.6875520d-05,-1.3985370d-04 /
      data fpp( 6,17,12,1),fpp( 6,17,12,2),fpp( 6,17,12,3)/
     x-6.4677854d-02, 1.8089724d-05, 4.3922101d-06 /
      data fpp( 6,17,13,1),fpp( 6,17,13,2),fpp( 6,17,13,3)/
     x 2.0999141d-02, 1.3622334d-05,-6.9311356d-06 /
      data fpp( 6,17,14,1),fpp( 6,17,14,2),fpp( 6,17,14,3)/
     x 3.5068908d-02, 1.2030224d-05, 1.6903323d-06 /
      data fpp( 6,17,15,1),fpp( 6,17,15,2),fpp( 6,17,15,3)/
     x 3.5845642d-02, 1.2189021d-05, 8.5380629d-07 /
      data fpp( 6,17,16,1),fpp( 6,17,16,2),fpp( 6,17,16,3)/
     x 3.6085664d-02, 1.3463454d-05, 1.1464425d-06 /
      data fpp( 6,17,17,1),fpp( 6,17,17,2),fpp( 6,17,17,3)/
     x 3.6258663d-02, 1.5381245d-05, 5.4842367d-07 /
      data fpp( 6,17,18,1),fpp( 6,17,18,2),fpp( 6,17,18,3)/
     x 3.6493007d-02, 1.7522738d-05, 1.8628059d-09 /
      data fpp( 6,17,19,1),fpp( 6,17,19,2),fpp( 6,17,19,3)/
     x 3.6695848d-02, 1.9425209d-05,-4.8387489d-07 /
      data fpp( 6,17,20,1),fpp( 6,17,20,2),fpp( 6,17,20,3)/
     x 3.6839695d-02, 2.0673875d-05,-9.1036323d-07 /
      data fpp( 6,17,21,1),fpp( 6,17,21,2),fpp( 6,17,21,3)/
     x 3.6839695d-02, 2.0673875d-05,-9.2397287d-07 /
      data fpp( 6,17,22,1),fpp( 6,17,22,2),fpp( 6,17,22,3)/
     x 3.6695848d-02, 1.9425209d-05,-4.2943632d-07 /
      data fpp( 6,17,23,1),fpp( 6,17,23,2),fpp( 6,17,23,3)/
     x 3.6493007d-02, 1.7522738d-05,-2.0228184d-07 /
      data fpp( 6,18, 1,1),fpp( 6,18, 1,2),fpp( 6,18, 1,3)/
     x-1.2650810d-02,-4.8690925d-05, 1.3330477d-05 /
      data fpp( 6,18, 2,1),fpp( 6,18, 2,2),fpp( 6,18, 2,3)/
     x-9.9763907d-03,-5.5995858d-05, 1.4209546d-05 /
      data fpp( 6,18, 3,1),fpp( 6,18, 3,2),fpp( 6,18, 3,3)/
     x-9.0523912d-03,-5.7944786d-05, 1.6129338d-05 /
      data fpp( 6,18, 4,1),fpp( 6,18, 4,2),fpp( 6,18, 4,3)/
     x-9.0523912d-03,-5.7944786d-05, 1.6066214d-05 /
      data fpp( 6,18, 5,1),fpp( 6,18, 5,2),fpp( 6,18, 5,3)/
     x-9.9763907d-03,-5.5995858d-05, 1.4462043d-05 /
      data fpp( 6,18, 6,1),fpp( 6,18, 6,2),fpp( 6,18, 6,3)/
     x-1.2650810d-02,-4.8690925d-05, 1.2383614d-05 /
      data fpp( 6,18, 7,1),fpp( 6,18, 7,2),fpp( 6,18, 7,3)/
     x-1.9995339d-02,-3.6591137d-05, 9.4075006d-06 /
      data fpp( 6,18, 8,1),fpp( 6,18, 8,2),fpp( 6,18, 8,3)/
     x-8.2131837d-03,-2.3699001d-05, 6.8663835d-06 /
      data fpp( 6,18, 9,1),fpp( 6,18, 9,2),fpp( 6,18, 9,3)/
     x-3.2844413d-02,-1.3340253d-05,-2.3250347d-06 /
      data fpp( 6,18,10,1),fpp( 6,18,10,2),fpp( 6,18,10,3)/
     x 1.4395782d-01,-1.4484349d-05, 2.8929755d-05 /
      data fpp( 6,18,11,1),fpp( 6,18,11,2),fpp( 6,18,11,3)/
     x-9.2297217d-01,-3.4717291d-05,-1.1695199d-04 /
      data fpp( 6,18,12,1),fpp( 6,18,12,2),fpp( 6,18,12,3)/
     x 2.4308587d-01,-1.0802064d-05, 2.3948193d-05 /
      data fpp( 6,18,13,1),fpp( 6,18,13,2),fpp( 6,18,13,3)/
     x-2.3705083d-03, 8.4161881d-07,-6.1527834d-06 /
      data fpp( 6,18,14,1),fpp( 6,18,14,2),fpp( 6,18,14,3)/
     x 1.1860229d-01, 8.0382218d-06, 2.4029409d-06 /
      data fpp( 6,18,15,1),fpp( 6,18,15,2),fpp( 6,18,15,3)/
     x 2.2745603d-01, 1.3959137d-05, 2.7901985d-07 /
      data fpp( 6,18,16,1),fpp( 6,18,16,2),fpp( 6,18,16,3)/
     x 3.2172205d-01, 1.9397870d-05, 8.2497970d-07 /
      data fpp( 6,18,17,1),fpp( 6,18,17,2),fpp( 6,18,17,3)/
     x 4.0113369d-01, 2.4411644d-05, 5.6706133d-07 /
      data fpp( 6,18,18,1),fpp( 6,18,18,2),fpp( 6,18,18,3)/
     x 4.6589645d-01, 2.8761932d-05, 4.8277498d-07 /
      data fpp( 6,18,19,1),fpp( 6,18,19,2),fpp( 6,18,19,3)/
     x 5.1597230d-01, 3.2159369d-05, 3.5183874d-07 /
      data fpp( 6,18,20,1),fpp( 6,18,20,2),fpp( 6,18,20,3)/
     x 5.4776453d-01, 3.4351893d-05, 2.6987005d-07 /
      data fpp( 6,18,21,1),fpp( 6,18,21,2),fpp( 6,18,21,3)/
     x 5.4776453d-01, 3.4351893d-05, 2.6547048d-07 /
      data fpp( 6,18,22,1),fpp( 6,18,22,2),fpp( 6,18,22,3)/
     x 5.1597230d-01, 3.2159369d-05, 3.6943700d-07 /
      data fpp( 6,18,23,1),fpp( 6,18,23,2),fpp( 6,18,23,3)/
     x 4.6589645d-01, 2.8761932d-05, 4.1678150d-07 /
      data fpp( 6,19, 1,1),fpp( 6,19, 1,2),fpp( 6,19, 1,3)/
     x 2.4443170d-02,-1.7749554d-04, 8.6964756d-20 /
      data fpp( 6,19, 2,1),fpp( 6,19, 2,2),fpp( 6,19, 2,3)/
     x 2.4443170d-02,-2.2266457d-04,-3.9944495d-20 /
      data fpp( 6,19, 3,1),fpp( 6,19, 3,2),fpp( 6,19, 3,3)/
     x 2.4443170d-02,-2.6338311d-04,-7.0238380d-20 /
      data fpp( 6,19, 4,1),fpp( 6,19, 4,2),fpp( 6,19, 4,3)/
     x 2.4443170d-02,-2.6338311d-04, 1.6440748d-20 /
      data fpp( 6,19, 5,1),fpp( 6,19, 5,2),fpp( 6,19, 5,3)/
     x 2.4443170d-02,-2.2266457d-04, 2.1754308d-20 /
      data fpp( 6,19, 6,1),fpp( 6,19, 6,2),fpp( 6,19, 6,3)/
     x 2.4443170d-02,-1.7749554d-04,-3.2907182d-20 /
      data fpp( 6,19, 7,1),fpp( 6,19, 7,2),fpp( 6,19, 7,3)/
     x 2.4443170d-02,-1.3907643d-04,-7.2801644d-20 /
      data fpp( 6,19, 8,1),fpp( 6,19, 8,2),fpp( 6,19, 8,3)/
     x 2.4443170d-02,-1.0870250d-04,-3.9715153d-20 /
      data fpp( 6,19, 9,1),fpp( 6,19, 9,2),fpp( 6,19, 9,3)/
     x 2.4443170d-02,-8.2400373d-05, 1.7021021d-20 /
      data fpp( 6,19,10,1),fpp( 6,19,10,2),fpp( 6,19,10,3)/
     x 2.4443170d-02,-7.0097825d-05, 3.1648933d-20 /
      data fpp( 6,19,11,1),fpp( 6,19,11,2),fpp( 6,19,11,3)/
     x 2.4443170d-02,-8.4134354d-05,-2.0496096d-20 /
      data fpp( 6,19,12,1),fpp( 6,19,12,2),fpp( 6,19,12,3)/
     x 2.4443170d-02,-3.0363468d-05, 8.9451896d-20 /
      data fpp( 6,19,13,1),fpp( 6,19,13,2),fpp( 6,19,13,3)/
     x 2.4443170d-02,-6.4168094d-06, 6.2638255d-20 /
      data fpp( 6,19,14,1),fpp( 6,19,14,2),fpp( 6,19,14,3)/
     x 2.4443170d-02, 7.3208891d-06, 2.0595446d-20 /
      data fpp( 6,19,15,1),fpp( 6,19,15,2),fpp( 6,19,15,3)/
     x 2.4443170d-02, 1.7618432d-05, 8.0172000d-21 /
      data fpp( 6,19,16,1),fpp( 6,19,16,2),fpp( 6,19,16,3)/
     x 2.4443170d-02, 2.6293065d-05,-6.1061760d-20 /
      data fpp( 6,19,17,1),fpp( 6,19,17,2),fpp( 6,19,17,3)/
     x 2.4443170d-02, 3.3720178d-05, 5.6326838d-20 /
      data fpp( 6,19,18,1),fpp( 6,19,18,2),fpp( 6,19,18,3)/
     x 2.4443170d-02, 3.9767534d-05,-4.9940307d-20 /
      data fpp( 6,19,19,1),fpp( 6,19,19,2),fpp( 6,19,19,3)/
     x 2.4443170d-02, 4.4237316d-05,-6.4516162d-20 /
      data fpp( 6,19,20,1),fpp( 6,19,20,2),fpp( 6,19,20,3)/
     x 2.4443170d-02, 4.7016554d-05, 7.2561486d-20 /
      data fpp( 6,19,21,1),fpp( 6,19,21,2),fpp( 6,19,21,3)/
     x 2.4443170d-02, 4.7016554d-05,-4.0373908d-20 /
      data fpp( 6,19,22,1),fpp( 6,19,22,2),fpp( 6,19,22,3)/
     x 2.4443170d-02, 4.4237316d-05, 4.7596893d-20 /
      data fpp( 6,19,23,1),fpp( 6,19,23,2),fpp( 6,19,23,3)/
     x 2.4443170d-02, 3.9767534d-05, 1.0905749d-19 /
      data fpp( 7, 1, 1,1),fpp( 7, 1, 1,2),fpp( 7, 1, 1,3)/
     x 2.9268354d-01, 9.0878380d-04, 8.4856020d-19 /
      data fpp( 7, 1, 2,1),fpp( 7, 1, 2,2),fpp( 7, 1, 2,3)/
     x 2.9268354d-01, 8.2891650d-04,-3.2132202d-19 /
      data fpp( 7, 1, 3,1),fpp( 7, 1, 3,2),fpp( 7, 1, 3,3)/
     x 2.9268354d-01, 1.9366877d-03,-3.7786200d-19 /
      data fpp( 7, 1, 4,1),fpp( 7, 1, 4,2),fpp( 7, 1, 4,3)/
     x 2.9268354d-01, 1.9366877d-03, 5.0860037d-19 /
      data fpp( 7, 1, 5,1),fpp( 7, 1, 5,2),fpp( 7, 1, 5,3)/
     x 2.9268354d-01, 8.2891650d-04,-3.0981669d-19 /
      data fpp( 7, 1, 6,1),fpp( 7, 1, 6,2),fpp( 7, 1, 6,3)/
     x 2.9268354d-01, 9.0878380d-04,-9.6871290d-19 /
      data fpp( 7, 1, 7,1),fpp( 7, 1, 7,2),fpp( 7, 1, 7,3)/
     x 2.9268354d-01,-1.2169798d-03,-1.1104963d-18 /
      data fpp( 7, 1, 8,1),fpp( 7, 1, 8,2),fpp( 7, 1, 8,3)/
     x 2.9268354d-01,-2.7462434d-03,-6.1096639d-19 /
      data fpp( 7, 1, 9,1),fpp( 7, 1, 9,2),fpp( 7, 1, 9,3)/
     x 2.9268354d-01,-3.6354936d-03, 6.9676435d-20 /
      data fpp( 7, 1,10,1),fpp( 7, 1,10,2),fpp( 7, 1,10,3)/
     x 2.9268354d-01,-4.1423455d-03, 1.2866873d-18 /
      data fpp( 7, 1,11,1),fpp( 7, 1,11,2),fpp( 7, 1,11,3)/
     x 2.9268354d-01,-4.4151448d-03,-1.5355109d-19 /
      data fpp( 7, 1,12,1),fpp( 7, 1,12,2),fpp( 7, 1,12,3)/
     x 2.9268354d-01,-4.5002766d-03, 7.6408730d-19 /
      data fpp( 7, 1,13,1),fpp( 7, 1,13,2),fpp( 7, 1,13,3)/
     x 2.9268354d-01,-4.4072269d-03, 7.0358394d-19 /
      data fpp( 7, 1,14,1),fpp( 7, 1,14,2),fpp( 7, 1,14,3)/
     x 2.9268354d-01,-4.1244783d-03, 3.3651511d-19 /
      data fpp( 7, 1,15,1),fpp( 7, 1,15,2),fpp( 7, 1,15,3)/
     x 2.9268354d-01,-3.6057671d-03,-1.0861339d-19 /
      data fpp( 7, 1,16,1),fpp( 7, 1,16,2),fpp( 7, 1,16,3)/
     x 2.9268354d-01,-2.7048600d-03,-4.2179277d-19 /
      data fpp( 7, 1,17,1),fpp( 7, 1,17,2),fpp( 7, 1,17,3)/
     x 2.9268354d-01,-1.0857070d-03, 5.9657344d-19 /
      data fpp( 7, 1,18,1),fpp( 7, 1,18,2),fpp( 7, 1,18,3)/
     x 2.9268354d-01, 8.9184857d-04,-1.3085389d-18 /
      data fpp( 7, 1,19,1),fpp( 7, 1,19,2),fpp( 7, 1,19,3)/
     x 2.9268354d-01, 8.2154037d-04,-1.4623523d-19 /
      data fpp( 7, 1,20,1),fpp( 7, 1,20,2),fpp( 7, 1,20,3)/
     x 2.9268354d-01, 1.9282141d-03, 3.5008293d-19 /
      data fpp( 7, 1,21,1),fpp( 7, 1,21,2),fpp( 7, 1,21,3)/
     x 2.9268354d-01, 1.9282141d-03,-1.4415599d-19 /
      data fpp( 7, 1,22,1),fpp( 7, 1,22,2),fpp( 7, 1,22,3)/
     x 2.9268354d-01, 8.2154037d-04, 3.7202684d-19 /
      data fpp( 7, 1,23,1),fpp( 7, 1,23,2),fpp( 7, 1,23,3)/
     x 2.9268354d-01, 8.9184857d-04, 1.2581938d-18 /
      data fpp( 7, 2, 1,1),fpp( 7, 2, 1,2),fpp( 7, 2, 1,3)/
     x 4.3086915d-01, 2.2520340d-04,-7.7228967d-07 /
      data fpp( 7, 2, 2,1),fpp( 7, 2, 2,2),fpp( 7, 2, 2,3)/
     x-1.8937087d-01, 1.0301600d-04,-4.0564207d-06 /
      data fpp( 7, 2, 3,1),fpp( 7, 2, 3,2),fpp( 7, 2, 3,3)/
     x 1.6056100d-02, 6.0029351d-04,-1.1142028d-05 /
      data fpp( 7, 2, 4,1),fpp( 7, 2, 4,2),fpp( 7, 2, 4,3)/
     x 1.6056100d-02, 6.0029351d-04,-1.1057707d-05 /
      data fpp( 7, 2, 5,1),fpp( 7, 2, 5,2),fpp( 7, 2, 5,3)/
     x-1.8937087d-01, 1.0301600d-04,-4.3937054d-06 /
      data fpp( 7, 2, 6,1),fpp( 7, 2, 6,2),fpp( 7, 2, 6,3)/
     x 4.3086915d-01, 2.2520340d-04, 4.9252824d-07 /
      data fpp( 7, 2, 7,1),fpp( 7, 2, 7,2),fpp( 7, 2, 7,3)/
     x 1.4327523d+00,-6.1016841d-04, 1.3435925d-06 /
      data fpp( 7, 2, 8,1),fpp( 7, 2, 8,2),fpp( 7, 2, 8,3)/
     x 2.2807074d+00,-1.2516312d-03, 9.4151019d-06 /
      data fpp( 7, 2, 9,1),fpp( 7, 2, 9,2),fpp( 7, 2, 9,3)/
     x-1.1446925d-01,-1.6303597d-03,-1.5160000d-06 /
      data fpp( 7, 2,10,1),fpp( 7, 2,10,2),fpp( 7, 2,10,3)/
     x-1.2782520d+00,-1.8482010d-03, 5.6248982d-06 /
      data fpp( 7, 2,11,1),fpp( 7, 2,11,2),fpp( 7, 2,11,3)/
     x-2.4529502d+00,-1.9663454d-03, 3.6344072d-06 /
      data fpp( 7, 2,12,1),fpp( 7, 2,12,2),fpp( 7, 2,12,3)/
     x-2.9735407d+00,-2.0038688d-03, 4.3594730d-06 /
      data fpp( 7, 2,13,1),fpp( 7, 2,13,2),fpp( 7, 2,13,3)/
     x-2.5737060d+00,-1.9646572d-03, 3.6777009d-06 /
      data fpp( 7, 2,14,1),fpp( 7, 2,14,2),fpp( 7, 2,14,3)/
     x-1.1675641d+00,-1.8438435d-03, 5.6077236d-06 /
      data fpp( 7, 2,15,1),fpp( 7, 2,15,2),fpp( 7, 2,15,3)/
     x 9.8702141d-02,-1.6221988d-03,-1.4665953d-06 /
      data fpp( 7, 2,16,1),fpp( 7, 2,16,2),fpp( 7, 2,16,3)/
     x 2.2756102d+00,-1.2392401d-03, 9.3906575d-06 /
      data fpp( 7, 2,17,1),fpp( 7, 2,17,2),fpp( 7, 2,17,3)/
     x 1.3403112d+00,-5.6231808d-04, 1.3199654d-06 /
      data fpp( 7, 2,18,1),fpp( 7, 2,18,2),fpp( 7, 2,18,3)/
     x 3.1610641d-01, 2.2135486d-04, 4.6148077d-07 /
      data fpp( 7, 2,19,1),fpp( 7, 2,19,2),fpp( 7, 2,19,3)/
     x-1.4415811d-01, 1.0727326d-04,-4.5278885d-06 /
      data fpp( 7, 2,20,1),fpp( 7, 2,20,2),fpp( 7, 2,20,3)/
     x 5.1515784d-02, 6.0452484d-04,-1.1185927d-05 /
      data fpp( 7, 2,21,1),fpp( 7, 2,21,2),fpp( 7, 2,21,3)/
     x 5.1515784d-02, 6.0452484d-04,-1.1275276d-05 /
      data fpp( 7, 2,22,1),fpp( 7, 2,22,2),fpp( 7, 2,22,3)/
     x-1.4415811d-01, 1.0727326d-04,-4.1704927d-06 /
      data fpp( 7, 2,23,1),fpp( 7, 2,23,2),fpp( 7, 2,23,3)/
     x 3.1610641d-01, 2.2135486d-04,-8.7875367d-07 /
      data fpp( 7, 3, 1,1),fpp( 7, 3, 1,2),fpp( 7, 3, 1,3)/
     x-1.6340727d-01,-1.5087034d-03, 5.4890322d-04 /
      data fpp( 7, 3, 2,1),fpp( 7, 3, 2,2),fpp( 7, 3, 2,3)/
     x-1.2678818d-01, 1.7579352d-04, 2.4998956d-04 /
      data fpp( 7, 3, 3,1),fpp( 7, 3, 3,2),fpp( 7, 3, 3,3)/
     x-4.1776713d-01,-5.2555177d-04,-3.2548546d-04 /
      data fpp( 7, 3, 4,1),fpp( 7, 3, 4,2),fpp( 7, 3, 4,3)/
     x-4.1776713d-01,-5.2555177d-04,-4.3933041d-04 /
      data fpp( 7, 3, 5,1),fpp( 7, 3, 5,2),fpp( 7, 3, 5,3)/
     x-1.2678818d-01, 1.7579352d-04, 7.0536937d-04 /
      data fpp( 7, 3, 6,1),fpp( 7, 3, 6,2),fpp( 7, 3, 6,3)/
     x-1.6340727d-01,-1.5087034d-03,-1.1587711d-03 /
      data fpp( 7, 3, 7,1),fpp( 7, 3, 7,2),fpp( 7, 3, 7,3)/
     x 6.9251226d-01,-4.4560258d-04, 6.3928486d-04 /
      data fpp( 7, 3, 8,1),fpp( 7, 3, 8,2),fpp( 7, 3, 8,3)/
     x 5.4917963d-01, 7.3281626d-04, 1.1964962d-04 /
      data fpp( 7, 3, 9,1),fpp( 7, 3, 9,2),fpp( 7, 3, 9,3)/
     x 4.4179076d-01, 1.4013065d-03, 1.3811466d-04 /
      data fpp( 7, 3,10,1),fpp( 7, 3,10,2),fpp( 7, 3,10,3)/
     x 6.1258732d-01, 1.7718895d-03, 7.3883741d-05 /
      data fpp( 7, 3,11,1),fpp( 7, 3,11,2),fpp( 7, 3,11,3)/
     x 4.6837986d-01, 1.9648885d-03, 7.0842376d-05 /
      data fpp( 7, 3,12,1),fpp( 7, 3,12,2),fpp( 7, 3,12,3)/
     x 5.2610779d-01, 2.0227718d-03, 6.6826754d-05 /
      data fpp( 7, 3,13,1),fpp( 7, 3,13,2),fpp( 7, 3,13,3)/
     x-2.2498749d-01, 1.9545137d-03, 7.0330608d-05 /
      data fpp( 7, 3,14,1),fpp( 7, 3,14,2),fpp( 7, 3,14,3)/
     x 6.1176879d-01, 1.7499841d-03, 8.1042816d-05 /
      data fpp( 7, 3,15,1),fpp( 7, 3,15,2),fpp( 7, 3,15,3)/
     x 4.3996739d-01, 1.3681443d-03, 1.1675813d-04 /
      data fpp( 7, 3,16,1),fpp( 7, 3,16,2),fpp( 7, 3,16,3)/
     x 5.6409734d-01, 6.9363631d-04, 2.0497266d-04 /
      data fpp( 7, 3,17,1),fpp( 7, 3,17,2),fpp( 7, 3,17,3)/
     x-4.6128375d-01,-5.3110871d-04, 4.8204521d-04 /
      data fpp( 7, 3,18,1),fpp( 7, 3,18,2),fpp( 7, 3,18,3)/
     x-1.9457046d-01,-1.4886440d-03,-1.0502735d-03 /
      data fpp( 7, 3,19,1),fpp( 7, 3,19,2),fpp( 7, 3,19,3)/
     x-1.2599413d-01, 1.5286259d-04, 6.7648486d-04 /
      data fpp( 7, 3,20,1),fpp( 7, 3,20,2),fpp( 7, 3,20,3)/
     x-4.1708975d-01,-5.4863143d-04,-4.3402392d-04 /
      data fpp( 7, 3,21,1),fpp( 7, 3,21,2),fpp( 7, 3,21,3)/
     x-4.1708975d-01,-5.4863143d-04,-3.2745766d-04 /
      data fpp( 7, 3,22,1),fpp( 7, 3,22,2),fpp( 7, 3,22,3)/
     x-1.2599413d-01, 1.5286259d-04, 2.5021983d-04 /
      data fpp( 7, 3,23,1),fpp( 7, 3,23,2),fpp( 7, 3,23,3)/
     x-1.9457046d-01,-1.4886440d-03, 5.4822033d-04 /
      data fpp( 7, 4, 1,1),fpp( 7, 4, 1,2),fpp( 7, 4, 1,3)/
     x-1.7233132d-01, 4.3353224d-04,-7.1224845d-04 /
      data fpp( 7, 4, 2,1),fpp( 7, 4, 2,2),fpp( 7, 4, 2,3)/
     x-1.2218482d-01,-2.5468021d-03,-5.7139460d-04 /
      data fpp( 7, 4, 3,1),fpp( 7, 4, 3,2),fpp( 7, 4, 3,3)/
     x-4.4012015d-01,-2.3883184d-03,-3.1236714d-04 /
      data fpp( 7, 4, 4,1),fpp( 7, 4, 4,2),fpp( 7, 4, 4,3)/
     x-4.4012015d-01,-2.3883184d-03,-2.3746328d-04 /
      data fpp( 7, 4, 5,1),fpp( 7, 4, 5,2),fpp( 7, 4, 5,3)/
     x-1.2218482d-01,-2.5468021d-03,-8.7101003d-04 /
      data fpp( 7, 4, 6,1),fpp( 7, 4, 6,2),fpp( 7, 4, 6,3)/
     x-1.7233132d-01, 4.3353224d-04, 4.1130941d-04 /
      data fpp( 7, 4, 7,1),fpp( 7, 4, 7,2),fpp( 7, 4, 7,3)/
     x 4.0847635d-01, 1.2668227d-03, 5.3178040d-04 /
      data fpp( 7, 4, 8,1),fpp( 7, 4, 8,2),fpp( 7, 4, 8,3)/
     x 1.3936709d-01, 1.0028402d-03, 4.0230975d-05 /
      data fpp( 7, 4, 9,1),fpp( 7, 4, 9,2),fpp( 7, 4, 9,3)/
     x 4.6786198d-02, 8.4010965d-04, 1.0607570d-04 /
      data fpp( 7, 4,10,1),fpp( 7, 4,10,2),fpp( 7, 4,10,3)/
     x-6.3297676d-02, 7.5116885d-04, 6.1522242d-05 /
      data fpp( 7, 4,11,1),fpp( 7, 4,11,2),fpp( 7, 4,11,3)/
     x 5.1285196d-02, 7.0760133d-04, 6.6935335d-05 /
      data fpp( 7, 4,12,1),fpp( 7, 4,12,2),fpp( 7, 4,12,3)/
     x 7.7393460d-02, 6.9359743d-04, 6.4096417d-05 /
      data fpp( 7, 4,13,1),fpp( 7, 4,13,2),fpp( 7, 4,13,3)/
     x 4.6371737d-02, 7.0558036d-04, 6.7044998d-05 /
      data fpp( 7, 4,14,1),fpp( 7, 4,14,2),fpp( 7, 4,14,3)/
     x 1.9109437d-02, 7.4763690d-04, 6.8019590d-05 /
      data fpp( 7, 4,15,1),fpp( 7, 4,15,2),fpp( 7, 4,15,3)/
     x 3.9381123d-02, 8.3477556d-04, 9.5426640d-05 /
      data fpp( 7, 4,16,1),fpp( 7, 4,16,2),fpp( 7, 4,16,3)/
     x 9.5405500d-02, 9.9111486d-04, 1.0707985d-04 /
      data fpp( 7, 4,17,1),fpp( 7, 4,17,2),fpp( 7, 4,17,3)/
     x-1.1997882d-01, 1.2227289d-03, 4.4451596d-04 /
      data fpp( 7, 4,18,1),fpp( 7, 4,18,2),fpp( 7, 4,18,3)/
     x-1.7124618d-01, 4.3962523d-04, 4.2635630d-04 /
      data fpp( 7, 4,19,1),fpp( 7, 4,19,2),fpp( 7, 4,19,3)/
     x-5.7946416d-02,-2.4610456d-03,-8.5286115d-04 /
      data fpp( 7, 4,20,1),fpp( 7, 4,20,2),fpp( 7, 4,20,3)/
     x-4.3987706d-01,-2.2986531d-03,-2.4039771d-04 /
      data fpp( 7, 4,21,1),fpp( 7, 4,21,2),fpp( 7, 4,21,3)/
     x-4.3987706d-01,-2.2986531d-03,-3.1468729d-04 /
      data fpp( 7, 4,22,1),fpp( 7, 4,22,2),fpp( 7, 4,22,3)/
     x-5.7946416d-02,-2.4610456d-03,-5.5570285d-04 /
      data fpp( 7, 4,23,1),fpp( 7, 4,23,2),fpp( 7, 4,23,3)/
     x-1.7124618d-01, 4.3962523d-04,-6.8798733d-04 /
      data fpp( 7, 5, 1,1),fpp( 7, 5, 1,2),fpp( 7, 5, 1,3)/
     x-9.1538640d-02, 1.1915284d-03, 2.8315615d-04 /
      data fpp( 7, 5, 2,1),fpp( 7, 5, 2,2),fpp( 7, 5, 2,3)/
     x-6.1969042d-02, 2.6914747d-03, 8.3408702d-05 /
      data fpp( 7, 5, 3,1),fpp( 7, 5, 3,2),fpp( 7, 5, 3,3)/
     x-1.8244785d-01, 2.1442994d-03,-3.3824696d-04 /
      data fpp( 7, 5, 4,1),fpp( 7, 5, 4,2),fpp( 7, 5, 4,3)/
     x-1.8244785d-01, 2.1442994d-03,-3.4940248d-04 /
      data fpp( 7, 5, 5,1),fpp( 7, 5, 5,2),fpp( 7, 5, 5,3)/
     x-6.1969042d-02, 2.6914747d-03, 1.2803082d-04 /
      data fpp( 7, 5, 6,1),fpp( 7, 5, 6,2),fpp( 7, 5, 6,3)/
     x-9.1538640d-02, 1.1915284d-03, 1.1582322d-04 /
      data fpp( 7, 5, 7,1),fpp( 7, 5, 7,2),fpp( 7, 5, 7,3)/
     x 2.5023424d-02, 2.3970372d-04, 1.8666292d-05 /
      data fpp( 7, 5, 8,1),fpp( 7, 5, 8,2),fpp( 7, 5, 8,3)/
     x 3.4002303d-02, 1.7288902d-04, 6.0053609d-05 /
      data fpp( 7, 5, 9,1),fpp( 7, 5, 9,2),fpp( 7, 5, 9,3)/
     x 3.8745509d-02, 1.7890687d-04, 5.0593271d-05 /
      data fpp( 7, 5,10,1),fpp( 7, 5,10,2),fpp( 7, 5,10,3)/
     x 4.2416984d-02, 1.9996706d-04, 5.5987306d-05 /
      data fpp( 7, 5,11,1),fpp( 7, 5,11,2),fpp( 7, 5,11,3)/
     x 4.4624786d-02, 2.1371015d-04, 5.5757503d-05 /
      data fpp( 7, 5,12,1),fpp( 7, 5,12,2),fpp( 7, 5,12,3)/
     x 4.5652920d-02, 2.1728443d-04, 5.6592681d-05 /
      data fpp( 7, 5,13,1),fpp( 7, 5,13,2),fpp( 7, 5,13,3)/
     x 4.4982888d-02, 2.1044883d-04, 5.7519773d-05 /
      data fpp( 7, 5,14,1),fpp( 7, 5,14,2),fpp( 7, 5,14,3)/
     x 4.3243697d-02, 1.9344826d-04, 5.8586226d-05 /
      data fpp( 7, 5,15,1),fpp( 7, 5,15,2),fpp( 7, 5,15,3)/
     x 4.0132304d-02, 1.6839544d-04, 6.0941323d-05 /
      data fpp( 7, 5,16,1),fpp( 7, 5,16,2),fpp( 7, 5,16,3)/
     x 4.9238029d-01, 1.5889024d-04, 5.7894482d-05 /
      data fpp( 7, 5,17,1),fpp( 7, 5,17,2),fpp( 7, 5,17,3)/
     x 2.4942433d-02, 2.5963504d-04, 8.6422748d-05 /
      data fpp( 7, 5,18,1),fpp( 7, 5,18,2),fpp( 7, 5,18,3)/
     x-1.5843758d-02, 1.0668291d-03, 5.1322524d-05 /
      data fpp( 7, 5,19,1),fpp( 7, 5,19,2),fpp( 7, 5,19,3)/
     x-6.5810409d-02, 2.5766159d-03, 1.7637716d-04 /
      data fpp( 7, 5,20,1),fpp( 7, 5,20,2),fpp( 7, 5,20,3)/
     x-1.8113484d-01, 2.2223940d-03,-3.8420115d-04 /
      data fpp( 7, 5,21,1),fpp( 7, 5,21,2),fpp( 7, 5,21,3)/
     x-1.8113484d-01, 2.2223940d-03,-3.6584714d-04 /
      data fpp( 7, 5,22,1),fpp( 7, 5,22,2),fpp( 7, 5,22,3)/
     x-6.5810409d-02, 2.5766159d-03, 1.0296111d-04 /
      data fpp( 7, 5,23,1),fpp( 7, 5,23,2),fpp( 7, 5,23,3)/
     x-1.5843758d-02, 1.0668291d-03, 3.2663269d-04 /
      data fpp( 7, 6, 1,1),fpp( 7, 6, 1,2),fpp( 7, 6, 1,3)/
     x-1.6564463d-02,-2.9685403d-04,-1.2933601d-05 /
      data fpp( 7, 6, 2,1),fpp( 7, 6, 2,2),fpp( 7, 6, 2,3)/
     x 6.7302790d-02,-5.5586082d-04,-4.4970798d-05 /
      data fpp( 7, 6, 3,1),fpp( 7, 6, 3,2),fpp( 7, 6, 3,3)/
     x 2.7397937d-02, 6.0714770d-05,-1.1398721d-04 /
      data fpp( 7, 6, 4,1),fpp( 7, 6, 4,2),fpp( 7, 6, 4,3)/
     x 2.7397937d-02, 6.0714770d-05,-1.1334798d-04 /
      data fpp( 7, 6, 5,1),fpp( 7, 6, 5,2),fpp( 7, 6, 5,3)/
     x 6.7302790d-02,-5.5586082d-04,-4.7527712d-05 /
      data fpp( 7, 6, 6,1),fpp( 7, 6, 6,2),fpp( 7, 6, 6,3)/
     x-1.6564463d-02,-2.9685403d-04,-3.3451749d-06 /
      data fpp( 7, 6, 7,1),fpp( 7, 6, 7,2),fpp( 7, 6, 7,3)/
     x-5.0035268d-03,-3.3657608d-05, 2.4512411d-05 /
      data fpp( 7, 6, 8,1),fpp( 7, 6, 8,2),fpp( 7, 6, 8,3)/
     x 2.1387106d-03,-8.2822702d-06, 3.2663531d-05 /
      data fpp( 7, 6, 9,1),fpp( 7, 6, 9,2),fpp( 7, 6, 9,3)/
     x 6.7312689d-03,-7.1113138d-07, 3.9779466d-05 /
      data fpp( 7, 6,10,1),fpp( 7, 6,10,2),fpp( 7, 6,10,3)/
     x 1.1421490d-02,-3.2171064d-06, 4.2872604d-05 /
      data fpp( 7, 6,11,1),fpp( 7, 6,11,2),fpp( 7, 6,11,3)/
     x 1.4046196d-02,-7.2119270d-06, 4.4846116d-05 /
      data fpp( 7, 6,12,1),fpp( 7, 6,12,2),fpp( 7, 6,12,3)/
     x 1.2235839d-02,-9.7551570d-06, 4.5942930d-05 /
      data fpp( 7, 6,13,1),fpp( 7, 6,13,2),fpp( 7, 6,13,3)/
     x 1.2387883d-02,-9.8936953d-06, 4.7064164d-05 /
      data fpp( 7, 6,14,1),fpp( 7, 6,14,2),fpp( 7, 6,14,3)/
     x 6.5848945d-03,-8.2119477d-06, 4.7254415d-05 /
      data fpp( 7, 6,15,1),fpp( 7, 6,15,2),fpp( 7, 6,15,3)/
     x 9.7870756d-03,-5.7593408d-06, 4.8624177d-05 /
      data fpp( 7, 6,16,1),fpp( 7, 6,16,2),fpp( 7, 6,16,3)/
     x-5.0617044d-03,-1.0911829d-05, 4.5720877d-05 /
      data fpp( 7, 6,17,1),fpp( 7, 6,17,2),fpp( 7, 6,17,3)/
     x 6.2836809d-04,-4.4017095d-05, 4.6436315d-05 /
      data fpp( 7, 6,18,1),fpp( 7, 6,18,2),fpp( 7, 6,18,3)/
     x-7.3777566d-03,-2.3901763d-04, 1.6033863d-05 /
      data fpp( 7, 6,19,1),fpp( 7, 6,19,2),fpp( 7, 6,19,3)/
     x-2.4277088d-02,-5.8128997d-04, 7.4060233d-05 /
      data fpp( 7, 6,20,1),fpp( 7, 6,20,2),fpp( 7, 6,20,3)/
     x-8.4913505d-02,-4.1428267d-04,-2.2522079d-04 /
      data fpp( 7, 6,21,1),fpp( 7, 6,21,2),fpp( 7, 6,21,3)/
     x-8.4913505d-02,-4.1428267d-04,-2.1583673d-04 /
      data fpp( 7, 6,22,1),fpp( 7, 6,22,2),fpp( 7, 6,22,3)/
     x-2.4277088d-02,-5.8128997d-04, 3.6523996d-05 /
      data fpp( 7, 6,23,1),fpp( 7, 6,23,2),fpp( 7, 6,23,3)/
     x-7.3777566d-03,-2.3901763d-04, 1.5679475d-04 /
      data fpp( 7, 7, 1,1),fpp( 7, 7, 1,2),fpp( 7, 7, 1,3)/
     x-1.2555586d-02, 2.4213683d-05, 3.8413591d-05 /
      data fpp( 7, 7, 2,1),fpp( 7, 7, 2,2),fpp( 7, 7, 2,3)/
     x-4.6659968d-03, 2.0260056d-04,-3.2511822d-06 /
      data fpp( 7, 7, 3,1),fpp( 7, 7, 3,2),fpp( 7, 7, 3,3)/
     x 7.1449646d-03,-2.4739649d-04,-9.0736862d-05 /
      data fpp( 7, 7, 4,1),fpp( 7, 7, 4,2),fpp( 7, 7, 4,3)/
     x 7.1449646d-03,-2.4739649d-04,-9.3879822d-05 /
      data fpp( 7, 7, 5,1),fpp( 7, 7, 5,2),fpp( 7, 7, 5,3)/
     x-4.6659968d-03, 2.0260056d-04, 9.3206588d-06 /
      data fpp( 7, 7, 6,1),fpp( 7, 7, 6,2),fpp( 7, 7, 6,3)/
     x-1.2555586d-02, 2.4213683d-05,-8.7308130d-06 /
      data fpp( 7, 7, 7,1),fpp( 7, 7, 7,2),fpp( 7, 7, 7,3)/
     x-6.9367702d-03,-5.7379291d-05, 4.4945930d-06 /
      data fpp( 7, 7, 8,1),fpp( 7, 7, 8,2),fpp( 7, 7, 8,3)/
     x-3.9730218d-03,-5.5459942d-05, 1.2184441d-05 /
      data fpp( 7, 7, 9,1),fpp( 7, 7, 9,2),fpp( 7, 7, 9,3)/
     x-2.6351604d-03,-6.0568344d-05, 2.1773643d-05 /
      data fpp( 7, 7,10,1),fpp( 7, 7,10,2),fpp( 7, 7,10,3)/
     x-1.7409371d-03,-6.3312639d-05, 2.8712986d-05 /
      data fpp( 7, 7,11,1),fpp( 7, 7,11,2),fpp( 7, 7,11,3)/
     x-1.0992202d-03,-6.4832441d-05, 3.3258411d-05 /
      data fpp( 7, 7,12,1),fpp( 7, 7,12,2),fpp( 7, 7,12,3)/
     x-4.6794757d-04,-6.5445803d-05, 3.5587368d-05 /
      data fpp( 7, 7,13,1),fpp( 7, 7,13,2),fpp( 7, 7,13,3)/
     x 1.5981906d-04,-6.5124051d-05, 3.6252115d-05 /
      data fpp( 7, 7,14,1),fpp( 7, 7,14,2),fpp( 7, 7,14,3)/
     x 1.3158131d-03,-6.3196471d-05, 3.5776172d-05 /
      data fpp( 7, 7,15,1),fpp( 7, 7,15,2),fpp( 7, 7,15,3)/
     x 8.4588826d-04,-5.9054082d-05, 3.4495197d-05 /
      data fpp( 7, 7,16,1),fpp( 7, 7,16,2),fpp( 7, 7,16,3)/
     x 1.2378139d-03,-4.9560927d-05, 3.1419041d-05 /
      data fpp( 7, 7,17,1),fpp( 7, 7,17,2),fpp( 7, 7,17,3)/
     x 1.4711212d-03,-2.8858666d-05, 2.6422640d-05 /
      data fpp( 7, 7,18,1),fpp( 7, 7,18,2),fpp( 7, 7,18,3)/
     x 1.7873515d-03, 4.0759419d-05, 1.0766400d-05 /
      data fpp( 7, 7,19,1),fpp( 7, 7,19,2),fpp( 7, 7,19,3)/
     x 5.1791225d-03, 1.6356399d-04,-1.6222385d-06 /
      data fpp( 7, 7,20,1),fpp( 7, 7,20,2),fpp( 7, 7,20,3)/
     x 1.5509030d-02, 2.0207675d-04,-1.1398145d-04 /
      data fpp( 7, 7,21,1),fpp( 7, 7,21,2),fpp( 7, 7,21,3)/
     x 1.5509030d-02, 2.0207675d-04,-1.1208054d-04 /
      data fpp( 7, 7,22,1),fpp( 7, 7,22,2),fpp( 7, 7,22,3)/
     x 5.1791225d-03, 1.6356399d-04,-9.2258446d-06 /
      data fpp( 7, 7,23,1),fpp( 7, 7,23,2),fpp( 7, 7,23,3)/
     x 1.7873515d-03, 4.0759419d-05, 3.9279922d-05 /
      data fpp( 7, 8, 1,1),fpp( 7, 8, 1,2),fpp( 7, 8, 1,3)/
     x-1.7456431d-02, 2.8507299d-05,-2.4143029d-04 /
      data fpp( 7, 8, 2,1),fpp( 7, 8, 2,2),fpp( 7, 8, 2,3)/
     x-2.1296106d-01,-4.1597741d-04,-1.4132192d-04 /
      data fpp( 7, 8, 3,1),fpp( 7, 8, 3,2),fpp( 7, 8, 3,3)/
     x 3.0632115d-02,-1.4307081d-04, 6.2303977d-05 /
      data fpp( 7, 8, 4,1),fpp( 7, 8, 4,2),fpp( 7, 8, 4,3)/
     x 3.0632115d-02,-1.4307081d-04, 8.1365030d-05 /
      data fpp( 7, 8, 5,1),fpp( 7, 8, 5,2),fpp( 7, 8, 5,3)/
     x-2.1296106d-01,-4.1597741d-04,-2.1756613d-04 /
      data fpp( 7, 8, 6,1),fpp( 7, 8, 6,2),fpp( 7, 8, 6,3)/
     x-1.7456431d-02, 2.8507299d-05, 4.4485500d-05 /
      data fpp( 7, 8, 7,1),fpp( 7, 8, 7,2),fpp( 7, 8, 7,3)/
     x 1.1290127d-03, 2.2568773d-05,-2.5253868d-05 /
      data fpp( 7, 8, 8,1),fpp( 7, 8, 8,2),fpp( 7, 8, 8,3)/
     x-6.8690676d-04,-5.3575963d-05,-1.9520272d-06 /
      data fpp( 7, 8, 9,1),fpp( 7, 8, 9,2),fpp( 7, 8, 9,3)/
     x-3.2283770d-03,-6.8127493d-05, 3.8059771d-06 /
      data fpp( 7, 8,10,1),fpp( 7, 8,10,2),fpp( 7, 8,10,3)/
     x-4.3188009d-03,-7.4036338d-05, 1.6080119d-05 /
      data fpp( 7, 8,11,1),fpp( 7, 8,11,2),fpp( 7, 8,11,3)/
     x-5.5365706d-03,-7.5950309d-05, 2.2929547d-05 /
      data fpp( 7, 8,12,1),fpp( 7, 8,12,2),fpp( 7, 8,12,3)/
     x-5.1228164d-03,-7.4991629d-05, 2.6619693d-05 /
      data fpp( 7, 8,13,1),fpp( 7, 8,13,2),fpp( 7, 8,13,3)/
     x-4.7369518d-03,-7.1466099d-05, 2.7341681d-05 /
      data fpp( 7, 8,14,1),fpp( 7, 8,14,2),fpp( 7, 8,14,3)/
     x-3.0478136d-03,-6.5234167d-05, 2.6253582d-05 /
      data fpp( 7, 8,15,1),fpp( 7, 8,15,2),fpp( 7, 8,15,3)/
     x-2.0265160d-03,-5.5468332d-05, 2.3805989d-05 /
      data fpp( 7, 8,16,1),fpp( 7, 8,16,2),fpp( 7, 8,16,3)/
     x 7.0362303d-04,-4.0972465d-05, 1.9930460d-05 /
      data fpp( 7, 8,17,1),fpp( 7, 8,17,2),fpp( 7, 8,17,3)/
     x 2.7519016d-03,-2.0818240d-05, 1.4258171d-05 /
      data fpp( 7, 8,18,1),fpp( 7, 8,18,2),fpp( 7, 8,18,3)/
     x 6.7646597d-03,-2.4160462d-06, 3.3048566d-06 /
      data fpp( 7, 8,19,1),fpp( 7, 8,19,2),fpp( 7, 8,19,3)/
     x 1.3329902d-02, 1.5288002d-05,-1.1601597d-05 /
      data fpp( 7, 8,20,1),fpp( 7, 8,20,2),fpp( 7, 8,20,3)/
     x 2.3476635d-02, 6.5407682d-05,-5.8832467d-05 /
      data fpp( 7, 8,21,1),fpp( 7, 8,21,2),fpp( 7, 8,21,3)/
     x 2.3476635d-02, 6.5407682d-05,-5.8493799d-05 /
      data fpp( 7, 8,22,1),fpp( 7, 8,22,2),fpp( 7, 8,22,3)/
     x 1.3329902d-02, 1.5288002d-05,-1.2956272d-05 /
      data fpp( 7, 8,23,1),fpp( 7, 8,23,2),fpp( 7, 8,23,3)/
     x 6.7646597d-03,-2.4160462d-06, 8.3848859d-06 /
      data fpp( 7, 9, 1,1),fpp( 7, 9, 1,2),fpp( 7, 9, 1,3)/
     x-1.6472115d-02,-5.1932688d-04, 3.3213380d-05 /
      data fpp( 7, 9, 2,1),fpp( 7, 9, 2,2),fpp( 7, 9, 2,3)/
     x-2.7633852d-02,-4.9484906d-05, 5.3189739d-05 /
      data fpp( 7, 9, 3,1),fpp( 7, 9, 3,2),fpp( 7, 9, 3,3)/
     x-1.6843034d-02,-4.2814270d-05, 1.0853766d-04 /
      data fpp( 7, 9, 4,1),fpp( 7, 9, 4,2),fpp( 7, 9, 4,3)/
     x-1.6843034d-02,-4.2814270d-05, 8.6590142d-05 /
      data fpp( 7, 9, 5,1),fpp( 7, 9, 5,2),fpp( 7, 9, 5,3)/
     x-2.7633852d-02,-4.9484906d-05, 1.4097982d-04 /
      data fpp( 7, 9, 6,1),fpp( 7, 9, 6,2),fpp( 7, 9, 6,3)/
     x-1.6472115d-02,-5.1932688d-04,-2.9599944d-04 /
      data fpp( 7, 9, 7,1),fpp( 7, 9, 7,2),fpp( 7, 9, 7,3)/
     x 9.0913441d-02,-2.4908180d-04,-3.0442061d-05 /
      data fpp( 7, 9, 8,1),fpp( 7, 9, 8,2),fpp( 7, 9, 8,3)/
     x 1.4393429d-02,-6.9824207d-05,-8.9283164d-06 /
      data fpp( 7, 9, 9,1),fpp( 7, 9, 9,2),fpp( 7, 9, 9,3)/
     x 6.1086680d-03,-7.0007685d-05,-7.4586738d-06 /
      data fpp( 7, 9,10,1),fpp( 7, 9,10,2),fpp( 7, 9,10,3)/
     x 1.1081856d-03,-7.0526009d-05, 6.0750115d-06 /
      data fpp( 7, 9,11,1),fpp( 7, 9,11,2),fpp( 7, 9,11,3)/
     x-3.5114587d-03,-6.8682324d-05, 1.4952628d-05 /
      data fpp( 7, 9,12,1),fpp( 7, 9,12,2),fpp( 7, 9,12,3)/
     x-4.6852836d-03,-6.5123679d-05, 1.9728477d-05 /
      data fpp( 7, 9,13,1),fpp( 7, 9,13,2),fpp( 7, 9,13,3)/
     x-4.4601309d-03,-5.9735552d-05, 2.0805463d-05 /
      data fpp( 7, 9,14,1),fpp( 7, 9,14,2),fpp( 7, 9,14,3)/
     x-2.4388836d-03,-5.2192862d-05, 1.9743671d-05 /
      data fpp( 7, 9,15,1),fpp( 7, 9,15,2),fpp( 7, 9,15,3)/
     x-1.6588632d-03,-4.2052589d-05, 1.7639854d-05 /
      data fpp( 7, 9,16,1),fpp( 7, 9,16,2),fpp( 7, 9,16,3)/
     x 1.3778960d-03,-2.9057215d-05, 1.4462914d-05 /
      data fpp( 7, 9,17,1),fpp( 7, 9,17,2),fpp( 7, 9,17,3)/
     x 3.0831352d-03,-1.3058375d-05, 1.0332491d-05 /
      data fpp( 7, 9,18,1),fpp( 7, 9,18,2),fpp( 7, 9,18,3)/
     x 7.2735259d-03, 7.3887660d-06, 3.2231237d-06 /
      data fpp( 7, 9,19,1),fpp( 7, 9,19,2),fpp( 7, 9,19,3)/
     x 1.4525749d-02, 3.0367999d-05,-6.4129854d-06 /
      data fpp( 7, 9,20,1),fpp( 7, 9,20,2),fpp( 7, 9,20,3)/
     x 2.5650225d-02, 4.2392524d-05,-3.7319182d-05 /
      data fpp( 7, 9,21,1),fpp( 7, 9,21,2),fpp( 7, 9,21,3)/
     x 2.5650225d-02, 4.2392524d-05,-3.7091961d-05 /
      data fpp( 7, 9,22,1),fpp( 7, 9,22,2),fpp( 7, 9,22,3)/
     x 1.4525749d-02, 3.0367999d-05,-7.3218682d-06 /
      data fpp( 7, 9,23,1),fpp( 7, 9,23,2),fpp( 7, 9,23,3)/
     x 7.2735259d-03, 7.3887660d-06, 6.6314341d-06 /
      data fpp( 7,10, 1,1),fpp( 7,10, 1,2),fpp( 7,10, 1,3)/
     x-4.7339688d-02, 1.2814022d-04, 4.8895283d-05 /
      data fpp( 7,10, 2,1),fpp( 7,10, 2,2),fpp( 7,10, 2,3)/
     x-1.1918311d-02, 3.1269037d-05, 7.1089434d-05 /
      data fpp( 7,10, 3,1),fpp( 7,10, 3,2),fpp( 7,10, 3,3)/
     x 9.1217592d-03, 6.8741889d-05, 1.1923098d-04 /
      data fpp( 7,10, 4,1),fpp( 7,10, 4,2),fpp( 7,10, 4,3)/
     x 9.1217592d-03, 6.8741889d-05, 1.1821134d-04 /
      data fpp( 7,10, 5,1),fpp( 7,10, 5,2),fpp( 7,10, 5,3)/
     x-1.1918311d-02, 3.1269037d-05, 7.5167975d-05 /
      data fpp( 7,10, 6,1),fpp( 7,10, 6,2),fpp( 7,10, 6,3)/
     x-4.7339688d-02, 1.2814022d-04, 3.3600756d-05 /
      data fpp( 7,10, 7,1),fpp( 7,10, 7,2),fpp( 7,10, 7,3)/
     x-1.3571239d-01,-2.0275756d-04,-2.0945700d-04 /
      data fpp( 7,10, 8,1),fpp( 7,10, 8,2),fpp( 7,10, 8,3)/
     x 2.8535930d-02,-2.1419521d-04,-1.0537876d-04 /
      data fpp( 7,10, 9,1),fpp( 7,10, 9,2),fpp( 7,10, 9,3)/
     x 2.7718450d-02,-9.7305768d-05,-1.4843968d-05 /
      data fpp( 7,10,10,1),fpp( 7,10,10,2),fpp( 7,10,10,3)/
     x 1.6069104d-02,-6.5233626d-05,-7.4873712d-06 /
      data fpp( 7,10,11,1),fpp( 7,10,11,2),fpp( 7,10,11,3)/
     x-1.6093290d-03,-5.5022396d-05, 8.9074526d-06 /
      data fpp( 7,10,12,1),fpp( 7,10,12,2),fpp( 7,10,12,3)/
     x-5.7043801d-03,-4.8957654d-05, 1.4253561d-05 /
      data fpp( 7,10,13,1),fpp( 7,10,13,2),fpp( 7,10,13,3)/
     x 1.8119713d-03,-4.3123693d-05, 1.6326304d-05 /
      data fpp( 7,10,14,1),fpp( 7,10,14,2),fpp( 7,10,14,3)/
     x-6.4417720d-03,-3.6410385d-05, 1.5793222d-05 /
      data fpp( 7,10,15,1),fpp( 7,10,15,2),fpp( 7,10,15,3)/
     x 2.2985199d-03,-2.8387312d-05, 1.4412809d-05 /
      data fpp( 7,10,16,1),fpp( 7,10,16,2),fpp( 7,10,16,3)/
     x 3.4522940d-03,-1.9066675d-05, 1.2127544d-05 /
      data fpp( 7,10,17,1),fpp( 7,10,17,2),fpp( 7,10,17,3)/
     x 4.9309045d-03,-9.3222594d-06, 9.0350150d-06 /
      data fpp( 7,10,18,1),fpp( 7,10,18,2),fpp( 7,10,18,3)/
     x 7.8219577d-03,-8.5301784d-07, 4.2623960d-06 /
      data fpp( 7,10,19,1),fpp( 7,10,19,2),fpp( 7,10,19,3)/
     x 1.5105179d-02, 5.6740017d-06,-8.4859895d-07 /
      data fpp( 7,10,20,1),fpp( 7,10,20,2),fpp( 7,10,20,3)/
     x 2.8979049d-02, 1.2930223d-05,-2.9104000d-05 /
      data fpp( 7,10,21,1),fpp( 7,10,21,2),fpp( 7,10,21,3)/
     x 2.8979049d-02, 1.2930223d-05,-2.8720700d-05 /
      data fpp( 7,10,22,1),fpp( 7,10,22,2),fpp( 7,10,22,3)/
     x 1.5105179d-02, 5.6740017d-06,-2.3818000d-06 /
      data fpp( 7,10,23,1),fpp( 7,10,23,2),fpp( 7,10,23,3)/
     x 7.8219577d-03,-8.5301784d-07, 1.0011900d-05 /
      data fpp( 7,11, 1,1),fpp( 7,11, 1,2),fpp( 7,11, 1,3)/
     x-1.6277982d-02, 5.1333994d-05, 1.0381620d-04 /
      data fpp( 7,11, 2,1),fpp( 7,11, 2,2),fpp( 7,11, 2,3)/
     x 3.8212924d-02, 1.6772676d-04, 1.0233210d-04 /
      data fpp( 7,11, 3,1),fpp( 7,11, 3,2),fpp( 7,11, 3,3)/
     x 9.7923328d-02, 2.7394671d-04, 1.0134541d-04 /
      data fpp( 7,11, 4,1),fpp( 7,11, 4,2),fpp( 7,11, 4,3)/
     x 9.7923328d-02, 2.7394671d-04, 9.7506735d-05 /
      data fpp( 7,11, 5,1),fpp( 7,11, 5,2),fpp( 7,11, 5,3)/
     x 3.8212924d-02, 1.6772676d-04, 1.1768678d-04 /
      data fpp( 7,11, 6,1),fpp( 7,11, 6,2),fpp( 7,11, 6,3)/
     x-1.6277982d-02, 5.1333994d-05, 4.6236152d-05 /
      data fpp( 7,11, 7,1),fpp( 7,11, 7,2),fpp( 7,11, 7,3)/
     x-6.5582986d-02, 7.6250061d-05,-5.8623388d-05 /
      data fpp( 7,11, 8,1),fpp( 7,11, 8,2),fpp( 7,11, 8,3)/
     x-6.6153804d-02,-4.4608956d-05,-1.6318060d-04 /
      data fpp( 7,11, 9,1),fpp( 7,11, 9,2),fpp( 7,11, 9,3)/
     x 2.2307097d-02,-8.8977242d-05,-9.6314208d-05 /
      data fpp( 7,11,10,1),fpp( 7,11,10,2),fpp( 7,11,10,3)/
     x 3.1661544d-02,-5.7027488d-05,-2.6644568d-05 /
      data fpp( 7,11,11,1),fpp( 7,11,11,2),fpp( 7,11,11,3)/
     x 2.0314754d-02,-4.1156091d-05,-1.8335194d-06 /
      data fpp( 7,11,12,1),fpp( 7,11,12,2),fpp( 7,11,12,3)/
     x 1.3116452d-02,-3.4161704d-05, 9.4086458d-06 /
      data fpp( 7,11,13,1),fpp( 7,11,13,2),fpp( 7,11,13,3)/
     x 9.6850445d-03,-2.9387677d-05, 1.2708936d-05 /
      data fpp( 7,11,14,1),fpp( 7,11,14,2),fpp( 7,11,14,3)/
     x 1.1551310d-03,-2.4741597d-05, 1.3309610d-05 /
      data fpp( 7,11,15,1),fpp( 7,11,15,2),fpp( 7,11,15,3)/
     x 7.6459829d-03,-1.9724165d-05, 1.2664625d-05 /
      data fpp( 7,11,16,1),fpp( 7,11,16,2),fpp( 7,11,16,3)/
     x 7.3642450d-03,-1.4586087d-05, 1.0575890d-05 /
      data fpp( 7,11,17,1),fpp( 7,11,17,2),fpp( 7,11,17,3)/
     x 7.3106700d-03,-9.7125872d-06, 7.5578166d-06 /
      data fpp( 7,11,18,1),fpp( 7,11,18,2),fpp( 7,11,18,3)/
     x 8.9224059d-03,-5.2966947d-06, 4.1268441d-06 /
      data fpp( 7,11,19,1),fpp( 7,11,19,2),fpp( 7,11,19,3)/
     x 1.7114624d-02,-1.8420059d-06, 3.3968070d-06 /
      data fpp( 7,11,20,1),fpp( 7,11,20,2),fpp( 7,11,20,3)/
     x 2.4119443d-02,-1.7914147d-06,-2.5880072d-05 /
      data fpp( 7,11,21,1),fpp( 7,11,21,2),fpp( 7,11,21,3)/
     x 2.4119443d-02,-1.7914147d-06,-2.5266187d-05 /
      data fpp( 7,11,22,1),fpp( 7,11,22,2),fpp( 7,11,22,3)/
     x 1.7114624d-02,-1.8420059d-06, 9.4126779d-07 /
      data fpp( 7,11,23,1),fpp( 7,11,23,2),fpp( 7,11,23,3)/
     x 8.9224059d-03,-5.2966947d-06, 1.3335116d-05 /
      data fpp( 7,12, 1,1),fpp( 7,12, 1,2),fpp( 7,12, 1,3)/
     x 3.3626876d-02, 1.3973180d-04, 2.3487231d-04 /
      data fpp( 7,12, 2,1),fpp( 7,12, 2,2),fpp( 7,12, 2,3)/
     x 1.6110164d-01, 2.1156993d-04, 1.6198838d-04 /
      data fpp( 7,12, 3,1),fpp( 7,12, 3,2),fpp( 7,12, 3,3)/
     x 3.3718690d-01, 3.0676726d-04, 1.0682166d-05 /
      data fpp( 7,12, 4,1),fpp( 7,12, 4,2),fpp( 7,12, 4,3)/
     x 3.3718690d-01, 3.0676726d-04, 2.1533102d-06 /
      data fpp( 7,12, 5,1),fpp( 7,12, 5,2),fpp( 7,12, 5,3)/
     x 1.6110164d-01, 2.1156993d-04, 1.9610381d-04 /
      data fpp( 7,12, 6,1),fpp( 7,12, 6,2),fpp( 7,12, 6,3)/
     x 3.3626876d-02, 1.3973180d-04, 1.0693947d-04 /
      data fpp( 7,12, 7,1),fpp( 7,12, 7,2),fpp( 7,12, 7,3)/
     x-3.5333278d-02, 6.2325321d-05,-4.0616728d-06 /
      data fpp( 7,12, 8,1),fpp( 7,12, 8,2),fpp( 7,12, 8,3)/
     x-6.7751107d-02, 3.0009034d-05,-1.0251278d-04 /
      data fpp( 7,12, 9,1),fpp( 7,12, 9,2),fpp( 7,12, 9,3)/
     x-2.8039653d-02,-1.8421265d-05,-1.3721522d-04 /
      data fpp( 7,12,10,1),fpp( 7,12,10,2),fpp( 7,12,10,3)/
     x 2.7379728d-02,-3.2426423d-05,-7.1668325d-05 /
      data fpp( 7,12,11,1),fpp( 7,12,11,2),fpp( 7,12,11,3)/
     x 2.9644661d-02,-2.6593239d-05,-1.6013475d-05 /
      data fpp( 7,12,12,1),fpp( 7,12,12,2),fpp( 7,12,12,3)/
     x 2.2384122d-02,-2.2589531d-05, 2.7022251d-06 /
      data fpp( 7,12,13,1),fpp( 7,12,13,2),fpp( 7,12,13,3)/
     x 1.7945863d-02,-2.0045599d-05, 9.4045745d-06 /
      data fpp( 7,12,14,1),fpp( 7,12,14,2),fpp( 7,12,14,3)/
     x 9.0711333d-03,-1.8013227d-05, 1.1291477d-05 /
      data fpp( 7,12,15,1),fpp( 7,12,15,2),fpp( 7,12,15,3)/
     x 1.4678794d-02,-1.6340030d-05, 1.1177518d-05 /
      data fpp( 7,12,16,1),fpp( 7,12,16,2),fpp( 7,12,16,3)/
     x 1.3994557d-02,-1.5060979d-05, 8.9004513d-06 /
      data fpp( 7,12,17,1),fpp( 7,12,17,2),fpp( 7,12,17,3)/
     x 1.3477087d-02,-1.3933392d-05, 5.5286768d-06 /
      data fpp( 7,12,18,1),fpp( 7,12,18,2),fpp( 7,12,18,3)/
     x 1.5219524d-02,-1.2796203d-05, 3.2268414d-06 /
      data fpp( 7,12,19,1),fpp( 7,12,19,2),fpp( 7,12,19,3)/
     x 2.5514005d-02,-1.3335978d-05, 3.7879574d-06 /
      data fpp( 7,12,20,1),fpp( 7,12,20,2),fpp( 7,12,20,3)/
     x 9.1103152d-02,-1.7092564d-05,-2.2578671d-05 /
      data fpp( 7,12,21,1),fpp( 7,12,21,2),fpp( 7,12,21,3)/
     x 9.1103152d-02,-1.7092564d-05,-2.1967965d-05 /
      data fpp( 7,12,22,1),fpp( 7,12,22,2),fpp( 7,12,22,3)/
     x 2.5514005d-02,-1.3335978d-05, 1.3451329d-06 /
      data fpp( 7,12,23,1),fpp( 7,12,23,2),fpp( 7,12,23,3)/
     x 1.5219524d-02,-1.2796203d-05, 1.2387434d-05 /
      data fpp( 7,13, 1,1),fpp( 7,13, 1,2),fpp( 7,13, 1,3)/
     x 9.8374010d-02, 7.6486791d-05, 3.8076195d-04 /
      data fpp( 7,13, 2,1),fpp( 7,13, 2,2),fpp( 7,13, 2,3)/
     x 3.3743349d-01,-2.1936494d-05, 2.2058409d-04 /
      data fpp( 7,13, 3,1),fpp( 7,13, 3,2),fpp( 7,13, 3,3)/
     x 7.3285486d-01,-2.2792976d-04,-1.1487832d-04 /
      data fpp( 7,13, 4,1),fpp( 7,13, 4,2),fpp( 7,13, 4,3)/
     x 7.3285486d-01,-2.2792976d-04,-1.2848610d-04 /
      data fpp( 7,13, 5,1),fpp( 7,13, 5,2),fpp( 7,13, 5,3)/
     x 3.3743349d-01,-2.1936494d-05, 2.7501521d-04 /
      data fpp( 7,13, 6,1),fpp( 7,13, 6,2),fpp( 7,13, 6,3)/
     x 9.8374010d-02, 7.6486791d-05, 1.7664525d-04 /
      data fpp( 7,13, 7,1),fpp( 7,13, 7,2),fpp( 7,13, 7,3)/
     x-4.8342983d-03, 9.0218654d-05, 4.8339792d-05 /
      data fpp( 7,13, 8,1),fpp( 7,13, 8,2),fpp( 7,13, 8,3)/
     x-5.3155328d-02, 5.7502821d-05,-5.4068417d-05 /
      data fpp( 7,13, 9,1),fpp( 7,13, 9,2),fpp( 7,13, 9,3)/
     x-5.5646531d-02, 1.9718302d-05,-1.2009613d-04 /
      data fpp( 7,13,10,1),fpp( 7,13,10,2),fpp( 7,13,10,3)/
     x 9.2361216d-04,-4.9248185d-06,-1.0938908d-04 /
      data fpp( 7,13,11,1),fpp( 7,13,11,2),fpp( 7,13,11,3)/
     x 2.9608964d-02,-1.0384951d-05,-3.4967547d-05 /
      data fpp( 7,13,12,1),fpp( 7,13,12,2),fpp( 7,13,12,3)/
     x 2.8108000d-02,-1.1932171d-05,-4.4927288d-06 /
      data fpp( 7,13,13,1),fpp( 7,13,13,2),fpp( 7,13,13,3)/
     x 2.4515337d-02,-1.2541927d-05, 5.7064624d-06 /
      data fpp( 7,13,14,1),fpp( 7,13,14,2),fpp( 7,13,14,3)/
     x 1.7467137d-02,-1.3245495d-05, 9.0688793d-06 /
      data fpp( 7,13,15,1),fpp( 7,13,15,2),fpp( 7,13,15,3)/
     x 2.1921881d-02,-1.4491715d-05, 9.2940205d-06 /
      data fpp( 7,13,16,1),fpp( 7,13,16,2),fpp( 7,13,16,3)/
     x 2.1742171d-02,-1.6267998d-05, 7.0290387d-06 /
      data fpp( 7,13,17,1),fpp( 7,13,17,2),fpp( 7,13,17,3)/
     x 2.2170584d-02,-1.8163846d-05, 3.6898248d-06 /
      data fpp( 7,13,18,1),fpp( 7,13,18,2),fpp( 7,13,18,3)/
     x 2.5204903d-02,-1.9976491d-05, 1.4256621d-06 /
      data fpp( 7,13,19,1),fpp( 7,13,19,2),fpp( 7,13,19,3)/
     x 3.5841906d-02,-2.1782081d-05,-6.8473226d-08 /
      data fpp( 7,13,20,1),fpp( 7,13,20,2),fpp( 7,13,20,3)/
     x 9.5013700d-02,-2.2622329d-05,-1.6691769d-05 /
      data fpp( 7,13,21,1),fpp( 7,13,21,2),fpp( 7,13,21,3)/
     x 9.5013700d-02,-2.2622329d-05,-1.6394456d-05 /
      data fpp( 7,13,22,1),fpp( 7,13,22,2),fpp( 7,13,22,3)/
     x 3.5841906d-02,-2.1782081d-05,-1.2577269d-06 /
      data fpp( 7,13,23,1),fpp( 7,13,23,2),fpp( 7,13,23,3)/
     x 2.5204903d-02,-1.9976491d-05, 5.8853635d-06 /
      data fpp( 7,14, 1,1),fpp( 7,14, 1,2),fpp( 7,14, 1,3)/
     x 1.3608749d-01, 4.0957031d-05, 3.2928548d-04 /
      data fpp( 7,14, 2,1),fpp( 7,14, 2,2),fpp( 7,14, 2,3)/
     x 3.6915581d-01,-9.1933960d-05, 1.8522504d-04 /
      data fpp( 7,14, 3,1),fpp( 7,14, 3,2),fpp( 7,14, 3,3)/
     x 7.4180696d-01,-2.6833623d-04,-1.1768563d-04 /
      data fpp( 7,14, 4,1),fpp( 7,14, 4,2),fpp( 7,14, 4,3)/
     x 7.4180696d-01,-2.6833623d-04,-1.2781862d-04 /
      data fpp( 7,14, 5,1),fpp( 7,14, 5,2),fpp( 7,14, 5,3)/
     x 3.6915581d-01,-9.1933960d-05, 2.2575697d-04 /
      data fpp( 7,14, 6,1),fpp( 7,14, 6,2),fpp( 7,14, 6,3)/
     x 1.3608749d-01, 4.0957031d-05, 1.7729075d-04 /
      data fpp( 7,14, 7,1),fpp( 7,14, 7,2),fpp( 7,14, 7,3)/
     x 1.7199199d-02, 8.6008063d-05, 7.2978016d-05 /
      data fpp( 7,14, 8,1),fpp( 7,14, 8,2),fpp( 7,14, 8,3)/
     x-3.6740338d-02, 7.8601681d-05,-1.8668818d-05 /
      data fpp( 7,14, 9,1),fpp( 7,14, 9,2),fpp( 7,14, 9,3)/
     x-6.1215071d-02, 4.6690056d-05,-8.3928743d-05 /
      data fpp( 7,14,10,1),fpp( 7,14,10,2),fpp( 7,14,10,3)/
     x-3.2801986d-02, 1.5711697d-05,-1.2233421d-04 /
      data fpp( 7,14,11,1),fpp( 7,14,11,2),fpp( 7,14,11,3)/
     x 2.0016582d-02, 4.4070439d-06,-5.5828421d-05 /
      data fpp( 7,14,12,1),fpp( 7,14,12,2),fpp( 7,14,12,3)/
     x 2.5038727d-02,-1.7657831d-06,-9.8821079d-06 /
      data fpp( 7,14,13,1),fpp( 7,14,13,2),fpp( 7,14,13,3)/
     x 2.8162435d-02,-5.2306931d-06, 1.6908524d-06 /
      data fpp( 7,14,14,1),fpp( 7,14,14,2),fpp( 7,14,14,3)/
     x 2.7284984d-02,-7.6947942d-06, 6.4246984d-06 /
      data fpp( 7,14,15,1),fpp( 7,14,15,2),fpp( 7,14,15,3)/
     x 2.7190033d-02,-1.0179111d-05, 6.8643539d-06 /
      data fpp( 7,14,16,1),fpp( 7,14,16,2),fpp( 7,14,16,3)/
     x 2.7599857d-02,-1.2837030d-05, 5.0758859d-06 /
      data fpp( 7,14,17,1),fpp( 7,14,17,2),fpp( 7,14,17,3)/
     x 2.8826757d-02,-1.5429226d-05, 2.1601024d-06 /
      data fpp( 7,14,18,1),fpp( 7,14,18,2),fpp( 7,14,18,3)/
     x 3.1741052d-02,-1.7397831d-05,-5.6429562d-07 /
      data fpp( 7,14,19,1),fpp( 7,14,19,2),fpp( 7,14,19,3)/
     x 3.8056222d-02,-1.7465697d-05,-3.2269200d-06 /
      data fpp( 7,14,20,1),fpp( 7,14,20,2),fpp( 7,14,20,3)/
     x 4.6814739d-02,-1.5082118d-05,-1.0312025d-05 /
      data fpp( 7,14,21,1),fpp( 7,14,21,2),fpp( 7,14,21,3)/
     x 4.6814739d-02,-1.5082118d-05,-1.0281466d-05 /
      data fpp( 7,14,22,1),fpp( 7,14,22,2),fpp( 7,14,22,3)/
     x 3.8056222d-02,-1.7465697d-05,-3.3491525d-06 /
      data fpp( 7,14,23,1),fpp( 7,14,23,2),fpp( 7,14,23,3)/
     x 3.1741052d-02,-1.7397831d-05,-1.0592377d-07 /
      data fpp( 7,15, 1,1),fpp( 7,15, 1,2),fpp( 7,15, 1,3)/
     x 9.3831312d-02, 1.2570309d-04, 1.5253707d-04 /
      data fpp( 7,15, 2,1),fpp( 7,15, 2,2),fpp( 7,15, 2,3)/
     x 2.0352454d-01, 1.8198233d-04, 9.8618852d-05 /
      data fpp( 7,15, 3,1),fpp( 7,15, 3,2),fpp( 7,15, 3,3)/
     x 3.7242999d-01, 2.9496069d-04,-1.5148481d-05 /
      data fpp( 7,15, 4,1),fpp( 7,15, 4,2),fpp( 7,15, 4,3)/
     x 3.7242999d-01, 2.9496069d-04,-1.8248984d-05 /
      data fpp( 7,15, 5,1),fpp( 7,15, 5,2),fpp( 7,15, 5,3)/
     x 2.0352454d-01, 1.8198233d-04, 1.1102086d-04 /
      data fpp( 7,15, 6,1),fpp( 7,15, 6,2),fpp( 7,15, 6,3)/
     x 9.3831312d-02, 1.2570309d-04, 1.0602953d-04 /
      data fpp( 7,15, 7,1),fpp( 7,15, 7,2),fpp( 7,15, 7,3)/
     x 1.7347756d-02, 1.1087909d-04, 5.6125013d-05 /
      data fpp( 7,15, 8,1),fpp( 7,15, 8,2),fpp( 7,15, 8,3)/
     x-2.6184363d-02, 9.6528456d-05,-1.2015834d-06 /
      data fpp( 7,15, 9,1),fpp( 7,15, 9,2),fpp( 7,15, 9,3)/
     x-5.6626923d-02, 7.1303474d-05,-4.8504679d-05 /
      data fpp( 7,15,10,1),fpp( 7,15,10,2),fpp( 7,15,10,3)/
     x-5.8081040d-02, 3.6050029d-05,-1.0752770d-04 /
      data fpp( 7,15,11,1),fpp( 7,15,11,2),fpp( 7,15,11,3)/
     x 3.5370090d-04, 1.4794776d-05,-7.5076524d-05 /
      data fpp( 7,15,12,1),fpp( 7,15,12,2),fpp( 7,15,12,3)/
     x 2.5509525d-02, 6.5513038d-06,-1.2022204d-05 /
      data fpp( 7,15,13,1),fpp( 7,15,13,2),fpp( 7,15,13,3)/
     x 2.9620823d-02, 1.7786995d-06,-1.6946609d-06 /
      data fpp( 7,15,14,1),fpp( 7,15,14,2),fpp( 7,15,14,3)/
     x 2.9533740d-02,-1.1673286d-06, 3.7468472d-06 /
      data fpp( 7,15,15,1),fpp( 7,15,15,2),fpp( 7,15,15,3)/
     x 2.9950669d-02,-3.1658404d-06, 4.2632720d-06 /
      data fpp( 7,15,16,1),fpp( 7,15,16,2),fpp( 7,15,16,3)/
     x 3.0380941d-02,-4.5698814d-06, 3.2120647d-06 /
      data fpp( 7,15,17,1),fpp( 7,15,17,2),fpp( 7,15,17,3)/
     x 3.1347445d-02,-5.4632517d-06, 1.0984693d-06 /
      data fpp( 7,15,18,1),fpp( 7,15,18,2),fpp( 7,15,18,3)/
     x 3.2883504d-02,-5.6401863d-06,-1.2219418d-06 /
      data fpp( 7,15,19,1),fpp( 7,15,19,2),fpp( 7,15,19,3)/
     x 3.5205916d-02,-4.5891309d-06,-3.3447022d-06 /
      data fpp( 7,15,20,1),fpp( 7,15,20,2),fpp( 7,15,20,3)/
     x 3.7682588d-02,-2.5791976d-06,-5.6972496d-06 /
      data fpp( 7,15,21,1),fpp( 7,15,21,2),fpp( 7,15,21,3)/
     x 3.7682588d-02,-2.5791976d-06,-5.7459001d-06 /
      data fpp( 7,15,22,1),fpp( 7,15,22,2),fpp( 7,15,22,3)/
     x 3.5205916d-02,-4.5891309d-06,-3.1501000d-06 /
      data fpp( 7,15,23,1),fpp( 7,15,23,2),fpp( 7,15,23,3)/
     x 3.2883504d-02,-5.6401863d-06,-1.9517000d-06 /
      data fpp( 7,16, 1,1),fpp( 7,16, 1,2),fpp( 7,16, 1,3)/
     x 3.4121476d-02, 1.4503063d-04, 5.8559895d-05 /
      data fpp( 7,16, 2,1),fpp( 7,16, 2,2),fpp( 7,16, 2,3)/
     x 7.2898946d-02, 2.1473863d-04, 5.2192710d-05 /
      data fpp( 7,16, 3,1),fpp( 7,16, 3,2),fpp( 7,16, 3,3)/
     x 1.1065682d-01, 2.9614349d-04, 3.8879266d-05 /
      data fpp( 7,16, 4,1),fpp( 7,16, 4,2),fpp( 7,16, 4,3)/
     x 1.1065682d-01, 2.9614349d-04, 3.8300846d-05 /
      data fpp( 7,16, 5,1),fpp( 7,16, 5,2),fpp( 7,16, 5,3)/
     x 7.2898946d-02, 2.1473863d-04, 5.4506390d-05 /
      data fpp( 7,16, 6,1),fpp( 7,16, 6,2),fpp( 7,16, 6,3)/
     x 3.4121476d-02, 1.4503063d-04, 4.9883592d-05 /
      data fpp( 7,16, 7,1),fpp( 7,16, 7,2),fpp( 7,16, 7,3)/
     x 1.6445569d-03, 1.0712356d-04, 3.0371240d-05 /
      data fpp( 7,16, 8,1),fpp( 7,16, 8,2),fpp( 7,16, 8,3)/
     x-2.3298897d-02, 8.7464496d-05, 4.4374475d-06 /
      data fpp( 7,16, 9,1),fpp( 7,16, 9,2),fpp( 7,16, 9,3)/
     x-4.7696469d-02, 6.9250048d-05,-2.3425030d-05 /
      data fpp( 7,16,10,1),fpp( 7,16,10,2),fpp( 7,16,10,3)/
     x-9.7813349d-02, 5.4930188d-05,-7.4801327d-05 /
      data fpp( 7,16,11,1),fpp( 7,16,11,2),fpp( 7,16,11,3)/
     x-3.0874681d-02, 3.4447854d-05,-8.6155662d-05 /
      data fpp( 7,16,12,1),fpp( 7,16,12,2),fpp( 7,16,12,3)/
     x 2.1998353d-02, 1.2988568d-05,-8.5560267d-06 /
      data fpp( 7,16,13,1),fpp( 7,16,13,2),fpp( 7,16,13,3)/
     x 2.9383386d-02, 6.9178950d-06,-3.6942317d-06 /
      data fpp( 7,16,14,1),fpp( 7,16,14,2),fpp( 7,16,14,3)/
     x 3.0410813d-02, 4.5581087d-06, 1.9369534d-06 /
      data fpp( 7,16,15,1),fpp( 7,16,15,2),fpp( 7,16,15,3)/
     x 3.0765214d-02, 3.7804727d-06, 2.1564180d-06 /
      data fpp( 7,16,16,1),fpp( 7,16,16,2),fpp( 7,16,16,3)/
     x 3.1184674d-02, 4.0925558d-06, 1.7973746d-06 /
      data fpp( 7,16,17,1),fpp( 7,16,17,2),fpp( 7,16,17,3)/
     x 3.1690698d-02, 5.1582324d-06, 6.0808363d-07 /
      data fpp( 7,16,18,1),fpp( 7,16,18,2),fpp( 7,16,18,3)/
     x 3.2369610d-02, 6.6405757d-06,-7.0770913d-07 /
      data fpp( 7,16,19,1),fpp( 7,16,19,2),fpp( 7,16,19,3)/
     x 3.3034060d-02, 8.1802207d-06,-1.8512471d-06 /
      data fpp( 7,16,20,1),fpp( 7,16,20,2),fpp( 7,16,20,3)/
     x 3.3569566d-02, 9.3729086d-06,-2.7593024d-06 /
      data fpp( 7,16,21,1),fpp( 7,16,21,2),fpp( 7,16,21,3)/
     x 3.3569566d-02, 9.3729086d-06,-2.7934691d-06 /
      data fpp( 7,16,22,1),fpp( 7,16,22,2),fpp( 7,16,22,3)/
     x 3.3034060d-02, 8.1802207d-06,-1.7145802d-06 /
      data fpp( 7,16,23,1),fpp( 7,16,23,2),fpp( 7,16,23,3)/
     x 3.2369610d-02, 6.6405757d-06,-1.2202099d-06 /
      data fpp( 7,17, 1,1),fpp( 7,17, 1,2),fpp( 7,17, 1,3)/
     x-3.6511013d-03, 1.1075641d-04, 2.8501323d-05 /
      data fpp( 7,17, 2,1),fpp( 7,17, 2,2),fpp( 7,17, 2,3)/
     x 5.3625553d-03, 1.2004514d-04, 3.0330853d-05 /
      data fpp( 7,17, 3,1),fpp( 7,17, 3,2),fpp( 7,17, 3,3)/
     x 1.2230775d-02, 1.2948537d-04, 3.4369264d-05 /
      data fpp( 7,17, 4,1),fpp( 7,17, 4,2),fpp( 7,17, 4,3)/
     x 1.2230775d-02, 1.2948537d-04, 3.4162782d-05 /
      data fpp( 7,17, 5,1),fpp( 7,17, 5,2),fpp( 7,17, 5,3)/
     x 5.3625553d-03, 1.2004514d-04, 3.1156783d-05 /
      data fpp( 7,17, 6,1),fpp( 7,17, 6,2),fpp( 7,17, 6,3)/
     x-3.6511013d-03, 1.1075641d-04, 2.5404087d-05 /
      data fpp( 7,17, 7,1),fpp( 7,17, 7,2),fpp( 7,17, 7,3)/
     x-1.4086070d-02, 1.0534466d-04, 1.7322870d-05 /
      data fpp( 7,17, 8,1),fpp( 7,17, 8,2),fpp( 7,17, 8,3)/
     x-2.6484681d-02, 1.0284156d-04, 3.9624321d-06 /
      data fpp( 7,17, 9,1),fpp( 7,17, 9,2),fpp( 7,17, 9,3)/
     x-4.2981039d-02, 9.6698333d-05, 4.6694015d-06 /
      data fpp( 7,17,10,1),fpp( 7,17,10,2),fpp( 7,17,10,3)/
     x-1.0995883d-01, 7.3359219d-05,-5.9666038d-05 /
      data fpp( 7,17,11,1),fpp( 7,17,11,2),fpp( 7,17,11,3)/
     x 1.7883120d-02, 1.2629809d-05,-7.7927250d-05 /
      data fpp( 7,17,12,1),fpp( 7,17,12,2),fpp( 7,17,12,3)/
     x 4.1119890d-02, 1.3104424d-05, 5.5790368d-06 /
      data fpp( 7,17,13,1),fpp( 7,17,13,2),fpp( 7,17,13,3)/
     x 3.1486936d-02, 1.1817721d-05,-4.4128976d-06 /
      data fpp( 7,17,14,1),fpp( 7,17,14,2),fpp( 7,17,14,3)/
     x 3.0628165d-02, 1.1176894d-05, 1.6505536d-06 /
      data fpp( 7,17,15,1),fpp( 7,17,15,2),fpp( 7,17,15,3)/
     x 3.1178917d-02, 1.1527950d-05, 9.4268315d-07 /
      data fpp( 7,17,16,1),fpp( 7,17,16,2),fpp( 7,17,16,3)/
     x 3.1524083d-02, 1.2715658d-05, 1.0767138d-06 /
      data fpp( 7,17,17,1),fpp( 7,17,17,2),fpp( 7,17,17,3)/
     x 3.1703858d-02, 1.4464322d-05, 5.3446171d-07 /
      data fpp( 7,17,18,1),fpp( 7,17,18,2),fpp( 7,17,18,3)/
     x 3.1924249d-02, 1.6409883d-05, 2.5439384d-08 /
      data fpp( 7,17,19,1),fpp( 7,17,19,2),fpp( 7,17,19,3)/
     x 3.2089446d-02, 1.8128248d-05,-4.2021924d-07 /
      data fpp( 7,17,20,1),fpp( 7,17,20,2),fpp( 7,17,20,3)/
     x 3.2245863d-02, 1.9261563d-05,-8.0456241d-07 /
      data fpp( 7,17,21,1),fpp( 7,17,21,2),fpp( 7,17,21,3)/
     x 3.2245863d-02, 1.9261563d-05,-8.1720316d-07 /
      data fpp( 7,17,22,1),fpp( 7,17,22,2),fpp( 7,17,22,3)/
     x 3.2089446d-02, 1.8128248d-05,-3.6965624d-07 /
      data fpp( 7,17,23,1),fpp( 7,17,23,2),fpp( 7,17,23,3)/
     x 3.1924249d-02, 1.6409883d-05,-1.6417188d-07 /
      data fpp( 7,18, 1,1),fpp( 7,18, 1,2),fpp( 7,18, 1,3)/
     x-2.3682751d-02,-1.1813026d-04, 1.2230576d-05 /
      data fpp( 7,18, 2,1),fpp( 7,18, 2,2),fpp( 7,18, 2,3)/
     x-2.3594962d-02,-1.2700718d-04, 1.3075348d-05 /
      data fpp( 7,18, 3,1),fpp( 7,18, 3,2),fpp( 7,18, 3,3)/
     x-2.0457761d-02,-1.3089496d-04, 1.4938033d-05 /
      data fpp( 7,18, 4,1),fpp( 7,18, 4,2),fpp( 7,18, 4,3)/
     x-2.0457761d-02,-1.3089496d-04, 1.4846227d-05 /
      data fpp( 7,18, 5,1),fpp( 7,18, 5,2),fpp( 7,18, 5,3)/
     x-2.3594962d-02,-1.2700718d-04, 1.3442573d-05 /
      data fpp( 7,18, 6,1),fpp( 7,18, 6,2),fpp( 7,18, 6,3)/
     x-2.3682751d-02,-1.1813026d-04, 1.0853480d-05 /
      data fpp( 7,18, 7,1),fpp( 7,18, 7,2),fpp( 7,18, 7,3)/
     x-8.7812075d-03,-1.0526219d-04, 1.0223506d-05 /
      data fpp( 7,18, 8,1),fpp( 7,18, 8,2),fpp( 7,18, 8,3)/
     x-6.6083975d-02,-9.2468731d-05,-4.2950292d-07 /
      data fpp( 7,18, 9,1),fpp( 7,18, 9,2),fpp( 7,18, 9,3)/
     x 9.3158819d-02,-8.4265381d-05, 2.4776506d-05 /
      data fpp( 7,18,10,1),fpp( 7,18,10,2),fpp( 7,18,10,3)/
     x-6.7372000d-01,-8.5957062d-05,-8.3448521d-05 /
      data fpp( 7,18,11,1),fpp( 7,18,11,2),fpp( 7,18,11,3)/
     x 2.0513408d-01,-2.9413088d-05,-3.5284212d-06 /
      data fpp( 7,18,12,1),fpp( 7,18,12,2),fpp( 7,18,12,3)/
     x-3.0865055d-02,-9.3602640d-06, 1.2982062d-06 /
      data fpp( 7,18,13,1),fpp( 7,18,13,2),fpp( 7,18,13,3)/
     x 3.9295516d-02, 4.0522269d-07, 4.1759652d-07 /
      data fpp( 7,18,14,1),fpp( 7,18,14,2),fpp( 7,18,14,3)/
     x 8.7388328d-03, 7.1343161d-06, 8.4140773d-07 /
      data fpp( 7,18,15,1),fpp( 7,18,15,2),fpp( 7,18,15,3)/
     x-1.9604677d-02, 1.2801729d-05, 7.5877255d-07 /
      data fpp( 7,18,16,1),fpp( 7,18,16,2),fpp( 7,18,16,3)/
     x-4.4500484d-02, 1.7974812d-05, 7.0150206d-07 /
      data fpp( 7,18,17,1),fpp( 7,18,17,2),fpp( 7,18,17,3)/
     x-6.5621435d-02, 2.2688479d-05, 5.8721920d-07 /
      data fpp( 7,18,18,1),fpp( 7,18,18,2),fpp( 7,18,18,3)/
     x-8.2913824d-02, 2.6743890d-05, 4.5362116d-07 /
      data fpp( 7,18,19,1),fpp( 7,18,19,2),fpp( 7,18,19,3)/
     x-9.6249146d-02, 2.9898786d-05, 3.5229618d-07 /
      data fpp( 7,18,20,1),fpp( 7,18,20,2),fpp( 7,18,20,3)/
     x-1.0474575d-01, 3.1918839d-05, 2.6719412d-07 /
      data fpp( 7,18,21,1),fpp( 7,18,21,2),fpp( 7,18,21,3)/
     x-1.0474575d-01, 3.1918839d-05, 2.6426956d-07 /
      data fpp( 7,18,22,1),fpp( 7,18,22,2),fpp( 7,18,22,3)/
     x-9.6249146d-02, 2.9898786d-05, 3.6399441d-07 /
      data fpp( 7,18,23,1),fpp( 7,18,23,2),fpp( 7,18,23,3)/
     x-8.2913824d-02, 2.6743890d-05, 4.0975279d-07 /
      data fpp( 7,19, 1,1),fpp( 7,19, 1,2),fpp( 7,19, 1,3)/
     x 3.6502285d-02,-2.9141337d-04,-1.4652921d-21 /
      data fpp( 7,19, 2,1),fpp( 7,19, 2,2),fpp( 7,19, 2,3)/
     x 3.6502285d-02,-3.3052841d-04, 2.7576669d-21 /
      data fpp( 7,19, 3,1),fpp( 7,19, 3,2),fpp( 7,19, 3,3)/
     x 3.6502285d-02,-3.6449752d-04,-5.9067647d-20 /
      data fpp( 7,19, 4,1),fpp( 7,19, 4,2),fpp( 7,19, 4,3)/
     x 3.6502285d-02,-3.6449752d-04, 3.5656995d-20 /
      data fpp( 7,19, 5,1),fpp( 7,19, 5,2),fpp( 7,19, 5,3)/
     x 3.6502285d-02,-3.3052841d-04, 2.0690435d-20 /
      data fpp( 7,19, 6,1),fpp( 7,19, 6,2),fpp( 7,19, 6,3)/
     x 3.6502285d-02,-2.9141337d-04,-1.6562713d-20 /
      data fpp( 7,19, 7,1),fpp( 7,19, 7,2),fpp( 7,19, 7,3)/
     x 3.6502285d-02,-2.5620391d-04,-7.1283366d-20 /
      data fpp( 7,19, 8,1),fpp( 7,19, 8,2),fpp( 7,19, 8,3)/
     x 3.6502285d-02,-2.2758263d-04,-3.1295414d-20 /
      data fpp( 7,19, 9,1),fpp( 7,19, 9,2),fpp( 7,19, 9,3)/
     x 3.6502285d-02,-2.0568281d-04, 1.4844983d-20 /
      data fpp( 7,19,10,1),fpp( 7,19,10,2),fpp( 7,19,10,3)/
     x 3.6502285d-02,-1.9448897d-04, 4.5071640d-20 /
      data fpp( 7,19,11,1),fpp( 7,19,11,2),fpp( 7,19,11,3)/
     x 3.6502285d-02,-6.5677456d-05,-2.4468633d-20 /
      data fpp( 7,19,12,1),fpp( 7,19,12,2),fpp( 7,19,12,3)/
     x 3.6502285d-02,-2.5373368d-05, 3.2271965d-20 /
      data fpp( 7,19,13,1),fpp( 7,19,13,2),fpp( 7,19,13,3)/
     x 3.6502285d-02,-6.3466113d-06, 7.2057244d-20 /
      data fpp( 7,19,14,1),fpp( 7,19,14,2),fpp( 7,19,14,3)/
     x 3.6502285d-02, 6.1378420d-06,-1.0474366d-20 /
      data fpp( 7,19,15,1),fpp( 7,19,15,2),fpp( 7,19,15,3)/
     x 3.6502285d-02, 1.5925136d-05,-2.4011091d-20 /
      data fpp( 7,19,16,1),fpp( 7,19,16,2),fpp( 7,19,16,3)/
     x 3.6502285d-02, 2.4195094d-05, 8.2634566d-21 /
      data fpp( 7,19,17,1),fpp( 7,19,17,2),fpp( 7,19,17,3)/
     x 3.6502285d-02, 3.1221760d-05, 2.7134761d-20 /
      data fpp( 7,19,18,1),fpp( 7,19,18,2),fpp( 7,19,18,3)/
     x 3.6502285d-02, 3.6916555d-05,-6.7735670d-20 /
      data fpp( 7,19,19,1),fpp( 7,19,19,2),fpp( 7,19,19,3)/
     x 3.6502285d-02, 4.1148607d-05,-5.3190244d-20 /
      data fpp( 7,19,20,1),fpp( 7,19,20,2),fpp( 7,19,20,3)/
     x 3.6502285d-02, 4.3785080d-05, 3.4067953d-20 /
      data fpp( 7,19,21,1),fpp( 7,19,21,2),fpp( 7,19,21,3)/
     x 3.6502285d-02, 4.3785080d-05,-2.9320001d-20 /
      data fpp( 7,19,22,1),fpp( 7,19,22,2),fpp( 7,19,22,3)/
     x 3.6502285d-02, 4.1148607d-05, 6.0659032d-20 /
      data fpp( 7,19,23,1),fpp( 7,19,23,2),fpp( 7,19,23,3)/
     x 3.6502285d-02, 3.6916555d-05, 1.7706459d-19 /
      data fpp( 8, 1, 1,1),fpp( 8, 1, 1,2),fpp( 8, 1, 1,3)/
     x 6.4056626d-01, 9.6270675d-04,-1.2235832d-20 /
      data fpp( 8, 1, 2,1),fpp( 8, 1, 2,2),fpp( 8, 1, 2,3)/
     x 6.4056626d-01, 9.2367931d-04, 9.2301488d-20 /
      data fpp( 8, 1, 3,1),fpp( 8, 1, 3,2),fpp( 8, 1, 3,3)/
     x 6.4056626d-01, 2.1997021d-03,-4.4713385d-19 /
      data fpp( 8, 1, 4,1),fpp( 8, 1, 4,2),fpp( 8, 1, 4,3)/
     x 6.4056626d-01, 2.1997021d-03, 1.8522105d-19 /
      data fpp( 8, 1, 5,1),fpp( 8, 1, 5,2),fpp( 8, 1, 5,3)/
     x 6.4056626d-01, 9.2367931d-04, 1.6881659d-19 /
      data fpp( 8, 1, 6,1),fpp( 8, 1, 6,2),fpp( 8, 1, 6,3)/
     x 6.4056626d-01, 9.6270675d-04,-2.9560829d-19 /
      data fpp( 8, 1, 7,1),fpp( 8, 1, 7,2),fpp( 8, 1, 7,3)/
     x 6.4056626d-01,-1.7819143d-03,-1.0719089d-18 /
      data fpp( 8, 1, 8,1),fpp( 8, 1, 8,2),fpp( 8, 1, 8,3)/
     x 6.4056626d-01,-3.2953347d-03,-3.7418593d-19 /
      data fpp( 8, 1, 9,1),fpp( 8, 1, 9,2),fpp( 8, 1, 9,3)/
     x 6.4056626d-01,-3.6201536d-03,-8.1148158d-20 /
      data fpp( 8, 1,10,1),fpp( 8, 1,10,2),fpp( 8, 1,10,3)/
     x 6.4056626d-01,-3.8228723d-03, 6.5032231d-19 /
      data fpp( 8, 1,11,1),fpp( 8, 1,11,2),fpp( 8, 1,11,3)/
     x 6.4056626d-01,-3.8349472d-03,-4.7768142d-19 /
      data fpp( 8, 1,12,1),fpp( 8, 1,12,2),fpp( 8, 1,12,3)/
     x 6.4056626d-01,-3.8394439d-03, 6.4866915d-19 /
      data fpp( 8, 1,13,1),fpp( 8, 1,13,2),fpp( 8, 1,13,3)/
     x 6.4056626d-01,-3.9346563d-03, 1.3186080d-19 /
      data fpp( 8, 1,14,1),fpp( 8, 1,14,2),fpp( 8, 1,14,3)/
     x 6.4056626d-01,-3.8306918d-03,-5.5398867d-20 /
      data fpp( 8, 1,15,1),fpp( 8, 1,15,2),fpp( 8, 1,15,3)/
     x 6.4056626d-01,-3.6367606d-03, 1.8307366d-19 /
      data fpp( 8, 1,16,1),fpp( 8, 1,16,2),fpp( 8, 1,16,3)/
     x 6.4056626d-01,-3.2512055d-03,-5.7598331d-19 /
      data fpp( 8, 1,17,1),fpp( 8, 1,17,2),fpp( 8, 1,17,3)/
     x 6.4056626d-01,-1.7450578d-03, 6.0957439d-19 /
      data fpp( 8, 1,18,1),fpp( 8, 1,18,2),fpp( 8, 1,18,3)/
     x 6.4056626d-01, 9.4658610d-04,-6.4660798d-19 /
      data fpp( 8, 1,19,1),fpp( 8, 1,19,2),fpp( 8, 1,19,3)/
     x 6.4056626d-01, 9.1476303d-04,-4.6024252d-19 /
      data fpp( 8, 1,20,1),fpp( 8, 1,20,2),fpp( 8, 1,20,3)/
     x 6.4056626d-01, 2.1906710d-03, 2.5967740d-19 /
      data fpp( 8, 1,21,1),fpp( 8, 1,21,2),fpp( 8, 1,21,3)/
     x 6.4056626d-01, 2.1906710d-03,-3.1980703d-19 /
      data fpp( 8, 1,22,1),fpp( 8, 1,22,2),fpp( 8, 1,22,3)/
     x 6.4056626d-01, 9.1476303d-04, 8.2919319d-19 /
      data fpp( 8, 1,23,1),fpp( 8, 1,23,2),fpp( 8, 1,23,3)/
     x 6.4056626d-01, 9.4658610d-04, 1.5873438d-18 /
      data fpp( 8, 2, 1,1),fpp( 8, 2, 1,2),fpp( 8, 2, 1,3)/
     x-6.7346596d-01, 2.4837349d-04,-4.6293012d-07 /
      data fpp( 8, 2, 2,1),fpp( 8, 2, 2,2),fpp( 8, 2, 2,3)/
     x 1.5791952d+00, 1.3968237d-04,-3.8996398d-06 /
      data fpp( 8, 2, 3,1),fpp( 8, 2, 3,2),fpp( 8, 2, 3,3)/
     x 8.3846331d-01, 6.9978376d-04,-1.0716511d-05 /
      data fpp( 8, 2, 4,1),fpp( 8, 2, 4,2),fpp( 8, 2, 4,3)/
     x 8.3846331d-01, 6.9978376d-04,-1.1674648d-05 /
      data fpp( 8, 2, 5,1),fpp( 8, 2, 5,2),fpp( 8, 2, 5,3)/
     x 1.5791952d+00, 1.3968237d-04,-6.7092731d-08 /
      data fpp( 8, 2, 6,1),fpp( 8, 2, 6,2),fpp( 8, 2, 6,3)/
     x-6.7346596d-01, 2.4837349d-04,-1.4834981d-05 /
      data fpp( 8, 2, 7,1),fpp( 8, 2, 7,2),fpp( 8, 2, 7,3)/
     x-4.3979796d+00,-8.5235733d-04, 5.9659019d-05 /
      data fpp( 8, 2, 8,1),fpp( 8, 2, 8,2),fpp( 8, 2, 8,3)/
     x-7.5984569d+00,-1.4875837d-03,-2.0770309d-04 /
      data fpp( 8, 2, 9,1),fpp( 8, 2, 9,2),fpp( 8, 2, 9,3)/
     x-5.2733282d+00,-1.5929967d-03, 1.4091935d-04 /
      data fpp( 8, 2,10,1),fpp( 8, 2,10,2),fpp( 8, 2,10,3)/
     x-4.4604461d+00,-1.6638865d-03,-3.3732322d-05 /
      data fpp( 8, 2,11,1),fpp( 8, 2,11,2),fpp( 8, 2,11,3)/
     x-3.2360355d+00,-1.6555246d-03, 6.0915932d-05 /
      data fpp( 8, 2,12,1),fpp( 8, 2,12,2),fpp( 8, 2,12,3)/
     x-2.1656496d+00,-1.6539823d-03, 2.8094592d-05 /
      data fpp( 8, 2,13,1),fpp( 8, 2,13,2),fpp( 8, 2,13,3)/
     x-2.6016102d+00,-1.7009493d-03, 5.7093700d-05 /
      data fpp( 8, 2,14,1),fpp( 8, 2,14,2),fpp( 8, 2,14,3)/
     x-4.5278645d+00,-1.6720303d-03,-2.2469392d-05 /
      data fpp( 8, 2,15,1),fpp( 8, 2,15,2),fpp( 8, 2,15,3)/
     x-5.4876222d+00,-1.6074959d-03, 1.1129387d-04 /
      data fpp( 8, 2,16,1),fpp( 8, 2,16,2),fpp( 8, 2,16,3)/
     x-7.3263666d+00,-1.4739931d-03,-1.8415208d-04 /
      data fpp( 8, 2,17,1),fpp( 8, 2,17,2),fpp( 8, 2,17,3)/
     x-4.0345287d+00,-8.4535436d-04, 5.3262444d-05 /
      data fpp( 8, 2,18,1),fpp( 8, 2,18,2),fpp( 8, 2,18,3)/
     x-2.4265906d-01, 2.4415679d-04,-1.3237699d-05 /
      data fpp( 8, 2,19,1),fpp( 8, 2,19,2),fpp( 8, 2,19,3)/
     x 1.4517287d+00, 1.4350695d-04,-5.0364695d-07 /
      data fpp( 8, 2,20,1),fpp( 8, 2,20,2),fpp( 8, 2,20,3)/
     x 7.0432469d-01, 7.0558903d-04,-1.1753713d-05 /
      data fpp( 8, 2,21,1),fpp( 8, 2,21,2),fpp( 8, 2,21,3)/
     x 7.0432469d-01, 7.0558903d-04,-1.0900038d-05 /
      data fpp( 8, 2,22,1),fpp( 8, 2,22,2),fpp( 8, 2,22,3)/
     x 1.4517287d+00, 1.4350695d-04,-3.9183463d-06 /
      data fpp( 8, 2,23,1),fpp( 8, 2,23,2),fpp( 8, 2,23,3)/
     x-2.4265906d-01, 2.4415679d-04,-4.3257686d-07 /
      data fpp( 8, 3, 1,1),fpp( 8, 3, 1,2),fpp( 8, 3, 1,3)/
     x 5.9465412d-01,-1.5971427d-03, 6.4905148d-04 /
      data fpp( 8, 3, 2,1),fpp( 8, 3, 2,2),fpp( 8, 3, 2,3)/
     x-1.7817916d-01, 7.7477195d-05, 2.9968553d-04 /
      data fpp( 8, 3, 3,1),fpp( 8, 3, 3,2),fpp( 8, 3, 3,3)/
     x-7.4683569d-01,-7.0288517d-04,-3.6611161d-04 /
      data fpp( 8, 3, 4,1),fpp( 8, 3, 4,2),fpp( 8, 3, 4,3)/
     x-7.4683569d-01,-7.0288517d-04,-5.1108894d-04 /
      data fpp( 8, 3, 5,1),fpp( 8, 3, 5,2),fpp( 8, 3, 5,3)/
     x-1.7817916d-01, 7.7477195d-05, 8.7959486d-04 /
      data fpp( 8, 3, 6,1),fpp( 8, 3, 6,2),fpp( 8, 3, 6,3)/
     x 5.9465412d-01,-1.5971427d-03,-1.5256085d-03 /
      data fpp( 8, 3, 7,1),fpp( 8, 3, 7,2),fpp( 8, 3, 7,3)/
     x 2.3887743d-01, 1.4126366d-04, 1.0150331d-03 /
      data fpp( 8, 3, 8,1),fpp( 8, 3, 8,2),fpp( 8, 3, 8,3)/
     x 4.5149096d-01, 1.3129674d-03, 2.4188151d-05 /
      data fpp( 8, 3, 9,1),fpp( 8, 3, 9,2),fpp( 8, 3, 9,3)/
     x 5.4059647d-01, 1.7106405d-03, 1.6157031d-04 /
      data fpp( 8, 3,10,1),fpp( 8, 3,10,2),fpp( 8, 3,10,3)/
     x 5.1474626d-01, 1.9327562d-03, 5.8650597d-05 /
      data fpp( 8, 3,11,1),fpp( 8, 3,11,2),fpp( 8, 3,11,3)/
     x 5.5774577d-01, 1.9990315d-03, 8.9449298d-05 /
      data fpp( 8, 3,12,1),fpp( 8, 3,12,2),fpp( 8, 3,12,3)/
     x 5.4182342d-01, 2.0171529d-03,-8.2497897d-06 /
      data fpp( 8, 3,13,1),fpp( 8, 3,13,2),fpp( 8, 3,13,3)/
     x 1.6587287d+00, 2.0975297d-03, 1.8182786d-04 /
      data fpp( 8, 3,14,1),fpp( 8, 3,14,2),fpp( 8, 3,14,3)/
     x 5.1385087d-01, 1.9217971d-03,-4.4496534d-06 /
      data fpp( 8, 3,15,1),fpp( 8, 3,15,2),fpp( 8, 3,15,3)/
     x 5.5098734d-01, 1.6985020d-03, 1.7785675d-04 /
      data fpp( 8, 3,16,1),fpp( 8, 3,16,2),fpp( 8, 3,16,3)/
     x 4.4206494d-01, 1.2692018d-03, 3.1622642d-05 /
      data fpp( 8, 3,17,1),fpp( 8, 3,17,2),fpp( 8, 3,17,3)/
     x 9.5660390d-01, 1.5992726d-04, 9.7271068d-04 /
      data fpp( 8, 3,18,1),fpp( 8, 3,18,2),fpp( 8, 3,18,3)/
     x 7.1105969d-01,-1.5761553d-03,-1.4889674d-03 /
      data fpp( 8, 3,19,1),fpp( 8, 3,19,2),fpp( 8, 3,19,3)/
     x-1.7899461d-01, 5.8639189d-05, 8.6954078d-04 /
      data fpp( 8, 3,20,1),fpp( 8, 3,20,2),fpp( 8, 3,20,3)/
     x-7.4626296d-01,-7.3132511d-04,-5.0930775d-04 /
      data fpp( 8, 3,21,1),fpp( 8, 3,21,2),fpp( 8, 3,21,3)/
     x-7.4626296d-01,-7.3132511d-04,-3.6680914d-04 /
      data fpp( 8, 3,22,1),fpp( 8, 3,22,2),fpp( 8, 3,22,3)/
     x-1.7899461d-01, 5.8639189d-05, 2.9954632d-04 /
      data fpp( 8, 3,23,1),fpp( 8, 3,23,2),fpp( 8, 3,23,3)/
     x 7.1105969d-01,-1.5761553d-03, 6.4851184d-04 /
      data fpp( 8, 4, 1,1),fpp( 8, 4, 1,2),fpp( 8, 4, 1,3)/
     x-1.9302385d-01, 5.1648140d-04,-6.1828197d-04 /
      data fpp( 8, 4, 2,1),fpp( 8, 4, 2,2),fpp( 8, 4, 2,3)/
     x-1.2498522d-01,-2.5109992d-03,-5.2301756d-04 /
      data fpp( 8, 4, 3,1),fpp( 8, 4, 3,2),fpp( 8, 4, 3,3)/
     x-7.0601274d-01,-2.4459271d-03,-3.5808979d-04 /
      data fpp( 8, 4, 4,1),fpp( 8, 4, 4,2),fpp( 8, 4, 4,3)/
     x-7.0601274d-01,-2.4459271d-03,-2.8947186d-04 /
      data fpp( 8, 4, 5,1),fpp( 8, 4, 5,2),fpp( 8, 4, 5,3)/
     x-1.2498522d-01,-2.5109992d-03,-7.9748925d-04 /
      data fpp( 8, 4, 6,1),fpp( 8, 4, 6,2),fpp( 8, 4, 6,3)/
     x-1.9302385d-01, 5.1648140d-04, 4.1098688d-04 /
      data fpp( 8, 4, 7,1),fpp( 8, 4, 7,2),fpp( 8, 4, 7,3)/
     x 3.0926722d-03, 9.1066071d-04, 5.4705973d-04 /
      data fpp( 8, 4, 8,1),fpp( 8, 4, 8,2),fpp( 8, 4, 8,3)/
     x 1.2462778d-01, 6.3871813d-04, 3.4672191d-05 /
      data fpp( 8, 4, 9,1),fpp( 8, 4, 9,2),fpp( 8, 4, 9,3)/
     x 1.5352657d-01, 5.4659679d-04, 1.0470950d-04 /
      data fpp( 8, 4,10,1),fpp( 8, 4,10,2),fpp( 8, 4,10,3)/
     x 9.7794673d-01, 4.9759982d-04, 5.7905797d-05 /
      data fpp( 8, 4,11,1),fpp( 8, 4,11,2),fpp( 8, 4,11,3)/
     x 1.1155554d-01, 4.9062046d-04, 6.5913310d-05 /
      data fpp( 8, 4,12,1),fpp( 8, 4,12,2),fpp( 8, 4,12,3)/
     x 1.5494338d-01, 4.8843073d-04, 6.2164965d-05 /
      data fpp( 8, 4,13,1),fpp( 8, 4,13,2),fpp( 8, 4,13,3)/
     x 1.1799196d-01, 4.1930671d-04, 6.5172830d-05 /
      data fpp( 8, 4,14,1),fpp( 8, 4,14,2),fpp( 8, 4,14,3)/
     x 6.4627381d-01, 4.9254396d-04, 6.6177713d-05 /
      data fpp( 8, 4,15,1),fpp( 8, 4,15,2),fpp( 8, 4,15,3)/
     x 1.5481279d-01, 5.3593374d-04, 9.0896317d-05 /
      data fpp( 8, 4,16,1),fpp( 8, 4,16,2),fpp( 8, 4,16,3)/
     x 1.3050853d-01, 6.3145785d-04, 1.0596502d-04 /
      data fpp( 8, 4,17,1),fpp( 8, 4,17,2),fpp( 8, 4,17,3)/
     x 8.7583881d-02, 7.9568533d-04, 4.5535361d-04 /
      data fpp( 8, 4,18,1),fpp( 8, 4,18,2),fpp( 8, 4,18,3)/
     x-1.9744373d-01, 5.1612233d-04, 4.3380654d-04 /
      data fpp( 8, 4,19,1),fpp( 8, 4,19,2),fpp( 8, 4,19,3)/
     x-2.2234576d-01,-2.4285877d-03,-7.8942379d-04 /
      data fpp( 8, 4,20,1),fpp( 8, 4,20,2),fpp( 8, 4,20,3)/
     x-7.0549146d-01,-2.3368266d-03,-2.8916140d-04 /
      data fpp( 8, 4,21,1),fpp( 8, 4,21,2),fpp( 8, 4,21,3)/
     x-7.0549146d-01,-2.3368266d-03,-3.5830790d-04 /
      data fpp( 8, 4,22,1),fpp( 8, 4,22,2),fpp( 8, 4,22,3)/
     x-2.2234576d-01,-2.4285877d-03,-5.1283782d-04 /
      data fpp( 8, 4,23,1),fpp( 8, 4,23,2),fpp( 8, 4,23,3)/
     x-1.9744373d-01, 5.1612233d-04,-6.0339084d-04 /
      data fpp( 8, 5, 1,1),fpp( 8, 5, 1,2),fpp( 8, 5, 1,3)/
     x 3.4554467d-01, 1.1014111d-03, 2.9277606d-04 /
      data fpp( 8, 5, 2,1),fpp( 8, 5, 2,2),fpp( 8, 5, 2,3)/
     x-6.6257394d-02, 2.6785234d-03, 8.9342888d-05 /
      data fpp( 8, 5, 3,1),fpp( 8, 5, 3,2),fpp( 8, 5, 3,3)/
     x-1.8151671d-01, 2.2693656d-03,-3.3975561d-04 /
      data fpp( 8, 5, 4,1),fpp( 8, 5, 4,2),fpp( 8, 5, 4,3)/
     x-1.8151671d-01, 2.2693656d-03,-3.5170762d-04 /
      data fpp( 8, 5, 5,1),fpp( 8, 5, 5,2),fpp( 8, 5, 5,3)/
     x-6.6257394d-02, 2.6785234d-03, 1.3715094d-04 /
      data fpp( 8, 5, 6,1),fpp( 8, 5, 6,2),fpp( 8, 5, 6,3)/
     x 3.4554467d-01, 1.1014111d-03, 1.1349588d-04 /
      data fpp( 8, 5, 7,1),fpp( 8, 5, 7,2),fpp( 8, 5, 7,3)/
     x 1.5443122d-02, 2.6228951d-04, 2.1519561d-05 /
      data fpp( 8, 5, 8,1),fpp( 8, 5, 8,2),fpp( 8, 5, 8,3)/
     x 2.2905061d-02, 2.0328609d-04, 5.8437882d-05 /
      data fpp( 8, 5, 9,1),fpp( 8, 5, 9,2),fpp( 8, 5, 9,3)/
     x 2.7506500d-02, 1.9642435d-04, 4.9684912d-05 /
      data fpp( 8, 5,10,1),fpp( 8, 5,10,2),fpp( 8, 5,10,3)/
     x 3.0781435d-02, 2.1061055d-04, 5.4522469d-05 /
      data fpp( 8, 5,11,1),fpp( 8, 5,11,2),fpp( 8, 5,11,3)/
     x 3.2946052d-02, 2.1566261d-04, 5.4191210d-05 /
      data fpp( 8, 5,12,1),fpp( 8, 5,12,2),fpp( 8, 5,12,3)/
     x 3.3744171d-02, 2.1663221d-04, 5.4884690d-05 /
      data fpp( 8, 5,13,1),fpp( 8, 5,13,2),fpp( 8, 5,13,3)/
     x 3.3523418d-02, 2.3148551d-04, 5.5886031d-05 /
      data fpp( 8, 5,14,1),fpp( 8, 5,14,2),fpp( 8, 5,14,3)/
     x 3.1673154d-02, 2.0499508d-04, 5.7019186d-05 /
      data fpp( 8, 5,15,1),fpp( 8, 5,15,2),fpp( 8, 5,15,3)/
     x 2.8716383d-02, 1.8916903d-04, 5.9423224d-05 /
      data fpp( 8, 5,16,1),fpp( 8, 5,16,2),fpp( 8, 5,16,3)/
     x-9.8315737d-02, 1.8949480d-04, 5.6827919d-05 /
      data fpp( 8, 5,17,1),fpp( 8, 5,17,2),fpp( 8, 5,17,3)/
     x 1.5776982d-02, 3.0372343d-04, 8.5169102d-05 /
      data fpp( 8, 5,18,1),fpp( 8, 5,18,2),fpp( 8, 5,18,3)/
     x-2.2018585d-03, 9.8425795d-04, 5.5705674d-05 /
      data fpp( 8, 5,19,1),fpp( 8, 5,19,2),fpp( 8, 5,19,3)/
     x-6.5570051d-02, 2.5289956d-03, 1.8243020d-04 /
      data fpp( 8, 5,20,1),fpp( 8, 5,20,2),fpp( 8, 5,20,3)/
     x-1.8361614d-01, 2.2580395d-03,-3.8598248d-04 /
      data fpp( 8, 5,21,1),fpp( 8, 5,21,2),fpp( 8, 5,21,3)/
     x-1.8361614d-01, 2.2580395d-03,-3.6737566d-04 /
      data fpp( 8, 5,22,1),fpp( 8, 5,22,2),fpp( 8, 5,22,3)/
     x-6.5570051d-02, 2.5289956d-03, 1.0800290d-04 /
      data fpp( 8, 5,23,1),fpp( 8, 5,23,2),fpp( 8, 5,23,3)/
     x-2.2018585d-03, 9.8425795d-04, 3.3480805d-04 /
      data fpp( 8, 6, 1,1),fpp( 8, 6, 1,2),fpp( 8, 6, 1,3)/
     x-2.1394573d-02,-2.8642395d-04,-2.0145738d-05 /
      data fpp( 8, 6, 2,1),fpp( 8, 6, 2,2),fpp( 8, 6, 2,3)/
     x-2.3117501d-01,-6.1862052d-04,-5.0282524d-05 /
      data fpp( 8, 6, 3,1),fpp( 8, 6, 3,2),fpp( 8, 6, 3,3)/
     x-1.3777927d-01,-1.2527918d-04,-1.1648817d-04 /
      data fpp( 8, 6, 4,1),fpp( 8, 6, 4,2),fpp( 8, 6, 4,3)/
     x-1.3777927d-01,-1.2527918d-04,-1.1364124d-04 /
      data fpp( 8, 6, 5,1),fpp( 8, 6, 5,2),fpp( 8, 6, 5,3)/
     x-2.3117501d-01,-6.1862052d-04,-6.1670217d-05 /
      data fpp( 8, 6, 6,1),fpp( 8, 6, 6,2),fpp( 8, 6, 6,3)/
     x-2.1394573d-02,-2.8642395d-04, 2.2558110d-05 /
      data fpp( 8, 6, 7,1),fpp( 8, 6, 7,2),fpp( 8, 6, 7,3)/
     x-9.2361644d-03,-5.6720745d-05, 1.9395778d-05 /
      data fpp( 8, 6, 8,1),fpp( 8, 6, 8,2),fpp( 8, 6, 8,3)/
     x-2.4650693d-03,-2.9622508d-05, 3.3730778d-05 /
      data fpp( 8, 6, 9,1),fpp( 8, 6, 9,2),fpp( 8, 6, 9,3)/
     x 1.5970484d-03,-1.8006210d-05, 3.8041109d-05 /
      data fpp( 8, 6,10,1),fpp( 8, 6,10,2),fpp( 8, 6,10,3)/
     x 3.6491264d-03,-1.8500021d-05, 4.1294788d-05 /
      data fpp( 8, 6,11,1),fpp( 8, 6,11,2),fpp( 8, 6,11,3)/
     x 4.9281044d-03,-2.0022918d-05, 4.2917741d-05 /
      data fpp( 8, 6,12,1),fpp( 8, 6,12,2),fpp( 8, 6,12,3)/
     x 6.4871141d-03,-2.1591564d-05, 4.4068248d-05 /
      data fpp( 8, 6,13,1),fpp( 8, 6,13,2),fpp( 8, 6,13,3)/
     x 6.5422463d-03,-2.7114764d-05, 4.4941268d-05 /
      data fpp( 8, 6,14,1),fpp( 8, 6,14,2),fpp( 8, 6,14,3)/
     x 8.2732507d-03,-2.1996274d-05, 4.5656680d-05 /
      data fpp( 8, 6,15,1),fpp( 8, 6,15,2),fpp( 8, 6,15,3)/
     x 4.4996705d-03,-2.1455843d-05, 4.6656012d-05 /
      data fpp( 8, 6,16,1),fpp( 8, 6,16,2),fpp( 8, 6,16,3)/
     x 4.9566346d-03,-2.8517045d-05, 4.4211271d-05 /
      data fpp( 8, 6,17,1),fpp( 8, 6,17,2),fpp( 8, 6,17,3)/
     x-2.1649755d-03,-6.4953060d-05, 4.5136903d-05 /
      data fpp( 8, 6,18,1),fpp( 8, 6,18,2),fpp( 8, 6,18,3)/
     x-1.0199409d-02,-2.2681414d-04, 1.6483118d-05 /
      data fpp( 8, 6,19,1),fpp( 8, 6,19,2),fpp( 8, 6,19,3)/
     x-2.7282497d-02,-5.7720279d-04, 7.1756625d-05 /
      data fpp( 8, 6,20,1),fpp( 8, 6,20,2),fpp( 8, 6,20,3)/
     x-7.3941148d-02,-4.2756939d-04,-2.1785362d-04 /
      data fpp( 8, 6,21,1),fpp( 8, 6,21,2),fpp( 8, 6,21,3)/
     x-7.3941148d-02,-4.2756939d-04,-2.0881446d-04 /
      data fpp( 8, 6,22,1),fpp( 8, 6,22,2),fpp( 8, 6,22,3)/
     x-2.7282497d-02,-5.7720279d-04, 3.5599988d-05 /
      data fpp( 8, 6,23,1),fpp( 8, 6,23,2),fpp( 8, 6,23,3)/
     x-1.0199409d-02,-2.2681414d-04, 1.5207051d-04 /
      data fpp( 8, 7, 1,1),fpp( 8, 7, 1,2),fpp( 8, 7, 1,3)/
     x-9.3865848d-03, 9.2626718d-06, 2.5007821d-05 /
      data fpp( 8, 7, 2,1),fpp( 8, 7, 2,2),fpp( 8, 7, 2,3)/
     x-1.8258834d-02, 2.2159865d-04,-8.9071430d-06 /
      data fpp( 8, 7, 3,1),fpp( 8, 7, 3,2),fpp( 8, 7, 3,3)/
     x-1.1166944d-02, 1.3007131d-05,-8.0345250d-05 /
      data fpp( 8, 7, 4,1),fpp( 8, 7, 4,2),fpp( 8, 7, 4,3)/
     x-1.1166944d-02, 1.3007131d-05,-8.2509680d-05 /
      data fpp( 8, 7, 5,1),fpp( 8, 7, 5,2),fpp( 8, 7, 5,3)/
     x-1.8258834d-02, 2.2159865d-04,-2.4942274d-07 /
      data fpp( 8, 7, 6,1),fpp( 8, 7, 6,2),fpp( 8, 7, 6,3)/
     x-9.3865848d-03, 9.2626718d-06,-7.4586294d-06 /
      data fpp( 8, 7, 7,1),fpp( 8, 7, 7,2),fpp( 8, 7, 7,3)/
     x-6.0051923d-03,-4.0440529d-05, 3.9959402d-06 /
      data fpp( 8, 7, 8,1),fpp( 8, 7, 8,2),fpp( 8, 7, 8,3)/
     x-4.5377455d-03,-4.9426062d-05, 1.1622869d-05 /
      data fpp( 8, 7, 9,1),fpp( 8, 7, 9,2),fpp( 8, 7, 9,3)/
     x-4.1277138d-03,-5.7601514d-05, 2.0300586d-05 /
      data fpp( 8, 7,10,1),fpp( 8, 7,10,2),fpp( 8, 7,10,3)/
     x-3.9785604d-03,-6.1412466d-05, 2.6826788d-05 /
      data fpp( 8, 7,11,1),fpp( 8, 7,11,2),fpp( 8, 7,11,3)/
     x-3.7177658d-03,-6.3468941d-05, 3.1206260d-05 /
      data fpp( 8, 7,12,1),fpp( 8, 7,12,2),fpp( 8, 7,12,3)/
     x-3.3038034d-03,-6.3989952d-05, 3.3514170d-05 /
      data fpp( 8, 7,13,1),fpp( 8, 7,13,2),fpp( 8, 7,13,3)/
     x-2.7525297d-03,-6.1754459d-05, 3.4207059d-05 /
      data fpp( 8, 7,14,1),fpp( 8, 7,14,2),fpp( 8, 7,14,3)/
     x-2.3483788d-03,-6.0171982d-05, 3.3759593d-05 /
      data fpp( 8, 7,15,1),fpp( 8, 7,15,2),fpp( 8, 7,15,3)/
     x-1.4398657d-03,-5.4259657d-05, 3.2498570d-05 /
      data fpp( 8, 7,16,1),fpp( 8, 7,16,2),fpp( 8, 7,16,3)/
     x-8.4923581d-04,-4.2282619d-05, 2.9500126d-05 /
      data fpp( 8, 7,17,1),fpp( 8, 7,17,2),fpp( 8, 7,17,3)/
     x 1.5526940d-05,-1.7337194d-05, 2.4244924d-05 /
      data fpp( 8, 7,18,1),fpp( 8, 7,18,2),fpp( 8, 7,18,3)/
     x 1.6537035d-03, 4.9442613d-05, 9.2341769d-06 /
      data fpp( 8, 7,19,1),fpp( 8, 7,19,2),fpp( 8, 7,19,3)/
     x 5.4705953d-03, 1.8559554d-04,-6.4856318d-06 /
      data fpp( 8, 7,20,1),fpp( 8, 7,20,2),fpp( 8, 7,20,3)/
     x 1.6378802d-02, 2.4602005d-04,-1.0275765d-04 /
      data fpp( 8, 7,21,1),fpp( 8, 7,21,2),fpp( 8, 7,21,3)/
     x 1.6378802d-02, 2.4602005d-04,-1.0137124d-04 /
      data fpp( 8, 7,22,1),fpp( 8, 7,22,2),fpp( 8, 7,22,3)/
     x 5.4705953d-03, 1.8559554d-04,-1.2031290d-05 /
      data fpp( 8, 7,23,1),fpp( 8, 7,23,2),fpp( 8, 7,23,3)/
     x 1.6537035d-03, 4.9442613d-05, 3.0030395d-05 /
      data fpp( 8, 8, 1,1),fpp( 8, 8, 1,2),fpp( 8, 8, 1,3)/
     x 1.1838562d-02, 1.2500527d-04,-9.7552452d-05 /
      data fpp( 8, 8, 2,1),fpp( 8, 8, 2,2),fpp( 8, 8, 2,3)/
     x 6.8450769d-02,-2.5828809d-04,-6.2329596d-05 /
      data fpp( 8, 8, 3,1),fpp( 8, 8, 3,2),fpp( 8, 8, 3,3)/
     x-2.2155828d-01,-2.7708335d-04, 9.0288370d-06 /
      data fpp( 8, 8, 4,1),fpp( 8, 8, 4,2),fpp( 8, 8, 4,3)/
     x-2.2155828d-01,-2.7708335d-04, 1.6237287d-05 /
      data fpp( 8, 8, 5,1),fpp( 8, 8, 5,2),fpp( 8, 8, 5,3)/
     x 6.8450769d-02,-2.5828809d-04,-9.1163397d-05 /
      data fpp( 8, 8, 6,1),fpp( 8, 8, 6,2),fpp( 8, 8, 6,3)/
     x 1.1838562d-02, 1.2500527d-04, 1.0574300d-05 /
      data fpp( 8, 8, 7,1),fpp( 8, 8, 7,2),fpp( 8, 8, 7,3)/
     x 4.5025002d-03,-3.8111385d-06,-1.5339801d-05 /
      data fpp( 8, 8, 8,1),fpp( 8, 8, 8,2),fpp( 8, 8, 8,3)/
     x 1.9447845d-03,-5.3935243d-05,-3.8330939d-06 /
      data fpp( 8, 8, 9,1),fpp( 8, 8, 9,2),fpp( 8, 8, 9,3)/
     x-1.3393881d-03,-6.7943732d-05, 3.7621771d-06 /
      data fpp( 8, 8,10,1),fpp( 8, 8,10,2),fpp( 8, 8,10,3)/
     x-4.0239127d-03,-7.3938114d-05, 1.4260386d-05 /
      data fpp( 8, 8,11,1),fpp( 8, 8,11,2),fpp( 8, 8,11,3)/
     x-5.6020659d-03,-7.5715317d-05, 2.0892280d-05 /
      data fpp( 8, 8,12,1),fpp( 8, 8,12,2),fpp( 8, 8,12,3)/
     x-5.7059585d-03,-7.4582627d-05, 2.4474493d-05 /
      data fpp( 8, 8,13,1),fpp( 8, 8,13,2),fpp( 8, 8,13,3)/
     x-5.0917019d-03,-7.1209401d-05, 2.5329746d-05 /
      data fpp( 8, 8,14,1),fpp( 8, 8,14,2),fpp( 8, 8,14,3)/
     x-4.1353913d-03,-6.4381796d-05, 2.4404523d-05 /
      data fpp( 8, 8,15,1),fpp( 8, 8,15,2),fpp( 8, 8,15,3)/
     x-2.2687610d-03,-5.4503531d-05, 2.2108163d-05 /
      data fpp( 8, 8,16,1),fpp( 8, 8,16,2),fpp( 8, 8,16,3)/
     x-1.8042731d-04,-4.0078480d-05, 1.8382824d-05 /
      data fpp( 8, 8,17,1),fpp( 8, 8,17,2),fpp( 8, 8,17,3)/
     x 3.0982101d-03,-2.0576163d-05, 1.2786540d-05 /
      data fpp( 8, 8,18,1),fpp( 8, 8,18,2),fpp( 8, 8,18,3)/
     x 7.3334537d-03,-1.4003089d-06, 2.2430151d-06 /
      data fpp( 8, 8,19,1),fpp( 8, 8,19,2),fpp( 8, 8,19,3)/
     x 1.3897182d-02, 1.1358649d-05,-1.2644600d-05 /
      data fpp( 8, 8,20,1),fpp( 8, 8,20,2),fpp( 8, 8,20,3)/
     x 2.3412552d-02, 5.1097190d-05,-5.2164613d-05 /
      data fpp( 8, 8,21,1),fpp( 8, 8,21,2),fpp( 8, 8,21,3)/
     x 2.3412552d-02, 5.1097190d-05,-5.1995860d-05 /
      data fpp( 8, 8,22,1),fpp( 8, 8,22,2),fpp( 8, 8,22,3)/
     x 1.3897182d-02, 1.1358649d-05,-1.3319611d-05 /
      data fpp( 8, 8,23,1),fpp( 8, 8,23,2),fpp( 8, 8,23,3)/
     x 7.3334537d-03,-1.4003089d-06, 4.7743057d-06 /
      data fpp( 8, 9, 1,1),fpp( 8, 9, 1,2),fpp( 8, 9, 1,3)/
     x-8.0765876d-01,-5.5722973d-04, 5.6957740d-06 /
      data fpp( 8, 9, 2,1),fpp( 8, 9, 2,2),fpp( 8, 9, 2,3)/
     x-3.5602996d-02,-1.7385630d-04, 3.2642452d-05 /
      data fpp( 8, 9, 3,1),fpp( 8, 9, 3,2),fpp( 8, 9, 3,3)/
     x-2.1402720d-02,-2.5417334d-06, 1.0402242d-04 /
      data fpp( 8, 9, 4,1),fpp( 8, 9, 4,2),fpp( 8, 9, 4,3)/
     x-2.1402720d-02,-2.5417334d-06, 8.0157519d-05 /
      data fpp( 8, 9, 5,1),fpp( 8, 9, 5,2),fpp( 8, 9, 5,3)/
     x-3.5602996d-02,-1.7385630d-04, 1.2810205d-04 /
      data fpp( 8, 9, 6,1),fpp( 8, 9, 6,2),fpp( 8, 9, 6,3)/
     x-8.0765876d-01,-5.5722973d-04,-3.5227771d-04 /
      data fpp( 8, 9, 7,1),fpp( 8, 9, 7,2),fpp( 8, 9, 7,3)/
     x 1.2434678d-02,-1.5748892d-04, 7.5992780d-05 /
      data fpp( 8, 9, 8,1),fpp( 8, 9, 8,2),fpp( 8, 9, 8,3)/
     x 1.8932238d-02,-6.8210966d-05,-3.6053414d-05 /
      data fpp( 8, 9, 9,1),fpp( 8, 9, 9,2),fpp( 8, 9, 9,3)/
     x 1.0015630d-02,-6.7691557d-05, 1.2687501d-07 /
      data fpp( 8, 9,10,1),fpp( 8, 9,10,2),fpp( 8, 9,10,3)/
     x 3.2119379d-03,-6.7653078d-05, 2.7859137d-06 /
      data fpp( 8, 9,11,1),fpp( 8, 9,11,2),fpp( 8, 9,11,3)/
     x-4.8309062d-04,-6.6035791d-05, 1.3509470d-05 /
      data fpp( 8, 9,12,1),fpp( 8, 9,12,2),fpp( 8, 9,12,3)/
     x-2.4224650d-03,-6.2707539d-05, 1.7504206d-05 /
      data fpp( 8, 9,13,1),fpp( 8, 9,13,2),fpp( 8, 9,13,3)/
     x-2.6891412d-03,-5.7381936d-05, 1.8959706d-05 /
      data fpp( 8, 9,14,1),fpp( 8, 9,14,2),fpp( 8, 9,14,3)/
     x-2.2183485d-03,-5.0070833d-05, 1.8100971d-05 /
      data fpp( 8, 9,15,1),fpp( 8, 9,15,2),fpp( 8, 9,15,3)/
     x-4.5387258d-04,-4.0080221d-05, 1.6216411d-05 /
      data fpp( 8, 9,16,1),fpp( 8, 9,16,2),fpp( 8, 9,16,3)/
     x 1.4919824d-03,-2.7329463d-05, 1.3231384d-05 /
      data fpp( 8, 9,17,1),fpp( 8, 9,17,2),fpp( 8, 9,17,3)/
     x 4.6215562d-03,-1.1664154d-05, 9.1580515d-06 /
      data fpp( 8, 9,18,1),fpp( 8, 9,18,2),fpp( 8, 9,18,3)/
     x 8.6965969d-03, 7.7406230d-06, 2.2344097d-06 /
      data fpp( 8, 9,19,1),fpp( 8, 9,19,2),fpp( 8, 9,19,3)/
     x 1.5122749d-02, 3.0623870d-05,-7.3796904d-06 /
      data fpp( 8, 9,20,1),fpp( 8, 9,20,2),fpp( 8, 9,20,3)/
     x 2.4270506d-02, 4.3277189d-05,-3.2289648d-05 /
      data fpp( 8, 9,21,1),fpp( 8, 9,21,2),fpp( 8, 9,21,3)/
     x 2.4270506d-02, 4.3277189d-05,-3.2194211d-05 /
      data fpp( 8, 9,22,1),fpp( 8, 9,22,2),fpp( 8, 9,22,3)/
     x 1.5122749d-02, 3.0623870d-05,-7.7614398d-06 /
      data fpp( 8, 9,23,1),fpp( 8, 9,23,2),fpp( 8, 9,23,3)/
     x 8.6965969d-03, 7.7406230d-06, 3.6659699d-06 /
      data fpp( 8,10, 1,1),fpp( 8,10, 1,2),fpp( 8,10, 1,3)/
     x-6.1641689d-02, 1.2519767d-04, 3.5540713d-05 /
      data fpp( 8,10, 2,1),fpp( 8,10, 2,2),fpp( 8,10, 2,3)/
     x-2.6514104d-02, 5.8717277d-05, 5.9679073d-05 /
      data fpp( 8,10, 3,1),fpp( 8,10, 3,2),fpp( 8,10, 3,3)/
     x-7.6513027d-03, 4.4670283d-05, 1.1285699d-04 /
      data fpp( 8,10, 4,1),fpp( 8,10, 4,2),fpp( 8,10, 4,3)/
     x-7.6513027d-03, 4.4670283d-05, 1.1031448d-04 /
      data fpp( 8,10, 5,1),fpp( 8,10, 5,2),fpp( 8,10, 5,3)/
     x-2.6514104d-02, 5.8717277d-05, 6.9849130d-05 /
      data fpp( 8,10, 6,1),fpp( 8,10, 6,2),fpp( 8,10, 6,3)/
     x-6.1641689d-02, 1.2519767d-04,-2.5970013d-06 /
      data fpp( 8,10, 7,1),fpp( 8,10, 7,2),fpp( 8,10, 7,3)/
     x-1.1957605d-01,-2.2590719d-04,-2.0252512d-04 /
      data fpp( 8,10, 8,1),fpp( 8,10, 8,2),fpp( 8,10, 8,3)/
     x 2.6845176d-02,-1.6034889d-04,-4.7900499d-05 /
      data fpp( 8,10, 9,1),fpp( 8,10, 9,2),fpp( 8,10, 9,3)/
     x 2.8197533d-02,-8.2388039d-05,-2.1666879d-05 /
      data fpp( 8,10,10,1),fpp( 8,10,10,2),fpp( 8,10,10,3)/
     x 1.6667763d-02,-5.9351575d-05,-5.2619844d-06 /
      data fpp( 8,10,11,1),fpp( 8,10,11,2),fpp( 8,10,11,3)/
     x 1.1369465d-02,-5.0987520d-05, 6.4388169d-06 /
      data fpp( 8,10,12,1),fpp( 8,10,12,2),fpp( 8,10,12,3)/
     x 7.1932083d-03,-4.5729217d-05, 1.2506717d-05 /
      data fpp( 8,10,13,1),fpp( 8,10,13,2),fpp( 8,10,13,3)/
     x 2.9228651d-03,-4.0542856d-05, 1.4544316d-05 /
      data fpp( 8,10,14,1),fpp( 8,10,14,2),fpp( 8,10,14,3)/
     x 4.6468204d-03,-3.4410873d-05, 1.4348020d-05 /
      data fpp( 8,10,15,1),fpp( 8,10,15,2),fpp( 8,10,15,3)/
     x 2.9431700d-03,-2.7065586d-05, 1.3149604d-05 /
      data fpp( 8,10,16,1),fpp( 8,10,16,2),fpp( 8,10,16,3)/
     x 4.0283594d-03,-1.8471670d-05, 1.1065563d-05 /
      data fpp( 8,10,17,1),fpp( 8,10,17,2),fpp( 8,10,17,3)/
     x 5.6593926d-03,-9.4112229d-06, 7.9641446d-06 /
      data fpp( 8,10,18,1),fpp( 8,10,18,2),fpp( 8,10,18,3)/
     x 8.7547368d-03,-1.3981831d-06, 3.0858587d-06 /
      data fpp( 8,10,19,1),fpp( 8,10,19,2),fpp( 8,10,19,3)/
     x 1.5007607d-02, 4.3318715d-06,-2.7755792d-06 /
      data fpp( 8,10,20,1),fpp( 8,10,20,2),fpp( 8,10,20,3)/
     x 2.5704874d-02, 1.0226053d-05,-2.4407542d-05 /
      data fpp( 8,10,21,1),fpp( 8,10,21,2),fpp( 8,10,21,3)/
     x 2.5704874d-02, 1.0226053d-05,-2.4206585d-05 /
      data fpp( 8,10,22,1),fpp( 8,10,22,2),fpp( 8,10,22,3)/
     x 1.5007607d-02, 4.3318715d-06,-3.5794042d-06 /
      data fpp( 8,10,23,1),fpp( 8,10,23,2),fpp( 8,10,23,3)/
     x 8.7547368d-03,-1.3981831d-06, 6.1002021d-06 /
      data fpp( 8,11, 1,1),fpp( 8,11, 1,2),fpp( 8,11, 1,3)/
     x-3.7364600d-02, 4.0149045d-05, 8.2289026d-05 /
      data fpp( 8,11, 2,1),fpp( 8,11, 2,2),fpp( 8,11, 2,3)/
     x 9.7075718d-03, 1.3305119d-04, 8.7588448d-05 /
      data fpp( 8,11, 3,1),fpp( 8,11, 3,2),fpp( 8,11, 3,3)/
     x 5.7587255d-02, 2.2786460d-04, 1.0088318d-04 /
      data fpp( 8,11, 4,1),fpp( 8,11, 4,2),fpp( 8,11, 4,3)/
     x 5.7587255d-02, 2.2786460d-04, 9.7490235d-05 /
      data fpp( 8,11, 5,1),fpp( 8,11, 5,2),fpp( 8,11, 5,3)/
     x 9.7075718d-03, 1.3305119d-04, 1.0116023d-04 /
      data fpp( 8,11, 6,1),fpp( 8,11, 6,2),fpp( 8,11, 6,3)/
     x-3.7364600d-02, 4.0149045d-05, 3.1394846d-05 /
      data fpp( 8,11, 7,1),fpp( 8,11, 7,2),fpp( 8,11, 7,3)/
     x-7.8845378d-02, 6.2975692d-05,-7.9349614d-05 /
      data fpp( 8,11, 8,1),fpp( 8,11, 8,2),fpp( 8,11, 8,3)/
     x-4.5880016d-02,-5.6875457d-05,-1.3732039d-04 /
      data fpp( 8,11, 9,1),fpp( 8,11, 9,2),fpp( 8,11, 9,3)/
     x 2.2612039d-02,-7.0210287d-05,-6.7494822d-05 /
      data fpp( 8,11,10,1),fpp( 8,11,10,2),fpp( 8,11,10,3)/
     x 2.8389842d-02,-4.7734624d-05,-2.3968321d-05 /
      data fpp( 8,11,11,1),fpp( 8,11,11,2),fpp( 8,11,11,3)/
     x 1.9913502d-02,-3.6350131d-05,-2.1658952d-06 /
      data fpp( 8,11,12,1),fpp( 8,11,12,2),fpp( 8,11,12,3)/
     x 1.3671367d-02,-3.0873595d-05, 7.6839016d-06 /
      data fpp( 8,11,13,1),fpp( 8,11,13,2),fpp( 8,11,13,3)/
     x 1.0317835d-02,-2.6884639d-05, 1.1186289d-05 /
      data fpp( 8,11,14,1),fpp( 8,11,14,2),fpp( 8,11,14,3)/
     x 1.0599207d-02,-2.2903674d-05, 1.1950943d-05 /
      data fpp( 8,11,15,1),fpp( 8,11,15,2),fpp( 8,11,15,3)/
     x 8.1740740d-03,-1.8547434d-05, 1.1509939d-05 /
      data fpp( 8,11,16,1),fpp( 8,11,16,2),fpp( 8,11,16,3)/
     x 8.2061634d-03,-1.4073858d-05, 9.7073019d-06 /
      data fpp( 8,11,17,1),fpp( 8,11,17,2),fpp( 8,11,17,3)/
     x 8.5790540d-03,-9.8629548d-06, 6.6308535d-06 /
      data fpp( 8,11,18,1),fpp( 8,11,18,2),fpp( 8,11,18,3)/
     x 1.0529652d-02,-6.1018907d-06, 2.7872839d-06 /
      data fpp( 8,11,19,1),fpp( 8,11,19,2),fpp( 8,11,19,3)/
     x 1.7149211d-02,-3.1253561d-06, 1.3001091d-07 /
      data fpp( 8,11,20,1),fpp( 8,11,20,2),fpp( 8,11,20,3)/
     x 3.4379008d-02,-2.8754001d-06,-2.0881328d-05 /
      data fpp( 8,11,21,1),fpp( 8,11,21,2),fpp( 8,11,21,3)/
     x 3.4379008d-02,-2.8754001d-06,-2.0542023d-05 /
      data fpp( 8,11,22,1),fpp( 8,11,22,2),fpp( 8,11,22,3)/
     x 1.7149211d-02,-3.1253561d-06,-1.2272078d-06 /
      data fpp( 8,11,23,1),fpp( 8,11,23,2),fpp( 8,11,23,3)/
     x 1.0529652d-02,-6.1018907d-06, 7.8768539d-06 /
      data fpp( 8,12, 1,1),fpp( 8,12, 1,2),fpp( 8,12, 1,3)/
     x 1.2509187d-03, 1.2407815d-04, 1.8156696d-04 /
      data fpp( 8,12, 2,1),fpp( 8,12, 2,2),fpp( 8,12, 2,3)/
     x 1.0069590d-01, 1.8109196d-04, 1.3325357d-04 /
      data fpp( 8,12, 3,1),fpp( 8,12, 3,2),fpp( 8,12, 3,3)/
     x 2.3986574d-01, 2.4616331d-04, 3.3492749d-05 /
      data fpp( 8,12, 4,1),fpp( 8,12, 4,2),fpp( 8,12, 4,3)/
     x 2.3986574d-01, 2.4616331d-04, 2.6898966d-05 /
      data fpp( 8,12, 5,1),fpp( 8,12, 5,2),fpp( 8,12, 5,3)/
     x 1.0069590d-01, 1.8109196d-04, 1.5962871d-04 /
      data fpp( 8,12, 6,1),fpp( 8,12, 6,2),fpp( 8,12, 6,3)/
     x 1.2509187d-03, 1.2407815d-04, 8.2660214d-05 /
      data fpp( 8,12, 7,1),fpp( 8,12, 7,2),fpp( 8,12, 7,3)/
     x-5.5216538d-02, 5.4146425d-05,-2.0013560d-05 /
      data fpp( 8,12, 8,1),fpp( 8,12, 8,2),fpp( 8,12, 8,3)/
     x-6.7793602d-02, 2.2738724d-05,-1.0417997d-04 /
      data fpp( 8,12, 9,1),fpp( 8,12, 9,2),fpp( 8,12, 9,3)/
     x-1.5387010d-02,-1.8010813d-05,-1.1059854d-04 /
      data fpp( 8,12,10,1),fpp( 8,12,10,2),fpp( 8,12,10,3)/
     x 2.4964324d-02,-2.5505930d-05,-5.4559847d-05 /
      data fpp( 8,12,11,1),fpp( 8,12,11,2),fpp( 8,12,11,3)/
     x 2.6569199d-02,-2.2395956d-05,-1.4386069d-05 /
      data fpp( 8,12,12,1),fpp( 8,12,12,2),fpp( 8,12,12,3)/
     x 2.1023157d-02,-1.9758405d-05, 1.9981218d-06 /
      data fpp( 8,12,13,1),fpp( 8,12,13,2),fpp( 8,12,13,3)/
     x 1.7199894d-02,-1.7908587d-05, 8.0855816d-06 /
      data fpp( 8,12,14,1),fpp( 8,12,14,2),fpp( 8,12,14,3)/
     x 1.6991884d-02,-1.6318432d-05, 1.0041552d-05 /
      data fpp( 8,12,15,1),fpp( 8,12,15,2),fpp( 8,12,15,3)/
     x 1.4365676d-02,-1.4988676d-05, 1.0116211d-05 /
      data fpp( 8,12,16,1),fpp( 8,12,16,2),fpp( 8,12,16,3)/
     x 1.4027367d-02,-1.4050899d-05, 8.2036030d-06 /
      data fpp( 8,12,17,1),fpp( 8,12,17,2),fpp( 8,12,17,3)/
     x 1.4008838d-02,-1.3350958d-05, 4.8113767d-06 /
      data fpp( 8,12,18,1),fpp( 8,12,18,2),fpp( 8,12,18,3)/
     x 1.5769431d-02,-1.2636254d-05, 1.7468903d-06 /
      data fpp( 8,12,19,1),fpp( 8,12,19,2),fpp( 8,12,19,3)/
     x 2.3555245d-02,-1.2824447d-05, 1.6506220d-07 /
      data fpp( 8,12,20,1),fpp( 8,12,20,2),fpp( 8,12,20,3)/
     x 2.8853745d-02,-1.4720452d-05,-1.7581139d-05 /
      data fpp( 8,12,21,1),fpp( 8,12,21,2),fpp( 8,12,21,3)/
     x 2.8853745d-02,-1.4720452d-05,-1.7263114d-05 /
      data fpp( 8,12,22,1),fpp( 8,12,22,2),fpp( 8,12,22,3)/
     x 2.3555245d-02,-1.2824447d-05,-1.1070389d-06 /
      data fpp( 8,12,23,1),fpp( 8,12,23,2),fpp( 8,12,23,3)/
     x 1.5769431d-02,-1.2636254d-05, 6.5172695d-06 /
      data fpp( 8,13, 1,1),fpp( 8,13, 1,2),fpp( 8,13, 1,3)/
     x 5.3544323d-02, 7.5748369d-05, 2.8535219d-04 /
      data fpp( 8,13, 2,1),fpp( 8,13, 2,2),fpp( 8,13, 2,3)/
     x 2.2801775d-01, 5.4709622d-06, 1.7386063d-04 /
      data fpp( 8,13, 3,1),fpp( 8,13, 3,2),fpp( 8,13, 3,3)/
     x 4.8127542d-01,-1.4020985d-04,-5.9434695d-05 /
      data fpp( 8,13, 4,1),fpp( 8,13, 4,2),fpp( 8,13, 4,3)/
     x 4.8127542d-01,-1.4020985d-04,-6.9261228d-05 /
      data fpp( 8,13, 5,1),fpp( 8,13, 5,2),fpp( 8,13, 5,3)/
     x 2.2801775d-01, 5.4709622d-06, 2.1316676d-04 /
      data fpp( 8,13, 6,1),fpp( 8,13, 6,2),fpp( 8,13, 6,3)/
     x 5.3544323d-02, 7.5748369d-05, 1.3795420d-04 /
      data fpp( 8,13, 7,1),fpp( 8,13, 7,2),fpp( 8,13, 7,3)/
     x-3.0878755d-02, 8.2838608d-05, 2.9008438d-05 /
      data fpp( 8,13, 8,1),fpp( 8,13, 8,2),fpp( 8,13, 8,3)/
     x-6.4756452d-02, 5.0154563d-05,-6.2167954d-05 /
      data fpp( 8,13, 9,1),fpp( 8,13, 9,2),fpp( 8,13, 9,3)/
     x-4.7199326d-02, 1.6733540d-05,-1.1046262d-04 /
      data fpp( 8,13,10,1),fpp( 8,13,10,2),fpp( 8,13,10,3)/
     x 6.1031440d-03,-2.7316545d-06,-8.4197558d-05 /
      data fpp( 8,13,11,1),fpp( 8,13,11,2),fpp( 8,13,11,3)/
     x 2.6145428d-02,-7.8120438d-06,-2.7947145d-05 /
      data fpp( 8,13,12,1),fpp( 8,13,12,2),fpp( 8,13,12,3)/
     x 2.5075430d-02,-9.9787858d-06,-4.1618617d-06 /
      data fpp( 8,13,13,1),fpp( 8,13,13,2),fpp( 8,13,13,3)/
     x 2.2282214d-02,-1.0837014d-05, 4.8925920d-06 /
      data fpp( 8,13,14,1),fpp( 8,13,14,2),fpp( 8,13,14,3)/
     x 2.2073358d-02,-1.1638597d-05, 7.9854939d-06 /
      data fpp( 8,13,15,1),fpp( 8,13,15,2),fpp( 8,13,15,3)/
     x 2.0166511d-02,-1.2817860d-05, 8.3574324d-06 /
      data fpp( 8,13,16,1),fpp( 8,13,16,2),fpp( 8,13,16,3)/
     x 2.0262173d-02,-1.4418548d-05, 6.4347763d-06 /
      data fpp( 8,13,17,1),fpp( 8,13,17,2),fpp( 8,13,17,3)/
     x 2.0853860d-02,-1.6089213d-05, 3.1334623d-06 /
      data fpp( 8,13,18,1),fpp( 8,13,18,2),fpp( 8,13,18,3)/
     x 2.3266663d-02,-1.7507092d-05, 2.6737467d-07 /
      data fpp( 8,13,19,1),fpp( 8,13,19,2),fpp( 8,13,19,3)/
     x 3.0575143d-02,-1.8488856d-05,-2.1449609d-06 /
      data fpp( 8,13,20,1),fpp( 8,13,20,2),fpp( 8,13,20,3)/
     x 3.2848573d-02,-1.8480791d-05,-1.3029531d-05 /
      data fpp( 8,13,21,1),fpp( 8,13,21,2),fpp( 8,13,21,3)/
     x 3.2848573d-02,-1.8480791d-05,-1.2902927d-05 /
      data fpp( 8,13,22,1),fpp( 8,13,22,2),fpp( 8,13,22,3)/
     x 3.0575143d-02,-1.8488856d-05,-2.6513781d-06 /
      data fpp( 8,13,23,1),fpp( 8,13,23,2),fpp( 8,13,23,3)/
     x 2.3266663d-02,-1.7507092d-05, 2.1664390d-06 /
      data fpp( 8,14, 1,1),fpp( 8,14, 1,2),fpp( 8,14, 1,3)/
     x 7.7518626d-02, 5.2370379d-05, 2.4783762d-04 /
      data fpp( 8,14, 2,1),fpp( 8,14, 2,2),fpp( 8,14, 2,3)/
     x 2.5922187d-01,-4.3117811d-05, 1.4699576d-04 /
      data fpp( 8,14, 3,1),fpp( 8,14, 3,2),fpp( 8,14, 3,3)/
     x 4.9919666d-01,-1.6883990d-04,-6.4964675d-05 /
      data fpp( 8,14, 4,1),fpp( 8,14, 4,2),fpp( 8,14, 4,3)/
     x 4.9919666d-01,-1.6883990d-04,-7.2190857d-05 /
      data fpp( 8,14, 5,1),fpp( 8,14, 5,2),fpp( 8,14, 5,3)/
     x 2.5922187d-01,-4.3117811d-05, 1.7590049d-04 /
      data fpp( 8,14, 6,1),fpp( 8,14, 6,2),fpp( 8,14, 6,3)/
     x 7.7518626d-02, 5.2370379d-05, 1.3944490d-04 /
      data fpp( 8,14, 7,1),fpp( 8,14, 7,2),fpp( 8,14, 7,3)/
     x-1.1937069d-02, 8.2403144d-05, 5.2925928d-05 /
      data fpp( 8,14, 8,1),fpp( 8,14, 8,2),fpp( 8,14, 8,3)/
     x-5.4163070d-02, 7.1363025d-05,-2.7580606d-05 /
      data fpp( 8,14, 9,1),fpp( 8,14, 9,2),fpp( 8,14, 9,3)/
     x-6.2955597d-02, 4.0692652d-05,-8.7443502d-05 /
      data fpp( 8,14,10,1),fpp( 8,14,10,2),fpp( 8,14,10,3)/
     x-2.1147013d-02, 1.8432548d-05,-1.0045538d-04 /
      data fpp( 8,14,11,1),fpp( 8,14,11,2),fpp( 8,14,11,3)/
     x 1.9232296d-02, 5.2421317d-06,-4.0696958d-05 /
      data fpp( 8,14,12,1),fpp( 8,14,12,2),fpp( 8,14,12,3)/
     x 2.6994372d-02,-8.8445192d-07,-8.7007819d-06 /
      data fpp( 8,14,13,1),fpp( 8,14,13,2),fpp( 8,14,13,3)/
     x 2.5063931d-02,-4.2333575d-06, 1.6280857d-06 /
      data fpp( 8,14,14,1),fpp( 8,14,14,2),fpp( 8,14,14,3)/
     x 2.4321200d-02,-6.5171798d-06, 5.6264389d-06 /
      data fpp( 8,14,15,1),fpp( 8,14,15,2),fpp( 8,14,15,3)/
     x 2.4255082d-02,-8.7578820d-06, 6.1541585d-06 /
      data fpp( 8,14,16,1),fpp( 8,14,16,2),fpp( 8,14,16,3)/
     x 2.4821251d-02,-1.1074910d-05, 4.5929271d-06 /
      data fpp( 8,14,17,1),fpp( 8,14,17,2),fpp( 8,14,17,3)/
     x 2.5826151d-02,-1.3252189d-05, 1.8141333d-06 /
      data fpp( 8,14,18,1),fpp( 8,14,18,2),fpp( 8,14,18,3)/
     x 2.8034327d-02,-1.4871376d-05,-9.8946016d-07 /
      data fpp( 8,14,19,1),fpp( 8,14,19,2),fpp( 8,14,19,3)/
     x 3.2326978d-02,-1.5202130d-05,-3.5742926d-06 /
      data fpp( 8,14,20,1),fpp( 8,14,20,2),fpp( 8,14,20,3)/
     x 3.8049088d-02,-1.4070385d-05,-8.5093693d-06 /
      data fpp( 8,14,21,1),fpp( 8,14,21,2),fpp( 8,14,21,3)/
     x 3.8049088d-02,-1.4070385d-05,-8.5227457d-06 /
      data fpp( 8,14,22,1),fpp( 8,14,22,2),fpp( 8,14,22,3)/
     x 3.2326978d-02,-1.5202130d-05,-3.5207869d-06 /
      data fpp( 8,14,23,1),fpp( 8,14,23,2),fpp( 8,14,23,3)/
     x 2.8034327d-02,-1.4871376d-05,-1.1901065d-06 /
      data fpp( 8,15, 1,1),fpp( 8,15, 1,2),fpp( 8,15, 1,3)/
     x 5.1410345d-02, 1.2029211d-04, 1.2150277d-04 /
      data fpp( 8,15, 2,1),fpp( 8,15, 2,2),fpp( 8,15, 2,3)/
     x 1.5346700d-01, 1.6219428d-04, 8.3880967d-05 /
      data fpp( 8,15, 3,1),fpp( 8,15, 3,2),fpp( 8,15, 3,3)/
     x 2.5985278d-01, 2.4170544d-04, 4.5953658d-06 /
      data fpp( 8,15, 4,1),fpp( 8,15, 4,2),fpp( 8,15, 4,3)/
     x 2.5985278d-01, 2.4170544d-04, 2.2634193d-06 /
      data fpp( 8,15, 5,1),fpp( 8,15, 5,2),fpp( 8,15, 5,3)/
     x 1.5346700d-01, 1.6219428d-04, 9.3208753d-05 /
      data fpp( 8,15, 6,1),fpp( 8,15, 6,2),fpp( 8,15, 6,3)/
     x 5.1410345d-02, 1.2029211d-04, 8.6523569d-05 /
      data fpp( 8,15, 7,1),fpp( 8,15, 7,2),fpp( 8,15, 7,3)/
     x-8.9747711d-03, 1.0639881d-04, 4.2916971d-05 /
      data fpp( 8,15, 8,1),fpp( 8,15, 8,2),fpp( 8,15, 8,3)/
     x-4.4883894d-02, 9.0861339d-05,-8.5854527d-06 /
      data fpp( 8,15, 9,1),fpp( 8,15, 9,2),fpp( 8,15, 9,3)/
     x-6.7892158d-02, 6.5637853d-05,-5.7073160d-05 /
      data fpp( 8,15,10,1),fpp( 8,15,10,2),fpp( 8,15,10,3)/
     x-5.0300470d-02, 2.4677461d-05,-9.8665907d-05 /
      data fpp( 8,15,11,1),fpp( 8,15,11,2),fpp( 8,15,11,3)/
     x 6.6313620d-03, 1.5223517d-05,-5.0817212d-05 /
      data fpp( 8,15,12,1),fpp( 8,15,12,2),fpp( 8,15,12,3)/
     x 2.4495187d-02, 6.5025935d-06,-9.9032453d-06 /
      data fpp( 8,15,13,1),fpp( 8,15,13,2),fpp( 8,15,13,3)/
     x 2.5924701d-02, 2.0184439d-06,-9.5580688d-07 /
      data fpp( 8,15,14,1),fpp( 8,15,14,2),fpp( 8,15,14,3)/
     x 2.6063519d-02,-6.9868387d-07, 3.2924728d-06 /
      data fpp( 8,15,15,1),fpp( 8,15,15,2),fpp( 8,15,15,3)/
     x 2.6196047d-02,-2.5206117d-06, 3.8599157d-06 /
      data fpp( 8,15,16,1),fpp( 8,15,16,2),fpp( 8,15,16,3)/
     x 2.6811884d-02,-3.8078114d-06, 2.8978645d-06 /
      data fpp( 8,15,17,1),fpp( 8,15,17,2),fpp( 8,15,17,3)/
     x 2.7653963d-02,-4.6240323d-06, 9.5862626d-07 /
      data fpp( 8,15,18,1),fpp( 8,15,18,2),fpp( 8,15,18,3)/
     x 2.8867070d-02,-4.8954019d-06,-1.2183695d-06 /
      data fpp( 8,15,19,1),fpp( 8,15,19,2),fpp( 8,15,19,3)/
     x 3.0544775d-02,-4.3126225d-06,-3.1351481d-06 /
      data fpp( 8,15,20,1),fpp( 8,15,20,2),fpp( 8,15,20,3)/
     x 3.2225729d-02,-3.0516704d-06,-4.9730381d-06 /
      data fpp( 8,15,21,1),fpp( 8,15,21,2),fpp( 8,15,21,3)/
     x 3.2225729d-02,-3.0516704d-06,-5.0233117d-06 /
      data fpp( 8,15,22,1),fpp( 8,15,22,2),fpp( 8,15,22,3)/
     x 3.0544775d-02,-4.3126225d-06,-2.9340538d-06 /
      data fpp( 8,15,23,1),fpp( 8,15,23,2),fpp( 8,15,23,3)/
     x 2.8867070d-02,-4.8954019d-06,-1.9724731d-06 /
      data fpp( 8,16, 1,1),fpp( 8,16, 1,2),fpp( 8,16, 1,3)/
     x 8.2189840d-03, 1.2417517d-04, 5.1025449d-05 /
      data fpp( 8,16, 2,1),fpp( 8,16, 2,2),fpp( 8,16, 2,3)/
     x 3.9671748d-02, 1.7743669d-04, 4.7395101d-05 /
      data fpp( 8,16, 3,1),fpp( 8,16, 3,2),fpp( 8,16, 3,3)/
     x 6.7797370d-02, 2.3862014d-04, 3.9906145d-05 /
      data fpp( 8,16, 4,1),fpp( 8,16, 4,2),fpp( 8,16, 4,3)/
     x 6.7797370d-02, 2.3862014d-04, 3.9398014d-05 /
      data fpp( 8,16, 5,1),fpp( 8,16, 5,2),fpp( 8,16, 5,3)/
     x 3.9671748d-02, 1.7743669d-04, 4.9427627d-05 /
      data fpp( 8,16, 6,1),fpp( 8,16, 6,2),fpp( 8,16, 6,3)/
     x 8.2189840d-03, 1.2417517d-04, 4.3403479d-05 /
      data fpp( 8,16, 7,1),fpp( 8,16, 7,2),fpp( 8,16, 7,3)/
     x-1.7790056d-02, 9.3759596d-05, 2.4218458d-05 /
      data fpp( 8,16, 8,1),fpp( 8,16, 8,2),fpp( 8,16, 8,3)/
     x-3.9696862d-02, 7.6313621d-05, 6.8669049d-07 /
      data fpp( 8,16, 9,1),fpp( 8,16, 9,2),fpp( 8,16, 9,3)/
     x-7.7539461d-02, 6.0451936d-05,-3.5911220d-05 /
      data fpp( 8,16,10,1),fpp( 8,16,10,2),fpp( 8,16,10,3)/
     x-2.5886405d-02, 7.2895608d-05,-7.6551812d-05 /
      data fpp( 8,16,11,1),fpp( 8,16,11,2),fpp( 8,16,11,3)/
     x-1.0948697d-02, 2.6227800d-05,-5.7043532d-05 /
      data fpp( 8,16,12,1),fpp( 8,16,12,2),fpp( 8,16,12,3)/
     x 2.0990803d-02, 1.1594078d-05,-4.9760583d-06 /
      data fpp( 8,16,13,1),fpp( 8,16,13,2),fpp( 8,16,13,3)/
     x 2.5688102d-02, 6.6295821d-06,-2.5582345d-06 /
      data fpp( 8,16,14,1),fpp( 8,16,14,2),fpp( 8,16,14,3)/
     x 2.6566173d-02, 4.4879153d-06, 1.8589963d-06 /
      data fpp( 8,16,15,1),fpp( 8,16,15,2),fpp( 8,16,15,3)/
     x 2.6902628d-02, 3.7383289d-06, 1.9982495d-06 /
      data fpp( 8,16,16,1),fpp( 8,16,16,2),fpp( 8,16,16,3)/
     x 2.7326249d-02, 4.0041556d-06, 1.6500058d-06 /
      data fpp( 8,16,17,1),fpp( 8,16,17,2),fpp( 8,16,17,3)/
     x 2.7858817d-02, 4.9283179d-06, 5.6372724d-07 /
      data fpp( 8,16,18,1),fpp( 8,16,18,2),fpp( 8,16,18,3)/
     x 2.8378207d-02, 6.2109840d-06,-6.4091477d-07 /
      data fpp( 8,16,19,1),fpp( 8,16,19,2),fpp( 8,16,19,3)/
     x 2.8951303d-02, 7.4926205d-06,-1.6780682d-06 /
      data fpp( 8,16,20,1),fpp( 8,16,20,2),fpp( 8,16,20,3)/
     x 2.9404802d-02, 8.4450663d-06,-2.4688126d-06 /
      data fpp( 8,16,21,1),fpp( 8,16,21,2),fpp( 8,16,21,3)/
     x 2.9404802d-02, 8.4450663d-06,-2.5005281d-06 /
      data fpp( 8,16,22,1),fpp( 8,16,22,2),fpp( 8,16,22,3)/
     x 2.8951303d-02, 7.4926205d-06,-1.5512063d-06 /
      data fpp( 8,16,23,1),fpp( 8,16,23,2),fpp( 8,16,23,3)/
     x 2.8378207d-02, 6.2109840d-06,-1.1166469d-06 /
      data fpp( 8,17, 1,1),fpp( 8,17, 1,2),fpp( 8,17, 1,3)/
     x-1.7230072d-02, 1.1534322d-04, 2.5830889d-05 /
      data fpp( 8,17, 2,1),fpp( 8,17, 2,2),fpp( 8,17, 2,3)/
     x-1.1081276d-02, 1.2141297d-04, 2.7800722d-05 /
      data fpp( 8,17, 3,1),fpp( 8,17, 3,2),fpp( 8,17, 3,3)/
     x-5.5123815d-03, 1.2795400d-04, 3.2136222d-05 /
      data fpp( 8,17, 4,1),fpp( 8,17, 4,2),fpp( 8,17, 4,3)/
     x-5.5123815d-03, 1.2795400d-04, 3.1935973d-05 /
      data fpp( 8,17, 5,1),fpp( 8,17, 5,2),fpp( 8,17, 5,3)/
     x-1.1081276d-02, 1.2141297d-04, 2.8601717d-05 /
      data fpp( 8,17, 6,1),fpp( 8,17, 6,2),fpp( 8,17, 6,3)/
     x-1.7230072d-02, 1.1534322d-04, 2.2827160d-05 /
      data fpp( 8,17, 7,1),fpp( 8,17, 7,2),fpp( 8,17, 7,3)/
     x-2.7141611d-02, 1.1232880d-04, 1.4837642d-05 /
      data fpp( 8,17, 8,1),fpp( 8,17, 8,2),fpp( 8,17, 8,3)/
     x-2.7602257d-02, 1.1083018d-04, 1.8942721d-06 /
      data fpp( 8,17, 9,1),fpp( 8,17, 9,2),fpp( 8,17, 9,3)/
     x-3.0351912d-02, 1.0420240d-04,-2.8673022d-07 /
      data fpp( 8,17,10,1),fpp( 8,17,10,2),fpp( 8,17,10,3)/
     x-2.1218728d-01, 7.1701054d-06,-9.7143351d-05 /
      data fpp( 8,17,11,1),fpp( 8,17,11,2),fpp( 8,17,11,3)/
     x-2.2818526d-02, 4.3832847d-06,-1.7603865d-05 /
      data fpp( 8,17,12,1),fpp( 8,17,12,2),fpp( 8,17,12,3)/
     x 1.3898295d-02, 9.8270944d-06,-2.9071890d-06 /
      data fpp( 8,17,13,1),fpp( 8,17,13,2),fpp( 8,17,13,3)/
     x 2.4413115d-02, 1.0313228d-05,-4.3737890d-07 /
      data fpp( 8,17,14,1),fpp( 8,17,14,2),fpp( 8,17,14,3)/
     x 2.6678433d-02, 1.0329023d-05, 9.7870463d-07 /
      data fpp( 8,17,15,1),fpp( 8,17,15,2),fpp( 8,17,15,3)/
     x 2.7178692d-02, 1.0841296d-05, 1.1605604d-06 /
      data fpp( 8,17,16,1),fpp( 8,17,16,2),fpp( 8,17,16,3)/
     x 2.7358006d-02, 1.1959189d-05, 9.5505383d-07 /
      data fpp( 8,17,17,1),fpp( 8,17,17,2),fpp( 8,17,17,3)/
     x 2.7665907d-02, 1.3578761d-05, 5.3922431d-07 /
      data fpp( 8,17,18,1),fpp( 8,17,18,2),fpp( 8,17,18,3)/
     x 2.7869997d-02, 1.5355466d-05, 3.8048926d-08 /
      data fpp( 8,17,19,1),fpp( 8,17,19,2),fpp( 8,17,19,3)/
     x 2.8086366d-02, 1.6924141d-05,-3.5542002d-07 /
      data fpp( 8,17,20,1),fpp( 8,17,20,2),fpp( 8,17,20,3)/
     x 2.8216855d-02, 1.7949405d-05,-7.1036887d-07 /
      data fpp( 8,17,21,1),fpp( 8,17,21,2),fpp( 8,17,21,3)/
     x 2.8216855d-02, 1.7949405d-05,-7.2118340d-07 /
      data fpp( 8,17,22,1),fpp( 8,17,22,2),fpp( 8,17,22,3)/
     x 2.8086366d-02, 1.6924141d-05,-3.1216189d-07 /
      data fpp( 8,17,23,1),fpp( 8,17,23,2),fpp( 8,17,23,3)/
     x 2.7869997d-02, 1.5355466d-05,-1.2416906d-07 /
      data fpp( 8,18, 1,1),fpp( 8,18, 1,2),fpp( 8,18, 1,3)/
     x-2.2578186d-02,-1.7972006d-04, 1.1075567d-05 /
      data fpp( 8,18, 2,1),fpp( 8,18, 2,2),fpp( 8,18, 2,3)/
     x-1.5583762d-02,-1.8939456d-04, 1.1893867d-05 /
      data fpp( 8,18, 3,1),fpp( 8,18, 3,2),fpp( 8,18, 3,3)/
     x-2.2576565d-02,-1.9441614d-04, 1.3636966d-05 /
      data fpp( 8,18, 4,1),fpp( 8,18, 4,2),fpp( 8,18, 4,3)/
     x-2.2576565d-02,-1.9441614d-04, 1.3655170d-05 /
      data fpp( 8,18, 5,1),fpp( 8,18, 5,2),fpp( 8,18, 5,3)/
     x-1.5583762d-02,-1.8939456d-04, 1.1821052d-05 /
      data fpp( 8,18, 6,1),fpp( 8,18, 6,2),fpp( 8,18, 6,3)/
     x-2.2578186d-02,-1.7972006d-04, 1.1348624d-05 /
      data fpp( 8,18, 7,1),fpp( 8,18, 7,2),fpp( 8,18, 7,3)/
     x-8.7079831d-02,-1.6681480d-04, 3.3184522d-06 /
      data fpp( 8,18, 8,1),fpp( 8,18, 8,2),fpp( 8,18, 8,3)/
     x 1.1552908d-01,-1.5462434d-04, 2.0875567d-05 /
      data fpp( 8,18, 9,1),fpp( 8,18, 9,2),fpp( 8,18, 9,3)/
     x-5.4487086d-01,-1.4801154d-04,-5.8128720d-05 /
      data fpp( 8,18,10,1),fpp( 8,18,10,2),fpp( 8,18,10,3)/
     x-6.0397819d-02,-6.6662030d-05,-2.0218685d-05 /
      data fpp( 8,18,11,1),fpp( 8,18,11,2),fpp( 8,18,11,3)/
     x-2.8724153d-02,-2.2310938d-05, 6.1094614d-06 /
      data fpp( 8,18,12,1),fpp( 8,18,12,2),fpp( 8,18,12,3)/
     x 3.9974349d-02,-8.2244555d-06,-7.5716050d-07 /
      data fpp( 8,18,13,1),fpp( 8,18,13,2),fpp( 8,18,13,3)/
     x 2.3688445d-02, 1.4750631d-07, 1.2091806d-06 /
      data fpp( 8,18,14,1),fpp( 8,18,14,2),fpp( 8,18,14,3)/
     x 3.3042380d-02, 6.3839935d-06, 7.2043822d-07 /
      data fpp( 8,18,15,1),fpp( 8,18,15,2),fpp( 8,18,15,3)/
     x 4.1162673d-02, 1.1738487d-05, 8.0506655d-07 /
      data fpp( 8,18,16,1),fpp( 8,18,16,2),fpp( 8,18,16,3)/
     x 4.8099889d-02, 1.6619089d-05, 6.7329556d-07 /
      data fpp( 8,18,17,1),fpp( 8,18,17,2),fpp( 8,18,17,3)/
     x 5.3892054d-02, 2.1024640d-05, 5.6975119d-07 /
      data fpp( 8,18,18,1),fpp( 8,18,18,2),fpp( 8,18,18,3)/
     x 5.8598846d-02, 2.4797153d-05, 4.3769968d-07 /
      data fpp( 8,18,19,1),fpp( 8,18,19,2),fpp( 8,18,19,3)/
     x 6.2224289d-02, 2.7716817d-05, 3.4345008d-07 /
      data fpp( 8,18,20,1),fpp( 8,18,20,2),fpp( 8,18,20,3)/
     x 6.4538458d-02, 2.9581313d-05, 2.6449998d-07 /
      data fpp( 8,18,21,1),fpp( 8,18,21,2),fpp( 8,18,21,3)/
     x 6.4538458d-02, 2.9581313d-05, 2.6177501d-07 /
      data fpp( 8,18,22,1),fpp( 8,18,22,2),fpp( 8,18,22,3)/
     x 6.2224289d-02, 2.7716817d-05, 3.5435000d-07 /
      data fpp( 8,18,23,1),fpp( 8,18,23,2),fpp( 8,18,23,3)/
     x 5.8598846d-02, 2.4797153d-05, 3.9682500d-07 /
      data fpp( 8,19, 1,1),fpp( 8,19, 1,2),fpp( 8,19, 1,3)/
     x 2.7487690d-02,-3.9300297d-04,-5.8764697d-20 /
      data fpp( 8,19, 2,1),fpp( 8,19, 2,2),fpp( 8,19, 2,3)/
     x 2.7487690d-02,-4.2740672d-04, 2.5161947d-20 /
      data fpp( 8,19, 3,1),fpp( 8,19, 3,2),fpp( 8,19, 3,3)/
     x 2.7487690d-02,-4.5629943d-04,-4.5380584d-20 /
      data fpp( 8,19, 4,1),fpp( 8,19, 4,2),fpp( 8,19, 4,3)/
     x 2.7487690d-02,-4.5629943d-04, 3.5371659d-20 /
      data fpp( 8,19, 5,1),fpp( 8,19, 5,2),fpp( 8,19, 5,3)/
     x 2.7487690d-02,-4.2740672d-04,-1.7965578d-20 /
      data fpp( 8,19, 6,1),fpp( 8,19, 6,2),fpp( 8,19, 6,3)/
     x 2.7487690d-02,-3.9300297d-04,-2.2811071d-20 /
      data fpp( 8,19, 7,1),fpp( 8,19, 7,2),fpp( 8,19, 7,3)/
     x 2.7487690d-02,-3.6089760d-04,-6.0265370d-20 /
      data fpp( 8,19, 8,1),fpp( 8,19, 8,2),fpp( 8,19, 8,3)/
     x 2.7487690d-02,-3.3437283d-04,-2.2727591d-20 /
      data fpp( 8,19, 9,1),fpp( 8,19, 9,2),fpp( 8,19, 9,3)/
     x 2.7487690d-02,-3.1566423d-04,-8.0963447d-21 /
      data fpp( 8,19,10,1),fpp( 8,19,10,2),fpp( 8,19,10,3)/
     x 2.7487690d-02,-1.3817798d-04, 6.6225471d-20 /
      data fpp( 8,19,11,1),fpp( 8,19,11,2),fpp( 8,19,11,3)/
     x 2.7487690d-02,-4.7619531d-05,-1.9663904d-20 /
      data fpp( 8,19,12,1),fpp( 8,19,12,2),fpp( 8,19,12,3)/
     x 2.7487690d-02,-2.1623272d-05, 2.2095132d-20 /
      data fpp( 8,19,13,1),fpp( 8,19,13,2),fpp( 8,19,13,3)/
     x 2.7487690d-02,-6.0612532d-06, 3.6216078d-20 /
      data fpp( 8,19,14,1),fpp( 8,19,14,2),fpp( 8,19,14,3)/
     x 2.7487690d-02, 5.2350033d-06, 2.3116993d-20 /
      data fpp( 8,19,15,1),fpp( 8,19,15,2),fpp( 8,19,15,3)/
     x 2.7487690d-02, 1.4408757d-05, 3.1064685d-22 /
      data fpp( 8,19,16,1),fpp( 8,19,16,2),fpp( 8,19,16,3)/
     x 2.7487690d-02, 2.2220456d-05,-4.0292305d-20 /
      data fpp( 8,19,17,1),fpp( 8,19,17,2),fpp( 8,19,17,3)/
     x 2.7487690d-02, 2.8814680d-05, 2.0794587d-20 /
      data fpp( 8,19,18,1),fpp( 8,19,18,2),fpp( 8,19,18,3)/
     x 2.7487690d-02, 3.4153924d-05,-4.2449737d-20 /
      data fpp( 8,19,19,1),fpp( 8,19,19,2),fpp( 8,19,19,3)/
     x 2.7487690d-02, 3.8120592d-05,-3.8690303d-20 /
      data fpp( 8,19,20,1),fpp( 8,19,20,2),fpp( 8,19,20,3)/
     x 2.7487690d-02, 4.0605344d-05, 3.6889608d-20 /
      data fpp( 8,19,21,1),fpp( 8,19,21,2),fpp( 8,19,21,3)/
     x 2.7487690d-02, 4.0605344d-05,-2.1593434d-20 /
      data fpp( 8,19,22,1),fpp( 8,19,22,2),fpp( 8,19,22,3)/
     x 2.7487690d-02, 3.8120592d-05,-1.9254058d-21 /
      data fpp( 8,19,23,1),fpp( 8,19,23,2),fpp( 8,19,23,3)/
     x 2.7487690d-02, 3.4153924d-05, 1.8465090d-19 /
      data fpp( 9, 1, 1,1),fpp( 9, 1, 1,2),fpp( 9, 1, 1,3)/
     x-1.1081686d+00, 1.5255882d-03, 6.7887352d-19 /
      data fpp( 9, 1, 2,1),fpp( 9, 1, 2,2),fpp( 9, 1, 2,3)/
     x-1.1081686d+00, 9.4801160d-04,-3.8894153d-19 /
      data fpp( 9, 1, 3,1),fpp( 9, 1, 3,2),fpp( 9, 1, 3,3)/
     x-1.1081686d+00, 2.2417214d-03,-1.7538352d-19 /
      data fpp( 9, 1, 4,1),fpp( 9, 1, 4,2),fpp( 9, 1, 4,3)/
     x-1.1081686d+00, 2.2417214d-03, 4.8043326d-19 /
      data fpp( 9, 1, 5,1),fpp( 9, 1, 5,2),fpp( 9, 1, 5,3)/
     x-1.1081686d+00, 9.4801160d-04,-5.3639233d-20 /
      data fpp( 9, 1, 6,1),fpp( 9, 1, 6,2),fpp( 9, 1, 6,3)/
     x-1.1081686d+00, 1.5255882d-03,-2.9051652d-19 /
      data fpp( 9, 1, 7,1),fpp( 9, 1, 7,2),fpp( 9, 1, 7,3)/
     x-1.1081686d+00,-8.9612334d-04,-6.8334577d-19 /
      data fpp( 9, 1, 8,1),fpp( 9, 1, 8,2),fpp( 9, 1, 8,3)/
     x-1.1081686d+00,-1.6559542d-03,-3.9901165d-19 /
      data fpp( 9, 1, 9,1),fpp( 9, 1, 9,2),fpp( 9, 1, 9,3)/
     x-1.1081686d+00,-1.9212716d-03, 2.2544619d-19 /
      data fpp( 9, 1,10,1),fpp( 9, 1,10,2),fpp( 9, 1,10,3)/
     x-1.1081686d+00,-2.0278150d-03, 8.7324059d-19 /
      data fpp( 9, 1,11,1),fpp( 9, 1,11,2),fpp( 9, 1,11,3)/
     x-1.1081686d+00,-2.0211917d-03,-5.0143577d-19 /
      data fpp( 9, 1,12,1),fpp( 9, 1,12,2),fpp( 9, 1,12,3)/
     x-1.1081686d+00,-2.1501493d-03, 6.1019161d-19 /
      data fpp( 9, 1,13,1),fpp( 9, 1,13,2),fpp( 9, 1,13,3)/
     x-1.1081686d+00,-2.1511132d-03, 1.9792968d-19 /
      data fpp( 9, 1,14,1),fpp( 9, 1,14,2),fpp( 9, 1,14,3)/
     x-1.1081686d+00,-2.0365693d-03, 1.8001405d-19 /
      data fpp( 9, 1,15,1),fpp( 9, 1,15,2),fpp( 9, 1,15,3)/
     x-1.1081686d+00,-1.9373701d-03, 6.3257453d-20 /
      data fpp( 9, 1,16,1),fpp( 9, 1,16,2),fpp( 9, 1,16,3)/
     x-1.1081686d+00,-1.6742031d-03,-4.9527543d-19 /
      data fpp( 9, 1,17,1),fpp( 9, 1,17,2),fpp( 9, 1,17,3)/
     x-1.1081686d+00,-9.3769579d-04, 6.0646216d-19 /
      data fpp( 9, 1,18,1),fpp( 9, 1,18,2),fpp( 9, 1,18,3)/
     x-1.1081686d+00, 1.4496318d-03,-5.8237229d-19 /
      data fpp( 9, 1,19,1),fpp( 9, 1,19,2),fpp( 9, 1,19,3)/
     x-1.1081686d+00, 9.4063998d-04,-3.4190778d-19 /
      data fpp( 9, 1,20,1),fpp( 9, 1,20,2),fpp( 9, 1,20,3)/
     x-1.1081686d+00, 2.2321185d-03, 4.3784435d-19 /
      data fpp( 9, 1,21,1),fpp( 9, 1,21,2),fpp( 9, 1,21,3)/
     x-1.1081686d+00, 2.2321185d-03,-8.5503209d-20 /
      data fpp( 9, 1,22,1),fpp( 9, 1,22,2),fpp( 9, 1,22,3)/
     x-1.1081686d+00, 9.4063998d-04, 8.9662097d-19 /
      data fpp( 9, 1,23,1),fpp( 9, 1,23,2),fpp( 9, 1,23,3)/
     x-1.1081686d+00, 1.4496318d-03, 1.1800924d-18 /
      data fpp( 9, 2, 1,1),fpp( 9, 2, 1,2),fpp( 9, 2, 1,3)/
     x-3.6521653d+00, 5.3213963d-04,-1.9490092d-04 /
      data fpp( 9, 2, 2,1),fpp( 9, 2, 2,2),fpp( 9, 2, 2,3)/
     x-5.1905100d+00, 1.5015079d-04,-1.3019316d-04 /
      data fpp( 9, 2, 3,1),fpp( 9, 2, 3,2),fpp( 9, 2, 3,3)/
     x-2.4552693d+00, 7.1351512d-04, 2.8255684d-06 /
      data fpp( 9, 2, 4,1),fpp( 9, 2, 4,2),fpp( 9, 2, 4,3)/
     x-2.4552693d+00, 7.1351512d-04, 1.2696876d-05 /
      data fpp( 9, 2, 5,1),fpp( 9, 2, 5,2),fpp( 9, 2, 5,3)/
     x-5.1905100d+00, 1.5015079d-04,-1.6967839d-04 /
      data fpp( 9, 2, 6,1),fpp( 9, 2, 6,2),fpp( 9, 2, 6,3)/
     x-3.6521653d+00, 5.3213963d-04,-4.6831304d-05 /
      data fpp( 9, 2, 7,1),fpp( 9, 2, 7,2),fpp( 9, 2, 7,3)/
     x 2.3558621d-01,-3.8994831d-04, 4.2951610d-05 /
      data fpp( 9, 2, 8,1),fpp( 9, 2, 8,2),fpp( 9, 2, 8,3)/
     x 3.5787604d+00,-6.6236964d-04, 3.1702864d-05 /
      data fpp( 9, 2, 9,1),fpp( 9, 2, 9,2),fpp( 9, 2, 9,3)/
     x 3.1503019d+00,-7.4186087d-04, 4.1046932d-05 /
      data fpp( 9, 2,10,1),fpp( 9, 2,10,2),fpp( 9, 2,10,3)/
     x 3.3636163d+00,-7.7212996d-04, 2.2035406d-05 /
      data fpp( 9, 2,11,1),fpp( 9, 2,11,2),fpp( 9, 2,11,3)/
     x 3.0217323d+00,-7.5092664d-04, 8.8005443d-05 /
      data fpp( 9, 2,12,1),fpp( 9, 2,12,2),fpp( 9, 2,12,3)/
     x 1.8057391d+00,-8.1037242d-04,-6.1371798d-06 /
      data fpp( 9, 2,13,1),fpp( 9, 2,13,2),fpp( 9, 2,13,3)/
     x 1.9532868d+00,-8.1647764d-04,-1.5727243d-06 /
      data fpp( 9, 2,14,1),fpp( 9, 2,14,2),fpp( 9, 2,14,3)/
     x 3.3226220d+00,-7.7921940d-04, 8.2442077d-05 /
      data fpp( 9, 2,15,1),fpp( 9, 2,15,2),fpp( 9, 2,15,3)/
     x 3.2066065d+00,-7.5610976d-04, 2.8258416d-05 /
      data fpp( 9, 2,16,1),fpp( 9, 2,16,2),fpp( 9, 2,16,3)/
     x 3.2871362d+00,-6.7926676d-04, 3.1624260d-05 /
      data fpp( 9, 2,17,1),fpp( 9, 2,17,2),fpp( 9, 2,17,3)/
     x-1.3745648d-01,-4.2136441d-04, 5.4224544d-05 /
      data fpp( 9, 2,18,1),fpp( 9, 2,18,2),fpp( 9, 2,18,3)/
     x-4.0906902d+00, 4.9192748d-04,-9.4076436d-05 /
      data fpp( 9, 2,19,1),fpp( 9, 2,19,2),fpp( 9, 2,19,3)/
     x-4.7200365d+00, 1.5475004d-04,-1.2715080d-04 /
      data fpp( 9, 2,20,1),fpp( 9, 2,20,2),fpp( 9, 2,20,3)/
     x-1.9538145d+00, 7.2117508d-04, 5.9376368d-06 /
      data fpp( 9, 2,21,1),fpp( 9, 2,21,2),fpp( 9, 2,21,3)/
     x-1.9538145d+00, 7.2117508d-04, 1.4194896d-06 /
      data fpp( 9, 2,22,1),fpp( 9, 2,22,2),fpp( 9, 2,22,3)/
     x-4.7200365d+00, 1.5475004d-04,-1.0907821d-04 /
      data fpp( 9, 2,23,1),fpp( 9, 2,23,2),fpp( 9, 2,23,3)/
     x-4.0906902d+00, 4.9192748d-04,-1.6184864d-04 /
      data fpp( 9, 3, 1,1),fpp( 9, 3, 1,2),fpp( 9, 3, 1,3)/
     x-2.7991292d+00,-1.9376067d-03, 6.4761948d-04 /
      data fpp( 9, 3, 2,1),fpp( 9, 3, 2,2),fpp( 9, 3, 2,3)/
     x-1.6525518d-01, 4.1205224d-05, 2.9608105d-04 /
      data fpp( 9, 3, 3,1),fpp( 9, 3, 3,2),fpp( 9, 3, 3,3)/
     x-7.4173009d-01,-7.3912191d-04,-3.6407966d-04 /
      data fpp( 9, 3, 4,1),fpp( 9, 3, 4,2),fpp( 9, 3, 4,3)/
     x-7.4173009d-01,-7.3912191d-04,-5.2706755d-04 /
      data fpp( 9, 3, 5,1),fpp( 9, 3, 5,2),fpp( 9, 3, 5,3)/
     x-1.6525518d-01, 4.1205224d-05, 9.4803259d-04 /
      data fpp( 9, 3, 6,1),fpp( 9, 3, 6,2),fpp( 9, 3, 6,3)/
     x-2.7991292d+00,-1.9376067d-03,-1.7971988d-03 /
      data fpp( 9, 3, 7,1),fpp( 9, 3, 7,2),fpp( 9, 3, 7,3)/
     x 2.6741803d-01, 9.9505895d-06, 1.3234327d-03 /
      data fpp( 9, 3, 8,1),fpp( 9, 3, 8,2),fpp( 9, 3, 8,3)/
     x 3.7119653d-01, 8.1416475d-04,-6.5972014d-05 /
      data fpp( 9, 3, 9,1),fpp( 9, 3, 9,2),fpp( 9, 3, 9,3)/
     x 3.8826337d-01, 1.1667591d-03, 1.7668935d-04 /
      data fpp( 9, 3,10,1),fpp( 9, 3,10,2),fpp( 9, 3,10,3)/
     x 4.0960765d-01, 1.4223508d-03, 5.3726625d-05 /
      data fpp( 9, 3,11,1),fpp( 9, 3,11,2),fpp( 9, 3,11,3)/
     x 4.1163705d-01, 1.3853582d-03, 6.9264154d-05 /
      data fpp( 9, 3,12,1),fpp( 9, 3,12,2),fpp( 9, 3,12,3)/
     x 4.0979852d-01, 1.4592570d-03, 5.7770759d-05 /
      data fpp( 9, 3,13,1),fpp( 9, 3,13,2),fpp( 9, 3,13,3)/
     x-2.8908741d-01, 1.4386517d-03, 7.0272810d-05 /
      data fpp( 9, 3,14,1),fpp( 9, 3,14,2),fpp( 9, 3,14,3)/
     x 4.0920773d-01, 1.3828789d-03, 5.4960000d-05 /
      data fpp( 9, 3,15,1),fpp( 9, 3,15,2),fpp( 9, 3,15,3)/
     x 3.4144325d-01, 1.1539932d-03, 1.7774319d-04 /
      data fpp( 9, 3,16,1),fpp( 9, 3,16,2),fpp( 9, 3,16,3)/
     x 3.7004289d-01, 7.9696416d-04,-6.0974760d-05 /
      data fpp( 9, 3,17,1),fpp( 9, 3,17,2),fpp( 9, 3,17,3)/
     x 8.0608130d-02, 6.2449439d-05, 1.3042079d-03 /
      data fpp( 9, 3,18,1),fpp( 9, 3,18,2),fpp( 9, 3,18,3)/
     x-2.7221483d+00,-1.8953757d-03,-1.7978966d-03 /
      data fpp( 9, 3,19,1),fpp( 9, 3,19,2),fpp( 9, 3,19,3)/
     x-1.6416742d-01, 1.7243871d-05, 9.6116272d-04 /
      data fpp( 9, 3,20,1),fpp( 9, 3,20,2),fpp( 9, 3,20,3)/
     x-7.4217841d-01,-7.7385078d-04,-5.2907222d-04 /
      data fpp( 9, 3,21,1),fpp( 9, 3,21,2),fpp( 9, 3,21,3)/
     x-7.4217841d-01,-7.7385078d-04,-3.6509268d-04 /
      data fpp( 9, 3,22,1),fpp( 9, 3,22,2),fpp( 9, 3,22,3)/
     x-1.6416742d-01, 1.7243871d-05, 3.0524455d-04 /
      data fpp( 9, 3,23,1),fpp( 9, 3,23,2),fpp( 9, 3,23,3)/
     x-2.7221483d+00,-1.8953757d-03, 6.6179647d-04 /
      data fpp( 9, 4, 1,1),fpp( 9, 4, 1,2),fpp( 9, 4, 1,3)/
     x-1.8069326d-01, 7.5968918d-04,-6.4956435d-04 /
      data fpp( 9, 4, 2,1),fpp( 9, 4, 2,2),fpp( 9, 4, 2,3)/
     x-1.4197431d-01,-2.4789437d-03,-5.4318680d-04 /
      data fpp( 9, 4, 3,1),fpp( 9, 4, 3,2),fpp( 9, 4, 3,3)/
     x-6.8502891d-01,-2.4562515d-03,-3.5899043d-04 /
      data fpp( 9, 4, 4,1),fpp( 9, 4, 4,2),fpp( 9, 4, 4,3)/
     x-6.8502891d-01,-2.4562515d-03,-2.8241830d-04 /
      data fpp( 9, 4, 5,1),fpp( 9, 4, 5,2),fpp( 9, 4, 5,3)/
     x-1.4197431d-01,-2.4789437d-03,-8.4947534d-04 /
      data fpp( 9, 4, 6,1),fpp( 9, 4, 6,2),fpp( 9, 4, 6,3)/
     x-1.8069326d-01, 7.5968918d-04, 4.9901768d-04 /
      data fpp( 9, 4, 7,1),fpp( 9, 4, 7,2),fpp( 9, 4, 7,3)/
     x-7.4407039d-02, 7.8181595d-04, 5.1769063d-04 /
      data fpp( 9, 4, 8,1),fpp( 9, 4, 8,2),fpp( 9, 4, 8,3)/
     x 6.0461799d-02, 6.0037464d-04, 7.3877853d-06 /
      data fpp( 9, 4, 9,1),fpp( 9, 4, 9,2),fpp( 9, 4, 9,3)/
     x 9.1207505d-02, 5.2314665d-04, 2.0508022d-04 /
      data fpp( 9, 4,10,1),fpp( 9, 4,10,2),fpp( 9, 4,10,3)/
     x-8.3600925d-01, 3.3104658d-04,-1.1027068d-04 /
      data fpp( 9, 4,11,1),fpp( 9, 4,11,2),fpp( 9, 4,11,3)/
     x 2.9431265d-01, 4.9057367d-04, 1.7329051d-04 /
      data fpp( 9, 4,12,1),fpp( 9, 4,12,2),fpp( 9, 4,12,3)/
     x 9.7173020d-02, 4.7440257d-04, 1.3514655d-05 /
      data fpp( 9, 4,13,1),fpp( 9, 4,13,2),fpp( 9, 4,13,3)/
     x 2.7228044d-01, 4.7205274d-04, 1.4115287d-04 /
      data fpp( 9, 4,14,1),fpp( 9, 4,14,2),fpp( 9, 4,14,3)/
     x-3.0524468d-01, 3.7835783d-04,-4.9148144d-05 /
      data fpp( 9, 4,15,1),fpp( 9, 4,15,2),fpp( 9, 4,15,3)/
     x 8.9987716d-02, 5.1314715d-04, 1.5658170d-04 /
      data fpp( 9, 4,16,1),fpp( 9, 4,16,2),fpp( 9, 4,16,3)/
     x 8.1380363d-02, 5.8866413d-04, 8.7525327d-05 /
      data fpp( 9, 4,17,1),fpp( 9, 4,17,2),fpp( 9, 4,17,3)/
     x 4.0423297d-02, 6.6007465d-04, 4.2745099d-04 /
      data fpp( 9, 4,18,1),fpp( 9, 4,18,2),fpp( 9, 4,18,3)/
     x-1.7441891d-01, 7.2091724d-04, 5.1572472d-04 /
      data fpp( 9, 4,19,1),fpp( 9, 4,19,2),fpp( 9, 4,19,3)/
     x-7.9210544d-02,-2.3896055d-03,-8.3360588d-04 /
      data fpp( 9, 4,20,1),fpp( 9, 4,20,2),fpp( 9, 4,20,3)/
     x-6.8573711d-01,-2.3245880d-03,-2.8490922d-04 /
      data fpp( 9, 4,21,1),fpp( 9, 4,21,2),fpp( 9, 4,21,3)/
     x-6.8573711d-01,-2.3245880d-03,-3.6111440d-04 /
      data fpp( 9, 4,22,1),fpp( 9, 4,22,2),fpp( 9, 4,22,3)/
     x-7.9210544d-02,-2.3896055d-03,-5.2878517d-04 /
      data fpp( 9, 4,23,1),fpp( 9, 4,23,2),fpp( 9, 4,23,3)/
     x-1.7441891d-01, 7.2091724d-04,-6.2735291d-04 /
      data fpp( 9, 5, 1,1),fpp( 9, 5, 1,2),fpp( 9, 5, 1,3)/
     x-3.7618006d-01, 8.8036198d-04, 3.1434040d-04 /
      data fpp( 9, 5, 2,1),fpp( 9, 5, 2,2),fpp( 9, 5, 2,3)/
     x-4.9441384d-02, 2.6332175d-03, 1.0519220d-04 /
      data fpp( 9, 5, 3,1),fpp( 9, 5, 3,2),fpp( 9, 5, 3,3)/
     x-1.5534532d-01, 2.3329679d-03,-3.3252119d-04 /
      data fpp( 9, 5, 4,1),fpp( 9, 5, 4,2),fpp( 9, 5, 4,3)/
     x-1.5534532d-01, 2.3329679d-03,-3.5082853d-04 /
      data fpp( 9, 5, 5,1),fpp( 9, 5, 5,2),fpp( 9, 5, 5,3)/
     x-4.9441384d-02, 2.6332175d-03, 1.7842156d-04 /
      data fpp( 9, 5, 6,1),fpp( 9, 5, 6,2),fpp( 9, 5, 6,3)/
     x-3.7618006d-01, 8.8036198d-04, 3.9730284d-05 /
      data fpp( 9, 5, 7,1),fpp( 9, 5, 7,2),fpp( 9, 5, 7,3)/
     x 7.0440871d-03, 2.2542560d-04, 6.6823304d-05 /
      data fpp( 9, 5, 8,1),fpp( 9, 5, 8,2),fpp( 9, 5, 8,3)/
     x 1.3157451d-02, 1.5636670d-04, 4.5014500d-05 /
      data fpp( 9, 5, 9,1),fpp( 9, 5, 9,2),fpp( 9, 5, 9,3)/
     x 1.7188490d-02, 1.5232635d-04, 5.1780696d-05 /
      data fpp( 9, 5,10,1),fpp( 9, 5,10,2),fpp( 9, 5,10,3)/
     x 2.0217276d-02, 2.6866082d-04, 5.2110716d-05 /
      data fpp( 9, 5,11,1),fpp( 9, 5,11,2),fpp( 9, 5,11,3)/
     x 2.2131004d-02, 1.7028509d-04, 5.2706440d-05 /
      data fpp( 9, 5,12,1),fpp( 9, 5,12,2),fpp( 9, 5,12,3)/
     x 2.2890395d-02, 1.7550675d-04, 5.3017524d-05 /
      data fpp( 9, 5,13,1),fpp( 9, 5,13,2),fpp( 9, 5,13,3)/
     x 2.2403439d-02, 1.7244531d-04, 5.4105462d-05 /
      data fpp( 9, 5,14,1),fpp( 9, 5,14,2),fpp( 9, 5,14,3)/
     x 2.1043686d-02, 2.3058978d-04, 5.5352626d-05 /
      data fpp( 9, 5,15,1),fpp( 9, 5,15,2),fpp( 9, 5,15,3)/
     x 1.8462164d-02, 1.4674624d-04, 5.7748034d-05 /
      data fpp( 9, 5,16,1),fpp( 9, 5,16,2),fpp( 9, 5,16,3)/
     x 4.7342662d-02, 1.4557133d-04, 5.5541239d-05 /
      data fpp( 9, 5,17,1),fpp( 9, 5,17,2),fpp( 9, 5,17,3)/
     x 7.6496377d-03, 2.7058195d-04, 8.2577010d-05 /
      data fpp( 9, 5,18,1),fpp( 9, 5,18,2),fpp( 9, 5,18,3)/
     x-1.1708808d-02, 8.3640871d-04, 5.7532722d-05 /
      data fpp( 9, 5,19,1),fpp( 9, 5,19,2),fpp( 9, 5,19,3)/
     x-5.8489388d-02, 2.4684862d-03, 1.7823010d-04 /
      data fpp( 9, 5,20,1),fpp( 9, 5,20,2),fpp( 9, 5,20,3)/
     x-1.5636061d-01, 2.2197567d-03,-3.7771113d-04 /
      data fpp( 9, 5,21,1),fpp( 9, 5,21,2),fpp( 9, 5,21,3)/
     x-1.5636061d-01, 2.2197567d-03,-3.5966667d-04 /
      data fpp( 9, 5,22,1),fpp( 9, 5,22,2),fpp( 9, 5,22,3)/
     x-5.8489388d-02, 2.4684862d-03, 1.0605226d-04 /
      data fpp( 9, 5,23,1),fpp( 9, 5,23,2),fpp( 9, 5,23,3)/
     x-1.1708808d-02, 8.3640871d-04, 3.2819962d-04 /
      data fpp( 9, 6, 1,1),fpp( 9, 6, 1,2),fpp( 9, 6, 1,3)/
     x-2.4457246d-02,-2.2058909d-04, 2.1462582d-05 /
      data fpp( 9, 6, 2,1),fpp( 9, 6, 2,2),fpp( 9, 6, 2,3)/
     x-2.5827511d-03,-6.3533442d-04,-2.7072663d-05 /
      data fpp( 9, 6, 3,1),fpp( 9, 6, 3,2),fpp( 9, 6, 3,3)/
     x 4.4001913d-01,-3.0321995d-04,-1.3092993d-04 /
      data fpp( 9, 6, 4,1),fpp( 9, 6, 4,2),fpp( 9, 6, 4,3)/
     x 4.4001913d-01,-3.0321995d-04,-1.3118688d-04 /
      data fpp( 9, 6, 5,1),fpp( 9, 6, 5,2),fpp( 9, 6, 5,3)/
     x-2.5827511d-03,-6.3533442d-04,-2.6044846d-05 /
      data fpp( 9, 6, 6,1),fpp( 9, 6, 6,2),fpp( 9, 6, 6,3)/
     x-2.4457246d-02,-2.2058909d-04, 1.7608265d-05 /
      data fpp( 9, 6, 7,1),fpp( 9, 6, 7,2),fpp( 9, 6, 7,3)/
     x-1.2531816d-02,-5.8874344d-05, 2.1797785d-05 /
      data fpp( 9, 6, 8,1),fpp( 9, 6, 8,2),fpp( 9, 6, 8,3)/
     x-6.3184332d-03,-2.6801450d-05, 3.2408597d-05 /
      data fpp( 9, 6, 9,1),fpp( 9, 6, 9,2),fpp( 9, 6, 9,3)/
     x-2.7994623d-03,-1.5852047d-05, 3.6733829d-05 /
      data fpp( 9, 6,10,1),fpp( 9, 6,10,2),fpp( 9, 6,10,3)/
     x-5.7799517d-04,-4.3785871d-05, 3.9458087d-05 /
      data fpp( 9, 6,11,1),fpp( 9, 6,11,2),fpp( 9, 6,11,3)/
     x 6.8138627d-04,-1.7530030d-05, 4.0981821d-05 /
      data fpp( 9, 6,12,1),fpp( 9, 6,12,2),fpp( 9, 6,12,3)/
     x 1.0557048d-03,-2.0019579d-05, 4.2062627d-05 /
      data fpp( 9, 6,13,1),fpp( 9, 6,13,2),fpp( 9, 6,13,3)/
     x 1.2831319d-03,-2.0297997d-05, 4.2929671d-05 /
      data fpp( 9, 6,14,1),fpp( 9, 6,14,2),fpp( 9, 6,14,3)/
     x 4.0210253d-04,-3.7170955d-05, 4.3708688d-05 /
      data fpp( 9, 6,15,1),fpp( 9, 6,15,2),fpp( 9, 6,15,3)/
     x-1.2575771d-04,-1.7486107d-05, 4.4711578d-05 /
      data fpp( 9, 6,16,1),fpp( 9, 6,16,2),fpp( 9, 6,16,3)/
     x-3.1248341d-03,-2.3119451d-05, 4.2596999d-05 /
      data fpp( 9, 6,17,1),fpp( 9, 6,17,2),fpp( 9, 6,17,3)/
     x-6.2484661d-03,-6.1892442d-05, 4.3242426d-05 /
      data fpp( 9, 6,18,1),fpp( 9, 6,18,2),fpp( 9, 6,18,3)/
     x-1.3984609d-02,-1.9428408d-04, 1.7221297d-05 /
      data fpp( 9, 6,19,1),fpp( 9, 6,19,2),fpp( 9, 6,19,3)/
     x-2.7812923d-02,-5.6954332d-04, 6.3774385d-05 /
      data fpp( 9, 6,20,1),fpp( 9, 6,20,2),fpp( 9, 6,20,3)/
     x-6.0501905d-02,-4.2003870d-04,-2.0615084d-04 /
      data fpp( 9, 6,21,1),fpp( 9, 6,21,2),fpp( 9, 6,21,3)/
     x-6.0501905d-02,-4.2003870d-04,-1.9796168d-04 /
      data fpp( 9, 6,22,1),fpp( 9, 6,22,2),fpp( 9, 6,22,3)/
     x-2.7812923d-02,-5.6954332d-04, 3.1017766d-05 /
      data fpp( 9, 6,23,1),fpp( 9, 6,23,2),fpp( 9, 6,23,3)/
     x-1.3984609d-02,-1.9428408d-04, 1.4005862d-04 /
      data fpp( 9, 7, 1,1),fpp( 9, 7, 1,2),fpp( 9, 7, 1,3)/
     x-6.2980748d-03, 1.4750368d-05, 1.4280483d-05 /
      data fpp( 9, 7, 2,1),fpp( 9, 7, 2,2),fpp( 9, 7, 2,3)/
     x-5.0986685d-03, 2.1484015d-04,-1.3033967d-05 /
      data fpp( 9, 7, 3,1),fpp( 9, 7, 3,2),fpp( 9, 7, 3,3)/
     x 8.2428114d-03, 2.1008794d-04,-7.0756616d-05 /
      data fpp( 9, 7, 4,1),fpp( 9, 7, 4,2),fpp( 9, 7, 4,3)/
     x 8.2428114d-03, 2.1008794d-04,-7.2171167d-05 /
      data fpp( 9, 7, 5,1),fpp( 9, 7, 5,2),fpp( 9, 7, 5,3)/
     x-5.0986685d-03, 2.1484015d-04,-7.3757631d-06 /
      data fpp( 9, 7, 6,1),fpp( 9, 7, 6,2),fpp( 9, 7, 6,3)/
     x-6.2980748d-03, 1.4750368d-05,-6.9377804d-06 /
      data fpp( 9, 7, 7,1),fpp( 9, 7, 7,2),fpp( 9, 7, 7,3)/
     x-5.2224607d-03,-3.1028223d-05, 3.4408848d-06 /
      data fpp( 9, 7, 8,1),fpp( 9, 7, 8,2),fpp( 9, 7, 8,3)/
     x-5.0559961d-03,-4.8752902d-05, 1.0916241d-05 /
      data fpp( 9, 7, 9,1),fpp( 9, 7, 9,2),fpp( 9, 7, 9,3)/
     x-5.4539846d-03,-5.8744163d-05, 1.8822150d-05 /
      data fpp( 9, 7,10,1),fpp( 9, 7,10,2),fpp( 9, 7,10,3)/
     x-5.9248212d-03,-5.5777339d-05, 2.4951160d-05 /
      data fpp( 9, 7,11,1),fpp( 9, 7,11,2),fpp( 9, 7,11,3)/
     x-6.0497165d-03,-6.5226970d-05, 2.9171210d-05 /
      data fpp( 9, 7,12,1),fpp( 9, 7,12,2),fpp( 9, 7,12,3)/
     x-5.8168390d-03,-6.5140434d-05, 3.1458000d-05 /
      data fpp( 9, 7,13,1),fpp( 9, 7,13,2),fpp( 9, 7,13,3)/
     x-5.2897001d-03,-6.3893327d-05, 3.2160789d-05 /
      data fpp( 9, 7,14,1),fpp( 9, 7,14,2),fpp( 9, 7,14,3)/
     x-4.5222979d-03,-5.5811959d-05, 3.1748843d-05 /
      data fpp( 9, 7,15,1),fpp( 9, 7,15,2),fpp( 9, 7,15,3)/
     x-3.9064253d-03,-5.4001809d-05, 3.0503838d-05 /
      data fpp( 9, 7,16,1),fpp( 9, 7,16,2),fpp( 9, 7,16,3)/
     x-2.7008707d-03,-4.0655527d-05, 2.7585805d-05 /
      data fpp( 9, 7,17,1),fpp( 9, 7,17,2),fpp( 9, 7,17,3)/
     x-1.2932290d-03,-1.2122179d-05, 2.2160943d-05 /
      data fpp( 9, 7,18,1),fpp( 9, 7,18,2),fpp( 9, 7,18,3)/
     x 8.9783426d-04, 5.1823624d-05, 7.7184225d-06 /
      data fpp( 9, 7,19,1),fpp( 9, 7,19,2),fpp( 9, 7,19,3)/
     x 5.5184964d-03, 2.0307108d-04,-1.0086633d-05 /
      data fpp( 9, 7,20,1),fpp( 9, 7,20,2),fpp( 9, 7,20,3)/
     x 1.5635764d-02, 2.7132815d-04,-9.2519890d-05 /
      data fpp( 9, 7,21,1),fpp( 9, 7,21,2),fpp( 9, 7,21,3)/
     x 1.5635764d-02, 2.7132815d-04,-9.1539014d-05 /
      data fpp( 9, 7,22,1),fpp( 9, 7,22,2),fpp( 9, 7,22,3)/
     x 5.5184964d-03, 2.0307108d-04,-1.4010139d-05 /
      data fpp( 9, 7,23,1),fpp( 9, 7,23,2),fpp( 9, 7,23,3)/
     x 8.9783426d-04, 5.1823624d-05, 2.2431569d-05 /
      data fpp( 9, 8, 1,1),fpp( 9, 8, 1,2),fpp( 9, 8, 1,3)/
     x 8.6821840d-03, 8.6821613d-05,-8.5152726d-06 /
      data fpp( 9, 8, 2,1),fpp( 9, 8, 2,2),fpp( 9, 8, 2,3)/
     x 1.1798142d-04,-1.0696020d-04,-1.3103955d-05 /
      data fpp( 9, 8, 3,1),fpp( 9, 8, 3,2),fpp( 9, 8, 3,3)/
     x-5.8637901d-01,-3.1256980d-04,-2.2870908d-05 /
      data fpp( 9, 8, 4,1),fpp( 9, 8, 4,2),fpp( 9, 8, 4,3)/
     x-5.8637901d-01,-3.1256980d-04,-2.2986298d-05 /
      data fpp( 9, 8, 5,1),fpp( 9, 8, 5,2),fpp( 9, 8, 5,3)/
     x 1.1798142d-04,-1.0696020d-04,-1.2642396d-05 /
      data fpp( 9, 8, 6,1),fpp( 9, 8, 6,2),fpp( 9, 8, 6,3)/
     x 8.6821840d-03, 8.6821613d-05,-1.0246116d-05 /
      data fpp( 9, 8, 7,1),fpp( 9, 8, 7,2),fpp( 9, 8, 7,3)/
     x 6.4209865d-03,-1.6650765d-05,-8.9711380d-06 /
      data fpp( 9, 8, 8,1),fpp( 9, 8, 8,2),fpp( 9, 8, 8,3)/
     x 2.8077687d-03,-5.1990941d-05,-4.8873316d-06 /
      data fpp( 9, 8, 9,1),fpp( 9, 8, 9,2),fpp( 9, 8, 9,3)/
     x-8.3407080d-04,-6.5761303d-05, 3.5904643d-06 /
      data fpp( 9, 8,10,1),fpp( 9, 8,10,2),fpp( 9, 8,10,3)/
     x-3.8255483d-03,-7.3940772d-05, 1.2575474d-05 /
      data fpp( 9, 8,11,1),fpp( 9, 8,11,2),fpp( 9, 8,11,3)/
     x-5.4151657d-03,-7.3786089d-05, 1.9013638d-05 /
      data fpp( 9, 8,12,1),fpp( 9, 8,12,2),fpp( 9, 8,12,3)/
     x-6.3733497d-03,-7.2764684d-05, 2.2375973d-05 /
      data fpp( 9, 8,13,1),fpp( 9, 8,13,2),fpp( 9, 8,13,3)/
     x-6.0362408d-03,-6.8858693d-05, 2.3386471d-05 /
      data fpp( 9, 8,14,1),fpp( 9, 8,14,2),fpp( 9, 8,14,3)/
     x-4.7106212d-03,-6.3383208d-05, 2.2600143d-05 /
      data fpp( 9, 8,15,1),fpp( 9, 8,15,2),fpp( 9, 8,15,3)/
     x-3.2984399d-03,-5.1968655d-05, 2.0468955d-05 /
      data fpp( 9, 8,16,1),fpp( 9, 8,16,2),fpp( 9, 8,16,3)/
     x-9.4191378d-04,-3.7542441d-05, 1.6910036d-05 /
      data fpp( 9, 8,17,1),fpp( 9, 8,17,2),fpp( 9, 8,17,3)/
     x 2.0752578d-03,-1.8858840d-05, 1.1430901d-05 /
      data fpp( 9, 8,18,1),fpp( 9, 8,18,2),fpp( 9, 8,18,3)/
     x 6.3815256d-03, 6.6958934d-07, 1.3503592d-06 /
      data fpp( 9, 8,19,1),fpp( 9, 8,19,2),fpp( 9, 8,19,3)/
     x 1.2621370d-02, 7.5969962d-06,-1.3100338d-05 /
      data fpp( 9, 8,20,1),fpp( 9, 8,20,2),fpp( 9, 8,20,3)/
     x 2.0753158d-02, 4.0848117d-05,-4.6287007d-05 /
      data fpp( 9, 8,21,1),fpp( 9, 8,21,2),fpp( 9, 8,21,3)/
     x 2.0753158d-02, 4.0848117d-05,-4.6237810d-05 /
      data fpp( 9, 8,22,1),fpp( 9, 8,22,2),fpp( 9, 8,22,3)/
     x 1.2621370d-02, 7.5969962d-06,-1.3297126d-05 /
      data fpp( 9, 8,23,1),fpp( 9, 8,23,2),fpp( 9, 8,23,3)/
     x 6.3815256d-03, 6.6958934d-07, 2.0883128d-06 /
      data fpp( 9, 9, 1,1),fpp( 9, 9, 1,2),fpp( 9, 9, 1,3)/
     x 2.4872716d-01,-3.9003882d-04,-9.8887931d-05 /
      data fpp( 9, 9, 2,1),fpp( 9, 9, 2,2),fpp( 9, 9, 2,3)/
     x-4.0194162d-02,-2.8852136d-04,-3.6767138d-05 /
      data fpp( 9, 9, 3,1),fpp( 9, 9, 3,2),fpp( 9, 9, 3,3)/
     x-4.1066086d-02,-2.1934740d-05, 9.9880485d-05 /
      data fpp( 9, 9, 4,1),fpp( 9, 9, 4,2),fpp( 9, 9, 4,3)/
     x-4.1066086d-02,-2.1934740d-05, 9.3700116d-05 /
      data fpp( 9, 9, 5,1),fpp( 9, 9, 5,2),fpp( 9, 9, 5,3)/
     x-4.0194162d-02,-2.8852136d-04,-1.2045663d-05 /
      data fpp( 9, 9, 6,1),fpp( 9, 9, 6,2),fpp( 9, 9, 6,3)/
     x 2.4872716d-01,-3.9003882d-04,-1.9159346d-04 /
      data fpp( 9, 9, 7,1),fpp( 9, 9, 7,2),fpp( 9, 9, 7,3)/
     x 3.0467848d-02,-1.0414872d-04, 3.7611519d-05 /
      data fpp( 9, 9, 8,1),fpp( 9, 9, 8,2),fpp( 9, 9, 8,3)/
     x 1.7937620d-02,-6.4343336d-05,-2.4132613d-05 /
      data fpp( 9, 9, 9,1),fpp( 9, 9, 9,2),fpp( 9, 9, 9,3)/
     x 1.0528812d-02,-6.4166627d-05,-2.4850661d-06 /
      data fpp( 9, 9,10,1),fpp( 9, 9,10,2),fpp( 9, 9,10,3)/
     x 4.4040628d-03,-6.3785572d-05, 2.5428777d-06 /
      data fpp( 9, 9,11,1),fpp( 9, 9,11,2),fpp( 9, 9,11,3)/
     x 4.3821132d-05,-6.3114672d-05, 1.1537555d-05 /
      data fpp( 9, 9,12,1),fpp( 9, 9,12,2),fpp( 9, 9,12,3)/
     x-1.9448565d-03,-6.0038830d-05, 1.5632901d-05 /
      data fpp( 9, 9,13,1),fpp( 9, 9,13,2),fpp( 9, 9,13,3)/
     x-2.7233042d-03,-5.5075899d-05, 1.7160841d-05 /
      data fpp( 9, 9,14,1),fpp( 9, 9,14,2),fpp( 9, 9,14,3)/
     x-2.0077222d-03,-4.7601208d-05, 1.6541733d-05 /
      data fpp( 9, 9,15,1),fpp( 9, 9,15,2),fpp( 9, 9,15,3)/
     x-7.8564649d-04,-3.8279571d-05, 1.4856225d-05 /
      data fpp( 9, 9,16,1),fpp( 9, 9,16,2),fpp( 9, 9,16,3)/
     x 1.3541743d-03,-2.5942711d-05, 1.2053366d-05 /
      data fpp( 9, 9,17,1),fpp( 9, 9,17,2),fpp( 9, 9,17,3)/
     x 4.1106400d-03,-1.0716459d-05, 8.1083095d-06 /
      data fpp( 9, 9,18,1),fpp( 9, 9,18,2),fpp( 9, 9,18,3)/
     x 8.0400863d-03, 7.6220191d-06, 1.4373957d-06 /
      data fpp( 9, 9,19,1),fpp( 9, 9,19,2),fpp( 9, 9,19,3)/
     x 1.3963254d-02, 3.0612934d-05,-7.7918922d-06 /
      data fpp( 9, 9,20,1),fpp( 9, 9,20,2),fpp( 9, 9,20,3)/
     x 2.1507750d-02, 4.3065386d-05,-2.8031827d-05 /
      data fpp( 9, 9,21,1),fpp( 9, 9,21,2),fpp( 9, 9,21,3)/
     x 2.1507750d-02, 4.3065386d-05,-2.8021573d-05 /
      data fpp( 9, 9,22,1),fpp( 9, 9,22,2),fpp( 9, 9,22,3)/
     x 1.3963254d-02, 3.0612934d-05,-7.8329077d-06 /
      data fpp( 9, 9,23,1),fpp( 9, 9,23,2),fpp( 9, 9,23,3)/
     x 8.0400863d-03, 7.6220191d-06, 1.5912038d-06 /
      data fpp( 9,10, 1,1),fpp( 9,10, 1,2),fpp( 9,10, 1,3)/
     x-9.3033556d-02, 1.4016724d-06, 1.9727144d-05 /
      data fpp( 9,10, 2,1),fpp( 9,10, 2,2),fpp( 9,10, 2,3)/
     x-3.8085274d-02, 8.6239644d-05, 4.6166712d-05 /
      data fpp( 9,10, 3,1),fpp( 9,10, 3,2),fpp( 9,10, 3,3)/
     x-2.2256548d-02, 4.0866758d-05, 1.0549401d-04 /
      data fpp( 9,10, 4,1),fpp( 9,10, 4,2),fpp( 9,10, 4,3)/
     x-2.2256548d-02, 4.0866758d-05, 1.0081962d-04 /
      data fpp( 9,10, 5,1),fpp( 9,10, 5,2),fpp( 9,10, 5,3)/
     x-3.8085274d-02, 8.6239644d-05, 6.4864289d-05 /
      data fpp( 9,10, 6,1),fpp( 9,10, 6,2),fpp( 9,10, 6,3)/
     x-9.3033556d-02, 1.4016724d-06,-5.0388771d-05 /
      data fpp( 9,10, 7,1),fpp( 9,10, 7,2),fpp( 9,10, 7,3)/
     x-6.8843417d-02,-2.0954037d-04,-1.5605520d-04 /
      data fpp( 9,10, 8,1),fpp( 9,10, 8,2),fpp( 9,10, 8,3)/
     x 2.5243368d-02,-1.2232972d-04,-2.2986411d-05 /
      data fpp( 9,10, 9,1),fpp( 9,10, 9,2),fpp( 9,10, 9,3)/
     x 2.4851419d-02,-7.0050189d-05,-2.1753152d-05 /
      data fpp( 9,10,10,1),fpp( 9,10,10,2),fpp( 9,10,10,3)/
     x 1.6559844d-02,-5.3512939d-05,-4.4449802d-06 /
      data fpp( 9,10,11,1),fpp( 9,10,11,2),fpp( 9,10,11,3)/
     x 9.0514704d-03,-4.6709222d-05, 4.8350729d-06 /
      data fpp( 9,10,12,1),fpp( 9,10,12,2),fpp( 9,10,12,3)/
     x 4.8915468d-03,-4.2291995d-05, 1.0850689d-05 /
      data fpp( 9,10,13,1),fpp( 9,10,13,2),fpp( 9,10,13,3)/
     x 3.4765684d-03,-3.7693711d-05, 1.2932173d-05 /
      data fpp( 9,10,14,1),fpp( 9,10,14,2),fpp( 9,10,14,3)/
     x 2.3144903d-03,-3.2267959d-05, 1.2978621d-05 /
      data fpp( 9,10,15,1),fpp( 9,10,15,2),fpp( 9,10,15,3)/
     x 3.2687999d-03,-2.5481063d-05, 1.1953345d-05 /
      data fpp( 9,10,16,1),fpp( 9,10,16,2),fpp( 9,10,16,3)/
     x 4.3742683d-03,-1.7596717d-05, 1.0032001d-05 /
      data fpp( 9,10,17,1),fpp( 9,10,17,2),fpp( 9,10,17,3)/
     x 6.1515250d-03,-9.2313251d-06, 7.0306511d-06 /
      data fpp( 9,10,18,1),fpp( 9,10,18,2),fpp( 9,10,18,3)/
     x 8.9390950d-03,-1.7096657d-06, 2.1593947d-06 /
      data fpp( 9,10,19,1),fpp( 9,10,19,2),fpp( 9,10,19,3)/
     x 1.4504393d-02, 3.2112696d-06,-3.8602298d-06 /
      data fpp( 9,10,20,1),fpp( 9,10,20,2),fpp( 9,10,20,3)/
     x 2.2581454d-02, 8.2243374d-06,-2.0642476d-05 /
      data fpp( 9,10,21,1),fpp( 9,10,21,2),fpp( 9,10,21,3)/
     x 2.2581454d-02, 8.2243374d-06,-2.0556459d-05 /
      data fpp( 9,10,22,1),fpp( 9,10,22,2),fpp( 9,10,22,3)/
     x 1.4504393d-02, 3.2112696d-06,-4.2042976d-06 /
      data fpp( 9,10,23,1),fpp( 9,10,23,2),fpp( 9,10,23,3)/
     x 8.9390950d-03,-1.7096657d-06, 3.4496488d-06 /
      data fpp( 9,11, 1,1),fpp( 9,11, 1,2),fpp( 9,11, 1,3)/
     x-5.7523616d-02, 6.2508132d-05, 6.3076564d-05 /
      data fpp( 9,11, 2,1),fpp( 9,11, 2,2),fpp( 9,11, 2,3)/
     x-1.3623211d-02, 1.0490279d-04, 7.3229872d-05 /
      data fpp( 9,11, 3,1),fpp( 9,11, 3,2),fpp( 9,11, 3,3)/
     x 2.4407654d-02, 1.9003971d-04, 9.6823947d-05 /
      data fpp( 9,11, 4,1),fpp( 9,11, 4,2),fpp( 9,11, 4,3)/
     x 2.4407654d-02, 1.9003971d-04, 9.3609223d-05 /
      data fpp( 9,11, 5,1),fpp( 9,11, 5,2),fpp( 9,11, 5,3)/
     x-1.3623211d-02, 1.0490279d-04, 8.6088768d-05 /
      data fpp( 9,11, 6,1),fpp( 9,11, 6,2),fpp( 9,11, 6,3)/
     x-5.7523616d-02, 6.2508132d-05, 1.4855707d-05 /
      data fpp( 9,11, 7,1),fpp( 9,11, 7,2),fpp( 9,11, 7,3)/
     x-8.5235503d-02, 3.6952190d-05,-9.0365594d-05 /
      data fpp( 9,11, 8,1),fpp( 9,11, 8,2),fpp( 9,11, 8,3)/
     x-2.8606131d-02,-5.7341797d-05,-1.0551733d-04 /
      data fpp( 9,11, 9,1),fpp( 9,11, 9,2),fpp( 9,11, 9,3)/
     x 2.1464747d-02,-5.6312616d-05,-4.9699085d-05 /
      data fpp( 9,11,10,1),fpp( 9,11,10,2),fpp( 9,11,10,3)/
     x 2.5239087d-02,-4.0240673d-05,-2.0766331d-05 /
      data fpp( 9,11,11,1),fpp( 9,11,11,2),fpp( 9,11,11,3)/
     x 1.8831239d-02,-3.2036439d-05,-2.3675919d-06 /
      data fpp( 9,11,12,1),fpp( 9,11,12,2),fpp( 9,11,12,3)/
     x 1.3498080d-02,-2.7767190d-05, 6.3266986d-06 /
      data fpp( 9,11,13,1),fpp( 9,11,13,2),fpp( 9,11,13,3)/
     x 1.0303614d-02,-2.4471255d-05, 9.8087977d-06 /
      data fpp( 9,11,14,1),fpp( 9,11,14,2),fpp( 9,11,14,3)/
     x 8.2280390d-03,-2.1032957d-05, 1.0700111d-05 /
      data fpp( 9,11,15,1),fpp( 9,11,15,2),fpp( 9,11,15,3)/
     x 8.2577210d-03,-1.7284178d-05, 1.0408759d-05 /
      data fpp( 9,11,16,1),fpp( 9,11,16,2),fpp( 9,11,16,3)/
     x 8.4711015d-03,-1.3392422d-05, 8.8408513d-06 /
      data fpp( 9,11,17,1),fpp( 9,11,17,2),fpp( 9,11,17,3)/
     x 9.1331142d-03,-9.7422412d-06, 5.8458352d-06 /
      data fpp( 9,11,18,1),fpp( 9,11,18,2),fpp( 9,11,18,3)/
     x 1.0998987d-02,-6.5133561d-06, 1.7958080d-06 /
      data fpp( 9,11,19,1),fpp( 9,11,19,2),fpp( 9,11,19,3)/
     x 1.6408532d-02,-3.8460119d-06,-1.7910672d-06 /
      data fpp( 9,11,20,1),fpp( 9,11,20,2),fpp( 9,11,20,3)/
     x 2.5324526d-02,-3.4287362d-06,-1.7137539d-05 /
      data fpp( 9,11,21,1),fpp( 9,11,21,2),fpp( 9,11,21,3)/
     x 2.5324526d-02,-3.4287362d-06,-1.6967849d-05 /
      data fpp( 9,11,22,1),fpp( 9,11,22,2),fpp( 9,11,22,3)/
     x 1.6408532d-02,-3.8460119d-06,-2.4698289d-06 /
      data fpp( 9,11,23,1),fpp( 9,11,23,2),fpp( 9,11,23,3)/
     x 1.0998987d-02,-6.5133561d-06, 4.3411645d-06 /
      data fpp( 9,12, 1,1),fpp( 9,12, 1,2),fpp( 9,12, 1,3)/
     x-2.7890551d-02, 1.0213380d-04, 1.4129478d-04 /
      data fpp( 9,12, 2,1),fpp( 9,12, 2,2),fpp( 9,12, 2,3)/
     x 5.1534768d-02, 1.5768321d-04, 1.0980443d-04 /
      data fpp( 9,12, 3,1),fpp( 9,12, 3,2),fpp( 9,12, 3,3)/
     x 1.5553015d-01, 2.0257041d-04, 4.5335491d-05 /
      data fpp( 9,12, 4,1),fpp( 9,12, 4,2),fpp( 9,12, 4,3)/
     x 1.5553015d-01, 2.0257041d-04, 4.0067311d-05 /
      data fpp( 9,12, 5,1),fpp( 9,12, 5,2),fpp( 9,12, 5,3)/
     x 5.1534768d-02, 1.5768321d-04, 1.3087715d-04 /
      data fpp( 9,12, 6,1),fpp( 9,12, 6,2),fpp( 9,12, 6,3)/
     x-2.7890551d-02, 1.0213380d-04, 6.2272079d-05 /
      data fpp( 9,12, 7,1),fpp( 9,12, 7,2),fpp( 9,12, 7,3)/
     x-7.1400572d-02, 4.9641607d-05,-3.2619468d-05 /
      data fpp( 9,12, 8,1),fpp( 9,12, 8,2),fpp( 9,12, 8,3)/
     x-6.2114485d-02, 1.5762903d-05,-9.6632205d-05 /
      data fpp( 9,12, 9,1),fpp( 9,12, 9,2),fpp( 9,12, 9,3)/
     x-7.0123067d-03,-1.5511345d-05,-8.6399711d-05 /
      data fpp( 9,12,10,1),fpp( 9,12,10,2),fpp( 9,12,10,3)/
     x 2.2462976d-02,-2.0538371d-05,-4.2808951d-05 /
      data fpp( 9,12,11,1),fpp( 9,12,11,2),fpp( 9,12,11,3)/
     x 2.3678541d-02,-1.8981020d-05,-1.2550485d-05 /
      data fpp( 9,12,12,1),fpp( 9,12,12,2),fpp( 9,12,12,3)/
     x 1.9403251d-02,-1.7285245d-05, 1.4568905d-06 /
      data fpp( 9,12,13,1),fpp( 9,12,13,2),fpp( 9,12,13,3)/
     x 1.6094560d-02,-1.5951267d-05, 6.9749227d-06 /
      data fpp( 9,12,14,1),fpp( 9,12,14,2),fpp( 9,12,14,3)/
     x 1.3801329d-02,-1.4724213d-05, 8.8994186d-06 /
      data fpp( 9,12,15,1),fpp( 9,12,15,2),fpp( 9,12,15,3)/
     x 1.3598501d-02,-1.3658225d-05, 9.1054028d-06 /
      data fpp( 9,12,16,1),fpp( 9,12,16,2),fpp( 9,12,16,3)/
     x 1.3595976d-02,-1.2965593d-05, 7.5029701d-06 /
      data fpp( 9,12,17,1),fpp( 9,12,17,2),fpp( 9,12,17,3)/
     x 1.3947562d-02,-1.2555710d-05, 4.2387167d-06 /
      data fpp( 9,12,18,1),fpp( 9,12,18,2),fpp( 9,12,18,3)/
     x 1.5542751d-02,-1.2130910d-05, 7.5416322d-07 /
      data fpp( 9,12,19,1),fpp( 9,12,19,2),fpp( 9,12,19,3)/
     x 2.1265015d-02,-1.2145222d-05,-1.8733696d-06 /
      data fpp( 9,12,20,1),fpp( 9,12,20,2),fpp( 9,12,20,3)/
     x 3.5041870d-02,-1.2971393d-05,-1.4068685d-05 /
      data fpp( 9,12,21,1),fpp( 9,12,21,2),fpp( 9,12,21,3)/
     x 3.5041870d-02,-1.2971393d-05,-1.3923260d-05 /
      data fpp( 9,12,22,1),fpp( 9,12,22,2),fpp( 9,12,22,3)/
     x 2.1265015d-02,-1.2145222d-05,-2.4550685d-06 /
      data fpp( 9,12,23,1),fpp( 9,12,23,2),fpp( 9,12,23,3)/
     x 1.5542751d-02,-1.2130910d-05, 2.9355342d-06 /
      data fpp( 9,13, 1,1),fpp( 9,13, 1,2),fpp( 9,13, 1,3)/
     x 1.1028698d-02, 7.4512667d-05, 2.1735407d-04 /
      data fpp( 9,13, 2,1),fpp( 9,13, 2,2),fpp( 9,13, 2,3)/
     x 1.4513551d-01, 2.0796361d-05, 1.3886186d-04 /
      data fpp( 9,13, 3,1),fpp( 9,13, 3,2),fpp( 9,13, 3,3)/
     x 3.3898345d-01,-8.4265365d-05,-2.5177518d-05 /
      data fpp( 9,13, 4,1),fpp( 9,13, 4,2),fpp( 9,13, 4,3)/
     x 3.3898345d-01,-8.4265365d-05,-3.2454378d-05 /
      data fpp( 9,13, 5,1),fpp( 9,13, 5,2),fpp( 9,13, 5,3)/
     x 1.4513551d-01, 2.0796361d-05, 1.6796931d-04 /
      data fpp( 9,13, 6,1),fpp( 9,13, 6,2),fpp( 9,13, 6,3)/
     x 1.1028698d-02, 7.4512667d-05, 1.0820116d-04 /
      data fpp( 9,13, 7,1),fpp( 9,13, 7,2),fpp( 9,13, 7,3)/
     x-5.3990682d-02, 7.4177383d-05, 1.3788065d-05 /
      data fpp( 9,13, 8,1),fpp( 9,13, 8,2),fpp( 9,13, 8,3)/
     x-7.0858862d-02, 4.3904183d-05,-6.5127416d-05 /
      data fpp( 9,13, 9,1),fpp( 9,13, 9,2),fpp( 9,13, 9,3)/
     x-3.7436164d-02, 1.4815998d-05,-9.5314400d-05 /
      data fpp( 9,13,10,1),fpp( 9,13,10,2),fpp( 9,13,10,3)/
     x 8.6238119d-03,-4.2584283d-07,-6.4736984d-05 /
      data fpp( 9,13,11,1),fpp( 9,13,11,2),fpp( 9,13,11,3)/
     x 2.3009325d-02,-5.9374793d-06,-2.2777665d-05 /
      data fpp( 9,13,12,1),fpp( 9,13,12,2),fpp( 9,13,12,3)/
     x 2.2370279d-02,-8.3798313d-06,-3.6623554d-06 /
      data fpp( 9,13,13,1),fpp( 9,13,13,2),fpp( 9,13,13,3)/
     x 2.0095806d-02,-9.3916751d-06, 4.1930870d-06 /
      data fpp( 9,13,14,1),fpp( 9,13,14,2),fpp( 9,13,14,3)/
     x 1.8379433d-02,-1.0238190d-05, 7.0200076d-06 /
      data fpp( 9,13,15,1),fpp( 9,13,15,2),fpp( 9,13,15,3)/
     x 1.8372075d-02,-1.1338921d-05, 7.4768826d-06 /
      data fpp( 9,13,16,1),fpp( 9,13,16,2),fpp( 9,13,16,3)/
     x 1.8649136d-02,-1.2769204d-05, 5.8644619d-06 /
      data fpp( 9,13,17,1),fpp( 9,13,17,2),fpp( 9,13,17,3)/
     x 1.9393977d-02,-1.4254918d-05, 2.7312699d-06 /
      data fpp( 9,13,18,1),fpp( 9,13,18,2),fpp( 9,13,18,3)/
     x 2.1288447d-02,-1.5421005d-05,-4.2754141d-07 /
      data fpp( 9,13,19,1),fpp( 9,13,19,2),fpp( 9,13,19,3)/
     x 2.6357522d-02,-1.5967100d-05,-3.1931042d-06 /
      data fpp( 9,13,20,1),fpp( 9,13,20,2),fpp( 9,13,20,3)/
     x 3.7412008d-02,-1.5611693d-05,-1.0506042d-05 /
      data fpp( 9,13,21,1),fpp( 9,13,21,2),fpp( 9,13,21,3)/
     x 3.7412008d-02,-1.5611693d-05,-1.0475323d-05 /
      data fpp( 9,13,22,1),fpp( 9,13,22,2),fpp( 9,13,22,3)/
     x 2.6357522d-02,-1.5967100d-05,-3.3159792d-06 /
      data fpp( 9,13,23,1),fpp( 9,13,23,2),fpp( 9,13,23,3)/
     x 2.1288447d-02,-1.5421005d-05, 3.3239583d-08 /
      data fpp( 9,14, 1,1),fpp( 9,14, 1,2),fpp( 9,14, 1,3)/
     x 3.2218005d-02, 5.6259531d-05, 1.8998022d-04 /
      data fpp( 9,14, 2,1),fpp( 9,14, 2,2),fpp( 9,14, 2,3)/
     x 1.6673672d-01,-1.3150657d-05, 1.1834756d-04 /
      data fpp( 9,14, 3,1),fpp( 9,14, 3,2),fpp( 9,14, 3,3)/
     x 3.4882640d-01,-1.0468096d-04,-3.2134447d-05 /
      data fpp( 9,14, 4,1),fpp( 9,14, 4,2),fpp( 9,14, 4,3)/
     x 3.4882640d-01,-1.0468096d-04,-3.7413437d-05 /
      data fpp( 9,14, 5,1),fpp( 9,14, 5,2),fpp( 9,14, 5,3)/
     x 1.6673672d-01,-1.3150657d-05, 1.3946352d-04 /
      data fpp( 9,14, 6,1),fpp( 9,14, 6,2),fpp( 9,14, 6,3)/
     x 3.2218005d-02, 5.6259531d-05, 1.1079537d-04 /
      data fpp( 9,14, 7,1),fpp( 9,14, 7,2),fpp( 9,14, 7,3)/
     x-3.8210923d-02, 7.7080863d-05, 3.7394994d-05 /
      data fpp( 9,14, 8,1),fpp( 9,14, 8,2),fpp( 9,14, 8,3)/
     x-6.7967381d-02, 6.3806366d-05,-3.4319348d-05 /
      data fpp( 9,14, 9,1),fpp( 9,14, 9,2),fpp( 9,14, 9,3)/
     x-5.9622539d-02, 3.7787354d-05,-8.4041604d-05 /
      data fpp( 9,14,10,1),fpp( 9,14,10,2),fpp( 9,14,10,3)/
     x-1.2449960d-02, 1.7849742d-05,-7.9004238d-05 /
      data fpp( 9,14,11,1),fpp( 9,14,11,2),fpp( 9,14,11,3)/
     x 1.7834233d-02, 5.6509375d-06,-3.0591445d-05 /
      data fpp( 9,14,12,1),fpp( 9,14,12,2),fpp( 9,14,12,3)/
     x 2.2383783d-02,-2.5543010d-07,-7.3879809d-06 /
      data fpp( 9,14,13,1),fpp( 9,14,13,2),fpp( 9,14,13,3)/
     x 2.2121842d-02,-3.4280323d-06, 1.5173690d-06 /
      data fpp( 9,14,14,1),fpp( 9,14,14,2),fpp( 9,14,14,3)/
     x 2.1530216d-02,-5.5470260d-06, 4.9305050d-06 /
      data fpp( 9,14,15,1),fpp( 9,14,15,2),fpp( 9,14,15,3)/
     x 2.1589639d-02,-7.5740899d-06, 5.4966111d-06 /
      data fpp( 9,14,16,1),fpp( 9,14,16,2),fpp( 9,14,16,3)/
     x 2.2095138d-02,-9.6075908d-06, 4.1450508d-06 /
      data fpp( 9,14,17,1),fpp( 9,14,17,2),fpp( 9,14,17,3)/
     x 2.3088637d-02,-1.1454619d-05, 1.5811857d-06 /
      data fpp( 9,14,18,1),fpp( 9,14,18,2),fpp( 9,14,18,3)/
     x 2.4721641d-02,-1.2825071d-05,-1.1877937d-06 /
      data fpp( 9,14,19,1),fpp( 9,14,19,2),fpp( 9,14,19,3)/
     x 2.7695867d-02,-1.3314379d-05,-3.6340108d-06 /
      data fpp( 9,14,20,1),fpp( 9,14,20,2),fpp( 9,14,20,3)/
     x 3.1448910d-02,-1.2907835d-05,-7.1901631d-06 /
      data fpp( 9,14,21,1),fpp( 9,14,21,2),fpp( 9,14,21,3)/
     x 3.1448910d-02,-1.2907835d-05,-7.2275054d-06 /
      data fpp( 9,14,22,1),fpp( 9,14,22,2),fpp( 9,14,22,3)/
     x 2.7695867d-02,-1.3314379d-05,-3.4846413d-06 /
      data fpp( 9,14,23,1),fpp( 9,14,23,2),fpp( 9,14,23,3)/
     x 2.4721641d-02,-1.2825071d-05,-1.7479293d-06 /
      data fpp( 9,15, 1,1),fpp( 9,15, 1,2),fpp( 9,15, 1,3)/
     x 1.4867307d-02, 1.1359121d-04, 9.8202183d-05 /
      data fpp( 9,15, 2,1),fpp( 9,15, 2,2),fpp( 9,15, 2,3)/
     x 8.7347449d-02, 1.4526627d-04, 7.1595134d-05 /
      data fpp( 9,15, 3,1),fpp( 9,15, 3,2),fpp( 9,15, 3,3)/
     x 1.7143887d-01, 2.0211319d-04, 1.5611282d-05 /
      data fpp( 9,15, 4,1),fpp( 9,15, 4,2),fpp( 9,15, 4,3)/
     x 1.7143887d-01, 2.0211319d-04, 1.3806586d-05 /
      data fpp( 9,15, 5,1),fpp( 9,15, 5,2),fpp( 9,15, 5,3)/
     x 8.7347449d-02, 1.4526627d-04, 7.8813919d-05 /
      data fpp( 9,15, 6,1),fpp( 9,15, 6,2),fpp( 9,15, 6,3)/
     x 1.4867307d-02, 1.1359121d-04, 7.1131738d-05 /
      data fpp( 9,15, 7,1),fpp( 9,15, 7,2),fpp( 9,15, 7,3)/
     x-3.2988672d-02, 1.0043317d-04, 3.2287130d-05 /
      data fpp( 9,15, 8,1),fpp( 9,15, 8,2),fpp( 9,15, 8,3)/
     x-6.2600062d-02, 8.4504355d-05,-1.5486259d-05 /
      data fpp( 9,15, 9,1),fpp( 9,15, 9,2),fpp( 9,15, 9,3)/
     x-7.1764444d-02, 5.2884588d-05,-6.1638096d-05 /
      data fpp( 9,15,10,1),fpp( 9,15,10,2),fpp( 9,15,10,3)/
     x-4.0417078d-02, 2.5800873d-05,-8.3111359d-05 /
      data fpp( 9,15,11,1),fpp( 9,15,11,2),fpp( 9,15,11,3)/
     x 9.3008511d-03, 1.4437729d-05,-3.3770469d-05 /
      data fpp( 9,15,12,1),fpp( 9,15,12,2),fpp( 9,15,12,3)/
     x 2.1109729d-02, 6.2755517d-06,-8.3727668d-06 /
      data fpp( 9,15,13,1),fpp( 9,15,13,2),fpp( 9,15,13,3)/
     x 2.2680373d-02, 2.1518042d-06,-3.5246427d-07 /
      data fpp( 9,15,14,1),fpp( 9,15,14,2),fpp( 9,15,14,3)/
     x 2.2752185d-02,-3.4570574d-07, 2.8826239d-06 /
      data fpp( 9,15,15,1),fpp( 9,15,15,2),fpp( 9,15,15,3)/
     x 2.3125145d-02,-2.0087190d-06, 3.4919688d-06 /
      data fpp( 9,15,16,1),fpp( 9,15,16,2),fpp( 9,15,16,3)/
     x 2.3651522d-02,-3.1904329d-06, 2.6075008d-06 /
      data fpp( 9,15,17,1),fpp( 9,15,17,2),fpp( 9,15,17,3)/
     x 2.4416702d-02,-3.9346047d-06, 8.5602800d-07 /
      data fpp( 9,15,18,1),fpp( 9,15,18,2),fpp( 9,15,18,3)/
     x 2.5408214d-02,-4.2347102d-06,-1.1596128d-06 /
      data fpp( 9,15,19,1),fpp( 9,15,19,2),fpp( 9,15,19,3)/
     x 2.6574983d-02,-3.9273847d-06,-2.9015768d-06 /
      data fpp( 9,15,20,1),fpp( 9,15,20,2),fpp( 9,15,20,3)/
     x 2.7754496d-02,-3.1309669d-06,-4.3820798d-06 /
      data fpp( 9,15,21,1),fpp( 9,15,21,2),fpp( 9,15,21,3)/
     x 2.7754496d-02,-3.1309669d-06,-4.4319721d-06 /
      data fpp( 9,15,22,1),fpp( 9,15,22,2),fpp( 9,15,22,3)/
     x 2.6574983d-02,-3.9273847d-06,-2.7020080d-06 /
      data fpp( 9,15,23,1),fpp( 9,15,23,2),fpp( 9,15,23,3)/
     x 2.5408214d-02,-4.2347102d-06,-1.9079960d-06 /
      data fpp( 9,16, 1,1),fpp( 9,16, 1,2),fpp( 9,16, 1,3)/
     x-1.3957412d-02, 1.0627763d-04, 4.4348918d-05 /
      data fpp( 9,16, 2,1),fpp( 9,16, 2,2),fpp( 9,16, 2,3)/
     x 1.0214060d-02, 1.4805359d-04, 4.2498664d-05 /
      data fpp( 9,16, 3,1),fpp( 9,16, 3,2),fpp( 9,16, 3,3)/
     x 3.2033697d-02, 1.9525621d-04, 3.8802426d-05 /
      data fpp( 9,16, 4,1),fpp( 9,16, 4,2),fpp( 9,16, 4,3)/
     x 3.2033697d-02, 1.9525621d-04, 3.8332389d-05 /
      data fpp( 9,16, 5,1),fpp( 9,16, 5,2),fpp( 9,16, 5,3)/
     x 1.0214060d-02, 1.4805359d-04, 4.4378813d-05 /
      data fpp( 9,16, 6,1),fpp( 9,16, 6,2),fpp( 9,16, 6,3)/
     x-1.3957412d-02, 1.0627763d-04, 3.7298357d-05 /
      data fpp( 9,16, 7,1),fpp( 9,16, 7,2),fpp( 9,16, 7,3)/
     x-3.5904332d-02, 8.0944471d-05, 1.9565757d-05 /
      data fpp( 9,16, 8,1),fpp( 9,16, 8,2),fpp( 9,16, 8,3)/
     x-5.8573653d-02, 6.5702214d-05,-7.1173842d-06 /
      data fpp( 9,16, 9,1),fpp( 9,16, 9,2),fpp( 9,16, 9,3)/
     x-7.6365687d-02, 7.6216296d-05,-3.9516220d-05 /
      data fpp( 9,16,10,1),fpp( 9,16,10,2),fpp( 9,16,10,3)/
     x-1.0698103d-01, 6.0302766d-05,-7.7829737d-05 /
      data fpp( 9,16,11,1),fpp( 9,16,11,2),fpp( 9,16,11,3)/
     x 8.0946788d-04, 2.0148145d-05,-2.7842833d-05 /
      data fpp( 9,16,12,1),fpp( 9,16,12,2),fpp( 9,16,12,3)/
     x 1.9018437d-02, 1.0283223d-05,-5.7869311d-06 /
      data fpp( 9,16,13,1),fpp( 9,16,13,2),fpp( 9,16,13,3)/
     x 2.2424205d-02, 6.2688154d-06,-8.7344262d-07 /
      data fpp( 9,16,14,1),fpp( 9,16,14,2),fpp( 9,16,14,3)/
     x 2.3164493d-02, 4.3738490d-06, 1.5467016d-06 /
      data fpp( 9,16,15,1),fpp( 9,16,15,2),fpp( 9,16,15,3)/
     x 2.3564273d-02, 3.6689659d-06, 1.9106363d-06 /
      data fpp( 9,16,16,1),fpp( 9,16,16,2),fpp( 9,16,16,3)/
     x 2.3970331d-02, 3.8773222d-06, 1.4967531d-06 /
      data fpp( 9,16,17,1),fpp( 9,16,17,2),fpp( 9,16,17,3)/
     x 2.4394032d-02, 4.6750384d-06, 5.2635138d-07 /
      data fpp( 9,16,18,1),fpp( 9,16,18,2),fpp( 9,16,18,3)/
     x 2.4937564d-02, 5.7879120d-06,-5.7215858d-07 /
      data fpp( 9,16,19,1),fpp( 9,16,19,2),fpp( 9,16,19,3)/
     x 2.5340729d-02, 6.8779175d-06,-1.5137171d-06 /
      data fpp( 9,16,20,1),fpp( 9,16,20,2),fpp( 9,16,20,3)/
     x 2.5691224d-02, 7.6597025d-06,-2.2109732d-06 /
      data fpp( 9,16,21,1),fpp( 9,16,21,2),fpp( 9,16,21,3)/
     x 2.5691224d-02, 7.6597025d-06,-2.2402219d-06 /
      data fpp( 9,16,22,1),fpp( 9,16,22,2),fpp( 9,16,22,3)/
     x 2.5340729d-02, 6.8779175d-06,-1.3967223d-06 /
      data fpp( 9,16,23,1),fpp( 9,16,23,2),fpp( 9,16,23,3)/
     x 2.4937564d-02, 5.7879120d-06,-1.0108888d-06 /
      data fpp( 9,17, 1,1),fpp( 9,17, 1,2),fpp( 9,17, 1,3)/
     x-3.3208610d-02, 1.1963625d-04, 2.3198346d-05 /
      data fpp( 9,17, 2,1),fpp( 9,17, 2,2),fpp( 9,17, 2,3)/
     x-2.5537451d-02, 1.2390938d-04, 2.5167809d-05 /
      data fpp( 9,17, 3,1),fpp( 9,17, 3,2),fpp( 9,17, 3,3)/
     x-2.1201249d-02, 1.2857198d-04, 2.9496419d-05 /
      data fpp( 9,17, 4,1),fpp( 9,17, 4,2),fpp( 9,17, 4,3)/
     x-2.1201249d-02, 1.2857198d-04, 2.9306837d-05 /
      data fpp( 9,17, 5,1),fpp( 9,17, 5,2),fpp( 9,17, 5,3)/
     x-2.5537451d-02, 1.2390938d-04, 2.5926138d-05 /
      data fpp( 9,17, 6,1),fpp( 9,17, 6,2),fpp( 9,17, 6,3)/
     x-3.3208610d-02, 1.1963625d-04, 2.0354611d-05 /
      data fpp( 9,17, 7,1),fpp( 9,17, 7,2),fpp( 9,17, 7,3)/
     x-3.8507486d-02, 1.1841695d-04, 1.0645417d-05 /
      data fpp( 9,17, 8,1),fpp( 9,17, 8,2),fpp( 9,17, 8,3)/
     x-7.8146290d-02, 1.1714679d-04, 6.6997225d-06 /
      data fpp( 9,17, 9,1),fpp( 9,17, 9,2),fpp( 9,17, 9,3)/
     x-1.7995131d-01, 3.2958228d-05,-3.8572306d-05 /
      data fpp( 9,17,10,1),fpp( 9,17,10,2),fpp( 9,17,10,3)/
     x-1.4757203d-01,-2.8211937d-05,-7.1440497d-05 /
      data fpp( 9,17,11,1),fpp( 9,17,11,2),fpp( 9,17,11,3)/
     x 9.1309861d-03, 7.5369182d-07, 3.7242934d-06 /
      data fpp( 9,17,12,1),fpp( 9,17,12,2),fpp( 9,17,12,3)/
     x 2.0046932d-02, 7.5335553d-06,-4.6926770d-06 /
      data fpp( 9,17,13,1),fpp( 9,17,13,2),fpp( 9,17,13,3)/
     x 2.2300605d-02, 9.0369343d-06, 1.0964147d-06 /
      data fpp( 9,17,14,1),fpp( 9,17,14,2),fpp( 9,17,14,3)/
     x 2.3158104d-02, 9.5083099d-06, 8.1101825d-07 /
      data fpp( 9,17,15,1),fpp( 9,17,15,2),fpp( 9,17,15,3)/
     x 2.3606316d-02, 1.0144855d-05, 1.1975123d-06 /
      data fpp( 9,17,16,1),fpp( 9,17,16,2),fpp( 9,17,16,3)/
     x 2.3923894d-02, 1.1225144d-05, 8.9093249d-07 /
      data fpp( 9,17,17,1),fpp( 9,17,17,2),fpp( 9,17,17,3)/
     x 2.4132515d-02, 1.2720451d-05, 5.1875771d-07 /
      data fpp( 9,17,18,1),fpp( 9,17,18,2),fpp( 9,17,18,3)/
     x 2.4355761d-02, 1.4347062d-05, 5.8036680d-08 /
      data fpp( 9,17,19,1),fpp( 9,17,19,2),fpp( 9,17,19,3)/
     x 2.4525088d-02, 1.5775715d-05,-3.0090443d-07 /
      data fpp( 9,17,20,1),fpp( 9,17,20,2),fpp( 9,17,20,3)/
     x 2.4626718d-02, 1.6706157d-05,-6.2441898d-07 /
      data fpp( 9,17,21,1),fpp( 9,17,21,2),fpp( 9,17,21,3)/
     x 2.4626718d-02, 1.6706157d-05,-6.3429086d-07 /
      data fpp( 9,17,22,1),fpp( 9,17,22,2),fpp( 9,17,22,3)/
     x 2.4525088d-02, 1.5775715d-05,-2.6141690d-07 /
      data fpp( 9,17,23,1),fpp( 9,17,23,2),fpp( 9,17,23,3)/
     x 2.4355761d-02, 1.4347062d-05,-9.0041551d-08 /
      data fpp( 9,18, 1,1),fpp( 9,18, 1,2),fpp( 9,18, 1,3)/
     x-5.8984506d-02,-2.3393064d-04, 9.9183974d-06 /
      data fpp( 9,18, 2,1),fpp( 9,18, 2,2),fpp( 9,18, 2,3)/
     x-8.0689989d-02,-2.4379711d-04, 1.0652205d-05 /
      data fpp( 9,18, 3,1),fpp( 9,18, 3,2),fpp( 9,18, 3,3)/
     x-5.1355978d-02,-2.4931414d-04, 1.2392781d-05 /
      data fpp( 9,18, 4,1),fpp( 9,18, 4,2),fpp( 9,18, 4,3)/
     x-5.1355978d-02,-2.4931414d-04, 1.2098553d-05 /
      data fpp( 9,18, 5,1),fpp( 9,18, 5,2),fpp( 9,18, 5,3)/
     x-8.0689989d-02,-2.4379711d-04, 1.1829119d-05 /
      data fpp( 9,18, 6,1),fpp( 9,18, 6,2),fpp( 9,18, 6,3)/
     x-5.8984506d-02,-2.3393064d-04, 5.5049695d-06 /
      data fpp( 9,18, 7,1),fpp( 9,18, 7,2),fpp( 9,18, 7,3)/
     x 1.7614053d-01,-2.2173827d-04, 1.9977003d-05 /
      data fpp( 9,18, 8,1),fpp( 9,18, 8,2),fpp( 9,18, 8,3)/
     x-5.8611236d-01,-2.1069737d-04,-4.5848980d-05 /
      data fpp( 9,18, 9,1),fpp( 9,18, 9,2),fpp( 9,18, 9,3)/
     x-2.0849536d-01,-1.2536321d-04,-2.2041081d-05 /
      data fpp( 9,18,10,1),fpp( 9,18,10,2),fpp( 9,18,10,3)/
     x 3.5891274d-02,-3.7557018d-05, 7.0833062d-06 /
      data fpp( 9,18,11,1),fpp( 9,18,11,2),fpp( 9,18,11,3)/
     x 3.3182533d-02,-1.8008912d-05,-7.9014337d-07 /
      data fpp( 9,18,12,1),fpp( 9,18,12,2),fpp( 9,18,12,3)/
     x 1.7787660d-02,-7.2794444d-06, 1.3212673d-06 /
      data fpp( 9,18,13,1),fpp( 9,18,13,2),fpp( 9,18,13,3)/
     x 2.3690706d-02,-8.5526646d-09, 7.5507431d-07 /
      data fpp( 9,18,14,1),fpp( 9,18,14,2),fpp( 9,18,14,3)/
     x 2.1931649d-02, 5.7369115d-06, 8.6643548d-07 /
      data fpp( 9,18,15,1),fpp( 9,18,15,2),fpp( 9,18,15,3)/
     x 2.0133984d-02, 1.0753613d-05, 7.5318376d-07 /
      data fpp( 9,18,16,1),fpp( 9,18,16,2),fpp( 9,18,16,3)/
     x 1.8480929d-02, 1.5320102d-05, 6.5682948d-07 /
      data fpp( 9,18,17,1),fpp( 9,18,17,2),fpp( 9,18,17,3)/
     x 1.7033220d-02, 1.9425157d-05, 5.4349831d-07 /
      data fpp( 9,18,18,1),fpp( 9,18,18,2),fpp( 9,18,18,3)/
     x 1.5858440d-02, 2.2923839d-05, 4.2117727d-07 /
      data fpp( 9,18,19,1),fpp( 9,18,19,2),fpp( 9,18,19,3)/
     x 1.4931991d-02, 2.5623224d-05, 3.3379260d-07 /
      data fpp( 9,18,20,1),fpp( 9,18,20,2),fpp( 9,18,20,3)/
     x 1.4351915d-02, 2.7341669d-05, 2.5965234d-07 /
      data fpp( 9,18,21,1),fpp( 9,18,21,2),fpp( 9,18,21,3)/
     x 1.4351915d-02, 2.7341669d-05, 2.5714668d-07 /
      data fpp( 9,18,22,1),fpp( 9,18,22,2),fpp( 9,18,22,3)/
     x 1.4931991d-02, 2.5623224d-05, 3.4381523d-07 /
      data fpp( 9,18,23,1),fpp( 9,18,23,2),fpp( 9,18,23,3)/
     x 1.5858440d-02, 2.2923839d-05, 3.8359238d-07 /
      data fpp( 9,19, 1,1),fpp( 9,19, 1,2),fpp( 9,19, 1,3)/
     x 2.4906953d-02,-4.8266168d-04, 8.0827621d-20 /
      data fpp( 9,19, 2,1),fpp( 9,19, 2,2),fpp( 9,19, 2,3)/
     x 2.4906953d-02,-5.1334295d-04, 1.9965671d-20 /
      data fpp( 9,19, 3,1),fpp( 9,19, 3,2),fpp( 9,19, 3,3)/
     x 2.4906953d-02,-5.3828543d-04,-2.8627388d-20 /
      data fpp( 9,19, 4,1),fpp( 9,19, 4,2),fpp( 9,19, 4,3)/
     x 2.4906953d-02,-5.3828543d-04, 2.5803199d-20 /
      data fpp( 9,19, 5,1),fpp( 9,19, 5,2),fpp( 9,19, 5,3)/
     x 2.4906953d-02,-5.1334295d-04, 3.3955278d-20 /
      data fpp( 9,19, 6,1),fpp( 9,19, 6,2),fpp( 9,19, 6,3)/
     x 2.4906953d-02,-4.8266168d-04,-4.9892613d-20 /
      data fpp( 9,19, 7,1),fpp( 9,19, 7,2),fpp( 9,19, 7,3)/
     x 2.4906953d-02,-4.5399986d-04,-2.9230021d-20 /
      data fpp( 9,19, 8,1),fpp( 9,19, 8,2),fpp( 9,19, 8,3)/
     x 2.4906953d-02,-4.3017332d-04,-3.4021728d-20 /
      data fpp( 9,19, 9,1),fpp( 9,19, 9,2),fpp( 9,19, 9,3)/
     x 2.4906953d-02,-2.5080940d-04,-2.8775540d-20 /
      data fpp( 9,19,10,1),fpp( 9,19,10,2),fpp( 9,19,10,3)/
     x 2.4906953d-02,-6.9521991d-05, 1.4782050d-20 /
      data fpp( 9,19,11,1),fpp( 9,19,11,2),fpp( 9,19,11,3)/
     x 2.4906953d-02,-3.6952044d-05,-2.0555610d-20 /
      data fpp( 9,19,12,1),fpp( 9,19,12,2),fpp( 9,19,12,3)/
     x 2.4906953d-02,-1.8645778d-05, 5.0091501d-20 /
      data fpp( 9,19,13,1),fpp( 9,19,13,2),fpp( 9,19,13,3)/
     x 2.4906953d-02,-5.6787237d-06, 7.1598450d-20 /
      data fpp( 9,19,14,1),fpp( 9,19,14,2),fpp( 9,19,14,3)/
     x 2.4906953d-02, 4.5100443d-06,-1.5111363d-20 /
      data fpp( 9,19,15,1),fpp( 9,19,15,2),fpp( 9,19,15,3)/
     x 2.4906953d-02, 1.3038694d-05, 4.0052698d-21 /
      data fpp( 9,19,16,1),fpp( 9,19,16,2),fpp( 9,19,16,3)/
     x 2.4906953d-02, 2.0344449d-05,-4.0133434d-20 /
      data fpp( 9,19,17,1),fpp( 9,19,17,2),fpp( 9,19,17,3)/
     x 2.4906953d-02, 2.6512922d-05, 2.4680845d-20 /
      data fpp( 9,19,18,1),fpp( 9,19,18,2),fpp( 9,19,18,3)/
     x 2.4906953d-02, 3.1495580d-05,-3.0233394d-20 /
      data fpp( 9,19,19,1),fpp( 9,19,19,2),fpp( 9,19,19,3)/
     x 2.4906953d-02, 3.5199388d-05,-5.9971195d-20 /
      data fpp( 9,19,20,1),fpp( 9,19,20,2),fpp( 9,19,20,3)/
     x 2.4906953d-02, 3.7523165d-05, 3.5060823d-20 /
      data fpp( 9,19,21,1),fpp( 9,19,21,2),fpp( 9,19,21,3)/
     x 2.4906953d-02, 3.7523165d-05,-2.1526472d-21 /
      data fpp( 9,19,22,1),fpp( 9,19,22,2),fpp( 9,19,22,3)/
     x 2.4906953d-02, 3.5199388d-05, 7.8289065d-20 /
      data fpp( 9,19,23,1),fpp( 9,19,23,2),fpp( 9,19,23,3)/
     x 2.4906953d-02, 3.1495580d-05, 1.5994001d-19 /
      data fpp(10, 1, 1,1),fpp(10, 1, 1,2),fpp(10, 1, 1,3)/
     x-3.4227719d+00, 2.2986929d-03,-5.1415210d-19 /
      data fpp(10, 1, 2,1),fpp(10, 1, 2,2),fpp(10, 1, 2,3)/
     x-3.4227719d+00, 2.0864156d-03, 1.1686206d-19 /
      data fpp(10, 1, 3,1),fpp(10, 1, 3,2),fpp(10, 1, 3,3)/
     x-3.4227719d+00, 2.6562327d-03,-4.3614772d-19 /
      data fpp(10, 1, 4,1),fpp(10, 1, 4,2),fpp(10, 1, 4,3)/
     x-3.4227719d+00, 2.6562327d-03, 2.9243830d-19 /
      data fpp(10, 1, 5,1),fpp(10, 1, 5,2),fpp(10, 1, 5,3)/
     x-3.4227719d+00, 2.0864156d-03,-1.7282651d-19 /
      data fpp(10, 1, 6,1),fpp(10, 1, 6,2),fpp(10, 1, 6,3)/
     x-3.4227719d+00, 2.2986929d-03,-3.3070067d-19 /
      data fpp(10, 1, 7,1),fpp(10, 1, 7,2),fpp(10, 1, 7,3)/
     x-3.4227719d+00, 2.3354336d-05,-5.8894273d-19 /
      data fpp(10, 1, 8,1),fpp(10, 1, 8,2),fpp(10, 1, 8,3)/
     x-3.4227719d+00,-6.8968633d-04,-3.0572792d-19 /
      data fpp(10, 1, 9,1),fpp(10, 1, 9,2),fpp(10, 1, 9,3)/
     x-3.4227719d+00,-9.4425740d-04, 2.9726388d-20 /
      data fpp(10, 1,10,1),fpp(10, 1,10,2),fpp(10, 1,10,3)/
     x-3.4227719d+00,-1.0435736d-03, 7.3787933d-19 /
      data fpp(10, 1,11,1),fpp(10, 1,11,2),fpp(10, 1,11,3)/
     x-3.4227719d+00,-1.0556752d-03,-3.5120304d-19 /
      data fpp(10, 1,12,1),fpp(10, 1,12,2),fpp(10, 1,12,3)/
     x-3.4227719d+00,-1.0592245d-03, 2.9313722d-19 /
      data fpp(10, 1,13,1),fpp(10, 1,13,2),fpp(10, 1,13,3)/
     x-3.4227719d+00,-1.0682755d-03, 2.8245877d-19 /
      data fpp(10, 1,14,1),fpp(10, 1,14,2),fpp(10, 1,14,3)/
     x-3.4227719d+00,-1.0557076d-03,-6.4266447d-20 /
      data fpp(10, 1,15,1),fpp(10, 1,15,2),fpp(10, 1,15,3)/
     x-3.4227719d+00,-9.6016780d-04, 9.7788393d-21 /
      data fpp(10, 1,16,1),fpp(10, 1,16,2),fpp(10, 1,16,3)/
     x-3.4227719d+00,-7.0671208d-04,-1.2962680d-19 /
      data fpp(10, 1,17,1),fpp(10, 1,17,2),fpp(10, 1,17,3)/
     x-3.4227719d+00,-1.4459401d-05, 3.3058563d-20 /
      data fpp(10, 1,18,1),fpp(10, 1,18,2),fpp(10, 1,18,3)/
     x-3.4227719d+00, 2.2703984d-03,-3.0860139d-19 /
      data fpp(10, 1,19,1),fpp(10, 1,19,2),fpp(10, 1,19,3)/
     x-3.4227719d+00, 1.9767510d-03,-4.2062991d-19 /
      data fpp(10, 1,20,1),fpp(10, 1,20,2),fpp(10, 1,20,3)/
     x-3.4227719d+00, 2.5356724d-03, 3.1665440d-19 /
      data fpp(10, 1,21,1),fpp(10, 1,21,2),fpp(10, 1,21,3)/
     x-3.4227719d+00, 2.5356724d-03,-2.3865603d-19 /
      data fpp(10, 1,22,1),fpp(10, 1,22,2),fpp(10, 1,22,3)/
     x-3.4227719d+00, 1.9767510d-03, 5.0561594d-19 /
      data fpp(10, 1,23,1),fpp(10, 1,23,2),fpp(10, 1,23,3)/
     x-3.4227719d+00, 2.2703984d-03, 1.7230917d-18 /
      data fpp(10, 2, 1,1),fpp(10, 2, 1,2),fpp(10, 2, 1,3)/
     x 2.2589472d+00, 9.3651511d-04,-1.7038277d-06 /
      data fpp(10, 2, 2,1),fpp(10, 2, 2,2),fpp(10, 2, 2,3)/
     x 1.7631047d+00, 6.9290283d-04,-3.2241345d-05 /
      data fpp(10, 2, 3,1),fpp(10, 2, 3,2),fpp(10, 2, 3,3)/
     x-1.1305059d+00, 9.1170456d-04,-9.7930794d-05 /
      data fpp(10, 2, 4,1),fpp(10, 2, 4,2),fpp(10, 2, 4,3)/
     x-1.1305059d+00, 9.1170456d-04,-9.7489945d-05 /
      data fpp(10, 2, 5,1),fpp(10, 2, 5,2),fpp(10, 2, 5,3)/
     x 1.7631047d+00, 6.9290283d-04,-3.4004740d-05 /
      data fpp(10, 2, 6,1),fpp(10, 2, 6,2),fpp(10, 2, 6,3)/
     x 2.2589472d+00, 9.3651511d-04, 4.9089071d-06 /
      data fpp(10, 2, 7,1),fpp(10, 2, 7,2),fpp(10, 2, 7,3)/
     x 1.2406148d+00, 6.7861329d-05, 2.7173112d-05 /
      data fpp(10, 2, 8,1),fpp(10, 2, 8,2),fpp(10, 2, 8,3)/
     x 3.7385551d-01,-1.8950834d-04, 3.3386645d-05 /
      data fpp(10, 2, 9,1),fpp(10, 2, 9,2),fpp(10, 2, 9,3)/
     x 4.9474041d-01,-2.6776919d-04, 3.3806309d-05 /
      data fpp(10, 2,10,1),fpp(10, 2,10,2),fpp(10, 2,10,3)/
     x 4.4662102d-01,-2.9497387d-04, 3.3582120d-05 /
      data fpp(10, 2,11,1),fpp(10, 2,11,2),fpp(10, 2,11,3)/
     x 5.3418640d-01,-2.8615667d-04, 3.1989210d-05 /
      data fpp(10, 2,12,1),fpp(10, 2,12,2),fpp(10, 2,12,3)/
     x 1.2743730d+00,-2.8370002d-04, 3.6491041d-05 /
      data fpp(10, 2,13,1),fpp(10, 2,13,2),fpp(10, 2,13,3)/
     x 1.1870432d+00,-2.9431501d-04, 2.7456628d-05 /
      data fpp(10, 2,14,1),fpp(10, 2,14,2),fpp(10, 2,14,3)/
     x 4.7641662d-01,-3.0513078d-04, 3.7066448d-05 /
      data fpp(10, 2,15,1),fpp(10, 2,15,2),fpp(10, 2,15,3)/
     x 4.8387599d-01,-2.8187640d-04, 3.2993579d-05 /
      data fpp(10, 2,16,1),fpp(10, 2,16,2),fpp(10, 2,16,3)/
     x 4.5358171d-01,-2.0592985d-04, 3.3549237d-05 /
      data fpp(10, 2,17,1),fpp(10, 2,17,2),fpp(10, 2,17,3)/
     x 1.3519746d+00, 3.8063802d-05, 2.6699475d-05 /
      data fpp(10, 2,18,1),fpp(10, 2,18,2),fpp(10, 2,18,3)/
     x 2.3801398d+00, 9.1643911d-04, 4.4088629d-06 /
      data fpp(10, 2,19,1),fpp(10, 2,19,2),fpp(10, 2,19,3)/
     x 1.2846375d+00, 6.4704603d-04,-3.5166927d-05 /
      data fpp(10, 2,20,1),fpp(10, 2,20,2),fpp(10, 2,20,3)/
     x-1.6344865d+00, 8.6842015d-04,-9.8533155d-05 /
      data fpp(10, 2,21,1),fpp(10, 2,21,2),fpp(10, 2,21,3)/
     x-1.6344865d+00, 8.6842015d-04,-9.9008071d-05 /
      data fpp(10, 2,22,1),fpp(10, 2,22,2),fpp(10, 2,22,3)/
     x 1.2846375d+00, 6.4704603d-04,-3.3267266d-05 /
      data fpp(10, 2,23,1),fpp(10, 2,23,2),fpp(10, 2,23,3)/
     x 2.3801398d+00, 9.1643911d-04,-2.7148672d-06 /
      data fpp(10, 3, 1,1),fpp(10, 3, 1,2),fpp(10, 3, 1,3)/
     x 6.2566278d-01,-2.0852034d-03, 2.7529072d-04 /
      data fpp(10, 3, 2,1),fpp(10, 3, 2,2),fpp(10, 3, 2,3)/
     x-1.3190010d-01,-5.7292291d-04, 6.8834063d-05 /
      data fpp(10, 3, 3,1),fpp(10, 3, 3,2),fpp(10, 3, 3,3)/
     x-4.2156394d-01,-9.9807897d-04,-3.1351297d-04 /
      data fpp(10, 3, 4,1),fpp(10, 3, 4,2),fpp(10, 3, 4,3)/
     x-4.2156394d-01,-9.9807897d-04,-4.1861812d-04 /
      data fpp(10, 3, 5,1),fpp(10, 3, 5,2),fpp(10, 3, 5,3)/
     x-1.3190010d-01,-5.7292291d-04, 4.8925468d-04 /
      data fpp(10, 3, 6,1),fpp(10, 3, 6,2),fpp(10, 3, 6,3)/
     x 6.2566278d-01,-2.0852034d-03,-1.3012866d-03 /
      data fpp(10, 3, 7,1),fpp(10, 3, 7,2),fpp(10, 3, 7,3)/
     x 2.2313044d-01,-2.6196765d-04, 1.1403357d-03 /
      data fpp(10, 3, 8,1),fpp(10, 3, 8,2),fpp(10, 3, 8,3)/
     x 3.0292291d-01, 4.8222970d-04,-3.7684205d-05 /
      data fpp(10, 3, 9,1),fpp(10, 3, 9,2),fpp(10, 3, 9,3)/
     x 3.3863005d-01, 8.1013818d-04, 1.5806912d-04 /
      data fpp(10, 3,10,1),fpp(10, 3,10,2),fpp(10, 3,10,3)/
     x 3.4234313d-01, 1.0210991d-03, 5.2327719d-05 /
      data fpp(10, 3,11,1),fpp(10, 3,11,2),fpp(10, 3,11,3)/
     x 3.0922603d-01, 1.0320838d-03, 6.4194001d-05 /
      data fpp(10, 3,12,1),fpp(10, 3,12,2),fpp(10, 3,12,3)/
     x 3.1672249d-01, 1.0294306d-03, 5.6428276d-05 /
      data fpp(10, 3,13,1),fpp(10, 3,13,2),fpp(10, 3,13,3)/
     x 5.0250093d-01, 1.0289995d-03, 6.5346894d-05 /
      data fpp(10, 3,14,1),fpp(10, 3,14,2),fpp(10, 3,14,3)/
     x 3.3967821d-01, 1.0118507d-03, 5.3050147d-05 /
      data fpp(10, 3,15,1),fpp(10, 3,15,2),fpp(10, 3,15,3)/
     x 5.0969968d-01, 7.9690538d-04, 1.6134052d-04 /
      data fpp(10, 3,16,1),fpp(10, 3,16,2),fpp(10, 3,16,3)/
     x 3.0124350d-01, 4.6550347d-04,-4.1004213d-05 /
      data fpp(10, 3,17,1),fpp(10, 3,17,2),fpp(10, 3,17,3)/
     x 2.6098358d-01,-2.1366581d-04, 1.1536743d-03 /
      data fpp(10, 3,18,1),fpp(10, 3,18,2),fpp(10, 3,18,3)/
     x 4.0755349d-01,-2.0927109d-03,-1.3539251d-03 /
      data fpp(10, 3,19,1),fpp(10, 3,19,2),fpp(10, 3,19,3)/
     x-1.3135569d-01,-5.4803111d-04, 5.3450820d-04 /
      data fpp(10, 3,20,1),fpp(10, 3,20,2),fpp(10, 3,20,3)/
     x-4.2082338d-01,-9.9110303d-04,-4.2580567d-04 /
      data fpp(10, 3,21,1),fpp(10, 3,21,2),fpp(10, 3,21,3)/
     x-4.2082338d-01,-9.9110303d-04,-3.1489208d-04 /
      data fpp(10, 3,22,1),fpp(10, 3,22,2),fpp(10, 3,22,3)/
     x-1.3135569d-01,-5.4803111d-04, 9.0853808d-05 /
      data fpp(10, 3,23,1),fpp(10, 3,23,2),fpp(10, 3,23,3)/
     x 4.0755349d-01,-2.0927109d-03, 3.0977885d-04 /
      data fpp(10, 4, 1,1),fpp(10, 4, 1,2),fpp(10, 4, 1,3)/
     x-1.0690309d-01, 7.0147047d-04,-8.0366727d-04 /
      data fpp(10, 4, 2,1),fpp(10, 4, 2,2),fpp(10, 4, 2,3)/
     x-8.6375295d-03,-2.2856532d-03,-6.3047646d-04 /
      data fpp(10, 4, 3,1),fpp(10, 4, 3,2),fpp(10, 4, 3,3)/
     x-4.0455162d-01,-2.3294687d-03,-3.1562288d-04 /
      data fpp(10, 4, 4,1),fpp(10, 4, 4,2),fpp(10, 4, 4,3)/
     x-4.0455162d-01,-2.3294687d-03,-2.1715112d-04 /
      data fpp(10, 4, 5,1),fpp(10, 4, 5,2),fpp(10, 4, 5,3)/
     x-8.6375295d-03,-2.2856532d-03,-1.0243635d-03 /
      data fpp(10, 4, 6,1),fpp(10, 4, 6,2),fpp(10, 4, 6,3)/
     x-1.0690309d-01, 7.0147047d-04, 6.7340914d-04 /
      data fpp(10, 4, 7,1),fpp(10, 4, 7,2),fpp(10, 4, 7,3)/
     x 5.5679549d-01, 7.1837927d-04, 4.2639493d-04 /
      data fpp(10, 4, 8,1),fpp(10, 4, 8,2),fpp(10, 4, 8,3)/
     x 8.7425026d-02, 5.5350755d-04, 3.2117149d-05 /
      data fpp(10, 4, 9,1),fpp(10, 4, 9,2),fpp(10, 4, 9,3)/
     x 7.7383404d-02, 4.8307848d-04, 1.5434248d-04 /
      data fpp(10, 4,10,1),fpp(10, 4,10,2),fpp(10, 4,10,3)/
     x 1.8502658d-03, 3.5101565d-04,-3.6209053d-05 /
      data fpp(10, 4,11,1),fpp(10, 4,11,2),fpp(10, 4,11,3)/
     x-2.3646615d-01, 4.2979728d-04, 1.0047974d-04 /
      data fpp(10, 4,12,1),fpp(10, 4,12,2),fpp(10, 4,12,3)/
     x 7.9224540d-02, 4.6093968d-04, 5.8772107d-05 /
      data fpp(10, 4,13,1),fpp(10, 4,13,2),fpp(10, 4,13,3)/
     x-2.0223372d-01, 4.2957485d-04, 1.0283984d-04 /
      data fpp(10, 4,14,1),fpp(10, 4,14,2),fpp(10, 4,14,3)/
     x-3.3279509d-01, 3.4641584d-04,-3.0649454d-05 /
      data fpp(10, 4,15,1),fpp(10, 4,15,2),fpp(10, 4,15,3)/
     x 7.6896347d-02, 4.7397086d-04, 1.4241598d-04 /
      data fpp(10, 4,16,1),fpp(10, 4,16,2),fpp(10, 4,16,3)/
     x 7.0230013d-02, 5.3965797d-04, 9.8209532d-05 /
      data fpp(10, 4,17,1),fpp(10, 4,17,2),fpp(10, 4,17,3)/
     x 2.2282930d-02, 5.9948942d-04, 3.4397389d-04 /
      data fpp(10, 4,18,1),fpp(10, 4,18,2),fpp(10, 4,18,3)/
     x-1.2080065d-01, 6.9130640d-04, 6.8753890d-04 /
      data fpp(10, 4,19,1),fpp(10, 4,19,2),fpp(10, 4,19,3)/
     x-3.2552064d-02,-2.2143056d-03,-1.0086315d-03 /
      data fpp(10, 4,20,1),fpp(10, 4,20,2),fpp(10, 4,20,3)/
     x-4.0350011d-01,-2.1776780d-03,-2.1961692d-04 /
      data fpp(10, 4,21,1),fpp(10, 4,21,2),fpp(10, 4,21,3)/
     x-4.0350011d-01,-2.1776780d-03,-3.1760950d-04 /
      data fpp(10, 4,22,1),fpp(10, 4,22,2),fpp(10, 4,22,3)/
     x-3.2552064d-02,-2.2143056d-03,-6.1666114d-04 /
      data fpp(10, 4,23,1),fpp(10, 4,23,2),fpp(10, 4,23,3)/
     x-1.2080065d-01, 6.9130640d-04,-7.8234993d-04 /
      data fpp(10, 5, 1,1),fpp(10, 5, 1,2),fpp(10, 5, 1,3)/
     x 8.7815556d-02, 7.7193551d-04, 2.9261998d-04 /
      data fpp(10, 5, 2,1),fpp(10, 5, 2,2),fpp(10, 5, 2,3)/
     x-4.9417072d-02, 2.5326777d-03, 9.5717534d-05 /
      data fpp(10, 5, 3,1),fpp(10, 5, 3,2),fpp(10, 5, 3,3)/
     x-1.1108199d-01, 2.3360677d-03,-3.1655212d-04 /
      data fpp(10, 5, 4,1),fpp(10, 5, 4,2),fpp(10, 5, 4,3)/
     x-1.1108199d-01, 2.3360677d-03,-3.3346441d-04 /
      data fpp(10, 5, 5,1),fpp(10, 5, 5,2),fpp(10, 5, 5,3)/
     x-4.9417072d-02, 2.5326777d-03, 1.6336667d-04 /
      data fpp(10, 5, 6,1),fpp(10, 5, 6,2),fpp(10, 5, 6,3)/
     x 8.7815556d-02, 7.7193551d-04, 3.8935711d-05 /
      data fpp(10, 5, 7,1),fpp(10, 5, 7,2),fpp(10, 5, 7,3)/
     x-7.1947057d-04, 1.7254056d-04, 6.3786481d-05 /
      data fpp(10, 5, 8,1),fpp(10, 5, 8,2),fpp(10, 5, 8,3)/
     x 4.2651335d-03, 1.1779409d-04, 4.4246366d-05 /
      data fpp(10, 5, 9,1),fpp(10, 5, 9,2),fpp(10, 5, 9,3)/
     x 8.0195396d-03, 1.2194791d-04, 5.0354056d-05 /
      data fpp(10, 5,10,1),fpp(10, 5,10,2),fpp(10, 5,10,3)/
     x 1.0809461d-02, 2.0611436d-04, 5.0503410d-05 /
      data fpp(10, 5,11,1),fpp(10, 5,11,2),fpp(10, 5,11,3)/
     x 1.2509932d-02, 1.6170904d-04, 5.0860305d-05 /
      data fpp(10, 5,12,1),fpp(10, 5,12,2),fpp(10, 5,12,3)/
     x 1.3234247d-02, 1.4310668d-04, 5.1095370d-05 /
      data fpp(10, 5,13,1),fpp(10, 5,13,2),fpp(10, 5,13,3)/
     x 1.3002825d-02, 1.5820105d-04, 5.2210215d-05 /
      data fpp(10, 5,14,1),fpp(10, 5,14,2),fpp(10, 5,14,3)/
     x 1.1652102d-02, 2.0260390d-04, 5.3575770d-05 /
      data fpp(10, 5,15,1),fpp(10, 5,15,2),fpp(10, 5,15,3)/
     x 9.3349602d-03, 1.1796518d-04, 5.5932707d-05 /
      data fpp(10, 5,16,1),fpp(10, 5,16,2),fpp(10, 5,16,3)/
     x-2.7349123d-03, 1.1164863d-04, 5.4127403d-05 /
      data fpp(10, 5,17,1),fpp(10, 5,17,2),fpp(10, 5,17,3)/
     x 3.6446702d-04, 2.2034012d-04, 7.8833680d-05 /
      data fpp(10, 5,18,1),fpp(10, 5,18,2),fpp(10, 5,18,3)/
     x-1.1742910d-02, 7.2440527d-04, 5.7497875d-05 /
      data fpp(10, 5,19,1),fpp(10, 5,19,2),fpp(10, 5,19,3)/
     x-4.5112399d-02, 2.3697674d-03, 1.6499482d-04 /
      data fpp(10, 5,20,1),fpp(10, 5,20,2),fpp(10, 5,20,3)/
     x-1.1404144d-01, 2.0820132d-03,-3.6089715d-04 /
      data fpp(10, 5,21,1),fpp(10, 5,21,2),fpp(10, 5,21,3)/
     x-1.1404144d-01, 2.0820132d-03,-3.4414495d-04 /
      data fpp(10, 5,22,1),fpp(10, 5,22,2),fpp(10, 5,22,3)/
     x-4.5112399d-02, 2.3697674d-03, 9.7985985d-05 /
      data fpp(10, 5,23,1),fpp(10, 5,23,2),fpp(10, 5,23,3)/
     x-1.1742910d-02, 7.2440527d-04, 3.0878101d-04 /
      data fpp(10, 6, 1,1),fpp(10, 6, 1,2),fpp(10, 6, 1,3)/
     x-2.5676445d-02,-2.0630651d-04, 1.0503695d-04 /
      data fpp(10, 6, 2,1),fpp(10, 6, 2,2),fpp(10, 6, 2,3)/
     x-6.4733986d-02,-6.3043551d-04, 1.9334595d-05 /
      data fpp(10, 6, 3,1),fpp(10, 6, 3,2),fpp(10, 6, 3,3)/
     x-8.9185726d-01,-5.0548604d-04,-1.6032533d-04 /
      data fpp(10, 6, 4,1),fpp(10, 6, 4,2),fpp(10, 6, 4,3)/
     x-8.9185726d-01,-5.0548604d-04,-1.6730430d-04 /
      data fpp(10, 6, 5,1),fpp(10, 6, 5,2),fpp(10, 6, 5,3)/
     x-6.4733986d-02,-6.3043551d-04, 4.7250484d-05 /
      data fpp(10, 6, 6,1),fpp(10, 6, 6,2),fpp(10, 6, 6,3)/
     x-2.5676445d-02,-2.0630651d-04, 3.5236593d-07 /
      data fpp(10, 6, 7,1),fpp(10, 6, 7,2),fpp(10, 6, 7,3)/
     x-1.4796573d-02,-5.2121497d-05, 2.6694052d-05 /
      data fpp(10, 6, 8,1),fpp(10, 6, 8,2),fpp(10, 6, 8,3)/
     x-9.4011978d-03,-2.3127908d-05, 3.0043427d-05 /
      data fpp(10, 6, 9,1),fpp(10, 6, 9,2),fpp(10, 6, 9,3)/
     x-6.4791991d-03,-1.4848104d-05, 3.5508241d-05 /
      data fpp(10, 6,10,1),fpp(10, 6,10,2),fpp(10, 6,10,3)/
     x-4.9371457d-03,-3.4483081d-05, 3.7479608d-05 /
      data fpp(10, 6,11,1),fpp(10, 6,11,2),fpp(10, 6,11,3)/
     x-4.0536495d-03,-2.2715450d-05, 3.9003326d-05 /
      data fpp(10, 6,12,1),fpp(10, 6,12,2),fpp(10, 6,12,3)/
     x-3.4499335d-03,-1.8610399d-05, 4.0015087d-05 /
      data fpp(10, 6,13,1),fpp(10, 6,13,2),fpp(10, 6,13,3)/
     x-3.2747738d-03,-2.3341067d-05, 4.0876327d-05 /
      data fpp(10, 6,14,1),fpp(10, 6,14,2),fpp(10, 6,14,3)/
     x-3.2816609d-03,-3.5857447d-05, 4.1675605d-05 /
      data fpp(10, 6,15,1),fpp(10, 6,15,2),fpp(10, 6,15,3)/
     x-4.1166397d-03,-1.4919595d-05, 4.2657252d-05 /
      data fpp(10, 6,16,1),fpp(10, 6,16,2),fpp(10, 6,16,3)/
     x-5.4772983d-03,-1.7852502d-05, 4.0889388d-05 /
      data fpp(10, 6,17,1),fpp(10, 6,17,2),fpp(10, 6,17,3)/
     x-8.7211602d-03,-5.1235895d-05, 4.0835197d-05 /
      data fpp(10, 6,18,1),fpp(10, 6,18,2),fpp(10, 6,18,3)/
     x-1.4142156d-02,-1.6819549d-04, 1.7949826d-05 /
      data fpp(10, 6,19,1),fpp(10, 6,19,2),fpp(10, 6,19,3)/
     x-2.6405812d-02,-5.5010406d-04, 5.2317501d-05 /
      data fpp(10, 6,20,1),fpp(10, 6,20,2),fpp(10, 6,20,3)/
     x-4.3331231d-02,-3.8583875d-04,-1.9150783d-04 /
      data fpp(10, 6,21,1),fpp(10, 6,21,2),fpp(10, 6,21,3)/
     x-4.3331231d-02,-3.8583875d-04,-1.8447526d-04 /
      data fpp(10, 6,22,1),fpp(10, 6,22,2),fpp(10, 6,22,3)/
     x-2.6405812d-02,-5.5010406d-04, 2.4187217d-05 /
      data fpp(10, 6,23,1),fpp(10, 6,23,2),fpp(10, 6,23,3)/
     x-1.4142156d-02,-1.6819549d-04, 1.2343839d-04 /
      data fpp(10, 7, 1,1),fpp(10, 7, 1,2),fpp(10, 7, 1,3)/
     x-3.8811160d-03, 3.1822546d-05, 6.2346264d-06 /
      data fpp(10, 7, 2,1),fpp(10, 7, 2,2),fpp(10, 7, 2,3)/
     x-1.6664924d-03, 2.0273636d-04,-1.5701753d-05 /
      data fpp(10, 7, 3,1),fpp(10, 7, 3,2),fpp(10, 7, 3,3)/
     x 1.0775698d-02, 3.3074449d-04,-6.2209615d-05 /
      data fpp(10, 7, 4,1),fpp(10, 7, 4,2),fpp(10, 7, 4,3)/
     x 1.0775698d-02, 3.3074449d-04,-6.3082278d-05 /
      data fpp(10, 7, 5,1),fpp(10, 7, 5,2),fpp(10, 7, 5,3)/
     x-1.6664924d-03, 2.0273636d-04,-1.2211103d-05 /
      data fpp(10, 7, 6,1),fpp(10, 7, 6,2),fpp(10, 7, 6,3)/
     x-3.8811160d-03, 3.1822546d-05,-6.8553100d-06 /
      data fpp(10, 7, 7,1),fpp(10, 7, 7,2),fpp(10, 7, 7,3)/
     x-4.4849651d-03,-2.5236568d-05, 2.8703429d-06 /
      data fpp(10, 7, 8,1),fpp(10, 7, 8,2),fpp(10, 7, 8,3)/
     x-5.4182701d-03,-4.7446455d-05, 1.0121938d-05 /
      data fpp(10, 7, 9,1),fpp(10, 7, 9,2),fpp(10, 7, 9,3)/
     x-6.6363480d-03,-5.8619492d-05, 1.7349904d-05 /
      data fpp(10, 7,10,1),fpp(10, 7,10,2),fpp(10, 7,10,3)/
     x-7.5421548d-03,-5.8456035d-05, 2.3114447d-05 /
      data fpp(10, 7,11,1),fpp(10, 7,11,2),fpp(10, 7,11,3)/
     x-7.9633681d-03,-6.3983244d-05, 2.7172307d-05 /
      data fpp(10, 7,12,1),fpp(10, 7,12,2),fpp(10, 7,12,3)/
     x-7.8688406d-03,-6.5407083d-05, 2.9428326d-05 /
      data fpp(10, 7,13,1),fpp(10, 7,13,2),fpp(10, 7,13,3)/
     x-7.4686699d-03,-6.2592784d-05, 3.0134391d-05 /
      data fpp(10, 7,14,1),fpp(10, 7,14,2),fpp(10, 7,14,3)/
     x-6.7424297d-03,-5.5112115d-05, 2.9746110d-05 /
      data fpp(10, 7,15,1),fpp(10, 7,15,2),fpp(10, 7,15,3)/
     x-5.1344331d-03,-5.2778806d-05, 2.8535170d-05 /
      data fpp(10, 7,16,1),fpp(10, 7,16,2),fpp(10, 7,16,3)/
     x-4.2472816d-03,-3.8660623d-05, 2.5691210d-05 /
      data fpp(10, 7,17,1),fpp(10, 7,17,2),fpp(10, 7,17,3)/
     x-2.4026111d-03,-9.0965396d-06, 2.0175991d-05 /
      data fpp(10, 7,18,1),fpp(10, 7,18,2),fpp(10, 7,18,3)/
     x 3.9495942d-04, 5.4666688d-05, 6.2728252d-06 /
      data fpp(10, 7,19,1),fpp(10, 7,19,2),fpp(10, 7,19,3)/
     x 5.5754192d-03, 2.1347285d-04,-1.2639292d-05 /
      data fpp(10, 7,20,1),fpp(10, 7,20,2),fpp(10, 7,20,3)/
     x 1.5158143d-02, 2.7837380d-04,-8.3197657d-05 /
      data fpp(10, 7,21,1),fpp(10, 7,21,2),fpp(10, 7,21,3)/
     x 1.5158143d-02, 2.7837380d-04,-8.2532382d-05 /
      data fpp(10, 7,22,1),fpp(10, 7,22,2),fpp(10, 7,22,3)/
     x 5.5754192d-03, 2.1347285d-04,-1.5300391d-05 /
      data fpp(10, 7,23,1),fpp(10, 7,23,2),fpp(10, 7,23,3)/
     x 3.9495942d-04, 5.4666688d-05, 1.6251945d-05 /
      data fpp(10, 8, 1,1),fpp(10, 8, 1,2),fpp(10, 8, 1,3)/
     x 1.1872702d-02, 5.2898329d-05,-9.2288022d-06 /
      data fpp(10, 8, 2,1),fpp(10, 8, 2,2),fpp(10, 8, 2,3)/
     x 2.1077305d-02, 3.0576053d-05,-1.2579396d-05 /
      data fpp(10, 8, 3,1),fpp(10, 8, 3,2),fpp(10, 8, 3,3)/
     x 1.9341431d-01,-1.8887193d-04,-1.9737616d-05 /
      data fpp(10, 8, 4,1),fpp(10, 8, 4,2),fpp(10, 8, 4,3)/
     x 1.9341431d-01,-1.8887193d-04,-1.9775455d-05 /
      data fpp(10, 8, 5,1),fpp(10, 8, 5,2),fpp(10, 8, 5,3)/
     x 2.1077305d-02, 3.0576053d-05,-1.2428038d-05 /
      data fpp(10, 8, 6,1),fpp(10, 8, 6,2),fpp(10, 8, 6,3)/
     x 1.1872702d-02, 5.2898329d-05,-9.7963938d-06 /
      data fpp(10, 8, 7,1),fpp(10, 8, 7,2),fpp(10, 8, 7,3)/
     x 7.4935538d-03,-2.1286233d-05,-8.2963871d-06 /
      data fpp(10, 8, 8,1),fpp(10, 8, 8,2),fpp(10, 8, 8,3)/
     x 3.5641405d-03,-4.9436271d-05,-4.4540578d-06 /
      data fpp(10, 8, 9,1),fpp(10, 8, 9,2),fpp(10, 8, 9,3)/
     x-4.2432875d-04,-6.3099930d-05, 3.0726182d-06 /
      data fpp(10, 8,10,1),fpp(10, 8,10,2),fpp(10, 8,10,3)/
     x-3.8338940d-03,-7.0908778d-05, 1.1165585d-05 /
      data fpp(10, 8,11,1),fpp(10, 8,11,2),fpp(10, 8,11,3)/
     x-6.0972713d-03,-7.1985573d-05, 1.7167041d-05 /
      data fpp(10, 8,12,1),fpp(10, 8,12,2),fpp(10, 8,12,3)/
     x-6.9006429d-03,-7.0515269d-05, 2.0420250d-05 /
      data fpp(10, 8,13,1),fpp(10, 8,13,2),fpp(10, 8,13,3)/
     x-6.7033351d-03,-6.6883795d-05, 2.1529959d-05 /
      data fpp(10, 8,14,1),fpp(10, 8,14,2),fpp(10, 8,14,3)/
     x-5.8221240d-03,-6.1016094d-05, 2.0803913d-05 /
      data fpp(10, 8,15,1),fpp(10, 8,15,2),fpp(10, 8,15,3)/
     x-4.0374794d-03,-4.9413181d-05, 1.8926388d-05 /
      data fpp(10, 8,16,1),fpp(10, 8,16,2),fpp(10, 8,16,3)/
     x-1.6919176d-03,-3.5033004d-05, 1.5498533d-05 /
      data fpp(10, 8,17,1),fpp(10, 8,17,2),fpp(10, 8,17,3)/
     x 1.5007586d-03,-1.6765947d-05, 1.0201479d-05 /
      data fpp(10, 8,18,1),fpp(10, 8,18,2),fpp(10, 8,18,3)/
     x 5.7804439d-03, 2.0407374d-06, 6.1154921d-07 /
      data fpp(10, 8,19,1),fpp(10, 8,19,2),fpp(10, 8,19,3)/
     x 1.1697338d-02, 4.8406825d-06,-1.3127676d-05 /
      data fpp(10, 8,20,1),fpp(10, 8,20,2),fpp(10, 8,20,3)/
     x 1.8974815d-02, 3.4775542d-05,-4.1088844d-05 /
      data fpp(10, 8,21,1),fpp(10, 8,21,2),fpp(10, 8,21,3)/
     x 1.8974815d-02, 3.4775542d-05,-4.1121630d-05 /
      data fpp(10, 8,22,1),fpp(10, 8,22,2),fpp(10, 8,22,3)/
     x 1.1697338d-02, 4.8406825d-06,-1.2996534d-05 /
      data fpp(10, 8,23,1),fpp(10, 8,23,2),fpp(10, 8,23,3)/
     x 5.7804439d-03, 2.0407374d-06, 1.1976720d-07 /
      data fpp(10, 9, 1,1),fpp(10, 9, 1,2),fpp(10, 9, 1,3)/
     x-3.5269889d-02,-2.5180986d-04,-1.8930053d-04 /
      data fpp(10, 9, 2,1),fpp(10, 9, 2,2),fpp(10, 9, 2,3)/
     x-5.9760354d-02,-3.9032058d-04,-9.7348438d-05 /
      data fpp(10, 9, 3,1),fpp(10, 9, 3,2),fpp(10, 9, 3,3)/
     x 1.1070625d-03,-1.4210679d-04, 9.4224285d-05 /
      data fpp(10, 9, 4,1),fpp(10, 9, 4,2),fpp(10, 9, 4,3)/
     x 1.1070625d-03,-1.4210679d-04, 1.0379237d-04 /
      data fpp(10, 9, 5,1),fpp(10, 9, 5,2),fpp(10, 9, 5,3)/
     x-5.9760354d-02,-3.9032058d-04,-1.3562076d-04 /
      data fpp(10, 9, 6,1),fpp(10, 9, 6,2),fpp(10, 9, 6,3)/
     x-3.5269889d-02,-2.5180986d-04,-4.5779325d-05 /
      data fpp(10, 9, 7,1),fpp(10, 9, 7,2),fpp(10, 9, 7,3)/
     x 2.2233931d-02,-7.5024502d-05, 1.7820617d-06 /
      data fpp(10, 9, 8,1),fpp(10, 9, 8,2),fpp(10, 9, 8,3)/
     x 1.7437281d-02,-5.9104461d-05,-1.2846921d-05 /
      data fpp(10, 9, 9,1),fpp(10, 9, 9,2),fpp(10, 9, 9,3)/
     x 1.0869121d-02,-5.9762790d-05,-4.7783769d-06 /
      data fpp(10, 9,10,1),fpp(10, 9,10,2),fpp(10, 9,10,3)/
     x 4.9718111d-03,-6.0052853d-05, 2.4524289d-06 /
      data fpp(10, 9,11,1),fpp(10, 9,11,2),fpp(10, 9,11,3)/
     x 7.2780609d-04,-5.9554465d-05, 9.8186612d-06 /
      data fpp(10, 9,12,1),fpp(10, 9,12,2),fpp(10, 9,12,3)/
     x-1.9181091d-03,-5.7015841d-05, 1.3880926d-05 /
      data fpp(10, 9,13,1),fpp(10, 9,13,2),fpp(10, 9,13,3)/
     x-2.4376419d-03,-5.2258037d-05, 1.5495634d-05 /
      data fpp(10, 9,14,1),fpp(10, 9,14,2),fpp(10, 9,14,3)/
     x-2.4107625d-03,-4.5169508d-05, 1.5054536d-05 /
      data fpp(10, 9,15,1),fpp(10, 9,15,2),fpp(10, 9,15,3)/
     x-7.8354147d-04,-3.6284468d-05, 1.3566221d-05 /
      data fpp(10, 9,16,1),fpp(10, 9,16,2),fpp(10, 9,16,3)/
     x 1.1913203d-03,-2.4469359d-05, 1.0942581d-05 /
      data fpp(10, 9,17,1),fpp(10, 9,17,2),fpp(10, 9,17,3)/
     x 3.9558838d-03,-9.9156724d-06, 7.1634559d-06 /
      data fpp(10, 9,18,1),fpp(10, 9,18,2),fpp(10, 9,18,3)/
     x 7.7430577d-03, 7.5323621d-06, 8.1959557d-07 /
      data fpp(10, 9,19,1),fpp(10, 9,19,2),fpp(10, 9,19,3)/
     x 1.3084236d-02, 3.0156425d-05,-7.8378382d-06 /
      data fpp(10, 9,20,1),fpp(10, 9,20,2),fpp(10, 9,20,3)/
     x 1.9418493d-02, 4.1710029d-05,-2.4398243d-05 /
      data fpp(10, 9,21,1),fpp(10, 9,21,2),fpp(10, 9,21,3)/
     x 1.9418493d-02, 4.1710029d-05,-2.4442353d-05 /
      data fpp(10, 9,22,1),fpp(10, 9,22,2),fpp(10, 9,22,3)/
     x 1.3084236d-02, 3.0156425d-05,-7.6613993d-06 /
      data fpp(10, 9,23,1),fpp(10, 9,23,2),fpp(10, 9,23,3)/
     x 7.7430577d-03, 7.5323621d-06, 1.5794964d-07 /
      data fpp(10,10, 1,1),fpp(10,10, 1,2),fpp(10,10, 1,3)/
     x-1.1390409d-01,-9.0126886d-05,-1.0830610d-06 /
      data fpp(10,10, 2,1),fpp(10,10, 2,2),fpp(10,10, 2,3)/
     x-5.8084799d-02, 1.1262425d-04, 2.9066122d-05 /
      data fpp(10,10, 3,1),fpp(10,10, 3,2),fpp(10,10, 3,3)/
     x-3.4182504d-02, 6.7455068d-05, 9.7014573d-05 /
      data fpp(10,10, 4,1),fpp(10,10, 4,2),fpp(10,10, 4,3)/
     x-3.4182504d-02, 6.7455068d-05, 9.1164221d-05 /
      data fpp(10,10, 5,1),fpp(10,10, 5,2),fpp(10,10, 5,3)/
     x-5.8084799d-02, 1.1262425d-04, 5.2467529d-05 /
      data fpp(10,10, 6,1),fpp(10,10, 6,2),fpp(10,10, 6,3)/
     x-1.1390409d-01,-9.0126886d-05,-8.8838338d-05 /
      data fpp(10,10, 7,1),fpp(10,10, 7,2),fpp(10,10, 7,3)/
     x-2.8290283d-02,-1.7437776d-04,-9.6024179d-05 /
      data fpp(10,10, 8,1),fpp(10,10, 8,2),fpp(10,10, 8,3)/
     x 2.2781352d-02,-9.5295884d-05,-1.6718947d-05 /
      data fpp(10,10, 9,1),fpp(10,10, 9,2),fpp(10,10, 9,3)/
     x 2.2456793d-02,-5.9810910d-05,-1.8252033d-05 /
      data fpp(10,10,10,1),fpp(10,10,10,2),fpp(10,10,10,3)/
     x 1.5792861d-02,-4.7775809d-05,-4.4129222d-06 /
      data fpp(10,10,11,1),fpp(10,10,11,2),fpp(10,10,11,3)/
     x 9.9646538d-03,-4.2524567d-05, 3.8037215d-06 /
      data fpp(10,10,12,1),fpp(10,10,12,2),fpp(10,10,12,3)/
     x 6.0006045d-03,-3.8813366d-05, 9.3280362d-06 /
      data fpp(10,10,13,1),fpp(10,10,13,2),fpp(10,10,13,3)/
     x 3.8108613d-03,-3.4842058d-05, 1.1480134d-05 /
      data fpp(10,10,14,1),fpp(10,10,14,2),fpp(10,10,14,3)/
     x 3.2552185d-03,-2.9973876d-05, 1.1699429d-05 /
      data fpp(10,10,15,1),fpp(10,10,15,2),fpp(10,10,15,3)/
     x 3.5416302d-03,-2.3812945d-05, 1.0824149d-05 /
      data fpp(10,10,16,1),fpp(10,10,16,2),fpp(10,10,16,3)/
     x 4.5745674d-03,-1.6615559d-05, 9.0539760d-06 /
      data fpp(10,10,17,1),fpp(10,10,17,2),fpp(10,10,17,3)/
     x 6.2145074d-03,-8.9053632d-06, 6.1919474d-06 /
      data fpp(10,10,18,1),fpp(10,10,18,2),fpp(10,10,18,3)/
     x 9.1288832d-03,-1.9301859d-06, 1.4762343d-06 /
      data fpp(10,10,19,1),fpp(10,10,19,2),fpp(10,10,19,3)/
     x 1.3674820d-02, 2.3336191d-06,-4.4228845d-06 /
      data fpp(10,10,20,1),fpp(10,10,20,2),fpp(10,10,20,3)/
     x 2.0109308d-02, 6.8303433d-06,-1.7570696d-05 /
      data fpp(10,10,21,1),fpp(10,10,21,2),fpp(10,10,21,3)/
     x 2.0109308d-02, 6.8303433d-06,-1.7559469d-05 /
      data fpp(10,10,22,1),fpp(10,10,22,2),fpp(10,10,22,3)/
     x 1.3674820d-02, 2.3336191d-06,-4.4677946d-06 /
      data fpp(10,10,23,1),fpp(10,10,23,2),fpp(10,10,23,3)/
     x 9.1288832d-03,-1.9301859d-06, 1.6446473d-06 /
      data fpp(10,11, 1,1),fpp(10,11, 1,2),fpp(10,11, 1,3)/
     x-7.6880934d-02, 7.5059406d-05, 4.4950564d-05 /
      data fpp(10,11, 2,1),fpp(10,11, 2,2),fpp(10,11, 2,3)/
     x-3.8254729d-02, 8.1909561d-05, 5.8671872d-05 /
      data fpp(10,11, 3,1),fpp(10,11, 3,2),fpp(10,11, 3,3)/
     x-2.9378695d-03, 1.5437052d-04, 8.9877950d-05 /
      data fpp(10,11, 4,1),fpp(10,11, 4,2),fpp(10,11, 4,3)/
     x-2.9378695d-03, 1.5437052d-04, 8.6722216d-05 /
      data fpp(10,11, 5,1),fpp(10,11, 5,2),fpp(10,11, 5,3)/
     x-3.8254729d-02, 8.1909561d-05, 7.1294807d-05 /
      data fpp(10,11, 6,1),fpp(10,11, 6,2),fpp(10,11, 6,3)/
     x-7.6880934d-02, 7.5059406d-05,-2.3854427d-06 /
      data fpp(10,11, 7,1),fpp(10,11, 7,2),fpp(10,11, 7,3)/
     x-8.2952610d-02, 9.9895439d-06,-8.8561036d-05 /
      data fpp(10,11, 8,1),fpp(10,11, 8,2),fpp(10,11, 8,3)/
     x-1.6215458d-02,-5.2198003d-05,-7.5832413d-05 /
      data fpp(10,11, 9,1),fpp(10,11, 9,2),fpp(10,11, 9,3)/
     x 1.9688975d-02,-4.5795568d-05,-3.8405311d-05 /
      data fpp(10,11,10,1),fpp(10,11,10,2),fpp(10,11,10,3)/
     x 2.2513810d-02,-3.4179912d-05,-1.7536341d-05 /
      data fpp(10,11,11,1),fpp(10,11,11,2),fpp(10,11,11,3)/
     x 1.7441542d-02,-2.8185266d-05,-2.4673230d-06 /
      data fpp(10,11,12,1),fpp(10,11,12,2),fpp(10,11,12,3)/
     x 1.2856313d-02,-2.4892695d-05, 5.2356334d-06 /
      data fpp(10,11,13,1),fpp(10,11,13,2),fpp(10,11,13,3)/
     x 9.9677101d-03,-2.2159733d-05, 8.5787892d-06 /
      data fpp(10,11,14,1),fpp(10,11,14,2),fpp(10,11,14,3)/
     x 8.6286364d-03,-1.9212990d-05, 9.5592097d-06 /
      data fpp(10,11,15,1),fpp(10,11,15,2),fpp(10,11,15,3)/
     x 8.1150419d-03,-1.5967753d-05, 9.3743720d-06 /
      data fpp(10,11,16,1),fpp(10,11,16,2),fpp(10,11,16,3)/
     x 8.4294307d-03,-1.2580404d-05, 7.9993024d-06 /
      data fpp(10,11,17,1),fpp(10,11,17,2),fpp(10,11,17,3)/
     x 9.3084893d-03,-9.4108746d-06, 5.1644183d-06 /
      data fpp(10,11,18,1),fpp(10,11,18,2),fpp(10,11,18,3)/
     x 1.1174399d-02,-6.6156184d-06, 1.1030245d-06 /
      data fpp(10,11,19,1),fpp(10,11,19,2),fpp(10,11,19,3)/
     x 1.5496660d-02,-4.1989010d-06,-2.8805163d-06 /
      data fpp(10,11,20,1),fpp(10,11,20,2),fpp(10,11,20,3)/
     x 2.2722889d-02,-3.6854018d-06,-1.4264959d-05 /
      data fpp(10,11,21,1),fpp(10,11,21,2),fpp(10,11,21,3)/
     x 2.2722889d-02,-3.6854018d-06,-1.4201864d-05 /
      data fpp(10,11,22,1),fpp(10,11,22,2),fpp(10,11,22,3)/
     x 1.5496660d-02,-4.1989010d-06,-3.1328959d-06 /
      data fpp(10,11,23,1),fpp(10,11,23,2),fpp(10,11,23,3)/
     x 1.1174399d-02,-6.6156184d-06, 2.0494480d-06 /
      data fpp(10,12, 1,1),fpp(10,12, 1,2),fpp(10,12, 1,3)/
     x-5.4568716d-02, 8.4765262d-05, 1.1031008d-04 /
      data fpp(10,12, 2,1),fpp(10,12, 2,2),fpp(10,12, 2,3)/
     x 1.0205031d-02, 1.3940950d-04, 8.9969333d-05 /
      data fpp(10,12, 3,1),fpp(10,12, 3,2),fpp(10,12, 3,3)/
     x 9.1413664d-02, 1.7176087d-04, 4.8878585d-05 /
      data fpp(10,12, 4,1),fpp(10,12, 4,2),fpp(10,12, 4,3)/
     x 9.1413664d-02, 1.7176087d-04, 4.4509579d-05 /
      data fpp(10,12, 5,1),fpp(10,12, 5,2),fpp(10,12, 5,3)/
     x 1.0205031d-02, 1.3940950d-04, 1.0744535d-04 /
      data fpp(10,12, 6,1),fpp(10,12, 6,2),fpp(10,12, 6,3)/
     x-5.4568716d-02, 8.4765262d-05, 4.4775004d-05 /
      data fpp(10,12, 7,1),fpp(10,12, 7,2),fpp(10,12, 7,3)/
     x-8.2481175d-02, 4.5991585d-05,-3.9759372d-05 /
      data fpp(10,12, 8,1),fpp(10,12, 8,2),fpp(10,12, 8,3)/
     x-5.2988456d-02, 1.0771897d-05,-8.2591517d-05 /
      data fpp(10,12, 9,1),fpp(10,12, 9,2),fpp(10,12, 9,3)/
     x-1.6837631d-03,-1.2528817d-05,-6.6632559d-05 /
      data fpp(10,12,10,1),fpp(10,12,10,2),fpp(10,12,10,3)/
     x 2.0003772d-02,-1.6756543d-05,-3.4242246d-05 /
      data fpp(10,12,11,1),fpp(10,12,11,2),fpp(10,12,11,3)/
     x 2.1036637d-02,-1.6172367d-05,-1.0790457d-05 /
      data fpp(10,12,12,1),fpp(10,12,12,2),fpp(10,12,12,3)/
     x 1.7643839d-02,-1.5125855d-05, 1.0480728d-06 /
      data fpp(10,12,13,1),fpp(10,12,13,2),fpp(10,12,13,3)/
     x 1.4841866d-02,-1.4183011d-05, 6.0281655d-06 /
      data fpp(10,12,14,1),fpp(10,12,14,2),fpp(10,12,14,3)/
     x 1.3362799d-02,-1.3234163d-05, 7.8692651d-06 /
      data fpp(10,12,15,1),fpp(10,12,15,2),fpp(10,12,15,3)/
     x 1.2720320d-02,-1.2384044d-05, 8.1607739d-06 /
      data fpp(10,12,16,1),fpp(10,12,16,2),fpp(10,12,16,3)/
     x 1.2888730d-02,-1.1872823d-05, 6.8156391d-06 /
      data fpp(10,12,17,1),fpp(10,12,17,2),fpp(10,12,17,3)/
     x 1.3480913d-02,-1.1657138d-05, 3.7626696d-06 /
      data fpp(10,12,18,1),fpp(10,12,18,2),fpp(10,12,18,3)/
     x 1.4999565d-02,-1.1435341d-05, 1.2968243d-07 /
      data fpp(10,12,19,1),fpp(10,12,19,2),fpp(10,12,19,3)/
     x 1.9184696d-02,-1.1386015d-05,-2.9613994d-06 /
      data fpp(10,12,20,1),fpp(10,12,20,2),fpp(10,12,20,3)/
     x 2.5618777d-02,-1.1618736d-05,-1.1528085d-05 /
      data fpp(10,12,21,1),fpp(10,12,21,2),fpp(10,12,21,3)/
     x 2.5618777d-02,-1.1618736d-05,-1.1485045d-05 /
      data fpp(10,12,22,1),fpp(10,12,22,2),fpp(10,12,22,3)/
     x 1.9184696d-02,-1.1386015d-05,-3.1335585d-06 /
      data fpp(10,12,23,1),fpp(10,12,23,2),fpp(10,12,23,3)/
     x 1.4999565d-02,-1.1435341d-05, 7.7527925d-07 /
      data fpp(10,13, 1,1),fpp(10,13, 1,2),fpp(10,13, 1,3)/
     x-2.5299114d-02, 7.0559548d-05, 1.6851969d-04 /
      data fpp(10,13, 2,1),fpp(10,13, 2,2),fpp(10,13, 2,3)/
     x 7.8120222d-02, 2.7382424d-05, 1.1186561d-04 /
      data fpp(10,13, 3,1),fpp(10,13, 3,2),fpp(10,13, 3,3)/
     x 2.2115077d-01,-5.1226003d-05,-6.3581436d-06 /
      data fpp(10,13, 4,1),fpp(10,13, 4,2),fpp(10,13, 4,3)/
     x 2.2115077d-01,-5.1226003d-05,-1.1919375d-05 /
      data fpp(10,13, 5,1),fpp(10,13, 5,2),fpp(10,13, 5,3)/
     x 7.8120222d-02, 2.7382424d-05, 1.3411054d-04 /
      data fpp(10,13, 6,1),fpp(10,13, 6,2),fpp(10,13, 6,3)/
     x-2.5299114d-02, 7.0559548d-05, 8.5101216d-05 /
      data fpp(10,13, 7,1),fpp(10,13, 7,2),fpp(10,13, 7,3)/
     x-7.3438518d-02, 6.5394116d-05, 2.7845980d-06 /
      data fpp(10,13, 8,1),fpp(10,13, 8,2),fpp(10,13, 8,3)/
     x-7.1208098d-02, 3.8360417d-05,-6.2255607d-05 /
      data fpp(10,13, 9,1),fpp(10,13, 9,2),fpp(10,13, 9,3)/
     x-2.8296019d-02, 1.3662837d-05,-7.8380168d-05 /
      data fpp(10,13,10,1),fpp(10,13,10,2),fpp(10,13,10,3)/
     x 9.5616083d-03, 1.2940825d-06,-5.0127720d-05 /
      data fpp(10,13,11,1),fpp(10,13,11,2),fpp(10,13,11,3)/
     x 2.0237271d-02,-4.5292645d-06,-1.8702951d-05 /
      data fpp(10,13,12,1),fpp(10,13,12,2),fpp(10,13,12,3)/
     x 1.9843454d-02,-7.0578862d-06,-3.1604745d-06 /
      data fpp(10,13,13,1),fpp(10,13,13,2),fpp(10,13,13,3)/
     x 1.7994563d-02,-8.1562242d-06, 3.6068495d-06 /
      data fpp(10,13,14,1),fpp(10,13,14,2),fpp(10,13,14,3)/
     x 1.6908911d-02,-9.0183584d-06, 6.1570765d-06 /
      data fpp(10,13,15,1),fpp(10,13,15,2),fpp(10,13,15,3)/
     x 1.6565188d-02,-1.0030073d-05, 6.6608443d-06 /
      data fpp(10,13,16,1),fpp(10,13,16,2),fpp(10,13,16,3)/
     x 1.6981282d-02,-1.1304303d-05, 5.3235462d-06 /
      data fpp(10,13,17,1),fpp(10,13,17,2),fpp(10,13,17,3)/
     x 1.7790231d-02,-1.2636572d-05, 2.4229708d-06 /
      data fpp(10,13,18,1),fpp(10,13,18,2),fpp(10,13,18,3)/
     x 1.9379549d-02,-1.3643019d-05,-8.0742926d-07 /
      data fpp(10,13,19,1),fpp(10,13,19,2),fpp(10,13,19,3)/
     x 2.2934770d-02,-1.3971038d-05,-3.6392537d-06 /
      data fpp(10,13,20,1),fpp(10,13,20,2),fpp(10,13,20,3)/
     x 2.7563397d-02,-1.3535654d-05,-8.7075559d-06 /
      data fpp(10,13,21,1),fpp(10,13,21,2),fpp(10,13,21,3)/
     x 2.7563397d-02,-1.3535654d-05,-8.7297054d-06 /
      data fpp(10,13,22,1),fpp(10,13,22,2),fpp(10,13,22,3)/
     x 2.2934770d-02,-1.3971038d-05,-3.5506556d-06 /
      data fpp(10,13,23,1),fpp(10,13,23,2),fpp(10,13,23,3)/
     x 1.9379549d-02,-1.3643019d-05,-1.1396722d-06 /
      data fpp(10,14, 1,1),fpp(10,14, 1,2),fpp(10,14, 1,3)/
     x-7.8506465d-03, 5.5336548d-05, 1.4852269d-04 /
      data fpp(10,14, 2,1),fpp(10,14, 2,2),fpp(10,14, 2,3)/
     x 9.5691262d-02, 3.1927990d-06, 9.6174625d-05 /
      data fpp(10,14, 3,1),fpp(10,14, 3,2),fpp(10,14, 3,3)/
     x 2.2943774d-01,-6.5622861d-05,-1.3729187d-05 /
      data fpp(10,14, 4,1),fpp(10,14, 4,2),fpp(10,14, 4,3)/
     x 2.2943774d-01,-6.5622861d-05,-1.7702753d-05 /
      data fpp(10,14, 5,1),fpp(10,14, 5,2),fpp(10,14, 5,3)/
     x 9.5691262d-02, 3.1927990d-06, 1.1206889d-04 /
      data fpp(10,14, 6,1),fpp(10,14, 6,2),fpp(10,14, 6,3)/
     x-7.8506465d-03, 5.5336548d-05, 8.8919199d-05 /
      data fpp(10,14, 7,1),fpp(10,14, 7,2),fpp(10,14, 7,3)/
     x-6.1719240d-02, 7.0467950d-05, 2.5556314d-05 /
      data fpp(10,14, 8,1),fpp(10,14, 8,2),fpp(10,14, 8,3)/
     x-7.6927406d-02, 5.8098435d-05,-3.7742457d-05 /
      data fpp(10,14, 9,1),fpp(10,14, 9,2),fpp(10,14, 9,3)/
     x-5.2494246d-02, 3.6483471d-05,-7.5046486d-05 /
      data fpp(10,14,10,1),fpp(10,14,10,2),fpp(10,14,10,3)/
     x-6.3931466d-03, 1.6512213d-05,-6.0483600d-05 /
      data fpp(10,14,11,1),fpp(10,14,11,2),fpp(10,14,11,3)/
     x 1.6230771d-02, 5.7594254d-06,-2.3603115d-05 /
      data fpp(10,14,12,1),fpp(10,14,12,2),fpp(10,14,12,3)/
     x 1.9970494d-02, 1.9339956d-07,-6.1199409d-06 /
      data fpp(10,14,13,1),fpp(10,14,13,2),fpp(10,14,13,3)/
     x 1.9528702d-02,-2.7760924d-06, 1.3908783d-06 /
      data fpp(10,14,14,1),fpp(10,14,14,2),fpp(10,14,14,3)/
     x 1.9037937d-02,-4.7464036d-06, 4.3244278d-06 /
      data fpp(10,14,15,1),fpp(10,14,15,2),fpp(10,14,15,3)/
     x 1.9106362d-02,-6.5776644d-06, 4.8794104d-06 /
      data fpp(10,14,16,1),fpp(10,14,16,2),fpp(10,14,16,3)/
     x 1.9698195d-02,-8.3579639d-06, 3.7399304d-06 /
      data fpp(10,14,17,1),fpp(10,14,17,2),fpp(10,14,17,3)/
     x 2.0599300d-02,-9.9345720d-06, 1.4068679d-06 /
      data fpp(10,14,18,1),fpp(10,14,18,2),fpp(10,14,18,3)/
     x 2.1999110d-02,-1.1110582d-05,-1.2374021d-06 /
      data fpp(10,14,19,1),fpp(10,14,19,2),fpp(10,14,19,3)/
     x 2.4109556d-02,-1.1689833d-05,-3.5312596d-06 /
      data fpp(10,14,20,1),fpp(10,14,20,2),fpp(10,14,20,3)/
     x 2.6535270d-02,-1.1686649d-05,-6.1835595d-06 /
      data fpp(10,14,21,1),fpp(10,14,21,2),fpp(10,14,21,3)/
     x 2.6535270d-02,-1.1686649d-05,-6.2336917d-06 /
      data fpp(10,14,22,1),fpp(10,14,22,2),fpp(10,14,22,3)/
     x 2.4109556d-02,-1.1689833d-05,-3.3307310d-06 /
      data fpp(10,14,23,1),fpp(10,14,23,2),fpp(10,14,23,3)/
     x 2.1999110d-02,-1.1110582d-05,-1.9893845d-06 /
      data fpp(10,15, 1,1),fpp(10,15, 1,2),fpp(10,15, 1,3)/
     x-1.6619573d-02, 1.0581026d-04, 8.0361723d-05 /
      data fpp(10,15, 2,1),fpp(10,15, 2,2),fpp(10,15, 2,3)/
     x 4.1283199d-02, 1.3028238d-04, 6.0941554d-05 /
      data fpp(10,15, 3,1),fpp(10,15, 3,2),fpp(10,15, 3,3)/
     x 1.0355173d-01, 1.7179345d-04, 2.0152061d-05 /
      data fpp(10,15, 4,1),fpp(10,15, 4,2),fpp(10,15, 4,3)/
     x 1.0355173d-01, 1.7179345d-04, 1.8708040d-05 /
      data fpp(10,15, 5,1),fpp(10,15, 5,2),fpp(10,15, 5,3)/
     x 4.1283199d-02, 1.3028238d-04, 6.6717640d-05 /
      data fpp(10,15, 6,1),fpp(10,15, 6,2),fpp(10,15, 6,3)/
     x-1.6619573d-02, 1.0581026d-04, 5.8701399d-05 /
      data fpp(10,15, 7,1),fpp(10,15, 7,2),fpp(10,15, 7,3)/
     x-5.5330542d-02, 9.3398082d-05, 2.3448763d-05 /
      data fpp(10,15, 8,1),fpp(10,15, 8,2),fpp(10,15, 8,3)/
     x-7.6055857d-02, 7.1563842d-05,-2.0970452d-05 /
      data fpp(10,15, 9,1),fpp(10,15, 9,2),fpp(10,15, 9,3)/
     x-6.8950067d-02, 3.8835280d-05,-6.1408954d-05 /
      data fpp(10,15,10,1),fpp(10,15,10,2),fpp(10,15,10,3)/
     x-2.7551217d-02, 2.7061067d-05,-6.4455731d-05 /
      data fpp(10,15,11,1),fpp(10,15,11,2),fpp(10,15,11,3)/
     x 1.0225234d-02, 1.3207563d-05,-2.3002122d-05 /
      data fpp(10,15,12,1),fpp(10,15,12,2),fpp(10,15,12,3)/
     x 1.8685897d-02, 5.9482880d-06,-6.8317814d-06 /
      data fpp(10,15,13,1),fpp(10,15,13,2),fpp(10,15,13,3)/
     x 1.9853806d-02, 2.2085938d-06, 1.9247515d-08 /
      data fpp(10,15,14,1),fpp(10,15,14,2),fpp(10,15,14,3)/
     x 2.0027740d-02,-7.0027213d-08, 2.5607913d-06 /
      data fpp(10,15,15,1),fpp(10,15,15,2),fpp(10,15,15,3)/
     x 2.0263374d-02,-1.6032695d-06, 3.1295871d-06 /
      data fpp(10,15,16,1),fpp(10,15,16,2),fpp(10,15,16,3)/
     x 2.0782029d-02,-2.6938412d-06, 2.3448602d-06 /
      data fpp(10,15,17,1),fpp(10,15,17,2),fpp(10,15,17,3)/
     x 2.1499228d-02,-3.3711395d-06, 7.7497217d-07 /
      data fpp(10,15,18,1),fpp(10,15,18,2),fpp(10,15,18,3)/
     x 2.2320073d-02,-3.6606535d-06,-1.0767488d-06 /
      data fpp(10,15,19,1),fpp(10,15,19,2),fpp(10,15,19,3)/
     x 2.3295292d-02,-3.4996304d-06,-2.6539768d-06 /
      data fpp(10,15,20,1),fpp(10,15,20,2),fpp(10,15,20,3)/
     x 2.4096287d-02,-2.9877516d-06,-3.8833440d-06 /
      data fpp(10,15,21,1),fpp(10,15,21,2),fpp(10,15,21,3)/
     x 2.4096287d-02,-2.9877516d-06,-3.9309796d-06 /
      data fpp(10,15,22,1),fpp(10,15,22,2),fpp(10,15,22,3)/
     x 2.3295292d-02,-3.4996304d-06,-2.4634344d-06 /
      data fpp(10,15,23,1),fpp(10,15,23,2),fpp(10,15,23,3)/
     x 2.2320073d-02,-3.6606535d-06,-1.7912828d-06 /
      data fpp(10,16, 1,1),fpp(10,16, 1,2),fpp(10,16, 1,3)/
     x-3.4109335d-02, 9.0342415d-05, 3.8241854d-05 /
      data fpp(10,16, 2,1),fpp(10,16, 2,2),fpp(10,16, 2,3)/
     x-1.3867987d-02, 1.2454168d-04, 3.7467793d-05 /
      data fpp(10,16, 3,1),fpp(10,16, 3,2),fpp(10,16, 3,3)/
     x 3.0878418d-03, 1.6236708d-04, 3.6064975d-05 /
      data fpp(10,16, 4,1),fpp(10,16, 4,2),fpp(10,16, 4,3)/
     x 3.0878418d-03, 1.6236708d-04, 3.5617177d-05 /
      data fpp(10,16, 5,1),fpp(10,16, 5,2),fpp(10,16, 5,3)/
     x-1.3867987d-02, 1.2454168d-04, 3.9258985d-05 /
      data fpp(10,16, 6,1),fpp(10,16, 6,2),fpp(10,16, 6,3)/
     x-3.4109335d-02, 9.0342415d-05, 3.1524884d-05 /
      data fpp(10,16, 7,1),fpp(10,16, 7,2),fpp(10,16, 7,3)/
     x-5.2432615d-02, 6.8915720d-05, 1.5283481d-05 /
      data fpp(10,16, 8,1),fpp(10,16, 8,2),fpp(10,16, 8,3)/
     x-7.6348525d-02, 7.8514197d-05,-1.7172808d-05 /
      data fpp(10,16, 9,1),fpp(10,16, 9,2),fpp(10,16, 9,3)/
     x-1.6209779d-01, 9.0439410d-05,-4.0312249d-05 /
      data fpp(10,16,10,1),fpp(10,16,10,2),fpp(10,16,10,3)/
     x-5.2889466d-02, 3.7417518d-05,-6.4776195d-05 /
      data fpp(10,16,11,1),fpp(10,16,11,2),fpp(10,16,11,3)/
     x 5.1308252d-03, 1.5756323d-05,-1.2204970d-05 /
      data fpp(10,16,12,1),fpp(10,16,12,2),fpp(10,16,12,3)/
     x 1.7055450d-02, 9.0914486d-06,-5.4199246d-06 /
      data fpp(10,16,13,1),fpp(10,16,13,2),fpp(10,16,13,3)/
     x 1.9555079d-02, 5.8697171d-06, 7.4668406d-08 /
      data fpp(10,16,14,1),fpp(10,16,14,2),fpp(10,16,14,3)/
     x 2.0215854d-02, 4.2105124d-06, 1.3712510d-06 /
      data fpp(10,16,15,1),fpp(10,16,15,2),fpp(10,16,15,3)/
     x 2.0560280d-02, 3.5647423d-06, 1.7903277d-06 /
      data fpp(10,16,16,1),fpp(10,16,16,2),fpp(10,16,16,3)/
     x 2.0972425d-02, 3.7193286d-06, 1.3554381d-06 /
      data fpp(10,16,17,1),fpp(10,16,17,2),fpp(10,16,17,3)/
     x 2.1445053d-02, 4.4051302d-06, 4.9791989d-07 /
      data fpp(10,16,18,1),fpp(10,16,18,2),fpp(10,16,18,3)/
     x 2.1811539d-02, 5.3651958d-06,-5.1511764d-07 /
      data fpp(10,16,19,1),fpp(10,16,19,2),fpp(10,16,19,3)/
     x 2.2265783d-02, 6.3083545d-06,-1.3534493d-06 /
      data fpp(10,16,20,1),fpp(10,16,20,2),fpp(10,16,20,3)/
     x 2.2510301d-02, 6.9636551d-06,-1.9790850d-06 /
      data fpp(10,16,21,1),fpp(10,16,21,2),fpp(10,16,21,3)/
     x 2.2510301d-02, 6.9636551d-06,-2.0050202d-06 /
      data fpp(10,16,22,1),fpp(10,16,22,2),fpp(10,16,22,3)/
     x 2.2265783d-02, 6.3083545d-06,-1.2497085d-06 /
      data fpp(10,16,23,1),fpp(10,16,23,2),fpp(10,16,23,3)/
     x 2.1811539d-02, 5.3651958d-06,-9.0414575d-07 /
      data fpp(10,17, 1,1),fpp(10,17, 1,2),fpp(10,17, 1,3)/
     x-3.8995487d-02, 1.2402408d-04, 2.0348901d-05 /
      data fpp(10,17, 2,1),fpp(10,17, 2,2),fpp(10,17, 2,3)/
     x-3.5868918d-02, 1.2714889d-04, 2.2292699d-05 /
      data fpp(10,17, 3,1),fpp(10,17, 3,2),fpp(10,17, 3,3)/
     x-3.3462623d-02, 1.3075225d-04, 2.6578304d-05 /
      data fpp(10,17, 4,1),fpp(10,17, 4,2),fpp(10,17, 4,3)/
     x-3.3462623d-02, 1.3075225d-04, 2.6367738d-05 /
      data fpp(10,17, 5,1),fpp(10,17, 5,2),fpp(10,17, 5,3)/
     x-3.5868918d-02, 1.2714889d-04, 2.3134962d-05 /
      data fpp(10,17, 6,1),fpp(10,17, 6,2),fpp(10,17, 6,3)/
     x-3.8995487d-02, 1.2402408d-04, 1.7190413d-05 /
      data fpp(10,17, 7,1),fpp(10,17, 7,2),fpp(10,17, 7,3)/
     x-4.1968446d-02, 1.2325704d-04, 9.9233842d-06 /
      data fpp(10,17, 8,1),fpp(10,17, 8,2),fpp(10,17, 8,3)/
     x 4.7567417d-02, 4.0025370d-05,-5.2239501d-06 /
      data fpp(10,17, 9,1),fpp(10,17, 9,2),fpp(10,17, 9,3)/
     x-1.0736284d-01,-4.9946918d-05,-6.2953584d-05 /
      data fpp(10,17,10,1),fpp(10,17,10,2),fpp(10,17,10,3)/
     x-6.7445978d-03,-2.6095139d-05,-2.3305715d-05 /
      data fpp(10,17,11,1),fpp(10,17,11,2),fpp(10,17,11,3)/
     x 7.5345819d-03,-1.1368563d-06,-3.6355589d-07 /
      data fpp(10,17,12,1),fpp(10,17,12,2),fpp(10,17,12,3)/
     x 1.6493978d-02, 5.8599177d-06,-1.3580613d-06 /
      data fpp(10,17,13,1),fpp(10,17,13,2),fpp(10,17,13,3)/
     x 1.9284467d-02, 7.9425377d-06, 8.6380119d-07 /
      data fpp(10,17,14,1),fpp(10,17,14,2),fpp(10,17,14,3)/
     x 2.0189152d-02, 8.7339774d-06, 1.0168566d-06 /
      data fpp(10,17,15,1),fpp(10,17,15,2),fpp(10,17,15,3)/
     x 2.0536044d-02, 9.4603001d-06, 1.1107726d-06 /
      data fpp(10,17,16,1),fpp(10,17,16,2),fpp(10,17,16,3)/
     x 2.0766419d-02, 1.0502527d-05, 8.5205319d-07 /
      data fpp(10,17,17,1),fpp(10,17,17,2),fpp(10,17,17,3)/
     x 2.1004034d-02, 1.1880619d-05, 4.9101467d-07 /
      data fpp(10,17,18,1),fpp(10,17,18,2),fpp(10,17,18,3)/
     x 2.1226958d-02, 1.3369870d-05, 7.5888128d-08 /
      data fpp(10,17,19,1),fpp(10,17,19,2),fpp(10,17,19,3)/
     x 2.1413281d-02, 1.4662212d-05,-2.5456718d-07 /
      data fpp(10,17,20,1),fpp(10,17,20,2),fpp(10,17,20,3)/
     x 2.1536274d-02, 1.5507131d-05,-5.4561940d-07 /
      data fpp(10,17,21,1),fpp(10,17,21,2),fpp(10,17,21,3)/
     x 2.1536274d-02, 1.5507131d-05,-5.5485821d-07 /
      data fpp(10,17,22,1),fpp(10,17,22,2),fpp(10,17,22,3)/
     x 2.1413281d-02, 1.4662212d-05,-2.1761194d-07 /
      data fpp(10,17,23,1),fpp(10,17,23,2),fpp(10,17,23,3)/
     x 2.1226958d-02, 1.3369870d-05,-6.2694030d-08 /
      data fpp(10,18, 1,1),fpp(10,18, 1,2),fpp(10,18, 1,3)/
     x 5.1696210d-02,-2.8152474d-04, 8.6811582d-06 /
      data fpp(10,18, 2,1),fpp(10,18, 2,2),fpp(10,18, 2,3)/
     x 1.3512372d-01,-2.9087926d-04, 9.5041836d-06 /
      data fpp(10,18, 3,1),fpp(10,18, 3,2),fpp(10,18, 3,3)/
     x 2.7000477d-02,-2.9637807d-04, 1.0716107d-05 /
      data fpp(10,18, 4,1),fpp(10,18, 4,2),fpp(10,18, 4,3)/
     x 2.7000477d-02,-2.9637807d-04, 1.1681586d-05 /
      data fpp(10,18, 5,1),fpp(10,18, 5,2),fpp(10,18, 5,3)/
     x 1.3512372d-01,-2.9087926d-04, 5.6422698d-06 /
      data fpp(10,18, 6,1),fpp(10,18, 6,2),fpp(10,18, 6,3)/
     x 5.1696210d-02,-2.8152474d-04, 2.3163335d-05 /
      data fpp(10,18, 7,1),fpp(10,18, 7,2),fpp(10,18, 7,3)/
     x-8.2928229d-01,-2.7039187d-04,-5.1315609d-05 /
      data fpp(10,18, 8,1),fpp(10,18, 8,2),fpp(10,18, 8,3)/
     x-1.9201966d-01,-1.7504568d-04,-4.6868983d-06 /
      data fpp(10,18, 9,1),fpp(10,18, 9,2),fpp(10,18, 9,3)/
     x 7.1452323d-02,-6.8275738d-05, 2.7192023d-06 /
      data fpp(10,18,10,1),fpp(10,18,10,2),fpp(10,18,10,3)/
     x 1.0912723d-02,-2.7572960d-05, 6.0208893d-07 /
      data fpp(10,18,11,1),fpp(10,18,11,2),fpp(10,18,11,3)/
     x 1.4734021d-02,-1.4982898d-05, 1.0884419d-06 /
      data fpp(10,18,12,1),fpp(10,18,12,2),fpp(10,18,12,3)/
     x 2.0575012d-02,-6.4671193d-06, 9.0014336d-07 /
      data fpp(10,18,13,1),fpp(10,18,13,2),fpp(10,18,13,3)/
     x 1.9908732d-02,-1.0386791d-07, 8.9098464d-07 /
      data fpp(10,18,14,1),fpp(10,18,14,2),fpp(10,18,14,3)/
     x 2.0891025d-02, 5.1635779d-06, 8.1591808d-07 /
      data fpp(10,18,15,1),fpp(10,18,15,2),fpp(10,18,15,3)/
     x 2.1641390d-02, 9.8340571d-06, 7.3534303d-07 /
      data fpp(10,18,16,1),fpp(10,18,16,2),fpp(10,18,16,3)/
     x 2.2216395d-02, 1.4084564d-05, 6.2270979d-07 /
      data fpp(10,18,17,1),fpp(10,18,17,2),fpp(10,18,17,3)/
     x 2.2755067d-02, 1.7894395d-05, 5.1781782d-07 /
      data fpp(10,18,18,1),fpp(10,18,18,2),fpp(10,18,18,3)/
     x 2.3107393d-02, 2.1129323d-05, 4.0201894d-07 /
      data fpp(10,18,19,1),fpp(10,18,19,2),fpp(10,18,19,3)/
     x 2.3427748d-02, 2.3620797d-05, 3.2210642d-07 /
      data fpp(10,18,20,1),fpp(10,18,20,2),fpp(10,18,20,3)/
     x 2.3553880d-02, 2.5201820d-05, 2.5355539d-07 /
      data fpp(10,18,21,1),fpp(10,18,21,2),fpp(10,18,21,3)/
     x 2.3553880d-02, 2.5201820d-05, 2.5128061d-07 /
      data fpp(10,18,22,1),fpp(10,18,22,2),fpp(10,18,22,3)/
     x 2.3427748d-02, 2.3620797d-05, 3.3120554d-07 /
      data fpp(10,18,23,1),fpp(10,18,23,2),fpp(10,18,23,3)/
     x 2.3107393d-02, 2.1129323d-05, 3.6789723d-07 /
      data fpp(10,19, 1,1),fpp(10,19, 1,2),fpp(10,19, 1,3)/
     x 2.1324497d-02,-5.6157913d-04,-3.2574864d-20 /
      data fpp(10,19, 2,1),fpp(10,19, 2,2),fpp(10,19, 2,3)/
     x 2.1324497d-02,-5.8872587d-04,-2.5377129d-20 /
      data fpp(10,19, 3,1),fpp(10,19, 3,2),fpp(10,19, 3,3)/
     x 2.1324497d-02,-6.1050396d-04,-2.3618882d-20 /
      data fpp(10,19, 4,1),fpp(10,19, 4,2),fpp(10,19, 4,3)/
     x 2.1324497d-02,-6.1050396d-04, 4.2715081d-20 /
      data fpp(10,19, 5,1),fpp(10,19, 5,2),fpp(10,19, 5,3)/
     x 2.1324497d-02,-5.8872587d-04,-8.6132451d-21 /
      data fpp(10,19, 6,1),fpp(10,19, 6,2),fpp(10,19, 6,3)/
     x 2.1324497d-02,-5.6157913d-04,-1.8680879d-20 /
      data fpp(10,19, 7,1),fpp(10,19, 7,2),fpp(10,19, 7,3)/
     x 2.1324497d-02,-5.3604357d-04,-3.2349127d-20 /
      data fpp(10,19, 8,1),fpp(10,19, 8,2),fpp(10,19, 8,3)/
     x 2.1324497d-02,-3.3966466d-04,-2.5100357d-20 /
      data fpp(10,19, 9,1),fpp(10,19, 9,2),fpp(10,19, 9,3)/
     x 2.1324497d-02,-1.2147813d-04,-2.1653514d-20 /
      data fpp(10,19,10,1),fpp(10,19,10,2),fpp(10,19,10,3)/
     x 2.1324497d-02,-4.6775020d-05, 4.9907276d-20 /
      data fpp(10,19,11,1),fpp(10,19,11,2),fpp(10,19,11,3)/
     x 2.1324497d-02,-2.9699551d-05,-2.2015350d-20 /
      data fpp(10,19,12,1),fpp(10,19,12,2),fpp(10,19,12,3)/
     x 2.1324497d-02,-1.6195440d-05, 4.6426108d-20 /
      data fpp(10,19,13,1),fpp(10,19,13,2),fpp(10,19,13,3)/
     x 2.1324497d-02,-5.2590660d-06, 3.2798820d-20 /
      data fpp(10,19,14,1),fpp(10,19,14,2),fpp(10,19,14,3)/
     x 2.1324497d-02, 3.9057111d-06, 1.4993466d-20 /
      data fpp(10,19,15,1),fpp(10,19,15,2),fpp(10,19,15,3)/
     x 2.1324497d-02, 1.1785471d-05,-1.7478695d-20 /
      data fpp(10,19,16,1),fpp(10,19,16,2),fpp(10,19,16,3)/
     x 2.1324497d-02, 1.8581218d-05,-2.3744995d-20 /
      data fpp(10,19,17,1),fpp(10,19,17,2),fpp(10,19,17,3)/
     x 2.1324497d-02, 2.4325803d-05, 1.1740218d-20 /
      data fpp(10,19,18,1),fpp(10,19,18,2),fpp(10,19,18,3)/
     x 2.1324497d-02, 2.8958839d-05,-4.3500993d-20 /
      data fpp(10,19,19,1),fpp(10,19,19,2),fpp(10,19,19,3)/
     x 2.1324497d-02, 3.2406602d-05,-5.3926112d-20 /
      data fpp(10,19,20,1),fpp(10,19,20,2),fpp(10,19,20,3)/
     x 2.1324497d-02, 3.4567590d-05, 3.2713533d-20 /
      data fpp(10,19,21,1),fpp(10,19,21,2),fpp(10,19,21,3)/
     x 2.1324497d-02, 3.4567590d-05,-2.4714655d-20 /
      data fpp(10,19,22,1),fpp(10,19,22,2),fpp(10,19,22,3)/
     x 2.1324497d-02, 3.2406602d-05, 1.8963193d-20 /
      data fpp(10,19,23,1),fpp(10,19,23,2),fpp(10,19,23,3)/
     x 2.1324497d-02, 2.8958839d-05, 1.3321339d-19 /
      data fpp(11, 1, 1,1),fpp(11, 1, 1,2),fpp(11, 1, 1,3)/
     x 2.5777964d+00, 2.1887054d-03,-5.0330760d-19 /
      data fpp(11, 1, 2,1),fpp(11, 1, 2,2),fpp(11, 1, 2,3)/
     x 2.5777964d+00, 2.6019091d-03,-3.4281390d-19 /
      data fpp(11, 1, 3,1),fpp(11, 1, 3,2),fpp(11, 1, 3,3)/
     x 2.5777964d+00, 3.0070424d-03,-2.0081561d-19 /
      data fpp(11, 1, 4,1),fpp(11, 1, 4,2),fpp(11, 1, 4,3)/
     x 2.5777964d+00, 3.0070424d-03, 1.8515418d-19 /
      data fpp(11, 1, 5,1),fpp(11, 1, 5,2),fpp(11, 1, 5,3)/
     x 2.5777964d+00, 2.6019091d-03, 2.1151563d-19 /
      data fpp(11, 1, 6,1),fpp(11, 1, 6,2),fpp(11, 1, 6,3)/
     x 2.5777964d+00, 2.1887054d-03,-2.4354139d-19 /
      data fpp(11, 1, 7,1),fpp(11, 1, 7,2),fpp(11, 1, 7,3)/
     x 2.5777964d+00, 1.3269130d-04,-6.0064521d-19 /
      data fpp(11, 1, 8,1),fpp(11, 1, 8,2),fpp(11, 1, 8,3)/
     x 2.5777964d+00,-4.9822711d-04,-3.3883152d-19 /
      data fpp(11, 1, 9,1),fpp(11, 1, 9,2),fpp(11, 1, 9,3)/
     x 2.5777964d+00,-7.3759561d-04, 3.7117096d-19 /
      data fpp(11, 1,10,1),fpp(11, 1,10,2),fpp(11, 1,10,3)/
     x 2.5777964d+00,-8.1902402d-04, 4.7426314d-19 /
      data fpp(11, 1,11,1),fpp(11, 1,11,2),fpp(11, 1,11,3)/
     x 2.5777964d+00,-8.5358011d-04, 1.0449321d-19 /
      data fpp(11, 1,12,1),fpp(11, 1,12,2),fpp(11, 1,12,3)/
     x 2.5777964d+00,-8.6483660d-04, 2.6824130d-19 /
      data fpp(11, 1,13,1),fpp(11, 1,13,2),fpp(11, 1,13,3)/
     x 2.5777964d+00,-8.6016451d-04, 2.2132982d-19 /
      data fpp(11, 1,14,1),fpp(11, 1,14,2),fpp(11, 1,14,3)/
     x 2.5777964d+00,-8.3165492d-04, 6.8873671d-20 /
      data fpp(11, 1,15,1),fpp(11, 1,15,2),fpp(11, 1,15,3)/
     x 2.5777964d+00,-7.5382559d-04, 1.3398893d-19 /
      data fpp(11, 1,16,1),fpp(11, 1,16,2),fpp(11, 1,16,3)/
     x 2.5777964d+00,-5.1493420d-04,-9.9283266d-20 /
      data fpp(11, 1,17,1),fpp(11, 1,17,2),fpp(11, 1,17,3)/
     x 2.5777964d+00, 1.1150018d-04, 3.3414524d-19 /
      data fpp(11, 1,18,1),fpp(11, 1,18,2),fpp(11, 1,18,3)/
     x 2.5777964d+00, 2.1614914d-03,-2.0885785d-19 /
      data fpp(11, 1,19,1),fpp(11, 1,19,2),fpp(11, 1,19,3)/
     x 2.5777964d+00, 2.4948406d-03,-4.0416008d-19 /
      data fpp(11, 1,20,1),fpp(11, 1,20,2),fpp(11, 1,20,3)/
     x 2.5777964d+00, 2.8879332d-03, 1.5319933d-19 /
      data fpp(11, 1,21,1),fpp(11, 1,21,2),fpp(11, 1,21,3)/
     x 2.5777964d+00, 2.8879332d-03,-2.8969477d-19 /
      data fpp(11, 1,22,1),fpp(11, 1,22,2),fpp(11, 1,22,3)/
     x 2.5777964d+00, 2.4948406d-03, 3.6427349d-19 /
      data fpp(11, 1,23,1),fpp(11, 1,23,2),fpp(11, 1,23,3)/
     x 2.5777964d+00, 2.1614914d-03, 1.4351087d-18 /
      data fpp(11, 2, 1,1),fpp(11, 2, 1,2),fpp(11, 2, 1,3)/
     x 4.0325659d-01, 8.8686615d-04,-2.7959919d-06 /
      data fpp(11, 2, 2,1),fpp(11, 2, 2,2),fpp(11, 2, 2,3)/
     x 5.0689119d-01, 9.0828178d-04,-2.9864016d-05 /
      data fpp(11, 2, 3,1),fpp(11, 2, 3,2),fpp(11, 2, 3,3)/
     x 1.2678131d+00, 1.0673711d-03,-8.8119943d-05 /
      data fpp(11, 2, 4,1),fpp(11, 2, 4,2),fpp(11, 2, 4,3)/
     x 1.2678131d+00, 1.0673711d-03,-8.7677162d-05 /
      data fpp(11, 2, 5,1),fpp(11, 2, 5,2),fpp(11, 2, 5,3)/
     x 5.0689119d-01, 9.0828178d-04,-3.1635140d-05 /
      data fpp(11, 2, 6,1),fpp(11, 2, 6,2),fpp(11, 2, 6,3)/
     x 4.0325659d-01, 8.8686615d-04, 3.8457213d-06 /
      data fpp(11, 2, 7,1),fpp(11, 2, 7,2),fpp(11, 2, 7,3)/
     x 7.0559463d-01, 9.6328407d-05, 2.5780254d-05 /
      data fpp(11, 2, 8,1),fpp(11, 2, 8,2),fpp(11, 2, 8,3)/
     x 9.3259760d-01,-1.2798078d-04, 2.8969261d-05 /
      data fpp(11, 2, 9,1),fpp(11, 2, 9,2),fpp(11, 2, 9,3)/
     x 9.2533644d-01,-2.0323078d-04, 3.1052702d-05 /
      data fpp(11, 2,10,1),fpp(11, 2,10,2),fpp(11, 2,10,3)/
     x 9.1763967d-01,-2.2058495d-04, 2.9813931d-05 /
      data fpp(11, 2,11,1),fpp(11, 2,11,2),fpp(11, 2,11,3)/
     x 9.0308211d-01,-2.2554078d-04, 3.0813574d-05 /
      data fpp(11, 2,12,1),fpp(11, 2,12,2),fpp(11, 2,12,3)/
     x 6.9654881d-01,-2.2797280d-04, 2.9511772d-05 /
      data fpp(11, 2,13,1),fpp(11, 2,13,2),fpp(11, 2,13,3)/
     x 7.4172051d-01,-2.3086298d-04, 3.0593336d-05 /
      data fpp(11, 2,14,1),fpp(11, 2,14,2),fpp(11, 2,14,3)/
     x 9.1229155d-01,-2.3090315d-04, 3.0268883d-05 /
      data fpp(11, 2,15,1),fpp(11, 2,15,2),fpp(11, 2,15,3)/
     x 9.1062948d-01,-2.1737481d-04, 3.0785132d-05 /
      data fpp(11, 2,16,1),fpp(11, 2,16,2),fpp(11, 2,16,3)/
     x 9.1563694d-01,-1.4421760d-04, 2.9890590d-05 /
      data fpp(11, 2,17,1),fpp(11, 2,17,2),fpp(11, 2,17,3)/
     x 6.6673818d-01, 7.7516641d-05, 2.4024509d-05 /
      data fpp(11, 2,18,1),fpp(11, 2,18,2),fpp(11, 2,18,3)/
     x 3.7357096d-01, 8.6683126d-04, 3.6953734d-06 /
      data fpp(11, 2,19,1),fpp(11, 2,19,2),fpp(11, 2,19,3)/
     x 6.4246643d-01, 8.6305075d-04,-3.2110003d-05 /
      data fpp(11, 2,20,1),fpp(11, 2,20,2),fpp(11, 2,20,3)/
     x 1.4013206d+00, 1.0246666d-03,-8.8993363d-05 /
      data fpp(11, 2,21,1),fpp(11, 2,21,2),fpp(11, 2,21,3)/
     x 1.4013206d+00, 1.0246666d-03,-8.9432911d-05 /
      data fpp(11, 2,22,1),fpp(11, 2,22,2),fpp(11, 2,22,3)/
     x 6.4246643d-01, 8.6305075d-04,-3.0351811d-05 /
      data fpp(11, 2,23,1),fpp(11, 2,23,2),fpp(11, 2,23,3)/
     x 3.7357096d-01, 8.6683126d-04,-2.8978444d-06 /
      data fpp(11, 3, 1,1),fpp(11, 3, 1,2),fpp(11, 3, 1,3)/
     x-1.4764188d-01,-1.9575440d-03,-1.5746865d-04 /
      data fpp(11, 3, 2,1),fpp(11, 3, 2,2),fpp(11, 3, 2,3)/
     x 4.0955603d-02,-1.0157442d-03,-1.9016920d-04 /
      data fpp(11, 3, 3,1),fpp(11, 3, 3,2),fpp(11, 3, 3,3)/
     x-5.8834158d-02,-1.3521749d-03,-2.3820454d-04 /
      data fpp(11, 3, 4,1),fpp(11, 3, 4,2),fpp(11, 3, 4,3)/
     x-5.8834158d-02,-1.3521749d-03,-2.7676977d-04 /
      data fpp(11, 3, 5,1),fpp(11, 3, 5,2),fpp(11, 3, 5,3)/
     x 4.0955603d-02,-1.0157442d-03,-3.5908301d-05 /
      data fpp(11, 3, 6,1),fpp(11, 3, 6,2),fpp(11, 3, 6,3)/
     x-1.4764188d-01,-1.9575440d-03,-7.3594703d-04 /
      data fpp(11, 3, 7,1),fpp(11, 3, 7,2),fpp(11, 3, 7,3)/
     x 1.9720021d-01,-2.7353492d-04, 9.0526241d-04 /
      data fpp(11, 3, 8,1),fpp(11, 3, 8,2),fpp(11, 3, 8,3)/
     x 2.4483184d-01, 3.2970822d-04,-3.9866209d-06 /
      data fpp(11, 3, 9,1),fpp(11, 3, 9,2),fpp(11, 3, 9,3)/
     x 2.1903644d-01, 6.2519872d-04, 1.3613807d-04 /
      data fpp(11, 3,10,1),fpp(11, 3,10,2),fpp(11, 3,10,3)/
     x 2.1049983d-01, 7.5386184d-04, 4.8118335d-05 /
      data fpp(11, 3,11,1),fpp(11, 3,11,2),fpp(11, 3,11,3)/
     x 2.6173885d-01, 8.1541722d-04, 6.2990589d-05 /
      data fpp(11, 3,12,1),fpp(11, 3,12,2),fpp(11, 3,12,3)/
     x 2.5675152d-01, 8.3116381d-04, 5.2665311d-05 /
      data fpp(11, 3,13,1),fpp(11, 3,13,2),fpp(11, 3,13,3)/
     x 2.0442369d-01, 8.1066842d-04, 6.3110168d-05 /
      data fpp(11, 3,14,1),fpp(11, 3,14,2),fpp(11, 3,14,3)/
     x 2.1615942d-01, 7.4522154d-04, 4.9488017d-05 /
      data fpp(11, 3,15,1),fpp(11, 3,15,2),fpp(11, 3,15,3)/
     x-4.2970195d-01, 6.1196484d-04, 1.3962976d-04 /
      data fpp(11, 3,16,1),fpp(11, 3,16,2),fpp(11, 3,16,3)/
     x 2.4250313d-01, 3.1244061d-04,-8.0970729d-06 /
      data fpp(11, 3,17,1),fpp(11, 3,17,2),fpp(11, 3,17,3)/
     x 1.8933756d-01,-2.9079674d-04, 9.1964053d-04 /
      data fpp(11, 3,18,1),fpp(11, 3,18,2),fpp(11, 3,18,3)/
     x-9.4625654d-02,-1.9653844d-03,-7.8856904d-04 /
      data fpp(11, 3,19,1),fpp(11, 3,19,2),fpp(11, 3,19,3)/
     x 3.3250176d-02,-9.9009562d-04, 8.8816251d-06 /
      data fpp(11, 3,20,1),fpp(11, 3,20,2),fpp(11, 3,20,3)/
     x-5.9608057d-02,-1.3456336d-03,-2.8393146d-04 /
      data fpp(11, 3,21,1),fpp(11, 3,21,2),fpp(11, 3,21,3)/
     x-5.9608057d-02,-1.3456336d-03,-2.3959143d-04 /
      data fpp(11, 3,22,1),fpp(11, 3,22,2),fpp(11, 3,22,3)/
     x 3.3250176d-02,-9.9009562d-04,-1.6847852d-04 /
      data fpp(11, 3,23,1),fpp(11, 3,23,2),fpp(11, 3,23,3)/
     x-9.4625654d-02,-1.9653844d-03,-1.2346849d-04 /
      data fpp(11, 4, 1,1),fpp(11, 4, 1,2),fpp(11, 4, 1,3)/
     x-5.8894365d-02, 5.9704391d-04,-1.0306399d-03 /
      data fpp(11, 4, 2,1),fpp(11, 4, 2,2),fpp(11, 4, 2,3)/
     x-3.2765557d-01,-2.1333749d-03,-7.5709066d-04 /
      data fpp(11, 4, 3,1),fpp(11, 4, 3,2),fpp(11, 4, 3,3)/
     x-8.6444623d-02,-2.0921594d-03,-2.4693944d-04 /
      data fpp(11, 4, 4,1),fpp(11, 4, 4,2),fpp(11, 4, 4,3)/
     x-8.6444623d-02,-2.0921594d-03,-1.1389436d-04 /
      data fpp(11, 4, 5,1),fpp(11, 4, 5,2),fpp(11, 4, 5,3)/
     x-3.2765557d-01,-2.1333749d-03,-1.2892710d-03 /
      data fpp(11, 4, 6,1),fpp(11, 4, 6,2),fpp(11, 4, 6,3)/
     x-5.8894365d-02, 5.9704391d-04, 9.6503627d-04 /
      data fpp(11, 4, 7,1),fpp(11, 4, 7,2),fpp(11, 4, 7,3)/
     x-5.3241490d-01, 5.2385329d-04, 2.0123391d-04 /
      data fpp(11, 4, 8,1),fpp(11, 4, 8,2),fpp(11, 4, 8,3)/
     x 4.8778095d-02, 4.8134791d-04, 1.3017409d-04 /
      data fpp(11, 4, 9,1),fpp(11, 4, 9,2),fpp(11, 4, 9,3)/
     x 5.3938879d-02, 4.2440189d-04, 5.9875716d-05 /
      data fpp(11, 4,10,1),fpp(11, 4,10,2),fpp(11, 4,10,3)/
     x 4.8570819d-01, 4.1228159d-04, 6.0109041d-05 /
      data fpp(11, 4,11,1),fpp(11, 4,11,2),fpp(11, 4,11,3)/
     x 2.5471193d-01, 4.1115991d-04, 5.6736120d-05 /
      data fpp(11, 4,12,1),fpp(11, 4,12,2),fpp(11, 4,12,3)/
     x 5.4648821d-02, 4.1234555d-04, 5.7454480d-05 /
      data fpp(11, 4,13,1),fpp(11, 4,13,2),fpp(11, 4,13,3)/
     x 2.3287444d-01, 4.0939530d-04, 5.7953959d-05 /
      data fpp(11, 4,14,1),fpp(11, 4,14,2),fpp(11, 4,14,3)/
     x 5.7202503d-01, 4.0754099d-04, 6.1903684d-05 /
      data fpp(11, 4,15,1),fpp(11, 4,15,2),fpp(11, 4,15,3)/
     x 5.3326895d-02, 4.1619346d-04, 6.6197306d-05 /
      data fpp(11, 4,16,1),fpp(11, 4,16,2),fpp(11, 4,16,3)/
     x 5.1819583d-02, 4.6830316d-04, 1.2784309d-04 /
      data fpp(11, 4,17,1),fpp(11, 4,17,2),fpp(11, 4,17,3)/
     x 4.2044983d-02, 5.1104434d-04, 2.2617833d-04 /
      data fpp(11, 4,18,1),fpp(11, 4,18,2),fpp(11, 4,18,3)/
     x-5.2178505d-02, 5.8384444d-04, 9.1378960d-04 /
      data fpp(11, 4,19,1),fpp(11, 4,19,2),fpp(11, 4,19,3)/
     x-2.9362120d-01,-2.0684943d-03,-1.2582687d-03 /
      data fpp(11, 4,20,1),fpp(11, 4,20,2),fpp(11, 4,20,3)/
     x-8.6582449d-02,-1.9413161d-03,-1.1931867d-04 /
      data fpp(11, 4,21,1),fpp(11, 4,21,2),fpp(11, 4,21,3)/
     x-8.6582449d-02,-1.9413161d-03,-2.4765261d-04 /
      data fpp(11, 4,22,1),fpp(11, 4,22,2),fpp(11, 4,22,3)/
     x-2.9362120d-01,-2.0684943d-03,-7.4493297d-04 /
      data fpp(11, 4,23,1),fpp(11, 4,23,2),fpp(11, 4,23,3)/
     x-5.2178505d-02, 5.8384444d-04,-1.0112195d-03 /
      data fpp(11, 5, 1,1),fpp(11, 5, 1,2),fpp(11, 5, 1,3)/
     x-3.9942166d-02, 6.5562638d-04, 2.6243191d-04 /
      data fpp(11, 5, 2,1),fpp(11, 5, 2,2),fpp(11, 5, 2,3)/
     x-1.8930328d-02, 2.4339219d-03, 8.2236189d-05 /
      data fpp(11, 5, 3,1),fpp(11, 5, 3,2),fpp(11, 5, 3,3)/
     x-5.9426704d-02, 2.1555444d-03,-2.9527666d-04 /
      data fpp(11, 5, 4,1),fpp(11, 5, 4,2),fpp(11, 5, 4,3)/
     x-5.9426704d-02, 2.1555444d-03,-3.1036311d-04 /
      data fpp(11, 5, 5,1),fpp(11, 5, 5,2),fpp(11, 5, 5,3)/
     x-1.8930328d-02, 2.4339219d-03, 1.4258197d-04 /
      data fpp(11, 5, 6,1),fpp(11, 5, 6,2),fpp(11, 5, 6,3)/
     x-3.9942166d-02, 6.5562638d-04, 3.6135233d-05 /
      data fpp(11, 5, 7,1),fpp(11, 5, 7,2),fpp(11, 5, 7,3)/
     x-7.7662048d-03, 1.9494376d-04, 6.0511101d-05 /
      data fpp(11, 5, 8,1),fpp(11, 5, 8,2),fpp(11, 5, 8,3)/
     x-3.3379851d-03, 9.4650133d-05, 4.3360365d-05 /
      data fpp(11, 5, 9,1),fpp(11, 5, 9,2),fpp(11, 5, 9,3)/
     x 1.1335147d-04, 1.0450570d-04, 4.8839440d-05 /
      data fpp(11, 5,10,1),fpp(11, 5,10,2),fpp(11, 5,10,3)/
     x 2.6048790d-03, 1.1849979d-04, 4.8783874d-05 /
      data fpp(11, 5,11,1),fpp(11, 5,11,2),fpp(11, 5,11,3)/
     x 4.2092670d-03, 1.2600313d-04, 4.8915062d-05 /
      data fpp(11, 5,12,1),fpp(11, 5,12,2),fpp(11, 5,12,3)/
     x 4.8126157d-03, 1.2733597d-04, 4.9075878d-05 /
      data fpp(11, 5,13,1),fpp(11, 5,13,2),fpp(11, 5,13,3)/
     x 4.5452607d-03, 1.2462839d-04, 5.0209427d-05 /
      data fpp(11, 5,14,1),fpp(11, 5,14,2),fpp(11, 5,14,3)/
     x 3.4479078d-03, 1.1634850d-04, 5.1700413d-05 /
      data fpp(11, 5,15,1),fpp(11, 5,15,2),fpp(11, 5,15,3)/
     x 1.4379948d-03, 1.0203932d-04, 5.4016922d-05 /
      data fpp(11, 5,16,1),fpp(11, 5,16,2),fpp(11, 5,16,3)/
     x 7.3698693d-04, 9.1364747d-05, 5.2589900d-05 /
      data fpp(11, 5,17,1),fpp(11, 5,17,2),fpp(11, 5,17,3)/
     x-6.1075058d-03, 1.7992139d-04, 7.4281479d-05 /
      data fpp(11, 5,18,1),fpp(11, 5,18,2),fpp(11, 5,18,3)/
     x-1.5059552d-02, 6.1507467d-04, 5.6562183d-05 /
      data fpp(11, 5,19,1),fpp(11, 5,19,2),fpp(11, 5,19,3)/
     x-2.3981017d-02, 2.2744747d-03, 1.4492779d-04 /
      data fpp(11, 5,20,1),fpp(11, 5,20,2),fpp(11, 5,20,3)/
     x-6.0613635d-02, 1.8851820d-03,-3.3795933d-04 /
      data fpp(11, 5,21,1),fpp(11, 5,21,2),fpp(11, 5,21,3)/
     x-6.0613635d-02, 1.8851820d-03,-3.2306790d-04 /
      data fpp(11, 5,22,1),fpp(11, 5,22,2),fpp(11, 5,22,3)/
     x-2.3981017d-02, 2.2744747d-03, 8.5362042d-05 /
      data fpp(11, 5,23,1),fpp(11, 5,23,2),fpp(11, 5,23,3)/
     x-1.5059552d-02, 6.1507467d-04, 2.7993373d-04 /
      data fpp(11, 6, 1,1),fpp(11, 6, 1,2),fpp(11, 6, 1,3)/
     x-2.5356976d-02,-1.8328542d-04, 9.5140376d-05 /
      data fpp(11, 6, 2,1),fpp(11, 6, 2,2),fpp(11, 6, 2,3)/
     x-4.2381306d-02,-6.1926066d-04, 1.5558248d-05 /
      data fpp(11, 6, 3,1),fpp(11, 6, 3,2),fpp(11, 6, 3,3)/
     x 1.1282992d-01,-4.9239209d-04,-1.5144537d-04 /
      data fpp(11, 6, 4,1),fpp(11, 6, 4,2),fpp(11, 6, 4,3)/
     x 1.1282992d-01,-4.9239209d-04,-1.5762202d-04 /
      data fpp(11, 6, 5,1),fpp(11, 6, 5,2),fpp(11, 6, 5,3)/
     x-4.2381306d-02,-6.1926066d-04, 4.0264850d-05 /
      data fpp(11, 6, 6,1),fpp(11, 6, 6,2),fpp(11, 6, 6,3)/
     x-2.5356976d-02,-1.8328542d-04, 2.4906191d-06 /
      data fpp(11, 6, 7,1),fpp(11, 6, 7,2),fpp(11, 6, 7,3)/
     x-1.6181892d-02,-6.1466332d-05, 2.5618674d-05 /
      data fpp(11, 6, 8,1),fpp(11, 6, 8,2),fpp(11, 6, 8,3)/
     x-1.1756776d-02,-2.0926444d-05, 2.8930686d-05 /
      data fpp(11, 6, 9,1),fpp(11, 6, 9,2),fpp(11, 6, 9,3)/
     x-9.5637412d-03,-1.5216711d-05, 3.3762582d-05 /
      data fpp(11, 6,10,1),fpp(11, 6,10,2),fpp(11, 6,10,3)/
     x-8.4134220d-03,-1.6580740d-05, 3.5542985d-05 /
      data fpp(11, 6,11,1),fpp(11, 6,11,2),fpp(11, 6,11,3)/
     x-7.8067884d-03,-1.8814427d-05, 3.6963476d-05 /
      data fpp(11, 6,12,1),fpp(11, 6,12,2),fpp(11, 6,12,3)/
     x-7.4759709d-03,-1.9865427d-05, 3.7943109d-05 /
      data fpp(11, 6,13,1),fpp(11, 6,13,2),fpp(11, 6,13,3)/
     x-7.2040368d-03,-1.9440874d-05, 3.8790087d-05 /
      data fpp(11, 6,14,1),fpp(11, 6,14,2),fpp(11, 6,14,3)/
     x-7.1954591d-03,-1.7184981d-05, 3.9588541d-05 /
      data fpp(11, 6,15,1),fpp(11, 6,15,2),fpp(11, 6,15,3)/
     x-7.5276835d-03,-1.3942733d-05, 4.0521748d-05 /
      data fpp(11, 6,16,1),fpp(11, 6,16,2),fpp(11, 6,16,3)/
     x-8.5659729d-03,-1.4168149d-05, 3.9032467d-05 /
      data fpp(11, 6,17,1),fpp(11, 6,17,2),fpp(11, 6,17,3)/
     x-1.0766893d-02,-4.0641916d-05, 3.8224383d-05 /
      data fpp(11, 6,18,1),fpp(11, 6,18,2),fpp(11, 6,18,3)/
     x-1.5306765d-02,-1.3976513d-04, 1.8076001d-05 /
      data fpp(11, 6,19,1),fpp(11, 6,19,2),fpp(11, 6,19,3)/
     x-2.3403828d-02,-5.2828457d-04, 3.9771614d-05 /
      data fpp(11, 6,20,1),fpp(11, 6,20,2),fpp(11, 6,20,3)/
     x-2.8793171d-02,-3.3500574d-04,-1.7538646d-04 /
      data fpp(11, 6,21,1),fpp(11, 6,21,2),fpp(11, 6,21,3)/
     x-2.8793171d-02,-3.3500574d-04,-1.6959044d-04 /
      data fpp(11, 6,22,1),fpp(11, 6,22,2),fpp(11, 6,22,3)/
     x-2.3403828d-02,-5.2828457d-04, 1.6587554d-05 /
      data fpp(11, 6,23,1),fpp(11, 6,23,2),fpp(11, 6,23,3)/
     x-1.5306765d-02,-1.3976513d-04, 1.0501622d-04 /
      data fpp(11, 7, 1,1),fpp(11, 7, 1,2),fpp(11, 7, 1,3)/
     x-1.8774614d-03, 4.3471318d-05, 4.8238490d-07 /
      data fpp(11, 7, 2,1),fpp(11, 7, 2,2),fpp(11, 7, 2,3)/
     x 2.4046381d-03, 1.9698474d-04,-1.7168270d-05 /
      data fpp(11, 7, 3,1),fpp(11, 7, 3,2),fpp(11, 7, 3,3)/
     x 1.4174396d-02, 3.1714201d-04,-5.4707306d-05 /
      data fpp(11, 7, 4,1),fpp(11, 7, 4,2),fpp(11, 7, 4,3)/
     x 1.4174396d-02, 3.1714201d-04,-5.5203948d-05 /
      data fpp(11, 7, 5,1),fpp(11, 7, 5,2),fpp(11, 7, 5,3)/
     x 2.4046381d-03, 1.9698474d-04,-1.5181701d-05 /
      data fpp(11, 7, 6,1),fpp(11, 7, 6,2),fpp(11, 7, 6,3)/
     x-1.8774614d-03, 4.3471318d-05,-6.9672493d-06 /
      data fpp(11, 7, 7,1),fpp(11, 7, 7,2),fpp(11, 7, 7,3)/
     x-3.8976791d-03,-1.5828431d-05, 2.3106978d-06 /
      data fpp(11, 7, 8,1),fpp(11, 7, 8,2),fpp(11, 7, 8,3)/
     x-5.7309234d-03,-4.5102356d-05, 9.2744580d-06 /
      data fpp(11, 7, 9,1),fpp(11, 7, 9,2),fpp(11, 7, 9,3)/
     x-7.4806233d-03,-5.7294861d-05, 1.5917470d-05 /
      data fpp(11, 7,10,1),fpp(11, 7,10,2),fpp(11, 7,10,3)/
     x-8.8465595d-03,-6.2604825d-05, 2.1327661d-05 /
      data fpp(11, 7,11,1),fpp(11, 7,11,2),fpp(11, 7,11,3)/
     x-9.5568110d-03,-6.4395419d-05, 2.5227885d-05 /
      data fpp(11, 7,12,1),fpp(11, 7,12,2),fpp(11, 7,12,3)/
     x-9.6877985d-03,-6.4236261d-05, 2.7430799d-05 /
      data fpp(11, 7,13,1),fpp(11, 7,13,2),fpp(11, 7,13,3)/
     x-9.2956203d-03,-6.2482900d-05, 2.8128921d-05 /
      data fpp(11, 7,14,1),fpp(11, 7,14,2),fpp(11, 7,14,3)/
     x-8.4679834d-03,-5.8480572d-05, 2.7825519d-05 /
      data fpp(11, 7,15,1),fpp(11, 7,15,2),fpp(11, 7,15,3)/
     x-8.0158422d-03,-5.0750387d-05, 2.6517003d-05 /
      data fpp(11, 7,16,1),fpp(11, 7,16,2),fpp(11, 7,16,3)/
     x-5.5700031d-03,-3.6066152d-05, 2.3882468d-05 /
      data fpp(11, 7,17,1),fpp(11, 7,17,2),fpp(11, 7,17,3)/
     x-3.3163267d-03,-6.3857323d-06, 1.8281126d-05 /
      data fpp(11, 7,18,1),fpp(11, 7,18,2),fpp(11, 7,18,3)/
     x-1.7671919d-05, 5.5513832d-05, 4.9450296d-06 /
      data fpp(11, 7,19,1),fpp(11, 7,19,2),fpp(11, 7,19,3)/
     x 5.4198269d-03, 2.1932756d-04,-1.4343244d-05 /
      data fpp(11, 7,20,1),fpp(11, 7,20,2),fpp(11, 7,20,3)/
     x 1.4451664d-02, 2.7225701d-04,-7.4718053d-05 /
      data fpp(11, 7,21,1),fpp(11, 7,21,2),fpp(11, 7,21,3)/
     x 1.4451664d-02, 2.7225701d-04,-7.4296219d-05 /
      data fpp(11, 7,22,1),fpp(11, 7,22,2),fpp(11, 7,22,3)/
     x 5.4198269d-03, 2.1932756d-04,-1.6030580d-05 /
      data fpp(11, 7,23,1),fpp(11, 7,23,2),fpp(11, 7,23,3)/
     x-1.7671919d-05, 5.5513832d-05, 1.1272540d-05 /
      data fpp(11, 8, 1,1),fpp(11, 8, 1,2),fpp(11, 8, 1,3)/
     x 1.1987007d-02, 2.8234153d-05,-9.2456682d-06 /
      data fpp(11, 8, 2,1),fpp(11, 8, 2,2),fpp(11, 8, 2,3)/
     x 1.5952799d-02, 1.1794769d-04,-1.1772664d-05 /
      data fpp(11, 8, 3,1),fpp(11, 8, 3,2),fpp(11, 8, 3,3)/
     x-4.2258226d-02,-4.3557959d-05,-1.7187678d-05 /
      data fpp(11, 8, 4,1),fpp(11, 8, 4,2),fpp(11, 8, 4,3)/
     x-4.2258226d-02,-4.3557959d-05,-1.7187635d-05 /
      data fpp(11, 8, 5,1),fpp(11, 8, 5,2),fpp(11, 8, 5,3)/
     x 1.5952799d-02, 1.1794769d-04,-1.1772833d-05 /
      data fpp(11, 8, 6,1),fpp(11, 8, 6,2),fpp(11, 8, 6,3)/
     x 1.1987007d-02, 2.8234153d-05,-9.2450340d-06 /
      data fpp(11, 8, 7,1),fpp(11, 8, 7,2),fpp(11, 8, 7,3)/
     x 7.9447981d-03,-2.3233943d-05,-7.6290314d-06 /
      data fpp(11, 8, 8,1),fpp(11, 8, 8,2),fpp(11, 8, 8,3)/
     x 3.9356692d-03,-4.6536132d-05,-4.0448403d-06 /
      data fpp(11, 8, 9,1),fpp(11, 8, 9,2),fpp(11, 8, 9,3)/
     x-2.2861422d-04,-6.0073846d-05, 2.6163926d-06 /
      data fpp(11, 8,10,1),fpp(11, 8,10,2),fpp(11, 8,10,3)/
     x-3.8188758d-03,-6.6779960d-05, 9.8872698d-06 /
      data fpp(11, 8,11,1),fpp(11, 8,11,2),fpp(11, 8,11,3)/
     x-6.1957491d-03,-6.9089897d-05, 1.5452528d-05 /
      data fpp(11, 8,12,1),fpp(11, 8,12,2),fpp(11, 8,12,3)/
     x-7.3040788d-03,-6.8105529d-05, 1.8578618d-05 /
      data fpp(11, 8,13,1),fpp(11, 8,13,2),fpp(11, 8,13,3)/
     x-7.2904189d-03,-6.4113526d-05, 1.9727001d-05 /
      data fpp(11, 8,14,1),fpp(11, 8,14,2),fpp(11, 8,14,3)/
     x-6.6808828d-03,-5.7202729d-05, 1.9111378d-05 /
      data fpp(11, 8,15,1),fpp(11, 8,15,2),fpp(11, 8,15,3)/
     x-4.6716424d-03,-4.6821720d-05, 1.7425487d-05 /
      data fpp(11, 8,16,1),fpp(11, 8,16,2),fpp(11, 8,16,3)/
     x-2.3104159d-03,-3.2649245d-05, 1.4170673d-05 /
      data fpp(11, 8,17,1),fpp(11, 8,17,2),fpp(11, 8,17,3)/
     x 8.6170771d-04,-1.4803155d-05, 9.0818212d-06 /
      data fpp(11, 8,18,1),fpp(11, 8,18,2),fpp(11, 8,18,3)/
     x 5.0566988d-03, 3.4317986d-06, 1.6042200d-08 /
      data fpp(11, 8,19,1),fpp(11, 8,19,2),fpp(11, 8,19,3)/
     x 1.0729280d-02, 2.5743333d-06,-1.2841990d-05 /
      data fpp(11, 8,20,1),fpp(11, 8,20,2),fpp(11, 8,20,3)/
     x 1.7107584d-02, 3.1689718d-05,-3.6482082d-05 /
      data fpp(11, 8,21,1),fpp(11, 8,21,2),fpp(11, 8,21,3)/
     x 1.7107584d-02, 3.1689718d-05,-3.6568759d-05 /
      data fpp(11, 8,22,1),fpp(11, 8,22,2),fpp(11, 8,22,3)/
     x 1.0729280d-02, 2.5743333d-06,-1.2495283d-05 /
      data fpp(11, 8,23,1),fpp(11, 8,23,2),fpp(11, 8,23,3)/
     x 5.0566988d-03, 3.4317986d-06,-1.2841084d-06 /
      data fpp(11, 9, 1,1),fpp(11, 9, 1,2),fpp(11, 9, 1,3)/
     x 3.8092394d-02,-1.4662193d-04,-2.1593424d-04 /
      data fpp(11, 9, 2,1),fpp(11, 9, 2,2),fpp(11, 9, 2,3)/
     x-7.6770442d-01,-4.2351950d-04,-1.2002651d-04 /
      data fpp(11, 9, 3,1),fpp(11, 9, 3,2),fpp(11, 9, 3,3)/
     x-1.8110216d-01,-2.5871018d-04, 7.5364291d-05 /
      data fpp(11, 9, 4,1),fpp(11, 9, 4,2),fpp(11, 9, 4,3)/
     x-1.8110216d-01,-2.5871018d-04, 9.3084384d-05 /
      data fpp(11, 9, 5,1),fpp(11, 9, 5,2),fpp(11, 9, 5,3)/
     x-7.6770442d-01,-4.2351950d-04,-1.9090689d-04 /
      data fpp(11, 9, 6,1),fpp(11, 9, 6,2),fpp(11, 9, 6,3)/
     x 3.8092394d-02,-1.4662193d-04, 4.9867162d-05 /
      data fpp(11, 9, 7,1),fpp(11, 9, 7,2),fpp(11, 9, 7,3)/
     x 2.1296427d-02,-5.7771796d-05,-2.1437761d-05 /
      data fpp(11, 9, 8,1),fpp(11, 9, 8,2),fpp(11, 9, 8,3)/
     x 1.6113256d-02,-5.3351117d-05,-5.0181175d-06 /
      data fpp(11, 9, 9,1),fpp(11, 9, 9,2),fpp(11, 9, 9,3)/
     x 1.0554703d-02,-5.4957756d-05,-6.0877689d-06 /
      data fpp(11, 9,10,1),fpp(11, 9,10,2),fpp(11, 9,10,3)/
     x 5.1686929d-03,-5.6189337d-05, 2.2971932d-06 /
      data fpp(11, 9,11,1),fpp(11, 9,11,2),fpp(11, 9,11,3)/
     x 9.4495451d-04,-5.5874994d-05, 8.3289961d-06 /
      data fpp(11, 9,12,1),fpp(11, 9,12,2),fpp(11, 9,12,3)/
     x-1.4227073d-03,-5.3617624d-05, 1.2338822d-05 /
      data fpp(11, 9,13,1),fpp(11, 9,13,2),fpp(11, 9,13,3)/
     x-2.4061282d-03,-4.9336997d-05, 1.3871714d-05 /
      data fpp(11, 9,14,1),fpp(11, 9,14,2),fpp(11, 9,14,3)/
     x-1.7292278d-03,-4.2852510d-05, 1.3726320d-05 /
      data fpp(11, 9,15,1),fpp(11, 9,15,2),fpp(11, 9,15,3)/
     x-9.4018763d-04,-3.4146733d-05, 1.2301005d-05 /
      data fpp(11, 9,16,1),fpp(11, 9,16,2),fpp(11, 9,16,3)/
     x 9.6054442d-04,-2.2906870d-05, 9.9156581d-06 /
      data fpp(11, 9,17,1),fpp(11, 9,17,2),fpp(11, 9,17,3)/
     x 3.6458250d-03,-9.1316471d-06, 6.3143620d-06 /
      data fpp(11, 9,18,1),fpp(11, 9,18,2),fpp(11, 9,18,3)/
     x 7.2476829d-03, 7.3189739d-06, 3.5289388d-07 /
      data fpp(11, 9,19,1),fpp(11, 9,19,2),fpp(11, 9,19,3)/
     x 1.2059801d-02, 2.9419108d-05,-7.6419375d-06 /
      data fpp(11, 9,20,1),fpp(11, 9,20,2),fpp(11, 9,20,3)/
     x 1.7338277d-02, 3.9542124d-05,-2.1277144d-05 /
      data fpp(11, 9,21,1),fpp(11, 9,21,2),fpp(11, 9,21,3)/
     x 1.7338277d-02, 3.9542124d-05,-2.1354600d-05 /
      data fpp(11, 9,22,1),fpp(11, 9,22,2),fpp(11, 9,22,3)/
     x 1.2059801d-02, 2.9419108d-05,-7.3321144d-06 /
      data fpp(11, 9,23,1),fpp(11, 9,23,2),fpp(11, 9,23,3)/
     x 7.2476829d-03, 7.3189739d-06,-8.0894281d-07 /
      data fpp(11,10, 1,1),fpp(11,10, 1,2),fpp(11,10, 1,3)/
     x-9.9950101d-02,-1.4594244d-04,-2.7290365d-05 /
      data fpp(11,10, 2,1),fpp(11,10, 2,2),fpp(11,10, 2,3)/
     x-4.6375531d-02, 1.0251833d-04, 8.1927308d-06 /
      data fpp(11,10, 3,1),fpp(11,10, 3,2),fpp(11,10, 3,3)/
     x-4.5253435d-02, 9.5778671d-05, 8.7099442d-05 /
      data fpp(11,10, 4,1),fpp(11,10, 4,2),fpp(11,10, 4,3)/
     x-4.5253435d-02, 9.5778671d-05, 8.2074308d-05 /
      data fpp(11,10, 5,1),fpp(11,10, 5,2),fpp(11,10, 5,3)/
     x-4.6375531d-02, 1.0251833d-04, 2.8293270d-05 /
      data fpp(11,10, 6,1),fpp(11,10, 6,2),fpp(11,10, 6,3)/
     x-9.9950101d-02,-1.4594244d-04,-1.0266739d-04 /
      data fpp(11,10, 7,1),fpp(11,10, 7,2),fpp(11,10, 7,3)/
     x-9.0954494d-03,-1.3723287d-04,-4.3767723d-05 /
      data fpp(11,10, 8,1),fpp(11,10, 8,2),fpp(11,10, 8,3)/
     x 2.0431223d-02,-7.5645400d-05,-1.6933723d-05 /
      data fpp(11,10, 9,1),fpp(11,10, 9,2),fpp(11,10, 9,3)/
     x 2.0021410d-02,-5.1259130d-05,-1.4047385d-05 /
      data fpp(11,10,10,1),fpp(11,10,10,2),fpp(11,10,10,3)/
     x 1.4708711d-02,-4.2404694d-05,-4.5287369d-06 /
      data fpp(11,10,11,1),fpp(11,10,11,2),fpp(11,10,11,3)/
     x 9.4099144d-03,-3.8460128d-05, 3.0743325d-06 /
      data fpp(11,10,12,1),fpp(11,10,12,2),fpp(11,10,12,3)/
     x 5.7260352d-03,-3.5453976d-05, 7.9874068d-06 /
      data fpp(11,10,13,1),fpp(11,10,13,2),fpp(11,10,13,3)/
     x 3.7799865d-03,-3.1986488d-05, 1.0156040d-05 /
      data fpp(11,10,14,1),fpp(11,10,14,2),fpp(11,10,14,3)/
     x 3.0846358d-03,-2.7617230d-05, 1.0530432d-05 /
      data fpp(11,10,15,1),fpp(11,10,15,2),fpp(11,10,15,3)/
     x 3.2046794d-03,-2.2127349d-05, 9.7562313d-06 /
      data fpp(11,10,16,1),fpp(11,10,16,2),fpp(11,10,16,3)/
     x 4.2674622d-03,-1.5589275d-05, 8.1286428d-06 /
      data fpp(11,10,17,1),fpp(11,10,17,2),fpp(11,10,17,3)/
     x 6.1304454d-03,-8.4902564d-06, 5.4711975d-06 /
      data fpp(11,10,18,1),fpp(11,10,18,2),fpp(11,10,18,3)/
     x 8.6653722d-03,-2.0596942d-06, 9.4656701d-07 /
      data fpp(11,10,19,1),fpp(11,10,19,2),fpp(11,10,19,3)/
     x 1.2876326d-02, 1.6392328d-06,-4.6194656d-06 /
      data fpp(11,10,20,1),fpp(11,10,20,2),fpp(11,10,20,3)/
     x 1.7821312d-02, 5.8557866d-06,-1.5036705d-05 /
      data fpp(11,10,21,1),fpp(11,10,21,2),fpp(11,10,21,3)/
     x 1.7821312d-02, 5.8557866d-06,-1.5070153d-05 /
      data fpp(11,10,22,1),fpp(11,10,22,2),fpp(11,10,22,3)/
     x 1.2876326d-02, 1.6392328d-06,-4.4856705d-06 /
      data fpp(11,10,23,1),fpp(11,10,23,2),fpp(11,10,23,3)/
     x 8.6653722d-03,-2.0596942d-06, 4.4483523d-07 /
      data fpp(11,11, 1,1),fpp(11,11, 1,2),fpp(11,11, 1,3)/
     x-9.4012646d-02, 7.6187686d-05, 2.7685521d-05 /
      data fpp(11,11, 2,1),fpp(11,11, 2,2),fpp(11,11, 2,3)/
     x-5.6197872d-02, 7.2660192d-05, 4.3886959d-05 /
      data fpp(11,11, 3,1),fpp(11,11, 3,2),fpp(11,11, 3,3)/
     x-2.5916176d-02, 1.2593949d-04, 8.0314644d-05 /
      data fpp(11,11, 4,1),fpp(11,11, 4,2),fpp(11,11, 4,3)/
     x-2.5916176d-02, 1.2593949d-04, 7.7321590d-05 /
      data fpp(11,11, 5,1),fpp(11,11, 5,2),fpp(11,11, 5,3)/
     x-5.6197872d-02, 7.2660192d-05, 5.5859173d-05 /
      data fpp(11,11, 6,1),fpp(11,11, 6,2),fpp(11,11, 6,3)/
     x-9.4012646d-02, 7.6187686d-05,-1.7210283d-05 /
      data fpp(11,11, 7,1),fpp(11,11, 7,2),fpp(11,11, 7,3)/
     x-7.3334057d-02,-9.7787067d-06,-7.5290042d-05 /
      data fpp(11,11, 8,1),fpp(11,11, 8,2),fpp(11,11, 8,3)/
     x-7.9320347d-03,-4.5155282d-05,-5.2399550d-05 /
      data fpp(11,11, 9,1),fpp(11,11, 9,2),fpp(11,11, 9,3)/
     x 1.7859355d-02,-3.7605724d-05,-3.0519758d-05 /
      data fpp(11,11,10,1),fpp(11,11,10,2),fpp(11,11,10,3)/
     x 1.9765672d-02,-2.9221887d-05,-1.4671419d-05 /
      data fpp(11,11,11,1),fpp(11,11,11,2),fpp(11,11,11,3)/
     x 1.5922591d-02,-2.4794496d-05,-2.4505681d-06 /
      data fpp(11,11,12,1),fpp(11,11,12,2),fpp(11,11,12,3)/
     x 1.1996668d-02,-2.2252474d-05, 4.3376911d-06 /
      data fpp(11,11,13,1),fpp(11,11,13,2),fpp(11,11,13,3)/
     x 9.4055461d-03,-1.9997053d-05, 7.4858038d-06 /
      data fpp(11,11,14,1),fpp(11,11,14,2),fpp(11,11,14,3)/
     x 8.0174152d-03,-1.7474568d-05, 8.5290936d-06 /
      data fpp(11,11,15,1),fpp(11,11,15,2),fpp(11,11,15,3)/
     x 7.7021114d-03,-1.4635870d-05, 8.4078218d-06 /
      data fpp(11,11,16,1),fpp(11,11,16,2),fpp(11,11,16,3)/
     x 8.1511758d-03,-1.1684031d-05, 7.2016193d-06 /
      data fpp(11,11,17,1),fpp(11,11,17,2),fpp(11,11,17,3)/
     x 9.1329287d-03,-8.9393274d-06, 4.5637009d-06 /
      data fpp(11,11,18,1),fpp(11,11,18,2),fpp(11,11,18,3)/
     x 1.0903419d-02,-6.4961972d-06, 6.3757704d-07 /
      data fpp(11,11,19,1),fpp(11,11,19,2),fpp(11,11,19,3)/
     x 1.4364827d-02,-4.3080395d-06,-3.4540091d-06 /
      data fpp(11,11,20,1),fpp(11,11,20,2),fpp(11,11,20,3)/
     x 1.9503918d-02,-3.7512705d-06,-1.2003541d-05 /
      data fpp(11,11,21,1),fpp(11,11,21,2),fpp(11,11,21,3)/
     x 1.9503918d-02,-3.7512705d-06,-1.2008373d-05 /
      data fpp(11,11,22,1),fpp(11,11,22,2),fpp(11,11,22,3)/
     x 1.4364827d-02,-4.3080395d-06,-3.4346791d-06 /
      data fpp(11,11,23,1),fpp(11,11,23,2),fpp(11,11,23,3)/
     x 1.0903419d-02,-6.4961972d-06, 5.6508954d-07 /
      data fpp(11,12, 1,1),fpp(11,12, 1,2),fpp(11,12, 1,3)/
     x-7.8734587d-02, 7.1837697d-05, 8.6101318d-05 /
      data fpp(11,12, 2,1),fpp(11,12, 2,2),fpp(11,12, 2,3)/
     x-2.5934892d-02, 1.2218090d-04, 7.2657863d-05 /
      data fpp(11,12, 3,1),fpp(11,12, 3,2),fpp(11,12, 3,3)/
     x 4.0775196d-02, 1.4868736d-04, 4.5973229d-05 /
      data fpp(11,12, 4,1),fpp(11,12, 4,2),fpp(11,12, 4,3)/
     x 4.0775196d-02, 1.4868736d-04, 4.2258381d-05 /
      data fpp(11,12, 5,1),fpp(11,12, 5,2),fpp(11,12, 5,3)/
     x-2.5934892d-02, 1.2218090d-04, 8.7517254d-05 /
      data fpp(11,12, 6,1),fpp(11,12, 6,2),fpp(11,12, 6,3)/
     x-7.8734587d-02, 7.1837697d-05, 3.0378603d-05 /
      data fpp(11,12, 7,1),fpp(11,12, 7,2),fpp(11,12, 7,3)/
     x-8.6774727d-02, 4.1737701d-05,-3.9993666d-05 /
      data fpp(11,12, 8,1),fpp(11,12, 8,2),fpp(11,12, 8,3)/
     x-4.2731689d-02, 7.8485280d-06,-6.5823940d-05 /
      data fpp(11,12, 9,1),fpp(11,12, 9,2),fpp(11,12, 9,3)/
     x 1.5073591d-03,-9.9199751d-06,-5.1352575d-05 /
      data fpp(11,12,10,1),fpp(11,12,10,2),fpp(11,12,10,3)/
     x 1.7761935d-02,-1.3741756d-05,-2.7661759d-05 /
      data fpp(11,12,11,1),fpp(11,12,11,2),fpp(11,12,11,3)/
     x 1.8594912d-02,-1.3831890d-05,-9.2283897d-06 /
      data fpp(11,12,12,1),fpp(11,12,12,2),fpp(11,12,12,3)/
     x 1.5921391d-02,-1.3242129d-05, 7.4731734d-07 /
      data fpp(11,12,13,1),fpp(11,12,13,2),fpp(11,12,13,3)/
     x 1.3517975d-02,-1.2591301d-05, 5.2071203d-06 /
      data fpp(11,12,14,1),fpp(11,12,14,2),fpp(11,12,14,3)/
     x 1.2067475d-02,-1.1858497d-05, 6.9542015d-06 /
      data fpp(11,12,15,1),fpp(11,12,15,2),fpp(11,12,15,3)/
     x 1.1720218d-02,-1.1189172d-05, 7.2840735d-06 /
      data fpp(11,12,16,1),fpp(11,12,16,2),fpp(11,12,16,3)/
     x 1.2069103d-02,-1.0814600d-05, 6.1555043d-06 /
      data fpp(11,12,17,1),fpp(11,12,17,2),fpp(11,12,17,3)/
     x 1.2828786d-02,-1.0724434d-05, 3.3559093d-06 /
      data fpp(11,12,18,1),fpp(11,12,18,2),fpp(11,12,18,3)/
     x 1.4218991d-02,-1.0649517d-05,-2.4114164d-07 /
      data fpp(11,12,19,1),fpp(11,12,19,2),fpp(11,12,19,3)/
     x 1.7376201d-02,-1.0591075d-05,-3.4773428d-06 /
      data fpp(11,12,20,1),fpp(11,12,20,2),fpp(11,12,20,3)/
     x 2.2503023d-02,-1.0506705d-05,-9.6274872d-06 /
      data fpp(11,12,21,1),fpp(11,12,21,2),fpp(11,12,21,3)/
     x 2.2503023d-02,-1.0506705d-05,-9.6448670d-06 /
      data fpp(11,12,22,1),fpp(11,12,22,2),fpp(11,12,22,3)/
     x 1.7376201d-02,-1.0591075d-05,-3.4078237d-06 /
      data fpp(11,12,23,1),fpp(11,12,23,2),fpp(11,12,23,3)/
     x 1.4218991d-02,-1.0649517d-05,-5.0183814d-07 /
      data fpp(11,13, 1,1),fpp(11,13, 1,2),fpp(11,13, 1,3)/
     x-5.8572242d-02, 6.4465528d-05, 1.3350331d-04 /
      data fpp(11,13, 2,1),fpp(11,13, 2,2),fpp(11,13, 2,3)/
     x 2.2803606d-02, 2.8518189d-05, 9.0516873d-05 /
      data fpp(11,13, 3,1),fpp(11,13, 3,2),fpp(11,13, 3,3)/
     x 1.3469348d-01,-3.4258930d-05, 9.2319502d-07 /
      data fpp(11,13, 4,1),fpp(11,13, 4,2),fpp(11,13, 4,3)/
     x 1.3469348d-01,-3.4258930d-05,-3.4870215d-06 /
      data fpp(11,13, 5,1),fpp(11,13, 5,2),fpp(11,13, 5,3)/
     x 2.2803606d-02, 2.8518189d-05, 1.0815774d-04 /
      data fpp(11,13, 6,1),fpp(11,13, 6,2),fpp(11,13, 6,3)/
     x-5.8572242d-02, 6.4465528d-05, 6.7350066d-05 /
      data fpp(11,13, 7,1),fpp(11,13, 7,2),fpp(11,13, 7,3)/
     x-8.7795245d-02, 5.6859901d-05,-3.2840020d-06 /
      data fpp(11,13, 8,1),fpp(11,13, 8,2),fpp(11,13, 8,3)/
     x-6.6468745d-02, 3.3651170d-05,-5.4454058d-05 /
      data fpp(11,13, 9,1),fpp(11,13, 9,2),fpp(11,13, 9,3)/
     x-2.0619759d-02, 1.3463624d-05,-6.2345768d-05 /
      data fpp(11,13,10,1),fpp(11,13,10,2),fpp(11,13,10,3)/
     x 9.6497549d-03, 2.2949131d-06,-3.9164872d-05 /
      data fpp(11,13,11,1),fpp(11,13,11,2),fpp(11,13,11,3)/
     x 1.7781592d-02,-3.4459461d-06,-1.5396744d-05 /
      data fpp(11,13,12,1),fpp(11,13,12,2),fpp(11,13,12,3)/
     x 1.7535905d-02,-5.9590090d-06,-2.7061510d-06 /
      data fpp(11,13,13,1),fpp(11,13,13,2),fpp(11,13,13,3)/
     x 1.6045941d-02,-7.0917447d-06, 3.1093483d-06 /
      data fpp(11,13,14,1),fpp(11,13,14,2),fpp(11,13,14,3)/
     x 1.5024921d-02,-7.9434427d-06, 5.3947577d-06 /
      data fpp(11,13,15,1),fpp(11,13,15,2),fpp(11,13,15,3)/
     x 1.4907174d-02,-8.8634441d-06, 5.9116209d-06 /
      data fpp(11,13,16,1),fpp(11,13,16,2),fpp(11,13,16,3)/
     x 1.5425734d-02,-9.9955685d-06, 4.8107587d-06 /
      data fpp(11,13,17,1),fpp(11,13,17,2),fpp(11,13,17,3)/
     x 1.6305098d-02,-1.1198937d-05, 2.1753444d-06 /
      data fpp(11,13,18,1),fpp(11,13,18,2),fpp(11,13,18,3)/
     x 1.7653357d-02,-1.2093735d-05,-9.8413618d-07 /
      data fpp(11,13,19,1),fpp(11,13,19,2),fpp(11,13,19,3)/
     x 2.0203400d-02,-1.2331662d-05,-3.7347997d-06 /
      data fpp(11,13,20,1),fpp(11,13,20,2),fpp(11,13,20,3)/
     x 2.3874405d-02,-1.1965910d-05,-7.3746652d-06 /
      data fpp(11,13,21,1),fpp(11,13,21,2),fpp(11,13,21,3)/
     x 2.3874405d-02,-1.1965910d-05,-7.4246047d-06 /
      data fpp(11,13,22,1),fpp(11,13,22,2),fpp(11,13,22,3)/
     x 2.0203400d-02,-1.2331662d-05,-3.5350415d-06 /
      data fpp(11,13,23,1),fpp(11,13,23,2),fpp(11,13,23,3)/
     x 1.7653357d-02,-1.2093735d-05,-1.7332292d-06 /
      data fpp(11,14, 1,1),fpp(11,14, 1,2),fpp(11,14, 1,3)/
     x-4.3595419d-02, 5.1516192d-05, 1.1880548d-04 /
      data fpp(11,14, 2,1),fpp(11,14, 2,2),fpp(11,14, 2,3)/
     x 3.7478234d-02, 9.5483387d-06, 7.8518044d-05 /
      data fpp(11,14, 3,1),fpp(11,14, 3,2),fpp(11,14, 3,3)/
     x 1.4108263d-01,-4.4705641d-05,-6.0376526d-06 /
      data fpp(11,14, 4,1),fpp(11,14, 4,2),fpp(11,14, 4,3)/
     x 1.4108263d-01,-4.4705641d-05,-9.1430641d-06 /
      data fpp(11,14, 5,1),fpp(11,14, 5,2),fpp(11,14, 5,3)/
     x 3.7478234d-02, 9.5483387d-06, 9.0939690d-05 /
      data fpp(11,14, 6,1),fpp(11,14, 6,2),fpp(11,14, 6,3)/
     x-4.3595419d-02, 5.1516192d-05, 7.2224305d-05 /
      data fpp(11,14, 7,1),fpp(11,14, 7,2),fpp(11,14, 7,3)/
     x-8.1872119d-02, 6.5064694d-05, 1.7285091d-05 /
      data fpp(11,14, 8,1),fpp(11,14, 8,2),fpp(11,14, 8,3)/
     x-8.0022994d-02, 5.4166792d-05,-3.7072669d-05 /
      data fpp(11,14, 9,1),fpp(11,14, 9,2),fpp(11,14, 9,3)/
     x-4.3780476d-02, 3.3423479d-05,-6.2884415d-05 /
      data fpp(11,14,10,1),fpp(11,14,10,2),fpp(11,14,10,3)/
     x-2.3574537d-03, 1.5500104d-05,-4.5655671d-05 /
      data fpp(11,14,11,1),fpp(11,14,11,2),fpp(11,14,11,3)/
     x 1.4562682d-02, 5.6616739d-06,-1.8540901d-05 /
      data fpp(11,14,12,1),fpp(11,14,12,2),fpp(11,14,12,3)/
     x 1.7434240d-02, 5.1416525d-07,-4.9867243d-06 /
      data fpp(11,14,13,1),fpp(11,14,13,2),fpp(11,14,13,3)/
     x 1.7183351d-02,-2.2477205d-06, 1.2637986d-06 /
      data fpp(11,14,14,1),fpp(11,14,14,2),fpp(11,14,14,3)/
     x 1.6798036d-02,-4.0797319d-06, 3.7895301d-06 /
      data fpp(11,14,15,1),fpp(11,14,15,2),fpp(11,14,15,3)/
     x 1.6884913d-02,-5.7310520d-06, 4.3140810d-06 /
      data fpp(11,14,16,1),fpp(11,14,16,2),fpp(11,14,16,3)/
     x 1.7492081d-02,-7.2891260d-06, 3.3621460d-06 /
      data fpp(11,14,17,1),fpp(11,14,17,2),fpp(11,14,17,3)/
     x 1.8414163d-02,-8.6378185d-06, 1.2753351d-06 /
      data fpp(11,14,18,1),fpp(11,14,18,2),fpp(11,14,18,3)/
     x 1.9521919d-02,-9.6635441d-06,-1.2034863d-06 /
      data fpp(11,14,19,1),fpp(11,14,19,2),fpp(11,14,19,3)/
     x 2.1065909d-02,-1.0276277d-05,-3.3433897d-06 /
      data fpp(11,14,20,1),fpp(11,14,20,2),fpp(11,14,20,3)/
     x 2.2790008d-02,-1.0467654d-05,-5.3789548d-06 /
      data fpp(11,14,21,1),fpp(11,14,21,2),fpp(11,14,21,3)/
     x 2.2790008d-02,-1.0467654d-05,-5.4354408d-06 /
      data fpp(11,14,22,1),fpp(11,14,22,2),fpp(11,14,22,3)/
     x 2.1065909d-02,-1.0276277d-05,-3.1174455d-06 /
      data fpp(11,14,23,1),fpp(11,14,23,2),fpp(11,14,23,3)/
     x 1.9521919d-02,-9.6635441d-06,-2.0507773d-06 /
      data fpp(11,15, 1,1),fpp(11,15, 1,2),fpp(11,15, 1,3)/
     x-4.5289016d-02, 9.5751706d-05, 6.6386053d-05 /
      data fpp(11,15, 2,1),fpp(11,15, 2,2),fpp(11,15, 2,3)/
     x 1.0797543d-03, 1.1670246d-04, 5.1347394d-05 /
      data fpp(11,15, 3,1),fpp(11,15, 3,2),fpp(11,15, 3,3)/
     x 5.0534226d-02, 1.4802349d-04, 1.9806373d-05 /
      data fpp(11,15, 4,1),fpp(11,15, 4,2),fpp(11,15, 4,3)/
     x 5.0534226d-02, 1.4802349d-04, 1.8608185d-05 /
      data fpp(11,15, 5,1),fpp(11,15, 5,2),fpp(11,15, 5,3)/
     x 1.0797543d-03, 1.1670246d-04, 5.6140143d-05 /
      data fpp(11,15, 6,1),fpp(11,15, 6,2),fpp(11,15, 6,3)/
     x-4.5289016d-02, 9.5751706d-05, 4.8413243d-05 /
      data fpp(11,15, 7,1),fpp(11,15, 7,2),fpp(11,15, 7,3)/
     x-7.6529159d-02, 7.8029322d-05, 1.6174887d-05 /
      data fpp(11,15, 8,1),fpp(11,15, 8,2),fpp(11,15, 8,3)/
     x-8.7856511d-02, 5.4139661d-05,-2.3844789d-05 /
      data fpp(11,15, 9,1),fpp(11,15, 9,2),fpp(11,15, 9,3)/
     x-6.5355288d-02, 3.5116460d-05,-5.6623732d-05 /
      data fpp(11,15,10,1),fpp(11,15,10,2),fpp(11,15,10,3)/
     x-1.7138054d-02, 2.4690671d-05,-4.6294283d-05 /
      data fpp(11,15,11,1),fpp(11,15,11,2),fpp(11,15,11,3)/
     x 1.0158214d-02, 1.1873250d-05,-1.6517134d-05 /
      data fpp(11,15,12,1),fpp(11,15,12,2),fpp(11,15,12,3)/
     x 1.6346681d-02, 5.5643480d-06,-5.2911796d-06 /
      data fpp(11,15,13,1),fpp(11,15,13,2),fpp(11,15,13,3)/
     x 1.7364404d-02, 2.2046268d-06, 2.1785256d-07 /
      data fpp(11,15,14,1),fpp(11,15,14,2),fpp(11,15,14,3)/
     x 1.7496853d-02, 1.3037014d-07, 2.2957693d-06 /
      data fpp(11,15,15,1),fpp(11,15,15,2),fpp(11,15,15,3)/
     x 1.7801359d-02,-1.2843479d-06, 2.7850701d-06 /
      data fpp(11,15,16,1),fpp(11,15,16,2),fpp(11,15,16,3)/
     x 1.8320361d-02,-2.2839276d-06, 2.1039503d-06 /
      data fpp(11,15,17,1),fpp(11,15,17,2),fpp(11,15,17,3)/
     x 1.8946387d-02,-2.8917890d-06, 7.0312855d-07 /
      data fpp(11,15,18,1),fpp(11,15,18,2),fpp(11,15,18,3)/
     x 1.9711494d-02,-3.1500890d-06,-9.7446452d-07 /
      data fpp(11,15,19,1),fpp(11,15,19,2),fpp(11,15,19,3)/
     x 2.0463850d-02,-3.0592296d-06,-2.4152704d-06 /
      data fpp(11,15,20,1),fpp(11,15,20,2),fpp(11,15,20,3)/
     x 2.1120355d-02,-2.7254739d-06,-3.4464537d-06 /
      data fpp(11,15,21,1),fpp(11,15,21,2),fpp(11,15,21,3)/
     x 2.1120355d-02,-2.7254739d-06,-3.4920037d-06 /
      data fpp(11,15,22,1),fpp(11,15,22,2),fpp(11,15,22,3)/
     x 2.0463850d-02,-3.0592296d-06,-2.2330704d-06 /
      data fpp(11,15,23,1),fpp(11,15,23,2),fpp(11,15,23,3)/
     x 1.9711494d-02,-3.1500890d-06,-1.6577148d-06 /
      data fpp(11,16, 1,1),fpp(11,16, 1,2),fpp(11,16, 1,3)/
     x-4.9945247d-02, 8.1482986d-05, 3.2448948d-05 /
      data fpp(11,16, 2,1),fpp(11,16, 2,2),fpp(11,16, 2,3)/
     x-3.4722110d-02, 1.0538984d-04, 3.2252603d-05 /
      data fpp(11,16, 3,1),fpp(11,16, 3,2),fpp(11,16, 3,3)/
     x-2.1045064d-02, 1.3728367d-04, 3.2046638d-05 /
      data fpp(11,16, 4,1),fpp(11,16, 4,2),fpp(11,16, 4,3)/
     x-2.1045064d-02, 1.3728367d-04, 3.1670785d-05 /
      data fpp(11,16, 5,1),fpp(11,16, 5,2),fpp(11,16, 5,3)/
     x-3.4722110d-02, 1.0538984d-04, 3.3756015d-05 /
      data fpp(11,16, 6,1),fpp(11,16, 6,2),fpp(11,16, 6,3)/
     x-4.9945247d-02, 8.1482986d-05, 2.6811154d-05 /
      data fpp(11,16, 7,1),fpp(11,16, 7,2),fpp(11,16, 7,3)/
     x-7.4225206d-02, 8.6498017d-05, 7.2293684d-06 /
      data fpp(11,16, 8,1),fpp(11,16, 8,2),fpp(11,16, 8,3)/
     x-1.2191225d-01, 1.0426257d-04,-1.7850628d-05 /
      data fpp(11,16, 9,1),fpp(11,16, 9,2),fpp(11,16, 9,3)/
     x 3.3889685d-01, 7.7756681d-05,-4.8242858d-05 /
      data fpp(11,16,10,1),fpp(11,16,10,2),fpp(11,16,10,3)/
     x-2.8801103d-02, 2.3509212d-05,-3.8711940d-05 /
      data fpp(11,16,11,1),fpp(11,16,11,2),fpp(11,16,11,3)/
     x 7.1672312d-03, 1.2497325d-05,-7.7433819d-06 /
      data fpp(11,16,12,1),fpp(11,16,12,2),fpp(11,16,12,3)/
     x 1.5179765d-02, 8.0264428d-06,-3.5505325d-06 /
      data fpp(11,16,13,1),fpp(11,16,13,2),fpp(11,16,13,3)/
     x 1.7075478d-02, 5.4592134d-06, 3.2751203d-07 /
      data fpp(11,16,14,1),fpp(11,16,14,2),fpp(11,16,14,3)/
     x 1.7592091d-02, 4.0202513d-06, 1.3344844d-06 /
      data fpp(11,16,15,1),fpp(11,16,15,2),fpp(11,16,15,3)/
     x 1.7974608d-02, 3.4284438d-06, 1.6365503d-06 /
      data fpp(11,16,16,1),fpp(11,16,16,2),fpp(11,16,16,3)/
     x 1.8319967d-02, 3.5248363d-06, 1.2333144d-06 /
      data fpp(11,16,17,1),fpp(11,16,17,2),fpp(11,16,17,3)/
     x 1.8705755d-02, 4.1009744d-06, 4.5619221d-07 /
      data fpp(11,16,18,1),fpp(11,16,18,2),fpp(11,16,18,3)/
     x 1.9156281d-02, 4.9419002d-06,-4.4808321d-07 /
      data fpp(11,16,19,1),fpp(11,16,19,2),fpp(11,16,19,3)/
     x 1.9456141d-02, 5.7611956d-06,-1.2138594d-06 /
      data fpp(11,16,20,1),fpp(11,16,20,2),fpp(11,16,20,3)/
     x 1.9747573d-02, 6.3275497d-06,-1.7644794d-06 /
      data fpp(11,16,21,1),fpp(11,16,21,2),fpp(11,16,21,3)/
     x 1.9747573d-02, 6.3275497d-06,-1.7886322d-06 /
      data fpp(11,16,22,1),fpp(11,16,22,2),fpp(11,16,22,3)/
     x 1.9456141d-02, 5.7611956d-06,-1.1172479d-06 /
      data fpp(11,16,23,1),fpp(11,16,23,2),fpp(11,16,23,3)/
     x 1.9156281d-02, 4.9419002d-06,-8.1037603d-07 /
      data fpp(11,17, 1,1),fpp(11,17, 1,2),fpp(11,17, 1,3)/
     x-5.8069442d-02, 1.0803835d-04, 1.7447400d-05 /
      data fpp(11,17, 2,1),fpp(11,17, 2,2),fpp(11,17, 2,3)/
     x-5.1186875d-02, 1.3087620d-04, 1.9301701d-05 /
      data fpp(11,17, 3,1),fpp(11,17, 3,2),fpp(11,17, 3,3)/
     x-4.5408261d-02, 1.3406382d-04, 2.3443798d-05 /
      data fpp(11,17, 4,1),fpp(11,17, 4,2),fpp(11,17, 4,3)/
     x-4.5408261d-02, 1.3406382d-04, 2.3148755d-05 /
      data fpp(11,17, 5,1),fpp(11,17, 5,2),fpp(11,17, 5,3)/
     x-5.1186875d-02, 1.3087620d-04, 2.0481871d-05 /
      data fpp(11,17, 6,1),fpp(11,17, 6,2),fpp(11,17, 6,3)/
     x-5.8069442d-02, 1.0803835d-04, 1.3021761d-05 /
      data fpp(11,17, 7,1),fpp(11,17, 7,2),fpp(11,17, 7,3)/
     x-8.2758728d-02, 1.9960611d-05, 1.1599085d-05 /
      data fpp(11,17, 8,1),fpp(11,17, 8,2),fpp(11,17, 8,3)/
     x-5.3302338d-01,-7.4739921d-05,-3.4722101d-05 /
      data fpp(11,17, 9,1),fpp(11,17, 9,2),fpp(11,17, 9,3)/
     x-2.4949732d-01,-8.5569183d-05,-5.0058680d-05 /
      data fpp(11,17,10,1),fpp(11,17,10,2),fpp(11,17,10,3)/
     x-1.1509579d-02,-2.2169519d-05, 4.3828219d-06 /
      data fpp(11,17,11,1),fpp(11,17,11,2),fpp(11,17,11,3)/
     x 1.0350686d-02,-2.1565489d-06,-3.6586074d-06 /
      data fpp(11,17,12,1),fpp(11,17,12,2),fpp(11,17,12,3)/
     x 1.5257158d-02, 4.5998808d-06, 8.4960789d-07 /
      data fpp(11,17,13,1),fpp(11,17,13,2),fpp(11,17,13,3)/
     x 1.6901528d-02, 6.9905195d-06, 6.8617589d-07 /
      data fpp(11,17,14,1),fpp(11,17,14,2),fpp(11,17,14,3)/
     x 1.7525287d-02, 7.9986246d-06, 1.1336885d-06 /
      data fpp(11,17,15,1),fpp(11,17,15,2),fpp(11,17,15,3)/
     x 1.7849509d-02, 8.7925728d-06, 1.0310699d-06 /
      data fpp(11,17,16,1),fpp(11,17,16,2),fpp(11,17,16,3)/
     x 1.8110431d-02, 9.7965825d-06, 8.0803180d-07 /
      data fpp(11,17,17,1),fpp(11,17,17,2),fpp(11,17,17,3)/
     x 1.8331351d-02, 1.1069892d-05, 4.6480287d-07 /
      data fpp(11,17,18,1),fpp(11,17,18,2),fpp(11,17,18,3)/
     x 1.8536408d-02, 1.2410488d-05, 8.6756716d-08 /
      data fpp(11,17,19,1),fpp(11,17,19,2),fpp(11,17,19,3)/
     x 1.8641789d-02, 1.3578447d-05,-2.1182973d-07 /
      data fpp(11,17,20,1),fpp(11,17,20,2),fpp(11,17,20,3)/
     x 1.8768186d-02, 1.4333275d-05,-4.7543779d-07 /
      data fpp(11,17,21,1),fpp(11,17,21,2),fpp(11,17,21,3)/
     x 1.8768186d-02, 1.4333275d-05,-4.8377177d-07 /
      data fpp(11,17,22,1),fpp(11,17,22,2),fpp(11,17,22,3)/
     x 1.8641789d-02, 1.3578447d-05,-1.7849378d-07 /
      data fpp(11,17,23,1),fpp(11,17,23,2),fpp(11,17,23,3)/
     x 1.8536408d-02, 1.2410488d-05,-3.8253111d-08 /
      data fpp(11,18, 1,1),fpp(11,18, 1,2),fpp(11,18, 1,3)/
     x-9.1460033d-01,-3.0196239d-04,-7.5075645d-06 /
      data fpp(11,18, 2,1),fpp(11,18, 2,2),fpp(11,18, 2,3)/
     x-6.9062488d-01,-3.3131263d-04,-1.8788709d-06 /
      data fpp(11,18, 3,1),fpp(11,18, 3,2),fpp(11,18, 3,3)/
     x-2.8680593d-01,-3.3636295d-04, 1.1399048d-05 /
      data fpp(11,18, 4,1),fpp(11,18, 4,2),fpp(11,18, 4,3)/
     x-2.8680593d-01,-3.3636295d-04, 9.2702908d-06 /
      data fpp(11,18, 5,1),fpp(11,18, 5,2),fpp(11,18, 5,3)/
     x-6.9062488d-01,-3.3131263d-04, 6.6361586d-06 /
      data fpp(11,18, 6,1),fpp(11,18, 6,2),fpp(11,18, 6,3)/
     x-9.1460033d-01,-3.0196239d-04,-3.9438925d-05 /
      data fpp(11,18, 7,1),fpp(11,18, 7,2),fpp(11,18, 7,3)/
     x 3.5148646d-02,-2.0085246d-04, 1.0947543d-05 /
      data fpp(11,18, 8,1),fpp(11,18, 8,2),fpp(11,18, 8,3)/
     x 6.5810984d-02,-9.5000880d-05,-1.8372464d-06 /
      data fpp(11,18, 9,1),fpp(11,18, 9,2),fpp(11,18, 9,3)/
     x-1.8939280d-03,-3.2677948d-05, 1.8074427d-06 /
      data fpp(11,18,10,1),fpp(11,18,10,2),fpp(11,18,10,3)/
     x 1.6757834d-02,-2.1693138d-05, 8.2947579d-07 /
      data fpp(11,18,11,1),fpp(11,18,11,2),fpp(11,18,11,3)/
     x 1.7381382d-02,-1.2697129d-05, 1.0366542d-06 /
      data fpp(11,18,12,1),fpp(11,18,12,2),fpp(11,18,12,3)/
     x 1.6852294d-02,-5.7559659d-06, 9.1590751d-07 /
      data fpp(11,18,13,1),fpp(11,18,13,2),fpp(11,18,13,3)/
     x 1.7634368d-02,-1.5729127d-07, 8.6771579d-07 /
      data fpp(11,18,14,1),fpp(11,18,14,2),fpp(11,18,14,3)/
     x 1.7684250d-02, 4.6532501d-06, 7.8522932d-07 /
      data fpp(11,18,15,1),fpp(11,18,15,2),fpp(11,18,15,3)/
     x 1.7680457d-02, 8.9752649d-06, 6.9536693d-07 /
      data fpp(11,18,16,1),fpp(11,18,16,2),fpp(11,18,16,3)/
     x 1.7633491d-02, 1.2914834d-05, 5.9730296d-07 /
      data fpp(11,18,17,1),fpp(11,18,17,2),fpp(11,18,17,3)/
     x 1.7526510d-02, 1.6431460d-05, 4.7942123d-07 /
      data fpp(11,18,18,1),fpp(11,18,18,2),fpp(11,18,18,3)/
     x 1.7531988d-02, 1.9420146d-05, 3.8901214d-07 /
      data fpp(11,18,19,1),fpp(11,18,19,2),fpp(11,18,19,3)/
     x 1.7477016d-02, 2.1711015d-05, 3.0453023d-07 /
      data fpp(11,18,20,1),fpp(11,18,20,2),fpp(11,18,20,3)/
     x 1.7672564d-02, 2.3165350d-05, 2.4686694d-07 /
      data fpp(11,18,21,1),fpp(11,18,21,2),fpp(11,18,21,3)/
     x 1.7672564d-02, 2.3165350d-05, 2.4413407d-07 /
      data fpp(11,18,22,1),fpp(11,18,22,2),fpp(11,18,22,3)/
     x 1.7477016d-02, 2.1711015d-05, 3.1546169d-07 /
      data fpp(11,18,23,1),fpp(11,18,23,2),fpp(11,18,23,3)/
     x 1.7531988d-02, 1.9420146d-05, 3.4801915d-07 /
      data fpp(11,19, 1,1),fpp(11,19, 1,2),fpp(11,19, 1,3)/
     x 1.8615060d-02,-5.8723281d-04, 1.9939618d-20 /
      data fpp(11,19, 2,1),fpp(11,19, 2,2),fpp(11,19, 2,3)/
     x 1.8615060d-02,-6.5416569d-04,-1.4618053d-20 /
      data fpp(11,19, 3,1),fpp(11,19, 3,2),fpp(11,19, 3,3)/
     x 1.8615060d-02,-6.7330203d-04,-2.7594856d-20 /
      data fpp(11,19, 4,1),fpp(11,19, 4,2),fpp(11,19, 4,3)/
     x 1.8615060d-02,-6.7330203d-04, 2.0668204d-20 /
      data fpp(11,19, 5,1),fpp(11,19, 5,2),fpp(11,19, 5,3)/
     x 1.8615060d-02,-6.5416569d-04, 2.0862290d-21 /
      data fpp(11,19, 6,1),fpp(11,19, 6,2),fpp(11,19, 6,3)/
     x 1.8615060d-02,-5.8723281d-04,-9.1939048d-21 /
      data fpp(11,19, 7,1),fpp(11,19, 7,2),fpp(11,19, 7,3)/
     x 1.8615060d-02,-3.7758677d-04,-4.4895021d-20 /
      data fpp(11,19, 8,1),fpp(11,19, 8,2),fpp(11,19, 8,3)/
     x 1.8615060d-02,-1.6061656d-04,-3.1273830d-20 /
      data fpp(11,19, 9,1),fpp(11,19, 9,2),fpp(11,19, 9,3)/
     x 1.8615060d-02,-4.1563026d-05, 1.5549934d-20 /
      data fpp(11,19,10,1),fpp(11,19,10,2),fpp(11,19,10,3)/
     x 1.8615060d-02,-3.4403931d-05, 3.2581414d-20 /
      data fpp(11,19,11,1),fpp(11,19,11,2),fpp(11,19,11,3)/
     x 1.8615060d-02,-2.4412936d-05,-3.3604238d-20 /
      data fpp(11,19,12,1),fpp(11,19,12,2),fpp(11,19,12,3)/
     x 1.8615060d-02,-1.4132017d-05, 2.5018790d-20 /
      data fpp(11,19,13,1),fpp(11,19,13,2),fpp(11,19,13,3)/
     x 1.8615060d-02,-4.8253544d-06, 1.4341585d-20 /
      data fpp(11,19,14,1),fpp(11,19,14,2),fpp(11,19,14,3)/
     x 1.8615060d-02, 3.4003749d-06, 1.5236058d-20 /
      data fpp(11,19,15,1),fpp(11,19,15,2),fpp(11,19,15,3)/
     x 1.8615060d-02, 1.0638368d-05, 1.3750956d-20 /
      data fpp(11,19,16,1),fpp(11,19,16,2),fpp(11,19,16,3)/
     x 1.8615060d-02, 1.6934083d-05,-2.7116554d-20 /
      data fpp(11,19,17,1),fpp(11,19,17,2),fpp(11,19,17,3)/
     x 1.8615060d-02, 2.2252270d-05, 1.2106056d-20 /
      data fpp(11,19,18,1),fpp(11,19,18,2),fpp(11,19,18,3)/
     x 1.8615060d-02, 2.6560927d-05,-3.9779638d-20 /
      data fpp(11,19,19,1),fpp(11,19,19,2),fpp(11,19,19,3)/
     x 1.8615060d-02, 2.9753492d-05,-3.3278496d-20 /
      data fpp(11,19,20,1),fpp(11,19,20,2),fpp(11,19,20,3)/
     x 1.8615060d-02, 3.1761325d-05, 2.1105562d-20 /
      data fpp(11,19,21,1),fpp(11,19,21,2),fpp(11,19,21,3)/
     x 1.8615060d-02, 3.1761325d-05,-3.5114910d-20 /
      data fpp(11,19,22,1),fpp(11,19,22,2),fpp(11,19,22,3)/
     x 1.8615060d-02, 2.9753492d-05, 2.0757090d-20 /
      data fpp(11,19,23,1),fpp(11,19,23,2),fpp(11,19,23,3)/
     x 1.8615060d-02, 2.6560927d-05, 6.5684118d-20 /
      data fpp(12, 1, 1,1),fpp(12, 1, 1,2),fpp(12, 1, 1,3)/
     x 4.9098648d-01, 1.9709122d-03, 2.1194567d-19 /
      data fpp(12, 1, 2,1),fpp(12, 1, 2,2),fpp(12, 1, 2,3)/
     x 4.9098648d-01, 2.9877526d-03,-1.1482762d-20 /
      data fpp(12, 1, 3,1),fpp(12, 1, 3,2),fpp(12, 1, 3,3)/
     x 4.9098648d-01, 3.2212388d-03,-2.5251229d-19 /
      data fpp(12, 1, 4,1),fpp(12, 1, 4,2),fpp(12, 1, 4,3)/
     x 4.9098648d-01, 3.2212388d-03, 1.8559947d-19 /
      data fpp(12, 1, 5,1),fpp(12, 1, 5,2),fpp(12, 1, 5,3)/
     x 4.9098648d-01, 2.9877526d-03, 1.2672124d-19 /
      data fpp(12, 1, 6,1),fpp(12, 1, 6,2),fpp(12, 1, 6,3)/
     x 4.9098648d-01, 1.9709122d-03,-1.5600571d-19 /
      data fpp(12, 1, 7,1),fpp(12, 1, 7,2),fpp(12, 1, 7,3)/
     x 4.9098648d-01, 1.9759872d-04,-2.3482458d-19 /
      data fpp(12, 1, 8,1),fpp(12, 1, 8,2),fpp(12, 1, 8,3)/
     x 4.9098648d-01,-3.5307050d-04,-2.7510653d-19 /
      data fpp(12, 1, 9,1),fpp(12, 1, 9,2),fpp(12, 1, 9,3)/
     x 4.9098648d-01,-5.8578756d-04, 1.0542047d-19 /
      data fpp(12, 1,10,1),fpp(12, 1,10,2),fpp(12, 1,10,3)/
     x 4.9098648d-01,-6.6600882d-04, 3.6492365d-19 /
      data fpp(12, 1,11,1),fpp(12, 1,11,2),fpp(12, 1,11,3)/
     x 4.9098648d-01,-7.0182923d-04,-1.5031915d-19 /
      data fpp(12, 1,12,1),fpp(12, 1,12,2),fpp(12, 1,12,3)/
     x 4.9098648d-01,-7.1407706d-04, 2.5491484d-19 /
      data fpp(12, 1,13,1),fpp(12, 1,13,2),fpp(12, 1,13,3)/
     x 4.9098648d-01,-7.0828813d-04, 2.4544022d-20 /
      data fpp(12, 1,14,1),fpp(12, 1,14,2),fpp(12, 1,14,3)/
     x 4.9098648d-01,-6.7862385d-04, 4.4926390d-20 /
      data fpp(12, 1,15,1),fpp(12, 1,15,2),fpp(12, 1,15,3)/
     x 4.9098648d-01,-6.8528315d-04, 1.4853336d-19 /
      data fpp(12, 1,16,1),fpp(12, 1,16,2),fpp(12, 1,16,3)/
     x 4.9098648d-01,-3.7054642d-04,-2.0153412d-19 /
      data fpp(12, 1,17,1),fpp(12, 1,17,2),fpp(12, 1,17,3)/
     x 4.9098648d-01, 1.7665449d-04, 2.0059690d-19 /
      data fpp(12, 1,18,1),fpp(12, 1,18,2),fpp(12, 1,18,3)/
     x 4.9098648d-01, 1.9433160d-03,-3.2012585d-19 /
      data fpp(12, 1,19,1),fpp(12, 1,19,2),fpp(12, 1,19,3)/
     x 4.9098648d-01, 2.8818698d-03,-3.2457790d-19 /
      data fpp(12, 1,20,1),fpp(12, 1,20,2),fpp(12, 1,20,3)/
     x 4.9098648d-01, 3.1046517d-03, 2.4707426d-19 /
      data fpp(12, 1,21,1),fpp(12, 1,21,2),fpp(12, 1,21,3)/
     x 4.9098648d-01, 3.1046517d-03,-9.2067596d-20 /
      data fpp(12, 1,22,1),fpp(12, 1,22,2),fpp(12, 1,22,3)/
     x 4.9098648d-01, 2.8818698d-03, 3.5180522d-19 /
      data fpp(12, 1,23,1),fpp(12, 1,23,2),fpp(12, 1,23,3)/
     x 4.9098648d-01, 1.9433160d-03, 8.7554778d-19 /
      data fpp(12, 2, 1,1),fpp(12, 2, 1,2),fpp(12, 2, 1,3)/
     x 7.0764646d-01, 7.9981057d-04,-2.8165382d-06 /
      data fpp(12, 2, 2,1),fpp(12, 2, 2,2),fpp(12, 2, 2,3)/
     x 6.7153053d-01, 1.0770578d-03,-2.6548924d-05 /
      data fpp(12, 2, 3,1),fpp(12, 2, 3,2),fpp(12, 2, 3,3)/
     x 4.5899346d-01, 1.1742704d-03,-7.7635767d-05 /
      data fpp(12, 2, 4,1),fpp(12, 2, 4,2),fpp(12, 2, 4,3)/
     x 4.5899346d-01, 1.1742704d-03,-7.7230236d-05 /
      data fpp(12, 2, 5,1),fpp(12, 2, 5,2),fpp(12, 2, 5,3)/
     x 6.7153053d-01, 1.0770578d-03,-2.8171047d-05 /
      data fpp(12, 2, 6,1),fpp(12, 2, 6,2),fpp(12, 2, 6,3)/
     x 7.0764646d-01, 7.9981057d-04, 3.2664231d-06 /
      data fpp(12, 2, 7,1),fpp(12, 2, 7,2),fpp(12, 2, 7,3)/
     x 6.2318668d-01, 1.1701756d-04, 2.0271354d-05 /
      data fpp(12, 2, 8,1),fpp(12, 2, 8,2),fpp(12, 2, 8,3)/
     x 5.6837408d-01,-7.9469003d-05, 2.8520160d-05 /
      data fpp(12, 2, 9,1),fpp(12, 2, 9,2),fpp(12, 2, 9,3)/
     x 5.3377385d-01,-1.5559687d-04, 2.3622005d-05 /
      data fpp(12, 2,10,1),fpp(12, 2,10,2),fpp(12, 2,10,3)/
     x 5.5904032d-01,-1.7420637d-04, 2.9697819d-05 /
      data fpp(12, 2,11,1),fpp(12, 2,11,2),fpp(12, 2,11,3)/
     x 5.4320515d-01,-1.8081255d-04, 2.6420717d-05 /
      data fpp(12, 2,12,1),fpp(12, 2,12,2),fpp(12, 2,12,3)/
     x 6.0341175d-01,-1.8392187d-04, 2.7825312d-05 /
      data fpp(12, 2,13,1),fpp(12, 2,13,2),fpp(12, 2,13,3)/
     x 6.0017479d-01,-1.8599474d-04, 2.7362035d-05 /
      data fpp(12, 2,14,1),fpp(12, 2,14,2),fpp(12, 2,14,3)/
     x 5.5555719d-01,-1.8443831d-04, 2.7342547d-05 /
      data fpp(12, 2,15,1),fpp(12, 2,15,2),fpp(12, 2,15,3)/
     x 5.6020608d-01,-2.0520169d-04, 2.7301776d-05 /
      data fpp(12, 2,16,1),fpp(12, 2,16,2),fpp(12, 2,16,3)/
     x 5.6327052d-01,-9.5974152d-05, 2.6194350d-05 /
      data fpp(12, 2,17,1),fpp(12, 2,17,2),fpp(12, 2,17,3)/
     x 6.3083272d-01, 9.8015013d-05, 2.0530825d-05 /
      data fpp(12, 2,18,1),fpp(12, 2,18,2),fpp(12, 2,18,3)/
     x 7.0705636d-01, 7.7905902d-04, 2.4303501d-06 /
      data fpp(12, 2,19,1),fpp(12, 2,19,2),fpp(12, 2,19,3)/
     x 6.2803677d-01, 1.0315133d-03,-2.9094226d-05 /
      data fpp(12, 2,20,1),fpp(12, 2,20,2),fpp(12, 2,20,3)/
     x 4.1748416d-01, 1.1321596d-03,-7.8269448d-05 /
      data fpp(12, 2,21,1),fpp(12, 2,21,2),fpp(12, 2,21,3)/
     x 4.1748416d-01, 1.1321596d-03,-7.8676543d-05 /
      data fpp(12, 2,22,1),fpp(12, 2,22,2),fpp(12, 2,22,3)/
     x 6.2803677d-01, 1.0315133d-03,-2.7465845d-05 /
      data fpp(12, 2,23,1),fpp(12, 2,23,2),fpp(12, 2,23,3)/
     x 7.0705636d-01, 7.7905902d-04,-3.6760776d-06 /
      data fpp(12, 3, 1,1),fpp(12, 3, 1,2),fpp(12, 3, 1,3)/
     x 2.1270474d-01,-1.7256565d-03,-5.8641235d-04 /
      data fpp(12, 3, 2,1),fpp(12, 3, 2,2),fpp(12, 3, 2,3)/
     x-2.7642231d-01,-1.3214538d-03,-4.4551680d-04 /
      data fpp(12, 3, 3,1),fpp(12, 3, 3,2),fpp(12, 3, 3,3)/
     x 1.3274057d-01,-1.5690125d-03,-1.6007045d-04 /
      data fpp(12, 3, 4,1),fpp(12, 3, 4,2),fpp(12, 3, 4,3)/
     x 1.3274057d-01,-1.5690125d-03,-1.3124324d-04 /
      data fpp(12, 3, 5,1),fpp(12, 3, 5,2),fpp(12, 3, 5,3)/
     x-2.7642231d-01,-1.3214538d-03,-5.6082565d-04 /
      data fpp(12, 3, 6,1),fpp(12, 3, 6,2),fpp(12, 3, 6,3)/
     x 2.1270474d-01,-1.7256565d-03,-1.5400416d-04 /
      data fpp(12, 3, 7,1),fpp(12, 3, 7,2),fpp(12, 3, 7,3)/
     x 1.9580871d-01,-2.8808296d-04, 6.5029429d-04 /
      data fpp(12, 3, 8,1),fpp(12, 3, 8,2),fpp(12, 3, 8,3)/
     x 2.1576973d-01, 2.2877051d-04, 2.5720995d-05 /
      data fpp(12, 3, 9,1),fpp(12, 3, 9,2),fpp(12, 3, 9,3)/
     x 2.2114421d-01, 4.9829105d-04, 1.1482373d-04 /
      data fpp(12, 3,10,1),fpp(12, 3,10,2),fpp(12, 3,10,3)/
     x 2.2475757d-01, 6.1380628d-04, 4.8960084d-05 /
      data fpp(12, 3,11,1),fpp(12, 3,11,2),fpp(12, 3,11,3)/
     x 1.8977858d-01, 6.6723742d-04, 5.7333935d-05 /
      data fpp(12, 3,12,1),fpp(12, 3,12,2),fpp(12, 3,12,3)/
     x 1.8981143d-01, 6.8172855d-04, 4.6736177d-05 /
      data fpp(12, 3,13,1),fpp(12, 3,13,2),fpp(12, 3,13,3)/
     x 2.0458430d-01, 6.6250508d-04, 7.4357357d-05 /
      data fpp(12, 3,14,1),fpp(12, 3,14,2),fpp(12, 3,14,3)/
     x 2.1696410d-01, 6.0450507d-04,-1.5317603d-05 /
      data fpp(12, 3,15,1),fpp(12, 3,15,2),fpp(12, 3,15,3)/
     x 1.2445081d+00, 5.7829792d-04, 2.2117106d-04 /
      data fpp(12, 3,16,1),fpp(12, 3,16,2),fpp(12, 3,16,3)/
     x 2.1668400d-01, 2.1149703d-04,-4.3112622d-05 /
      data fpp(12, 3,17,1),fpp(12, 3,17,2),fpp(12, 3,17,3)/
     x 1.9504618d-01,-3.0197855d-04, 6.8133543d-04 /
      data fpp(12, 3,18,1),fpp(12, 3,18,2),fpp(12, 3,18,3)/
     x 1.9852913d-01,-1.7317301d-03,-2.0932911d-04 /
      data fpp(12, 3,19,1),fpp(12, 3,19,2),fpp(12, 3,19,3)/
     x-2.4410502d-01,-1.2937452d-03,-5.1643301d-04 /
      data fpp(12, 3,20,1),fpp(12, 3,20,2),fpp(12, 3,20,3)/
     x 1.3473561d-01,-1.5617762d-03,-1.3839086d-04 /
      data fpp(12, 3,21,1),fpp(12, 3,21,2),fpp(12, 3,21,3)/
     x 1.3473561d-01,-1.5617762d-03,-1.6134293d-04 /
      data fpp(12, 3,22,1),fpp(12, 3,22,2),fpp(12, 3,22,3)/
     x-2.4410502d-01,-1.2937452d-03,-4.2462474d-04 /
      data fpp(12, 3,23,1),fpp(12, 3,23,2),fpp(12, 3,23,3)/
     x 1.9852913d-01,-1.7317301d-03,-5.5361013d-04 /
      data fpp(12, 4, 1,1),fpp(12, 4, 1,2),fpp(12, 4, 1,3)/
     x 1.8900554d-02, 4.8915540d-04,-1.2740903d-03 /
      data fpp(12, 4, 2,1),fpp(12, 4, 2,2),fpp(12, 4, 2,3)/
     x 1.0713998d+00,-2.0126064d-03,-8.9318482d-04 /
      data fpp(12, 4, 3,1),fpp(12, 4, 3,2),fpp(12, 4, 3,3)/
     x 1.0149011d-01,-1.8751944d-03,-1.7152837d-04 /
      data fpp(12, 4, 4,1),fpp(12, 4, 4,2),fpp(12, 4, 4,3)/
     x 1.0149011d-01,-1.8751944d-03,-6.0314794d-06 /
      data fpp(12, 4, 5,1),fpp(12, 4, 5,2),fpp(12, 4, 5,3)/
     x 1.0713998d+00,-2.0126064d-03,-1.5551724d-03 /
      data fpp(12, 4, 6,1),fpp(12, 4, 6,2),fpp(12, 4, 6,3)/
     x 1.8900554d-02, 4.8915540d-04, 1.2083630d-03 /
      data fpp(12, 4, 7,1),fpp(12, 4, 7,2),fpp(12, 4, 7,3)/
     x 2.3822413d-01, 4.4263429d-04, 7.6734322d-05 /
      data fpp(12, 4, 8,1),fpp(12, 4, 8,2),fpp(12, 4, 8,3)/
     x 3.9962592d-02, 4.1577696d-04, 1.4070570d-04 /
      data fpp(12, 4, 9,1),fpp(12, 4, 9,2),fpp(12, 4, 9,3)/
     x 3.6201081d-02, 3.6923867d-04, 4.9818889d-05 /
      data fpp(12, 4,10,1),fpp(12, 4,10,2),fpp(12, 4,10,3)/
     x-8.0183010d-02, 3.6508325d-04, 5.9144748d-05 /
      data fpp(12, 4,11,1),fpp(12, 4,11,2),fpp(12, 4,11,3)/
     x-1.8101578d-02, 3.7067086d-04, 5.4174118d-05 /
      data fpp(12, 4,12,1),fpp(12, 4,12,2),fpp(12, 4,12,3)/
     x 3.5720177d-02, 3.7314565d-04, 5.5640781d-05 /
      data fpp(12, 4,13,1),fpp(12, 4,13,2),fpp(12, 4,13,3)/
     x-1.2264022d-02, 3.6928240d-04, 5.5290759d-05 /
      data fpp(12, 4,14,1),fpp(12, 4,14,2),fpp(12, 4,14,3)/
     x-1.0370502d-01, 3.6179602d-04, 6.1176182d-05 /
      data fpp(12, 4,15,1),fpp(12, 4,15,2),fpp(12, 4,15,3)/
     x 3.5836072d-02, 2.9983401d-04, 5.4862514d-05 /
      data fpp(12, 4,16,1),fpp(12, 4,16,2),fpp(12, 4,16,3)/
     x 3.7791653d-02, 4.0382202d-04, 1.4270376d-04 /
      data fpp(12, 4,17,1),fpp(12, 4,17,2),fpp(12, 4,17,3)/
     x 3.6637139d-02, 4.2276717d-04, 9.4844432d-05 /
      data fpp(12, 4,18,1),fpp(12, 4,18,2),fpp(12, 4,18,3)/
     x 1.4274668d-02, 4.7034322d-04, 1.1635525d-03 /
      data fpp(12, 4,19,1),fpp(12, 4,19,2),fpp(12, 4,19,3)/
     x 9.5911686d-01,-1.9568467d-03,-1.5274505d-03 /
      data fpp(12, 4,20,1),fpp(12, 4,20,2),fpp(12, 4,20,3)/
     x 1.0344991d-01,-1.7306587d-03,-1.0932633d-05 /
      data fpp(12, 4,21,1),fpp(12, 4,21,2),fpp(12, 4,21,3)/
     x 1.0344991d-01,-1.7306587d-03,-1.7226387d-04 /
      data fpp(12, 4,22,1),fpp(12, 4,22,2),fpp(12, 4,22,3)/
     x 9.5911686d-01,-1.9568467d-03,-8.8212554d-04 /
      data fpp(12, 4,23,1),fpp(12, 4,23,2),fpp(12, 4,23,3)/
     x 1.4274668d-02, 4.7034322d-04,-1.2564160d-03 /
      data fpp(12, 5, 1,1),fpp(12, 5, 1,2),fpp(12, 5, 1,3)/
     x-1.0366893d-02, 5.3020088d-04, 2.2566592d-04 /
      data fpp(12, 5, 2,1),fpp(12, 5, 2,2),fpp(12, 5, 2,3)/
     x-8.9616168d-03, 2.3358056d-03, 6.5345151d-05 /
      data fpp(12, 5, 3,1),fpp(12, 5, 3,2),fpp(12, 5, 3,3)/
     x-8.3911925d-03, 1.9607740d-03,-2.7091453d-04 /
      data fpp(12, 5, 4,1),fpp(12, 5, 4,2),fpp(12, 5, 4,3)/
     x-8.3911925d-03, 1.9607740d-03,-2.8366299d-04 /
      data fpp(12, 5, 5,1),fpp(12, 5, 5,2),fpp(12, 5, 5,3)/
     x-8.9616168d-03, 2.3358056d-03, 1.1633898d-04 /
      data fpp(12, 5, 6,1),fpp(12, 5, 6,2),fpp(12, 5, 6,3)/
     x-1.0366893d-02, 5.3020088d-04, 3.4439061d-05 /
      data fpp(12, 5, 7,1),fpp(12, 5, 7,2),fpp(12, 5, 7,3)/
     x-1.4295710d-02, 1.5019380d-04, 5.6722773d-05 /
      data fpp(12, 5, 8,1),fpp(12, 5, 8,2),fpp(12, 5, 8,3)/
     x-1.0113193d-02, 7.6949662d-05, 4.2485845d-05 /
      data fpp(12, 5, 9,1),fpp(12, 5, 9,2),fpp(12, 5, 9,3)/
     x-6.7329455d-03, 9.2876266d-05, 4.7197846d-05 /
      data fpp(12, 5,10,1),fpp(12, 5,10,2),fpp(12, 5,10,3)/
     x-4.3689774d-03, 1.0725673d-04, 4.6978772d-05 /
      data fpp(12, 5,11,1),fpp(12, 5,11,2),fpp(12, 5,11,3)/
     x-3.0670004d-03, 1.1358513d-04, 4.6869065d-05 /
      data fpp(12, 5,12,1),fpp(12, 5,12,2),fpp(12, 5,12,3)/
     x-2.4847101d-03, 1.1480283d-04, 4.6974966d-05 /
      data fpp(12, 5,13,1),fpp(12, 5,13,2),fpp(12, 5,13,3)/
     x-2.6238678d-03, 1.1255531d-04, 4.8119071d-05 /
      data fpp(12, 5,14,1),fpp(12, 5,14,2),fpp(12, 5,14,3)/
     x-3.5437326d-03, 1.0565885d-04, 4.9742750d-05 /
      data fpp(12, 5,15,1),fpp(12, 5,15,2),fpp(12, 5,15,3)/
     x-5.3069395d-03, 1.0847804d-04, 5.1973929d-05 /
      data fpp(12, 5,16,1),fpp(12, 5,16,2),fpp(12, 5,16,3)/
     x-8.6130354d-03, 7.6360889d-05, 5.1037536d-05 /
      data fpp(12, 5,17,1),fpp(12, 5,17,2),fpp(12, 5,17,3)/
     x-1.1874444d-02, 1.4520586d-04, 6.8979928d-05 /
      data fpp(12, 5,18,1),fpp(12, 5,18,2),fpp(12, 5,18,3)/
     x-1.6878883d-02, 5.0049316d-04, 5.6100752d-05 /
      data fpp(12, 5,19,1),fpp(12, 5,19,2),fpp(12, 5,19,3)/
     x-2.8823533d-02, 2.1857740d-03, 1.2090506d-04 /
      data fpp(12, 5,20,1),fpp(12, 5,20,2),fpp(12, 5,20,3)/
     x-1.6584022d-02, 1.6922971d-03,-3.1189501d-04 /
      data fpp(12, 5,21,1),fpp(12, 5,21,2),fpp(12, 5,21,3)/
     x-1.6584022d-02, 1.6922971d-03,-2.9923151d-04 /
      data fpp(12, 5,22,1),fpp(12, 5,22,2),fpp(12, 5,22,3)/
     x-2.8823533d-02, 2.1857740d-03, 7.0251074d-05 /
      data fpp(12, 5,23,1),fpp(12, 5,23,2),fpp(12, 5,23,3)/
     x-1.6878883d-02, 5.0049316d-04, 2.4605321d-04 /
      data fpp(12, 6, 1,1),fpp(12, 6, 1,2),fpp(12, 6, 1,3)/
     x-2.3795651d-02,-1.5132093d-04, 7.8802237d-05 /
      data fpp(12, 6, 2,1),fpp(12, 6, 2,2),fpp(12, 6, 2,3)/
     x-3.9340791d-02,-6.0445982d-04, 8.6500265d-06 /
      data fpp(12, 6, 3,1),fpp(12, 6, 3,2),fpp(12, 6, 3,3)/
     x-1.0816243d-01,-4.5028376d-04,-1.3883634d-04 /
      data fpp(12, 6, 4,1),fpp(12, 6, 4,2),fpp(12, 6, 4,3)/
     x-1.0816243d-01,-4.5028376d-04,-1.4380598d-04 /
      data fpp(12, 6, 5,1),fpp(12, 6, 5,2),fpp(12, 6, 5,3)/
     x-3.9340791d-02,-6.0445982d-04, 2.8528593d-05 /
      data fpp(12, 6, 6,1),fpp(12, 6, 6,2),fpp(12, 6, 6,3)/
     x-2.3795651d-02,-1.5132093d-04, 4.2576123d-06 /
      data fpp(12, 6, 7,1),fpp(12, 6, 7,2),fpp(12, 6, 7,3)/
     x-1.6775860d-02,-4.9383504d-05, 2.3968958d-05 /
      data fpp(12, 6, 8,1),fpp(12, 6, 8,2),fpp(12, 6, 8,3)/
     x-1.3531700d-02,-1.7993605d-05, 2.7660557d-05 /
      data fpp(12, 6, 9,1),fpp(12, 6, 9,2),fpp(12, 6, 9,3)/
     x-1.2025836d-02,-1.5439733d-05, 3.1906816d-05 /
      data fpp(12, 6,10,1),fpp(12, 6,10,2),fpp(12, 6,10,3)/
     x-1.1389166d-02,-1.7620171d-05, 3.3562179d-05 /
      data fpp(12, 6,11,1),fpp(12, 6,11,2),fpp(12, 6,11,3)/
     x-1.1039197d-02,-1.9673383d-05, 3.4898467d-05 /
      data fpp(12, 6,12,1),fpp(12, 6,12,2),fpp(12, 6,12,3)/
     x-1.0806183d-02,-2.0526958d-05, 3.5865954d-05 /
      data fpp(12, 6,13,1),fpp(12, 6,13,2),fpp(12, 6,13,3)/
     x-1.0569079d-02,-1.9883652d-05, 3.6683718d-05 /
      data fpp(12, 6,14,1),fpp(12, 6,14,2),fpp(12, 6,14,3)/
     x-1.0356503d-02,-1.7367412d-05, 3.7461175d-05 /
      data fpp(12, 6,15,1),fpp(12, 6,15,2),fpp(12, 6,15,3)/
     x-1.0292626d-02,-1.7646172d-05, 3.8333582d-05 /
      data fpp(12, 6,16,1),fpp(12, 6,16,2),fpp(12, 6,16,3)/
     x-1.0778810d-02,-1.0319576d-05, 3.7036497d-05 /
      data fpp(12, 6,17,1),fpp(12, 6,17,2),fpp(12, 6,17,3)/
     x-1.2111268d-02,-2.9520629d-05, 3.5484429d-05 /
      data fpp(12, 6,18,1),fpp(12, 6,18,2),fpp(12, 6,18,3)/
     x-1.4930782d-02,-1.0707387d-04, 1.7555785d-05 /
      data fpp(12, 6,19,1),fpp(12, 6,19,2),fpp(12, 6,19,3)/
     x-1.9658875d-02,-5.0345710d-04, 2.7642429d-05 /
      data fpp(12, 6,20,1),fpp(12, 6,20,2),fpp(12, 6,20,3)/
     x-1.6576084d-02,-2.8178386d-04,-1.5888750d-04 /
      data fpp(12, 6,21,1),fpp(12, 6,21,2),fpp(12, 6,21,3)/
     x-1.6576084d-02,-2.8178386d-04,-1.5427671d-04 /
      data fpp(12, 6,22,1),fpp(12, 6,22,2),fpp(12, 6,22,3)/
     x-1.9658875d-02,-5.0345710d-04, 9.1992749d-06 /
      data fpp(12, 6,23,1),fpp(12, 6,23,2),fpp(12, 6,23,3)/
     x-1.4930782d-02,-1.0707387d-04, 8.6717613d-05 /
      data fpp(12, 7, 1,1),fpp(12, 7, 1,2),fpp(12, 7, 1,3)/
     x-3.6903849d-04, 4.9234823d-05,-3.4453623d-06 /
      data fpp(12, 7, 2,1),fpp(12, 7, 2,2),fpp(12, 7, 2,3)/
     x 4.7679401d-03, 2.1867172d-04,-1.7717775d-05 /
      data fpp(12, 7, 3,1),fpp(12, 7, 3,2),fpp(12, 7, 3,3)/
     x 1.5086719d-02, 2.8400702d-04,-4.8161536d-05 /
      data fpp(12, 7, 4,1),fpp(12, 7, 4,2),fpp(12, 7, 4,3)/
     x 1.5086719d-02, 2.8400702d-04,-4.8406504d-05 /
      data fpp(12, 7, 5,1),fpp(12, 7, 5,2),fpp(12, 7, 5,3)/
     x 4.7679401d-03, 2.1867172d-04,-1.6737904d-05 /
      data fpp(12, 7, 6,1),fpp(12, 7, 6,2),fpp(12, 7, 6,3)/
     x-3.6903849d-04, 4.9234823d-05,-7.1198798d-06 /
      data fpp(12, 7, 7,1),fpp(12, 7, 7,2),fpp(12, 7, 7,3)/
     x-3.3243186d-03,-1.2665789d-05, 1.7834233d-06 /
      data fpp(12, 7, 8,1),fpp(12, 7, 8,2),fpp(12, 7, 8,3)/
     x-5.9180362d-03,-4.2481244d-05, 8.4161865d-06 /
      data fpp(12, 7, 9,1),fpp(12, 7, 9,2),fpp(12, 7, 9,3)/
     x-8.2011586d-03,-5.5315332d-05, 1.4531831d-05 /
      data fpp(12, 7,10,1),fpp(12, 7,10,2),fpp(12, 7,10,3)/
     x-9.8716070d-03,-6.0956045d-05, 1.9610491d-05 /
      data fpp(12, 7,11,1),fpp(12, 7,11,2),fpp(12, 7,11,3)/
     x-1.0809388d-02,-6.2863598d-05, 2.3342207d-05 /
      data fpp(12, 7,12,1),fpp(12, 7,12,2),fpp(12, 7,12,3)/
     x-1.1099966d-02,-6.2616994d-05, 2.5476683d-05 /
      data fpp(12, 7,13,1),fpp(12, 7,13,2),fpp(12, 7,13,3)/
     x-1.0788849d-02,-6.0656703d-05, 2.6191063d-05 /
      data fpp(12, 7,14,1),fpp(12, 7,14,2),fpp(12, 7,14,3)/
     x-9.9656368d-03,-5.6379199d-05, 2.5849066d-05 /
      data fpp(12, 7,15,1),fpp(12, 7,15,2),fpp(12, 7,15,3)/
     x-8.1021979d-03,-4.7013354d-05, 2.4696673d-05 /
      data fpp(12, 7,16,1),fpp(12, 7,16,2),fpp(12, 7,16,3)/
     x-6.6527062d-03,-3.3462584d-05, 2.2022242d-05 /
      data fpp(12, 7,17,1),fpp(12, 7,17,2),fpp(12, 7,17,3)/
     x-4.0720822d-03,-4.2753474d-06, 1.6526360d-05 /
      data fpp(12, 7,18,1),fpp(12, 7,18,2),fpp(12, 7,18,3)/
     x-3.8427174d-04, 5.3736323d-05, 3.7323168d-06 /
      data fpp(12, 7,19,1),fpp(12, 7,19,2),fpp(12, 7,19,3)/
     x 5.3852731d-03, 2.2077246d-04,-1.5345628d-05 /
      data fpp(12, 7,20,1),fpp(12, 7,20,2),fpp(12, 7,20,3)/
     x 1.3795202d-02, 2.5902229d-04,-6.7017806d-05 /
      data fpp(12, 7,21,1),fpp(12, 7,21,2),fpp(12, 7,21,3)/
     x 1.3795202d-02, 2.5902229d-04,-6.6778768d-05 /
      data fpp(12, 7,22,1),fpp(12, 7,22,2),fpp(12, 7,22,3)/
     x 5.3852731d-03, 2.2077246d-04,-1.6301781d-05 /
      data fpp(12, 7,23,1),fpp(12, 7,23,2),fpp(12, 7,23,3)/
     x-3.8427174d-04, 5.3736323d-05, 7.3178903d-06 /
      data fpp(12, 8, 1,1),fpp(12, 8, 1,2),fpp(12, 8, 1,3)/
     x 1.1999269d-02, 1.2611633d-05,-8.8816040d-06 /
      data fpp(12, 8, 2,1),fpp(12, 8, 2,2),fpp(12, 8, 2,3)/
     x 1.6631499d-02, 7.2186945d-05,-1.0847792d-05 /
      data fpp(12, 8, 3,1),fpp(12, 8, 3,2),fpp(12, 8, 3,3)/
     x 1.1103859d-01, 9.3031678d-05,-1.5071228d-05 /
      data fpp(12, 8, 4,1),fpp(12, 8, 4,2),fpp(12, 8, 4,3)/
     x 1.1103859d-01, 9.3031678d-05,-1.5053420d-05 /
      data fpp(12, 8, 5,1),fpp(12, 8, 5,2),fpp(12, 8, 5,3)/
     x 1.6631499d-02, 7.2186945d-05,-1.0919024d-05 /
      data fpp(12, 8, 6,1),fpp(12, 8, 6,2),fpp(12, 8, 6,3)/
     x 1.1999269d-02, 1.2611633d-05,-8.6144848d-06 /
      data fpp(12, 8, 7,1),fpp(12, 8, 7,2),fpp(12, 8, 7,3)/
     x 8.0072537d-03,-2.1849339d-05,-6.9610369d-06 /
      data fpp(12, 8, 8,1),fpp(12, 8, 8,2),fpp(12, 8, 8,3)/
     x 3.9131826d-03,-4.3297420d-05,-3.6693676d-06 /
      data fpp(12, 8, 9,1),fpp(12, 8, 9,2),fpp(12, 8, 9,3)/
     x-2.2121439d-04,-5.6692939d-05, 2.2225073d-06 /
      data fpp(12, 8,10,1),fpp(12, 8,10,2),fpp(12, 8,10,3)/
     x-3.8106030d-03,-6.3629647d-05, 8.7353385d-06 /
      data fpp(12, 8,11,1),fpp(12, 8,11,2),fpp(12, 8,11,3)/
     x-6.3797323d-03,-6.6168224d-05, 1.3872139d-05 /
      data fpp(12, 8,12,1),fpp(12, 8,12,2),fpp(12, 8,12,3)/
     x-7.6230419d-03,-6.5329066d-05, 1.6860106d-05 /
      data fpp(12, 8,13,1),fpp(12, 8,13,2),fpp(12, 8,13,3)/
     x-7.6949893d-03,-6.1399535d-05, 1.7963436d-05 /
      data fpp(12, 8,14,1),fpp(12, 8,14,2),fpp(12, 8,14,3)/
     x-6.5143448d-03,-5.4445793d-05, 1.7570151d-05 /
      data fpp(12, 8,15,1),fpp(12, 8,15,2),fpp(12, 8,15,3)/
     x-5.2359508d-03,-4.4572413d-05, 1.5939962d-05 /
      data fpp(12, 8,16,1),fpp(12, 8,16,2),fpp(12, 8,16,3)/
     x-2.8664189d-03,-3.0262088d-05, 1.2936002d-05 /
      data fpp(12, 8,17,1),fpp(12, 8,17,2),fpp(12, 8,17,3)/
     x 2.7241054d-04,-1.2885981d-05, 8.0600304d-06 /
      data fpp(12, 8,18,1),fpp(12, 8,18,2),fpp(12, 8,18,3)/
     x 4.4727608d-03, 5.0905793d-06,-4.4012371d-07 /
      data fpp(12, 8,19,1),fpp(12, 8,19,2),fpp(12, 8,19,3)/
     x 9.7655437d-03, 8.8125659d-07,-1.2347536d-05 /
      data fpp(12, 8,20,1),fpp(12, 8,20,2),fpp(12, 8,20,3)/
     x 1.5494851d-02, 3.0116683d-05,-3.2387734d-05 /
      data fpp(12, 8,21,1),fpp(12, 8,21,2),fpp(12, 8,21,3)/
     x 1.5494851d-02, 3.0116683d-05,-3.2509031d-05 /
      data fpp(12, 8,22,1),fpp(12, 8,22,2),fpp(12, 8,22,3)/
     x 9.7655437d-03, 8.8125659d-07,-1.1862348d-05 /
      data fpp(12, 8,23,1),fpp(12, 8,23,2),fpp(12, 8,23,3)/
     x 4.4727608d-03, 5.0905793d-06,-2.2595758d-06 /
      data fpp(12, 9, 1,1),fpp(12, 9, 1,2),fpp(12, 9, 1,3)/
     x 1.5500315d-02,-7.3995357d-05,-6.2305990d-05 /
      data fpp(12, 9, 2,1),fpp(12, 9, 2,2),fpp(12, 9, 2,3)/
     x 2.5645804d-01,-2.5807150d-04,-3.6604520d-05 /
      data fpp(12, 9, 3,1),fpp(12, 9, 3,2),fpp(12, 9, 3,3)/
     x 4.7958159d-01,-3.6408373d-04, 1.5554072d-05 /
      data fpp(12, 9, 4,1),fpp(12, 9, 4,2),fpp(12, 9, 4,3)/
     x 4.7958159d-01,-3.6408373d-04, 2.0657045d-05 /
      data fpp(12, 9, 5,1),fpp(12, 9, 5,2),fpp(12, 9, 5,3)/
     x 2.5645804d-01,-2.5807150d-04,-5.7016414d-05 /
      data fpp(12, 9, 6,1),fpp(12, 9, 6,2),fpp(12, 9, 6,3)/
     x 1.5500315d-02,-7.3995357d-05, 1.4238611d-05 /
      data fpp(12, 9, 7,1),fpp(12, 9, 7,2),fpp(12, 9, 7,3)/
     x 1.8640361d-02,-4.6792855d-05,-1.0060029d-05 /
      data fpp(12, 9, 8,1),fpp(12, 9, 8,2),fpp(12, 9, 8,3)/
     x 1.4889695d-02,-4.7621077d-05,-6.5784950d-06 /
      data fpp(12, 9, 9,1),fpp(12, 9, 9,2),fpp(12, 9, 9,3)/
     x 9.9720651d-03,-5.0084914d-05,-4.8819912d-06 /
      data fpp(12, 9,10,1),fpp(12, 9,10,2),fpp(12, 9,10,3)/
     x 5.0134173d-03,-5.1839365d-05, 1.6024597d-06 /
      data fpp(12, 9,11,1),fpp(12, 9,11,2),fpp(12, 9,11,3)/
     x 1.0723759d-03,-5.1933505d-05, 7.2141526d-06 /
      data fpp(12, 9,12,1),fpp(12, 9,12,2),fpp(12, 9,12,3)/
     x-1.3910619d-03,-5.0058742d-05, 1.0886930d-05 /
      data fpp(12, 9,13,1),fpp(12, 9,13,2),fpp(12, 9,13,3)/
     x-2.3378452d-03,-4.6179156d-05, 1.2430127d-05 /
      data fpp(12, 9,14,1),fpp(12, 9,14,2),fpp(12, 9,14,3)/
     x-2.2523264d-03,-4.0183629d-05, 1.2400562d-05 /
      data fpp(12, 9,15,1),fpp(12, 9,15,2),fpp(12, 9,15,3)/
     x-1.0957080d-03,-3.1850994d-05, 1.1155627d-05 /
      data fpp(12, 9,16,1),fpp(12, 9,16,2),fpp(12, 9,16,3)/
     x 7.2650201d-04,-2.1349064d-05, 8.9529313d-06 /
      data fpp(12, 9,17,1),fpp(12, 9,17,2),fpp(12, 9,17,3)/
     x 3.3008164d-03,-8.3987284d-06, 5.5566479d-06 /
      data fpp(12, 9,18,1),fpp(12, 9,18,2),fpp(12, 9,18,3)/
     x 6.7062107d-03, 6.9013597d-06, 8.4769791d-09 /
      data fpp(12, 9,19,1),fpp(12, 9,19,2),fpp(12, 9,19,3)/
     x 1.1036558d-02, 2.8422512d-05,-7.2945558d-06 /
      data fpp(12, 9,20,1),fpp(12, 9,20,2),fpp(12, 9,20,3)/
     x 1.5568397d-02, 3.6970973d-05,-1.8578254d-05 /
      data fpp(12, 9,21,1),fpp(12, 9,21,2),fpp(12, 9,21,3)/
     x 1.5568397d-02, 3.6970973d-05,-1.8674961d-05 /
      data fpp(12, 9,22,1),fpp(12, 9,22,2),fpp(12, 9,22,3)/
     x 1.1036558d-02, 2.8422512d-05,-6.9077254d-06 /
      data fpp(12, 9,23,1),fpp(12, 9,23,2),fpp(12, 9,23,3)/
     x 6.7062107d-03, 6.9013597d-06,-1.4421373d-06 /
      data fpp(12,10, 1,1),fpp(12,10, 1,2),fpp(12,10, 1,3)/
     x-1.6453551d-01,-1.6771621d-04,-5.5821013d-05 /
      data fpp(12,10, 2,1),fpp(12,10, 2,2),fpp(12,10, 2,3)/
     x-1.7017308d-01,-2.5442956d-05,-1.4554473d-05 /
      data fpp(12,10, 3,1),fpp(12,10, 3,2),fpp(12,10, 3,3)/
     x-5.3303757d-02, 1.2334326d-04, 7.5080907d-05 /
      data fpp(12,10, 4,1),fpp(12,10, 4,2),fpp(12,10, 4,3)/
     x-5.3303757d-02, 1.2334326d-04, 7.2968515d-05 /
      data fpp(12,10, 5,1),fpp(12,10, 5,2),fpp(12,10, 5,3)/
     x-1.7017308d-01,-2.5442956d-05,-6.1049047d-06 /
      data fpp(12,10, 6,1),fpp(12,10, 6,2),fpp(12,10, 6,3)/
     x-1.6453551d-01,-1.6771621d-04,-8.7506896d-05 /
      data fpp(12,10, 7,1),fpp(12,10, 7,2),fpp(12,10, 7,3)/
     x 2.9208100d-04,-1.0524724d-04,-9.4115107d-06 /
      data fpp(12,10, 8,1),fpp(12,10, 8,2),fpp(12,10, 8,3)/
     x 1.8193754d-02,-6.1004272d-05,-1.7215061d-05 /
      data fpp(12,10, 9,1),fpp(12,10, 9,2),fpp(12,10, 9,3)/
     x 1.7817566d-02,-4.4065406d-05,-1.0618245d-05 /
      data fpp(12,10,10,1),fpp(12,10,10,2),fpp(12,10,10,3)/
     x 1.3452295d-02,-3.7616893d-05,-4.4699608d-06 /
      data fpp(12,10,11,1),fpp(12,10,11,2),fpp(12,10,11,3)/
     x 8.9156885d-03,-3.4659757d-05, 2.4940876d-06 /
      data fpp(12,10,12,1),fpp(12,10,12,2),fpp(12,10,12,3)/
     x 5.5952547d-03,-3.2227967d-05, 6.8296104d-06 /
      data fpp(12,10,13,1),fpp(12,10,13,2),fpp(12,10,13,3)/
     x 3.6891926d-03,-2.9235842d-05, 8.9654709d-06 /
      data fpp(12,10,14,1),fpp(12,10,14,2),fpp(12,10,14,3)/
     x 3.0062384d-03,-2.5341692d-05, 9.4305060d-06 /
      data fpp(12,10,15,1),fpp(12,10,15,2),fpp(12,10,15,3)/
     x 3.2596524d-03,-2.0437612d-05, 8.7825049d-06 /
      data fpp(12,10,16,1),fpp(12,10,16,2),fpp(12,10,16,3)/
     x 4.2155840d-03,-1.4493657d-05, 7.2794742d-06 /
      data fpp(12,10,17,1),fpp(12,10,17,2),fpp(12,10,17,3)/
     x 5.9237109d-03,-8.0051052d-06, 4.8075981d-06 /
      data fpp(12,10,18,1),fpp(12,10,18,2),fpp(12,10,18,3)/
     x 8.4096278d-03,-2.0600181d-06, 5.8613336d-07 /
      data fpp(12,10,19,1),fpp(12,10,19,2),fpp(12,10,19,3)/
     x 1.1859875d-02, 1.0786952d-06,-4.6201315d-06 /
      data fpp(12,10,20,1),fpp(12,10,20,2),fpp(12,10,20,3)/
     x 1.5945443d-02, 5.1374256d-06,-1.2909607d-05 /
      data fpp(12,10,21,1),fpp(12,10,21,2),fpp(12,10,21,3)/
     x 1.5945443d-02, 5.1374256d-06,-1.2973112d-05 /
      data fpp(12,10,22,1),fpp(12,10,22,2),fpp(12,10,22,3)/
     x 1.1859875d-02, 1.0786952d-06,-4.3661107d-06 /
      data fpp(12,10,23,1),fpp(12,10,23,2),fpp(12,10,23,3)/
     x 8.4096278d-03,-2.0600181d-06,-3.6644464d-07 /
      data fpp(12,11, 1,1),fpp(12,11, 1,2),fpp(12,11, 1,3)/
     x-1.0338848d-01, 6.6986183d-05, 1.1302392d-05 /
      data fpp(12,11, 2,1),fpp(12,11, 2,2),fpp(12,11, 2,3)/
     x-8.0513783d-02, 9.7169320d-05, 2.8986715d-05 /
      data fpp(12,11, 3,1),fpp(12,11, 3,2),fpp(12,11, 3,3)/
     x-4.4897427d-02, 1.0349270d-04, 6.8260747d-05 /
      data fpp(12,11, 4,1),fpp(12,11, 4,2),fpp(12,11, 4,3)/
     x-4.4897427d-02, 1.0349270d-04, 6.5847401d-05 /
      data fpp(12,11, 5,1),fpp(12,11, 5,2),fpp(12,11, 5,3)/
     x-8.0513783d-02, 9.7169320d-05, 3.8640097d-05 /
      data fpp(12,11, 6,1),fpp(12,11, 6,2),fpp(12,11, 6,3)/
     x-1.0338848d-01, 6.6986183d-05,-2.4897791d-05 /
      data fpp(12,11, 7,1),fpp(12,11, 7,2),fpp(12,11, 7,3)/
     x-5.9611160d-02,-2.0744177d-05,-5.5466935d-05 /
      data fpp(12,11, 8,1),fpp(12,11, 8,2),fpp(12,11, 8,3)/
     x-2.7564026d-03,-3.7983834d-05,-3.5834470d-05 /
      data fpp(12,11, 9,1),fpp(12,11, 9,2),fpp(12,11, 9,3)/
     x 1.6033607d-02,-3.1101463d-05,-2.4449187d-05 /
      data fpp(12,11,10,1),fpp(12,11,10,2),fpp(12,11,10,3)/
     x 1.7583502d-02,-2.5051063d-05,-1.2264783d-05 /
      data fpp(12,11,11,1),fpp(12,11,11,2),fpp(12,11,11,3)/
     x 1.4328092d-02,-2.1809468d-05,-2.3556815d-06 /
      data fpp(12,11,12,1),fpp(12,11,12,2),fpp(12,11,12,3)/
     x 1.0977014d-02,-1.9857389d-05, 3.5915089d-06 /
      data fpp(12,11,13,1),fpp(12,11,13,2),fpp(12,11,13,3)/
     x 8.6901056d-03,-1.7987477d-05, 6.5176459d-06 /
      data fpp(12,11,14,1),fpp(12,11,14,2),fpp(12,11,14,3)/
     x 7.5417026d-03,-1.5817602d-05, 7.5979077d-06 /
      data fpp(12,11,15,1),fpp(12,11,15,2),fpp(12,11,15,3)/
     x 7.2765124d-03,-1.3346556d-05, 7.5207235d-06 /
      data fpp(12,11,16,1),fpp(12,11,16,2),fpp(12,11,16,3)/
     x 7.7458661d-03,-1.0778310d-05, 6.4491985d-06 /
      data fpp(12,11,17,1),fpp(12,11,17,2),fpp(12,11,17,3)/
     x 8.8197961d-03,-8.3788507d-06, 4.0324825d-06 /
      data fpp(12,11,18,1),fpp(12,11,18,2),fpp(12,11,18,3)/
     x 1.0551927d-02,-6.2512874d-06, 3.2887158d-07 /
      data fpp(12,11,19,1),fpp(12,11,19,2),fpp(12,11,19,3)/
     x 1.3384030d-02,-4.2312929d-06,-3.6919688d-06 /
      data fpp(12,11,20,1),fpp(12,11,20,2),fpp(12,11,20,3)/
     x 1.7161439d-02,-3.6826751d-06,-1.0184996d-05 /
      data fpp(12,11,21,1),fpp(12,11,21,2),fpp(12,11,21,3)/
     x 1.7161439d-02,-3.6826751d-06,-1.0232026d-05 /
      data fpp(12,11,22,1),fpp(12,11,22,2),fpp(12,11,22,3)/
     x 1.3384030d-02,-4.2312929d-06,-3.5038496d-06 /
      data fpp(12,11,23,1),fpp(12,11,23,2),fpp(12,11,23,3)/
     x 1.0551927d-02,-6.2512874d-06,-3.7657518d-07 /
      data fpp(12,12, 1,1),fpp(12,12, 1,2),fpp(12,12, 1,3)/
     x-9.9152937d-02, 6.2761476d-05, 6.7640641d-05 /
      data fpp(12,12, 2,1),fpp(12,12, 2,2),fpp(12,12, 2,3)/
     x-5.9765462d-02, 9.9779674d-05, 5.7548719d-05 /
      data fpp(12,12, 3,1),fpp(12,12, 3,2),fpp(12,12, 3,3)/
     x-3.5444814d-04, 1.3130193d-04, 3.7720484d-05 /
      data fpp(12,12, 4,1),fpp(12,12, 4,2),fpp(12,12, 4,3)/
     x-3.5444814d-04, 1.3130193d-04, 3.4575188d-05 /
      data fpp(12,12, 5,1),fpp(12,12, 5,2),fpp(12,12, 5,3)/
     x-5.9765462d-02, 9.9779674d-05, 7.0129906d-05 /
      data fpp(12,12, 6,1),fpp(12,12, 6,2),fpp(12,12, 6,3)/
     x-9.9152937d-02, 6.2761476d-05, 2.0461190d-05 /
      data fpp(12,12, 7,1),fpp(12,12, 7,2),fpp(12,12, 7,3)/
     x-8.4259916d-02, 3.6789951d-05,-3.3666666d-05 /
      data fpp(12,12, 8,1),fpp(12,12, 8,2),fpp(12,12, 8,3)/
     x-3.3124789d-02, 6.1256072d-06,-4.9582526d-05 /
      data fpp(12,12, 9,1),fpp(12,12, 9,2),fpp(12,12, 9,3)/
     x 3.3343266d-03,-7.8387431d-06,-3.9737230d-05 /
      data fpp(12,12,10,1),fpp(12,12,10,2),fpp(12,12,10,3)/
     x 1.5688489d-02,-1.1344855d-05,-2.2462552d-05 /
      data fpp(12,12,11,1),fpp(12,12,11,2),fpp(12,12,11,3)/
     x 1.6423715d-02,-1.1860372d-05,-7.8725607d-06 /
      data fpp(12,12,12,1),fpp(12,12,12,2),fpp(12,12,12,3)/
     x 1.4250596d-02,-1.1600476d-05, 5.1679496d-07 /
      data fpp(12,12,13,1),fpp(12,12,13,2),fpp(12,12,13,3)/
     x 1.2206233d-02,-1.1164250d-05, 4.4913808d-06 /
      data fpp(12,12,14,1),fpp(12,12,14,2),fpp(12,12,14,3)/
     x 1.1027302d-02,-1.0597900d-05, 6.1476817d-06 /
      data fpp(12,12,15,1),fpp(12,12,15,2),fpp(12,12,15,3)/
     x 1.0718806d-02,-1.0074162d-05, 6.4798924d-06 /
      data fpp(12,12,16,1),fpp(12,12,16,2),fpp(12,12,16,3)/
     x 1.1134857d-02,-9.8031038d-06, 5.5287487d-06 /
      data fpp(12,12,17,1),fpp(12,12,17,2),fpp(12,12,17,3)/
     x 1.2003943d-02,-9.8034922d-06, 2.9951129d-06 /
      data fpp(12,12,18,1),fpp(12,12,18,2),fpp(12,12,18,3)/
     x 1.3324472d-02,-9.8228322d-06,-4.3920042d-07 /
      data fpp(12,12,19,1),fpp(12,12,19,2),fpp(12,12,19,3)/
     x 1.5710501d-02,-9.7975235d-06,-3.6503113d-06 /
      data fpp(12,12,20,1),fpp(12,12,20,2),fpp(12,12,20,3)/
     x 1.9129131d-02,-9.5587250d-06,-8.1555545d-06 /
      data fpp(12,12,21,1),fpp(12,12,21,2),fpp(12,12,21,3)/
     x 1.9129131d-02,-9.5587250d-06,-8.2081809d-06 /
      data fpp(12,12,22,1),fpp(12,12,22,2),fpp(12,12,22,3)/
     x 1.5710501d-02,-9.7975235d-06,-3.4398054d-06 /
      data fpp(12,12,23,1),fpp(12,12,23,2),fpp(12,12,23,3)/
     x 1.3324472d-02,-9.8228322d-06,-1.2285973d-06 /
      data fpp(12,13, 1,1),fpp(12,13, 1,2),fpp(12,13, 1,3)/
     x-8.8471918d-02, 5.6589913d-05, 1.0930495d-04 /
      data fpp(12,13, 2,1),fpp(12,13, 2,2),fpp(12,13, 2,3)/
     x-2.6174645d-02, 2.7205983d-05, 7.3599596d-05 /
      data fpp(12,13, 3,1),fpp(12,13, 3,2),fpp(12,13, 3,3)/
     x 6.9515311d-02,-2.9066415d-05,-8.3333436d-07 /
      data fpp(12,13, 4,1),fpp(12,13, 4,2),fpp(12,13, 4,3)/
     x 6.9515311d-02,-2.9066415d-05,-4.4707947d-06 /
      data fpp(12,13, 5,1),fpp(12,13, 5,2),fpp(12,13, 5,3)/
     x-2.6174645d-02, 2.7205983d-05, 8.8149437d-05 /
      data fpp(12,13, 6,1),fpp(12,13, 6,2),fpp(12,13, 6,3)/
     x-8.8471918d-02, 5.6589913d-05, 5.4743047d-05 /
      data fpp(12,13, 7,1),fpp(12,13, 7,2),fpp(12,13, 7,3)/
     x-9.5340500d-02, 4.9480372d-05,-3.9416264d-06 /
      data fpp(12,13, 8,1),fpp(12,13, 8,2),fpp(12,13, 8,3)/
     x-5.8436922d-02, 3.0797405d-05,-4.3806542d-05 /
      data fpp(12,13, 9,1),fpp(12,13, 9,2),fpp(12,13, 9,3)/
     x-1.4684944d-02, 1.3694435d-05,-4.8544206d-05 /
      data fpp(12,13,10,1),fpp(12,13,10,2),fpp(12,13,10,3)/
     x 9.3193721d-03, 2.8704832d-06,-3.0828633d-05 /
      data fpp(12,13,11,1),fpp(12,13,11,2),fpp(12,13,11,3)/
     x 1.5616360d-02,-2.6050460d-06,-1.2695261d-05 /
      data fpp(12,13,12,1),fpp(12,13,12,2),fpp(12,13,12,3)/
     x 1.5492925d-02,-5.0327079d-06,-2.3063230d-06 /
      data fpp(12,13,13,1),fpp(12,13,13,2),fpp(12,13,13,3)/
     x 1.4241674d-02,-6.1695218d-06, 2.6785531d-06 /
      data fpp(12,13,14,1),fpp(12,13,14,2),fpp(12,13,14,3)/
     x 1.3411403d-02,-6.9927990d-06, 4.7261108d-06 /
      data fpp(12,13,15,1),fpp(12,13,15,2),fpp(12,13,15,3)/
     x 1.3326115d-02,-7.8267970d-06, 5.2310037d-06 /
      data fpp(12,13,16,1),fpp(12,13,16,2),fpp(12,13,16,3)/
     x 1.3895780d-02,-8.8332751d-06, 4.3258745d-06 /
      data fpp(12,13,17,1),fpp(12,13,17,2),fpp(12,13,17,3)/
     x 1.4789376d-02,-9.9171807d-06, 1.9634985d-06 /
      data fpp(12,13,18,1),fpp(12,13,18,2),fpp(12,13,18,3)/
     x 1.6027022d-02,-1.0737384d-05,-1.0318685d-06 /
      data fpp(12,13,19,1),fpp(12,13,19,2),fpp(12,13,19,3)/
     x 1.7931631d-02,-1.0950613d-05,-3.6380246d-06 /
      data fpp(12,13,20,1),fpp(12,13,20,2),fpp(12,13,20,3)/
     x 2.0278982d-02,-1.0702425d-05,-6.3400331d-06 /
      data fpp(12,13,21,1),fpp(12,13,21,2),fpp(12,13,21,3)/
     x 2.0278982d-02,-1.0702425d-05,-6.4038884d-06 /
      data fpp(12,13,22,1),fpp(12,13,22,2),fpp(12,13,22,3)/
     x 1.7931631d-02,-1.0950613d-05,-3.3826033d-06 /
      data fpp(12,13,23,1),fpp(12,13,23,2),fpp(12,13,23,3)/
     x 1.6027022d-02,-1.0737384d-05,-1.9896983d-06 /
      data fpp(12,14, 1,1),fpp(12,14, 1,2),fpp(12,14, 1,3)/
     x-7.6787676d-02, 4.7814872d-05, 9.8088137d-05 /
      data fpp(12,14, 2,1),fpp(12,14, 2,2),fpp(12,14, 2,3)/
     x-1.2684200d-02, 1.0198395d-05, 6.4299225d-05 /
      data fpp(12,14, 3,1),fpp(12,14, 3,2),fpp(12,14, 3,3)/
     x 7.5511750d-02,-3.5922268d-05,-6.6550380d-06 /
      data fpp(12,14, 4,1),fpp(12,14, 4,2),fpp(12,14, 4,3)/
     x 7.5511750d-02,-3.5922268d-05,-9.1934986d-06 /
      data fpp(12,14, 5,1),fpp(12,14, 5,2),fpp(12,14, 5,3)/
     x-1.2684200d-02, 1.0198395d-05, 7.4453068d-05 /
      data fpp(12,14, 6,1),fpp(12,14, 6,2),fpp(12,14, 6,3)/
     x-7.6787676d-02, 4.7814872d-05, 6.0011228d-05 /
      data fpp(12,14, 7,1),fpp(12,14, 7,2),fpp(12,14, 7,3)/
     x-9.7032286d-02, 5.9720562d-05, 1.2916020d-05 /
      data fpp(12,14, 8,1),fpp(12,14, 8,2),fpp(12,14, 8,3)/
     x-7.7280618d-02, 4.7582773d-05,-3.2577309d-05 /
      data fpp(12,14, 9,1),fpp(12,14, 9,2),fpp(12,14, 9,3)/
     x-3.4823849d-02, 2.8787003d-05,-4.9934785d-05 /
      data fpp(12,14,10,1),fpp(12,14,10,2),fpp(12,14,10,3)/
     x 1.6296121d-04, 1.4418922d-05,-3.4311551d-05 /
      data fpp(12,14,11,1),fpp(12,14,11,2),fpp(12,14,11,3)/
     x 1.2938502d-02, 5.4325556d-06,-1.4701012d-05 /
      data fpp(12,14,12,1),fpp(12,14,12,2),fpp(12,14,12,3)/
     x 1.5292547d-02, 7.2930738d-07,-4.0304012d-06 /
      data fpp(12,14,13,1),fpp(12,14,13,2),fpp(12,14,13,3)/
     x 1.5117895d-02,-1.8196626d-06, 1.1466168d-06 /
      data fpp(12,14,14,1),fpp(12,14,14,2),fpp(12,14,14,3)/
     x 1.4749917d-02,-3.5209043d-06, 3.3139341d-06 /
      data fpp(12,14,15,1),fpp(12,14,15,2),fpp(12,14,15,3)/
     x 1.4933984d-02,-4.9986502d-06, 3.8016467d-06 /
      data fpp(12,14,16,1),fpp(12,14,16,2),fpp(12,14,16,3)/
     x 1.5513480d-02,-6.3557960d-06, 3.0134792d-06 /
      data fpp(12,14,17,1),fpp(12,14,17,2),fpp(12,14,17,3)/
     x 1.6384048d-02,-7.5217850d-06, 1.1604364d-06 /
      data fpp(12,14,18,1),fpp(12,14,18,2),fpp(12,14,18,3)/
     x 1.7453215d-02,-8.4156321d-06,-1.1212247d-06 /
      data fpp(12,14,19,1),fpp(12,14,19,2),fpp(12,14,19,3)/
     x 1.8646808d-02,-9.0220237d-06,-3.1075376d-06 /
      data fpp(12,14,20,1),fpp(12,14,20,2),fpp(12,14,20,3)/
     x 1.9824699d-02,-9.2995761d-06,-4.7126250d-06 /
      data fpp(12,14,21,1),fpp(12,14,21,2),fpp(12,14,21,3)/
     x 1.9824699d-02,-9.2995761d-06,-4.7713563d-06 /
      data fpp(12,14,22,1),fpp(12,14,22,2),fpp(12,14,22,3)/
     x 1.8646808d-02,-9.0220237d-06,-2.8726125d-06 /
      data fpp(12,14,23,1),fpp(12,14,23,2),fpp(12,14,23,3)/
     x 1.7453215d-02,-8.4156321d-06,-2.0021938d-06 /
      data fpp(12,15, 1,1),fpp(12,15, 1,2),fpp(12,15, 1,3)/
     x-7.2884363d-02, 7.6930601d-05, 5.5233904d-05 /
      data fpp(12,15, 2,1),fpp(12,15, 2,2),fpp(12,15, 2,3)/
     x-3.2342216d-02, 9.7450438d-05, 4.2444193d-05 /
      data fpp(12,15, 3,1),fpp(12,15, 3,2),fpp(12,15, 3,3)/
     x 9.0113719d-03, 1.2512149d-04, 1.5625326d-05 /
      data fpp(12,15, 4,1),fpp(12,15, 4,2),fpp(12,15, 4,3)/
     x 9.0113719d-03, 1.2512149d-04, 1.4596926d-05 /
      data fpp(12,15, 5,1),fpp(12,15, 5,2),fpp(12,15, 5,3)/
     x-3.2342216d-02, 9.7450438d-05, 4.6557790d-05 /
      data fpp(12,15, 6,1),fpp(12,15, 6,2),fpp(12,15, 6,3)/
     x-7.2884363d-02, 7.6930601d-05, 3.9807913d-05 /
      data fpp(12,15, 7,1),fpp(12,15, 7,2),fpp(12,15, 7,3)/
     x-9.5452820d-02, 6.0831380d-05, 1.0942558d-05 /
      data fpp(12,15, 8,1),fpp(12,15, 8,2),fpp(12,15, 8,3)/
     x-8.6418101d-02, 4.9387503d-05,-2.3644145d-05 /
      data fpp(12,15, 9,1),fpp(12,15, 9,2),fpp(12,15, 9,3)/
     x-5.7588783d-02, 3.8419555d-05,-4.7885979d-05 /
      data fpp(12,15,10,1),fpp(12,15,10,2),fpp(12,15,10,3)/
     x-9.9165683d-03, 2.1299827d-05,-3.1417940d-05 /
      data fpp(12,15,11,1),fpp(12,15,11,2),fpp(12,15,11,3)/
     x 9.6819101d-03, 1.0574823d-05,-1.2382261d-05 /
      data fpp(12,15,12,1),fpp(12,15,12,2),fpp(12,15,12,3)/
     x 1.4327378d-02, 5.1634784d-06,-3.9350160d-06 /
      data fpp(12,15,13,1),fpp(12,15,13,2),fpp(12,15,13,3)/
     x 1.5148578d-02, 2.1561720d-06, 3.2432496d-07 /
      data fpp(12,15,14,1),fpp(12,15,14,2),fpp(12,15,14,3)/
     x 1.5344848d-02, 2.6841636d-07, 2.0677162d-06 /
      data fpp(12,15,15,1),fpp(12,15,15,2),fpp(12,15,15,3)/
     x 1.5571189d-02,-1.0386020d-06, 2.4628104d-06 /
      data fpp(12,15,16,1),fpp(12,15,16,2),fpp(12,15,16,3)/
     x 1.6036527d-02,-1.9535408d-06, 1.8750423d-06 /
      data fpp(12,15,17,1),fpp(12,15,17,2),fpp(12,15,17,3)/
     x 1.6715226d-02,-2.4816791d-06, 6.4502052d-07 /
      data fpp(12,15,18,1),fpp(12,15,18,2),fpp(12,15,18,3)/
     x 1.7393953d-02,-2.7000875d-06,-8.7312437d-07 /
      data fpp(12,15,19,1),fpp(12,15,19,2),fpp(12,15,19,3)/
     x 1.8029307d-02,-2.6412920d-06,-2.1805231d-06 /
      data fpp(12,15,20,1),fpp(12,15,20,2),fpp(12,15,20,3)/
     x 1.8562293d-02,-2.4092711d-06,-3.0587834d-06 /
      data fpp(12,15,21,1),fpp(12,15,21,2),fpp(12,15,21,3)/
     x 1.8562293d-02,-2.4092711d-06,-3.1013883d-06 /
      data fpp(12,15,22,1),fpp(12,15,22,2),fpp(12,15,22,3)/
     x 1.8029307d-02,-2.6412920d-06,-2.0101033d-06 /
      data fpp(12,15,23,1),fpp(12,15,23,2),fpp(12,15,23,3)/
     x 1.7393953d-02,-2.7000875d-06,-1.5121983d-06 /
      data fpp(12,16, 1,1),fpp(12,16, 1,2),fpp(12,16, 1,3)/
     x-7.5109678d-02, 1.0488473d-04, 2.6714862d-05 /
      data fpp(12,16, 2,1),fpp(12,16, 2,2),fpp(12,16, 2,3)/
     x-5.1843571d-02, 1.1481185d-04, 2.6756775d-05 /
      data fpp(12,16, 3,1),fpp(12,16, 3,2),fpp(12,16, 3,3)/
     x-3.9867586d-02, 1.3275432d-04, 2.7016036d-05 /
      data fpp(12,16, 4,1),fpp(12,16, 4,2),fpp(12,16, 4,3)/
     x-3.9867586d-02, 1.3275432d-04, 2.6719504d-05 /
      data fpp(12,16, 5,1),fpp(12,16, 5,2),fpp(12,16, 5,3)/
     x-5.1843571d-02, 1.1481185d-04, 2.7942902d-05 /
      data fpp(12,16, 6,1),fpp(12,16, 6,2),fpp(12,16, 6,3)/
     x-7.5109678d-02, 1.0488473d-04, 2.2266888d-05 /
      data fpp(12,16, 7,1),fpp(12,16, 7,2),fpp(12,16, 7,3)/
     x-8.9566560d-02, 1.1020392d-04,-3.7424523d-06 /
      data fpp(12,16, 8,1),fpp(12,16, 8,2),fpp(12,16, 8,3)/
     x-5.5202492d-02, 7.5405216d-05,-1.2067078d-05 /
      data fpp(12,16, 9,1),fpp(12,16, 9,2),fpp(12,16, 9,3)/
     x-1.7125496d+00, 3.8004779d-05,-5.1057234d-05 /
      data fpp(12,16,10,1),fpp(12,16,10,2),fpp(12,16,10,3)/
     x-1.3886123d-02, 1.5191768d-05,-1.5879985d-05 /
      data fpp(12,16,11,1),fpp(12,16,11,2),fpp(12,16,11,3)/
     x 7.7802500d-03, 1.0018150d-05,-6.8208274d-06 /
      data fpp(12,16,12,1),fpp(12,16,12,2),fpp(12,16,12,3)/
     x 1.3365492d-02, 7.0687790d-06,-1.6927057d-06 /
      data fpp(12,16,13,1),fpp(12,16,13,2),fpp(12,16,13,3)/
     x 1.4863010d-02, 5.0449745d-06, 3.6765029d-07 /
      data fpp(12,16,14,1),fpp(12,16,14,2),fpp(12,16,14,3)/
     x 1.5375782d-02, 3.8092389d-06, 1.3261046d-06 /
      data fpp(12,16,15,1),fpp(12,16,15,2),fpp(12,16,15,3)/
     x 1.5661289d-02, 3.2610583d-06, 1.4739314d-06 /
      data fpp(12,16,16,1),fpp(12,16,16,2),fpp(12,16,16,3)/
     x 1.6027708d-02, 3.3099594d-06, 1.1181696d-06 /
      data fpp(12,16,17,1),fpp(12,16,17,2),fpp(12,16,17,3)/
     x 1.6411925d-02, 3.7865016d-06, 4.1938996d-07 /
      data fpp(12,16,18,1),fpp(12,16,18,2),fpp(12,16,18,3)/
     x 1.6763339d-02, 4.5219822d-06,-3.9572950d-07 /
      data fpp(12,16,19,1),fpp(12,16,19,2),fpp(12,16,19,3)/
     x 1.7089653d-02, 5.2471917d-06,-1.0744720d-06 /
      data fpp(12,16,20,1),fpp(12,16,20,2),fpp(12,16,20,3)/
     x 1.7299408d-02, 5.7306603d-06,-1.5703826d-06 /
      data fpp(12,16,21,1),fpp(12,16,21,2),fpp(12,16,21,3)/
     x 1.7299408d-02, 5.7306603d-06,-1.5916161d-06 /
      data fpp(12,16,22,1),fpp(12,16,22,2),fpp(12,16,22,3)/
     x 1.7089653d-02, 5.2471917d-06,-9.8953826d-07 /
      data fpp(12,16,23,1),fpp(12,16,23,2),fpp(12,16,23,3)/
     x 1.6763339d-02, 4.5219822d-06,-7.1423087d-07 /
      data fpp(12,17, 1,1),fpp(12,17, 1,2),fpp(12,17, 1,3)/
     x-3.2806744d-02,-2.3903503d-05, 1.4352881d-05 /
      data fpp(12,17, 2,1),fpp(12,17, 2,2),fpp(12,17, 2,3)/
     x-3.9043580d-02, 4.0260155d-05, 1.6218239d-05 /
      data fpp(12,17, 3,1),fpp(12,17, 3,2),fpp(12,17, 3,3)/
     x-4.9804334d-02, 8.3463221d-05, 1.9906165d-05 /
      data fpp(12,17, 4,1),fpp(12,17, 4,2),fpp(12,17, 4,3)/
     x-4.9804334d-02, 8.3463221d-05, 2.0447386d-05 /
      data fpp(12,17, 5,1),fpp(12,17, 5,2),fpp(12,17, 5,3)/
     x-3.9043580d-02, 4.0260155d-05, 1.4053355d-05 /
      data fpp(12,17, 6,1),fpp(12,17, 6,2),fpp(12,17, 6,3)/
     x-3.2806744d-02,-2.3903503d-05, 2.2471194d-05 /
      data fpp(12,17, 7,1),fpp(12,17, 7,2),fpp(12,17, 7,3)/
     x 1.0483360d-02,-1.0016306d-04,-4.0824133d-05 /
      data fpp(12,17, 8,1),fpp(12,17, 8,2),fpp(12,17, 8,3)/
     x 3.0318610d-01,-8.9438366d-05, 2.5193366d-06 /
      data fpp(12,17, 9,1),fpp(12,17, 9,2),fpp(12,17, 9,3)/
     x 1.4132135d-02,-6.4042671d-05,-3.9129214d-05 /
      data fpp(12,17,10,1),fpp(12,17,10,2),fpp(12,17,10,3)/
     x 1.7229145d-03,-1.8898899d-05, 8.1975175d-06 /
      data fpp(12,17,11,1),fpp(12,17,11,2),fpp(12,17,11,3)/
     x 1.0042672d-02,-2.6954251d-06,-2.5048566d-06 /
      data fpp(12,17,12,1),fpp(12,17,12,2),fpp(12,17,12,3)/
     x 1.3497392d-02, 3.6414057d-06, 1.3359089d-06 /
      data fpp(12,17,13,1),fpp(12,17,13,2),fpp(12,17,13,3)/
     x 1.4749422d-02, 6.1639299d-06, 8.0322086d-07 /
      data fpp(12,17,14,1),fpp(12,17,14,2),fpp(12,17,14,3)/
     x 1.5249699d-02, 7.3066280d-06, 1.1212076d-06 /
      data fpp(12,17,15,1),fpp(12,17,15,2),fpp(12,17,15,3)/
     x 1.5525920d-02, 8.1483689d-06, 9.7594860d-07 /
      data fpp(12,17,16,1),fpp(12,17,16,2),fpp(12,17,16,3)/
     x 1.5751859d-02, 9.1017032d-06, 7.5299796d-07 /
      data fpp(12,17,17,1),fpp(12,17,17,2),fpp(12,17,17,3)/
     x 1.5950563d-02, 1.0261673d-05, 4.4005954d-07 /
      data fpp(12,17,18,1),fpp(12,17,18,2),fpp(12,17,18,3)/
     x 1.6107412d-02, 1.1462159d-05, 9.0763871d-08 /
      data fpp(12,17,19,1),fpp(12,17,19,2),fpp(12,17,19,3)/
     x 1.6399564d-02, 1.2504525d-05,-1.7311503d-07 /
      data fpp(12,17,20,1),fpp(12,17,20,2),fpp(12,17,20,3)/
     x 1.6370984d-02, 1.3200630d-05,-4.1230377d-07 /
      data fpp(12,17,21,1),fpp(12,17,21,2),fpp(12,17,21,3)/
     x 1.6370984d-02, 1.3200630d-05,-4.1953118d-07 /
      data fpp(12,17,22,1),fpp(12,17,22,2),fpp(12,17,22,3)/
     x 1.6399564d-02, 1.2504525d-05,-1.4420538d-07 /
      data fpp(12,17,23,1),fpp(12,17,23,2),fpp(12,17,23,3)/
     x 1.6107412d-02, 1.1462159d-05,-1.7647312d-08 /
      data fpp(12,18, 1,1),fpp(12,18, 1,2),fpp(12,18, 1,3)/
     x 2.6128512d-01,-1.9546271d-04,-1.2582327d-06 /
      data fpp(12,18, 2,1),fpp(12,18, 2,2),fpp(12,18, 2,3)/
     x-1.6034418d-01,-2.6624647d-04,-2.1150345d-06 /
      data fpp(12,18, 3,1),fpp(12,18, 3,2),fpp(12,18, 3,3)/
     x-6.0003676d-01,-3.1239521d-04,-3.9676292d-06 /
      data fpp(12,18, 4,1),fpp(12,18, 4,2),fpp(12,18, 4,3)/
     x-6.0003676d-01,-3.1239521d-04,-3.9385953d-06 /
      data fpp(12,18, 5,1),fpp(12,18, 5,2),fpp(12,18, 5,3)/
     x-1.6034418d-01,-2.6624647d-04,-2.2311702d-06 /
      data fpp(12,18, 6,1),fpp(12,18, 6,2),fpp(12,18, 6,3)/
     x 2.6128512d-01,-1.9546271d-04,-8.2272410d-07 /
      data fpp(12,18, 7,1),fpp(12,18, 7,2),fpp(12,18, 7,3)/
     x 5.7677114d-03,-1.0980570d-04, 2.1806658d-07 /
      data fpp(12,18, 8,1),fpp(12,18, 8,2),fpp(12,18, 8,3)/
     x-1.8642800d-03,-5.9333753d-05, 7.4245779d-07 /
      data fpp(12,18, 9,1),fpp(12,18, 9,2),fpp(12,18, 9,3)/
     x 1.7483389d-02,-2.4132094d-05, 9.4010226d-07 /
      data fpp(12,18,10,1),fpp(12,18,10,2),fpp(12,18,10,3)/
     x 1.3675941d-02,-1.7608172d-05, 9.7513319d-07 /
      data fpp(12,18,11,1),fpp(12,18,11,2),fpp(12,18,11,3)/
     x 1.4440452d-02,-1.0882450d-05, 9.4936500d-07 /
      data fpp(12,18,12,1),fpp(12,18,12,2),fpp(12,18,12,3)/
     x 1.5215814d-02,-5.1284016d-06, 8.9740680d-07 /
      data fpp(12,18,13,1),fpp(12,18,13,2),fpp(12,18,13,3)/
     x 1.5333798d-02,-1.8669427d-07, 8.2500780d-07 /
      data fpp(12,18,14,1),fpp(12,18,14,2),fpp(12,18,14,3)/
     x 1.5531974d-02, 4.1942491d-06, 7.4656201d-07 /
      data fpp(12,18,15,1),fpp(12,18,15,2),fpp(12,18,15,3)/
     x 1.5636783d-02, 8.1734660d-06, 6.5274417d-07 /
      data fpp(12,18,16,1),fpp(12,18,16,2),fpp(12,18,16,3)/
     x 1.5789639d-02, 1.1811228d-05, 5.6046132d-07 /
      data fpp(12,18,17,1),fpp(12,18,17,2),fpp(12,18,17,3)/
     x 1.5858891d-02, 1.5052808d-05, 4.5341056d-07 /
      data fpp(12,18,18,1),fpp(12,18,18,2),fpp(12,18,18,3)/
     x 1.5904654d-02, 1.7801383d-05, 3.6189645d-07 /
      data fpp(12,18,19,1),fpp(12,18,19,2),fpp(12,18,19,3)/
     x 1.5984187d-02, 1.9902707d-05, 3.0700366d-07 /
      data fpp(12,18,20,1),fpp(12,18,20,2),fpp(12,18,20,3)/
     x 1.5795865d-02, 2.1212820d-05, 2.2808893d-07 /
      data fpp(12,18,21,1),fpp(12,18,21,2),fpp(12,18,21,3)/
     x 1.5795865d-02, 2.1212820d-05, 2.2723137d-07 /
      data fpp(12,18,22,1),fpp(12,18,22,2),fpp(12,18,22,3)/
     x 1.5984187d-02, 1.9902707d-05, 3.1043389d-07 /
      data fpp(12,18,23,1),fpp(12,18,23,2),fpp(12,18,23,3)/
     x 1.5904654d-02, 1.7801383d-05, 3.4903305d-07 /
      data fpp(12,19, 1,1),fpp(12,19, 1,2),fpp(12,19, 1,3)/
     x 1.6235263d-02,-3.5480164d-04,-3.3707875d-20 /
      data fpp(12,19, 2,1),fpp(12,19, 2,2),fpp(12,19, 2,3)/
     x 1.6235263d-02,-5.0648026d-04, 1.3127210d-20 /
      data fpp(12,19, 3,1),fpp(12,19, 3,2),fpp(12,19, 3,3)/
     x 1.6235263d-02,-6.0923440d-04,-2.4948272d-20 /
      data fpp(12,19, 4,1),fpp(12,19, 4,2),fpp(12,19, 4,3)/
     x 1.6235263d-02,-6.0923440d-04, 1.5392970d-20 /
      data fpp(12,19, 5,1),fpp(12,19, 5,2),fpp(12,19, 5,3)/
     x 1.6235263d-02,-5.0648026d-04, 1.5249737d-20 /
      data fpp(12,19, 6,1),fpp(12,19, 6,2),fpp(12,19, 6,3)/
     x 1.6235263d-02,-3.5480164d-04, 6.6674349d-21 /
      data fpp(12,19, 7,1),fpp(12,19, 7,2),fpp(12,19, 7,3)/
     x 1.6235263d-02,-1.7679815d-04,-4.0932407d-20 /
      data fpp(12,19, 8,1),fpp(12,19, 8,2),fpp(12,19, 8,3)/
     x 1.6235263d-02,-8.4928624d-05,-1.8099342d-21 /
      data fpp(12,19, 9,1),fpp(12,19, 9,2),fpp(12,19, 9,3)/
     x 1.6235263d-02,-2.4780953d-05,-2.1602019d-20 /
      data fpp(12,19,10,1),fpp(12,19,10,2),fpp(12,19,10,3)/
     x 1.6235263d-02,-2.6426414d-05, 1.8093428d-20 /
      data fpp(12,19,11,1),fpp(12,19,11,2),fpp(12,19,11,3)/
     x 1.6235263d-02,-2.0362775d-05,-5.4333127d-21 /
      data fpp(12,19,12,1),fpp(12,19,12,2),fpp(12,19,12,3)/
     x 1.6235263d-02,-1.2371799d-05, 2.1770850d-20 /
      data fpp(12,19,13,1),fpp(12,19,13,2),fpp(12,19,13,3)/
     x 1.6235263d-02,-4.4031529d-06, 2.8990083d-20 /
      data fpp(12,19,14,1),fpp(12,19,14,2),fpp(12,19,14,3)/
     x 1.6235263d-02, 2.9703754d-06,-5.1422591d-21 /
      data fpp(12,19,15,1),fpp(12,19,15,2),fpp(12,19,15,3)/
     x 1.6235263d-02, 9.5877670d-06,-2.1787106d-20 /
      data fpp(12,19,16,1),fpp(12,19,16,2),fpp(12,19,16,3)/
     x 1.6235263d-02, 1.5401386d-05,-1.7124443d-20 /
      data fpp(12,19,17,1),fpp(12,19,17,2),fpp(12,19,17,3)/
     x 1.6235263d-02, 2.0325096d-05, 1.7549434d-20 /
      data fpp(12,19,18,1),fpp(12,19,18,2),fpp(12,19,18,3)/
     x 1.6235263d-02, 2.4312308d-05,-6.1999515d-21 /
      data fpp(12,19,19,1),fpp(12,19,19,2),fpp(12,19,19,3)/
     x 1.6235263d-02, 2.7260646d-05,-3.1958435d-20 /
      data fpp(12,19,20,1),fpp(12,19,20,2),fpp(12,19,20,3)/
     x 1.6235263d-02, 2.9070090d-05, 1.5399713d-20 /
      data fpp(12,19,21,1),fpp(12,19,21,2),fpp(12,19,21,3)/
     x 1.6235263d-02, 2.9070090d-05,-1.3403872d-20 /
      data fpp(12,19,22,1),fpp(12,19,22,2),fpp(12,19,22,3)/
     x 1.6235263d-02, 2.7260646d-05, 4.2019561d-20 /
      data fpp(12,19,23,1),fpp(12,19,23,2),fpp(12,19,23,3)/
     x 1.6235263d-02, 2.4312308d-05, 4.4094572d-20 /
      data fpp(13, 1, 1,1),fpp(13, 1, 1,2),fpp(13, 1, 1,3)/
     x 1.0608177d+00, 1.6964830d-03, 2.9955744d-19 /
      data fpp(13, 1, 2,1),fpp(13, 1, 2,2),fpp(13, 1, 2,3)/
     x 1.0608177d+00, 3.2686852d-03,-1.5565264d-19 /
      data fpp(13, 1, 3,1),fpp(13, 1, 3,2),fpp(13, 1, 3,3)/
     x 1.0608177d+00, 3.3659624d-03,-7.4340958d-20 /
      data fpp(13, 1, 4,1),fpp(13, 1, 4,2),fpp(13, 1, 4,3)/
     x 1.0608177d+00, 3.3659624d-03, 1.1990603d-19 /
      data fpp(13, 1, 5,1),fpp(13, 1, 5,2),fpp(13, 1, 5,3)/
     x 1.0608177d+00, 3.2686852d-03, 1.3173396d-19 /
      data fpp(13, 1, 6,1),fpp(13, 1, 6,2),fpp(13, 1, 6,3)/
     x 1.0608177d+00, 1.6964830d-03,-2.0927479d-19 /
      data fpp(13, 1, 7,1),fpp(13, 1, 7,2),fpp(13, 1, 7,3)/
     x 1.0608177d+00, 2.1867769d-04,-3.2590258d-19 /
      data fpp(13, 1, 8,1),fpp(13, 1, 8,2),fpp(13, 1, 8,3)/
     x 1.0608177d+00,-2.4726973d-04,-1.2003450d-20 /
      data fpp(13, 1, 9,1),fpp(13, 1, 9,2),fpp(13, 1, 9,3)/
     x 1.0608177d+00,-4.6187488d-04, 2.2864766d-20 /
      data fpp(13, 1,10,1),fpp(13, 1,10,2),fpp(13, 1,10,3)/
     x 1.0608177d+00,-5.4662346d-04, 2.2948867d-19 /
      data fpp(13, 1,11,1),fpp(13, 1,11,2),fpp(13, 1,11,3)/
     x 1.0608177d+00,-5.8579843d-04,-9.1738490d-20 /
      data fpp(13, 1,12,1),fpp(13, 1,12,2),fpp(13, 1,12,3)/
     x 1.0608177d+00,-6.0006086d-04, 1.2265805d-19 /
      data fpp(13, 1,13,1),fpp(13, 1,13,2),fpp(13, 1,13,3)/
     x 1.0608177d+00,-5.9272354d-04, 2.1221522d-19 /
      data fpp(13, 1,14,1),fpp(13, 1,14,2),fpp(13, 1,14,3)/
     x 1.0608177d+00,-5.5927393d-04,-9.5961344d-21 /
      data fpp(13, 1,15,1),fpp(13, 1,15,2),fpp(13, 1,15,3)/
     x 1.0608177d+00,-4.7822450d-04,-1.2269412d-19 /
      data fpp(13, 1,16,1),fpp(13, 1,16,2),fpp(13, 1,16,3)/
     x 1.0608177d+00,-2.6460396d-04,-1.8650891d-19 /
      data fpp(13, 1,17,1),fpp(13, 1,17,2),fpp(13, 1,17,3)/
     x 1.0608177d+00, 1.9899288d-04, 1.4841001d-19 /
      data fpp(13, 1,18,1),fpp(13, 1,18,2),fpp(13, 1,18,3)/
     x 1.0608177d+00, 1.6712162d-03,-1.0533104d-19 /
      data fpp(13, 1,19,1),fpp(13, 1,19,2),fpp(13, 1,19,3)/
     x 1.0608177d+00, 3.1662320d-03,-2.2194875d-19 /
      data fpp(13, 1,20,1),fpp(13, 1,20,2),fpp(13, 1,20,3)/
     x 1.0608177d+00, 3.2534663d-03, 7.2272334d-20 /
      data fpp(13, 1,21,1),fpp(13, 1,21,2),fpp(13, 1,21,3)/
     x 1.0608177d+00, 3.2534663d-03,-1.6908467d-19 /
      data fpp(13, 1,22,1),fpp(13, 1,22,2),fpp(13, 1,22,3)/
     x 1.0608177d+00, 3.1662320d-03, 2.3682468d-19 /
      data fpp(13, 1,23,1),fpp(13, 1,23,2),fpp(13, 1,23,3)/
     x 1.0608177d+00, 1.6712162d-03, 4.3612187d-19 /
      data fpp(13, 2, 1,1),fpp(13, 2, 1,2),fpp(13, 2, 1,3)/
     x 4.5771756d-01, 6.9311305d-04,-3.3435356d-06 /
      data fpp(13, 2, 2,1),fpp(13, 2, 2,2),fpp(13, 2, 2,3)/
     x 4.7952670d-01, 1.2061166d-03,-2.3461929d-05 /
      data fpp(13, 2, 3,1),fpp(13, 2, 3,2),fpp(13, 2, 3,3)/
     x 5.3965306d-01, 1.2553763d-03,-6.6740749d-05 /
      data fpp(13, 2, 4,1),fpp(13, 2, 4,2),fpp(13, 2, 4,3)/
     x 5.3965306d-01, 1.2553763d-03,-6.6446788d-05 /
      data fpp(13, 2, 5,1),fpp(13, 2, 5,2),fpp(13, 2, 5,3)/
     x 4.7952670d-01, 1.2061166d-03,-2.4637775d-05 /
      data fpp(13, 2, 6,1),fpp(13, 2, 6,2),fpp(13, 2, 6,3)/
     x 4.5771756d-01, 6.9311305d-04, 1.0658893d-06 /
      data fpp(13, 2, 7,1),fpp(13, 2, 7,2),fpp(13, 2, 7,3)/
     x 4.7023866d-01, 1.2308362d-04, 1.6978218d-05 /
      data fpp(13, 2, 8,1),fpp(13, 2, 8,2),fpp(13, 2, 8,3)/
     x 4.5960607d-01,-4.3331547d-05, 2.2839237d-05 /
      data fpp(13, 2, 9,1),fpp(13, 2, 9,2),fpp(13, 2, 9,3)/
     x 4.8772818d-01,-1.1474623d-04, 2.3436832d-05 /
      data fpp(13, 2,10,1),fpp(13, 2,10,2),fpp(13, 2,10,3)/
     x 4.6251905d-01,-1.3732907d-04, 2.4401434d-05 /
      data fpp(13, 2,11,1),fpp(13, 2,11,2),fpp(13, 2,11,3)/
     x 5.0117728d-01,-1.4627213d-04, 2.4763433d-05 /
      data fpp(13, 2,12,1),fpp(13, 2,12,2),fpp(13, 2,12,3)/
     x 4.7426418d-01,-1.5052328d-04, 2.5038833d-05 /
      data fpp(13, 2,13,1),fpp(13, 2,13,2),fpp(13, 2,13,3)/
     x 4.4000032d-01,-1.5158591d-04, 2.4853234d-05 /
      data fpp(13, 2,14,1),fpp(13, 2,14,2),fpp(13, 2,14,3)/
     x 4.6373968d-01,-1.4739415d-04, 2.4414231d-05 /
      data fpp(13, 2,15,1),fpp(13, 2,15,2),fpp(13, 2,15,3)/
     x 4.7056620d-01,-1.2858801d-04, 2.3895843d-05 /
      data fpp(13, 2,16,1),fpp(13, 2,16,2),fpp(13, 2,16,3)/
     x 4.7772098d-01,-5.9571085d-05, 2.2256396d-05 /
      data fpp(13, 2,17,1),fpp(13, 2,17,2),fpp(13, 2,17,3)/
     x 4.7029093d-01, 1.0464924d-04, 1.6876574d-05 /
      data fpp(13, 2,18,1),fpp(13, 2,18,2),fpp(13, 2,18,3)/
     x 4.5958362d-01, 6.7294160d-04, 7.5930763d-07 /
      data fpp(13, 2,19,1),fpp(13, 2,19,2),fpp(13, 2,19,3)/
     x 4.8978651d-01, 1.1611250d-03,-2.6093805d-05 /
      data fpp(13, 2,20,1),fpp(13, 2,20,2),fpp(13, 2,20,3)/
     x 5.5388277d-01, 1.2142294d-03,-6.7306089d-05 /
      data fpp(13, 2,21,1),fpp(13, 2,21,2),fpp(13, 2,21,3)/
     x 5.5388277d-01, 1.2142294d-03,-6.7667831d-05 /
      data fpp(13, 2,22,1),fpp(13, 2,22,2),fpp(13, 2,22,3)/
     x 4.8978651d-01, 1.1611250d-03,-2.4646834d-05 /
      data fpp(13, 2,23,1),fpp(13, 2,23,2),fpp(13, 2,23,3)/
     x 4.5958362d-01, 6.7294160d-04,-4.6668331d-06 /
      data fpp(13, 3, 1,1),fpp(13, 3, 1,2),fpp(13, 3, 1,3)/
     x 2.3990292d-01,-1.4423132d-03,-9.6846496d-04 /
      data fpp(13, 3, 2,1),fpp(13, 3, 2,2),fpp(13, 3, 2,3)/
     x 1.1820336d+00,-1.5259055d-03,-6.7309309d-04 /
      data fpp(13, 3, 3,1),fpp(13, 3, 3,2),fpp(13, 3, 3,3)/
     x 2.9557188d-01,-1.7048654d-03,-9.2294693d-05 /
      data fpp(13, 3, 4,1),fpp(13, 3, 4,2),fpp(13, 3, 4,3)/
     x 2.9557188d-01,-1.7048654d-03,-1.0473766d-06 /
      data fpp(13, 3, 5,1),fpp(13, 3, 5,2),fpp(13, 3, 5,3)/
     x 1.1820336d+00,-1.5259055d-03,-1.0380824d-03 /
      data fpp(13, 3, 6,1),fpp(13, 3, 6,2),fpp(13, 3, 6,3)/
     x 2.3990292d-01,-1.4423132d-03, 4.0024479d-04 /
      data fpp(13, 3, 7,1),fpp(13, 3, 7,2),fpp(13, 3, 7,3)/
     x 1.8680496d-01,-2.5704616d-04, 3.9827919d-04 /
      data fpp(13, 3, 8,1),fpp(13, 3, 8,2),fpp(13, 3, 8,3)/
     x 1.1176922d-01, 1.6576991d-04, 5.4138463d-05 /
      data fpp(13, 3, 9,1),fpp(13, 3, 9,2),fpp(13, 3, 9,3)/
     x 1.4618674d-01, 4.0201582d-04, 9.3484961d-05 /
      data fpp(13, 3,10,1),fpp(13, 3,10,2),fpp(13, 3,10,3)/
     x 1.3564991d-01, 5.0689575d-04, 4.7715693d-05 /
      data fpp(13, 3,11,1),fpp(13, 3,11,2),fpp(13, 3,11,3)/
     x 1.3978681d-01, 5.5643297d-04, 5.2054267d-05 /
      data fpp(13, 3,12,1),fpp(13, 3,12,2),fpp(13, 3,12,3)/
     x 1.3798274d-01, 5.7040797d-04, 4.9173240d-05 /
      data fpp(13, 3,13,1),fpp(13, 3,13,2),fpp(13, 3,13,3)/
     x 1.3529909d-01, 5.5206919d-04, 5.2836775d-05 /
      data fpp(13, 3,14,1),fpp(13, 3,14,2),fpp(13, 3,14,3)/
     x 1.3668419d-01, 4.9782651d-04, 4.8437662d-05 /
      data fpp(13, 3,15,1),fpp(13, 3,15,2),fpp(13, 3,15,3)/
     x-5.0691051d-01, 3.8834653d-04, 9.7044578d-05 /
      data fpp(13, 3,16,1),fpp(13, 3,16,2),fpp(13, 3,16,3)/
     x 9.9100885d-02, 1.4816230d-04, 5.0602025d-05 /
      data fpp(13, 3,17,1),fpp(13, 3,17,2),fpp(13, 3,17,3)/
     x 1.8487771d-01,-2.7126385d-04, 4.1169132d-04 /
      data fpp(13, 3,18,1),fpp(13, 3,18,2),fpp(13, 3,18,3)/
     x 2.4466914d-01,-1.4483746d-03, 3.5090669d-04 /
      data fpp(13, 3,19,1),fpp(13, 3,19,2),fpp(13, 3,19,3)/
     x 1.0584299d+00,-1.4964221d-03,-9.9625807d-04 /
      data fpp(13, 3,20,1),fpp(13, 3,20,2),fpp(13, 3,20,3)/
     x 2.8728561d-01,-1.6964320d-03,-7.7783917d-06 /
      data fpp(13, 3,21,1),fpp(13, 3,21,2),fpp(13, 3,21,3)/
     x 2.8728561d-01,-1.6964320d-03,-9.3622788d-05 /
      data fpp(13, 3,22,1),fpp(13, 3,22,2),fpp(13, 3,22,3)/
     x 1.0584299d+00,-1.4964221d-03,-6.5288049d-04 /
      data fpp(13, 3,23,1),fpp(13, 3,23,2),fpp(13, 3,23,3)/
     x 2.4466914d-01,-1.4483746d-03,-9.3675926d-04 /
      data fpp(13, 4, 1,1),fpp(13, 4, 1,2),fpp(13, 4, 1,3)/
     x 7.1612150d-02, 3.8445762d-04,-1.4945305d-03 /
      data fpp(13, 4, 2,1),fpp(13, 4, 2,2),fpp(13, 4, 2,3)/
     x-3.9727636d+00,-1.9148406d-03,-1.0164690d-03 /
      data fpp(13, 4, 3,1),fpp(13, 4, 3,2),fpp(13, 4, 3,3)/
     x 2.2306420d-01,-1.6913125d-03,-1.0431351d-04 /
      data fpp(13, 4, 4,1),fpp(13, 4, 4,2),fpp(13, 4, 4,3)/
     x 2.2306420d-01,-1.6913125d-03, 9.2145016d-05 /
      data fpp(13, 4, 5,1),fpp(13, 4, 5,2),fpp(13, 4, 5,3)/
     x-3.9727636d+00,-1.9148406d-03,-1.8023031d-03 /
      data fpp(13, 4, 6,1),fpp(13, 4, 6,2),fpp(13, 4, 6,3)/
     x 7.1612150d-02, 3.8445762d-04, 1.4523473d-03 /
      data fpp(13, 4, 7,1),fpp(13, 4, 7,2),fpp(13, 4, 7,3)/
     x-1.0458161d-01, 3.5869901d-04,-5.6722220d-05 /
      data fpp(13, 4, 8,1),fpp(13, 4, 8,2),fpp(13, 4, 8,3)/
     x 2.4711537d-02, 3.5679989d-04, 1.5539355d-04 /
      data fpp(13, 4, 9,1),fpp(13, 4, 9,2),fpp(13, 4, 9,3)/
     x 2.0016799d-02, 3.2506096d-04, 3.8892009d-05 /
      data fpp(13, 4,10,1),fpp(13, 4,10,2),fpp(13, 4,10,3)/
     x 4.9643854d-02, 3.2886407d-04, 5.8548411d-05 /
      data fpp(13, 4,11,1),fpp(13, 4,11,2),fpp(13, 4,11,3)/
     x 3.3334382d-02, 3.3801225d-04, 5.1526349d-05 /
      data fpp(13, 4,12,1),fpp(13, 4,12,2),fpp(13, 4,12,3)/
     x 1.9190472d-02, 3.4146142d-04, 5.3808195d-05 /
      data fpp(13, 4,13,1),fpp(13, 4,13,2),fpp(13, 4,13,3)/
     x 3.1821654d-02, 3.3691316d-04, 5.2572873d-05 /
      data fpp(13, 4,14,1),fpp(13, 4,14,2),fpp(13, 4,14,3)/
     x 5.6275052d-02, 3.2635410d-04, 6.0578315d-05 /
      data fpp(13, 4,15,1),fpp(13, 4,15,2),fpp(13, 4,15,3)/
     x 1.9808816d-02, 3.1973790d-04, 4.3579868d-05 /
      data fpp(13, 4,16,1),fpp(13, 4,16,2),fpp(13, 4,16,3)/
     x 2.4233803d-02, 3.4644389d-04, 1.5800021d-04 /
      data fpp(13, 4,17,1),fpp(13, 4,17,2),fpp(13, 4,17,3)/
     x 3.5326461d-02, 3.3831616d-04,-3.9688727d-05 /
      data fpp(13, 4,18,1),fpp(13, 4,18,2),fpp(13, 4,18,3)/
     x 6.7739832d-02, 3.6095479d-04, 1.4108807d-03 /
      data fpp(13, 4,19,1),fpp(13, 4,19,2),fpp(13, 4,19,3)/
     x-3.5586263d+00,-1.8704287d-03,-1.7774120d-03 /
      data fpp(13, 4,20,1),fpp(13, 4,20,2),fpp(13, 4,20,3)/
     x 2.1506282d-01,-1.5571074d-03, 8.7657465d-05 /
      data fpp(13, 4,21,1),fpp(13, 4,21,2),fpp(13, 4,21,3)/
     x 2.1506282d-01,-1.5571074d-03,-1.0500038d-04 /
      data fpp(13, 4,22,1),fpp(13, 4,22,2),fpp(13, 4,22,3)/
     x-3.5586263d+00,-1.8704287d-03,-1.0067807d-03 /
      data fpp(13, 4,23,1),fpp(13, 4,23,2),fpp(13, 4,23,3)/
     x 6.7739832d-02, 3.6095479d-04,-1.4789869d-03 /
      data fpp(13, 5, 1,1),fpp(13, 5, 1,2),fpp(13, 5, 1,3)/
     x-2.4490261d-02, 4.0661069d-04, 1.8735855d-04 /
      data fpp(13, 5, 2,1),fpp(13, 5, 2,2),fpp(13, 5, 2,3)/
     x-6.4232050d-03, 2.2370159d-03, 4.7496910d-05 /
      data fpp(13, 5, 3,1),fpp(13, 5, 3,2),fpp(13, 5, 3,3)/
     x 2.4291474d-02, 1.7787356d-03,-2.4640218d-04 /
      data fpp(13, 5, 4,1),fpp(13, 5, 4,2),fpp(13, 5, 4,3)/
     x 2.4291474d-02, 1.7787356d-03,-2.5655990d-04 /
      data fpp(13, 5, 5,1),fpp(13, 5, 5,2),fpp(13, 5, 5,3)/
     x-6.4232050d-03, 2.2370159d-03, 8.8127776d-05 /
      data fpp(13, 5, 6,1),fpp(13, 5, 6,2),fpp(13, 5, 6,3)/
     x-2.4490261d-02, 4.0661069d-04, 3.4992797d-05 /
      data fpp(13, 5, 7,1),fpp(13, 5, 7,2),fpp(13, 5, 7,3)/
     x-1.9890954d-02, 1.1578412d-04, 5.2479036d-05 /
      data fpp(13, 5, 8,1),fpp(13, 5, 8,2),fpp(13, 5, 8,3)/
     x-1.5549243d-02, 6.4302533d-05, 4.1627060d-05 /
      data fpp(13, 5, 9,1),fpp(13, 5, 9,2),fpp(13, 5, 9,3)/
     x-1.2301570d-02, 8.3988355d-05, 4.5420725d-05 /
      data fpp(13, 5,10,1),fpp(13, 5,10,2),fpp(13, 5,10,3)/
     x-1.0268969d-02, 9.8031982d-05, 4.5076042d-05 /
      data fpp(13, 5,11,1),fpp(13, 5,11,2),fpp(13, 5,11,3)/
     x-9.1012652d-03, 1.0369002d-04, 4.4749109d-05 /
      data fpp(13, 5,12,1),fpp(13, 5,12,2),fpp(13, 5,12,3)/
     x-8.6737752d-03, 1.0476637d-04, 4.4805523d-05 /
      data fpp(13, 5,13,1),fpp(13, 5,13,2),fpp(13, 5,13,3)/
     x-8.7497895d-03, 1.0298817d-04, 4.5950800d-05 /
      data fpp(13, 5,14,1),fpp(13, 5,14,2),fpp(13, 5,14,3)/
     x-9.4329773d-03, 9.7077096d-05, 4.7709279d-05 /
      data fpp(13, 5,15,1),fpp(13, 5,15,2),fpp(13, 5,15,3)/
     x-1.0930237d-02, 8.3921868d-05, 4.9802085d-05 /
      data fpp(13, 5,16,1),fpp(13, 5,16,2),fpp(13, 5,16,3)/
     x-1.3204845d-02, 6.6034123d-05, 4.9512381d-05 /
      data fpp(13, 5,17,1),fpp(13, 5,17,2),fpp(13, 5,17,3)/
     x-1.6774718d-02, 1.1690720d-04, 6.2972391d-05 /
      data fpp(13, 5,18,1),fpp(13, 5,18,2),fpp(13, 5,18,3)/
     x-2.0984917d-02, 3.8928745d-04, 5.7464056d-05 /
      data fpp(13, 5,19,1),fpp(13, 5,19,2),fpp(13, 5,19,3)/
     x 5.4735151d-02, 2.1032470d-03, 9.5509385d-05 /
      data fpp(13, 5,20,1),fpp(13, 5,20,2),fpp(13, 5,20,3)/
     x 2.8669721d-02, 1.5247277d-03,-2.8543960d-04 /
      data fpp(13, 5,21,1),fpp(13, 5,21,2),fpp(13, 5,21,3)/
     x 2.8669721d-02, 1.5247277d-03,-2.7519490d-04 /
      data fpp(13, 5,22,1),fpp(13, 5,22,2),fpp(13, 5,22,3)/
     x 5.4735151d-02, 2.1032470d-03, 5.4530615d-05 /
      data fpp(13, 5,23,1),fpp(13, 5,23,2),fpp(13, 5,23,3)/
     x-2.0984917d-02, 3.8928745d-04, 2.1113444d-04 /
      data fpp(13, 6, 1,1),fpp(13, 6, 1,2),fpp(13, 6, 1,3)/
     x-2.1300418d-02,-1.1406040d-04, 6.1176123d-05 /
      data fpp(13, 6, 2,1),fpp(13, 6, 2,2),fpp(13, 6, 2,3)/
     x-2.9215530d-02,-5.7610100d-04, 1.2982549d-06 /
      data fpp(13, 6, 3,1),fpp(13, 6, 3,2),fpp(13, 6, 3,3)/
     x-1.3360192d-02,-3.9133990d-04,-1.2487514d-04 /
      data fpp(13, 6, 4,1),fpp(13, 6, 4,2),fpp(13, 6, 4,3)/
     x-1.3360192d-02,-3.9133990d-04,-1.2861370d-04 /
      data fpp(13, 6, 5,1),fpp(13, 6, 5,2),fpp(13, 6, 5,3)/
     x-2.9215530d-02,-5.7610100d-04, 1.6252491d-05 /
      data fpp(13, 6, 6,1),fpp(13, 6, 6,2),fpp(13, 6, 6,3)/
     x-2.1300418d-02,-1.1406040d-04, 5.0977385d-06 /
      data fpp(13, 6, 7,1),fpp(13, 6, 7,2),fpp(13, 6, 7,3)/
     x-1.6734667d-02,-3.7389474d-05, 2.2036555d-05 /
      data fpp(13, 6, 8,1),fpp(13, 6, 8,2),fpp(13, 6, 8,3)/
     x-1.4636425d-02,-1.4718019d-05, 2.6216040d-05 /
      data fpp(13, 6, 9,1),fpp(13, 6, 9,2),fpp(13, 6, 9,3)/
     x-1.3912914d-02,-1.5072376d-05, 2.9975284d-05 /
      data fpp(13, 6,10,1),fpp(13, 6,10,2),fpp(13, 6,10,3)/
     x-1.3709912d-02,-1.7989994d-05, 3.1554823d-05 /
      data fpp(13, 6,11,1),fpp(13, 6,11,2),fpp(13, 6,11,3)/
     x-1.3736424d-02,-2.0028336d-05, 3.2823426d-05 /
      data fpp(13, 6,12,1),fpp(13, 6,12,2),fpp(13, 6,12,3)/
     x-1.3619297d-02,-2.0690909d-05, 3.3795475d-05 /
      data fpp(13, 6,13,1),fpp(13, 6,13,2),fpp(13, 6,13,3)/
     x-1.3339647d-02,-1.9871830d-05, 3.4572674d-05 /
      data fpp(13, 6,14,1),fpp(13, 6,14,2),fpp(13, 6,14,3)/
     x-1.2938530d-02,-1.7060484d-05, 3.5321827d-05 /
      data fpp(13, 6,15,1),fpp(13, 6,15,2),fpp(13, 6,15,3)/
     x-1.2621811d-02,-1.1973375d-05, 3.6096017d-05 /
      data fpp(13, 6,16,1),fpp(13, 6,16,2),fpp(13, 6,16,3)/
     x-1.2518786d-02,-6.5963873d-06, 3.4938105d-05 /
      data fpp(13, 6,17,1),fpp(13, 6,17,2),fpp(13, 6,17,3)/
     x-1.2968036d-02,-1.8642975d-05, 3.2693565d-05 /
      data fpp(13, 6,18,1),fpp(13, 6,18,2),fpp(13, 6,18,3)/
     x-1.4250108d-02,-7.2948605d-05, 1.6429637d-05 /
      data fpp(13, 6,19,1),fpp(13, 6,19,2),fpp(13, 6,19,3)/
     x-1.5620673d-02,-4.7453143d-04, 1.6859889d-05 /
      data fpp(13, 6,20,1),fpp(13, 6,20,2),fpp(13, 6,20,3)/
     x-7.0824926d-03,-2.2905136d-04,-1.4278319d-04 /
      data fpp(13, 6,21,1),fpp(13, 6,21,2),fpp(13, 6,21,3)/
     x-7.0824926d-03,-2.2905136d-04,-1.3922637d-04 /
      data fpp(13, 6,22,1),fpp(13, 6,22,2),fpp(13, 6,22,3)/
     x-1.5620673d-02,-4.7453143d-04, 2.6326059d-06 /
      data fpp(13, 6,23,1),fpp(13, 6,23,2),fpp(13, 6,23,3)/
     x-1.4250108d-02,-7.2948605d-05, 6.9781947d-05 /
      data fpp(13, 7, 1,1),fpp(13, 7, 1,2),fpp(13, 7, 1,3)/
     x 8.3361537d-04, 4.9504895d-05,-5.9977270d-06 /
      data fpp(13, 7, 2,1),fpp(13, 7, 2,2),fpp(13, 7, 2,3)/
     x 6.4836014d-03, 2.2926812d-04,-1.7611546d-05 /
      data fpp(13, 7, 3,1),fpp(13, 7, 3,2),fpp(13, 7, 3,3)/
     x 1.5538727d-02, 2.3956998d-04,-4.2452089d-05 /
      data fpp(13, 7, 4,1),fpp(13, 7, 4,2),fpp(13, 7, 4,3)/
     x 1.5538727d-02, 2.3956998d-04,-4.2532960d-05 /
      data fpp(13, 7, 5,1),fpp(13, 7, 5,2),fpp(13, 7, 5,3)/
     x 6.4836014d-03, 2.2926812d-04,-1.7288064d-05 /
      data fpp(13, 7, 6,1),fpp(13, 7, 6,2),fpp(13, 7, 6,3)/
     x 8.3361537d-04, 4.9504895d-05,-7.2107832d-06 /
      data fpp(13, 7, 7,1),fpp(13, 7, 7,2),fpp(13, 7, 7,3)/
     x-2.9050465d-03,-9.9782184d-06, 1.2931970d-06 /
      data fpp(13, 7, 8,1),fpp(13, 7, 8,2),fpp(13, 7, 8,3)/
     x-5.9969318d-03,-3.9654458d-05, 7.5759952d-06 /
      data fpp(13, 7, 9,1),fpp(13, 7, 9,2),fpp(13, 7, 9,3)/
     x-8.6747423d-03,-5.2930849d-05, 1.3210822d-05 /
      data fpp(13, 7,10,1),fpp(13, 7,10,2),fpp(13, 7,10,3)/
     x-1.0647012d-02,-5.8880006d-05, 1.7970716d-05 /
      data fpp(13, 7,11,1),fpp(13, 7,11,2),fpp(13, 7,11,3)/
     x-1.1825637d-02,-6.0908677d-05, 2.1520312d-05 /
      data fpp(13, 7,12,1),fpp(13, 7,12,2),fpp(13, 7,12,3)/
     x-1.2212339d-02,-6.0630737d-05, 2.3586035d-05 /
      data fpp(13, 7,13,1),fpp(13, 7,13,2),fpp(13, 7,13,3)/
     x-1.1988984d-02,-5.8504846d-05, 2.4289547d-05 /
      data fpp(13, 7,14,1),fpp(13, 7,14,2),fpp(13, 7,14,3)/
     x-1.1129470d-02,-5.3993162d-05, 2.3975775d-05 /
      data fpp(13, 7,15,1),fpp(13, 7,15,2),fpp(13, 7,15,3)/
     x-9.7953661d-03,-4.5616368d-05, 2.2853352d-05 /
      data fpp(13, 7,16,1),fpp(13, 7,16,2),fpp(13, 7,16,3)/
     x-7.5991723d-03,-3.0864574d-05, 2.0270816d-05 /
      data fpp(13, 7,17,1),fpp(13, 7,17,2),fpp(13, 7,17,3)/
     x-4.6353444d-03,-2.6333025d-06, 1.4869384d-05 /
      data fpp(13, 7,18,1),fpp(13, 7,18,2),fpp(13, 7,18,3)/
     x-6.6524113d-04, 5.0124963d-05, 2.6676472d-06 /
      data fpp(13, 7,19,1),fpp(13, 7,19,2),fpp(13, 7,19,3)/
     x 5.1990808d-03, 2.1794469d-04,-1.5801973d-05 /
      data fpp(13, 7,20,1),fpp(13, 7,20,2),fpp(13, 7,20,3)/
     x 1.3107528d-02, 2.4131175d-04,-6.0029755d-05 /
      data fpp(13, 7,21,1),fpp(13, 7,21,2),fpp(13, 7,21,3)/
     x 1.3107528d-02, 2.4131175d-04,-5.9926748d-05 /
      data fpp(13, 7,22,1),fpp(13, 7,22,2),fpp(13, 7,22,3)/
     x 5.1990808d-03, 2.1794469d-04,-1.6214001d-05 /
      data fpp(13, 7,23,1),fpp(13, 7,23,2),fpp(13, 7,23,3)/
     x-6.6524113d-04, 5.0124963d-05, 4.2127503d-06 /
      data fpp(13, 8, 1,1),fpp(13, 8, 1,2),fpp(13, 8, 1,3)/
     x 1.1535917d-02, 7.1388174d-06,-8.3165498d-06 /
      data fpp(13, 8, 2,1),fpp(13, 8, 2,2),fpp(13, 8, 2,3)/
     x 1.5321203d-02, 3.8522536d-05,-9.8924004d-06 /
      data fpp(13, 8, 3,1),fpp(13, 8, 3,2),fpp(13, 8, 3,3)/
     x-2.7787615d-01, 2.1906597d-04,-1.3283849d-05 /
      data fpp(13, 8, 4,1),fpp(13, 8, 4,2),fpp(13, 8, 4,3)/
     x-2.7787615d-01, 2.1906597d-04,-1.3258254d-05 /
      data fpp(13, 8, 5,1),fpp(13, 8, 5,2),fpp(13, 8, 5,3)/
     x 1.5321203d-02, 3.8522536d-05,-9.9947773d-06 /
      data fpp(13, 8, 6,1),fpp(13, 8, 6,2),fpp(13, 8, 6,3)/
     x 1.1535917d-02, 7.1388174d-06,-7.9326365d-06 /
      data fpp(13, 8, 7,1),fpp(13, 8, 7,2),fpp(13, 8, 7,3)/
     x 7.7861872d-03,-1.9681652d-05,-6.3166767d-06 /
      data fpp(13, 8, 8,1),fpp(13, 8, 8,2),fpp(13, 8, 8,3)/
     x 3.8116003d-03,-3.9856148d-05,-3.3106565d-06 /
      data fpp(13, 8, 9,1),fpp(13, 8, 9,2),fpp(13, 8, 9,3)/
     x-2.6652823d-04,-5.3026226d-05, 1.8773028d-06 /
      data fpp(13, 8,10,1),fpp(13, 8,10,2),fpp(13, 8,10,3)/
     x-4.0987122d-03,-6.0145982d-05, 7.7054451d-06 /
      data fpp(13, 8,11,1),fpp(13, 8,11,2),fpp(13, 8,11,3)/
     x-6.5053215d-03,-6.2910958d-05, 1.2426917d-05 /
      data fpp(13, 8,12,1),fpp(13, 8,12,2),fpp(13, 8,12,3)/
     x-7.8037535d-03,-6.2250143d-05, 1.5246889d-05 /
      data fpp(13, 8,13,1),fpp(13, 8,13,2),fpp(13, 8,13,3)/
     x-8.0096239d-03,-5.8444785d-05, 1.6333529d-05 /
      data fpp(13, 8,14,1),fpp(13, 8,14,2),fpp(13, 8,14,3)/
     x-7.3417378d-03,-5.1588869d-05, 1.6036995d-05 /
      data fpp(13, 8,15,1),fpp(13, 8,15,2),fpp(13, 8,15,3)/
     x-5.6445543d-03,-4.1553154d-05, 1.4570492d-05 /
      data fpp(13, 8,16,1),fpp(13, 8,16,2),fpp(13, 8,16,3)/
     x-3.3239086d-03,-2.7901317d-05, 1.1763037d-05 /
      data fpp(13, 8,17,1),fpp(13, 8,17,2),fpp(13, 8,17,3)/
     x-1.5134987d-04,-1.1041815d-05, 7.1493596d-06 /
      data fpp(13, 8,18,1),fpp(13, 8,18,2),fpp(13, 8,18,3)/
     x 3.8722581d-03, 6.8487512d-06,-7.9047534d-07 /
      data fpp(13, 8,19,1),fpp(13, 8,19,2),fpp(13, 8,19,3)/
     x 8.8885454d-03,-1.4932696d-07,-1.1703458d-05 /
      data fpp(13, 8,20,1),fpp(13, 8,20,2),fpp(13, 8,20,3)/
     x 1.3973011d-02, 2.9476347d-05,-2.8745692d-05 /
      data fpp(13, 8,21,1),fpp(13, 8,21,2),fpp(13, 8,21,3)/
     x 1.3973011d-02, 2.9476347d-05,-2.8886195d-05 /
      data fpp(13, 8,22,1),fpp(13, 8,22,2),fpp(13, 8,22,3)/
     x 8.8885454d-03,-1.4932696d-07,-1.1141444d-05 /
      data fpp(13, 8,23,1),fpp(13, 8,23,2),fpp(13, 8,23,3)/
     x 3.8722581d-03, 6.8487512d-06,-2.8980279d-06 /
      data fpp(13, 9, 1,1),fpp(13, 9, 1,2),fpp(13, 9, 1,3)/
     x 1.8766347d-02,-3.9144165d-05, 7.2632049d-05 /
      data fpp(13, 9, 2,1),fpp(13, 9, 2,2),fpp(13, 9, 2,3)/
     x-6.3607727d-02,-1.2723026d-04, 3.6481401d-05 /
      data fpp(13, 9, 3,1),fpp(13, 9, 3,2),fpp(13, 9, 3,3)/
     x-2.0013442d+00,-4.5814384d-04,-3.7651655d-05 /
      data fpp(13, 9, 4,1),fpp(13, 9, 4,2),fpp(13, 9, 4,3)/
     x-2.0013442d+00,-4.5814384d-04,-4.3483736d-05 /
      data fpp(13, 9, 5,1),fpp(13, 9, 5,2),fpp(13, 9, 5,3)/
     x-6.3607727d-02,-1.2723026d-04, 5.9809723d-05 /
      data fpp(13, 9, 6,1),fpp(13, 9, 6,2),fpp(13, 9, 6,3)/
     x 1.8766347d-02,-3.9144165d-05,-1.4849158d-05 /
      data fpp(13, 9, 7,1),fpp(13, 9, 7,2),fpp(13, 9, 7,3)/
     x 1.6642128d-02,-3.8783173d-05,-8.5109166d-07 /
      data fpp(13, 9, 8,1),fpp(13, 9, 8,2),fpp(13, 9, 8,3)/
     x 1.3427964d-02,-4.2216950d-05,-7.7084755d-06 /
      data fpp(13, 9, 9,1),fpp(13, 9, 9,2),fpp(13, 9, 9,3)/
     x 9.2570363d-03,-4.5410246d-05,-3.8290065d-06 /
      data fpp(13, 9,10,1),fpp(13, 9,10,2),fpp(13, 9,10,3)/
     x 4.7776377d-03,-4.7516067d-05, 1.0585016d-06 /
      data fpp(13, 9,11,1),fpp(13, 9,11,2),fpp(13, 9,11,3)/
     x 1.0655421d-03,-4.7945492d-05, 6.2490001d-06 /
      data fpp(13, 9,12,1),fpp(13, 9,12,2),fpp(13, 9,12,3)/
     x-1.3530451d-03,-4.6420689d-05, 9.5914979d-06 /
      data fpp(13, 9,13,1),fpp(13, 9,13,2),fpp(13, 9,13,3)/
     x-2.3424909d-03,-4.2948013d-05, 1.1101008d-05 /
      data fpp(13, 9,14,1),fpp(13, 9,14,2),fpp(13, 9,14,3)/
     x-2.2214665d-03,-3.7425360d-05, 1.1158469d-05 /
      data fpp(13, 9,15,1),fpp(13, 9,15,2),fpp(13, 9,15,3)/
     x-1.2769803d-03,-2.9725018d-05, 1.0085117d-05 /
      data fpp(13, 9,16,1),fpp(13, 9,16,2),fpp(13, 9,16,3)/
     x 4.5344753d-04,-1.9806158d-05, 8.0630647d-06 /
      data fpp(13, 9,17,1),fpp(13, 9,17,2),fpp(13, 9,17,3)/
     x 2.8909096d-03,-7.7154388d-06, 4.8826244d-06 /
      data fpp(13, 9,18,1),fpp(13, 9,18,2),fpp(13, 9,18,3)/
     x 6.1274745d-03, 6.3540317d-06,-2.3956243d-07 /
      data fpp(13, 9,19,1),fpp(13, 9,19,2),fpp(13, 9,19,3)/
     x 1.0093967d-02, 2.7158618d-05,-6.8523747d-06 /
      data fpp(13, 9,20,1),fpp(13, 9,20,2),fpp(13, 9,20,3)/
     x 1.3988134d-02, 3.4166860d-05,-1.6234939d-05 /
      data fpp(13, 9,21,1),fpp(13, 9,21,2),fpp(13, 9,21,3)/
     x 1.3988134d-02, 3.4166860d-05,-1.6340996d-05 /
      data fpp(13, 9,22,1),fpp(13, 9,22,2),fpp(13, 9,22,3)/
     x 1.0093967d-02, 2.7158618d-05,-6.4281439d-06 /
      data fpp(13, 9,23,1),fpp(13, 9,23,2),fpp(13, 9,23,3)/
     x 6.1274745d-03, 6.3540317d-06,-1.8304281d-06 /
      data fpp(13,10, 1,1),fpp(13,10, 1,2),fpp(13,10, 1,3)/
     x-6.2467857d-02,-1.4721416d-04,-7.9275655d-05 /
      data fpp(13,10, 2,1),fpp(13,10, 2,2),fpp(13,10, 2,3)/
     x 1.0708783d-01,-1.1819549d-04,-3.4936689d-05 /
      data fpp(13,10, 3,1),fpp(13,10, 3,2),fpp(13,10, 3,3)/
     x-6.0851536d-02, 1.4950341d-04, 5.8534413d-05 /
      data fpp(13,10, 4,1),fpp(13,10, 4,2),fpp(13,10, 4,3)/
     x-6.0851536d-02, 1.4950341d-04, 6.1231106d-05 /
      data fpp(13,10, 5,1),fpp(13,10, 5,2),fpp(13,10, 5,3)/
     x 1.0708783d-01,-1.1819549d-04,-4.5723460d-05 /
      data fpp(13,10, 6,1),fpp(13,10, 6,2),fpp(13,10, 6,3)/
     x-6.2467857d-02,-1.4721416d-04,-3.8825265d-05 /
      data fpp(13,10, 7,1),fpp(13,10, 7,2),fpp(13,10, 7,3)/
     x 4.6271254d-03,-8.0221655d-05,-2.1354784d-06 /
      data fpp(13,10, 8,1),fpp(13,10, 8,2),fpp(13,10, 8,3)/
     x 1.6173759d-02,-4.9804051d-05,-1.3154821d-05 /
      data fpp(13,10, 9,1),fpp(13,10, 9,2),fpp(13,10, 9,3)/
     x 1.5748324d-02,-3.7738788d-05,-8.9772381d-06 /
      data fpp(13,10,10,1),fpp(13,10,10,2),fpp(13,10,10,3)/
     x 1.2182108d-02,-3.3301751d-05,-4.0002268d-06 /
      data fpp(13,10,11,1),fpp(13,10,11,2),fpp(13,10,11,3)/
     x 8.2073316d-03,-3.1135073d-05, 1.9501452d-06 /
      data fpp(13,10,12,1),fpp(13,10,12,2),fpp(13,10,12,3)/
     x 5.1329459d-03,-2.9189099d-05, 5.8536461d-06 /
      data fpp(13,10,13,1),fpp(13,10,13,2),fpp(13,10,13,3)/
     x 3.4232431d-03,-2.6611161d-05, 7.8872705d-06 /
      data fpp(13,10,14,1),fpp(13,10,14,2),fpp(13,10,14,3)/
     x 2.7704107d-03,-2.3151689d-05, 8.4192720d-06 /
      data fpp(13,10,15,1),fpp(13,10,15,2),fpp(13,10,15,3)/
     x 2.9567110d-03,-1.8724774d-05, 7.8816415d-06 /
      data fpp(13,10,16,1),fpp(13,10,16,2),fpp(13,10,16,3)/
     x 3.9502020d-03,-1.3378052d-05, 6.5061619d-06 /
      data fpp(13,10,17,1),fpp(13,10,17,2),fpp(13,10,17,3)/
     x 5.5747110d-03,-7.4764302d-06, 4.2117107d-06 /
      data fpp(13,10,18,1),fpp(13,10,18,2),fpp(13,10,18,3)/
     x 7.9161164d-03,-1.9768782d-06, 3.2899529d-07 /
      data fpp(13,10,19,1),fpp(13,10,19,2),fpp(13,10,19,3)/
     x 1.0964173d-02, 6.6085618d-07,-4.4776918d-06 /
      data fpp(13,10,20,1),fpp(13,10,20,2),fpp(13,10,20,3)/
     x 1.4216917d-02, 4.5862140d-06,-1.1110228d-05 /
      data fpp(13,10,21,1),fpp(13,10,21,2),fpp(13,10,21,3)/
     x 1.4216917d-02, 4.5862140d-06,-1.1191470d-05 /
      data fpp(13,10,22,1),fpp(13,10,22,2),fpp(13,10,22,3)/
     x 1.0964173d-02, 6.6085618d-07,-4.1527228d-06 /
      data fpp(13,10,23,1),fpp(13,10,23,2),fpp(13,10,23,3)/
     x 7.9161164d-03,-1.9768782d-06,-8.8963860d-07 /
      data fpp(13,11, 1,1),fpp(13,11, 1,2),fpp(13,11, 1,3)/
     x-1.0437342d-01, 4.1260801d-05,-1.2882404d-06 /
      data fpp(13,11, 2,1),fpp(13,11, 2,2),fpp(13,11, 2,3)/
     x-1.0108700d-01, 1.1096420d-04, 1.5806481d-05 /
      data fpp(13,11, 3,1),fpp(13,11, 3,2),fpp(13,11, 3,3)/
     x-6.3834114d-02, 8.5868190d-05, 5.3274317d-05 /
      data fpp(13,11, 4,1),fpp(13,11, 4,2),fpp(13,11, 4,3)/
     x-6.3834114d-02, 8.5868190d-05, 5.1810808d-05 /
      data fpp(13,11, 5,1),fpp(13,11, 5,2),fpp(13,11, 5,3)/
     x-1.0108700d-01, 1.1096420d-04, 2.1660517d-05 /
      data fpp(13,11, 6,1),fpp(13,11, 6,2),fpp(13,11, 6,3)/
     x-1.0437342d-01, 4.1260801d-05,-2.3240876d-05 /
      data fpp(13,11, 7,1),fpp(13,11, 7,2),fpp(13,11, 7,3)/
     x-4.5101301d-02,-2.4678209d-05,-3.4495011d-05 /
      data fpp(13,11, 8,1),fpp(13,11, 8,2),fpp(13,11, 8,3)/
     x 5.3764502d-04,-3.1530847d-05,-2.4869079d-05 /
      data fpp(13,11, 9,1),fpp(13,11, 9,2),fpp(13,11, 9,3)/
     x 1.4306217d-02,-2.6738601d-05,-1.9502674d-05 /
      data fpp(13,11,10,1),fpp(13,11,10,2),fpp(13,11,10,3)/
     x 1.5440321d-02,-2.1548930d-05,-1.0310226d-05 /
      data fpp(13,11,11,1),fpp(13,11,11,2),fpp(13,11,11,3)/
     x 1.2865041d-02,-1.9184217d-05,-2.1964209d-06 /
      data fpp(13,11,12,1),fpp(13,11,12,2),fpp(13,11,12,3)/
     x 9.9752740d-03,-1.7686913d-05, 2.9619100d-06 /
      data fpp(13,11,13,1),fpp(13,11,13,2),fpp(13,11,13,3)/
     x 7.9740314d-03,-1.6135341d-05, 5.6667810d-06 /
      data fpp(13,11,14,1),fpp(13,11,14,2),fpp(13,11,14,3)/
     x 6.9357742d-03,-1.4267882d-05, 6.7529659d-06 /
      data fpp(13,11,15,1),fpp(13,11,15,2),fpp(13,11,15,3)/
     x 6.6918389d-03,-1.2129884d-05, 6.7113554d-06 /
      data fpp(13,11,16,1),fpp(13,11,16,2),fpp(13,11,16,3)/
     x 7.2453597d-03,-9.8836328d-06, 5.7496124d-06 /
      data fpp(13,11,17,1),fpp(13,11,17,2),fpp(13,11,17,3)/
     x 8.3278871d-03,-7.7748405d-06, 3.5601951d-06 /
      data fpp(13,11,18,1),fpp(13,11,18,2),fpp(13,11,18,3)/
     x 9.9488718d-03,-5.9285189d-06, 1.2760742d-07 /
      data fpp(13,11,19,1),fpp(13,11,19,2),fpp(13,11,19,3)/
     x 1.2379052d-02,-4.0560424d-06,-3.7286247d-06 /
      data fpp(13,11,20,1),fpp(13,11,20,2),fpp(13,11,20,3)/
     x 1.5290326d-02,-3.5097159d-06,-8.6851085d-06 /
      data fpp(13,11,21,1),fpp(13,11,21,2),fpp(13,11,21,3)/
     x 1.5290326d-02,-3.5097159d-06,-8.7583620d-06 /
      data fpp(13,11,22,1),fpp(13,11,22,2),fpp(13,11,22,3)/
     x 1.2379052d-02,-4.0560424d-06,-3.4356109d-06 /
      data fpp(13,11,23,1),fpp(13,11,23,2),fpp(13,11,23,3)/
     x 9.9488718d-03,-5.9285189d-06,-9.7119457d-07 /
      data fpp(13,12, 1,1),fpp(13,12, 1,2),fpp(13,12, 1,3)/
     x-1.1295367d-01, 5.9006954d-05, 5.5777709d-05 /
      data fpp(13,12, 2,1),fpp(13,12, 2,2),fpp(13,12, 2,3)/
     x-9.3863260d-02, 8.3010668d-05, 4.5371582d-05 /
      data fpp(13,12, 3,1),fpp(13,12, 3,2),fpp(13,12, 3,3)/
     x-3.4557404d-02, 1.1844783d-04, 2.4563963d-05 /
      data fpp(13,12, 4,1),fpp(13,12, 4,2),fpp(13,12, 4,3)/
     x-3.4557404d-02, 1.1844783d-04, 2.1954320d-05 /
      data fpp(13,12, 5,1),fpp(13,12, 5,2),fpp(13,12, 5,3)/
     x-9.3863260d-02, 8.3010668d-05, 5.5810156d-05 /
      data fpp(13,12, 6,1),fpp(13,12, 6,2),fpp(13,12, 6,3)/
     x-1.1295367d-01, 5.9006954d-05, 1.6633056d-05 /
      data fpp(13,12, 7,1),fpp(13,12, 7,2),fpp(13,12, 7,3)/
     x-7.6045610d-02, 3.1736489d-05,-2.2976379d-05 /
      data fpp(13,12, 8,1),fpp(13,12, 8,2),fpp(13,12, 8,3)/
     x-2.4929155d-02, 5.3234379d-06,-3.5757540d-05 /
      data fpp(13,12, 9,1),fpp(13,12, 9,2),fpp(13,12, 9,3)/
     x 4.2953344d-03,-2.9668074d-06,-3.0859462d-05 /
      data fpp(13,12,10,1),fpp(13,12,10,2),fpp(13,12,10,3)/
     x 1.3864108d-02,-9.4005305d-06,-1.8302613d-05 /
      data fpp(13,12,11,1),fpp(13,12,11,2),fpp(13,12,11,3)/
     x 1.4470228d-02,-1.0190061d-05,-6.7080849d-06 /
      data fpp(13,12,12,1),fpp(13,12,12,2),fpp(13,12,12,3)/
     x 1.2636227d-02,-1.0169249d-05, 3.3295280d-07 /
      data fpp(13,12,13,1),fpp(13,12,13,2),fpp(13,12,13,3)/
     x 1.0917093d-02,-9.8874750d-06, 3.8702736d-06 /
      data fpp(13,12,14,1),fpp(13,12,14,2),fpp(13,12,14,3)/
     x 9.9433174d-03,-9.4467808d-06, 5.4319526d-06 /
      data fpp(13,12,15,1),fpp(13,12,15,2),fpp(13,12,15,3)/
     x 9.7245566d-03,-9.0396879d-06, 5.7519159d-06 /
      data fpp(13,12,16,1),fpp(13,12,16,2),fpp(13,12,16,3)/
     x 1.0231469d-02,-8.8514166d-06, 4.9383837d-06 /
      data fpp(13,12,17,1),fpp(13,12,17,2),fpp(13,12,17,3)/
     x 1.1095443d-02,-8.9142079d-06, 2.6705492d-06 /
      data fpp(13,12,18,1),fpp(13,12,18,2),fpp(13,12,18,3)/
     x 1.2403122d-02,-8.9890463d-06,-5.3058037d-07 /
      data fpp(13,12,19,1),fpp(13,12,19,2),fpp(13,12,19,3)/
     x 1.4401796d-02,-9.0066866d-06,-3.6142277d-06 /
      data fpp(13,12,20,1),fpp(13,12,20,2),fpp(13,12,20,3)/
     x 1.6780452d-02,-8.7213506d-06,-6.9785089d-06 /
      data fpp(13,12,21,1),fpp(13,12,21,2),fpp(13,12,21,3)/
     x 1.6780452d-02,-8.7213506d-06,-7.0503594d-06 /
      data fpp(13,12,22,1),fpp(13,12,22,2),fpp(13,12,22,3)/
     x 1.4401796d-02,-9.0066866d-06,-3.3268259d-06 /
      data fpp(13,12,23,1),fpp(13,12,23,2),fpp(13,12,23,3)/
     x 1.2403122d-02,-8.9890463d-06,-1.6083371d-06 /
      data fpp(13,13, 1,1),fpp(13,13, 1,2),fpp(13,13, 1,3)/
     x-1.1344008d-01, 4.7827382d-05, 9.5429816d-05 /
      data fpp(13,13, 2,1),fpp(13,13, 2,2),fpp(13,13, 2,3)/
     x-7.3625026d-02, 2.2365125d-05, 6.1211369d-05 /
      data fpp(13,13, 3,1),fpp(13,13, 3,2),fpp(13,13, 3,3)/
     x 9.4052736d-03,-3.2499493d-05,-1.0299290d-05 /
      data fpp(13,13, 4,1),fpp(13,13, 4,2),fpp(13,13, 4,3)/
     x 9.4052736d-03,-3.2499493d-05,-1.3474814d-05 /
      data fpp(13,13, 5,1),fpp(13,13, 5,2),fpp(13,13, 5,3)/
     x-7.3625026d-02, 2.2365125d-05, 7.3913462d-05 /
      data fpp(13,13, 6,1),fpp(13,13, 6,2),fpp(13,13, 6,3)/
     x-1.1344008d-01, 4.7827382d-05, 4.7796967d-05 /
      data fpp(13,13, 7,1),fpp(13,13, 7,2),fpp(13,13, 7,3)/
     x-9.5142754d-02, 4.3346254d-05, 1.8267200d-07 /
      data fpp(13,13, 8,1),fpp(13,13, 8,2),fpp(13,13, 8,3)/
     x-4.9043567d-02, 2.8243095d-05,-3.2603655d-05 /
      data fpp(13,13, 9,1),fpp(13,13, 9,2),fpp(13,13, 9,3)/
     x-1.0100465d-02, 1.7598308d-06,-3.7270054d-05 /
      data fpp(13,13,10,1),fpp(13,13,10,2),fpp(13,13,10,3)/
     x 8.6927567d-03, 3.1650517d-06,-2.4410130d-05 /
      data fpp(13,13,11,1),fpp(13,13,11,2),fpp(13,13,11,3)/
     x 1.3652968d-02,-1.9515411d-06,-1.0475425d-05 /
      data fpp(13,13,12,1),fpp(13,13,12,2),fpp(13,13,12,3)/
     x 1.3612396d-02,-4.2520912d-06,-1.9681702d-06 /
      data fpp(13,13,13,1),fpp(13,13,13,2),fpp(13,13,13,3)/
     x 1.2607365d-02,-5.3647593d-06, 2.3041056d-06 /
      data fpp(13,13,14,1),fpp(13,13,14,2),fpp(13,13,14,3)/
     x 1.1909468d-02,-6.1509945d-06, 4.1397478d-06 /
      data fpp(13,13,15,1),fpp(13,13,15,2),fpp(13,13,15,3)/
     x 1.1888367d-02,-6.8993639d-06, 4.6209032d-06 /
      data fpp(13,13,16,1),fpp(13,13,16,2),fpp(13,13,16,3)/
     x 1.2511146d-02,-7.7987010d-06, 3.8666393d-06 /
      data fpp(13,13,17,1),fpp(13,13,17,2),fpp(13,13,17,3)/
     x 1.3457398d-02,-8.7743281d-06, 1.7765394d-06 /
      data fpp(13,13,18,1),fpp(13,13,18,2),fpp(13,13,18,3)/
     x 1.4538554d-02,-9.5352960d-06,-1.0067970d-06 /
      data fpp(13,13,19,1),fpp(13,13,19,2),fpp(13,13,19,3)/
     x 1.6010077d-02,-9.7592113d-06,-3.4313515d-06 /
      data fpp(13,13,20,1),fpp(13,13,20,2),fpp(13,13,20,3)/
     x 1.7709665d-02,-9.6468819d-06,-5.5057969d-06 /
      data fpp(13,13,21,1),fpp(13,13,21,2),fpp(13,13,21,3)/
     x 1.7709665d-02,-9.6468819d-06,-5.5749336d-06 /
      data fpp(13,13,22,1),fpp(13,13,22,2),fpp(13,13,22,3)/
     x 1.6010077d-02,-9.7592113d-06,-3.1548047d-06 /
      data fpp(13,13,23,1),fpp(13,13,23,2),fpp(13,13,23,3)/
     x 1.4538554d-02,-9.5352960d-06,-2.0438477d-06 /
      data fpp(13,14, 1,1),fpp(13,14, 1,2),fpp(13,14, 1,3)/
     x-1.0699388d-01, 4.2915518d-05, 8.5665298d-05 /
      data fpp(13,14, 2,1),fpp(13,14, 2,2),fpp(13,14, 2,3)/
     x-6.0481436d-02, 7.1748309d-06, 5.3459904d-05 /
      data fpp(13,14, 3,1),fpp(13,14, 3,2),fpp(13,14, 3,3)/
     x 1.5150375d-02,-3.5291852d-05,-1.4282915d-05 /
      data fpp(13,14, 4,1),fpp(13,14, 4,2),fpp(13,14, 4,3)/
     x 1.5150375d-02,-3.5291852d-05,-1.6503207d-05 /
      data fpp(13,14, 5,1),fpp(13,14, 5,2),fpp(13,14, 5,3)/
     x-6.0481436d-02, 7.1748309d-06, 6.2341071d-05 /
      data fpp(13,14, 6,1),fpp(13,14, 6,2),fpp(13,14, 6,3)/
     x-1.0699388d-01, 4.2915518d-05, 5.2360921d-05 /
      data fpp(13,14, 7,1),fpp(13,14, 7,2),fpp(13,14, 7,3)/
     x-1.0503874d-01, 5.4870496d-05, 1.2591245d-05 /
      data fpp(13,14, 8,1),fpp(13,14, 8,2),fpp(13,14, 8,3)/
     x-7.0154534d-02, 4.2786182d-05,-2.5517899d-05 /
      data fpp(13,14, 9,1),fpp(13,14, 9,2),fpp(13,14, 9,3)/
     x-2.6684128d-02, 6.8851484d-05,-3.7905647d-05 /
      data fpp(13,14,10,1),fpp(13,14,10,2),fpp(13,14,10,3)/
     x 1.7056088d-03, 1.3228324d-05,-2.5827513d-05 /
      data fpp(13,14,11,1),fpp(13,14,11,2),fpp(13,14,11,3)/
     x 1.1503309d-02, 5.1322249d-06,-1.1694302d-05 /
      data fpp(13,14,12,1),fpp(13,14,12,2),fpp(13,14,12,3)/
     x 1.3375573d-02, 8.6761362d-07,-3.2472779d-06 /
      data fpp(13,14,13,1),fpp(13,14,13,2),fpp(13,14,13,3)/
     x 1.3245070d-02,-1.4794879d-06, 1.0314141d-06 /
      data fpp(13,14,14,1),fpp(13,14,14,2),fpp(13,14,14,3)/
     x 1.3002294d-02,-3.0412413d-06, 2.9016215d-06 /
      data fpp(13,14,15,1),fpp(13,14,15,2),fpp(13,14,15,3)/
     x 1.3079149d-02,-4.3668566d-06, 3.3341000d-06 /
      data fpp(13,14,16,1),fpp(13,14,16,2),fpp(13,14,16,3)/
     x 1.3753998d-02,-5.5417796d-06, 2.6919786d-06 /
      data fpp(13,14,17,1),fpp(13,14,17,2),fpp(13,14,17,3)/
     x 1.4629643d-02,-6.5504798d-06, 1.0599857d-06 /
      data fpp(13,14,18,1),fpp(13,14,18,2),fpp(13,14,18,3)/
     x 1.5545220d-02,-7.3377697d-06,-1.0219213d-06 /
      data fpp(13,14,19,1),fpp(13,14,19,2),fpp(13,14,19,3)/
     x 1.6546859d-02,-7.9124682d-06,-2.8523003d-06 /
      data fpp(13,14,20,1),fpp(13,14,20,2),fpp(13,14,20,3)/
     x 1.7431198d-02,-8.1971220d-06,-4.1408773d-06 /
      data fpp(13,14,21,1),fpp(13,14,21,2),fpp(13,14,21,3)/
     x 1.7431198d-02,-8.1971220d-06,-4.1992179d-06 /
      data fpp(13,14,22,1),fpp(13,14,22,2),fpp(13,14,22,3)/
     x 1.6546859d-02,-7.9124682d-06,-2.6189377d-06 /
      data fpp(13,14,23,1),fpp(13,14,23,2),fpp(13,14,23,3)/
     x 1.5545220d-02,-7.3377697d-06,-1.8970311d-06 /
      data fpp(13,15, 1,1),fpp(13,15, 1,2),fpp(13,15, 1,3)/
     x-1.0117353d-01, 5.8946546d-05, 4.6397931d-05 /
      data fpp(13,15, 2,1),fpp(13,15, 2,2),fpp(13,15, 2,3)/
     x-6.7010889d-02, 7.6087551d-05, 3.4081137d-05 /
      data fpp(13,15, 3,1),fpp(13,15, 3,2),fpp(13,15, 3,3)/
     x-2.6879713d-02, 9.9986902d-05, 8.1975196d-06 /
      data fpp(13,15, 4,1),fpp(13,15, 4,2),fpp(13,15, 4,3)/
     x-2.6879713d-02, 9.9986902d-05, 7.3058725d-06 /
      data fpp(13,15, 5,1),fpp(13,15, 5,2),fpp(13,15, 5,3)/
     x-6.7010889d-02, 7.6087551d-05, 3.7647726d-05 /
      data fpp(13,15, 6,1),fpp(13,15, 6,2),fpp(13,15, 6,3)/
     x-1.0117353d-01, 5.8946546d-05, 3.3023224d-05 /
      data fpp(13,15, 7,1),fpp(13,15, 7,2),fpp(13,15, 7,3)/
     x-1.0775956d-01, 4.2379762d-05, 9.2153789d-06 /
      data fpp(13,15, 8,1),fpp(13,15, 8,2),fpp(13,15, 8,3)/
     x-8.6011086d-02, 4.2166178d-05,-2.1818739d-05 /
      data fpp(13,15, 9,1),fpp(13,15, 9,2),fpp(13,15, 9,3)/
     x-4.5029582d-02,-1.2598377d-04,-3.5928421d-05 /
      data fpp(13,15,10,1),fpp(13,15,10,2),fpp(13,15,10,3)/
     x-5.1756730d-03, 1.7991654d-05,-2.1049576d-05 /
      data fpp(13,15,11,1),fpp(13,15,11,2),fpp(13,15,11,3)/
     x 8.9541456d-03, 9.3586414d-06,-9.3292749d-06 /
      data fpp(13,15,12,1),fpp(13,15,12,2),fpp(13,15,12,3)/
     x 1.2563806d-02, 4.7536367d-06,-2.8873246d-06 /
      data fpp(13,15,13,1),fpp(13,15,13,2),fpp(13,15,13,3)/
     x 1.3241283d-02, 2.0787108d-06, 4.0657308d-07 /
      data fpp(13,15,14,1),fpp(13,15,14,2),fpp(13,15,14,3)/
     x 1.3343754d-02, 3.5195969d-07, 1.8490323d-06 /
      data fpp(13,15,15,1),fpp(13,15,15,2),fpp(13,15,15,3)/
     x 1.3573884d-02,-8.4520969d-07, 2.1692979d-06 /
      data fpp(13,15,16,1),fpp(13,15,16,2),fpp(13,15,16,3)/
     x 1.4073532d-02,-1.6721806d-06, 1.6657761d-06 /
      data fpp(13,15,17,1),fpp(13,15,17,2),fpp(13,15,17,3)/
     x 1.4692711d-02,-2.1277526d-06, 5.8759769d-07 /
      data fpp(13,15,18,1),fpp(13,15,18,2),fpp(13,15,18,3)/
     x 1.5352695d-02,-2.2976253d-06,-7.7616687d-07 /
      data fpp(13,15,19,1),fpp(13,15,19,2),fpp(13,15,19,3)/
     x 1.5958921d-02,-2.2469160d-06,-1.9529302d-06 /
      data fpp(13,15,20,1),fpp(13,15,20,2),fpp(13,15,20,3)/
     x 1.6350472d-02,-2.0846303d-06,-2.7101122d-06 /
      data fpp(13,15,21,1),fpp(13,15,21,2),fpp(13,15,21,3)/
     x 1.6350472d-02,-2.0846303d-06,-2.7491982d-06 /
      data fpp(13,15,22,1),fpp(13,15,22,2),fpp(13,15,22,3)/
     x 1.5958921d-02,-2.2469160d-06,-1.7965862d-06 /
      data fpp(13,15,23,1),fpp(13,15,23,2),fpp(13,15,23,3)/
     x 1.5352695d-02,-2.2976253d-06,-1.3624569d-06 /
      data fpp(13,16, 1,1),fpp(13,16, 1,2),fpp(13,16, 1,3)/
     x-6.7636041d-02, 1.2616030d-04, 2.0670995d-05 /
      data fpp(13,16, 2,1),fpp(13,16, 2,2),fpp(13,16, 2,3)/
     x-7.1103605d-02, 1.3671697d-04, 2.0668510d-05 /
      data fpp(13,16, 3,1),fpp(13,16, 3,2),fpp(13,16, 3,3)/
     x-6.0144593d-02, 1.5513024d-04, 2.1436965d-05 /
      data fpp(13,16, 4,1),fpp(13,16, 4,2),fpp(13,16, 4,3)/
     x-6.0144593d-02, 1.5513024d-04, 2.0082849d-05 /
      data fpp(13,16, 5,1),fpp(13,16, 5,2),fpp(13,16, 5,3)/
     x-7.1103605d-02, 1.3671697d-04, 2.6084975d-05 /
      data fpp(13,16, 6,1),fpp(13,16, 6,2),fpp(13,16, 6,3)/
     x-6.7636041d-02, 1.2616030d-04, 3.5924922d-07 /
      data fpp(13,16, 7,1),fpp(13,16, 7,2),fpp(13,16, 7,3)/
     x-1.7302855d-01, 1.3359446d-04, 4.2516028d-05 /
      data fpp(13,16, 8,1),fpp(13,16, 8,2),fpp(13,16, 8,3)/
     x-1.0433779d-01, 6.7909107d-05,-1.8324536d-04 /
      data fpp(13,16, 9,1),fpp(13,16, 9,2),fpp(13,16, 9,3)/
     x 2.4788816d+00, 2.6830759d-04, 2.2236341d-04 /
      data fpp(13,16,10,1),fpp(13,16,10,2),fpp(13,16,10,3)/
     x-6.4344039d-03, 9.9710619d-06,-1.6832629d-04 /
      data fpp(13,16,11,1),fpp(13,16,11,2),fpp(13,16,11,3)/
     x 7.7317689d-03, 8.0972095d-06, 3.8495735d-05 /
      data fpp(13,16,12,1),fpp(13,16,12,2),fpp(13,16,12,3)/
     x 1.1818266d-02, 6.2238397d-06,-1.2368655d-05 /
      data fpp(13,16,13,1),fpp(13,16,13,2),fpp(13,16,13,3)/
     x 1.2992481d-02, 4.6366445d-06, 3.6108831d-06 /
      data fpp(13,16,14,1),fpp(13,16,14,2),fpp(13,16,14,3)/
     x 1.3364780d-02, 3.5774026d-06, 4.2712223d-07 /
      data fpp(13,16,15,1),fpp(13,16,15,2),fpp(13,16,15,3)/
     x 1.3640237d-02, 3.0676954d-06, 1.5566280d-06 /
      data fpp(13,16,16,1),fpp(13,16,16,2),fpp(13,16,16,3)/
     x 1.3929200d-02, 3.0685020d-06, 9.4236587d-07 /
      data fpp(13,16,17,1),fpp(13,16,17,2),fpp(13,16,17,3)/
     x 1.4286543d-02, 3.4634904d-06, 3.9790854d-07 /
      data fpp(13,16,18,1),fpp(13,16,18,2),fpp(13,16,18,3)/
     x 1.4650365d-02, 4.1082707d-06,-3.5000003d-07 /
      data fpp(13,16,19,1),fpp(13,16,19,2),fpp(13,16,19,3)/
     x 1.5025246d-02, 4.7681321d-06,-9.4790841d-07 /
      data fpp(13,16,20,1),fpp(13,16,20,2),fpp(13,16,20,3)/
     x 1.5154793d-02, 5.1836432d-06,-1.3903663d-06 /
      data fpp(13,16,21,1),fpp(13,16,21,2),fpp(13,16,21,3)/
     x 1.5154793d-02, 5.1836432d-06,-1.4089468d-06 /
      data fpp(13,16,22,1),fpp(13,16,22,2),fpp(13,16,22,3)/
     x 1.5025246d-02, 4.7681321d-06,-8.7358663d-07 /
      data fpp(13,16,23,1),fpp(13,16,23,2),fpp(13,16,23,3)/
     x 1.4650365d-02, 4.1082707d-06,-6.2870668d-07 /
      data fpp(13,17, 1,1),fpp(13,17, 1,2),fpp(13,17, 1,3)/
     x-1.6626358d-01,-1.4392973d-04, 1.0926484d-05 /
      data fpp(13,17, 2,1),fpp(13,17, 2,2),fpp(13,17, 2,3)/
     x-1.2065880d-01,-8.7869414d-05, 1.2789031d-05 /
      data fpp(13,17, 3,1),fpp(13,17, 3,2),fpp(13,17, 3,3)/
     x-7.1874402d-02,-5.0073873d-05, 1.6481391d-05 /
      data fpp(13,17, 4,1),fpp(13,17, 4,2),fpp(13,17, 4,3)/
     x-7.1874402d-02,-5.0073873d-05, 1.7004312d-05 /
      data fpp(13,17, 5,1),fpp(13,17, 5,2),fpp(13,17, 5,3)/
     x-1.2065880d-01,-8.7869414d-05, 1.0697346d-05 /
      data fpp(13,17, 6,1),fpp(13,17, 6,2),fpp(13,17, 6,3)/
     x-1.6626358d-01,-1.4392973d-04, 1.8770305d-05 /
      data fpp(13,17, 7,1),fpp(13,17, 7,2),fpp(13,17, 7,3)/
     x-4.7523471d-01,-2.0488358d-04,-5.7014567d-05 /
      data fpp(13,17, 8,1),fpp(13,17, 8,2),fpp(13,17, 8,3)/
     x-4.8430100d-01,-1.3011261d-04,-4.8220375d-06 /
      data fpp(13,17, 9,1),fpp(13,17, 9,2),fpp(13,17, 9,3)/
     x-2.3331216d-02,-2.0424858d-04, 1.5787169d-06 /
      data fpp(13,17,10,1),fpp(13,17,10,2),fpp(13,17,10,3)/
     x 3.5379211d-03,-1.6247901d-05, 1.7516985d-07 /
      data fpp(13,17,11,1),fpp(13,17,11,2),fpp(13,17,11,3)/
     x 9.7186238d-03,-2.9454795d-06, 8.2860369d-07 /
      data fpp(13,17,12,1),fpp(13,17,12,2),fpp(13,17,12,3)/
     x 1.1993275d-02, 2.8950047d-06, 9.0841538d-07 /
      data fpp(13,17,13,1),fpp(13,17,13,2),fpp(13,17,13,3)/
     x 1.2900783d-02, 5.4387111d-06, 1.0517348d-06 /
      data fpp(13,17,14,1),fpp(13,17,14,2),fpp(13,17,14,3)/
     x 1.3275918d-02, 6.6624301d-06, 1.0406455d-06 /
      data fpp(13,17,15,1),fpp(13,17,15,2),fpp(13,17,15,3)/
     x 1.3526810d-02, 7.5224282d-06, 9.2968313d-07 /
      data fpp(13,17,16,1),fpp(13,17,16,2),fpp(13,17,16,3)/
     x 1.3682134d-02, 8.4241725d-06, 6.9462196d-07 /
      data fpp(13,17,17,1),fpp(13,17,17,2),fpp(13,17,17,3)/
     x 1.3866396d-02, 9.4657910d-06, 4.0782902d-07 /
      data fpp(13,17,18,1),fpp(13,17,18,2),fpp(13,17,18,3)/
     x 1.4053946d-02, 1.0530543d-05, 1.1006197d-07 /
      data fpp(13,17,19,1),fpp(13,17,19,2),fpp(13,17,19,3)/
     x 1.4039955d-02, 1.1428388d-05,-1.6407690d-07 /
      data fpp(13,17,20,1),fpp(13,17,20,2),fpp(13,17,20,3)/
     x 1.4267879d-02, 1.2064058d-05,-3.4775436d-07 /
      data fpp(13,17,21,1),fpp(13,17,21,2),fpp(13,17,21,3)/
     x 1.4267879d-02, 1.2064058d-05,-3.5669847d-07 /
      data fpp(13,17,22,1),fpp(13,17,22,2),fpp(13,17,22,3)/
     x 1.4039955d-02, 1.1428388d-05,-1.2830044d-07 /
      data fpp(13,17,23,1),fpp(13,17,23,2),fpp(13,17,23,3)/
     x 1.4053946d-02, 1.0530543d-05,-2.4099782d-08 /
      data fpp(13,18, 1,1),fpp(13,18, 1,2),fpp(13,18, 1,3)/
     x-5.3380158d-02,-9.7473362d-05,-1.2861513d-06 /
      data fpp(13,18, 2,1),fpp(13,18, 2,2),fpp(13,18, 2,3)/
     x 6.1561620d-02,-1.5636931d-04,-1.9551974d-06 /
      data fpp(13,18, 3,1),fpp(13,18, 3,2),fpp(13,18, 3,3)/
     x 1.8129297d-01,-1.9491875d-04,-3.4030592d-06 /
      data fpp(13,18, 4,1),fpp(13,18, 4,2),fpp(13,18, 4,3)/
     x 1.8129297d-01,-1.9491875d-04,-3.3782237d-06 /
      data fpp(13,18, 5,1),fpp(13,18, 5,2),fpp(13,18, 5,3)/
     x 6.1561620d-02,-1.5636931d-04,-2.0545392d-06 /
      data fpp(13,18, 6,1),fpp(13,18, 6,2),fpp(13,18, 6,3)/
     x-5.3380158d-02,-9.7473362d-05,-9.1361944d-07 /
      data fpp(13,18, 7,1),fpp(13,18, 7,2),fpp(13,18, 7,3)/
     x 1.4080509d-02,-3.0166119d-05, 2.7016958d-08 /
      data fpp(13,18, 8,1),fpp(13,18, 8,2),fpp(13,18, 8,3)/
     x 1.6046136d-02,-1.7474684d-05, 5.7155161d-07 /
      data fpp(13,18, 9,1),fpp(13,18, 9,2),fpp(13,18, 9,3)/
     x 1.1280373d-02, 9.2387375d-06, 8.1877661d-07 /
      data fpp(13,18,10,1),fpp(13,18,10,2),fpp(13,18,10,3)/
     x 1.2898402d-02,-1.4567457d-05, 8.9934194d-07 /
      data fpp(13,18,11,1),fpp(13,18,11,2),fpp(13,18,11,3)/
     x 1.3176809d-02,-9.3952916d-06, 8.9385564d-07 /
      data fpp(13,18,12,1),fpp(13,18,12,2),fpp(13,18,12,3)/
     x 1.3244452d-02,-4.5678585d-06, 8.4123549d-07 /
      data fpp(13,18,13,1),fpp(13,18,13,2),fpp(13,18,13,3)/
     x 1.3430441d-02,-1.9548888d-07, 7.8120241d-07 /
      data fpp(13,18,14,1),fpp(13,18,14,2),fpp(13,18,14,3)/
     x 1.3487853d-02, 3.7808771d-06, 6.9595487d-07 /
      data fpp(13,18,15,1),fpp(13,18,15,2),fpp(13,18,15,3)/
     x 1.3552412d-02, 7.4325920d-06, 6.1697813d-07 /
      data fpp(13,18,16,1),fpp(13,18,16,2),fpp(13,18,16,3)/
     x 1.3527952d-02, 1.0772808d-05, 5.1413263d-07 /
      data fpp(13,18,17,1),fpp(13,18,17,2),fpp(13,18,17,3)/
     x 1.3597926d-02, 1.3753345d-05, 4.2849135d-07 /
      data fpp(13,18,18,1),fpp(13,18,18,2),fpp(13,18,18,3)/
     x 1.3649395d-02, 1.6271559d-05, 3.3990198d-07 /
      data fpp(13,18,19,1),fpp(13,18,19,2),fpp(13,18,19,3)/
     x 1.3626237d-02, 1.8200318d-05, 2.8790072d-07 /
      data fpp(13,18,20,1),fpp(13,18,20,2),fpp(13,18,20,3)/
     x 1.3703975d-02, 1.9388126d-05, 2.1849515d-07 /
      data fpp(13,18,21,1),fpp(13,18,21,2),fpp(13,18,21,3)/
     x 1.3703975d-02, 1.9388126d-05, 2.1756420d-07 /
      data fpp(13,18,22,1),fpp(13,18,22,2),fpp(13,18,22,3)/
     x 1.3626237d-02, 1.8200318d-05, 2.9162451d-07 /
      data fpp(13,18,23,1),fpp(13,18,23,2),fpp(13,18,23,3)/
     x 1.3649395d-02, 1.6271559d-05, 3.2593774d-07 /
      data fpp(13,19, 1,1),fpp(13,19, 1,2),fpp(13,19, 1,3)/
     x 1.4183890d-02,-1.4145882d-04, 5.3467081d-21 /
      data fpp(13,19, 2,1),fpp(13,19, 2,2),fpp(13,19, 2,3)/
     x 1.4183890d-02,-2.6946534d-04,-2.4072433d-20 /
      data fpp(13,19, 3,1),fpp(13,19, 3,2),fpp(13,19, 3,3)/
     x 1.4183890d-02,-3.5700912d-04,-1.5563704d-20 /
      data fpp(13,19, 4,1),fpp(13,19, 4,2),fpp(13,19, 4,3)/
     x 1.4183890d-02,-3.5700912d-04, 1.8837208d-20 /
      data fpp(13,19, 5,1),fpp(13,19, 5,2),fpp(13,19, 5,3)/
     x 1.4183890d-02,-2.6946534d-04,-1.5394838d-20 /
      data fpp(13,19, 6,1),fpp(13,19, 6,2),fpp(13,19, 6,3)/
     x 1.4183890d-02,-1.4145882d-04,-1.7571114d-20 /
      data fpp(13,19, 7,1),fpp(13,19, 7,2),fpp(13,19, 7,3)/
     x 1.4183890d-02,-2.0759406d-06,-3.4607213d-20 /
      data fpp(13,19, 8,1),fpp(13,19, 8,2),fpp(13,19, 8,3)/
     x 1.4183890d-02, 6.4033420d-06,-3.7063401d-20 /
      data fpp(13,19, 9,1),fpp(13,19, 9,2),fpp(13,19, 9,3)/
     x 1.4183890d-02, 2.6713631d-05,-1.3355610d-20 /
      data fpp(13,19,10,1),fpp(13,19,10,2),fpp(13,19,10,3)/
     x 1.4183890d-02,-2.0858272d-05, 2.1986806d-20 /
      data fpp(13,19,11,1),fpp(13,19,11,2),fpp(13,19,11,3)/
     x 1.4183890d-02,-1.7157354d-05,-3.6497231d-20 /
      data fpp(13,19,12,1),fpp(13,19,12,2),fpp(13,19,12,3)/
     x 1.4183890d-02,-1.0849571d-05, 1.2874019d-20 /
      data fpp(13,19,13,1),fpp(13,19,13,2),fpp(13,19,13,3)/
     x 1.4183890d-02,-3.9907556d-06, 5.7937224d-21 /
      data fpp(13,19,14,1),fpp(13,19,14,2),fpp(13,19,14,3)/
     x 1.4183890d-02, 2.6040614d-06, 1.3833711d-20 /
      data fpp(13,19,15,1),fpp(13,19,15,2),fpp(13,19,15,3)/
     x 1.4183890d-02, 8.6412040d-06,-1.4987787d-20 /
      data fpp(13,19,16,1),fpp(13,19,16,2),fpp(13,19,16,3)/
     x 1.4183890d-02, 1.3980596d-05,-3.3278538d-20 /
      data fpp(13,19,17,1),fpp(13,19,17,2),fpp(13,19,17,3)/
     x 1.4183890d-02, 1.8530827d-05, 1.2388735d-20 /
      data fpp(13,19,18,1),fpp(13,19,18,2),fpp(13,19,18,3)/
     x 1.4183890d-02, 2.2207220d-05,-5.9341478d-21 /
      data fpp(13,19,19,1),fpp(13,19,19,2),fpp(13,19,19,3)/
     x 1.4183890d-02, 2.4940341d-05,-3.4936745d-20 /
      data fpp(13,19,20,1),fpp(13,19,20,2),fpp(13,19,20,3)/
     x 1.4183890d-02, 2.6585437d-05, 2.0549544d-20 /
      data fpp(13,19,21,1),fpp(13,19,21,2),fpp(13,19,21,3)/
     x 1.4183890d-02, 2.6585437d-05,-1.4796109d-20 /
      data fpp(13,19,22,1),fpp(13,19,22,2),fpp(13,19,22,3)/
     x 1.4183890d-02, 2.4940341d-05, 3.8171369d-20 /
      data fpp(13,19,23,1),fpp(13,19,23,2),fpp(13,19,23,3)/
     x 1.4183890d-02, 2.2207220d-05, 6.0732197d-20 /
      data fpp(14, 1, 1,1),fpp(14, 1, 1,2),fpp(14, 1, 1,3)/
     x-4.7173740d-01, 1.4109742d-03, 1.8354534d-19 /
      data fpp(14, 1, 2,1),fpp(14, 1, 2,2),fpp(14, 1, 2,3)/
     x-4.7173740d-01, 3.6391795d-03,-2.9580386d-20 /
      data fpp(14, 1, 3,1),fpp(14, 1, 3,2),fpp(14, 1, 3,3)/
     x-4.7173740d-01, 3.4717602d-03,-8.1683083d-20 /
      data fpp(14, 1, 4,1),fpp(14, 1, 4,2),fpp(14, 1, 4,3)/
     x-4.7173740d-01, 3.4717602d-03, 1.4470278d-19 /
      data fpp(14, 1, 5,1),fpp(14, 1, 5,2),fpp(14, 1, 5,3)/
     x-4.7173740d-01, 3.6391795d-03,-2.7719120d-21 /
      data fpp(14, 1, 6,1),fpp(14, 1, 6,2),fpp(14, 1, 6,3)/
     x-4.7173740d-01, 1.4109742d-03,-1.5476965d-19 /
      data fpp(14, 1, 7,1),fpp(14, 1, 7,2),fpp(14, 1, 7,3)/
     x-4.7173740d-01, 2.1332356d-04,-1.5567644d-19 /
      data fpp(14, 1, 8,1),fpp(14, 1, 8,2),fpp(14, 1, 8,3)/
     x-4.7173740d-01,-1.7751665d-04,-4.2394868d-20 /
      data fpp(14, 1, 9,1),fpp(14, 1, 9,2),fpp(14, 1, 9,3)/
     x-4.7173740d-01,-3.7086922d-04,-4.6687609d-20 /
      data fpp(14, 1,10,1),fpp(14, 1,10,2),fpp(14, 1,10,3)/
     x-4.7173740d-01,-4.5655030d-04, 4.9731565d-20 /
      data fpp(14, 1,11,1),fpp(14, 1,11,2),fpp(14, 1,11,3)/
     x-4.7173740d-01,-4.9930099d-04,-1.2282350d-19 /
      data fpp(14, 1,12,1),fpp(14, 1,12,2),fpp(14, 1,12,3)/
     x-4.7173740d-01,-5.1497108d-04, 9.9421890d-20 /
      data fpp(14, 1,13,1),fpp(14, 1,13,2),fpp(14, 1,13,3)/
     x-4.7173740d-01,-5.0636086d-04, 2.1690151d-19 /
      data fpp(14, 1,14,1),fpp(14, 1,14,2),fpp(14, 1,14,3)/
     x-4.7173740d-01,-4.6956810d-04,-3.3301519d-20 /
      data fpp(14, 1,15,1),fpp(14, 1,15,2),fpp(14, 1,15,3)/
     x-4.7173740d-01,-3.8812791d-04,-1.6430347d-20 /
      data fpp(14, 1,16,1),fpp(14, 1,16,2),fpp(14, 1,16,3)/
     x-4.7173740d-01,-2.0004485d-04, 1.3230255d-19 /
      data fpp(14, 1,17,1),fpp(14, 1,17,2),fpp(14, 1,17,3)/
     x-4.7173740d-01, 1.9393260d-04, 3.2191217d-19 /
      data fpp(14, 1,18,1),fpp(14, 1,18,2),fpp(14, 1,18,3)/
     x-4.7173740d-01, 1.3877369d-03,-3.9830047d-20 /
      data fpp(14, 1,19,1),fpp(14, 1,19,2),fpp(14, 1,19,3)/
     x-4.7173740d-01, 3.5267394d-03,-2.1737845d-19 /
      data fpp(14, 1,20,1),fpp(14, 1,20,2),fpp(14, 1,20,3)/
     x-4.7173740d-01, 3.3626378d-03, 6.5227727d-20 /
      data fpp(14, 1,21,1),fpp(14, 1,21,2),fpp(14, 1,21,3)/
     x-4.7173740d-01, 3.3626378d-03,-1.0580280d-19 /
      data fpp(14, 1,22,1),fpp(14, 1,22,2),fpp(14, 1,22,3)/
     x-4.7173740d-01, 3.5267394d-03, 6.8166883d-20 /
      data fpp(14, 1,23,1),fpp(14, 1,23,2),fpp(14, 1,23,3)/
     x-4.7173740d-01, 1.3877369d-03, 6.2133936d-19 /
      data fpp(14, 2, 1,1),fpp(14, 2, 1,2),fpp(14, 2, 1,3)/
     x 4.0262330d-01, 5.8345958d-04,-4.7907499d-06 /
      data fpp(14, 2, 2,1),fpp(14, 2, 2,2),fpp(14, 2, 2,3)/
     x 4.2080268d-01, 1.4144820d-03,-2.1075500d-05 /
      data fpp(14, 2, 3,1),fpp(14, 2, 3,2),fpp(14, 2, 3,3)/
     x 4.2181432d-01, 1.3204616d-03,-5.6155249d-05 /
      data fpp(14, 2, 4,1),fpp(14, 2, 4,2),fpp(14, 2, 4,3)/
     x 4.2181432d-01, 1.3204616d-03,-5.5833503d-05 /
      data fpp(14, 2, 5,1),fpp(14, 2, 5,2),fpp(14, 2, 5,3)/
     x 4.2080268d-01, 1.4144820d-03,-2.2362487d-05 /
      data fpp(14, 2, 6,1),fpp(14, 2, 6,2),fpp(14, 2, 6,3)/
     x 4.0262330d-01, 5.8345958d-04, 3.5449004d-08 /
      data fpp(14, 2, 7,1),fpp(14, 2, 7,2),fpp(14, 2, 7,3)/
     x 3.8017868d-01, 1.2037787d-04, 1.1510691d-05 /
      data fpp(14, 2, 8,1),fpp(14, 2, 8,2),fpp(14, 2, 8,3)/
     x 3.9142164d-01,-1.9380707d-05, 2.1757789d-05 /
      data fpp(14, 2, 9,1),fpp(14, 2, 9,2),fpp(14, 2, 9,3)/
     x 3.4305344d-01,-8.4714556d-05, 1.8590155d-05 /
      data fpp(14, 2,10,1),fpp(14, 2,10,2),fpp(14, 2,10,3)/
     x 3.3744347d-01,-1.0927640d-04, 2.2081591d-05 /
      data fpp(14, 2,11,1),fpp(14, 2,11,2),fpp(14, 2,11,3)/
     x 1.8130574d-01,-1.2054602d-04, 2.2245480d-05 /
      data fpp(14, 2,12,1),fpp(14, 2,12,2),fpp(14, 2,12,3)/
     x 2.1435154d-01,-1.2560385d-04, 2.3012487d-05 /
      data fpp(14, 2,13,1),fpp(14, 2,13,2),fpp(14, 2,13,3)/
     x 3.6298391d-01,-1.2581428d-04, 2.2438570d-05 /
      data fpp(14, 2,14,1),fpp(14, 2,14,2),fpp(14, 2,14,3)/
     x 3.3610410d-01,-1.1930480d-04, 2.1861232d-05 /
      data fpp(14, 2,15,1),fpp(14, 2,15,2),fpp(14, 2,15,3)/
     x 3.4380913d-01,-9.8703187d-05, 2.0514502d-05 /
      data fpp(14, 2,16,1),fpp(14, 2,16,2),fpp(14, 2,16,3)/
     x 3.5928558d-01,-3.7758302d-05, 1.8594760d-05 /
      data fpp(14, 2,17,1),fpp(14, 2,17,2),fpp(14, 2,17,3)/
     x 3.7904354d-01, 1.0217981d-04, 1.3136456d-05 /
      data fpp(14, 2,18,1),fpp(14, 2,18,2),fpp(14, 2,18,3)/
     x 4.0276918d-01, 5.6375825d-04,-8.9258602d-07 /
      data fpp(14, 2,19,1),fpp(14, 2,19,2),fpp(14, 2,19,3)/
     x 4.1659719d-01, 1.3613712d-03,-2.3234112d-05 /
      data fpp(14, 2,20,1),fpp(14, 2,20,2),fpp(14, 2,20,3)/
     x 4.1552478d-01, 1.2797183d-03,-5.6884965d-05 /
      data fpp(14, 2,21,1),fpp(14, 2,21,2),fpp(14, 2,21,3)/
     x 4.1552478d-01, 1.2797183d-03,-5.7200050d-05 /
      data fpp(14, 2,22,1),fpp(14, 2,22,2),fpp(14, 2,22,3)/
     x 4.1659719d-01, 1.3613712d-03,-2.1973771d-05 /
      data fpp(14, 2,23,1),fpp(14, 2,23,2),fpp(14, 2,23,3)/
     x 4.0276918d-01, 5.6375825d-04,-5.6188643d-06 /
      data fpp(14, 3, 1,1),fpp(14, 3, 1,2),fpp(14, 3, 1,3)/
     x 3.0374360d-01,-1.1504365d-03,-1.2843052d-03 /
      data fpp(14, 3, 2,1),fpp(14, 3, 2,2),fpp(14, 3, 2,3)/
     x-4.1028722d+00,-2.2780974d-03,-8.6169650d-04 /
      data fpp(14, 3, 3,1),fpp(14, 3, 3,2),fpp(14, 3, 3,3)/
     x-1.8668108d-02,-1.7897067d-03,-3.9148737d-05 /
      data fpp(14, 3, 4,1),fpp(14, 3, 4,2),fpp(14, 3, 4,3)/
     x-1.8668108d-02,-1.7897067d-03, 1.0617546d-04 /
      data fpp(14, 3, 5,1),fpp(14, 3, 5,2),fpp(14, 3, 5,3)/
     x-4.1028722d+00,-2.2780974d-03,-1.4429933d-03 /
      data fpp(14, 3, 6,1),fpp(14, 3, 6,2),fpp(14, 3, 6,3)/
     x 3.0374360d-01,-1.1504365d-03, 8.9555775d-04 /
      data fpp(14, 3, 7,1),fpp(14, 3, 7,2),fpp(14, 3, 7,3)/
     x 1.7513145d-01,-2.0328506d-04, 1.6115031d-04 /
      data fpp(14, 3, 8,1),fpp(14, 3, 8,2),fpp(14, 3, 8,3)/
     x 1.7175337d-01, 1.3763147d-04, 8.9380997d-05 /
      data fpp(14, 3, 9,1),fpp(14, 3, 9,2),fpp(14, 3, 9,3)/
     x 1.1264885d-01, 3.3448145d-04, 6.6709699d-05 /
      data fpp(14, 3,10,1),fpp(14, 3,10,2),fpp(14, 3,10,3)/
     x 1.0258280d-01, 4.2852989d-04, 4.8138207d-05 /
      data fpp(14, 3,11,1),fpp(14, 3,11,2),fpp(14, 3,11,3)/
     x 9.5334158d-02, 4.7525308d-04, 4.7835471d-05 /
      data fpp(14, 3,12,1),fpp(14, 3,12,2),fpp(14, 3,12,3)/
     x 9.3937590d-02, 4.8878647d-04, 4.7409907d-05 /
      data fpp(14, 3,13,1),fpp(14, 3,13,2),fpp(14, 3,13,3)/
     x 9.6079337d-02, 4.7118997d-04, 4.8532900d-05 /
      data fpp(14, 3,14,1),fpp(14, 3,14,2),fpp(14, 3,14,3)/
     x 1.0131916d-01, 4.2004130d-04, 4.9224493d-05 /
      data fpp(14, 3,15,1),fpp(14, 3,15,2),fpp(14, 3,15,3)/
     x 2.8603393d-01, 3.2155865d-04, 6.9047130d-05 /
      data fpp(14, 3,16,1),fpp(14, 3,16,2),fpp(14, 3,16,3)/
     x 1.8029246d-01, 1.2347406d-04, 8.8028989d-05 /
      data fpp(14, 3,17,1),fpp(14, 3,17,2),fpp(14, 3,17,3)/
     x 1.7262299d-01,-2.1797383d-04, 1.7340092d-04 /
      data fpp(14, 3,18,1),fpp(14, 3,18,2),fpp(14, 3,18,3)/
     x 2.9921432d-01,-1.1571139d-03, 8.4755935d-04 /
      data fpp(14, 3,19,1),fpp(14, 3,19,2),fpp(14, 3,19,3)/
     x-3.6391545d+00,-2.1972404d-03,-1.4026243d-03 /
      data fpp(14, 3,20,1),fpp(14, 3,20,2),fpp(14, 3,20,3)/
     x 1.1581937d-02,-1.7790312d-03, 9.9677879d-05 /
      data fpp(14, 3,21,1),fpp(14, 3,21,2),fpp(14, 3,21,3)/
     x 1.1581937d-02,-1.7790312d-03,-4.0413483d-05 /
      data fpp(14, 3,22,1),fpp(14, 3,22,2),fpp(14, 3,22,3)/
     x-3.6391545d+00,-2.1972404d-03,-8.4225886d-04 /
      data fpp(14, 3,23,1),fpp(14, 3,23,2),fpp(14, 3,23,3)/
     x 2.9921432d-01,-1.1571139d-03,-1.2538111d-03 /
      data fpp(14, 4, 1,1),fpp(14, 4, 1,2),fpp(14, 4, 1,3)/
     x 9.9830846d-02, 2.8800252d-04,-7.8880098d-04 /
      data fpp(14, 4, 2,1),fpp(14, 4, 2,2),fpp(14, 4, 2,3)/
     x 1.2301948d+00,-8.3309036d-04,-5.9875103d-04 /
      data fpp(14, 4, 3,1),fpp(14, 4, 3,2),fpp(14, 4, 3,3)/
     x 7.5813110d-02,-1.5438307d-03,-2.6191088d-04 /
      data fpp(14, 4, 4,1),fpp(14, 4, 4,2),fpp(14, 4, 4,3)/
     x 7.5813110d-02,-1.5438307d-03,-1.3869383d-04 /
      data fpp(14, 4, 5,1),fpp(14, 4, 5,2),fpp(14, 4, 5,3)/
     x 1.2301948d+00,-8.3309036d-04,-1.0916192d-03 /
      data fpp(14, 4, 6,1),fpp(14, 4, 6,2),fpp(14, 4, 6,3)/
     x 9.9830846d-02, 2.8800252d-04, 1.0594548d-03 /
      data fpp(14, 4, 7,1),fpp(14, 4, 7,2),fpp(14, 4, 7,3)/
     x 4.1134231d-01, 2.8056235d-04,-1.7343860d-05 /
      data fpp(14, 4, 8,1),fpp(14, 4, 8,2),fpp(14, 4, 8,3)/
     x 1.2331258d-02, 2.9857681d-04, 1.2500267d-04 /
      data fpp(14, 4, 9,1),fpp(14, 4, 9,2),fpp(14, 4, 9,3)/
     x 6.0117244d-03, 2.8803277d-04, 4.0569199d-05 /
      data fpp(14, 4,10,1),fpp(14, 4,10,2),fpp(14, 4,10,3)/
     x-3.2524078d-03, 2.9947285d-04, 5.4786540d-05 /
      data fpp(14, 4,11,1),fpp(14, 4,11,2),fpp(14, 4,11,3)/
     x 1.3440493d-03, 3.1139770d-04, 4.9794643d-05 /
      data fpp(14, 4,12,1),fpp(14, 4,12,2),fpp(14, 4,12,3)/
     x 5.4179370d-03, 3.1559595d-04, 5.1464889d-05 /
      data fpp(14, 4,13,1),fpp(14, 4,13,2),fpp(14, 4,13,3)/
     x 1.9174051d-03, 3.1059239d-04, 5.0753802d-05 /
      data fpp(14, 4,14,1),fpp(14, 4,14,2),fpp(14, 4,14,3)/
     x-4.9351891d-03, 2.9759759d-04, 5.6943903d-05 /
      data fpp(14, 4,15,1),fpp(14, 4,15,2),fpp(14, 4,15,3)/
     x 6.1886639d-03, 2.8389057d-04, 4.4072587d-05 /
      data fpp(14, 4,16,1),fpp(14, 4,16,2),fpp(14, 4,16,3)/
     x 1.1853134d-02, 2.8839607d-04, 1.3128375d-04 /
      data fpp(14, 4,17,1),fpp(14, 4,17,2),fpp(14, 4,17,3)/
     x 3.1457018d-02, 2.6127551d-04,-1.4195586d-05 /
      data fpp(14, 4,18,1),fpp(14, 4,18,2),fpp(14, 4,18,3)/
     x 1.0074600d-01, 2.6114120d-04, 1.0714926d-03 /
      data fpp(14, 4,19,1),fpp(14, 4,19,2),fpp(14, 4,19,3)/
     x 7.9832814d-01,-8.7949979d-04,-1.1444968d-03 /
      data fpp(14, 4,20,1),fpp(14, 4,20,2),fpp(14, 4,20,3)/
     x 1.0693880d-01,-1.4223756d-03,-1.1746941d-04 /
      data fpp(14, 4,21,1),fpp(14, 4,21,2),fpp(14, 4,21,3)/
     x 1.0693880d-01,-1.4223756d-03,-2.4540938d-04 /
      data fpp(14, 4,22,1),fpp(14, 4,22,2),fpp(14, 4,22,3)/
     x 7.9832814d-01,-8.7949979d-04,-6.3273689d-04 /
      data fpp(14, 4,23,1),fpp(14, 4,23,2),fpp(14, 4,23,3)/
     x 1.0074600d-01, 2.6114120d-04,-8.4760705d-04 /
      data fpp(14, 5, 1,1),fpp(14, 5, 1,2),fpp(14, 5, 1,3)/
     x-2.7932061d-02, 2.9446046d-04, 1.5072200d-04 /
      data fpp(14, 5, 2,1),fpp(14, 5, 2,2),fpp(14, 5, 2,3)/
     x 3.3214437d-02, 1.5026608d-03, 3.0176499d-05 /
      data fpp(14, 5, 3,1),fpp(14, 5, 3,2),fpp(14, 5, 3,3)/
     x 6.2305297d-02, 1.6221176d-03,-2.2390200d-04 /
      data fpp(14, 5, 4,1),fpp(14, 5, 4,2),fpp(14, 5, 4,3)/
     x 6.2305297d-02, 1.6221176d-03,-2.3131026d-04 /
      data fpp(14, 5, 5,1),fpp(14, 5, 5,2),fpp(14, 5, 5,3)/
     x 3.3214437d-02, 1.5026608d-03, 5.9809561d-05 /
      data fpp(14, 5, 6,1),fpp(14, 5, 6,2),fpp(14, 5, 6,3)/
     x-2.7932061d-02, 2.9446046d-04, 3.9598017d-05 /
      data fpp(14, 5, 7,1),fpp(14, 5, 7,2),fpp(14, 5, 7,3)/
     x-2.4520473d-02, 8.9185665d-05, 4.7406370d-05 /
      data fpp(14, 5, 8,1),fpp(14, 5, 8,2),fpp(14, 5, 8,3)/
     x-1.9969834d-02, 5.7781289d-05, 4.0854504d-05 /
      data fpp(14, 5, 9,1),fpp(14, 5, 9,2),fpp(14, 5, 9,3)/
     x-1.6900776d-02, 7.7875485d-05, 4.3461615d-05 /
      data fpp(14, 5,10,1),fpp(14, 5,10,2),fpp(14, 5,10,3)/
     x-1.5095145d-02, 9.0862726d-05, 4.3101036d-05 /
      data fpp(14, 5,11,1),fpp(14, 5,11,2),fpp(14, 5,11,3)/
     x-1.4227939d-02, 9.5734136d-05, 4.2554240d-05 /
      data fpp(14, 5,12,1),fpp(14, 5,12,2),fpp(14, 5,12,3)/
     x-1.3820189d-02, 9.6643713d-05, 4.2594003d-05 /
      data fpp(14, 5,13,1),fpp(14, 5,13,2),fpp(14, 5,13,3)/
     x-1.3796974d-02, 9.5326457d-05, 4.3713748d-05 /
      data fpp(14, 5,14,1),fpp(14, 5,14,2),fpp(14, 5,14,3)/
     x-1.4224358d-02, 9.0520340d-05, 4.5627005d-05 /
      data fpp(14, 5,15,1),fpp(14, 5,15,2),fpp(14, 5,15,3)/
     x-1.5412113d-02, 7.8801068d-05, 4.7408231d-05 /
      data fpp(14, 5,16,1),fpp(14, 5,16,2),fpp(14, 5,16,3)/
     x-1.7587583d-02, 6.1859652d-05, 4.8360070d-05 /
      data fpp(14, 5,17,1),fpp(14, 5,17,2),fpp(14, 5,17,3)/
     x-2.0686683d-02, 9.5263807d-05, 5.5089490d-05 /
      data fpp(14, 5,18,1),fpp(14, 5,18,2),fpp(14, 5,18,3)/
     x-2.3801451d-02, 2.8986105d-04, 6.5523970d-05 /
      data fpp(14, 5,19,1),fpp(14, 5,19,2),fpp(14, 5,19,3)/
     x-1.3725707d-01, 1.4365615d-03, 6.5446630d-05 /
      data fpp(14, 5,20,1),fpp(14, 5,20,2),fpp(14, 5,20,3)/
     x 1.2725136d-02, 1.3868794d-03,-2.5896449d-04 /
      data fpp(14, 5,21,1),fpp(14, 5,21,2),fpp(14, 5,21,3)/
     x 1.2725136d-02, 1.3868794d-03,-2.5178184d-04 /
      data fpp(14, 5,22,1),fpp(14, 5,22,2),fpp(14, 5,22,3)/
     x-1.3725707d-01, 1.4365615d-03, 3.6716026d-05 /
      data fpp(14, 5,23,1),fpp(14, 5,23,2),fpp(14, 5,23,3)/
     x-2.3801451d-02, 2.8986105d-04, 1.7326374d-04 /
      data fpp(14, 6, 1,1),fpp(14, 6, 1,2),fpp(14, 6, 1,3)/
     x-1.8442676d-02,-7.5776338d-05, 4.5016559d-05 /
      data fpp(14, 6, 2,1),fpp(14, 6, 2,2),fpp(14, 6, 2,3)/
     x-2.1277087d-02,-3.6587104d-04,-5.1126188d-06 /
      data fpp(14, 6, 3,1),fpp(14, 6, 3,2),fpp(14, 6, 3,3)/
     x-1.4556798d-02,-3.3855375d-04,-1.1100808d-04 /
      data fpp(14, 6, 4,1),fpp(14, 6, 4,2),fpp(14, 6, 4,3)/
     x-1.4556798d-02,-3.3855375d-04,-1.1367544d-04 /
      data fpp(14, 6, 5,1),fpp(14, 6, 5,2),fpp(14, 6, 5,3)/
     x-2.1277087d-02,-3.6587104d-04, 5.5567973d-06 /
      data fpp(14, 6, 6,1),fpp(14, 6, 6,2),fpp(14, 6, 6,3)/
     x-1.8442676d-02,-7.5776338d-05, 5.0062489d-06 /
      data fpp(14, 6, 7,1),fpp(14, 6, 7,2),fpp(14, 6, 7,3)/
     x-1.6185472d-02,-2.5629007d-05, 2.0000207d-05 /
      data fpp(14, 6, 8,1),fpp(14, 6, 8,2),fpp(14, 6, 8,3)/
     x-1.5402600d-02,-1.1877965d-05, 2.4606923d-05 /
      data fpp(14, 6, 9,1),fpp(14, 6, 9,2),fpp(14, 6, 9,3)/
     x-1.5362507d-02,-1.4462706d-05, 2.8008101d-05 /
      data fpp(14, 6,10,1),fpp(14, 6,10,2),fpp(14, 6,10,3)/
     x-1.5671184d-02,-1.7977751d-05, 2.9524673d-05 /
      data fpp(14, 6,11,1),fpp(14, 6,11,2),fpp(14, 6,11,3)/
     x-1.5855106d-02,-1.9970241d-05, 3.0767205d-05 /
      data fpp(14, 6,12,1),fpp(14, 6,12,2),fpp(14, 6,12,3)/
     x-1.5836628d-02,-2.0450806d-05, 3.1738506d-05 /
      data fpp(14, 6,13,1),fpp(14, 6,13,2),fpp(14, 6,13,3)/
     x-1.5572335d-02,-1.9502223d-05, 3.2478771d-05 /
      data fpp(14, 6,14,1),fpp(14, 6,14,2),fpp(14, 6,14,3)/
     x-1.5049379d-02,-1.6508950d-05, 3.3172408d-05 /
      data fpp(14, 6,15,1),fpp(14, 6,15,2),fpp(14, 6,15,3)/
     x-1.4400130d-02,-1.0794842d-05, 3.3845596d-05 /
      data fpp(14, 6,16,1),fpp(14, 6,16,2),fpp(14, 6,16,3)/
     x-1.3786044d-02,-3.8146805d-06, 3.2757209d-05 /
      data fpp(14, 6,17,1),fpp(14, 6,17,2),fpp(14, 6,17,3)/
     x-1.3416587d-02,-8.6647352d-06, 2.9915567d-05 /
      data fpp(14, 6,18,1),fpp(14, 6,18,2),fpp(14, 6,18,3)/
     x-1.3148787d-02,-4.0501399d-05, 1.4842522d-05 /
      data fpp(14, 6,19,1),fpp(14, 6,19,2),fpp(14, 6,19,3)/
     x-1.1338432d-02,-2.8110833d-04, 7.8363458d-06 /
      data fpp(14, 6,20,1),fpp(14, 6,20,2),fpp(14, 6,20,3)/
     x 8.6054459d-05,-1.7596618d-04,-1.2754790d-04 /
      data fpp(14, 6,21,1),fpp(14, 6,21,2),fpp(14, 6,21,3)/
     x 8.6054459d-05,-1.7596618d-04,-1.2488146d-04 /
      data fpp(14, 6,22,1),fpp(14, 6,22,2),fpp(14, 6,22,3)/
     x-1.1338432d-02,-2.8110833d-04,-2.8294405d-06 /
      data fpp(14, 6,23,1),fpp(14, 6,23,2),fpp(14, 6,23,3)/
     x-1.3148787d-02,-4.0501399d-05, 5.4839220d-05 /
      data fpp(14, 7, 1,1),fpp(14, 7, 1,2),fpp(14, 7, 1,3)/
     x 1.7145770d-03, 4.6570897d-05,-7.5365607d-06 /
      data fpp(14, 7, 2,1),fpp(14, 7, 2,2),fpp(14, 7, 2,3)/
     x 7.4576541d-03, 1.8711329d-04,-1.7054879d-05 /
      data fpp(14, 7, 3,1),fpp(14, 7, 3,2),fpp(14, 7, 3,3)/
     x 1.5338374d-02, 2.5394137d-04,-3.7463925d-05 /
      data fpp(14, 7, 4,1),fpp(14, 7, 4,2),fpp(14, 7, 4,3)/
     x 1.5338374d-02, 2.5394137d-04,-3.7441787d-05 /
      data fpp(14, 7, 5,1),fpp(14, 7, 5,2),fpp(14, 7, 5,3)/
     x 7.4576541d-03, 1.8711329d-04,-1.7143431d-05 /
      data fpp(14, 7, 6,1),fpp(14, 7, 6,2),fpp(14, 7, 6,3)/
     x 1.7145770d-03, 4.6570897d-05,-7.2044875d-06 /
      data fpp(14, 7, 7,1),fpp(14, 7, 7,2),fpp(14, 7, 7,3)/
     x-2.4554954d-03,-7.7656368d-06, 8.5938146d-07 /
      data fpp(14, 7, 8,1),fpp(14, 7, 8,2),fpp(14, 7, 8,3)/
     x-6.0342364d-03,-3.6537430d-05, 6.7669616d-06 /
      data fpp(14, 7, 9,1),fpp(14, 7, 9,2),fpp(14, 7, 9,3)/
     x-8.9998721d-03,-5.0156663d-05, 1.1966772d-05 /
      data fpp(14, 7,10,1),fpp(14, 7,10,2),fpp(14, 7,10,3)/
     x-1.1200343d-02,-5.6427724d-05, 1.6411950d-05 /
      data fpp(14, 7,11,1),fpp(14, 7,11,2),fpp(14, 7,11,3)/
     x-1.2508063d-02,-5.8609171d-05, 1.9777427d-05 /
      data fpp(14, 7,12,1),fpp(14, 7,12,2),fpp(14, 7,12,3)/
     x-1.3070677d-02,-5.8352490d-05, 2.1754343d-05 /
      data fpp(14, 7,13,1),fpp(14, 7,13,2),fpp(14, 7,13,3)/
     x-1.2895217d-02,-5.6095567d-05, 2.2451200d-05 /
      data fpp(14, 7,14,1),fpp(14, 7,14,2),fpp(14, 7,14,3)/
     x-1.2056485d-02,-5.1382541d-05, 2.2162857d-05 /
      data fpp(14, 7,15,1),fpp(14, 7,15,2),fpp(14, 7,15,3)/
     x-1.0436338d-02,-4.2857701d-05, 2.1077373d-05 /
      data fpp(14, 7,16,1),fpp(14, 7,16,2),fpp(14, 7,16,3)/
     x-7.8906048d-03,-2.8120930d-05, 1.8585652d-05 /
      data fpp(14, 7,17,1),fpp(14, 7,17,2),fpp(14, 7,17,3)/
     x-5.1065400d-03,-1.3068667d-06, 1.3324018d-05 /
      data fpp(14, 7,18,1),fpp(14, 7,18,2),fpp(14, 7,18,3)/
     x-8.5476374d-04, 4.5610548d-05, 1.7502767d-06 /
      data fpp(14, 7,19,1),fpp(14, 7,19,2),fpp(14, 7,19,3)/
     x 5.0784037d-03, 1.6839380d-04,-1.5825125d-05 /
      data fpp(14, 7,20,1),fpp(14, 7,20,2),fpp(14, 7,20,3)/
     x 1.2434685d-02, 2.2038128d-04,-5.3697778d-05 /
      data fpp(14, 7,21,1),fpp(14, 7,21,2),fpp(14, 7,21,3)/
     x 1.2434685d-02, 2.2038128d-04,-5.3693103d-05 /
      data fpp(14, 7,22,1),fpp(14, 7,22,2),fpp(14, 7,22,3)/
     x 5.0784037d-03, 1.6839380d-04,-1.5843828d-05 /
      data fpp(14, 7,23,1),fpp(14, 7,23,2),fpp(14, 7,23,3)/
     x-8.5476374d-04, 4.5610548d-05, 1.8204139d-06 /
      data fpp(14, 8, 1,1),fpp(14, 8, 1,2),fpp(14, 8, 1,3)/
     x 1.0917063d-02, 6.6847497d-06,-7.6637064d-06 /
      data fpp(14, 8, 2,1),fpp(14, 8, 2,2),fpp(14, 8, 2,3)/
     x 1.4243687d-02, 1.7827865d-05,-8.9585872d-06 /
      data fpp(14, 8, 3,1),fpp(14, 8, 3,2),fpp(14, 8, 3,3)/
     x 1.1132060d+00, 9.1166262d-05,-1.1749945d-05 /
      data fpp(14, 8, 4,1),fpp(14, 8, 4,2),fpp(14, 8, 4,3)/
     x 1.1132060d+00, 9.1166262d-05,-1.1720872d-05 /
      data fpp(14, 8, 5,1),fpp(14, 8, 5,2),fpp(14, 8, 5,3)/
     x 1.4243687d-02, 1.7827865d-05,-9.0748799d-06 /
      data fpp(14, 8, 6,1),fpp(14, 8, 6,2),fpp(14, 8, 6,3)/
     x 1.0917063d-02, 6.6847497d-06,-7.2276088d-06 /
      data fpp(14, 8, 7,1),fpp(14, 8, 7,2),fpp(14, 8, 7,3)/
     x 7.4079975d-03,-1.7234446d-05,-5.7006851d-06 /
      data fpp(14, 8, 8,1),fpp(14, 8, 8,2),fpp(14, 8, 8,3)/
     x 3.7604163d-03,-3.6408316d-05,-2.9756510d-06 /
      data fpp(14, 8, 9,1),fpp(14, 8, 9,2),fpp(14, 8, 9,3)/
     x-3.9267270d-04,-4.9252644d-05, 1.5592890d-06 /
      data fpp(14, 8,10,1),fpp(14, 8,10,2),fpp(14, 8,10,3)/
     x-3.7345483d-03,-5.6401354d-05, 6.8244950d-06 /
      data fpp(14, 8,11,1),fpp(14, 8,11,2),fpp(14, 8,11,3)/
     x-6.4789815d-03,-5.9393074d-05, 1.1090731d-05 /
      data fpp(14, 8,12,1),fpp(14, 8,12,2),fpp(14, 8,12,3)/
     x-7.9619442d-03,-5.8931235d-05, 1.3750582d-05 /
      data fpp(14, 8,13,1),fpp(14, 8,13,2),fpp(14, 8,13,3)/
     x-8.2665152d-03,-5.5299510d-05, 1.4798943d-05 /
      data fpp(14, 8,14,1),fpp(14, 8,14,2),fpp(14, 8,14,3)/
     x-7.4987038d-03,-4.8620886d-05, 1.4587648d-05 /
      data fpp(14, 8,15,1),fpp(14, 8,15,2),fpp(14, 8,15,3)/
     x-5.9658320d-03,-3.8838354d-05, 1.3268465d-05 /
      data fpp(14, 8,16,1),fpp(14, 8,16,2),fpp(14, 8,16,3)/
     x-3.6379469d-03,-2.5637600d-05, 1.0674490d-05 /
      data fpp(14, 8,17,1),fpp(14, 8,17,2),fpp(14, 8,17,3)/
     x-5.6701107d-04,-9.3217980d-06, 6.3255744d-06 /
      data fpp(14, 8,18,1),fpp(14, 8,18,2),fpp(14, 8,18,3)/
     x 3.3782067d-03, 8.5032062d-06,-1.0387874d-06 /
      data fpp(14, 8,19,1),fpp(14, 8,19,2),fpp(14, 8,19,3)/
     x 8.0802747d-03, 1.0955123d-05,-1.0972425d-05 /
      data fpp(14, 8,20,1),fpp(14, 8,20,2),fpp(14, 8,20,3)/
     x 1.2613104d-02, 2.9549065d-05,-2.5499514d-05 /
      data fpp(14, 8,21,1),fpp(14, 8,21,2),fpp(14, 8,21,3)/
     x 1.2613104d-02, 2.9549065d-05,-2.5649245d-05 /
      data fpp(14, 8,22,1),fpp(14, 8,22,2),fpp(14, 8,22,3)/
     x 8.0802747d-03, 1.0955123d-05,-1.0373501d-05 /
      data fpp(14, 8,23,1),fpp(14, 8,23,2),fpp(14, 8,23,3)/
     x 3.3782067d-03, 8.5032062d-06,-3.2847493d-06 /
      data fpp(14, 9, 1,1),fpp(14, 9, 1,2),fpp(14, 9, 1,3)/
     x 1.5454299d-02,-2.3905896d-05, 9.6550695d-06 /
      data fpp(14, 9, 2,1),fpp(14, 9, 2,2),fpp(14, 9, 2,3)/
     x 3.6192872d-02,-6.3107511d-06, 2.5683609d-06 /
      data fpp(14, 9, 3,1),fpp(14, 9, 3,2),fpp(14, 9, 3,3)/
     x 2.0231353d+00,-1.5883242d-04,-1.2254513d-05 /
      data fpp(14, 9, 4,1),fpp(14, 9, 4,2),fpp(14, 9, 4,3)/
     x 2.0231353d+00,-1.5883242d-04,-1.2889641d-05 /
      data fpp(14, 9, 5,1),fpp(14, 9, 5,2),fpp(14, 9, 5,3)/
     x 3.6192872d-02,-6.3107511d-06, 5.1088708d-06 /
      data fpp(14, 9, 6,1),fpp(14, 9, 6,2),fpp(14, 9, 6,3)/
     x 1.5454299d-02,-2.3905896d-05, 1.2815751d-07 /
      data fpp(14, 9, 7,1),fpp(14, 9, 7,2),fpp(14, 9, 7,3)/
     x 1.4751127d-02,-3.2472580d-05,-3.7615008d-06 /
      data fpp(14, 9, 8,1),fpp(14, 9, 8,2),fpp(14, 9, 8,3)/
     x 1.2158450d-02,-3.7231306d-05,-5.7401542d-06 /
      data fpp(14, 9, 9,1),fpp(14, 9, 9,2),fpp(14, 9, 9,3)/
     x 8.3797897d-03,-4.0868761d-05,-3.6678826d-06 /
      data fpp(14, 9,10,1),fpp(14, 9,10,2),fpp(14, 9,10,3)/
     x 4.3760318d-03,-4.3340861d-05, 8.3368435d-07 /
      data fpp(14, 9,11,1),fpp(14, 9,11,2),fpp(14, 9,11,3)/
     x 9.0545585d-04,-4.4006532d-05, 5.3611451d-06 /
      data fpp(14, 9,12,1),fpp(14, 9,12,2),fpp(14, 9,12,3)/
     x-1.2967578d-03,-4.2786570d-05, 8.4597351d-06 /
      data fpp(14, 9,13,1),fpp(14, 9,13,2),fpp(14, 9,13,3)/
     x-2.3921914d-03,-3.9710394d-05, 9.8739145d-06 /
      data fpp(14, 9,14,1),fpp(14, 9,14,2),fpp(14, 9,14,3)/
     x-2.3618076d-03,-3.4663914d-05, 1.0004607d-05 /
      data fpp(14, 9,15,1),fpp(14, 9,15,2),fpp(14, 9,15,3)/
     x-1.4163709d-03,-2.7520882d-05, 9.0876576d-06 /
      data fpp(14, 9,16,1),fpp(14, 9,16,2),fpp(14, 9,16,3)/
     x 2.1970787d-04,-1.8278671d-05, 7.2427625d-06 /
      data fpp(14, 9,17,1),fpp(14, 9,17,2),fpp(14, 9,17,3)/
     x 2.5955452d-03,-7.0659413d-06, 4.2892924d-06 /
      data fpp(14, 9,18,1),fpp(14, 9,18,2),fpp(14, 9,18,3)/
     x 5.6238915d-03, 5.7506270d-06,-4.1193221d-07 /
      data fpp(14, 9,19,1),fpp(14, 9,19,2),fpp(14, 9,19,3)/
     x 9.1275760d-03, 2.2577704d-05,-6.3615636d-06 /
      data fpp(14, 9,20,1),fpp(14, 9,20,2),fpp(14, 9,20,3)/
     x 1.2419065d-02, 3.1190461d-05,-1.4191813d-05 /
      data fpp(14, 9,21,1),fpp(14, 9,21,2),fpp(14, 9,21,3)/
     x 1.2419065d-02, 3.1190461d-05,-1.4300778d-05 /
      data fpp(14, 9,22,1),fpp(14, 9,22,2),fpp(14, 9,22,3)/
     x 9.1275760d-03, 2.2577704d-05,-5.9257063d-06 /
      data fpp(14, 9,23,1),fpp(14, 9,23,2),fpp(14, 9,23,3)/
     x 5.6238915d-03, 5.7506270d-06,-2.0463968d-06 /
      data fpp(14,10, 1,1),fpp(14,10, 1,2),fpp(14,10, 1,3)/
     x-3.2473061d-02,-1.1226517d-04,-1.0980672d-04 /
      data fpp(14,10, 2,1),fpp(14,10, 2,2),fpp(14,10, 2,3)/
     x-5.4983826d-01,-2.1182486d-04,-5.9484568d-05 /
      data fpp(14,10, 3,1),fpp(14,10, 3,2),fpp(14,10, 3,3)/
     x-6.7790099d-02,-6.8532580d-05, 4.2920987d-05 /
      data fpp(14,10, 4,1),fpp(14,10, 4,2),fpp(14,10, 4,3)/
     x-6.7790099d-02,-6.8532580d-05, 5.2419323d-05 /
      data fpp(14,10, 5,1),fpp(14,10, 5,2),fpp(14,10, 5,3)/
     x-5.4983826d-01,-2.1182486d-04,-9.7477913d-05 /
      data fpp(14,10, 6,1),fpp(14,10, 6,2),fpp(14,10, 6,3)/
     x-3.2473061d-02,-1.1226517d-04, 3.2668330d-05 /
      data fpp(14,10, 7,1),fpp(14,10, 7,2),fpp(14,10, 7,3)/
     x 6.6994174d-03,-6.1465232d-05,-1.1211405d-05 /
      data fpp(14,10, 8,1),fpp(14,10, 8,2),fpp(14,10, 8,3)/
     x 1.4311211d-02,-4.1076461d-05,-6.5667079d-06 /
      data fpp(14,10, 9,1),fpp(14,10, 9,2),fpp(14,10, 9,3)/
     x 1.3989138d-02,-3.2750313d-05,-8.5057630d-06 /
      data fpp(14,10,10,1),fpp(14,10,10,2),fpp(14,10,10,3)/
     x 1.0959273d-02,-2.9435204d-05,-3.3062402d-06 /
      data fpp(14,10,11,1),fpp(14,10,11,2),fpp(14,10,11,3)/
     x 7.4549851d-03,-2.7890799d-05, 1.4507237d-06 /
      data fpp(14,10,12,1),fpp(14,10,12,2),fpp(14,10,12,3)/
     x 4.7729616d-03,-2.6344485d-05, 5.0393454d-06 /
      data fpp(14,10,13,1),fpp(14,10,13,2),fpp(14,10,13,3)/
     x 3.1378349d-03,-2.4130915d-05, 6.9098945d-06 /
      data fpp(14,10,14,1),fpp(14,10,14,2),fpp(14,10,14,3)/
     x 2.5321187d-03,-2.1061458d-05, 7.4910764d-06 /
      data fpp(14,10,15,1),fpp(14,10,15,2),fpp(14,10,15,3)/
     x 2.7335036d-03,-1.7092117d-05, 7.0577999d-06 /
      data fpp(14,10,16,1),fpp(14,10,16,2),fpp(14,10,16,3)/
     x 3.5636080d-03,-1.2277717d-05, 5.7977240d-06 /
      data fpp(14,10,17,1),fpp(14,10,17,2),fpp(14,10,17,3)/
     x 5.1974453d-03,-6.9284368d-06, 3.6873041d-06 /
      data fpp(14,10,18,1),fpp(14,10,18,2),fpp(14,10,18,3)/
     x 7.3859066d-03,-1.8537142d-06, 1.4105971d-07 /
      data fpp(14,10,19,1),fpp(14,10,19,2),fpp(14,10,19,3)/
     x 1.0103432d-02, 1.1900612d-06,-4.2515429d-06 /
      data fpp(14,10,20,1),fpp(14,10,20,2),fpp(14,10,20,3)/
     x 1.2806888d-02, 4.1850913d-06,-9.5708881d-06 /
      data fpp(14,10,21,1),fpp(14,10,21,2),fpp(14,10,21,3)/
     x 1.2806888d-02, 4.1850913d-06,-9.6615642d-06 /
      data fpp(14,10,22,1),fpp(14,10,22,2),fpp(14,10,22,3)/
     x 1.0103432d-02, 1.1900612d-06,-3.8888388d-06 /
      data fpp(14,10,23,1),fpp(14,10,23,2),fpp(14,10,23,3)/
     x 7.3859066d-03,-1.8537142d-06,-1.2190806d-06 /
      data fpp(14,11, 1,1),fpp(14,11, 1,2),fpp(14,11, 1,3)/
     x-1.0275782d-01, 1.4974560d-05,-3.6547056d-06 /
      data fpp(14,11, 2,1),fpp(14,11, 2,2),fpp(14,11, 2,3)/
     x-1.5725823d-01, 1.3613019d-04, 8.2809112d-06 /
      data fpp(14,11, 3,1),fpp(14,11, 3,2),fpp(14,11, 3,3)/
     x-7.2246115d-02, 1.3704274d-04, 3.4257061d-05 /
      data fpp(14,11, 4,1),fpp(14,11, 4,2),fpp(14,11, 4,3)/
     x-7.2246115d-02, 1.3704274d-04, 3.3557362d-05 /
      data fpp(14,11, 5,1),fpp(14,11, 5,2),fpp(14,11, 5,3)/
     x-1.5725823d-01, 1.3613019d-04, 1.1079706d-05 /
      data fpp(14,11, 6,1),fpp(14,11, 6,2),fpp(14,11, 6,3)/
     x-1.0275782d-01, 1.4974560d-05,-1.4150187d-05 /
      data fpp(14,11, 7,1),fpp(14,11, 7,2),fpp(14,11, 7,3)/
     x-3.2203636d-02,-2.4162490d-05,-1.6362958d-05 /
      data fpp(14,11, 8,1),fpp(14,11, 8,2),fpp(14,11, 8,3)/
     x 2.4058225d-03,-2.5952849d-05,-1.7717980d-05 /
      data fpp(14,11, 9,1),fpp(14,11, 9,2),fpp(14,11, 9,3)/
     x 1.2721526d-02,-2.1713986d-05,-1.5443120d-05 /
      data fpp(14,11,10,1),fpp(14,11,10,2),fpp(14,11,10,3)/
     x 1.3655216d-02,-1.8582325d-05,-8.7095394d-06 /
      data fpp(14,11,11,1),fpp(14,11,11,2),fpp(14,11,11,3)/
     x 1.1431746d-02,-1.6882271d-05,-2.0147223d-06 /
      data fpp(14,11,12,1),fpp(14,11,12,2),fpp(14,11,12,3)/
     x 8.9418895d-03,-1.5743489d-05, 2.4344286d-06 /
      data fpp(14,11,13,1),fpp(14,11,13,2),fpp(14,11,13,3)/
     x 7.1737688d-03,-1.4449947d-05, 4.9190080d-06 /
      data fpp(14,11,14,1),fpp(14,11,14,2),fpp(14,11,14,3)/
     x 6.2952006d-03,-1.2838253d-05, 5.9815393d-06 /
      data fpp(14,11,15,1),fpp(14,11,15,2),fpp(14,11,15,3)/
     x 6.1561321d-03,-1.0976650d-05, 5.9848346d-06 /
      data fpp(14,11,16,1),fpp(14,11,16,2),fpp(14,11,16,3)/
     x 6.6526950d-03,-9.0144600d-06, 5.1011223d-06 /
      data fpp(14,11,17,1),fpp(14,11,17,2),fpp(14,11,17,3)/
     x 7.7886554d-03,-7.1603114d-06, 3.1366762d-06 /
      data fpp(14,11,18,1),fpp(14,11,18,2),fpp(14,11,18,3)/
     x 9.3525854d-03,-5.5477701d-06, 4.1730687d-09 /
      data fpp(14,11,19,1),fpp(14,11,19,2),fpp(14,11,19,3)/
     x 1.1379760d-02,-4.0339488d-06,-3.6453684d-06 /
      data fpp(14,11,20,1),fpp(14,11,20,2),fpp(14,11,20,3)/
     x 1.3717257d-02,-3.2908262d-06,-7.4246994d-06 /
      data fpp(14,11,21,1),fpp(14,11,21,2),fpp(14,11,21,3)/
     x 1.3717257d-02,-3.2908262d-06,-7.5142177d-06 /
      data fpp(14,11,22,1),fpp(14,11,22,2),fpp(14,11,22,3)/
     x 1.1379760d-02,-4.0339488d-06,-3.2872949d-06 /
      data fpp(14,11,23,1),fpp(14,11,23,2),fpp(14,11,23,3)/
     x 9.3525854d-03,-5.5477701d-06,-1.3386025d-06 /
      data fpp(14,12, 1,1),fpp(14,12, 1,2),fpp(14,12, 1,3)/
     x-1.1779240d-01, 5.6212928d-05, 5.3753561d-05 /
      data fpp(14,12, 2,1),fpp(14,12, 2,2),fpp(14,12, 2,3)/
     x-1.2890150d-01, 6.4480094d-05, 3.8261878d-05 /
      data fpp(14,12, 3,1),fpp(14,12, 3,2),fpp(14,12, 3,3)/
     x-6.9975938d-02, 9.1783622d-05, 6.3909259d-06 /
      data fpp(14,12, 4,1),fpp(14,12, 4,2),fpp(14,12, 4,3)/
     x-6.9975938d-02, 9.1783622d-05, 4.0712830d-06 /
      data fpp(14,12, 5,1),fpp(14,12, 5,2),fpp(14,12, 5,3)/
     x-1.2890150d-01, 6.4480094d-05, 4.7540450d-05 /
      data fpp(14,12, 6,1),fpp(14,12, 6,2),fpp(14,12, 6,3)/
     x-1.1779240d-01, 5.6212928d-05, 1.8958917d-05 /
      data fpp(14,12, 7,1),fpp(14,12, 7,2),fpp(14,12, 7,3)/
     x-6.4677644d-02, 2.6835192d-05,-1.0924118d-05 /
      data fpp(14,12, 8,1),fpp(14,12, 8,2),fpp(14,12, 8,3)/
     x-1.8358592d-02, 4.7338568d-06,-2.4906446d-05 /
      data fpp(14,12, 9,1),fpp(14,12, 9,2),fpp(14,12, 9,3)/
     x 4.7443357d-03,-4.5937420d-06,-2.3994100d-05 /
      data fpp(14,12,10,1),fpp(14,12,10,2),fpp(14,12,10,3)/
     x 1.2195079d-02,-7.8174979d-06,-1.4957155d-05 /
      data fpp(14,12,11,1),fpp(14,12,11,2),fpp(14,12,11,3)/
     x 1.2695374d-02,-8.7701150d-06,-5.7152794d-06 /
      data fpp(14,12,12,1),fpp(14,12,12,2),fpp(14,12,12,3)/
     x 1.1224498d-02,-8.9075578d-06, 1.8627282d-07 /
      data fpp(14,12,13,1),fpp(14,12,13,2),fpp(14,12,13,3)/
     x 9.7653947d-03,-8.7352960d-06, 3.3321881d-06 /
      data fpp(14,12,14,1),fpp(14,12,14,2),fpp(14,12,14,3)/
     x 8.8994283d-03,-8.3995297d-06, 4.7909747d-06 /
      data fpp(14,12,15,1),fpp(14,12,15,2),fpp(14,12,15,3)/
     x 8.7629674d-03,-8.0912827d-06, 5.1039130d-06 /
      data fpp(14,12,16,1),fpp(14,12,16,2),fpp(14,12,16,3)/
     x 9.2592679d-03,-7.9684426d-06, 4.3793732d-06 /
      data fpp(14,12,17,1),fpp(14,12,17,2),fpp(14,12,17,3)/
     x 1.0274285d-02,-8.0623175d-06, 2.3805943d-06 /
      data fpp(14,12,18,1),fpp(14,12,18,2),fpp(14,12,18,3)/
     x 1.1463040d-02,-8.1812053d-06,-5.5175040d-07 /
      data fpp(14,12,19,1),fpp(14,12,19,2),fpp(14,12,19,3)/
     x 1.3022317d-02,-8.1902659d-06,-3.4735927d-06 /
      data fpp(14,12,20,1),fpp(14,12,20,2),fpp(14,12,20,3)/
     x 1.4909061d-02,-7.9477864d-06,-6.0018787d-06 /
      data fpp(14,12,21,1),fpp(14,12,21,2),fpp(14,12,21,3)/
     x 1.4909061d-02,-7.9477864d-06,-6.0845674d-06 /
      data fpp(14,12,22,1),fpp(14,12,22,2),fpp(14,12,22,3)/
     x 1.3022317d-02,-8.1902659d-06,-3.1428379d-06 /
      data fpp(14,12,23,1),fpp(14,12,23,2),fpp(14,12,23,3)/
     x 1.1463040d-02,-8.1812053d-06,-1.7920811d-06 /
      data fpp(14,13, 1,1),fpp(14,13, 1,2),fpp(14,13, 1,3)/
     x-1.2982774d-01, 3.9965729d-05, 9.4001946d-05 /
      data fpp(14,13, 2,1),fpp(14,13, 2,2),fpp(14,13, 2,3)/
     x-1.2158525d-01, 1.7585432d-05, 5.4928609d-05 /
      data fpp(14,13, 3,1),fpp(14,13, 3,2),fpp(14,13, 3,3)/
     x-2.3196406d-02,-3.6633229d-05,-2.6994381d-05 /
      data fpp(14,13, 4,1),fpp(14,13, 4,2),fpp(14,13, 4,3)/
     x-2.3196406d-02,-3.6633229d-05,-3.0154162d-05 /
      data fpp(14,13, 5,1),fpp(14,13, 5,2),fpp(14,13, 5,3)/
     x-1.2158525d-01, 1.7585432d-05, 6.7567733d-05 /
      data fpp(14,13, 6,1),fpp(14,13, 6,2),fpp(14,13, 6,3)/
     x-1.2982774d-01, 3.9965729d-05, 4.6605230d-05 /
      data fpp(14,13, 7,1),fpp(14,13, 7,2),fpp(14,13, 7,3)/
     x-8.8148482d-02, 3.9149722d-05, 7.1793453d-06 /
      data fpp(14,13, 8,1),fpp(14,13, 8,2),fpp(14,13, 8,3)/
     x-3.9688811d-02, 2.6703422d-05,-2.2468612d-05 /
      data fpp(14,13, 9,1),fpp(14,13, 9,2),fpp(14,13, 9,3)/
     x-6.8331947d-03, 1.2512954d-05,-2.8334899d-05 /
      data fpp(14,13,10,1),fpp(14,13,10,2),fpp(14,13,10,3)/
     x 7.9896010d-03, 3.2803163d-06,-1.9405792d-05 /
      data fpp(14,13,11,1),fpp(14,13,11,2),fpp(14,13,11,3)/
     x 1.1971769d-02,-1.4312685d-06,-8.6479326d-06 /
      data fpp(14,13,12,1),fpp(14,13,12,2),fpp(14,13,12,3)/
     x 1.1957490d-02,-3.5982795d-06,-1.6884776d-06 /
      data fpp(14,13,13,1),fpp(14,13,13,2),fpp(14,13,13,3)/
     x 1.1108867d-02,-4.6688687d-06, 1.9738429d-06 /
      data fpp(14,13,14,1),fpp(14,13,14,2),fpp(14,13,14,3)/
     x 1.0530726d-02,-5.3976282d-06, 3.6271061d-06 /
      data fpp(14,13,15,1),fpp(14,13,15,2),fpp(14,13,15,3)/
     x 1.0580417d-02,-6.0742192d-06, 4.0797326d-06 /
      data fpp(14,13,16,1),fpp(14,13,16,2),fpp(14,13,16,3)/
     x 1.1179635d-02,-6.8777695d-06, 3.4359636d-06 /
      data fpp(14,13,17,1),fpp(14,13,17,2),fpp(14,13,17,3)/
     x 1.2081032d-02,-7.7624185d-06, 1.5984131d-06 /
      data fpp(14,13,18,1),fpp(14,13,18,2),fpp(14,13,18,3)/
     x 1.3178762d-02,-8.4614087d-06,-9.3761617d-07 /
      data fpp(14,13,19,1),fpp(14,13,19,2),fpp(14,13,19,3)/
     x 1.4448061d-02,-8.7149875d-06,-3.1699485d-06 /
      data fpp(14,13,20,1),fpp(14,13,20,2),fpp(14,13,20,3)/
     x 1.5622358d-02,-8.7360283d-06,-4.8085899d-06 /
      data fpp(14,13,21,1),fpp(14,13,21,2),fpp(14,13,21,3)/
     x 1.5622358d-02,-8.7360283d-06,-4.8782560d-06 /
      data fpp(14,13,22,1),fpp(14,13,22,2),fpp(14,13,22,3)/
     x 1.4448061d-02,-8.7149875d-06,-2.8912840d-06 /
      data fpp(14,13,23,1),fpp(14,13,23,2),fpp(14,13,23,3)/
     x 1.3178762d-02,-8.4614087d-06,-1.9826080d-06 /
      data fpp(14,14, 1,1),fpp(14,14, 1,2),fpp(14,14, 1,3)/
     x-1.3111682d-01, 3.7400156d-05, 8.3208077d-05 /
      data fpp(14,14, 2,1),fpp(14,14, 2,2),fpp(14,14, 2,3)/
     x-1.1109006d-01, 1.1381789d-06, 4.7250845d-05 /
      data fpp(14,14, 3,1),fpp(14,14, 3,2),fpp(14,14, 3,3)/
     x-1.2813249d-02,-4.3362707d-05,-2.8515458d-05 /
      data fpp(14,14, 4,1),fpp(14,14, 4,2),fpp(14,14, 4,3)/
     x-1.2813249d-02,-4.3362707d-05,-3.0764048d-05 /
      data fpp(14,14, 5,1),fpp(14,14, 5,2),fpp(14,14, 5,3)/
     x-1.1109006d-01, 1.1381789d-06, 5.6245205d-05 /
      data fpp(14,14, 6,1),fpp(14,14, 6,2),fpp(14,14, 6,3)/
     x-1.3111682d-01, 3.7400156d-05, 4.9479229d-05 /
      data fpp(14,14, 7,1),fpp(14,14, 7,2),fpp(14,14, 7,3)/
     x-1.0477277d-01, 4.7421919d-05, 1.5585880d-05 /
      data fpp(14,14, 8,1),fpp(14,14, 8,2),fpp(14,14, 8,3)/
     x-6.0181245d-02, 3.5650456d-05,-1.7508748d-05 /
      data fpp(14,14, 9,1),fpp(14,14, 9,2),fpp(14,14, 9,3)/
     x-1.9839640d-02, 2.3433925d-05,-2.7714887d-05 /
      data fpp(14,14,10,1),fpp(14,14,10,2),fpp(14,14,10,3)/
     x 2.5546035d-03, 1.1988233d-05,-1.9513704d-05 /
      data fpp(14,14,11,1),fpp(14,14,11,2),fpp(14,14,11,3)/
     x 1.0108263d-02, 4.7811889d-06,-9.3102974d-06 /
      data fpp(14,14,12,1),fpp(14,14,12,2),fpp(14,14,12,3)/
     x 1.1665162d-02, 9.5067594d-07,-2.6151065d-06 /
      data fpp(14,14,13,1),fpp(14,14,13,2),fpp(14,14,13,3)/
     x 1.1581824d-02,-1.2032291d-06, 9.2472336d-07 /
      data fpp(14,14,14,1),fpp(14,14,14,2),fpp(14,14,14,3)/
     x 1.1360906d-02,-2.6379575d-06, 2.5282130d-06 /
      data fpp(14,14,15,1),fpp(14,14,15,2),fpp(14,14,15,3)/
     x 1.1589419d-02,-3.8098406d-06, 2.9304245d-06 /
      data fpp(14,14,16,1),fpp(14,14,16,2),fpp(14,14,16,3)/
     x 1.2150528d-02,-4.8284792d-06, 2.3880891d-06 /
      data fpp(14,14,17,1),fpp(14,14,17,2),fpp(14,14,17,3)/
     x 1.2997378d-02,-5.7020085d-06, 9.6321902d-07 /
      data fpp(14,14,18,1),fpp(14,14,18,2),fpp(14,14,18,3)/
     x 1.3905906d-02,-6.3991599d-06,-9.1296522d-07 /
      data fpp(14,14,19,1),fpp(14,14,19,2),fpp(14,14,19,3)/
     x 1.4765755d-02,-6.9297843d-06,-2.5973581d-06 /
      data fpp(14,14,20,1),fpp(14,14,20,2),fpp(14,14,20,3)/
     x 1.5510509d-02,-7.1781005d-06,-3.6376022d-06 /
      data fpp(14,14,21,1),fpp(14,14,21,2),fpp(14,14,21,3)/
     x 1.5510509d-02,-7.1781005d-06,-3.6945142d-06 /
      data fpp(14,14,22,1),fpp(14,14,22,2),fpp(14,14,22,3)/
     x 1.4765755d-02,-6.9297843d-06,-2.3697102d-06 /
      data fpp(14,14,23,1),fpp(14,14,23,2),fpp(14,14,23,3)/
     x 1.3905906d-02,-6.3991599d-06,-1.7666449d-06 /
      data fpp(14,15, 1,1),fpp(14,15, 1,2),fpp(14,15, 1,3)/
     x-1.2896151d-01, 4.1841646d-05, 4.0347235d-05 /
      data fpp(14,15, 2,1),fpp(14,15, 2,2),fpp(14,15, 2,3)/
     x-9.3874227d-02, 5.6203853d-05, 2.6617031d-05 /
      data fpp(14,15, 3,1),fpp(14,15, 3,2),fpp(14,15, 3,3)/
     x-5.1492519d-02, 7.9092057d-05,-2.4133584d-06 /
      data fpp(14,15, 4,1),fpp(14,15, 4,2),fpp(14,15, 4,3)/
     x-5.1492519d-02, 7.9092057d-05,-3.0984404d-06 /
      data fpp(14,15, 5,1),fpp(14,15, 5,2),fpp(14,15, 5,3)/
     x-9.3874227d-02, 5.6203853d-05, 2.9357359d-05 /
      data fpp(14,15, 6,1),fpp(14,15, 6,2),fpp(14,15, 6,3)/
     x-1.2896151d-01, 4.1841646d-05, 3.0071003d-05 /
      data fpp(14,15, 7,1),fpp(14,15, 7,2),fpp(14,15, 7,3)/
     x-1.0962894d-01, 3.6758602d-05, 9.8086274d-06 /
      data fpp(14,15, 8,1),fpp(14,15, 8,2),fpp(14,15, 8,3)/
     x-8.1217554d-02, 4.6304753d-05,-1.7705513d-05 /
      data fpp(14,15, 9,1),fpp(14,15, 9,2),fpp(14,15, 9,3)/
     x-3.2412891d-02, 2.7929346d-05,-2.3730576d-05 /
      data fpp(14,15,10,1),fpp(14,15,10,2),fpp(14,15,10,3)/
     x-2.2007398d-03, 1.5078753d-05,-1.4356182d-05 /
      data fpp(14,15,11,1),fpp(14,15,11,2),fpp(14,15,11,3)/
     x 8.1415076d-03, 8.2505129d-06,-6.9006959d-06 /
      data fpp(14,15,12,1),fpp(14,15,12,2),fpp(14,15,12,3)/
     x 1.0957397d-02, 4.3435758d-06,-2.1230345d-06 /
      data fpp(14,15,13,1),fpp(14,15,13,2),fpp(14,15,13,3)/
     x 1.1566290d-02, 1.9757851d-06, 4.7083375d-07 /
      data fpp(14,15,14,1),fpp(14,15,14,2),fpp(14,15,14,3)/
     x 1.1680134d-02, 4.0345823d-07, 1.6436995d-06 /
      data fpp(14,15,15,1),fpp(14,15,15,2),fpp(14,15,15,3)/
     x 1.1913276d-02,-6.9441840d-07, 1.9063684d-06 /
      data fpp(14,15,16,1),fpp(14,15,16,2),fpp(14,15,16,3)/
     x 1.2329344d-02,-1.4323136d-06, 1.4708270d-06 /
      data fpp(14,15,17,1),fpp(14,15,17,2),fpp(14,15,17,3)/
     x 1.2953930d-02,-1.8175474d-06, 5.3232358d-07 /
      data fpp(14,15,18,1),fpp(14,15,18,2),fpp(14,15,18,3)/
     x 1.3595265d-02,-1.9419516d-06,-6.8412134d-07 /
      data fpp(14,15,19,1),fpp(14,15,19,2),fpp(14,15,19,3)/
     x 1.4135010d-02,-1.8758755d-06,-1.7438382d-06 /
      data fpp(14,15,20,1),fpp(14,15,20,2),fpp(14,15,20,3)/
     x 1.4555820d-02,-1.7675698d-06,-2.3905258d-06 /
      data fpp(14,15,21,1),fpp(14,15,21,2),fpp(14,15,21,3)/
     x 1.4555820d-02,-1.7675698d-06,-2.4265035d-06 /
      data fpp(14,15,22,1),fpp(14,15,22,2),fpp(14,15,22,3)/
     x 1.4135010d-02,-1.8758755d-06,-1.5999276d-06 /
      data fpp(14,15,23,1),fpp(14,15,23,2),fpp(14,15,23,3)/
     x 1.3595265d-02,-1.9419516d-06,-1.2237862d-06 /
      data fpp(14,16, 1,1),fpp(14,16, 1,2),fpp(14,16, 1,3)/
     x-2.1192616d-01, 1.4649726d-04, 1.3077645d-05 /
      data fpp(14,16, 2,1),fpp(14,16, 2,2),fpp(14,16, 2,3)/
     x-7.7202008d-02, 1.5665441d-04, 1.3426210d-05 /
      data fpp(14,16, 3,1),fpp(14,16, 3,2),fpp(14,16, 3,3)/
     x-6.1494042d-02, 1.7738448d-04, 1.4763513d-05 /
      data fpp(14,16, 4,1),fpp(14,16, 4,2),fpp(14,16, 4,3)/
     x-6.1494042d-02, 1.7738448d-04, 1.3730355d-05 /
      data fpp(14,16, 5,1),fpp(14,16, 5,2),fpp(14,16, 5,3)/
     x-7.7202008d-02, 1.5665441d-04, 1.7558844d-05 /
      data fpp(14,16, 6,1),fpp(14,16, 6,2),fpp(14,16, 6,3)/
     x-2.1192616d-01, 1.4649726d-04,-2.4197308d-06 /
      data fpp(14,16, 7,1),fpp(14,16, 7,2),fpp(14,16, 7,3)/
     x 1.7100779d-02, 9.6831674d-05, 1.2640079d-05 /
      data fpp(14,16, 8,1),fpp(14,16, 8,2),fpp(14,16, 8,3)/
     x-1.4508636d-01, 1.6076530d-05,-3.3620586d-05 /
      data fpp(14,16, 9,1),fpp(14,16, 9,2),fpp(14,16, 9,3)/
     x-1.6386770d+00, 5.1406907d-06,-7.7937344d-06 /
      data fpp(14,16,10,1),fpp(14,16,10,2),fpp(14,16,10,3)/
     x-2.0762610d-03, 6.5667571d-06,-6.0584761d-06 /
      data fpp(14,16,11,1),fpp(14,16,11,2),fpp(14,16,11,3)/
     x 7.4326745d-03, 6.5867594d-06,-2.0823610d-06 /
      data fpp(14,16,12,1),fpp(14,16,12,2),fpp(14,16,12,3)/
     x 1.0401442d-02, 5.4770209d-06,-4.7407985d-07 /
      data fpp(14,16,13,1),fpp(14,16,13,2),fpp(14,16,13,3)/
     x 1.1287066d-02, 4.2380885d-06, 6.8468038d-07 /
      data fpp(14,16,14,1),fpp(14,16,14,2),fpp(14,16,14,3)/
     x 1.1625097d-02, 3.3281246d-06, 1.1613583d-06 /
      data fpp(14,16,15,1),fpp(14,16,15,2),fpp(14,16,15,3)/
     x 1.1857765d-02, 2.8555142d-06, 1.2038864d-06 /
      data fpp(14,16,16,1),fpp(14,16,16,2),fpp(14,16,16,3)/
     x 1.2135492d-02, 2.8177335d-06, 8.9309622d-07 /
      data fpp(14,16,17,1),fpp(14,16,17,2),fpp(14,16,17,3)/
     x 1.2481901d-02, 3.1441983d-06, 3.4172874d-07 /
      data fpp(14,16,18,1),fpp(14,16,18,2),fpp(14,16,18,3)/
     x 1.2835201d-02, 3.7149664d-06,-2.9201120d-07 /
      data fpp(14,16,19,1),fpp(14,16,19,2),fpp(14,16,19,3)/
     x 1.3049363d-02, 4.2932862d-06,-8.4768394d-07 /
      data fpp(14,16,20,1),fpp(14,16,20,2),fpp(14,16,20,3)/
     x 1.3341418d-02, 4.6783795d-06,-1.2192530d-06 /
      data fpp(14,16,21,1),fpp(14,16,21,2),fpp(14,16,21,3)/
     x 1.3341418d-02, 4.6783795d-06,-1.2373989d-06 /
      data fpp(14,16,22,1),fpp(14,16,22,2),fpp(14,16,22,3)/
     x 1.3049363d-02, 4.2932862d-06,-7.7510030d-07 /
      data fpp(14,16,23,1),fpp(14,16,23,2),fpp(14,16,23,3)/
     x 1.2835201d-02, 3.7149664d-06,-5.6419985d-07 /
      data fpp(14,17, 1,1),fpp(14,17, 1,2),fpp(14,17, 1,3)/
     x 2.7762107d-01,-2.5224269d-04, 6.5093944d-06 /
      data fpp(14,17, 2,1),fpp(14,17, 2,2),fpp(14,17, 2,3)/
     x 1.5507880d-01,-2.0300150d-04, 8.2917113d-06 /
      data fpp(14,17, 3,1),fpp(14,17, 3,2),fpp(14,17, 3,3)/
     x-1.8678059d-02,-1.6957398d-04, 1.4017761d-05 /
      data fpp(14,17, 4,1),fpp(14,17, 4,2),fpp(14,17, 4,3)/
     x-1.8678059d-02,-1.6957398d-04, 1.0680863d-05 /
      data fpp(14,17, 5,1),fpp(14,17, 5,2),fpp(14,17, 5,3)/
     x 1.5507880d-01,-2.0300150d-04, 2.1639302d-05 /
      data fpp(14,17, 6,1),fpp(14,17, 6,2),fpp(14,17, 6,3)/
     x 2.7762107d-01,-2.5224269d-04,-4.3544070d-05 /
      data fpp(14,17, 7,1),fpp(14,17, 7,2),fpp(14,17, 7,3)/
     x-1.5320451d-01,-1.9688330d-04,-1.0027020d-05 /
      data fpp(14,17, 8,1),fpp(14,17, 8,2),fpp(14,17, 8,3)/
     x 9.2557921d-02,-8.6586873d-05, 6.3001505d-06 /
      data fpp(14,17, 9,1),fpp(14,17, 9,2),fpp(14,17, 9,3)/
     x 5.2730405d-05,-3.6678109d-05, 1.2664180d-06 /
      data fpp(14,17,10,1),fpp(14,17,10,2),fpp(14,17,10,3)/
     x 5.4254011d-03,-1.4069781d-05, 1.5821776d-06 /
      data fpp(14,17,11,1),fpp(14,17,11,2),fpp(14,17,11,3)/
     x 9.0428324d-03,-3.0135506d-06, 1.0868715d-06 /
      data fpp(14,17,12,1),fpp(14,17,12,2),fpp(14,17,12,3)/
     x 1.0589507d-02, 2.3083405d-06, 1.0963363d-06 /
      data fpp(14,17,13,1),fpp(14,17,13,2),fpp(14,17,13,3)/
     x 1.1227445d-02, 4.8018608d-06, 1.0557834d-06 /
      data fpp(14,17,14,1),fpp(14,17,14,2),fpp(14,17,14,3)/
     x 1.1566629d-02, 6.0600434d-06, 1.0045301d-06 /
      data fpp(14,17,15,1),fpp(14,17,15,2),fpp(14,17,15,3)/
     x 1.1726839d-02, 6.9123616d-06, 8.6009609d-07 /
      data fpp(14,17,16,1),fpp(14,17,16,2),fpp(14,17,16,3)/
     x 1.1899607d-02, 7.7533794d-06, 6.4308553d-07 /
      data fpp(14,17,17,1),fpp(14,17,17,2),fpp(14,17,17,3)/
     x 1.2043852d-02, 8.6807543d-06, 3.7756181d-07 /
      data fpp(14,17,18,1),fpp(14,17,18,2),fpp(14,17,18,3)/
     x 1.2156806d-02, 9.6120860d-06, 1.0866724d-07 /
      data fpp(14,17,19,1),fpp(14,17,19,2),fpp(14,17,19,3)/
     x 1.2340615d-02, 1.0400731d-05,-1.3423076d-07 /
      data fpp(14,17,20,1),fpp(14,17,20,2),fpp(14,17,20,3)/
     x 1.2357499d-02, 1.0948052d-05,-2.9774420d-07 /
      data fpp(14,17,21,1),fpp(14,17,21,2),fpp(14,17,21,3)/
     x 1.2357499d-02, 1.0948052d-05,-3.0565203d-07 /
      data fpp(14,17,22,1),fpp(14,17,22,2),fpp(14,17,22,3)/
     x 1.2340615d-02, 1.0400731d-05,-1.0259942d-07 /
      data fpp(14,17,23,1),fpp(14,17,23,2),fpp(14,17,23,3)/
     x 1.2156806d-02, 9.6120860d-06,-9.9502902d-09 /
      data fpp(14,18, 1,1),fpp(14,18, 1,2),fpp(14,18, 1,3)/
     x 3.0355510d-02,-9.2965185d-06,-1.2551649d-06 /
      data fpp(14,18, 2,1),fpp(14,18, 2,2),fpp(14,18, 2,3)/
     x 9.7770514d-04,-5.5852430d-05,-1.7891701d-06 /
      data fpp(14,18, 3,1),fpp(14,18, 3,2),fpp(14,18, 3,3)/
     x-2.9735137d-02,-8.6926578d-05,-2.9461545d-06 /
      data fpp(14,18, 4,1),fpp(14,18, 4,2),fpp(14,18, 4,3)/
     x-2.9735137d-02,-8.6926578d-05,-2.9239515d-06 /
      data fpp(14,18, 5,1),fpp(14,18, 5,2),fpp(14,18, 5,3)/
     x 9.7770514d-04,-5.5852430d-05,-1.8779823d-06 /
      data fpp(14,18, 6,1),fpp(14,18, 6,2),fpp(14,18, 6,3)/
     x 3.0355510d-02,-9.2965185d-06,-9.2211930d-07 /
      data fpp(14,18, 7,1),fpp(14,18, 7,2),fpp(14,18, 7,3)/
     x 1.1290254d-02,-1.6444866d-06,-9.1540499d-08 /
      data fpp(14,18, 8,1),fpp(14,18, 8,2),fpp(14,18, 8,3)/
     x 1.0399736d-02,-1.4279036d-05, 4.3628129d-07 /
      data fpp(14,18, 9,1),fpp(14,18, 9,2),fpp(14,18, 9,3)/
     x 1.1735119d-02,-1.5334255d-05, 7.1041533d-07 /
      data fpp(14,18,10,1),fpp(14,18,10,2),fpp(14,18,10,3)/
     x 1.1470451d-02,-1.2207634d-05, 8.1405740d-07 /
      data fpp(14,18,11,1),fpp(14,18,11,2),fpp(14,18,11,3)/
     x 1.1572313d-02,-8.1525570d-06, 8.2135509d-07 /
      data fpp(14,18,12,1),fpp(14,18,12,2),fpp(14,18,12,3)/
     x 1.1726378d-02,-4.0603830d-06, 7.8452224d-07 /
      data fpp(14,18,13,1),fpp(14,18,13,2),fpp(14,18,13,3)/
     x 1.1764438d-02,-1.8953165d-07, 7.2655595d-07 /
      data fpp(14,18,14,1),fpp(14,18,14,2),fpp(14,18,14,3)/
     x 1.1816614d-02, 3.4097019d-06, 6.4725394d-07 /
      data fpp(14,18,15,1),fpp(14,18,15,2),fpp(14,18,15,3)/
     x 1.1813569d-02, 6.7490396d-06, 5.7242827d-07 /
      data fpp(14,18,16,1),fpp(14,18,16,2),fpp(14,18,16,3)/
     x 1.1878554d-02, 9.8067487d-06, 4.7703298d-07 /
      data fpp(14,18,17,1),fpp(14,18,17,2),fpp(14,18,17,3)/
     x 1.1889405d-02, 1.2532784d-05, 3.9943980d-07 /
      data fpp(14,18,18,1),fpp(14,18,18,2),fpp(14,18,18,3)/
     x 1.1877767d-02, 1.4830690d-05, 3.1320783d-07 /
      data fpp(14,18,19,1),fpp(14,18,19,2),fpp(14,18,19,3)/
     x 1.1950864d-02, 1.6587791d-05, 2.7372889d-07 /
      data fpp(14,18,20,1),fpp(14,18,20,2),fpp(14,18,20,3)/
     x 1.2008234d-02, 1.7667414d-05, 2.0587663d-07 /
      data fpp(14,18,21,1),fpp(14,18,21,2),fpp(14,18,21,3)/
     x 1.2008234d-02, 1.7667414d-05, 2.0550568d-07 /
      data fpp(14,18,22,1),fpp(14,18,22,2),fpp(14,18,22,3)/
     x 1.1950864d-02, 1.6587791d-05, 2.7521266d-07 /
      data fpp(14,18,23,1),fpp(14,18,23,2),fpp(14,18,23,3)/
     x 1.1877767d-02, 1.4830690d-05, 3.0764367d-07 /
      data fpp(14,19, 1,1),fpp(14,19, 1,2),fpp(14,19, 1,3)/
     x 1.2409179d-02, 5.0310759d-05,-1.1339247d-20 /
      data fpp(14,19, 2,1),fpp(14,19, 2,2),fpp(14,19, 2,3)/
     x 1.2409179d-02,-5.3504785d-05, 1.1039484d-20 /
      data fpp(14,19, 3,1),fpp(14,19, 3,2),fpp(14,19, 3,3)/
     x 1.2409179d-02,-1.2702371d-04,-2.0121297d-20 /
      data fpp(14,19, 4,1),fpp(14,19, 4,2),fpp(14,19, 4,3)/
     x 1.2409179d-02,-1.2702371d-04, 5.3131069d-21 /
      data fpp(14,19, 5,1),fpp(14,19, 5,2),fpp(14,19, 5,3)/
     x 1.2409179d-02,-5.3504785d-05, 5.1752334d-21 /
      data fpp(14,19, 6,1),fpp(14,19, 6,2),fpp(14,19, 6,3)/
     x 1.2409179d-02, 5.0310759d-05, 9.6096176d-22 /
      data fpp(14,19, 7,1),fpp(14,19, 7,2),fpp(14,19, 7,3)/
     x 1.2409179d-02, 5.3893243d-05,-2.8599278d-20 /
      data fpp(14,19, 8,1),fpp(14,19, 8,2),fpp(14,19, 8,3)/
     x 1.2409179d-02, 8.0370181d-06,-2.3278579d-20 /
      data fpp(14,19, 9,1),fpp(14,19, 9,2),fpp(14,19, 9,3)/
     x 1.2409179d-02,-1.2036873d-05,-6.2058749d-21 /
      data fpp(14,19,10,1),fpp(14,19,10,2),fpp(14,19,10,3)/
     x 1.2409179d-02,-1.6773683d-05, 2.6169246d-20 /
      data fpp(14,19,11,1),fpp(14,19,11,2),fpp(14,19,11,3)/
     x 1.2409179d-02,-1.4566222d-05,-9.7927823d-21 /
      data fpp(14,19,12,1),fpp(14,19,12,2),fpp(14,19,12,3)/
     x 1.2409179d-02,-9.5148085d-06, 1.8897379d-20 /
      data fpp(14,19,13,1),fpp(14,19,13,2),fpp(14,19,13,3)/
     x 1.2409179d-02,-3.5937342d-06, 5.7561744d-21 /
      data fpp(14,19,14,1),fpp(14,19,14,2),fpp(14,19,14,3)/
     x 1.2409179d-02, 2.2971491d-06, 5.2220328d-21 /
      data fpp(14,19,15,1),fpp(14,19,15,2),fpp(14,19,15,3)/
     x 1.2409179d-02, 7.7914802d-06, 2.5989130d-21 /
      data fpp(14,19,16,1),fpp(14,19,16,2),fpp(14,19,16,3)/
     x 1.2409179d-02, 1.2683626d-05,-1.6516320d-20 /
      data fpp(14,19,17,1),fpp(14,19,17,2),fpp(14,19,17,3)/
     x 1.2409179d-02, 1.6866108d-05, 2.8270902d-20 /
      data fpp(14,19,18,1),fpp(14,19,18,2),fpp(14,19,18,3)/
     x 1.2409179d-02, 2.0243155d-05,-8.1021595d-21 /
      data fpp(14,19,19,1),fpp(14,19,19,2),fpp(14,19,19,3)/
     x 1.2409179d-02, 2.2752104d-05,-1.1800176d-20 /
      data fpp(14,19,20,1),fpp(14,19,20,2),fpp(14,19,20,3)/
     x 1.2409179d-02, 2.4258293d-05, 6.6233084d-21 /
      data fpp(14,19,21,1),fpp(14,19,21,2),fpp(14,19,21,3)/
     x 1.2409179d-02, 2.4258293d-05,-5.1633453d-21 /
      data fpp(14,19,22,1),fpp(14,19,22,2),fpp(14,19,22,3)/
     x 1.2409179d-02, 2.2752104d-05, 1.6736553d-20 /
      data fpp(14,19,23,1),fpp(14,19,23,2),fpp(14,19,23,3)/
     x 1.2409179d-02, 2.0243155d-05, 5.6921240d-20 /
      data fpp(15, 1, 1,1),fpp(15, 1, 1,2),fpp(15, 1, 1,3)/
     x 1.8487719d+00, 1.0692020d-03,-6.7300690d-20 /
      data fpp(15, 1, 2,1),fpp(15, 1, 2,2),fpp(15, 1, 2,3)/
     x 1.8487719d+00, 2.9408434d-03,-4.3156013d-20 /
      data fpp(15, 1, 3,1),fpp(15, 1, 3,2),fpp(15, 1, 3,3)/
     x 1.8487719d+00, 3.4707911d-03,-5.9011717d-20 /
      data fpp(15, 1, 4,1),fpp(15, 1, 4,2),fpp(15, 1, 4,3)/
     x 1.8487719d+00, 3.4707911d-03, 1.0928566d-19 /
      data fpp(15, 1, 5,1),fpp(15, 1, 5,2),fpp(15, 1, 5,3)/
     x 1.8487719d+00, 2.9408434d-03, 4.8873379d-20 /
      data fpp(15, 1, 6,1),fpp(15, 1, 6,2),fpp(15, 1, 6,3)/
     x 1.8487719d+00, 1.0692020d-03,-4.3847501d-20 /
      data fpp(15, 1, 7,1),fpp(15, 1, 7,2),fpp(15, 1, 7,3)/
     x 1.8487719d+00, 1.1035015d-04,-1.6738043d-19 /
      data fpp(15, 1, 8,1),fpp(15, 1, 8,2),fpp(15, 1, 8,3)/
     x 1.8487719d+00,-2.0361852d-04,-1.0919503d-19 /
      data fpp(15, 1, 9,1),fpp(15, 1, 9,2),fpp(15, 1, 9,3)/
     x 1.8487719d+00,-3.7652983d-04, 1.0676765d-20 /
      data fpp(15, 1,10,1),fpp(15, 1,10,2),fpp(15, 1,10,3)/
     x 1.8487719d+00,-4.6214081d-04, 1.2053011d-19 /
      data fpp(15, 1,11,1),fpp(15, 1,11,2),fpp(15, 1,11,3)/
     x 1.8487719d+00,-5.0754974d-04,-2.7627537d-20 /
      data fpp(15, 1,12,1),fpp(15, 1,12,2),fpp(15, 1,12,3)/
     x 1.8487719d+00,-5.2452842d-04, 1.6766060d-19 /
      data fpp(15, 1,13,1),fpp(15, 1,13,2),fpp(15, 1,13,3)/
     x 1.8487719d+00,-5.1473564d-04, 1.0250202d-19 /
      data fpp(15, 1,14,1),fpp(15, 1,14,2),fpp(15, 1,14,3)/
     x 1.8487719d+00,-4.7550916d-04, 1.0396879d-19 /
      data fpp(15, 1,15,1),fpp(15, 1,15,2),fpp(15, 1,15,3)/
     x 1.8487719d+00,-3.9399118d-04,-2.1510797d-20 /
      data fpp(15, 1,16,1),fpp(15, 1,16,2),fpp(15, 1,16,3)/
     x 1.8487719d+00,-2.2293346d-04,-9.5892034d-20 /
      data fpp(15, 1,17,1),fpp(15, 1,17,2),fpp(15, 1,17,3)/
     x 1.8487719d+00, 1.0105376d-04, 6.9532903d-20 /
      data fpp(15, 1,18,1),fpp(15, 1,18,2),fpp(15, 1,18,3)/
     x 1.8487719d+00, 1.0470362d-03,-9.9432107d-20 /
      data fpp(15, 1,19,1),fpp(15, 1,19,2),fpp(15, 1,19,3)/
     x 1.8487719d+00, 2.9120410d-03,-1.6135710d-19 /
      data fpp(15, 1,20,1),fpp(15, 1,20,2),fpp(15, 1,20,3)/
     x 1.8487719d+00, 3.3659683d-03, 7.5445134d-20 /
      data fpp(15, 1,21,1),fpp(15, 1,21,2),fpp(15, 1,21,3)/
     x 1.8487719d+00, 3.3659683d-03,-1.0527883d-19 /
      data fpp(15, 1,22,1),fpp(15, 1,22,2),fpp(15, 1,22,3)/
     x 1.8487719d+00, 2.9120410d-03, 1.0896384d-19 /
      data fpp(15, 1,23,1),fpp(15, 1,23,2),fpp(15, 1,23,3)/
     x 1.8487719d+00, 1.0470362d-03, 3.4873325d-19 /
      data fpp(15, 2, 1,1),fpp(15, 2, 1,2),fpp(15, 2, 1,3)/
     x 3.1732926d-01, 4.4032798d-04,-6.1167122d-06 /
      data fpp(15, 2, 2,1),fpp(15, 2, 2,2),fpp(15, 2, 2,3)/
     x 3.3614259d-01, 1.1526283d-03,-1.8967576d-05 /
      data fpp(15, 2, 3,1),fpp(15, 2, 3,2),fpp(15, 2, 3,3)/
     x 3.6430967d-01, 1.3295848d-03,-4.6676986d-05 /
      data fpp(15, 2, 4,1),fpp(15, 2, 4,2),fpp(15, 2, 4,3)/
     x 3.6430967d-01, 1.3295848d-03,-4.6376255d-05 /
      data fpp(15, 2, 5,1),fpp(15, 2, 5,2),fpp(15, 2, 5,3)/
     x 3.3614259d-01, 1.1526283d-03,-2.0170498d-05 /
      data fpp(15, 2, 6,1),fpp(15, 2, 6,2),fpp(15, 2, 6,3)/
     x 3.1732926d-01, 4.4032798d-04,-1.6057522d-06 /
      data fpp(15, 2, 7,1),fpp(15, 2, 7,2),fpp(15, 2, 7,3)/
     x 2.9510661d-01, 6.5876701d-05, 9.9555071d-06 /
      data fpp(15, 2, 8,1),fpp(15, 2, 8,2),fpp(15, 2, 8,3)/
     x 2.5578738d-01,-4.3816955d-05, 1.5087724d-05 /
      data fpp(15, 2, 9,1),fpp(15, 2, 9,2),fpp(15, 2, 9,3)/
     x 2.6981805d-01,-1.0253635d-04, 1.7551598d-05 /
      data fpp(15, 2,10,1),fpp(15, 2,10,2),fpp(15, 2,10,3)/
     x 2.5758705d-01,-1.2830438d-04, 1.9261883d-05 /
      data fpp(15, 2,11,1),fpp(15, 2,11,2),fpp(15, 2,11,3)/
     x 8.0933975d-01,-1.4132752d-04, 2.0492868d-05 /
      data fpp(15, 2,12,1),fpp(15, 2,12,2),fpp(15, 2,12,3)/
     x 6.9578965d-01,-1.4710516d-04, 2.1010645d-05 /
      data fpp(15, 2,13,1),fpp(15, 2,13,2),fpp(15, 2,13,3)/
     x 1.4194404d-01,-1.4653172d-04, 2.0630552d-05 /
      data fpp(15, 2,14,1),fpp(15, 2,14,2),fpp(15, 2,14,3)/
     x 2.5788392d-01,-1.3825567d-04, 1.9431145d-05 /
      data fpp(15, 2,15,1),fpp(15, 2,15,2),fpp(15, 2,15,3)/
     x 2.6919729d-01,-1.1627165d-04, 1.7714866d-05 /
      data fpp(15, 2,16,1),fpp(15, 2,16,2),fpp(15, 2,16,3)/
     x 2.7495672d-01,-6.0236084d-05, 1.5069391d-05 /
      data fpp(15, 2,17,1),fpp(15, 2,17,2),fpp(15, 2,17,3)/
     x 2.9251489d-01, 5.4452476d-05, 9.7035686d-06 /
      data fpp(15, 2,18,1),fpp(15, 2,18,2),fpp(15, 2,18,3)/
     x 3.1331966d-01, 4.2078456d-04,-2.3256657d-06 /
      data fpp(15, 2,19,1),fpp(15, 2,19,2),fpp(15, 2,19,3)/
     x 3.3964474d-01, 1.1327721d-03,-2.0872906d-05 /
      data fpp(15, 2,20,1),fpp(15, 2,20,2),fpp(15, 2,20,3)/
     x 3.6407813d-01, 1.2895453d-03,-4.7448711d-05 /
      data fpp(15, 2,21,1),fpp(15, 2,21,2),fpp(15, 2,21,3)/
     x 3.6407813d-01, 1.2895453d-03,-4.7740414d-05 /
      data fpp(15, 2,22,1),fpp(15, 2,22,2),fpp(15, 2,22,3)/
     x 3.3964474d-01, 1.1327721d-03,-1.9706096d-05 /
      data fpp(15, 2,23,1),fpp(15, 2,23,2),fpp(15, 2,23,3)/
     x 3.1331966d-01, 4.2078456d-04,-6.7012019d-06 /
      data fpp(15, 3, 1,1),fpp(15, 3, 1,2),fpp(15, 3, 1,3)/
     x 3.1614270d-01,-8.6612593d-04,-5.7576153d-04 /
      data fpp(15, 3, 2,1),fpp(15, 3, 2,2),fpp(15, 3, 2,3)/
     x 8.7553524d-01,-1.9134865d-03,-4.5022643d-04 /
      data fpp(15, 3, 3,1),fpp(15, 3, 3,2),fpp(15, 3, 3,3)/
     x 1.1285005d+00,-1.8249724d-03,-2.2785473d-04 /
      data fpp(15, 3, 4,1),fpp(15, 3, 4,2),fpp(15, 3, 4,3)/
     x 1.1285005d+00,-1.8249724d-03,-1.4624859d-04 /
      data fpp(15, 3, 5,1),fpp(15, 3, 5,2),fpp(15, 3, 5,3)/
     x 8.7553524d-01,-1.9134865d-03,-7.7665102d-04 /
      data fpp(15, 3, 6,1),fpp(15, 3, 6,2),fpp(15, 3, 6,3)/
     x 3.1614270d-01,-8.6612593d-04, 6.4833065d-04 /
      data fpp(15, 3, 7,1),fpp(15, 3, 7,2),fpp(15, 3, 7,3)/
     x 1.6482926d-01,-9.4454953d-05, 1.3854842d-04 /
      data fpp(15, 3, 8,1),fpp(15, 3, 8,2),fpp(15, 3, 8,3)/
     x 9.0357303d-02, 1.3385834d-04, 6.4639662d-05 /
      data fpp(15, 3, 9,1),fpp(15, 3, 9,2),fpp(15, 3, 9,3)/
     x 7.5337880d-02, 2.9855122d-04, 5.9942929d-05 /
      data fpp(15, 3,10,1),fpp(15, 3,10,2),fpp(15, 3,10,3)/
     x 6.3498905d-02, 3.8338633d-04, 4.3948622d-05 /
      data fpp(15, 3,11,1),fpp(15, 3,11,2),fpp(15, 3,11,3)/
     x 5.9196555d-02, 4.2799780d-04, 4.5404582d-05 /
      data fpp(15, 3,12,1),fpp(15, 3,12,2),fpp(15, 3,12,3)/
     x 5.7766894d-02, 4.4141706d-04, 4.5141051d-05 /
      data fpp(15, 3,13,1),fpp(15, 3,13,2),fpp(15, 3,13,3)/
     x 5.8663563d-02, 4.2432053d-04, 4.6023214d-05 /
      data fpp(15, 3,14,1),fpp(15, 3,14,2),fpp(15, 3,14,3)/
     x 6.3079183d-02, 3.7562385d-04, 4.5338091d-05 /
      data fpp(15, 3,15,1),fpp(15, 3,15,2),fpp(15, 3,15,3)/
     x 2.7514800d-02, 2.8628176d-04, 6.1242420d-05 /
      data fpp(15, 3,16,1),fpp(15, 3,16,2),fpp(15, 3,16,3)/
     x 8.6089263d-02, 1.1833179d-04, 6.7550228d-05 /
      data fpp(15, 3,17,1),fpp(15, 3,17,2),fpp(15, 3,17,3)/
     x 1.6353034d-01,-1.4547566d-04, 1.3563267d-04 /
      data fpp(15, 3,18,1),fpp(15, 3,18,2),fpp(15, 3,18,3)/
     x 3.1137356d-01,-8.7271246d-04, 6.5817510d-04 /
      data fpp(15, 3,19,1),fpp(15, 3,19,2),fpp(15, 3,19,3)/
     x 3.9748825d-01,-1.9144413d-03,-8.2212508d-04 /
      data fpp(15, 3,20,1),fpp(15, 3,20,2),fpp(15, 3,20,3)/
     x 1.0150666d+00,-1.8120216d-03,-1.2399277d-04 /
      data fpp(15, 3,21,1),fpp(15, 3,21,2),fpp(15, 3,21,3)/
     x 1.0150666d+00,-1.8120216d-03,-2.0972514d-04 /
      data fpp(15, 3,22,1),fpp(15, 3,22,2),fpp(15, 3,22,3)/
     x 3.9748825d-01,-1.9144413d-03,-4.7919560d-04 /
      data fpp(15, 3,23,1),fpp(15, 3,23,2),fpp(15, 3,23,3)/
     x 3.1137356d-01,-8.7271246d-04,-6.2781045d-04 /
      data fpp(15, 4, 1,1),fpp(15, 4, 1,2),fpp(15, 4, 1,3)/
     x 1.2216447d-01, 1.9894972d-04,-1.0203123d-04 /
      data fpp(15, 4, 2,1),fpp(15, 4, 2,2),fpp(15, 4, 2,3)/
     x 2.5906454d-01,-5.0695227d-04,-1.9288553d-04 /
      data fpp(15, 4, 3,1),fpp(15, 4, 3,2),fpp(15, 4, 3,3)/
     x 6.4014337d-01,-1.4328011d-03,-4.1859863d-04 /
      data fpp(15, 4, 4,1),fpp(15, 4, 4,2),fpp(15, 4, 4,3)/
     x 6.4014337d-01,-1.4328011d-03,-3.6430433d-04 /
      data fpp(15, 4, 5,1),fpp(15, 4, 5,2),fpp(15, 4, 5,3)/
     x 2.5906454d-01,-5.0695227d-04,-4.1006275d-04 /
      data fpp(15, 4, 6,1),fpp(15, 4, 6,2),fpp(15, 4, 6,3)/
     x 1.2216447d-01, 1.9894972d-04, 7.1238331d-04 /
      data fpp(15, 4, 7,1),fpp(15, 4, 7,2),fpp(15, 4, 7,3)/
     x-5.5480762d-01, 1.5071711d-04,-3.1436513d-05 /
      data fpp(15, 4, 8,1),fpp(15, 4, 8,2),fpp(15, 4, 8,3)/
     x 1.2342947d-04, 2.4897558d-04, 1.3220474d-04 /
      data fpp(15, 4, 9,1),fpp(15, 4, 9,2),fpp(15, 4, 9,3)/
     x-5.9036963d-03, 2.5480946d-04, 3.2927559d-05 /
      data fpp(15, 4,10,1),fpp(15, 4,10,2),fpp(15, 4,10,3)/
     x-4.4142233d-03, 2.7258705d-04, 5.3713026d-05 /
      data fpp(15, 4,11,1),fpp(15, 4,11,2),fpp(15, 4,11,3)/
     x-5.1105796d-03, 2.8646230d-04, 4.7360337d-05 /
      data fpp(15, 4,12,1),fpp(15, 4,12,2),fpp(15, 4,12,3)/
     x-5.8222196d-03, 2.9109291d-04, 4.9249625d-05 /
      data fpp(15, 4,13,1),fpp(15, 4,13,2),fpp(15, 4,13,3)/
     x-4.9912746d-03, 2.8590360d-04, 4.8927162d-05 /
      data fpp(15, 4,14,1),fpp(15, 4,14,2),fpp(15, 4,14,3)/
     x-3.4742958d-03, 2.7131229d-04, 5.3121728d-05 /
      data fpp(15, 4,15,1),fpp(15, 4,15,2),fpp(15, 4,15,3)/
     x-5.4434717d-03, 2.5191661d-04, 4.6073925d-05 /
      data fpp(15, 4,16,1),fpp(15, 4,16,2),fpp(15, 4,16,3)/
     x 2.3365927d-04, 2.4135291d-04, 1.0139057d-04 /
      data fpp(15, 4,17,1),fpp(15, 4,17,2),fpp(15, 4,17,3)/
     x 2.3465467d-02, 1.9124018d-04, 3.0493782d-05 /
      data fpp(15, 4,18,1),fpp(15, 4,18,2),fpp(15, 4,18,3)/
     x 1.1703616d-01, 1.6914929d-04, 6.8753630d-04 /
      data fpp(15, 4,19,1),fpp(15, 4,19,2),fpp(15, 4,19,3)/
     x 3.7155368d-01,-5.2384893d-04,-4.5097098d-04 /
      data fpp(15, 4,20,1),fpp(15, 4,20,2),fpp(15, 4,20,3)/
     x 5.2280199d-01,-1.3255848d-03,-3.4638039d-04 /
      data fpp(15, 4,21,1),fpp(15, 4,21,2),fpp(15, 4,21,3)/
     x 5.2280199d-01,-1.3255848d-03,-4.0274034d-04 /
      data fpp(15, 4,22,1),fpp(15, 4,22,2),fpp(15, 4,22,3)/
     x 3.7155368d-01,-5.2384893d-04,-2.2553119d-04 /
      data fpp(15, 4,23,1),fpp(15, 4,23,2),fpp(15, 4,23,3)/
     x 1.1703616d-01, 1.6914929d-04,-1.5786291d-04 /
      data fpp(15, 5, 1,1),fpp(15, 5, 1,2),fpp(15, 5, 1,3)/
     x-3.3581493d-02, 2.0176904d-04, 1.1907559d-04 /
      data fpp(15, 5, 2,1),fpp(15, 5, 2,2),fpp(15, 5, 2,3)/
     x-1.2835454d-01, 9.9695158d-04, 1.5089825d-05 /
      data fpp(15, 5, 3,1),fpp(15, 5, 3,2),fpp(15, 5, 3,3)/
     x-4.8326635d-03, 1.4902489d-03,-2.0505489d-04 /
      data fpp(15, 5, 4,1),fpp(15, 5, 4,2),fpp(15, 5, 4,3)/
     x-4.8326635d-03, 1.4902489d-03,-2.0974825d-04 /
      data fpp(15, 5, 5,1),fpp(15, 5, 5,2),fpp(15, 5, 5,3)/
     x-1.2835454d-01, 9.9695158d-04, 3.3863267d-05 /
      data fpp(15, 5, 6,1),fpp(15, 5, 6,2),fpp(15, 5, 6,3)/
     x-3.3581493d-02, 2.0176904d-04, 4.8675180d-05 /
      data fpp(15, 5, 7,1),fpp(15, 5, 7,2),fpp(15, 5, 7,3)/
     x-2.7767154d-02, 1.0779850d-04, 4.1268012d-05 /
      data fpp(15, 5, 8,1),fpp(15, 5, 8,2),fpp(15, 5, 8,3)/
     x-2.3191421d-02, 5.4627334d-05, 4.0178773d-05 /
      data fpp(15, 5, 9,1),fpp(15, 5, 9,2),fpp(15, 5, 9,3)/
     x-2.0355325d-02, 7.4492938d-05, 4.1304896d-05 /
      data fpp(15, 5,10,1),fpp(15, 5,10,2),fpp(15, 5,10,3)/
     x-1.8930452d-02, 8.5995477d-05, 4.1051641d-05 /
      data fpp(15, 5,11,1),fpp(15, 5,11,2),fpp(15, 5,11,3)/
     x-1.8286981d-02, 9.0018999d-05, 4.0314538d-05 /
      data fpp(15, 5,12,1),fpp(15, 5,12,2),fpp(15, 5,12,3)/
     x-1.8005468d-02, 9.0765291d-05, 4.0342206d-05 /
      data fpp(15, 5,13,1),fpp(15, 5,13,2),fpp(15, 5,13,3)/
     x-1.7902314d-02, 8.9871064d-05, 4.1460638d-05 /
      data fpp(15, 5,14,1),fpp(15, 5,14,2),fpp(15, 5,14,3)/
     x-1.8149590d-02, 8.6155011d-05, 4.3373242d-05 /
      data fpp(15, 5,15,1),fpp(15, 5,15,2),fpp(15, 5,15,3)/
     x-1.8981309d-02, 7.6169793d-05, 4.5272394d-05 /
      data fpp(15, 5,16,1),fpp(15, 5,16,2),fpp(15, 5,16,3)/
     x-2.0784822d-02, 5.9946559d-05, 4.5777183d-05 /
      data fpp(15, 5,17,1),fpp(15, 5,17,2),fpp(15, 5,17,3)/
     x-2.3538549d-02, 8.1050932d-05, 5.2076874d-05 /
      data fpp(15, 5,18,1),fpp(15, 5,18,2),fpp(15, 5,18,3)/
     x-2.6549280d-02, 2.0947128d-04, 5.5437322d-05 /
      data fpp(15, 5,19,1),fpp(15, 5,19,2),fpp(15, 5,19,3)/
     x 2.8931247d-03, 9.6691302d-04, 7.0201837d-05 /
      data fpp(15, 5,20,1),fpp(15, 5,20,2),fpp(15, 5,20,3)/
     x 1.4908974d-01, 1.2757968d-03,-2.4674267d-04 /
      data fpp(15, 5,21,1),fpp(15, 5,21,2),fpp(15, 5,21,3)/
     x 1.4908974d-01, 1.2757968d-03,-2.3902090d-04 /
      data fpp(15, 5,22,1),fpp(15, 5,22,2),fpp(15, 5,22,3)/
     x 2.8931247d-03, 9.6691302d-04, 3.9314758d-05 /
      data fpp(15, 5,23,1),fpp(15, 5,23,2),fpp(15, 5,23,3)/
     x-2.6549280d-02, 2.0947128d-04, 1.7126387d-04 /
      data fpp(15, 6, 1,1),fpp(15, 6, 1,2),fpp(15, 6, 1,3)/
     x-1.5388877d-02,-4.0505873d-05, 3.1461513d-05 /
      data fpp(15, 6, 2,1),fpp(15, 6, 2,2),fpp(15, 6, 2,3)/
     x-1.3896121d-02,-2.0634205d-04,-1.0060027d-05 /
      data fpp(15, 6, 3,1),fpp(15, 6, 3,2),fpp(15, 6, 3,3)/
     x 1.6273851d-03,-2.9239846d-04,-9.7997406d-05 /
      data fpp(15, 6, 4,1),fpp(15, 6, 4,2),fpp(15, 6, 4,3)/
     x 1.6273851d-03,-2.9239846d-04,-9.9812769d-05 /
      data fpp(15, 6, 5,1),fpp(15, 6, 5,2),fpp(15, 6, 5,3)/
     x-1.3896121d-02,-2.0634205d-04,-2.7985741d-06 /
      data fpp(15, 6, 6,1),fpp(15, 6, 6,2),fpp(15, 6, 6,3)/
     x-1.5388877d-02,-4.0505873d-05, 4.2310653d-06 /
      data fpp(15, 6, 7,1),fpp(15, 6, 7,2),fpp(15, 6, 7,3)/
     x-1.5363446d-02,-2.4943121d-05, 1.7944313d-05 /
      data fpp(15, 6, 8,1),fpp(15, 6, 8,2),fpp(15, 6, 8,3)/
     x-1.5673175d-02,-9.1809177d-06, 2.2889683d-05 /
      data fpp(15, 6, 9,1),fpp(15, 6, 9,2),fpp(15, 6, 9,3)/
     x-1.6377059d-02,-1.3885212d-05, 2.6018953d-05 /
      data fpp(15, 6,10,1),fpp(15, 6,10,2),fpp(15, 6,10,3)/
     x-1.7025353d-02,-1.7882957d-05, 2.7504503d-05 /
      data fpp(15, 6,11,1),fpp(15, 6,11,2),fpp(15, 6,11,3)/
     x-1.7523151d-02,-1.9802295d-05, 2.8735036d-05 /
      data fpp(15, 6,12,1),fpp(15, 6,12,2),fpp(15, 6,12,3)/
     x-1.7654191d-02,-2.0116077d-05, 2.9707354d-05 /
      data fpp(15, 6,13,1),fpp(15, 6,13,2),fpp(15, 6,13,3)/
     x-1.7371015d-02,-1.9071858d-05, 3.0413549d-05 /
      data fpp(15, 6,14,1),fpp(15, 6,14,2),fpp(15, 6,14,3)/
     x-1.6743956d-02,-1.5980331d-05, 3.1032451d-05 /
      data fpp(15, 6,15,1),fpp(15, 6,15,2),fpp(15, 6,15,3)/
     x-1.5817669d-02,-9.8277853d-06, 3.1600647d-05 /
      data fpp(15, 6,16,1),fpp(15, 6,16,2),fpp(15, 6,16,3)/
     x-1.4717037d-02,-1.2651486d-06, 3.0526959d-05 /
      data fpp(15, 6,17,1),fpp(15, 6,17,2),fpp(15, 6,17,3)/
     x-1.3465616d-02,-3.4991185d-07, 2.7191515d-05 /
      data fpp(15, 6,18,1),fpp(15, 6,18,2),fpp(15, 6,18,3)/
     x-1.1874745d-02,-1.2570435d-05, 1.2998979d-05 /
      data fpp(15, 6,19,1),fpp(15, 6,19,2),fpp(15, 6,19,3)/
     x-8.1455991d-03,-1.4856316d-04, 6.0656863d-07 /
      data fpp(15, 6,20,1),fpp(15, 6,20,2),fpp(15, 6,20,3)/
     x 5.2982748d-03,-1.2131649d-04,-1.1342325d-04 /
      data fpp(15, 6,21,1),fpp(15, 6,21,2),fpp(15, 6,21,3)/
     x 5.2982748d-03,-1.2131649d-04,-1.1148552d-04 /
      data fpp(15, 6,22,1),fpp(15, 6,22,2),fpp(15, 6,22,3)/
     x-8.1455991d-03,-1.4856316d-04,-7.1443504d-06 /
      data fpp(15, 6,23,1),fpp(15, 6,23,2),fpp(15, 6,23,3)/
     x-1.1874745d-02,-1.2570435d-05, 4.2064925d-05 /
      data fpp(15, 7, 1,1),fpp(15, 7, 1,2),fpp(15, 7, 1,3)/
     x 2.3280765d-03, 4.2346455d-05,-8.3404056d-06 /
      data fpp(15, 7, 2,1),fpp(15, 7, 2,2),fpp(15, 7, 2,3)/
     x 8.0857822d-03, 1.4900862d-04,-1.6201689d-05 /
      data fpp(15, 7, 3,1),fpp(15, 7, 3,2),fpp(15, 7, 3,3)/
     x 1.4907778d-02, 3.2012693d-04,-3.3094839d-05 /
      data fpp(15, 7, 4,1),fpp(15, 7, 4,2),fpp(15, 7, 4,3)/
     x 1.4907778d-02, 3.2012693d-04,-3.3011639d-05 /
      data fpp(15, 7, 5,1),fpp(15, 7, 5,2),fpp(15, 7, 5,3)/
     x 8.0857822d-03, 1.4900862d-04,-1.6534489d-05 /
      data fpp(15, 7, 6,1),fpp(15, 7, 6,2),fpp(15, 7, 6,3)/
     x 2.3280765d-03, 4.2346455d-05,-7.0924059d-06 /
      data fpp(15, 7, 7,1),fpp(15, 7, 7,2),fpp(15, 7, 7,3)/
     x-2.2129718d-03,-3.1660193d-06, 4.8011223d-07 /
      data fpp(15, 7, 8,1),fpp(15, 7, 8,2),fpp(15, 7, 8,3)/
     x-5.9861224d-03,-3.3305664d-05, 6.0119569d-06 /
      data fpp(15, 7, 9,1),fpp(15, 7, 9,2),fpp(15, 7, 9,3)/
     x-9.1457694d-03,-4.7044088d-05, 1.0800060d-05 /
      data fpp(15, 7,10,1),fpp(15, 7,10,2),fpp(15, 7,10,3)/
     x-1.1511615d-02,-5.3577651d-05, 1.4945803d-05 /
      data fpp(15, 7,11,1),fpp(15, 7,11,2),fpp(15, 7,11,3)/
     x-1.3022111d-02,-5.5971818d-05, 1.8108728d-05 /
      data fpp(15, 7,12,1),fpp(15, 7,12,2),fpp(15, 7,12,3)/
     x-1.3684953d-02,-5.5786984d-05, 1.9995284d-05 /
      data fpp(15, 7,13,1),fpp(15, 7,13,2),fpp(15, 7,13,3)/
     x-1.3590150d-02,-5.3435631d-05, 2.0680135d-05 /
      data fpp(15, 7,14,1),fpp(15, 7,14,2),fpp(15, 7,14,3)/
     x-1.2704591d-02,-4.8549687d-05, 2.0416176d-05 /
      data fpp(15, 7,15,1),fpp(15, 7,15,2),fpp(15, 7,15,3)/
     x-1.1099284d-02,-3.9954652d-05, 1.9401162d-05 /
      data fpp(15, 7,16,1),fpp(15, 7,16,2),fpp(15, 7,16,3)/
     x-9.1384085d-03,-2.5497965d-05, 1.6927177d-05 /
      data fpp(15, 7,17,1),fpp(15, 7,17,2),fpp(15, 7,17,3)/
     x-5.3584955d-03,-8.5284782d-08, 1.1926130d-05 /
      data fpp(15, 7,18,1),fpp(15, 7,18,2),fpp(15, 7,18,3)/
     x-9.5570390d-04, 4.1090453d-05, 9.6630118d-07 /
      data fpp(15, 7,19,1),fpp(15, 7,19,2),fpp(15, 7,19,3)/
     x 4.9673042d-03, 1.3304963d-04,-1.5515335d-05 /
      data fpp(15, 7,20,1),fpp(15, 7,20,2),fpp(15, 7,20,3)/
     x 1.1793730d-02, 1.9704513d-04,-4.7966960d-05 /
      data fpp(15, 7,21,1),fpp(15, 7,21,2),fpp(15, 7,21,3)/
     x 1.1793730d-02, 1.9704513d-04,-4.8030451d-05 /
      data fpp(15, 7,22,1),fpp(15, 7,22,2),fpp(15, 7,22,3)/
     x 4.9673042d-03, 1.3304963d-04,-1.5261371d-05 /
      data fpp(15, 7,23,1),fpp(15, 7,23,2),fpp(15, 7,23,3)/
     x-9.5570390d-04, 4.1090453d-05, 1.3935517d-08 /
      data fpp(15, 8, 1,1),fpp(15, 8, 1,2),fpp(15, 8, 1,3)/
     x 1.0195831d-02, 7.8960524d-06, 7.8301401d-05 /
      data fpp(15, 8, 2,1),fpp(15, 8, 2,2),fpp(15, 8, 2,3)/
     x 1.3084048d-02, 1.8469556d-05, 3.8119698d-05 /
      data fpp(15, 8, 3,1),fpp(15, 8, 3,2),fpp(15, 8, 3,3)/
     x-1.7084679d+00,-1.6067255d-05,-4.3994193d-05 /
      data fpp(15, 8, 4,1),fpp(15, 8, 4,2),fpp(15, 8, 4,3)/
     x-1.7084679d+00,-1.6067255d-05,-5.0976271d-05 /
      data fpp(15, 8, 5,1),fpp(15, 8, 5,2),fpp(15, 8, 5,3)/
     x 1.3084048d-02, 1.8469556d-05, 6.6048012d-05 /
      data fpp(15, 8, 6,1),fpp(15, 8, 6,2),fpp(15, 8, 6,3)/
     x 1.0195831d-02, 7.8960524d-06,-2.6429775d-05 /
      data fpp(15, 8, 7,1),fpp(15, 8, 7,2),fpp(15, 8, 7,3)/
     x 6.9218229d-03,-1.5522802d-05, 2.3309007d-07 /
      data fpp(15, 8, 8,1),fpp(15, 8, 8,2),fpp(15, 8, 8,3)/
     x 3.1067345d-03,-3.3048428d-05,-4.1365848d-06 /
      data fpp(15, 8, 9,1),fpp(15, 8, 9,2),fpp(15, 8, 9,3)/
     x-5.0278097d-04,-4.5444434d-05, 1.7152493d-06 /
      data fpp(15, 8,10,1),fpp(15, 8,10,2),fpp(15, 8,10,3)/
     x-4.0030948d-03,-5.2584440d-05, 5.9035876d-06 /
      data fpp(15, 8,11,1),fpp(15, 8,11,2),fpp(15, 8,11,3)/
     x-6.5187526d-03,-5.5722432d-05, 9.9204002d-06 /
      data fpp(15, 8,12,1),fpp(15, 8,12,2),fpp(15, 8,12,3)/
     x-7.9284699d-03,-5.5439988d-05, 1.2356812d-05 /
      data fpp(15, 8,13,1),fpp(15, 8,13,2),fpp(15, 8,13,3)/
     x-8.3043155d-03,-5.2023617d-05, 1.3372354d-05 /
      data fpp(15, 8,14,1),fpp(15, 8,14,2),fpp(15, 8,14,3)/
     x-7.7234471d-03,-4.5600920d-05, 1.3215774d-05 /
      data fpp(15, 8,15,1),fpp(15, 8,15,2),fpp(15, 8,15,3)/
     x-6.2521177d-03,-3.6141607d-05, 1.2046551d-05 /
      data fpp(15, 8,16,1),fpp(15, 8,16,2),fpp(15, 8,16,3)/
     x-3.9043040d-03,-2.3414992d-05, 9.6560204d-06 /
      data fpp(15, 8,17,1),fpp(15, 8,17,2),fpp(15, 8,17,3)/
     x-8.8060586d-04,-7.7749490d-06, 5.5913669d-06 /
      data fpp(15, 8,18,1),fpp(15, 8,18,2),fpp(15, 8,18,3)/
     x 2.8949150d-03, 9.8606207d-06,-1.2054879d-06 /
      data fpp(15, 8,19,1),fpp(15, 8,19,2),fpp(15, 8,19,3)/
     x 7.2703559d-03, 1.7950625d-05,-1.0195415d-05 /
      data fpp(15, 8,20,1),fpp(15, 8,20,2),fpp(15, 8,20,3)/
     x 1.1414572d-02, 3.0191971d-05,-2.2602851d-05 /
      data fpp(15, 8,21,1),fpp(15, 8,21,2),fpp(15, 8,21,3)/
     x 1.1414572d-02, 3.0191971d-05,-2.2754740d-05 /
      data fpp(15, 8,22,1),fpp(15, 8,22,2),fpp(15, 8,22,3)/
     x 7.2703559d-03, 1.7950625d-05,-9.5878601d-06 /
      data fpp(15, 8,23,1),fpp(15, 8,23,2),fpp(15, 8,23,3)/
     x 2.8949150d-03, 9.8606207d-06,-3.4838200d-06 /
      data fpp(15, 9, 1,1),fpp(15, 9, 1,2),fpp(15, 9, 1,3)/
     x 1.3976459d-02,-1.6660665d-05, 9.3011074d-05 /
      data fpp(15, 9, 2,1),fpp(15, 9, 2,2),fpp(15, 9, 2,3)/
     x 8.1762377d-03, 2.1511153d-05, 4.7922352d-05 /
      data fpp(15, 9, 3,1),fpp(15, 9, 3,2),fpp(15, 9, 3,3)/
     x-1.9486768d+00,-6.3863908d-05,-4.4418481d-05 /
      data fpp(15, 9, 4,1),fpp(15, 9, 4,2),fpp(15, 9, 4,3)/
     x-1.9486768d+00,-6.3863908d-05,-5.1904733d-05 /
      data fpp(15, 9, 5,1),fpp(15, 9, 5,2),fpp(15, 9, 5,3)/
     x 8.1762377d-03, 2.1511153d-05, 7.7867361d-05 /
      data fpp(15, 9, 6,1),fpp(15, 9, 6,2),fpp(15, 9, 6,3)/
     x 1.3976459d-02,-1.6660665d-05,-1.9282709d-05 /
      data fpp(15, 9, 7,1),fpp(15, 9, 7,2),fpp(15, 9, 7,3)/
     x 1.3093363d-02,-2.7094773d-05, 2.3174759d-06 /
      data fpp(15, 9, 8,1),fpp(15, 9, 8,2),fpp(15, 9, 8,3)/
     x 1.0838236d-02,-3.2722624d-05,-6.3431945d-06 /
      data fpp(15, 9, 9,1),fpp(15, 9, 9,2),fpp(15, 9, 9,3)/
     x 7.6238048d-03,-3.6678174d-05,-2.8766980d-06 /
      data fpp(15, 9,10,1),fpp(15, 9,10,2),fpp(15, 9,10,3)/
     x 3.9382351d-03,-3.9318587d-05, 4.9198653d-07 /
      data fpp(15, 9,11,1),fpp(15, 9,11,2),fpp(15, 9,11,3)/
     x 8.3263451d-04,-4.0164455d-05, 4.6587519d-06 /
      data fpp(15, 9,12,1),fpp(15, 9,12,2),fpp(15, 9,12,3)/
     x-1.3799236d-03,-3.9223063d-05, 7.4290059d-06 /
      data fpp(15, 9,13,1),fpp(15, 9,13,2),fpp(15, 9,13,3)/
     x-2.3687437d-03,-3.6513902d-05, 8.7652246d-06 /
      data fpp(15, 9,14,1),fpp(15, 9,14,2),fpp(15, 9,14,3)/
     x-2.3713032d-03,-3.1930631d-05, 8.9360959d-06 /
      data fpp(15, 9,15,1),fpp(15, 9,15,2),fpp(15, 9,15,3)/
     x-1.5775362d-03,-2.5352922d-05, 8.1583919d-06 /
      data fpp(15, 9,16,1),fpp(15, 9,16,2),fpp(15, 9,16,3)/
     x-1.2279004d-05,-1.6808066d-05, 6.4963363d-06 /
      data fpp(15, 9,17,1),fpp(15, 9,17,2),fpp(15, 9,17,3)/
     x 2.2069096d-03,-6.4529191d-06, 3.7642627d-06 /
      data fpp(15, 9,18,1),fpp(15, 9,18,2),fpp(15, 9,18,3)/
     x 5.0369595d-03, 5.1470636d-06,-5.2938718d-07 /
      data fpp(15, 9,19,1),fpp(15, 9,19,2),fpp(15, 9,19,3)/
     x 8.2957296d-03, 1.9067863d-05,-5.8527140d-06 /
      data fpp(15, 9,20,1),fpp(15, 9,20,2),fpp(15, 9,20,3)/
     x 1.1215604d-02, 2.8122987d-05,-1.2401757d-05 /
      data fpp(15, 9,21,1),fpp(15, 9,21,2),fpp(15, 9,21,3)/
     x 1.1215604d-02, 2.8122987d-05,-1.2509373d-05 /
      data fpp(15, 9,22,1),fpp(15, 9,22,2),fpp(15, 9,22,3)/
     x 8.2957296d-03, 1.9067863d-05,-5.4222507d-06 /
      data fpp(15, 9,23,1),fpp(15, 9,23,2),fpp(15, 9,23,3)/
     x 5.0369595d-03, 5.1470636d-06,-2.1436247d-06 /
      data fpp(15,10, 1,1),fpp(15,10, 1,2),fpp(15,10, 1,3)/
     x-1.3619899d-02,-7.9979393d-05,-2.3794436d-05 /
      data fpp(15,10, 2,1),fpp(15,10, 2,2),fpp(15,10, 2,3)/
     x-3.3414793d-02,-1.7629817d-04,-1.5451128d-05 /
      data fpp(15,10, 3,1),fpp(15,10, 3,2),fpp(15,10, 3,3)/
     x-7.3408067d-02,-1.1226111d-04, 4.3494727d-07 /
      data fpp(15,10, 4,1),fpp(15,10, 4,2),fpp(15,10, 4,3)/
     x-7.3408067d-02,-1.1226111d-04, 3.9217221d-06 /
      data fpp(15,10, 5,1),fpp(15,10, 5,2),fpp(15,10, 5,3)/
     x-3.3414793d-02,-1.7629817d-04,-2.9398227d-05 /
      data fpp(15,10, 6,1),fpp(15,10, 6,2),fpp(15,10, 6,3)/
     x-1.3619899d-02,-7.9979393d-05, 2.8507186d-05 /
      data fpp(15,10, 7,1),fpp(15,10, 7,2),fpp(15,10, 7,3)/
     x 7.4552049d-03,-4.7668107d-05,-4.9865178d-06 /
      data fpp(15,10, 8,1),fpp(15,10, 8,2),fpp(15,10, 8,3)/
     x 1.2681399d-02,-3.4127074d-05,-5.2911152d-06 /
      data fpp(15,10, 9,1),fpp(15,10, 9,2),fpp(15,10, 9,3)/
     x 1.2295126d-02,-2.8306869d-05,-7.0170215d-06 /
      data fpp(15,10,10,1),fpp(15,10,10,2),fpp(15,10,10,3)/
     x 9.7407998d-03,-2.6001210d-05,-2.9827987d-06 /
      data fpp(15,10,11,1),fpp(15,10,11,2),fpp(15,10,11,3)/
     x 6.7327280d-03,-2.4933750d-05, 1.1402165d-06 /
      data fpp(15,10,12,1),fpp(15,10,12,2),fpp(15,10,12,3)/
     x 4.2752076d-03,-2.3713761d-05, 4.3139327d-06 /
      data fpp(15,10,13,1),fpp(15,10,13,2),fpp(15,10,13,3)/
     x 2.8054172d-03,-2.1820775d-05, 6.0420527d-06 /
      data fpp(15,10,14,1),fpp(15,10,14,2),fpp(15,10,14,3)/
     x 2.2211143d-03,-1.9096556d-05, 6.6418565d-06 /
      data fpp(15,10,15,1),fpp(15,10,15,2),fpp(15,10,15,3)/
     x 2.4292746d-03,-1.5536707d-05, 6.2945212d-06 /
      data fpp(15,10,16,1),fpp(15,10,16,2),fpp(15,10,16,3)/
     x 3.3353659d-03,-1.1196744d-05, 5.1700587d-06 /
      data fpp(15,10,17,1),fpp(15,10,17,2),fpp(15,10,17,3)/
     x 4.7755079d-03,-6.3733744d-06, 3.2172439d-06 /
      data fpp(15,10,18,1),fpp(15,10,18,2),fpp(15,10,18,3)/
     x 6.8202571d-03,-1.7088751d-06, 8.9655291d-09 /
      data fpp(15,10,19,1),fpp(15,10,19,2),fpp(15,10,19,3)/
     x 9.2220991d-03, 1.4719207d-06,-3.9851061d-06 /
      data fpp(15,10,20,1),fpp(15,10,20,2),fpp(15,10,20,3)/
     x 1.1535531d-02, 3.8840827d-06,-8.2425413d-06 /
      data fpp(15,10,21,1),fpp(15,10,21,2),fpp(15,10,21,3)/
     x 1.1535531d-02, 3.8840827d-06,-8.3378230d-06 /
      data fpp(15,10,22,1),fpp(15,10,22,2),fpp(15,10,22,3)/
     x 9.2220991d-03, 1.4719207d-06,-3.6039791d-06 /
      data fpp(15,10,23,1),fpp(15,10,23,2),fpp(15,10,23,3)/
     x 6.8202571d-03,-1.7088751d-06,-1.4202604d-06 /
      data fpp(15,11, 1,1),fpp(15,11, 1,2),fpp(15,11, 1,3)/
     x-8.9215300d-02,-2.4757620d-06, 1.1256773d-05 /
      data fpp(15,11, 2,1),fpp(15,11, 2,2),fpp(15,11, 2,3)/
     x-6.6680087d-02, 9.2159517d-05, 1.0736454d-05 /
      data fpp(15,11, 3,1),fpp(15,11, 3,2),fpp(15,11, 3,3)/
     x-1.1536143d-01, 1.4384836d-04, 1.0117412d-05 /
      data fpp(15,11, 4,1),fpp(15,11, 4,2),fpp(15,11, 4,3)/
     x-1.1536143d-01, 1.4384836d-04, 9.2495360d-06 /
      data fpp(15,11, 5,1),fpp(15,11, 5,2),fpp(15,11, 5,3)/
     x-6.6680087d-02, 9.2159517d-05, 1.4207959d-05 /
      data fpp(15,11, 6,1),fpp(15,11, 6,2),fpp(15,11, 6,3)/
     x-8.9215300d-02,-2.4757620d-06,-1.7613725d-06 /
      data fpp(15,11, 7,1),fpp(15,11, 7,2),fpp(15,11, 7,3)/
     x-2.2104156d-02,-2.1380800d-05,-3.4904692d-06 /
      data fpp(15,11, 8,1),fpp(15,11, 8,2),fpp(15,11, 8,3)/
     x 3.5190650d-03,-2.1347078d-05,-1.2716751d-05 /
      data fpp(15,11, 9,1),fpp(15,11, 9,2),fpp(15,11, 9,3)/
     x 1.1307680d-02,-1.8268349d-05,-1.2212528d-05 /
      data fpp(15,11,10,1),fpp(15,11,10,2),fpp(15,11,10,3)/
     x 1.1958816d-02,-1.6060573d-05,-7.3731391d-06 /
      data fpp(15,11,11,1),fpp(15,11,11,2),fpp(15,11,11,3)/
     x 1.0107976d-02,-1.4864546d-05,-1.8309159d-06 /
      data fpp(15,11,12,1),fpp(15,11,12,2),fpp(15,11,12,3)/
     x 7.9571678d-03,-1.3995894d-05, 1.9948028d-06 /
      data fpp(15,11,13,1),fpp(15,11,13,2),fpp(15,11,13,3)/
     x 6.4708933d-03,-1.2912997d-05, 4.2617048d-06 /
      data fpp(15,11,14,1),fpp(15,11,14,2),fpp(15,11,14,3)/
     x 5.6834233d-03,-1.1527146d-05, 5.2823778d-06 /
      data fpp(15,11,15,1),fpp(15,11,15,2),fpp(15,11,15,3)/
     x 5.5836329d-03,-9.9042503d-06, 5.3227838d-06 /
      data fpp(15,11,16,1),fpp(15,11,16,2),fpp(15,11,16,3)/
     x 6.1038604d-03,-8.1909569d-06, 4.5184871d-06 /
      data fpp(15,11,17,1),fpp(15,11,17,2),fpp(15,11,17,3)/
     x 7.1974911d-03,-6.5495831d-06, 2.7512677d-06 /
      data fpp(15,11,18,1),fpp(15,11,18,2),fpp(15,11,18,3)/
     x 8.6807866d-03,-5.1395630d-06,-7.3558055d-08 /
      data fpp(15,11,19,1),fpp(15,11,19,2),fpp(15,11,19,3)/
     x 1.0501906d-02,-3.8835464d-06,-3.4830355d-06 /
      data fpp(15,11,20,1),fpp(15,11,20,2),fpp(15,11,20,3)/
     x 1.2340647d-02,-3.0393174d-06,-6.3522999d-06 /
      data fpp(15,11,21,1),fpp(15,11,21,2),fpp(15,11,21,3)/
     x 1.2340647d-02,-3.0393174d-06,-6.4505825d-06 /
      data fpp(15,11,22,1),fpp(15,11,22,2),fpp(15,11,22,3)/
     x 1.0501906d-02,-3.8835464d-06,-3.0899050d-06 /
      data fpp(15,11,23,1),fpp(15,11,23,2),fpp(15,11,23,3)/
     x 8.6807866d-03,-5.1395630d-06,-1.5477975d-06 /
      data fpp(15,12, 1,1),fpp(15,12, 1,2),fpp(15,12, 1,3)/
     x-1.1265673d-01, 5.1386441d-05, 6.6104391d-05 /
      data fpp(15,12, 2,1),fpp(15,12, 2,2),fpp(15,12, 2,3)/
     x-1.5025075d-01, 6.4160100d-05, 3.9171219d-05 /
      data fpp(15,12, 3,1),fpp(15,12, 3,2),fpp(15,12, 3,3)/
     x-9.5638846d-02, 8.0371664d-05,-1.6977266d-05 /
      data fpp(15,12, 4,1),fpp(15,12, 4,2),fpp(15,12, 4,3)/
     x-9.5638846d-02, 8.0371664d-05,-1.9716812d-05 /
      data fpp(15,12, 5,1),fpp(15,12, 5,2),fpp(15,12, 5,3)/
     x-1.5025075d-01, 6.4160100d-05, 5.0129405d-05 /
      data fpp(15,12, 6,1),fpp(15,12, 6,2),fpp(15,12, 6,3)/
     x-1.1265673d-01, 5.1386441d-05, 2.5011193d-05 /
      data fpp(15,12, 7,1),fpp(15,12, 7,2),fpp(15,12, 7,3)/
     x-5.2423814d-02, 2.2203305d-05, 2.9822042d-08 /
      data fpp(15,12, 8,1),fpp(15,12, 8,2),fpp(15,12, 8,3)/
     x-1.3296476d-02, 4.5193864d-06,-1.6796481d-05 /
      data fpp(15,12, 9,1),fpp(15,12, 9,2),fpp(15,12, 9,3)/
     x 4.8073227d-03,-3.4517331d-06,-1.8643896d-05 /
      data fpp(15,12,10,1),fpp(15,12,10,2),fpp(15,12,10,3)/
     x 1.0735576d-02,-6.5124963d-06,-1.2253934d-05 /
      data fpp(15,12,11,1),fpp(15,12,11,2),fpp(15,12,11,3)/
     x 1.1128275d-02,-7.5520671d-06,-4.8683680d-06 /
      data fpp(15,12,12,1),fpp(15,12,12,2),fpp(15,12,12,3)/
     x 9.8457820d-03,-7.8006629d-06, 6.5406117d-08 /
      data fpp(15,12,13,1),fpp(15,12,13,2),fpp(15,12,13,3)/
     x 8.6413282d-03,-7.7072357d-06, 2.8607436d-06 /
      data fpp(15,12,14,1),fpp(15,12,14,2),fpp(15,12,14,3)/
     x 7.9789694d-03,-7.4488604d-06, 4.2236196d-06 /
      data fpp(15,12,15,1),fpp(15,12,15,2),fpp(15,12,15,3)/
     x 7.9035739d-03,-7.2222918d-06, 4.5207781d-06 /
      data fpp(15,12,16,1),fpp(15,12,16,2),fpp(15,12,16,3)/
     x 8.4114597d-03,-7.1534283d-06, 3.8712682d-06 /
      data fpp(15,12,17,1),fpp(15,12,17,2),fpp(15,12,17,3)/
     x 9.3074163d-03,-7.2742933d-06, 2.1041493d-06 /
      data fpp(15,12,18,1),fpp(15,12,18,2),fpp(15,12,18,3)/
     x 1.0504717d-02,-7.4088728d-06,-5.3386545d-07 /
      data fpp(15,12,19,1),fpp(15,12,19,2),fpp(15,12,19,3)/
     x 1.1928937d-02,-7.4177353d-06,-3.2626875d-06 /
      data fpp(15,12,20,1),fpp(15,12,20,2),fpp(15,12,20,3)/
     x 1.3343306d-02,-7.2308131d-06,-5.1773844d-06 /
      data fpp(15,12,21,1),fpp(15,12,21,2),fpp(15,12,21,3)/
     x 1.3343306d-02,-7.2308131d-06,-5.2645030d-06 /
      data fpp(15,12,22,1),fpp(15,12,22,2),fpp(15,12,22,3)/
     x 1.1928937d-02,-7.4177353d-06,-2.9142134d-06 /
      data fpp(15,12,23,1),fpp(15,12,23,2),fpp(15,12,23,3)/
     x 1.0504717d-02,-7.4088728d-06,-1.8406433d-06 /
      data fpp(15,13, 1,1),fpp(15,13, 1,2),fpp(15,13, 1,3)/
     x-1.3368894d-01, 3.3647997d-05, 1.0882215d-04 /
      data fpp(15,13, 2,1),fpp(15,13, 2,2),fpp(15,13, 2,3)/
     x-1.6531397d-01, 8.8360831d-06, 5.7370703d-05 /
      data fpp(15,13, 3,1),fpp(15,13, 3,2),fpp(15,13, 3,3)/
     x-1.5853965d-01,-4.6397020d-05,-5.0616960d-05 /
      data fpp(15,13, 4,1),fpp(15,13, 4,2),fpp(15,13, 4,3)/
     x-1.5853965d-01,-4.6397020d-05,-5.4581472d-05 /
      data fpp(15,13, 5,1),fpp(15,13, 5,2),fpp(15,13, 5,3)/
     x-1.6531397d-01, 8.8360831d-06, 7.3228750d-05 /
      data fpp(15,13, 6,1),fpp(15,13, 6,2),fpp(15,13, 6,3)/
     x-1.3368894d-01, 3.3647997d-05, 4.9354470d-05 /
      data fpp(15,13, 7,1),fpp(15,13, 7,2),fpp(15,13, 7,3)/
     x-7.6603317d-02, 3.7009578d-05, 1.4731369d-05 /
      data fpp(15,13, 8,1),fpp(15,13, 8,2),fpp(15,13, 8,3)/
     x-3.1301188d-02, 2.4425533d-05,-1.4181947d-05 /
      data fpp(15,13, 9,1),fpp(15,13, 9,2),fpp(15,13, 9,3)/
     x-4.3867560d-03, 1.1621282d-05,-2.1357583d-05 /
      data fpp(15,13,10,1),fpp(15,13,10,2),fpp(15,13,10,3)/
     x 7.2888394d-03, 3.2725586d-06,-1.5473722d-05 /
      data fpp(15,13,11,1),fpp(15,13,11,2),fpp(15,13,11,3)/
     x 1.0459956d-02,-1.0251859d-06,-7.1435276d-06 /
      data fpp(15,13,12,1),fpp(15,13,12,2),fpp(15,13,12,3)/
     x 1.0437644d-02,-3.0474543d-06,-1.4621670d-06 /
      data fpp(15,13,13,1),fpp(15,13,13,2),fpp(15,13,13,3)/
     x 9.7371676d-03,-4.0600600d-06, 1.6821957d-06 /
      data fpp(15,13,14,1),fpp(15,13,14,2),fpp(15,13,14,3)/
     x 9.3276299d-03,-4.7274125d-06, 3.1813842d-06 /
      data fpp(15,13,15,1),fpp(15,13,15,2),fpp(15,13,15,3)/
     x 9.3899634d-03,-5.3365825d-06, 3.5982674d-06 /
      data fpp(15,13,16,1),fpp(15,13,16,2),fpp(15,13,16,3)/
     x 9.9703128d-03,-6.0593301d-06, 3.0355461d-06 /
      data fpp(15,13,17,1),fpp(15,13,17,2),fpp(15,13,17,3)/
     x 1.0938473d-02,-6.8512439d-06, 1.4315483d-06 /
      data fpp(15,13,18,1),fpp(15,13,18,2),fpp(15,13,18,3)/
     x 1.1946399d-02,-7.5009458d-06,-8.4773942d-07 /
      data fpp(15,13,19,1),fpp(15,13,19,2),fpp(15,13,19,3)/
     x 1.2957680d-02,-7.7915124d-06,-2.8945906d-06 /
      data fpp(15,13,20,1),fpp(15,13,20,2),fpp(15,13,20,3)/
     x 1.3940905d-02,-7.9194301d-06,-4.2058980d-06 /
      data fpp(15,13,21,1),fpp(15,13,21,2),fpp(15,13,21,3)/
     x 1.3940905d-02,-7.9194301d-06,-4.2740107d-06 /
      data fpp(15,13,22,1),fpp(15,13,22,2),fpp(15,13,22,3)/
     x 1.2957680d-02,-7.7915124d-06,-2.6221398d-06 /
      data fpp(15,13,23,1),fpp(15,13,23,2),fpp(15,13,23,3)/
     x 1.1946399d-02,-7.5009458d-06,-1.8694301d-06 /
      data fpp(15,14, 1,1),fpp(15,14, 1,2),fpp(15,14, 1,3)/
     x-1.4487884d-01, 3.3717571d-05, 9.4849756d-05 /
      data fpp(15,14, 2,1),fpp(15,14, 2,2),fpp(15,14, 2,3)/
     x-1.6157834d-01,-4.7884323d-06, 4.8390987d-05 /
      data fpp(15,14, 3,1),fpp(15,14, 3,2),fpp(15,14, 3,3)/
     x-1.5259738d-01,-5.5661585d-05,-4.9463705d-05 /
      data fpp(15,14, 4,1),fpp(15,14, 4,2),fpp(15,14, 4,3)/
     x-1.5259738d-01,-5.5661585d-05,-5.2438378d-05 /
      data fpp(15,14, 5,1),fpp(15,14, 5,2),fpp(15,14, 5,3)/
     x-1.6157834d-01,-4.7884323d-06, 6.0289677d-05 /
      data fpp(15,14, 6,1),fpp(15,14, 6,2),fpp(15,14, 6,3)/
     x-1.4487884d-01, 3.3717571d-05, 5.0229671d-05 /
      data fpp(15,14, 7,1),fpp(15,14, 7,2),fpp(15,14, 7,3)/
     x-9.6930201d-02, 3.5522381d-05, 2.0431639d-05 /
      data fpp(15,14, 8,1),fpp(15,14, 8,2),fpp(15,14, 8,3)/
     x-4.9240487d-02, 3.1734484d-05,-9.9702260d-06 /
      data fpp(15,14, 9,1),fpp(15,14, 9,2),fpp(15,14, 9,3)/
     x-1.4377312d-02, 2.0956605d-05,-1.9616735d-05 /
      data fpp(15,14,10,1),fpp(15,14,10,2),fpp(15,14,10,3)/
     x 3.0159772d-03, 1.0762262d-05,-1.4792835d-05 /
      data fpp(15,14,11,1),fpp(15,14,11,2),fpp(15,14,11,3)/
     x 8.9036401d-03, 4.4108107d-06,-7.4079262d-06 /
      data fpp(15,14,12,1),fpp(15,14,12,2),fpp(15,14,12,3)/
     x 1.0223777d-02, 9.8847997d-07,-2.1114604d-06 /
      data fpp(15,14,13,1),fpp(15,14,13,2),fpp(15,14,13,3)/
     x 1.0147633d-02,-9.7652426d-07, 8.1776773d-07 /
      data fpp(15,14,14,1),fpp(15,14,14,2),fpp(15,14,14,3)/
     x 9.9540810d-03,-2.2854898d-06, 2.2063894d-06 /
      data fpp(15,14,15,1),fpp(15,14,15,2),fpp(15,14,15,3)/
     x 1.0103174d-02,-3.3213783d-06, 2.5666745d-06 /
      data fpp(15,14,16,1),fpp(15,14,16,2),fpp(15,14,16,3)/
     x 1.0723891d-02,-4.2012513d-06, 2.1129126d-06 /
      data fpp(15,14,17,1),fpp(15,14,17,2),fpp(15,14,17,3)/
     x 1.1560843d-02,-4.9627311d-06, 8.6767502d-07 /
      data fpp(15,14,18,1),fpp(15,14,18,2),fpp(15,14,18,3)/
     x 1.2411155d-02,-5.5773439d-06,-8.0761272d-07 /
      data fpp(15,14,19,1),fpp(15,14,19,2),fpp(15,14,19,3)/
     x 1.3190122d-02,-6.0502150d-06,-2.3472241d-06 /
      data fpp(15,14,20,1),fpp(15,14,20,2),fpp(15,14,20,3)/
     x 1.3766767d-02,-6.2534666d-06,-3.1894907d-06 /
      data fpp(15,14,21,1),fpp(15,14,21,2),fpp(15,14,21,3)/
     x 1.3766767d-02,-6.2534666d-06,-3.2439157d-06 /
      data fpp(15,14,22,1),fpp(15,14,22,2),fpp(15,14,22,3)/
     x 1.3190122d-02,-6.0502150d-06,-2.1295241d-06 /
      data fpp(15,14,23,1),fpp(15,14,23,2),fpp(15,14,23,3)/
     x 1.2411155d-02,-5.5773439d-06,-1.6239880d-06 /
      data fpp(15,15, 1,1),fpp(15,15, 1,2),fpp(15,15, 1,3)/
     x-1.3664041d-01, 1.9119720d-05, 4.0678013d-05 /
      data fpp(15,15, 2,1),fpp(15,15, 2,2),fpp(15,15, 2,3)/
     x-1.7603220d-01, 3.8751646d-05, 2.2243475d-05 /
      data fpp(15,15, 3,1),fpp(15,15, 3,2),fpp(15,15, 3,3)/
     x-1.0219021d-01, 6.0783361d-05,-1.6929912d-05 /
      data fpp(15,15, 4,1),fpp(15,15, 4,2),fpp(15,15, 4,3)/
     x-1.0219021d-01, 6.0783361d-05,-1.7506001d-05 /
      data fpp(15,15, 5,1),fpp(15,15, 5,2),fpp(15,15, 5,3)/
     x-1.7603220d-01, 3.8751646d-05, 2.4547829d-05 /
      data fpp(15,15, 6,1),fpp(15,15, 6,2),fpp(15,15, 6,3)/
     x-1.3664041d-01, 1.9119720d-05, 3.2036685d-05 /
      data fpp(15,15, 7,1),fpp(15,15, 7,2),fpp(15,15, 7,3)/
     x-1.1102467d-01, 5.2932898d-05, 1.0397431d-05 /
      data fpp(15,15, 8,1),fpp(15,15, 8,2),fpp(15,15, 8,3)/
     x-6.8218699d-02, 3.8506533d-05,-1.0308408d-05 /
      data fpp(15,15, 9,1),fpp(15,15, 9,2),fpp(15,15, 9,3)/
     x-2.2478854d-02, 2.1912296d-05,-1.4289797d-05 /
      data fpp(15,15,10,1),fpp(15,15,10,2),fpp(15,15,10,3)/
     x-3.0136768d-04, 1.2610394d-05,-9.8244038d-06 /
      data fpp(15,15,11,1),fpp(15,15,11,2),fpp(15,15,11,3)/
     x 7.3798242d-03, 7.2559430d-06,-5.0385880d-06 /
      data fpp(15,15,12,1),fpp(15,15,12,2),fpp(15,15,12,3)/
     x 9.5466076d-03, 3.9475344d-06,-1.5452442d-06 /
      data fpp(15,15,13,1),fpp(15,15,13,2),fpp(15,15,13,3)/
     x 1.0033558d-02, 1.8461571d-06, 5.0356473d-07 /
      data fpp(15,15,14,1),fpp(15,15,14,2),fpp(15,15,14,3)/
     x 1.0135709d-02, 4.1737157d-07, 1.4569853d-06 /
      data fpp(15,15,15,1),fpp(15,15,15,2),fpp(15,15,15,3)/
     x 1.0293014d-02,-5.7790414d-07, 1.6664942d-06 /
      data fpp(15,15,16,1),fpp(15,15,16,2),fpp(15,15,16,3)/
     x 1.0769092d-02,-1.2256647d-06, 1.2970379d-06 /
      data fpp(15,15,17,1),fpp(15,15,17,2),fpp(15,15,17,3)/
     x 1.1371571d-02,-1.5458317d-06, 4.7735411d-07 /
      data fpp(15,15,18,1),fpp(15,15,18,2),fpp(15,15,18,3)/
     x 1.1986243d-02,-1.6296786d-06,-6.0245434d-07 /
      data fpp(15,15,19,1),fpp(15,15,19,2),fpp(15,15,19,3)/
     x 1.2521039d-02,-1.5536275d-06,-1.5475367d-06 /
      data fpp(15,15,20,1),fpp(15,15,20,2),fpp(15,15,20,3)/
     x 1.2846250d-02,-1.4707037d-06,-2.0993987d-06 /
      data fpp(15,15,21,1),fpp(15,15,21,2),fpp(15,15,21,3)/
     x 1.2846250d-02,-1.4707037d-06,-2.1320354d-06 /
      data fpp(15,15,22,1),fpp(15,15,22,2),fpp(15,15,22,3)/
     x 1.2521039d-02,-1.5536275d-06,-1.4169899d-06 /
      data fpp(15,15,23,1),fpp(15,15,23,2),fpp(15,15,23,3)/
     x 1.1986243d-02,-1.6296786d-06,-1.0920051d-06 /
      data fpp(15,16, 1,1),fpp(15,16, 1,2),fpp(15,16, 1,3)/
     x 5.9620676d-02, 1.7499555d-04,-1.3768500d-06 /
      data fpp(15,16, 2,1),fpp(15,16, 2,2),fpp(15,16, 2,3)/
     x-1.2966836d-01, 1.7286385d-04, 1.5687001d-06 /
      data fpp(15,16, 3,1),fpp(15,16, 3,2),fpp(15,16, 3,3)/
     x-1.2029924d-01, 1.9901814d-04, 7.1140498d-06 /
      data fpp(15,16, 4,1),fpp(15,16, 4,2),fpp(15,16, 4,3)/
     x-1.2029924d-01, 1.9901814d-04, 8.4555005d-06 /
      data fpp(15,16, 5,1),fpp(15,16, 5,2),fpp(15,16, 5,3)/
     x-1.2966836d-01, 1.7286385d-04,-3.7971027d-06 /
      data fpp(15,16, 6,1),fpp(15,16, 6,2),fpp(15,16, 6,3)/
     x 5.9620676d-02, 1.7499555d-04, 1.8744910d-05 /
      data fpp(15,16, 7,1),fpp(15,16, 7,2),fpp(15,16, 7,3)/
     x-2.4877456d-01, 1.1352027d-05,-1.5334538d-05 /
      data fpp(15,16, 8,1),fpp(15,16, 8,2),fpp(15,16, 8,3)/
     x-6.8796772d-02,-6.7686172d-06,-5.7847586d-06 /
      data fpp(15,16, 9,1),fpp(15,16, 9,2),fpp(15,16, 9,3)/
     x 4.1126623d-01,-3.1179077d-07,-3.7964276d-06 /
      data fpp(15,16,10,1),fpp(15,16,10,2),fpp(15,16,10,3)/
     x 3.3944785d-04, 4.2801625d-06,-2.4955310d-06 /
      data fpp(15,16,11,1),fpp(15,16,11,2),fpp(15,16,11,3)/
     x 6.8775330d-03, 5.3794173d-06,-1.1374486d-06 /
      data fpp(15,16,12,1),fpp(15,16,12,2),fpp(15,16,12,3)/
     x 9.0959650d-03, 4.8093825d-06,-2.2674761d-08 /
      data fpp(15,16,13,1),fpp(15,16,13,2),fpp(15,16,13,3)/
     x 9.8392553d-03, 3.8578960d-06, 7.3614762d-07 /
      data fpp(15,16,14,1),fpp(15,16,14,2),fpp(15,16,14,3)/
     x 1.0094832d-02, 3.0760035d-06, 1.0800843d-06 /
      data fpp(15,16,15,1),fpp(15,16,15,2),fpp(15,16,15,3)/
     x 1.0268704d-02, 2.6329949d-06, 1.0755152d-06 /
      data fpp(15,16,16,1),fpp(15,16,16,2),fpp(15,16,16,3)/
     x 1.0548833d-02, 2.5639101d-06, 7.9185497d-07 /
      data fpp(15,16,17,1),fpp(15,16,17,2),fpp(15,16,17,3)/
     x 1.0845851d-02, 2.8360580d-06, 3.0506494d-07 /
      data fpp(15,16,18,1),fpp(15,16,18,2),fpp(15,16,18,3)/
     x 1.1168832d-02, 3.3420582d-06,-2.5411473d-07 /
      data fpp(15,16,19,1),fpp(15,16,19,2),fpp(15,16,19,3)/
     x 1.1497304d-02, 3.8647249d-06,-7.4060604d-07 /
      data fpp(15,16,20,1),fpp(15,16,20,2),fpp(15,16,20,3)/
     x 1.1639536d-02, 4.2042814d-06,-1.0674611d-06 /
      data fpp(15,16,21,1),fpp(15,16,21,2),fpp(15,16,21,3)/
     x 1.1639536d-02, 4.2042814d-06,-1.0833136d-06 /
      data fpp(15,16,22,1),fpp(15,16,22,2),fpp(15,16,22,3)/
     x 1.1497304d-02, 3.8647249d-06,-6.7719611d-07 /
      data fpp(15,16,23,1),fpp(15,16,23,2),fpp(15,16,23,3)/
     x 1.1168832d-02, 3.3420582d-06,-4.9190194d-07 /
      data fpp(15,17, 1,1),fpp(15,17, 1,2),fpp(15,17, 1,3)/
     x-1.5260407d+00,-3.4998792d-04,-2.4858861d-06 /
      data fpp(15,17, 2,1),fpp(15,17, 2,2),fpp(15,17, 2,3)/
     x-8.9847638d-01,-3.0547304d-04, 6.2277216d-07 /
      data fpp(15,17, 3,1),fpp(15,17, 3,2),fpp(15,17, 3,3)/
     x-2.3699336d-01,-2.7575592d-04, 1.2042797d-05 /
      data fpp(15,17, 4,1),fpp(15,17, 4,2),fpp(15,17, 4,3)/
     x-2.3699336d-01,-2.7575592d-04, 3.7152216d-06 /
      data fpp(15,17, 5,1),fpp(15,17, 5,2),fpp(15,17, 5,3)/
     x-8.9847638d-01,-3.0547304d-04, 3.3933076d-05 /
      data fpp(15,17, 6,1),fpp(15,17, 6,2),fpp(15,17, 6,3)/
     x-1.5260407d+00,-3.4998792d-04,-1.2739952d-04 /
      data fpp(15,17, 7,1),fpp(15,17, 7,2),fpp(15,17, 7,3)/
     x-1.5287257d-02,-1.2119501d-04, 8.7921019d-05 /
      data fpp(15,17, 8,1),fpp(15,17, 8,2),fpp(15,17, 8,3)/
     x-3.9110681d-02,-5.9606065d-05,-1.7710553d-05 /
      data fpp(15,17, 9,1),fpp(15,17, 9,2),fpp(15,17, 9,3)/
     x 1.4029472d-04,-2.9137133d-05, 8.5291920d-06 /
      data fpp(15,17,10,1),fpp(15,17,10,2),fpp(15,17,10,3)/
     x 5.9004747d-03,-1.2241044d-05, 2.1378479d-07 /
      data fpp(15,17,11,1),fpp(15,17,11,2),fpp(15,17,11,3)/
     x 8.2900468d-03,-2.9676124d-06, 1.7636688d-06 /
      data fpp(15,17,12,1),fpp(15,17,12,2),fpp(15,17,12,3)/
     x 9.3686960d-03, 1.8529355d-06, 1.0355399d-06 /
      data fpp(15,17,13,1),fpp(15,17,13,2),fpp(15,17,13,3)/
     x 9.8694358d-03, 4.2442588d-06, 1.0781717d-06 /
      data fpp(15,17,14,1),fpp(15,17,14,2),fpp(15,17,14,3)/
     x 1.0057565d-02, 5.4946144d-06, 9.3977340d-07 /
      data fpp(15,17,15,1),fpp(15,17,15,2),fpp(15,17,15,3)/
     x 1.0185835d-02, 6.3239244d-06, 7.9673472d-07 /
      data fpp(15,17,16,1),fpp(15,17,16,2),fpp(15,17,16,3)/
     x 1.0299439d-02, 7.0980242d-06, 5.8928771d-07 /
      data fpp(15,17,17,1),fpp(15,17,17,2),fpp(15,17,17,3)/
     x 1.0438194d-02, 7.9135998d-06, 3.4411445d-07 /
      data fpp(15,17,18,1),fpp(15,17,18,2),fpp(15,17,18,3)/
     x 1.0578831d-02, 8.7214459d-06, 1.1025448d-07 /
      data fpp(15,17,19,1),fpp(15,17,19,2),fpp(15,17,19,3)/
     x 1.0637584d-02, 9.3987279d-06,-1.1313236d-07 /
      data fpp(15,17,20,1),fpp(15,17,20,2),fpp(15,17,20,3)/
     x 1.0762125d-02, 9.8835781d-06,-2.5172503d-07 /
      data fpp(15,17,21,1),fpp(15,17,21,2),fpp(15,17,21,3)/
     x 1.0762125d-02, 9.8835781d-06,-2.5925874d-07 /
      data fpp(15,17,22,1),fpp(15,17,22,2),fpp(15,17,22,3)/
     x 1.0637584d-02, 9.3987279d-06,-8.2997503d-08 /
      data fpp(15,17,23,1),fpp(15,17,23,2),fpp(15,17,23,3)/
     x 1.0578831d-02, 8.7214459d-06,-2.7512487d-09 /
      data fpp(15,18, 1,1),fpp(15,18, 1,2),fpp(15,18, 1,3)/
     x 6.8981180d-03, 6.6734119d-05,-1.1854137d-06 /
      data fpp(15,18, 2,1),fpp(15,18, 2,2),fpp(15,18, 2,3)/
     x 1.5887560d-02, 3.4692296d-05,-1.6211725d-06 /
      data fpp(15,18, 3,1),fpp(15,18, 3,2),fpp(15,18, 3,3)/
     x 2.5127573d-02, 1.1235549d-05,-2.5658962d-06 /
      data fpp(15,18, 4,1),fpp(15,18, 4,2),fpp(15,18, 4,3)/
     x 2.5127573d-02, 1.1235549d-05,-2.5467251d-06 /
      data fpp(15,18, 5,1),fpp(15,18, 5,2),fpp(15,18, 5,3)/
     x 1.5887560d-02, 3.4692296d-05,-1.6978569d-06 /
      data fpp(15,18, 6,1),fpp(15,18, 6,2),fpp(15,18, 6,3)/
     x 6.8981180d-03, 6.6734119d-05,-8.9784743d-07 /
      data fpp(15,18, 7,1),fpp(15,18, 7,2),fpp(15,18, 7,3)/
     x 1.1138475d-02,-2.7919979d-06,-1.5875340d-07 /
      data fpp(15,18, 8,1),fpp(15,18, 8,2),fpp(15,18, 8,3)/
     x 1.0874919d-02,-1.1751124d-05, 3.3286105d-07 /
      data fpp(15,18, 9,1),fpp(15,18, 9,2),fpp(15,18, 9,3)/
     x 1.0299150d-02,-1.2511676d-05, 6.0930920d-07 /
      data fpp(15,18,10,1),fpp(15,18,10,2),fpp(15,18,10,3)/
     x 1.0339796d-02,-1.0323988d-05, 7.2790215d-07 /
      data fpp(15,18,11,1),fpp(15,18,11,2),fpp(15,18,11,3)/
     x 1.0313941d-02,-7.0929679d-06, 7.5108221d-07 /
      data fpp(15,18,12,1),fpp(15,18,12,2),fpp(15,18,12,3)/
     x 1.0290035d-02,-3.6051244d-06, 7.1976903d-07 /
      data fpp(15,18,13,1),fpp(15,18,13,2),fpp(15,18,13,3)/
     x 1.0311806d-02,-1.7693107d-07, 6.7184168d-07 /
      data fpp(15,18,14,1),fpp(15,18,14,2),fpp(15,18,14,3)/
     x 1.0285690d-02, 3.0735387d-06, 5.9486427d-07 /
      data fpp(15,18,15,1),fpp(15,18,15,2),fpp(15,18,15,3)/
     x 1.0353311d-02, 6.1153073d-06, 5.3070125d-07 /
      data fpp(15,18,16,1),fpp(15,18,16,2),fpp(15,18,16,3)/
     x 1.0297831d-02, 8.9019931d-06, 4.3833071d-07 /
      data fpp(15,18,17,1),fpp(15,18,17,2),fpp(15,18,17,3)/
     x 1.0304454d-02, 1.1385543d-05, 3.6797589d-07 /
      data fpp(15,18,18,1),fpp(15,18,18,2),fpp(15,18,18,3)/
     x 1.0359538d-02, 1.3474158d-05, 2.9176572d-07 /
      data fpp(15,18,19,1),fpp(15,18,19,2),fpp(15,18,19,3)/
     x 1.0330306d-02, 1.5066363d-05, 2.5896122d-07 /
      data fpp(15,18,20,1),fpp(15,18,20,2),fpp(15,18,20,3)/
     x 1.0263088d-02, 1.6033406d-05, 1.9038939d-07 /
      data fpp(15,18,21,1),fpp(15,18,21,2),fpp(15,18,21,3)/
     x 1.0263088d-02, 1.6033406d-05, 1.9035121d-07 /
      data fpp(15,18,22,1),fpp(15,18,22,2),fpp(15,18,22,3)/
     x 1.0330306d-02, 1.5066363d-05, 2.5911394d-07 /
      data fpp(15,18,23,1),fpp(15,18,23,2),fpp(15,18,23,3)/
     x 1.0359538d-02, 1.3474158d-05, 2.9119303d-07 /
      data fpp(15,19, 1,1),fpp(15,19, 1,2),fpp(15,19, 1,3)/
     x 1.0879394d-02, 2.1439744d-04,-8.5019586d-21 /
      data fpp(15,19, 2,1),fpp(15,19, 2,2),fpp(15,19, 2,3)/
     x 1.0879394d-02, 1.4099985d-04,-6.0544470d-22 /
      data fpp(15,19, 3,1),fpp(15,19, 3,2),fpp(15,19, 3,3)/
     x 1.0879394d-02, 8.0579725d-05,-1.0585376d-20 /
      data fpp(15,19, 4,1),fpp(15,19, 4,2),fpp(15,19, 4,3)/
     x 1.0879394d-02, 8.0579725d-05, 1.5484243d-20 /
      data fpp(15,19, 5,1),fpp(15,19, 5,2),fpp(15,19, 5,3)/
     x 1.0879394d-02, 1.4099985d-04, 1.4845973d-21 /
      data fpp(15,19, 6,1),fpp(15,19, 6,2),fpp(15,19, 6,3)/
     x 1.0879394d-02, 2.1439744d-04,-5.5792079d-21 /
      data fpp(15,19, 7,1),fpp(15,19, 7,2),fpp(15,19, 7,3)/
     x 1.0879394d-02, 4.3910999d-05,-3.0073373d-20 /
      data fpp(15,19, 8,1),fpp(15,19, 8,2),fpp(15,19, 8,3)/
     x 1.0879394d-02, 7.3345622d-06,-7.6197010d-21 /
      data fpp(15,19, 9,1),fpp(15,19, 9,2),fpp(15,19, 9,3)/
     x 1.0879394d-02,-8.8721619d-06, 1.5953094d-20 /
      data fpp(15,19,10,1),fpp(15,19,10,2),fpp(15,19,10,3)/
     x 1.0879394d-02,-1.3675006d-05, 1.4715659d-20 /
      data fpp(15,19,11,1),fpp(15,19,11,2),fpp(15,19,11,3)/
     x 1.0879394d-02,-1.2424516d-05,-1.1009113d-20 /
      data fpp(15,19,12,1),fpp(15,19,12,2),fpp(15,19,12,3)/
     x 1.0879394d-02,-8.3484378d-06, 2.1131886d-20 /
      data fpp(15,19,13,1),fpp(15,19,13,2),fpp(15,19,13,3)/
     x 1.0879394d-02,-3.2245345d-06,-2.0597745d-21 /
      data fpp(15,19,14,1),fpp(15,19,14,2),fpp(15,19,14,3)/
     x 1.0879394d-02, 2.0352306d-06,-7.3208848d-21 /
      data fpp(15,19,15,1),fpp(15,19,15,2),fpp(15,19,15,3)/
     x 1.0879394d-02, 7.0208463d-06, 4.0234599d-21 /
      data fpp(15,19,16,1),fpp(15,19,16,2),fpp(15,19,16,3)/
     x 1.0879394d-02, 1.1486003d-05,-2.0562174d-21 /
      data fpp(15,19,17,1),fpp(15,19,17,2),fpp(15,19,17,3)/
     x 1.0879394d-02, 1.5316229d-05, 1.2828671d-20 /
      data fpp(15,19,18,1),fpp(15,19,18,2),fpp(15,19,18,3)/
     x 1.0879394d-02, 1.8405921d-05,-1.5700038d-20 /
      data fpp(15,19,19,1),fpp(15,19,19,2),fpp(15,19,19,3)/
     x 1.0879394d-02, 2.0695818d-05,-1.5590008d-20 /
      data fpp(15,19,20,1),fpp(15,19,20,2),fpp(15,19,20,3)/
     x 1.0879394d-02, 2.2048797d-05, 1.1005350d-20 /
      data fpp(15,19,21,1),fpp(15,19,21,2),fpp(15,19,21,3)/
     x 1.0879394d-02, 2.2048797d-05,-9.3759015d-21 /
      data fpp(15,19,22,1),fpp(15,19,22,2),fpp(15,19,22,3)/
     x 1.0879394d-02, 2.0695818d-05, 2.8420549d-20 /
      data fpp(15,19,23,1),fpp(15,19,23,2),fpp(15,19,23,3)/
     x 1.0879394d-02, 1.8405921d-05, 1.6114083d-20 /
      data fpp(16, 1, 1,1),fpp(16, 1, 1,2),fpp(16, 1, 1,3)/
     x-2.2587100d+00, 8.3081859d-04, 7.9694051d-20 /
      data fpp(16, 1, 2,1),fpp(16, 1, 2,2),fpp(16, 1, 2,3)/
     x-2.2587100d+00, 2.2017642d-03, 7.2448282d-20 /
      data fpp(16, 1, 3,1),fpp(16, 1, 3,2),fpp(16, 1, 3,3)/
     x-2.2587100d+00, 3.5060755d-03,-1.5538485d-19 /
      data fpp(16, 1, 4,1),fpp(16, 1, 4,2),fpp(16, 1, 4,3)/
     x-2.2587100d+00, 3.5060755d-03, 1.3176972d-19 /
      data fpp(16, 1, 5,1),fpp(16, 1, 5,2),fpp(16, 1, 5,3)/
     x-2.2587100d+00, 2.2017642d-03, 6.2558039d-20 /
      data fpp(16, 1, 6,1),fpp(16, 1, 6,2),fpp(16, 1, 6,3)/
     x-2.2587100d+00, 8.3081859d-04, 2.0454220d-20 /
      data fpp(16, 1, 7,1),fpp(16, 1, 7,2),fpp(16, 1, 7,3)/
     x-2.2587100d+00, 9.2342916d-05,-1.4072014d-19 /
      data fpp(16, 1, 8,1),fpp(16, 1, 8,2),fpp(16, 1, 8,3)/
     x-2.2587100d+00,-1.7070563d-04,-2.2282797d-20 /
      data fpp(16, 1, 9,1),fpp(16, 1, 9,2),fpp(16, 1, 9,3)/
     x-2.2587100d+00,-3.2815794d-04, 5.8787363d-20 /
      data fpp(16, 1,10,1),fpp(16, 1,10,2),fpp(16, 1,10,3)/
     x-2.2587100d+00,-4.1281600d-04, 1.0905787d-19 /
      data fpp(16, 1,11,1),fpp(16, 1,11,2),fpp(16, 1,11,3)/
     x-2.2587100d+00,-5.5878574d-04,-1.7333834d-19 /
      data fpp(16, 1,12,1),fpp(16, 1,12,2),fpp(16, 1,12,3)/
     x-2.2587100d+00,-5.7598161d-04, 4.1972609d-20 /
      data fpp(16, 1,13,1),fpp(16, 1,13,2),fpp(16, 1,13,3)/
     x-2.2587100d+00,-4.6682777d-04,-1.7744270d-20 /
      data fpp(16, 1,14,1),fpp(16, 1,14,2),fpp(16, 1,14,3)/
     x-2.2587100d+00,-4.2663066d-04,-3.7484448d-20 /
      data fpp(16, 1,15,1),fpp(16, 1,15,2),fpp(16, 1,15,3)/
     x-2.2587100d+00,-3.4604110d-04, 5.5078118d-20 /
      data fpp(16, 1,16,1),fpp(16, 1,16,2),fpp(16, 1,16,3)/
     x-2.2587100d+00,-1.9042087d-04,-2.2694970d-20 /
      data fpp(16, 1,17,1),fpp(16, 1,17,2),fpp(16, 1,17,3)/
     x-2.2587100d+00, 7.3676807d-05, 4.2874046d-20 /
      data fpp(16, 1,18,1),fpp(16, 1,18,2),fpp(16, 1,18,3)/
     x-2.2587100d+00, 8.0970785d-04,-5.8491157d-20 /
      data fpp(16, 1,19,1),fpp(16, 1,19,2),fpp(16, 1,19,3)/
     x-2.2587100d+00, 2.1746123d-03,-1.2833925d-19 /
      data fpp(16, 1,20,1),fpp(16, 1,20,2),fpp(16, 1,20,3)/
     x-2.2587100d+00, 3.4062053d-03, 1.4488376d-19 /
      data fpp(16, 1,21,1),fpp(16, 1,21,2),fpp(16, 1,21,3)/
     x-2.2587100d+00, 3.4062053d-03,-2.6574619d-20 /
      data fpp(16, 1,22,1),fpp(16, 1,22,2),fpp(16, 1,22,3)/
     x-2.2587100d+00, 2.1746123d-03, 9.0719349d-20 /
      data fpp(16, 1,23,1),fpp(16, 1,23,2),fpp(16, 1,23,3)/
     x-2.2587100d+00, 8.0970785d-04, 4.1597305d-19 /
      data fpp(16, 2, 1,1),fpp(16, 2, 1,2),fpp(16, 2, 1,3)/
     x 2.6329968d-01, 3.4864683d-04,-6.6682991d-06 /
      data fpp(16, 2, 2,1),fpp(16, 2, 2,2),fpp(16, 2, 2,3)/
     x 2.9856696d-01, 8.7261964d-04,-1.6824402d-05 /
      data fpp(16, 2, 3,1),fpp(16, 2, 3,2),fpp(16, 2, 3,3)/
     x 3.0746698d-01, 1.3612670d-03,-3.8726093d-05 /
      data fpp(16, 2, 4,1),fpp(16, 2, 4,2),fpp(16, 2, 4,3)/
     x 3.0746698d-01, 1.3612670d-03,-3.8483519d-05 /
      data fpp(16, 2, 5,1),fpp(16, 2, 5,2),fpp(16, 2, 5,3)/
     x 2.9856696d-01, 8.7261964d-04,-1.7794701d-05 /
      data fpp(16, 2, 6,1),fpp(16, 2, 6,2),fpp(16, 2, 6,3)/
     x 2.6329968d-01, 3.4864683d-04,-3.0296791d-06 /
      data fpp(16, 2, 7,1),fpp(16, 2, 7,2),fpp(16, 2, 7,3)/
     x 2.3321490d-01, 6.1599168d-05, 6.0754169d-06 /
      data fpp(16, 2, 8,1),fpp(16, 2, 8,2),fpp(16, 2, 8,3)/
     x 2.1436885d-01,-3.2271732d-05, 1.5154012d-05 /
      data fpp(16, 2, 9,1),fpp(16, 2, 9,2),fpp(16, 2, 9,3)/
     x 1.5969436d-01,-8.6129112d-05, 3.6885371d-06 /
      data fpp(16, 2,10,1),fpp(16, 2,10,2),fpp(16, 2,10,3)/
     x 1.5104831d-01,-1.1237899d-04, 5.9377840d-05 /
      data fpp(16, 2,11,1),fpp(16, 2,11,2),fpp(16, 2,11,3)/
     x-7.0462474d-01,-1.7481853d-04,-1.4339898d-05 /
      data fpp(16, 2,12,1),fpp(16, 2,12,2),fpp(16, 2,12,3)/
     x-3.0369016d-01,-1.8074979d-04,-1.3148249d-05 /
      data fpp(16, 2,13,1),fpp(16, 2,13,2),fpp(16, 2,13,3)/
     x 5.4697992d-01,-1.3150047d-04, 6.0944893d-05 /
      data fpp(16, 2,14,1),fpp(16, 2,14,2),fpp(16, 2,14,3)/
     x 1.4928022d-01,-1.2227468d-04, 6.1946766d-06 /
      data fpp(16, 2,15,1),fpp(16, 2,15,2),fpp(16, 2,15,3)/
     x 1.5848171d-01,-9.9668795d-05, 1.8316401d-05 /
      data fpp(16, 2,16,1),fpp(16, 2,16,2),fpp(16, 2,16,3)/
     x 2.0702753d-01,-4.8409260d-05, 1.1235721d-05 /
      data fpp(16, 2,17,1),fpp(16, 2,17,2),fpp(16, 2,17,3)/
     x 2.3223688d-01, 4.4382387d-05, 6.9167169d-06 /
      data fpp(16, 2,18,1),fpp(16, 2,18,2),fpp(16, 2,18,3)/
     x 2.6305218d-01, 3.2953331d-04,-3.7785882d-06 /
      data fpp(16, 2,19,1),fpp(16, 2,19,2),fpp(16, 2,19,3)/
     x 2.8510385d-01, 8.5222635d-04,-1.8736364d-05 /
      data fpp(16, 2,20,1),fpp(16, 2,20,2),fpp(16, 2,20,3)/
     x 3.0598270d-01, 1.3222403d-03,-3.9457955d-05 /
      data fpp(16, 2,21,1),fpp(16, 2,21,2),fpp(16, 2,21,3)/
     x 3.0598270d-01, 1.3222403d-03,-3.9708953d-05 /
      data fpp(16, 2,22,1),fpp(16, 2,22,2),fpp(16, 2,22,3)/
     x 2.8510385d-01, 8.5222635d-04,-1.7732370d-05 /
      data fpp(16, 2,23,1),fpp(16, 2,23,2),fpp(16, 2,23,3)/
     x 2.6305218d-01, 3.2953331d-04,-7.5435648d-06 /
      data fpp(16, 3, 1,1),fpp(16, 3, 1,2),fpp(16, 3, 1,3)/
     x 2.9720561d-01,-6.2503789d-04, 2.2164046d-04 /
      data fpp(16, 3, 2,1),fpp(16, 3, 2,2),fpp(16, 3, 2,3)/
     x 7.1251125d-01,-1.3706588d-03, 1.4118070d-05 /
      data fpp(16, 3, 3,1),fpp(16, 3, 3,2),fpp(16, 3, 3,3)/
     x-3.3028941d+00,-1.8383237d-03,-4.3347675d-04 /
      data fpp(16, 3, 4,1),fpp(16, 3, 4,2),fpp(16, 3, 4,3)/
     x-3.3028941d+00,-1.8383237d-03,-4.2839480d-04 /
      data fpp(16, 3, 5,1),fpp(16, 3, 5,2),fpp(16, 3, 5,3)/
     x 7.1251125d-01,-1.3706588d-03,-6.2097136d-06 /
      data fpp(16, 3, 6,1),fpp(16, 3, 6,2),fpp(16, 3, 6,3)/
     x 2.9720561d-01,-6.2503789d-04, 2.9786965d-04 /
      data fpp(16, 3, 7,1),fpp(16, 3, 7,2),fpp(16, 3, 7,3)/
     x 1.1463153d-01,-6.8877589d-05, 1.5776510d-04 /
      data fpp(16, 3, 8,1),fpp(16, 3, 8,2),fpp(16, 3, 8,3)/
     x 7.4437419d-02, 1.2858256d-04, 3.3355952d-05 /
      data fpp(16, 3, 9,1),fpp(16, 3, 9,2),fpp(16, 3, 9,3)/
     x 4.5119635d-02, 2.6764439d-04, 5.6823093d-05 /
      data fpp(16, 3,10,1),fpp(16, 3,10,2),fpp(16, 3,10,3)/
     x 3.4021585d-02, 3.4526998d-04, 3.9711678d-05 /
      data fpp(16, 3,11,1),fpp(16, 3,11,2),fpp(16, 3,11,3)/
     x 2.9559624d-02, 4.3439185d-04, 4.3476197d-05 /
      data fpp(16, 3,12,1),fpp(16, 3,12,2),fpp(16, 3,12,3)/
     x 2.8454832d-02, 4.4756276d-04, 4.2979536d-05 /
      data fpp(16, 3,13,1),fpp(16, 3,13,2),fpp(16, 3,13,3)/
     x 2.9506412d-02, 3.8511364d-04, 4.4081660d-05 /
      data fpp(16, 3,14,1),fpp(16, 3,14,2),fpp(16, 3,14,3)/
     x 3.3544109d-02, 3.3845738d-04, 4.1087826d-05 /
      data fpp(16, 3,15,1),fpp(16, 3,15,2),fpp(16, 3,15,3)/
     x 5.6426872d-02, 2.5640628d-04, 5.8165037d-05 /
      data fpp(16, 3,16,1),fpp(16, 3,16,2),fpp(16, 3,16,3)/
     x 7.3370485d-02, 1.1360791d-04, 3.6542028d-05 /
      data fpp(16, 3,17,1),fpp(16, 3,17,2),fpp(16, 3,17,3)/
     x 1.1219567d-01,-8.5018353d-05, 1.5479685d-04 /
      data fpp(16, 3,18,1),fpp(16, 3,18,2),fpp(16, 3,18,3)/
     x 2.9639142d-01,-6.3181908d-04, 3.0771456d-04 /
      data fpp(16, 3,19,1),fpp(16, 3,19,2),fpp(16, 3,19,3)/
     x 8.3546152d-01,-1.3680917d-03,-4.9953095d-05 /
      data fpp(16, 3,20,1),fpp(16, 3,20,2),fpp(16, 3,20,3)/
     x-2.8803085d+00,-1.8233366d-03,-4.0726618d-04 /
      data fpp(16, 3,21,1),fpp(16, 3,21,2),fpp(16, 3,21,3)/
     x-2.8803085d+00,-1.8233366d-03,-4.1632891d-04 /
      data fpp(16, 3,22,1),fpp(16, 3,22,2),fpp(16, 3,22,3)/
     x 8.3546152d-01,-1.3680917d-03,-1.3702168d-05 /
      data fpp(16, 3,23,1),fpp(16, 3,23,2),fpp(16, 3,23,3)/
     x 2.9639142d-01,-6.3181908d-04, 1.7177358d-04 /
      data fpp(16, 4, 1,1),fpp(16, 4, 1,2),fpp(16, 4, 1,3)/
     x 1.0967129d-01, 1.2157275d-04, 4.6431153d-04 /
      data fpp(16, 4, 2,1),fpp(16, 4, 2,2),fpp(16, 4, 2,3)/
     x 5.0374708d-01,-4.1446863d-04, 1.4133995d-04 /
      data fpp(16, 4, 3,1),fpp(16, 4, 3,2),fpp(16, 4, 3,3)/
     x-1.5799066d+00,-1.3461764d-03,-5.4687532d-04 /
      data fpp(16, 4, 4,1),fpp(16, 4, 4,2),fpp(16, 4, 4,3)/
     x-1.5799066d+00,-1.3461764d-03,-5.5364202d-04 /
      data fpp(16, 4, 5,1),fpp(16, 4, 5,2),fpp(16, 4, 5,3)/
     x 5.0374708d-01,-4.1446863d-04, 1.6840678d-04 /
      data fpp(16, 4, 6,1),fpp(16, 4, 6,2),fpp(16, 4, 6,3)/
     x 1.0967129d-01, 1.2157275d-04, 3.6281091d-04 /
      data fpp(16, 4, 7,1),fpp(16, 4, 7,2),fpp(16, 4, 7,3)/
     x 3.7274816d-01, 1.4971119d-04, 6.1435598d-05 /
      data fpp(16, 4, 8,1),fpp(16, 4, 8,2),fpp(16, 4, 8,3)/
     x-1.0904976d-02, 2.1096548d-04, 7.1084701d-05 /
      data fpp(16, 4, 9,1),fpp(16, 4, 9,2),fpp(16, 4, 9,3)/
     x-1.5696939d-02, 2.3031155d-04, 4.4381599d-05 /
      data fpp(16, 4,10,1),fpp(16, 4,10,2),fpp(16, 4,10,3)/
     x-1.6350699d-02, 2.5267709d-04, 4.7704904d-05 /
      data fpp(16, 4,11,1),fpp(16, 4,11,2),fpp(16, 4,11,3)/
     x-1.5461731d-02, 2.5525113d-04, 4.6234784d-05 /
      data fpp(16, 4,12,1),fpp(16, 4,12,2),fpp(16, 4,12,3)/
     x-1.4829059d-02, 2.6009276d-04, 4.6649961d-05 /
      data fpp(16, 4,13,1),fpp(16, 4,13,2),fpp(16, 4,13,3)/
     x-1.5132307d-02, 2.6722390d-04, 4.7095373d-05 /
      data fpp(16, 4,14,1),fpp(16, 4,14,2),fpp(16, 4,14,3)/
     x-1.5907628d-02, 2.5187316d-04, 4.9596546d-05 /
      data fpp(16, 4,15,1),fpp(16, 4,15,2),fpp(16, 4,15,3)/
     x-1.4894777d-02, 2.2852167d-04, 4.7474442d-05 /
      data fpp(16, 4,16,1),fpp(16, 4,16,2),fpp(16, 4,16,3)/
     x-1.0147772d-02, 2.0560562d-04, 7.6489684d-05 /
      data fpp(16, 4,17,1),fpp(16, 4,17,2),fpp(16, 4,17,3)/
     x 1.3641115d-02, 1.3595303d-04, 6.6134822d-05 /
      data fpp(16, 4,18,1),fpp(16, 4,18,2),fpp(16, 4,18,3)/
     x 1.0904937d-01, 9.0951016d-05, 3.7504703d-04 /
      data fpp(16, 4,19,1),fpp(16, 4,19,2),fpp(16, 4,19,3)/
     x 4.7575712d-01,-4.4564743d-04, 1.2007306d-04 /
      data fpp(16, 4,20,1),fpp(16, 4,20,2),fpp(16, 4,20,3)/
     x-1.1419668d+00,-1.2532719d-03,-5.3547927d-04 /
      data fpp(16, 4,21,1),fpp(16, 4,21,2),fpp(16, 4,21,3)/
     x-1.1419668d+00,-1.2532719d-03,-5.3306073d-04 /
      data fpp(16, 4,22,1),fpp(16, 4,22,2),fpp(16, 4,22,3)/
     x 4.7575712d-01,-4.4564743d-04, 1.1039892d-04 /
      data fpp(16, 4,23,1),fpp(16, 4,23,2),fpp(16, 4,23,3)/
     x 1.0904937d-01, 9.0951016d-05, 4.1132504d-04 /
      data fpp(16, 5, 1,1),fpp(16, 5, 1,2),fpp(16, 5, 1,3)/
     x-3.6041968d-02, 1.3268690d-04, 1.2306004d-04 /
      data fpp(16, 5, 2,1),fpp(16, 5, 2,2),fpp(16, 5, 2,3)/
     x-2.2836266d-02, 6.5447728d-04, 2.0165418d-05 /
      data fpp(16, 5, 3,1),fpp(16, 5, 3,2),fpp(16, 5, 3,3)/
     x 2.0200536d-01, 1.3665312d-03,-1.9721171d-04 /
      data fpp(16, 5, 4,1),fpp(16, 5, 4,2),fpp(16, 5, 4,3)/
     x 2.0200536d-01, 1.3665312d-03,-2.0265657d-04 /
      data fpp(16, 5, 5,1),fpp(16, 5, 5,2),fpp(16, 5, 5,3)/
     x-2.2836266d-02, 6.5447728d-04, 4.1944823d-05 /
      data fpp(16, 5, 6,1),fpp(16, 5, 6,2),fpp(16, 5, 6,3)/
     x-3.6041968d-02, 1.3268690d-04, 4.1387272d-05 /
      data fpp(16, 5, 7,1),fpp(16, 5, 7,2),fpp(16, 5, 7,3)/
     x-2.9470911d-02, 5.9736834d-05, 3.9412087d-05 /
      data fpp(16, 5, 8,1),fpp(16, 5, 8,2),fpp(16, 5, 8,3)/
     x-2.5204484d-02, 5.3195500d-05, 3.8126378d-05 /
      data fpp(16, 5, 9,1),fpp(16, 5, 9,2),fpp(16, 5, 9,3)/
     x-2.2937923d-02, 7.1631413d-05, 3.9328399d-05 /
      data fpp(16, 5,10,1),fpp(16, 5,10,2),fpp(16, 5,10,3)/
     x-2.1923047d-02, 8.1435674d-05, 3.8842025d-05 /
      data fpp(16, 5,11,1),fpp(16, 5,11,2),fpp(16, 5,11,3)/
     x-2.1524139d-02, 8.7947628d-05, 3.8067501d-05 /
      data fpp(16, 5,12,1),fpp(16, 5,12,2),fpp(16, 5,12,3)/
     x-2.1317939d-02, 8.8530193d-05, 3.8069971d-05 /
      data fpp(16, 5,13,1),fpp(16, 5,13,2),fpp(16, 5,13,3)/
     x-2.1153770d-02, 8.4720765d-05, 3.9182616d-05 /
      data fpp(16, 5,14,1),fpp(16, 5,14,2),fpp(16, 5,14,3)/
     x-2.1117282d-02, 8.2025969d-05, 4.1041566d-05 /
      data fpp(16, 5,15,1),fpp(16, 5,15,2),fpp(16, 5,15,3)/
     x-2.1582649d-02, 7.3877042d-05, 4.3113119d-05 /
      data fpp(16, 5,16,1),fpp(16, 5,16,2),fpp(16, 5,16,3)/
     x-2.2873129d-02, 5.9345606d-05, 4.2795959d-05 /
      data fpp(16, 5,17,1),fpp(16, 5,17,2),fpp(16, 5,17,3)/
     x-2.5139121d-02, 7.1990250d-05, 5.0111044d-05 /
      data fpp(16, 5,18,1),fpp(16, 5,18,2),fpp(16, 5,18,3)/
     x-2.7681429d-02, 1.5016902d-04, 4.1429865d-05 /
      data fpp(16, 5,19,1),fpp(16, 5,19,2),fpp(16, 5,19,3)/
     x-4.1355430d-02, 6.5337345d-04, 9.0427494d-05 /
      data fpp(16, 5,20,1),fpp(16, 5,20,2),fpp(16, 5,20,3)/
     x-2.8964408d-01, 1.1808123d-03,-2.4289784d-04 /
      data fpp(16, 5,21,1),fpp(16, 5,21,2),fpp(16, 5,21,3)/
     x-2.8964408d-01, 1.1808123d-03,-2.3318822d-04 /
      data fpp(16, 5,22,1),fpp(16, 5,22,2),fpp(16, 5,22,3)/
     x-4.1355430d-02, 6.5337345d-04, 5.1588991d-05 /
      data fpp(16, 5,23,1),fpp(16, 5,23,2),fpp(16, 5,23,3)/
     x-2.7681429d-02, 1.5016902d-04, 1.8707425d-04 /
      data fpp(16, 6, 1,1),fpp(16, 6, 1,2),fpp(16, 6, 1,3)/
     x-1.2461815d-02,-1.1118334d-05, 2.0717867d-05 /
      data fpp(16, 6, 2,1),fpp(16, 6, 2,2),fpp(16, 6, 2,3)/
     x-7.9184295d-03,-9.6948471d-05,-1.3506235d-05 /
      data fpp(16, 6, 3,1),fpp(16, 6, 3,2),fpp(16, 6, 3,3)/
     x 7.2672578d-03,-1.9786847d-04,-8.6170929d-05 /
      data fpp(16, 6, 4,1),fpp(16, 6, 4,2),fpp(16, 6, 4,3)/
     x 7.2672578d-03,-1.9786847d-04,-8.7348096d-05 /
      data fpp(16, 6, 5,1),fpp(16, 6, 5,2),fpp(16, 6, 5,3)/
     x-7.9184295d-03,-9.6948471d-05,-8.7975681d-06 /
      data fpp(16, 6, 6,1),fpp(16, 6, 6,2),fpp(16, 6, 6,3)/
     x-1.2461815d-02,-1.1118334d-05, 3.0603680d-06 /
      data fpp(16, 6, 7,1),fpp(16, 6, 7,2),fpp(16, 6, 7,3)/
     x-1.4220744d-02,-6.0865253d-06, 1.5942096d-05 /
      data fpp(16, 6, 8,1),fpp(16, 6, 8,2),fpp(16, 6, 8,3)/
     x-1.5684702d-02,-6.5614850d-06, 2.1101247d-05 /
      data fpp(16, 6, 9,1),fpp(16, 6, 9,2),fpp(16, 6, 9,3)/
     x-1.6989259d-02,-1.2981201d-05, 2.4044914d-05 /
      data fpp(16, 6,10,1),fpp(16, 6,10,2),fpp(16, 6,10,3)/
     x-1.8107405d-02,-1.7359784d-05, 2.5501095d-05 /
      data fpp(16, 6,11,1),fpp(16, 6,11,2),fpp(16, 6,11,3)/
     x-1.8752290d-02,-2.0079642d-05, 2.6740704d-05 /
      data fpp(16, 6,12,1),fpp(16, 6,12,2),fpp(16, 6,12,3)/
     x-1.8966609d-02,-2.0237536d-05, 2.7718088d-05 /
      data fpp(16, 6,13,1),fpp(16, 6,13,2),fpp(16, 6,13,3)/
     x-1.8683605d-02,-1.8250959d-05, 2.8382945d-05 /
      data fpp(16, 6,14,1),fpp(16, 6,14,2),fpp(16, 6,14,3)/
     x-1.7934798d-02,-1.5125039d-05, 2.8922134d-05 /
      data fpp(16, 6,15,1),fpp(16, 6,15,2),fpp(16, 6,15,3)/
     x-1.6769193d-02,-8.7018382d-06, 2.9376520d-05 /
      data fpp(16, 6,16,1),fpp(16, 6,16,2),fpp(16, 6,16,3)/
     x-1.5245807d-02, 9.3395605d-07, 2.8285785d-05 /
      data fpp(16, 6,17,1),fpp(16, 6,17,2),fpp(16, 6,17,3)/
     x-1.3360948d-02, 6.4359727d-06, 2.4562338d-05 /
      data fpp(16, 6,18,1),fpp(16, 6,18,2),fpp(16, 6,18,3)/
     x-1.0512232d-02, 9.4309084d-06, 1.1008861d-05 /
      data fpp(16, 6,19,1),fpp(16, 6,19,2),fpp(16, 6,19,3)/
     x-4.9791718d-03,-5.8456373d-05,-4.8537815d-06 /
      data fpp(16, 6,20,1),fpp(16, 6,20,2),fpp(16, 6,20,3)/
     x 8.9008465d-03,-6.1833226d-05,-1.0054773d-04 /
      data fpp(16, 6,21,1),fpp(16, 6,21,2),fpp(16, 6,21,3)/
     x 8.9008465d-03,-6.1833226d-05,-9.9180905d-05 /
      data fpp(16, 6,22,1),fpp(16, 6,22,2),fpp(16, 6,22,3)/
     x-4.9791718d-03,-5.8456373d-05,-1.0321098d-05 /
      data fpp(16, 6,23,1),fpp(16, 6,23,2),fpp(16, 6,23,3)/
     x-1.0512232d-02, 9.4309084d-06, 3.1511299d-05 /
      data fpp(16, 7, 1,1),fpp(16, 7, 1,2),fpp(16, 7, 1,3)/
     x 2.7731168d-03, 3.8086438d-05,-8.6346277d-06 /
      data fpp(16, 7, 2,1),fpp(16, 7, 2,2),fpp(16, 7, 2,3)/
     x 8.3192170d-03, 1.1967461d-04,-1.5174245d-05 /
      data fpp(16, 7, 3,1),fpp(16, 7, 3,2),fpp(16, 7, 3,3)/
     x 1.4250514d-02, 2.1823868d-04,-2.9254394d-05 /
      data fpp(16, 7, 4,1),fpp(16, 7, 4,2),fpp(16, 7, 4,3)/
     x 1.4250514d-02, 2.1823868d-04,-2.9137695d-05 /
      data fpp(16, 7, 5,1),fpp(16, 7, 5,2),fpp(16, 7, 5,3)/
     x 8.3192170d-03, 1.1967461d-04,-1.5641041d-05 /
      data fpp(16, 7, 6,1),fpp(16, 7, 6,2),fpp(16, 7, 6,3)/
     x 2.7731168d-03, 3.8086438d-05,-6.8841414d-06 /
      data fpp(16, 7, 7,1),fpp(16, 7, 7,2),fpp(16, 7, 7,3)/
     x-1.8326173d-03,-4.0227328d-06, 1.6960635d-07 /
      data fpp(16, 7, 8,1),fpp(16, 7, 8,2),fpp(16, 7, 8,3)/
     x-5.8412740d-03,-3.0105560d-05, 5.3117160d-06 /
      data fpp(16, 7, 9,1),fpp(16, 7, 9,2),fpp(16, 7, 9,3)/
     x-9.1970504d-03,-4.3790609d-05, 9.7175298d-06 /
      data fpp(16, 7,10,1),fpp(16, 7,10,2),fpp(16, 7,10,3)/
     x-1.1693197d-02,-5.0540538d-05, 1.3568165d-05 /
      data fpp(16, 7,11,1),fpp(16, 7,11,2),fpp(16, 7,11,3)/
     x-1.3283492d-02,-5.2935061d-05, 1.6523810d-05 /
      data fpp(16, 7,12,1),fpp(16, 7,12,2),fpp(16, 7,12,3)/
     x-1.4029510d-02,-5.2856048d-05, 1.8310594d-05 /
      data fpp(16, 7,13,1),fpp(16, 7,13,2),fpp(16, 7,13,3)/
     x-1.3984183d-02,-5.0674930d-05, 1.8983815d-05 /
      data fpp(16, 7,14,1),fpp(16, 7,14,2),fpp(16, 7,14,3)/
     x-1.3145153d-02,-4.5663814d-05, 1.8758146d-05 /
      data fpp(16, 7,15,1),fpp(16, 7,15,2),fpp(16, 7,15,3)/
     x-1.1466528d-02,-3.7059690d-05, 1.7745600d-05 /
      data fpp(16, 7,16,1),fpp(16, 7,16,2),fpp(16, 7,16,3)/
     x-8.6557613d-03,-2.2875430d-05, 1.5445455d-05 /
      data fpp(16, 7,17,1),fpp(16, 7,17,2),fpp(16, 7,17,3)/
     x-5.5594781d-03, 1.0198588d-06, 1.0580579d-05 /
      data fpp(16, 7,18,1),fpp(16, 7,18,2),fpp(16, 7,18,3)/
     x-1.0224207d-03, 3.7095347d-05, 3.3622888d-07 /
      data fpp(16, 7,19,1),fpp(16, 7,19,2),fpp(16, 7,19,3)/
     x 4.8123793d-03, 1.0740204d-04,-1.4967494d-05 /
      data fpp(16, 7,20,1),fpp(16, 7,20,2),fpp(16, 7,20,3)/
     x 1.1190394d-02, 1.7126462d-04,-4.2784251d-05 /
      data fpp(16, 7,21,1),fpp(16, 7,21,2),fpp(16, 7,21,3)/
     x 1.1190394d-02, 1.7126462d-04,-4.2894500d-05 /
      data fpp(16, 7,22,1),fpp(16, 7,22,2),fpp(16, 7,22,3)/
     x 4.8123793d-03, 1.0740204d-04,-1.4526500d-05 /
      data fpp(16, 7,23,1),fpp(16, 7,23,2),fpp(16, 7,23,3)/
     x-1.0224207d-03, 3.7095347d-05,-1.3174999d-06 /
      data fpp(16, 8, 1,1),fpp(16, 8, 1,2),fpp(16, 8, 1,3)/
     x 9.3796138d-03, 9.2345808d-06,-6.2921981d-06 /
      data fpp(16, 8, 2,1),fpp(16, 8, 2,2),fpp(16, 8, 2,3)/
     x 1.1960121d-02, 2.3916042d-05,-7.2281038d-06 /
      data fpp(16, 8, 3,1),fpp(16, 8, 3,2),fpp(16, 8, 3,3)/
     x 1.0839256d+00, 1.9023755d-05,-9.2493866d-06 /
      data fpp(16, 8, 4,1),fpp(16, 8, 4,2),fpp(16, 8, 4,3)/
     x 1.0839256d+00, 1.9023755d-05,-9.2217883d-06 /
      data fpp(16, 8, 5,1),fpp(16, 8, 5,2),fpp(16, 8, 5,3)/
     x 1.1960121d-02, 2.3916042d-05,-7.3384972d-06 /
      data fpp(16, 8, 6,1),fpp(16, 8, 6,2),fpp(16, 8, 6,3)/
     x 9.3796138d-03, 9.2345808d-06,-5.8782229d-06 /
      data fpp(16, 8, 7,1),fpp(16, 8, 7,2),fpp(16, 8, 7,3)/
     x 6.3647109d-03,-1.2568544d-05,-4.5546112d-06 /
      data fpp(16, 8, 8,1),fpp(16, 8, 8,2),fpp(16, 8, 8,3)/
     x 3.0126459d-03,-2.9778274d-05,-2.4293325d-06 /
      data fpp(16, 8, 9,1),fpp(16, 8, 9,2),fpp(16, 8, 9,3)/
     x-6.5620340d-04,-4.1662363d-05, 1.1199410d-06 /
      data fpp(16, 8,10,1),fpp(16, 8,10,2),fpp(16, 8,10,3)/
     x-3.8930726d-03,-4.8708065d-05, 5.2875685d-06 /
      data fpp(16, 8,11,1),fpp(16, 8,11,2),fpp(16, 8,11,3)/
     x-6.3860082d-03,-5.1992113d-05, 8.8097848d-06 /
      data fpp(16, 8,12,1),fpp(16, 8,12,2),fpp(16, 8,12,3)/
     x-7.9041763d-03,-5.1886272d-05, 1.1085292d-05 /
      data fpp(16, 8,13,1),fpp(16, 8,13,2),fpp(16, 8,13,3)/
     x-8.3162230d-03,-4.8647322d-05, 1.2039047d-05 /
      data fpp(16, 8,14,1),fpp(16, 8,14,2),fpp(16, 8,14,3)/
     x-7.7475078d-03,-4.2525705d-05, 1.1936521d-05 /
      data fpp(16, 8,15,1),fpp(16, 8,15,2),fpp(16, 8,15,3)/
     x-6.1056973d-03,-3.3463403d-05, 1.0900868d-05 /
      data fpp(16, 8,16,1),fpp(16, 8,16,2),fpp(16, 8,16,3)/
     x-4.0848370d-03,-2.1344236d-05, 8.7080057d-06 /
      data fpp(16, 8,17,1),fpp(16, 8,17,2),fpp(16, 8,17,3)/
     x-1.1305655d-03,-6.3994079d-06, 4.9371088d-06 /
      data fpp(16, 8,18,1),fpp(16, 8,18,2),fpp(16, 8,18,3)/
     x 2.5021334d-03, 1.0817703d-05,-1.3064410d-06 /
      data fpp(16, 8,19,1),fpp(16, 8,19,2),fpp(16, 8,19,3)/
     x 6.6383016d-03, 2.2136212d-05,-9.3953447d-06 /
      data fpp(16, 8,20,1),fpp(16, 8,20,2),fpp(16, 8,20,3)/
     x 1.0308606d-02, 3.1494758d-05,-2.0020180d-05 /
      data fpp(16, 8,21,1),fpp(16, 8,21,2),fpp(16, 8,21,3)/
     x 1.0308606d-02, 3.1494758d-05,-2.0168787d-05 /
      data fpp(16, 8,22,1),fpp(16, 8,22,2),fpp(16, 8,22,3)/
     x 6.6383016d-03, 2.2136212d-05,-8.8009180d-06 /
      data fpp(16, 8,23,1),fpp(16, 8,23,2),fpp(16, 8,23,3)/
     x 2.5021334d-03, 1.0817703d-05,-3.5355410d-06 /
      data fpp(16, 9, 1,1),fpp(16, 9, 1,2),fpp(16, 9, 1,3)/
     x 1.2399864d-02,-1.2348761d-05, 6.5529498d-06 /
      data fpp(16, 9, 2,1),fpp(16, 9, 2,2),fpp(16, 9, 2,3)/
     x 1.4142177d-02, 1.8751223d-05, 1.3076003d-06 /
      data fpp(16, 9, 3,1),fpp(16, 9, 3,2),fpp(16, 9, 3,3)/
     x 1.1456921d+00, 1.0356230d-04,-9.7133511d-06 /
      data fpp(16, 9, 4,1),fpp(16, 9, 4,2),fpp(16, 9, 4,3)/
     x 1.1456921d+00, 1.0356230d-04,-1.0096747d-05 /
      data fpp(16, 9, 5,1),fpp(16, 9, 5,2),fpp(16, 9, 5,3)/
     x 1.4142177d-02, 1.8751223d-05, 2.8411831d-06 /
      data fpp(16, 9, 6,1),fpp(16, 9, 6,2),fpp(16, 9, 6,3)/
     x 1.2399864d-02,-1.2348761d-05, 8.0201431d-07 /
      data fpp(16, 9, 7,1),fpp(16, 9, 7,2),fpp(16, 9, 7,3)/
     x 1.1595420d-02,-2.2965093d-05,-2.3772404d-06 /
      data fpp(16, 9, 8,1),fpp(16, 9, 8,2),fpp(16, 9, 8,3)/
     x 9.6486076d-03,-2.8729343d-05,-4.1990529d-06 /
      data fpp(16, 9, 9,1),fpp(16, 9, 9,2),fpp(16, 9, 9,3)/
     x 6.7249910d-03,-3.2829937d-05,-2.9005480d-06 /
      data fpp(16, 9,10,1),fpp(16, 9,10,2),fpp(16, 9,10,3)/
     x 3.5110279d-03,-3.5523202d-05, 4.2324509d-07 /
      data fpp(16, 9,11,1),fpp(16, 9,11,2),fpp(16, 9,11,3)/
     x 6.2400609d-04,-3.6474485d-05, 3.9975677d-06 /
      data fpp(16, 9,12,1),fpp(16, 9,12,2),fpp(16, 9,12,3)/
     x-1.3435477d-03,-3.5758864d-05, 6.5364841d-06 /
      data fpp(16, 9,13,1),fpp(16, 9,13,2),fpp(16, 9,13,3)/
     x-2.4128338d-03,-3.3411783d-05, 7.7524959d-06 /
      data fpp(16, 9,14,1),fpp(16, 9,14,2),fpp(16, 9,14,3)/
     x-2.4929798d-03,-2.9279366d-05, 7.9515323d-06 /
      data fpp(16, 9,15,1),fpp(16, 9,15,2),fpp(16, 9,15,3)/
     x-1.6334842d-03,-2.3252698d-05, 7.3013749d-06 /
      data fpp(16, 9,16,1),fpp(16, 9,16,2),fpp(16, 9,16,3)/
     x-1.7059185d-04,-1.5371625d-05, 5.8149682d-06 /
      data fpp(16, 9,17,1),fpp(16, 9,17,2),fpp(16, 9,17,3)/
     x 1.8968164d-03,-5.8722273d-06, 3.3027522d-06 /
      data fpp(16, 9,18,1),fpp(16, 9,18,2),fpp(16, 9,18,3)/
     x 4.5282705d-03, 4.5878422d-06,-5.9997708d-07 /
      data fpp(16, 9,19,1),fpp(16, 9,19,2),fpp(16, 9,19,3)/
     x 7.4295055d-03, 1.6291113d-05,-5.3488439d-06 /
      data fpp(16, 9,20,1),fpp(16, 9,20,2),fpp(16, 9,20,3)/
     x 9.9785187d-03, 2.4950351d-05,-1.0830647d-05 /
      data fpp(16, 9,21,1),fpp(16, 9,21,2),fpp(16, 9,21,3)/
     x 9.9785187d-03, 2.4950351d-05,-1.0934636d-05 /
      data fpp(16, 9,22,1),fpp(16, 9,22,2),fpp(16, 9,22,3)/
     x 7.4295055d-03, 1.6291113d-05,-4.9328897d-06 /
      data fpp(16, 9,23,1),fpp(16, 9,23,2),fpp(16, 9,23,3)/
     x 4.5282705d-03, 4.5878422d-06,-2.1598051d-06 /
      data fpp(16,10, 1,1),fpp(16,10, 1,2),fpp(16,10, 1,3)/
     x-5.3273422d-03,-5.5959535d-05, 6.3814172d-05 /
      data fpp(16,10, 2,1),fpp(16,10, 2,2),fpp(16,10, 2,3)/
     x-4.8142567d-02,-1.0516694d-04, 3.1277657d-05 /
      data fpp(16,10, 3,1),fpp(16,10, 3,2),fpp(16,10, 3,3)/
     x-8.2909763d-01,-2.4569495d-04,-3.6380799d-05 /
      data fpp(16,10, 4,1),fpp(16,10, 4,2),fpp(16,10, 4,3)/
     x-8.2909763d-01,-2.4569495d-04,-3.9990430d-05 /
      data fpp(16,10, 5,1),fpp(16,10, 5,2),fpp(16,10, 5,3)/
     x-4.8142567d-02,-1.0516694d-04, 4.5716181d-05 /
      data fpp(16,10, 6,1),fpp(16,10, 6,2),fpp(16,10, 6,3)/
     x-5.3273422d-03,-5.5959535d-05, 9.6697068d-06 /
      data fpp(16,10, 7,1),fpp(16,10, 7,2),fpp(16,10, 7,3)/
     x 7.5197628d-03,-3.7315084d-05, 2.6049921d-06 /
      data fpp(16,10, 8,1),fpp(16,10, 8,2),fpp(16,10, 8,3)/
     x 1.1223195d-02,-2.8512353d-05,-5.2156751d-06 /
      data fpp(16,10, 9,1),fpp(16,10, 9,2),fpp(16,10, 9,3)/
     x 1.0870360d-02,-2.4489887d-05,-5.5382916d-06 /
      data fpp(16,10,10,1),fpp(16,10,10,2),fpp(16,10,10,3)/
     x 8.6375279d-03,-2.2955129d-05,-2.7451586d-06 /
      data fpp(16,10,11,1),fpp(16,10,11,2),fpp(16,10,11,3)/
     x 5.9941030d-03,-2.2255946d-05, 9.1292609d-07 /
      data fpp(16,10,12,1),fpp(16,10,12,2),fpp(16,10,12,3)/
     x 3.8062079d-03,-2.1306271d-05, 3.6894543d-06 /
      data fpp(16,10,13,1),fpp(16,10,13,2),fpp(16,10,13,3)/
     x 2.4404961d-03,-1.9677546d-05, 5.2692569d-06 /
      data fpp(16,10,14,1),fpp(16,10,14,2),fpp(16,10,14,3)/
     x 2.0234240d-03,-1.7260832d-05, 5.8635183d-06 /
      data fpp(16,10,15,1),fpp(16,10,15,2),fpp(16,10,15,3)/
     x 2.1293981d-03,-1.4069806d-05, 5.6026699d-06 /
      data fpp(16,10,16,1),fpp(16,10,16,2),fpp(16,10,16,3)/
     x 2.9549283d-03,-1.0175266d-05, 4.5998022d-06 /
      data fpp(16,10,17,1),fpp(16,10,17,2),fpp(16,10,17,3)/
     x 4.4405232d-03,-5.8296829d-06, 2.8061214d-06 /
      data fpp(16,10,18,1),fpp(16,10,18,2),fpp(16,10,18,3)/
     x 6.2530649d-03,-1.5630714d-06,-8.6287778d-08 /
      data fpp(16,10,19,1),fpp(16,10,19,2),fpp(16,10,19,3)/
     x 8.3881718d-03, 1.6013365d-06,-3.6969703d-06 /
      data fpp(16,10,20,1),fpp(16,10,20,2),fpp(16,10,20,3)/
     x 1.0350990d-02, 3.6798372d-06,-7.0918311d-06 /
      data fpp(16,10,21,1),fpp(16,10,21,2),fpp(16,10,21,3)/
     x 1.0350990d-02, 3.6798372d-06,-7.1880216d-06 /
      data fpp(16,10,22,1),fpp(16,10,22,2),fpp(16,10,22,3)/
     x 8.3881718d-03, 1.6013365d-06,-3.3122081d-06 /
      data fpp(16,10,23,1),fpp(16,10,23,2),fpp(16,10,23,3)/
     x 6.2530649d-03,-1.5630714d-06,-1.5291459d-06 /
      data fpp(16,11, 1,1),fpp(16,11, 1,2),fpp(16,11, 1,3)/
     x-6.5920980d-02,-9.6510970d-06, 3.1152075d-05 /
      data fpp(16,11, 2,1),fpp(16,11, 2,2),fpp(16,11, 2,3)/
     x-2.0494142d-01, 2.8092517d-05, 1.6263349d-05 /
      data fpp(16,11, 3,1),fpp(16,11, 3,2),fpp(16,11, 3,3)/
     x-3.7568180d-02, 1.5540751d-04,-1.5187473d-05 /
      data fpp(16,11, 4,1),fpp(16,11, 4,2),fpp(16,11, 4,3)/
     x-3.7568180d-02, 1.5540751d-04,-1.5981256d-05 /
      data fpp(16,11, 5,1),fpp(16,11, 5,2),fpp(16,11, 5,3)/
     x-2.0494142d-01, 2.8092517d-05, 1.9438483d-05 /
      data fpp(16,11, 6,1),fpp(16,11, 6,2),fpp(16,11, 6,3)/
     x-6.5920980d-02,-9.6510970d-06, 1.9245325d-05 /
      data fpp(16,11, 7,1),fpp(16,11, 7,2),fpp(16,11, 7,3)/
     x-1.4679740d-02,-1.8040570d-05, 1.4942191d-06 /
      data fpp(16,11, 8,1),fpp(16,11, 8,2),fpp(16,11, 8,3)/
     x 4.0379176d-03,-1.7571245d-05,-8.2242007d-06 /
      data fpp(16,11, 9,1),fpp(16,11, 9,2),fpp(16,11, 9,3)/
     x 9.9677547d-03,-1.5430513d-05,-9.9014161d-06 /
      data fpp(16,11,10,1),fpp(16,11,10,2),fpp(16,11,10,3)/
     x 1.0509519d-02,-1.3908284d-05,-6.1821348d-06 /
      data fpp(16,11,11,1),fpp(16,11,11,2),fpp(16,11,11,3)/
     x 8.9163485d-03,-1.3089731d-05,-1.6760446d-06 /
      data fpp(16,11,12,1),fpp(16,11,12,2),fpp(16,11,12,3)/
     x 7.0494392d-03,-1.2426052d-05, 1.6423134d-06 /
      data fpp(16,11,13,1),fpp(16,11,13,2),fpp(16,11,13,3)/
     x 5.7026581d-03,-1.1526032d-05, 3.6747911d-06 /
      data fpp(16,11,14,1),fpp(16,11,14,2),fpp(16,11,14,3)/
     x 5.0511061d-03,-1.0331307d-05, 4.6525222d-06 /
      data fpp(16,11,15,1),fpp(16,11,15,2),fpp(16,11,15,3)/
     x 4.9893364d-03,-8.9140766d-06, 4.7211200d-06 /
      data fpp(16,11,16,1),fpp(16,11,16,2),fpp(16,11,16,3)/
     x 5.5318633d-03,-7.4073132d-06, 3.9969977d-06 /
      data fpp(16,11,17,1),fpp(16,11,17,2),fpp(16,11,17,3)/
     x 6.5613802d-03,-5.9630409d-06, 2.4028893d-06 /
      data fpp(16,11,18,1),fpp(16,11,18,2),fpp(16,11,18,3)/
     x 8.0042684d-03,-4.7255564d-06,-1.2055482d-07 /
      data fpp(16,11,19,1),fpp(16,11,19,2),fpp(16,11,19,3)/
     x 9.6126139d-03,-3.6584591d-06,-3.2826700d-06 /
      data fpp(16,11,20,1),fpp(16,11,20,2),fpp(16,11,20,3)/
     x 1.1200154d-02,-2.7757000d-06,-5.4267651d-06 /
      data fpp(16,11,21,1),fpp(16,11,21,2),fpp(16,11,21,3)/
     x 1.1200154d-02,-2.7757000d-06,-5.5293697d-06 /
      data fpp(16,11,22,1),fpp(16,11,22,2),fpp(16,11,22,3)/
     x 9.6126139d-03,-3.6584591d-06,-2.8722515d-06 /
      data fpp(16,11,23,1),fpp(16,11,23,2),fpp(16,11,23,3)/
     x 8.0042684d-03,-4.7255564d-06,-1.6596242d-06 /
      data fpp(16,12, 1,1),fpp(16,12, 1,2),fpp(16,12, 1,3)/
     x-9.8900675d-02, 4.2873924d-05, 9.3070195d-05 /
      data fpp(16,12, 2,1),fpp(16,12, 2,2),fpp(16,12, 2,3)/
     x-1.6067552d-01, 7.2182867d-05, 4.8693110d-05 /
      data fpp(16,12, 3,1),fpp(16,12, 3,2),fpp(16,12, 3,3)/
     x-2.0788868d-01, 6.8808923d-05,-4.4068635d-05 /
      data fpp(16,12, 4,1),fpp(16,12, 4,2),fpp(16,12, 4,3)/
     x-2.0788868d-01, 6.8808923d-05,-4.8149650d-05 /
      data fpp(16,12, 5,1),fpp(16,12, 5,2),fpp(16,12, 5,3)/
     x-1.6067552d-01, 7.2182867d-05, 6.5017171d-05 /
      data fpp(16,12, 6,1),fpp(16,12, 6,2),fpp(16,12, 6,3)/
     x-9.8900675d-02, 4.2873924d-05, 3.1854965d-05 /
      data fpp(16,12, 7,1),fpp(16,12, 7,2),fpp(16,12, 7,3)/
     x-4.0987100d-02, 1.8709364d-05, 8.3889702d-06 /
      data fpp(16,12, 8,1),fpp(16,12, 8,2),fpp(16,12, 8,3)/
     x-9.4555036d-03, 4.3813348d-06,-1.0858845d-05 /
      data fpp(16,12, 9,1),fpp(16,12, 9,2),fpp(16,12, 9,3)/
     x 4.7663734d-03,-2.5580590d-06,-1.4471589d-05 /
      data fpp(16,12,10,1),fpp(16,12,10,2),fpp(16,12,10,3)/
     x 9.4226181d-03,-5.4297359d-06,-1.0058798d-05 /
      data fpp(16,12,11,1),fpp(16,12,11,2),fpp(16,12,11,3)/
     x 9.7515241d-03,-6.5051296d-06,-4.1532176d-06 /
      data fpp(16,12,12,1),fpp(16,12,12,2),fpp(16,12,12,3)/
     x 8.6723743d-03,-6.8275202d-06,-2.8331293d-08 /
      data fpp(16,12,13,1),fpp(16,12,13,2),fpp(16,12,13,3)/
     x 7.6292924d-03,-6.7883271d-06, 2.4485428d-06 /
      data fpp(16,12,14,1),fpp(16,12,14,2),fpp(16,12,14,3)/
     x 7.0646942d-03,-6.5919417d-06, 3.7161602d-06 /
      data fpp(16,12,15,1),fpp(16,12,15,2),fpp(16,12,15,3)/
     x 7.0227369d-03,-6.4338872d-06, 3.9988163d-06 /
      data fpp(16,12,16,1),fpp(16,12,16,2),fpp(16,12,16,3)/
     x 7.4948933d-03,-6.4134818d-06, 3.4065745d-06 /
      data fpp(16,12,17,1),fpp(16,12,17,2),fpp(16,12,17,3)/
     x 8.4760497d-03,-6.5341534d-06, 1.8508856d-06 /
      data fpp(16,12,18,1),fpp(16,12,18,2),fpp(16,12,18,3)/
     x 9.6380930d-03,-6.6727028d-06,-4.9611709d-07 /
      data fpp(16,12,19,1),fpp(16,12,19,2),fpp(16,12,19,3)/
     x 1.0841936d-02,-6.6955001d-06,-3.0224173d-06 /
      data fpp(16,12,20,1),fpp(16,12,20,2),fpp(16,12,20,3)/
     x 1.1997717d-02,-6.5570371d-06,-4.4662137d-06 /
      data fpp(16,12,21,1),fpp(16,12,21,2),fpp(16,12,21,3)/
     x 1.1997717d-02,-6.5570371d-06,-4.5541502d-06 /
      data fpp(16,12,22,1),fpp(16,12,22,2),fpp(16,12,22,3)/
     x 1.0841936d-02,-6.6955001d-06,-2.6706714d-06 /
      data fpp(16,12,23,1),fpp(16,12,23,2),fpp(16,12,23,3)/
     x 9.6380930d-03,-6.6727028d-06,-1.8151643d-06 /
      data fpp(16,13, 1,1),fpp(16,13, 1,2),fpp(16,13, 1,3)/
     x-1.2375650d-01, 3.3875403d-05, 1.4039140d-04 /
      data fpp(16,13, 2,1),fpp(16,13, 2,2),fpp(16,13, 2,3)/
     x-1.9995889d-01, 3.7560165d-06, 6.9493693d-05 /
      data fpp(16,13, 3,1),fpp(16,13, 3,2),fpp(16,13, 3,3)/
     x-1.3504993d-02,-5.2439198d-05,-7.9072176d-05 /
      data fpp(16,13, 4,1),fpp(16,13, 4,2),fpp(16,13, 4,3)/
     x-1.3504993d-02,-5.2439198d-05,-8.4948319d-05 /
      data fpp(16,13, 5,1),fpp(16,13, 5,2),fpp(16,13, 5,3)/
     x-1.9995889d-01, 3.7560165d-06, 9.2998265d-05 /
      data fpp(16,13, 6,1),fpp(16,13, 6,2),fpp(16,13, 6,3)/
     x-1.2375650d-01, 3.3875403d-05, 5.2249260d-05 /
      data fpp(16,13, 7,1),fpp(16,13, 7,2),fpp(16,13, 7,3)/
     x-6.3238251d-02, 3.3521116d-05, 2.1200697d-05 /
      data fpp(16,13, 8,1),fpp(16,13, 8,2),fpp(16,13, 8,3)/
     x-2.4226438d-02, 2.2011906d-05,-7.8960474d-06 /
      data fpp(16,13, 9,1),fpp(16,13, 9,2),fpp(16,13, 9,3)/
     x-2.6797813d-03, 1.0668749d-05,-1.5956507d-05 /
      data fpp(16,13,10,1),fpp(16,13,10,2),fpp(16,13,10,3)/
     x 6.5350413d-03, 3.1792273d-06,-1.2367923d-05 /
      data fpp(16,13,11,1),fpp(16,13,11,2),fpp(16,13,11,3)/
     x 9.1284066d-03,-7.1175048d-07,-5.9057993d-06 /
      data fpp(16,13,12,1),fpp(16,13,12,2),fpp(16,13,12,3)/
     x 9.1119324d-03,-2.5758670d-06,-1.2808795d-06 /
      data fpp(16,13,13,1),fpp(16,13,13,2),fpp(16,13,13,3)/
     x 8.5624626d-03,-3.5186599d-06, 1.4293172d-06 /
      data fpp(16,13,14,1),fpp(16,13,14,2),fpp(16,13,14,3)/
     x 8.1987547d-03,-4.1309266d-06, 2.7876106d-06 /
      data fpp(16,13,15,1),fpp(16,13,15,2),fpp(16,13,15,3)/
     x 8.3197288d-03,-4.6803745d-06, 3.1702405d-06 /
      data fpp(16,13,16,1),fpp(16,13,16,2),fpp(16,13,16,3)/
     x 8.8791136d-03,-5.3267596d-06, 2.6754275d-06 /
      data fpp(16,13,17,1),fpp(16,13,17,2),fpp(16,13,17,3)/
     x 9.7450757d-03,-6.0483457d-06, 1.2660496d-06 /
      data fpp(16,13,18,1),fpp(16,13,18,2),fpp(16,13,18,3)/
     x 1.0735643d-02,-6.6476322d-06,-7.5562585d-07 /
      data fpp(16,13,19,1),fpp(16,13,19,2),fpp(16,13,19,3)/
     x 1.1721219d-02,-6.9575403d-06,-2.6115462d-06 /
      data fpp(16,13,20,1),fpp(16,13,20,2),fpp(16,13,20,3)/
     x 1.2494023d-02,-7.1821517d-06,-3.6781894d-06 /
      data fpp(16,13,21,1),fpp(16,13,21,2),fpp(16,13,21,3)/
     x 1.2494023d-02,-7.1821517d-06,-3.7426587d-06 /
      data fpp(16,13,22,1),fpp(16,13,22,2),fpp(16,13,22,3)/
     x 1.1721219d-02,-6.9575403d-06,-2.3536689d-06 /
      data fpp(16,13,23,1),fpp(16,13,23,2),fpp(16,13,23,3)/
     x 1.0735643d-02,-6.6476322d-06,-1.7226655d-06 /
      data fpp(16,14, 1,1),fpp(16,14, 1,2),fpp(16,14, 1,3)/
     x-1.4358784d-01, 1.3054465d-05, 1.2272746d-04 /
      data fpp(16,14, 2,1),fpp(16,14, 2,2),fpp(16,14, 2,3)/
     x-1.9989660d-01,-2.1962933d-05, 5.8664581d-05 /
      data fpp(16,14, 3,1),fpp(16,14, 3,2),fpp(16,14, 3,3)/
     x 3.5442757d-02,-7.3342132d-05,-7.5919784d-05 /
      data fpp(16,14, 4,1),fpp(16,14, 4,2),fpp(16,14, 4,3)/
     x 3.5442757d-02,-7.3342132d-05,-8.0632939d-05 /
      data fpp(16,14, 5,1),fpp(16,14, 5,2),fpp(16,14, 5,3)/
     x-1.9989660d-01,-2.1962933d-05, 7.7517202d-05 /
      data fpp(16,14, 6,1),fpp(16,14, 6,2),fpp(16,14, 6,3)/
     x-1.4358784d-01, 1.3054465d-05, 5.2030133d-05 /
      data fpp(16,14, 7,1),fpp(16,14, 7,2),fpp(16,14, 7,3)/
     x-8.3566430d-02, 3.0296174d-05, 2.5402268d-05 /
      data fpp(16,14, 8,1),fpp(16,14, 8,2),fpp(16,14, 8,3)/
     x-3.8716809d-02, 2.8423040d-05,-3.7772031d-06 /
      data fpp(16,14, 9,1),fpp(16,14, 9,2),fpp(16,14, 9,3)/
     x-1.0311112d-02, 1.8491061d-05,-1.3461455d-05 /
      data fpp(16,14,10,1),fpp(16,14,10,2),fpp(16,14,10,3)/
     x 3.1414876d-03, 9.5968266d-06,-1.1232977d-05 /
      data fpp(16,14,11,1),fpp(16,14,11,2),fpp(16,14,11,3)/
     x 7.7971768d-03, 4.0421315d-06,-5.8846378d-06 /
      data fpp(16,14,12,1),fpp(16,14,12,2),fpp(16,14,12,3)/
     x 8.8197280d-03, 9.7898804d-07,-1.7204720d-06 /
      data fpp(16,14,13,1),fpp(16,14,13,2),fpp(16,14,13,3)/
     x 8.7876444d-03,-8.0303340d-07, 7.1252595d-07 /
      data fpp(16,14,14,1),fpp(16,14,14,2),fpp(16,14,14,3)/
     x 8.7027698d-03,-1.9763520d-06, 1.9243683d-06 /
      data fpp(16,14,15,1),fpp(16,14,15,2),fpp(16,14,15,3)/
     x 8.8978865d-03,-2.8886147d-06, 2.2520010d-06 /
      data fpp(16,14,16,1),fpp(16,14,16,2),fpp(16,14,16,3)/
     x 9.4539072d-03,-3.6534797d-06, 1.8596276d-06 /
      data fpp(16,14,17,1),fpp(16,14,17,2),fpp(16,14,17,3)/
     x 1.0239250d-02,-4.3124640d-06, 7.7348843d-07 /
      data fpp(16,14,18,1),fpp(16,14,18,2),fpp(16,14,18,3)/
     x 1.1089474d-02,-4.8547684d-06,-7.1158134d-07 /
      data fpp(16,14,19,1),fpp(16,14,19,2),fpp(16,14,19,3)/
     x 1.1793756d-02,-5.2723386d-06,-2.1091631d-06 /
      data fpp(16,14,20,1),fpp(16,14,20,2),fpp(16,14,20,3)/
     x 1.2402425d-02,-5.4183561d-06,-2.7857664d-06 /
      data fpp(16,14,21,1),fpp(16,14,21,2),fpp(16,14,21,3)/
     x 1.2402425d-02,-5.4183561d-06,-2.8371193d-06 /
      data fpp(16,14,22,1),fpp(16,14,22,2),fpp(16,14,22,3)/
     x 1.1793756d-02,-5.2723386d-06,-1.9037516d-06 /
      data fpp(16,14,23,1),fpp(16,14,23,2),fpp(16,14,23,3)/
     x 1.1089474d-02,-4.8547684d-06,-1.4818742d-06 /
      data fpp(16,15, 1,1),fpp(16,15, 1,2),fpp(16,15, 1,3)/
     x-1.3963685d-01, 6.8268737d-05, 5.7827472d-05 /
      data fpp(16,15, 2,1),fpp(16,15, 2,2),fpp(16,15, 2,3)/
     x-1.1585696d-01, 6.4415714d-05, 2.7280555d-05 /
      data fpp(16,15, 3,1),fpp(16,15, 3,2),fpp(16,15, 3,3)/
     x-6.4746642d-02, 5.8245726d-05,-3.7151694d-05 /
      data fpp(16,15, 4,1),fpp(16,15, 4,2),fpp(16,15, 4,3)/
     x-6.4746642d-02, 5.8245726d-05,-3.8946196d-05 /
      data fpp(16,15, 5,1),fpp(16,15, 5,2),fpp(16,15, 5,3)/
     x-1.1585696d-01, 6.4415714d-05, 3.4458566d-05 /
      data fpp(16,15, 6,1),fpp(16,15, 6,2),fpp(16,15, 6,3)/
     x-1.3963685d-01, 6.8268737d-05, 3.0909931d-05 /
      data fpp(16,15, 7,1),fpp(16,15, 7,2),fpp(16,15, 7,3)/
     x-1.0699238d-01, 4.7122188d-05, 1.4209710d-05 /
      data fpp(16,15, 8,1),fpp(16,15, 8,2),fpp(16,15, 8,3)/
     x-5.1387651d-02, 2.8137934d-05,-2.6327713d-06 /
      data fpp(16,15, 9,1),fpp(16,15, 9,2),fpp(16,15, 9,3)/
     x-1.5191692d-02, 1.6983006d-05,-7.9146249d-06 /
      data fpp(16,15,10,1),fpp(16,15,10,2),fpp(16,15,10,3)/
     x 8.2621055d-04, 1.0543466d-05,-6.6107289d-06 /
      data fpp(16,15,11,1),fpp(16,15,11,2),fpp(16,15,11,3)/
     x 6.5591958d-03, 6.3592244d-06,-3.6524593d-06 /
      data fpp(16,15,12,1),fpp(16,15,12,2),fpp(16,15,12,3)/
     x 8.3361731d-03, 3.5739148d-06,-1.0994338d-06 /
      data fpp(16,15,13,1),fpp(16,15,13,2),fpp(16,15,13,3)/
     x 8.7194777d-03, 1.7087935d-06, 5.0819458d-07 /
      data fpp(16,15,14,1),fpp(16,15,14,2),fpp(16,15,14,3)/
     x 8.7970284d-03, 4.0833466d-07, 1.2806555d-06 /
      data fpp(16,15,15,1),fpp(16,15,15,2),fpp(16,15,15,3)/
     x 9.0146687d-03,-4.8116679d-07, 1.4611835d-06 /
      data fpp(16,15,16,1),fpp(16,15,16,2),fpp(16,15,16,3)/
     x 9.3942867d-03,-1.0413218d-06, 1.1366107d-06 /
      data fpp(16,15,17,1),fpp(16,15,17,2),fpp(16,15,17,3)/
     x 9.9597879d-03,-1.3077983d-06, 4.2437392d-07 /
      data fpp(16,15,18,1),fpp(16,15,18,2),fpp(16,15,18,3)/
     x 1.0579762d-02,-1.3592941d-06,-5.3010633d-07 /
      data fpp(16,15,19,1),fpp(16,15,19,2),fpp(16,15,19,3)/
     x 1.1080832d-02,-1.2691054d-06,-1.3699486d-06 /
      data fpp(16,15,20,1),fpp(16,15,20,2),fpp(16,15,20,3)/
     x 1.1459181d-02,-1.2044239d-06,-1.8320993d-06 /
      data fpp(16,15,21,1),fpp(16,15,21,2),fpp(16,15,21,3)/
     x 1.1459181d-02,-1.2044239d-06,-1.8617277d-06 /
      data fpp(16,15,22,1),fpp(16,15,22,2),fpp(16,15,22,3)/
     x 1.1080832d-02,-1.2691054d-06,-1.2514349d-06 /
      data fpp(16,15,23,1),fpp(16,15,23,2),fpp(16,15,23,3)/
     x 1.0579762d-02,-1.3592941d-06,-9.7453253d-07 /
      data fpp(16,16, 1,1),fpp(16,16, 1,2),fpp(16,16, 1,3)/
     x-3.8649655d-01,-2.5393414d-05,-1.3172244d-06 /
      data fpp(16,16, 2,1),fpp(16,16, 2,2),fpp(16,16, 2,3)/
     x-6.5924541d-02, 4.8718077d-05,-1.7835512d-06 /
      data fpp(16,16, 3,1),fpp(16,16, 3,2),fpp(16,16, 3,3)/
     x 4.3370996d-02, 1.5924123d-04,-2.6365707d-06 /
      data fpp(16,16, 4,1),fpp(16,16, 4,2),fpp(16,16, 4,3)/
     x 4.3370996d-02, 1.5924123d-04,-2.8925123d-06 /
      data fpp(16,16, 5,1),fpp(16,16, 5,2),fpp(16,16, 5,3)/
     x-6.5924541d-02, 4.8718077d-05,-7.5978488d-07 /
      data fpp(16,16, 6,1),fpp(16,16, 6,2),fpp(16,16, 6,3)/
     x-3.8649655d-01,-2.5393414d-05,-5.1563482d-06 /
      data fpp(16,16, 7,1),fpp(16,16, 7,2),fpp(16,16, 7,3)/
     x-1.2834253d-01,-2.8956927d-05, 7.7351776d-06 /
      data fpp(16,16, 8,1),fpp(16,16, 8,2),fpp(16,16, 8,3)/
     x-4.2626553d-02,-1.4716776d-05, 1.9236376d-06 /
      data fpp(16,16, 9,1),fpp(16,16, 9,2),fpp(16,16, 9,3)/
     x-1.2284796d-01,-3.0350840d-06,-3.3728216d-08 /
      data fpp(16,16,10,1),fpp(16,16,10,2),fpp(16,16,10,3)/
     x 1.7384696d-03, 2.7213080d-06,-7.6272478d-07 /
      data fpp(16,16,11,1),fpp(16,16,11,2),fpp(16,16,11,3)/
     x 6.3371933d-03, 4.4149708d-06,-3.5937265d-07 /
      data fpp(16,16,12,1),fpp(16,16,12,2),fpp(16,16,12,3)/
     x 7.9946978d-03, 4.2193527d-06, 2.5021540d-07 /
      data fpp(16,16,13,1),fpp(16,16,13,2),fpp(16,16,13,3)/
     x 8.5759130d-03, 3.4958595d-06, 7.6251106d-07 /
      data fpp(16,16,14,1),fpp(16,16,14,2),fpp(16,16,14,3)/
     x 8.7755735d-03, 2.8210134d-06, 9.8974037d-07 /
      data fpp(16,16,15,1),fpp(16,16,15,2),fpp(16,16,15,3)/
     x 8.9274175d-03, 2.4012818d-06, 9.6052745d-07 /
      data fpp(16,16,16,1),fpp(16,16,16,2),fpp(16,16,16,3)/
     x 9.0891745d-03, 2.3107667d-06, 6.9414984d-07 /
      data fpp(16,16,17,1),fpp(16,16,17,2),fpp(16,16,17,3)/
     x 9.4146944d-03, 2.5476573d-06, 2.7087318d-07 /
      data fpp(16,16,18,1),fpp(16,16,18,2),fpp(16,16,18,3)/
     x 9.7494705d-03, 3.0019448d-06,-2.1764256d-07 /
      data fpp(16,16,19,1),fpp(16,16,19,2),fpp(16,16,19,3)/
     x 1.0021422d-02, 3.4667602d-06,-6.4830294d-07 /
      data fpp(16,16,20,1),fpp(16,16,20,2),fpp(16,16,20,3)/
     x 1.0240439d-02, 3.7740518d-06,-9.2714567d-07 /
      data fpp(16,16,21,1),fpp(16,16,21,2),fpp(16,16,21,3)/
     x 1.0240439d-02, 3.7740518d-06,-9.4141152d-07 /
      data fpp(16,16,22,1),fpp(16,16,22,2),fpp(16,16,22,3)/
     x 1.0021422d-02, 3.4667602d-06,-5.9123957d-07 /
      data fpp(16,16,23,1),fpp(16,16,23,2),fpp(16,16,23,3)/
     x 9.7494705d-03, 3.0019448d-06,-4.3163022d-07 /
      data fpp(16,17, 1,1),fpp(16,17, 1,2),fpp(16,17, 1,3)/
     x 8.2152166d-01,-1.1408508d-04, 5.0824332d-06 /
      data fpp(16,17, 2,1),fpp(16,17, 2,2),fpp(16,17, 2,3)/
     x-3.1332793d-03,-1.9286202d-04,-1.3898664d-06 /
      data fpp(16,17, 3,1),fpp(16,17, 3,2),fpp(16,17, 3,3)/
     x-7.7334850d-01,-2.7870264d-04,-1.5230967d-05 /
      data fpp(16,17, 4,1),fpp(16,17, 4,2),fpp(16,17, 4,3)/
     x-7.7334850d-01,-2.7870264d-04,-1.5280164d-05 /
      data fpp(16,17, 5,1),fpp(16,17, 5,2),fpp(16,17, 5,3)/
     x-3.1332793d-03,-1.9286202d-04,-1.1930789d-06 /
      data fpp(16,17, 6,1),fpp(16,17, 6,2),fpp(16,17, 6,3)/
     x 8.2152166d-01,-1.1408508d-04, 4.3444799d-06 /
      data fpp(16,17, 7,1),fpp(16,17, 7,2),fpp(16,17, 7,3)/
     x-1.0586465d-02,-7.1502481d-05, 5.2051592d-06 /
      data fpp(16,17, 8,1),fpp(16,17, 8,2),fpp(16,17, 8,3)/
     x 6.1648043d-03,-4.3382830d-05, 4.0488832d-06 /
      data fpp(16,17, 9,1),fpp(16,17, 9,2),fpp(16,17, 9,3)/
     x 3.2860907d-03,-2.3670670d-05, 2.8153079d-06 /
      data fpp(16,17,10,1),fpp(16,17,10,2),fpp(16,17,10,3)/
     x 6.0127003d-03,-1.0682698d-05, 1.9338852d-06 /
      data fpp(16,17,11,1),fpp(16,17,11,2),fpp(16,17,11,3)/
     x 7.5369806d-03,-2.8511075d-06, 1.4191513d-06 /
      data fpp(16,17,12,1),fpp(16,17,12,2),fpp(16,17,12,3)/
     x 8.2757086d-03, 1.4906743d-06, 1.1615097d-06 /
      data fpp(16,17,13,1),fpp(16,17,13,2),fpp(16,17,13,3)/
     x 8.5748116d-03, 3.7477686d-06, 1.0088101d-06 /
      data fpp(16,17,14,1),fpp(16,17,14,2),fpp(16,17,14,3)/
     x 8.7431125d-03, 4.9636118d-06, 8.8725010d-07 /
      data fpp(16,17,15,1),fpp(16,17,15,2),fpp(16,17,15,3)/
     x 8.8498225d-03, 5.7620395d-06, 7.2818953d-07 /
      data fpp(16,17,16,1),fpp(16,17,16,2),fpp(16,17,16,3)/
     x 8.9426378d-03, 6.4622551d-06, 5.3799179d-07 /
      data fpp(16,17,17,1),fpp(16,17,17,2),fpp(16,17,17,3)/
     x 9.0233698d-03, 7.1671692d-06, 3.1184331d-07 /
      data fpp(16,17,18,1),fpp(16,17,18,2),fpp(16,17,18,3)/
     x 9.1278714d-03, 7.8615149d-06, 1.0463497d-07 /
      data fpp(16,17,19,1),fpp(16,17,19,2),fpp(16,17,19,3)/
     x 9.2490483d-03, 8.4440646d-06,-8.8383185d-08 /
      data fpp(16,17,20,1),fpp(16,17,20,2),fpp(16,17,20,3)/
     x 9.2740013d-03, 8.8542168d-06,-2.1310223d-07 /
      data fpp(16,17,21,1),fpp(16,17,21,2),fpp(16,17,21,3)/
     x 9.2740013d-03, 8.8542168d-06,-2.1950172d-07 /
      data fpp(16,17,22,1),fpp(16,17,22,2),fpp(16,17,22,3)/
     x 9.2490483d-03, 8.4440646d-06,-6.2785223d-08 /
      data fpp(16,17,23,1),fpp(16,17,23,2),fpp(16,17,23,3)/
     x 9.1278714d-03, 7.8615149d-06, 8.6426115d-09 /
      data fpp(16,18, 1,1),fpp(16,18, 1,2),fpp(16,18, 1,3)/
     x 1.2012018d-02, 9.0657374d-06,-1.0991384d-06 /
      data fpp(16,18, 2,1),fpp(16,18, 2,2),fpp(16,18, 2,3)/
     x 1.0652056d-02, 3.4992006d-05,-1.4597232d-06 /
      data fpp(16,18, 3,1),fpp(16,18, 3,2),fpp(16,18, 3,3)/
     x 8.9648441d-03, 6.3909325d-05,-2.2419688d-06 /
      data fpp(16,18, 4,1),fpp(16,18, 4,2),fpp(16,18, 4,3)/
     x 8.9648441d-03, 6.3909325d-05,-2.2252321d-06 /
      data fpp(16,18, 5,1),fpp(16,18, 5,2),fpp(16,18, 5,3)/
     x 1.0652056d-02, 3.4992006d-05,-1.5266699d-06 /
      data fpp(16,18, 6,1),fpp(16,18, 6,2),fpp(16,18, 6,3)/
     x 1.2012018d-02, 9.0657374d-06,-8.4808843d-07 /
      data fpp(16,18, 7,1),fpp(16,18, 7,2),fpp(16,18, 7,3)/
     x 1.0095846d-02,-4.1791482d-06,-1.9897640d-07 /
      data fpp(16,18, 8,1),fpp(16,18, 8,2),fpp(16,18, 8,3)/
     x 9.5805886d-03,-9.4879059d-06, 2.5199403d-07 /
      data fpp(16,18, 9,1),fpp(16,18, 9,2),fpp(16,18, 9,3)/
     x 9.4082820d-03,-1.0312237d-05, 5.2300026d-07 /
      data fpp(16,18,10,1),fpp(16,18,10,2),fpp(16,18,10,3)/
     x 9.2103662d-03,-8.7885148d-06, 6.4400492d-07 /
      data fpp(16,18,11,1),fpp(16,18,11,2),fpp(16,18,11,3)/
     x 9.1519240d-03,-6.1805407d-06, 6.8098006d-07 /
      data fpp(16,18,12,1),fpp(16,18,12,2),fpp(16,18,12,3)/
     x 9.0934829d-03,-3.1920498d-06, 6.5807484d-07 /
      data fpp(16,18,13,1),fpp(16,18,13,2),fpp(16,18,13,3)/
     x 9.0283384d-03,-1.5693389d-07, 6.1072058d-07 /
      data fpp(16,18,14,1),fpp(16,18,14,2),fpp(16,18,14,3)/
     x 9.0206275d-03, 2.7705395d-06, 5.5304282d-07 /
      data fpp(16,18,15,1),fpp(16,18,15,2),fpp(16,18,15,3)/
     x 8.9331863d-03, 5.5225601d-06, 4.7710812d-07 /
      data fpp(16,18,16,1),fpp(16,18,16,2),fpp(16,18,16,3)/
     x 8.9701232d-03, 8.0562128d-06, 4.0652471d-07 /
      data fpp(16,18,17,1),fpp(16,18,17,2),fpp(16,18,17,3)/
     x 8.9927784d-03, 1.0309666d-05, 3.3879306d-07 /
      data fpp(16,18,18,1),fpp(16,18,18,2),fpp(16,18,18,3)/
     x 8.9640821d-03, 1.2195996d-05, 2.6630305d-07 /
      data fpp(16,18,19,1),fpp(16,18,19,2),fpp(16,18,19,3)/
     x 9.0079116d-03, 1.3630982d-05, 2.3999474d-07 /
      data fpp(16,18,20,1),fpp(16,18,20,2),fpp(16,18,20,3)/
     x 9.0394125d-03, 1.4503081d-05, 1.7771797d-07 /
      data fpp(16,18,21,1),fpp(16,18,21,2),fpp(16,18,21,3)/
     x 9.0394125d-03, 1.4503081d-05, 1.7784871d-07 /
      data fpp(16,18,22,1),fpp(16,18,22,2),fpp(16,18,22,3)/
     x 9.0079116d-03, 1.3630982d-05, 2.3947180d-07 /
      data fpp(16,18,23,1),fpp(16,18,23,2),fpp(16,18,23,3)/
     x 8.9640821d-03, 1.2195996d-05, 2.6826410d-07 /
      data fpp(16,19, 1,1),fpp(16,19, 1,2),fpp(16,19, 1,3)/
     x 9.5932452d-03, 7.1690131d-05, 1.0138933d-20 /
      data fpp(16,19, 2,1),fpp(16,19, 2,2),fpp(16,19, 2,3)/
     x 9.5932452d-03, 1.2872200d-04, 7.5359405d-21 /
      data fpp(16,19, 3,1),fpp(16,19, 3,2),fpp(16,19, 3,3)/
     x 9.5932452d-03, 1.8350534d-04,-1.0537950d-20 /
      data fpp(16,19, 4,1),fpp(16,19, 4,2),fpp(16,19, 4,3)/
     x 9.5932452d-03, 1.8350534d-04, 9.1153222d-21 /
      data fpp(16,19, 5,1),fpp(16,19, 5,2),fpp(16,19, 5,3)/
     x 9.5932452d-03, 1.2872200d-04, 1.7981002d-21 /
      data fpp(16,19, 6,1),fpp(16,19, 6,2),fpp(16,19, 6,3)/
     x 9.5932452d-03, 7.1690131d-05,-8.0000225d-21 /
      data fpp(16,19, 7,1),fpp(16,19, 7,2),fpp(16,19, 7,3)/
     x 9.5932452d-03, 3.1753074d-05,-1.7421657d-20 /
      data fpp(16,19, 8,1),fpp(16,19, 8,2),fpp(16,19, 8,3)/
     x 9.5932452d-03, 6.5324529d-06,-1.2024103d-20 /
      data fpp(16,19, 9,1),fpp(16,19, 9,2),fpp(16,19, 9,3)/
     x 9.5932452d-03,-6.6663814d-06, 4.9330327d-21 /
      data fpp(16,19,10,1),fpp(16,19,10,2),fpp(16,19,10,3)/
     x 9.5932452d-03,-1.1265243d-05, 1.2297376d-20 /
      data fpp(16,19,11,1),fpp(16,19,11,2),fpp(16,19,11,3)/
     x 9.5932452d-03,-1.0634730d-05,-2.0630100d-20 /
      data fpp(16,19,12,1),fpp(16,19,12,2),fpp(16,19,12,3)/
     x 9.5932452d-03,-7.3164751d-06, 7.0494726d-21 /
      data fpp(16,19,13,1),fpp(16,19,13,2),fpp(16,19,13,3)/
     x 9.5932452d-03,-2.8740331d-06, 7.1850759d-21 /
      data fpp(16,19,14,1),fpp(16,19,14,2),fpp(16,19,14,3)/
     x 9.5932452d-03, 1.8162303d-06,-9.2221352d-21 /
      data fpp(16,19,15,1),fpp(16,19,15,2),fpp(16,19,15,3)/
     x 9.5932452d-03, 6.3117199d-06,-6.6723579d-21 /
      data fpp(16,19,16,1),fpp(16,19,16,2),fpp(16,19,16,3)/
     x 9.5932452d-03, 1.0380894d-05,-1.1110827d-21 /
      data fpp(16,19,17,1),fpp(16,19,17,2),fpp(16,19,17,3)/
     x 9.5932452d-03, 1.3874167d-05, 1.2693368d-20 /
      data fpp(16,19,18,1),fpp(16,19,18,2),fpp(16,19,18,3)/
     x 9.5932452d-03, 1.6680502d-05,-1.2193185d-20 /
      data fpp(16,19,19,1),fpp(16,19,19,2),fpp(16,19,19,3)/
     x 9.5932452d-03, 1.8758009d-05,-1.1797484d-20 /
      data fpp(16,19,20,1),fpp(16,19,20,2),fpp(16,19,20,3)/
     x 9.5932452d-03, 1.9989460d-05, 6.2818827d-21 /
      data fpp(16,19,21,1),fpp(16,19,21,2),fpp(16,19,21,3)/
     x 9.5932452d-03, 1.9989460d-05,-6.8209350d-21 /
      data fpp(16,19,22,1),fpp(16,19,22,2),fpp(16,19,22,3)/
     x 9.5932452d-03, 1.8758009d-05, 1.4511726d-20 /
      data fpp(16,19,23,1),fpp(16,19,23,2),fpp(16,19,23,3)/
     x 9.5932452d-03, 1.6680502d-05, 2.2840885d-20 /
      data fpp(17, 1, 1,1),fpp(17, 1, 1,2),fpp(17, 1, 1,3)/
     x 6.5919482d+00, 5.4999137d-04, 5.2340576d-20 /
      data fpp(17, 1, 2,1),fpp(17, 1, 2,2),fpp(17, 1, 2,3)/
     x 6.5919482d+00, 1.5405040d-03,-1.3063772d-20 /
      data fpp(17, 1, 3,1),fpp(17, 1, 3,2),fpp(17, 1, 3,3)/
     x 6.5919482d+00, 2.7311195d-03,-2.9392813d-20 /
      data fpp(17, 1, 4,1),fpp(17, 1, 4,2),fpp(17, 1, 4,3)/
     x 6.5919482d+00, 2.7311195d-03, 1.1357603d-19 /
      data fpp(17, 1, 5,1),fpp(17, 1, 5,2),fpp(17, 1, 5,3)/
     x 6.5919482d+00, 1.5405040d-03,-2.6603943d-20 /
      data fpp(17, 1, 6,1),fpp(17, 1, 6,2),fpp(17, 1, 6,3)/
     x 6.5919482d+00, 5.4999137d-04,-9.8012081d-20 /
      data fpp(17, 1, 7,1),fpp(17, 1, 7,2),fpp(17, 1, 7,3)/
     x 6.5919482d+00,-1.5540132d-05,-2.4364272d-19 /
      data fpp(17, 1, 8,1),fpp(17, 1, 8,2),fpp(17, 1, 8,3)/
     x 6.5919482d+00,-2.2962119d-04, 1.5522828d-20 /
      data fpp(17, 1, 9,1),fpp(17, 1, 9,2),fpp(17, 1, 9,3)/
     x 6.5919482d+00,-3.7284412d-04, 5.2108340d-20 /
      data fpp(17, 1,10,1),fpp(17, 1,10,2),fpp(17, 1,10,3)/
     x 6.5919482d+00,-4.5544523d-04, 9.9789781d-20 /
      data fpp(17, 1,11,1),fpp(17, 1,11,2),fpp(17, 1,11,3)/
     x 6.5919482d+00,-5.0207487d-04, 2.2747918d-20 /
      data fpp(17, 1,12,1),fpp(17, 1,12,2),fpp(17, 1,12,3)/
     x 6.5919482d+00,-6.0798964d-04, 1.2615334d-19 /
      data fpp(17, 1,13,1),fpp(17, 1,13,2),fpp(17, 1,13,3)/
     x 6.5919482d+00,-5.9818489d-04, 6.6371469d-20 /
      data fpp(17, 1,14,1),fpp(17, 1,14,2),fpp(17, 1,14,3)/
     x 6.5919482d+00,-4.6929193d-04,-6.9867828d-20 /
      data fpp(17, 1,15,1),fpp(17, 1,15,2),fpp(17, 1,15,3)/
     x 6.5919482d+00,-3.9102987d-04, 8.6162387d-20 /
      data fpp(17, 1,16,1),fpp(17, 1,16,2),fpp(17, 1,16,3)/
     x 6.5919482d+00,-2.4962801d-04,-1.0683269d-19 /
      data fpp(17, 1,17,1),fpp(17, 1,17,2),fpp(17, 1,17,3)/
     x 6.5919482d+00,-3.3951602d-05, 2.5966472d-20 /
      data fpp(17, 1,18,1),fpp(17, 1,18,2),fpp(17, 1,18,3)/
     x 6.5919482d+00, 5.3016097d-04,-6.9005368d-20 /
      data fpp(17, 1,19,1),fpp(17, 1,19,2),fpp(17, 1,19,3)/
     x 6.5919482d+00, 1.5161348d-03,-1.8762649d-19 /
      data fpp(17, 1,20,1),fpp(17, 1,20,2),fpp(17, 1,20,3)/
     x 6.5919482d+00, 2.7006859d-03, 9.5115881d-20 /
      data fpp(17, 1,21,1),fpp(17, 1,21,2),fpp(17, 1,21,3)/
     x 6.5919482d+00, 2.7006859d-03,-4.7086694d-20 /
      data fpp(17, 1,22,1),fpp(17, 1,22,2),fpp(17, 1,22,3)/
     x 6.5919482d+00, 1.5161348d-03, 1.1842132d-19 /
      data fpp(17, 1,23,1),fpp(17, 1,23,2),fpp(17, 1,23,3)/
     x 6.5919482d+00, 5.3016097d-04, 2.5298231d-19 /
      data fpp(17, 2, 1,1),fpp(17, 2, 1,2),fpp(17, 2, 1,3)/
     x 1.6199203d-01, 2.2641826d-04,-7.7196011d-06 /
      data fpp(17, 2, 2,1),fpp(17, 2, 2,2),fpp(17, 2, 2,3)/
     x 1.7574958d-01, 6.0713606d-04,-1.5473798d-05 /
      data fpp(17, 2, 3,1),fpp(17, 2, 3,2),fpp(17, 2, 3,3)/
     x 2.3450239d-01, 1.0535270d-03,-3.2217207d-05 /
      data fpp(17, 2, 4,1),fpp(17, 2, 4,2),fpp(17, 2, 4,3)/
     x 2.3450239d-01, 1.0535270d-03,-3.1994479d-05 /
      data fpp(17, 2, 5,1),fpp(17, 2, 5,2),fpp(17, 2, 5,3)/
     x 1.7574958d-01, 6.0713606d-04,-1.6364713d-05 /
      data fpp(17, 2, 6,1),fpp(17, 2, 6,2),fpp(17, 2, 6,3)/
     x 1.6199203d-01, 2.2641826d-04,-4.3786682d-06 /
      data fpp(17, 2, 7,1),fpp(17, 2, 7,2),fpp(17, 2, 7,3)/
     x 1.4711381d-01, 6.7922643d-06, 4.4613862d-06 /
      data fpp(17, 2, 8,1),fpp(17, 2, 8,2),fpp(17, 2, 8,3)/
     x 1.3221723d-01,-6.8787626d-05, 8.8651235d-06 /
      data fpp(17, 2, 9,1),fpp(17, 2, 9,2),fpp(17, 2, 9,3)/
     x 2.3500451d-01,-1.1769376d-04, 1.5752120d-05 /
      data fpp(17, 2,10,1),fpp(17, 2,10,2),fpp(17, 2,10,3)/
     x 2.1731970d-01,-1.4361754d-04, 5.8803972d-06 /
      data fpp(17, 2,11,1),fpp(17, 2,11,2),fpp(17, 2,11,3)/
     x 5.8133923d-01,-1.5781827d-04, 5.5112291d-05 /
      data fpp(17, 2,12,1),fpp(17, 2,12,2),fpp(17, 2,12,3)/
     x 1.8669097d-01,-2.0706972d-04,-1.0587562d-05 /
      data fpp(17, 2,13,1),fpp(17, 2,13,2),fpp(17, 2,13,3)/
     x-1.8564372d-01,-2.0613922d-04,-1.1808042d-05 /
      data fpp(17, 2,14,1),fpp(17, 2,14,2),fpp(17, 2,14,3)/
     x 2.1641521d-01,-1.5323514d-04, 5.3577729d-05 /
      data fpp(17, 2,15,1),fpp(17, 2,15,2),fpp(17, 2,15,3)/
     x 2.3393587d-01,-1.3093826d-04, 3.3511255d-06 /
      data fpp(17, 2,16,1),fpp(17, 2,16,2),fpp(17, 2,16,3)/
     x 1.3215315d-01,-8.4506980d-05, 1.2301769d-05 /
      data fpp(17, 2,17,1),fpp(17, 2,17,2),fpp(17, 2,17,3)/
     x 1.4533759d-01,-9.7477952d-06, 3.4397987d-06 /
      data fpp(17, 2,18,1),fpp(17, 2,18,2),fpp(17, 2,18,3)/
     x 1.5901163d-01, 2.0811706d-04,-4.7549637d-06 /
      data fpp(17, 2,19,1),fpp(17, 2,19,2),fpp(17, 2,19,3)/
     x 2.0881985d-01, 5.8712438d-04,-1.7155944d-05 /
      data fpp(17, 2,20,1),fpp(17, 2,20,2),fpp(17, 2,20,3)/
     x 2.3209106d-01, 1.0332752d-03,-3.3031261d-05 /
      data fpp(17, 2,21,1),fpp(17, 2,21,2),fpp(17, 2,21,3)/
     x 2.3209106d-01, 1.0332752d-03,-3.3268246d-05 /
      data fpp(17, 2,22,1),fpp(17, 2,22,2),fpp(17, 2,22,3)/
     x 2.0881985d-01, 5.8712438d-04,-1.6208001d-05 /
      data fpp(17, 2,23,1),fpp(17, 2,23,2),fpp(17, 2,23,3)/
     x 1.5901163d-01, 2.0811706d-04,-8.3097495d-06 /
      data fpp(17, 3, 1,1),fpp(17, 3, 1,2),fpp(17, 3, 1,3)/
     x 2.5261485d-01,-4.0947443d-04, 3.6543326d-04 /
      data fpp(17, 3, 2,1),fpp(17, 3, 2,2),fpp(17, 3, 2,3)/
     x 6.1115977d-01,-9.3072022d-04, 1.1701198d-04 /
      data fpp(17, 3, 3,1),fpp(17, 3, 3,2),fpp(17, 3, 3,3)/
     x 3.2637577d-01,-1.2845636d-03,-4.0694720d-04 /
      data fpp(17, 3, 4,1),fpp(17, 3, 4,2),fpp(17, 3, 4,3)/
     x 3.2637577d-01,-1.2845636d-03,-4.2159840d-04 /
      data fpp(17, 3, 5,1),fpp(17, 3, 5,2),fpp(17, 3, 5,3)/
     x 6.1115977d-01,-9.3072022d-04, 1.7561681d-04 /
      data fpp(17, 3, 6,1),fpp(17, 3, 6,2),fpp(17, 3, 6,3)/
     x 2.5261485d-01,-4.0947443d-04, 1.4566517d-04 /
      data fpp(17, 3, 7,1),fpp(17, 3, 7,2),fpp(17, 3, 7,3)/
     x 1.9882462d-01,-3.5169251d-06, 1.3694651d-04 /
      data fpp(17, 3, 8,1),fpp(17, 3, 8,2),fpp(17, 3, 8,3)/
     x 4.3533022d-02, 1.4203569d-04, 1.8442805d-05 /
      data fpp(17, 3, 9,1),fpp(17, 3, 9,2),fpp(17, 3, 9,3)/
     x 1.7903581d-02, 2.6092318d-04, 5.1518273d-05 /
      data fpp(17, 3,10,1),fpp(17, 3,10,2),fpp(17, 3,10,3)/
     x 8.1347538d-03, 3.3330340d-04, 3.7036101d-05 /
      data fpp(17, 3,11,1),fpp(17, 3,11,2),fpp(17, 3,11,3)/
     x 4.9049507d-03, 3.7525993d-04, 4.1549323d-05 /
      data fpp(17, 3,12,1),fpp(17, 3,12,2),fpp(17, 3,12,3)/
     x 4.1537781d-03, 4.2958251d-04, 4.1128608d-05 /
      data fpp(17, 3,13,1),fpp(17, 3,13,2),fpp(17, 3,13,3)/
     x 4.8707908d-03, 4.1375179d-04, 4.2138245d-05 /
      data fpp(17, 3,14,1),fpp(17, 3,14,2),fpp(17, 3,14,3)/
     x 8.0043823d-03, 3.2742649d-04, 3.8322411d-05 /
      data fpp(17, 3,15,1),fpp(17, 3,15,2),fpp(17, 3,15,3)/
     x 1.5097711d-02, 2.5096690d-04, 5.3086111d-05 /
      data fpp(17, 3,16,1),fpp(17, 3,16,2),fpp(17, 3,16,3)/
     x 4.1748798d-02, 1.2797793d-04, 2.1049146d-05 /
      data fpp(17, 3,17,1),fpp(17, 3,17,2),fpp(17, 3,17,3)/
     x 1.9402699d-01,-2.0207217d-05, 1.3710331d-04 /
      data fpp(17, 3,18,1),fpp(17, 3,18,2),fpp(17, 3,18,3)/
     x 2.5134076d-01,-4.1753922d-04, 1.4486163d-04 /
      data fpp(17, 3,19,1),fpp(17, 3,19,2),fpp(17, 3,19,3)/
     x 5.9482565d-01,-9.2624032d-04, 1.7304016d-04 /
      data fpp(17, 3,20,1),fpp(17, 3,20,2),fpp(17, 3,20,3)/
     x 8.2673493d-03,-1.2754767d-03,-4.2322628d-04 /
      data fpp(17, 3,21,1),fpp(17, 3,21,2),fpp(17, 3,21,3)/
     x 8.2673493d-03,-1.2754767d-03,-4.0868025d-04 /
      data fpp(17, 3,22,1),fpp(17, 3,22,2),fpp(17, 3,22,3)/
     x 5.9482565d-01,-9.2624032d-04, 1.1485607d-04 /
      data fpp(17, 3,23,1),fpp(17, 3,23,2),fpp(17, 3,23,3)/
     x 2.5134076d-01,-4.1753922d-04, 3.6305196d-04 /
      data fpp(17, 4, 1,1),fpp(17, 4, 1,2),fpp(17, 4, 1,3)/
     x 1.3089036d-01, 4.7751444d-05, 6.4016882d-04 /
      data fpp(17, 4, 2,1),fpp(17, 4, 2,2),fpp(17, 4, 2,3)/
     x 4.1412714d-01,-3.5286717d-04, 2.5855486d-04 /
      data fpp(17, 4, 3,1),fpp(17, 4, 3,2),fpp(17, 4, 3,3)/
     x-8.8595709d-01,-1.3109105d-03,-5.4163026d-04 /
      data fpp(17, 4, 4,1),fpp(17, 4, 4,2),fpp(17, 4, 4,3)/
     x-8.8595709d-01,-1.3109105d-03,-5.7235865d-04 /
      data fpp(17, 4, 5,1),fpp(17, 4, 5,2),fpp(17, 4, 5,3)/
     x 4.1412714d-01,-3.5286717d-04, 3.8146844d-04 /
      data fpp(17, 4, 6,1),fpp(17, 4, 6,2),fpp(17, 4, 6,3)/
     x 1.3089036d-01, 4.7751444d-05, 1.7924290d-04 /
      data fpp(17, 4, 7,1),fpp(17, 4, 7,2),fpp(17, 4, 7,3)/
     x-6.3725008d-02, 1.0041944d-04, 7.3413972d-05 /
      data fpp(17, 4, 8,1),fpp(17, 4, 8,2),fpp(17, 4, 8,3)/
     x-2.0763525d-02, 1.7789486d-04, 5.5791214d-05 /
      data fpp(17, 4, 9,1),fpp(17, 4, 9,2),fpp(17, 4, 9,3)/
     x-2.3828546d-02, 2.0740706d-04, 4.4269174d-05 /
      data fpp(17, 4,10,1),fpp(17, 4,10,2),fpp(17, 4,10,3)/
     x-2.3182981d-02, 2.3239795d-04, 4.4914092d-05 /
      data fpp(17, 4,11,1),fpp(17, 4,11,2),fpp(17, 4,11,3)/
     x-2.2442497d-02, 2.4746253d-04, 4.4214458d-05 /
      data fpp(17, 4,12,1),fpp(17, 4,12,2),fpp(17, 4,12,3)/
     x-2.2101546d-02, 2.4117166d-04, 4.4268074d-05 /
      data fpp(17, 4,13,1),fpp(17, 4,13,2),fpp(17, 4,13,3)/
     x-2.2079498d-02, 2.3618408d-04, 4.5035244d-05 /
      data fpp(17, 4,14,1),fpp(17, 4,14,2),fpp(17, 4,14,3)/
     x-2.2415193d-02, 2.3197117d-04, 4.6610949d-05 /
      data fpp(17, 4,15,1),fpp(17, 4,15,2),fpp(17, 4,15,3)/
     x-2.2697419d-02, 2.0652467d-04, 4.7316958d-05 /
      data fpp(17, 4,16,1),fpp(17, 4,16,2),fpp(17, 4,16,3)/
     x-1.9402573d-02, 1.7468926d-04, 5.9897217d-05 /
      data fpp(17, 4,17,1),fpp(17, 4,17,2),fpp(17, 4,17,3)/
     x 1.2900744d-03, 9.0654662d-05, 8.1212174d-05 /
      data fpp(17, 4,18,1),fpp(17, 4,18,2),fpp(17, 4,18,3)/
     x 1.1954636d-01, 1.9447815d-05, 1.8194209d-04 /
      data fpp(17, 4,19,1),fpp(17, 4,19,2),fpp(17, 4,19,3)/
     x 4.1017784d-01,-3.9436509d-04, 3.7599548d-04 /
      data fpp(17, 4,20,1),fpp(17, 4,20,2),fpp(17, 4,20,3)/
     x-1.2061949d+00,-1.3395345d-03,-5.7827602d-04 /
      data fpp(17, 4,21,1),fpp(17, 4,21,2),fpp(17, 4,21,3)/
     x-1.2061949d+00,-1.3395345d-03,-5.4792569d-04 /
      data fpp(17, 4,22,1),fpp(17, 4,22,2),fpp(17, 4,22,3)/
     x 4.1017784d-01,-3.9436509d-04, 2.5459420d-04 /
      data fpp(17, 4,23,1),fpp(17, 4,23,2),fpp(17, 4,23,3)/
     x 1.1954636d-01, 1.9447815d-05, 6.3719690d-04 /
      data fpp(17, 5, 1,1),fpp(17, 5, 1,2),fpp(17, 5, 1,3)/
     x-3.6390637d-02, 9.0902650d-05, 1.5408172d-04 /
      data fpp(17, 5, 2,1),fpp(17, 5, 2,2),fpp(17, 5, 2,3)/
     x-5.8100393d-02, 4.0667891d-04, 4.0071050d-05 /
      data fpp(17, 5, 3,1),fpp(17, 5, 3,2),fpp(17, 5, 3,3)/
     x-3.8138876d-01, 1.0607356d-03,-1.9939993d-04 /
      data fpp(17, 5, 4,1),fpp(17, 5, 4,2),fpp(17, 5, 4,3)/
     x-3.8138876d-01, 1.0607356d-03,-2.0786575d-04 /
      data fpp(17, 5, 5,1),fpp(17, 5, 5,2),fpp(17, 5, 5,3)/
     x-5.8100393d-02, 4.0667891d-04, 7.3934347d-05 /
      data fpp(17, 5, 6,1),fpp(17, 5, 6,2),fpp(17, 5, 6,3)/
     x-3.6390637d-02, 9.0902650d-05, 2.7094362d-05 /
      data fpp(17, 5, 7,1),fpp(17, 5, 7,2),fpp(17, 5, 7,3)/
     x-3.0029202d-02, 5.5193180d-05, 3.9148204d-05 /
      data fpp(17, 5, 8,1),fpp(17, 5, 8,2),fpp(17, 5, 8,3)/
     x-2.6470644d-02, 5.4244867d-05, 3.5384821d-05 /
      data fpp(17, 5, 9,1),fpp(17, 5, 9,2),fpp(17, 5, 9,3)/
     x-2.4752981d-02, 7.0400599d-05, 3.7358513d-05 /
      data fpp(17, 5,10,1),fpp(17, 5,10,2),fpp(17, 5,10,3)/
     x-2.4177359d-02, 7.8494786d-05, 3.6539126d-05 /
      data fpp(17, 5,11,1),fpp(17, 5,11,2),fpp(17, 5,11,3)/
     x-2.4076462d-02, 8.0979954d-05, 3.5814983d-05 /
      data fpp(17, 5,12,1),fpp(17, 5,12,2),fpp(17, 5,12,3)/
     x-2.3982775d-02, 8.4400842d-05, 3.5798943d-05 /
      data fpp(17, 5,13,1),fpp(17, 5,13,2),fpp(17, 5,13,3)/
     x-2.3722607d-02, 8.4217902d-05, 3.6887244d-05 /
      data fpp(17, 5,14,1),fpp(17, 5,14,2),fpp(17, 5,14,3)/
     x-2.3441280d-02, 7.9436822d-05, 3.8694080d-05 /
      data fpp(17, 5,15,1),fpp(17, 5,15,2),fpp(17, 5,15,3)/
     x-2.3508096d-02, 7.3050420d-05, 4.0740438d-05 /
      data fpp(17, 5,16,1),fpp(17, 5,16,2),fpp(17, 5,16,3)/
     x-2.4282660d-02, 6.0755047d-05, 4.0186170d-05 /
      data fpp(17, 5,17,1),fpp(17, 5,17,2),fpp(17, 5,17,3)/
     x-2.5784966d-02, 6.8402570d-05, 4.6314882d-05 /
      data fpp(17, 5,18,1),fpp(17, 5,18,2),fpp(17, 5,18,3)/
     x-2.7485003d-02, 1.1449596d-04, 3.4216302d-05 /
      data fpp(17, 5,19,1),fpp(17, 5,19,2),fpp(17, 5,19,3)/
     x-3.0431405d-02, 4.2917666d-04, 8.3975911d-05 /
      data fpp(17, 5,20,1),fpp(17, 5,20,2),fpp(17, 5,20,3)/
     x-6.1453431d-02, 1.0543227d-03,-2.2411595d-04 /
      data fpp(17, 5,21,1),fpp(17, 5,21,2),fpp(17, 5,21,3)/
     x-6.1453431d-02, 1.0543227d-03,-2.1492912d-04 /
      data fpp(17, 5,22,1),fpp(17, 5,22,2),fpp(17, 5,22,3)/
     x-3.0431405d-02, 4.2917666d-04, 4.7228605d-05 /
      data fpp(17, 5,23,1),fpp(17, 5,23,2),fpp(17, 5,23,3)/
     x-2.7485003d-02, 1.1449596d-04, 1.7201870d-04 /
      data fpp(17, 6, 1,1),fpp(17, 6, 1,2),fpp(17, 6, 1,3)/
     x-9.7038620d-03, 1.0029956d-05, 1.2527021d-05 /
      data fpp(17, 6, 2,1),fpp(17, 6, 2,2),fpp(17, 6, 2,3)/
     x-3.0301612d-03,-1.5858485d-05,-1.5646043d-05 /
      data fpp(17, 6, 3,1),fpp(17, 6, 3,2),fpp(17, 6, 3,3)/
     x 1.2203584d-02,-6.0281783d-05,-7.5606850d-05 /
      data fpp(17, 6, 4,1),fpp(17, 6, 4,2),fpp(17, 6, 4,3)/
     x 1.2203584d-02,-6.0281783d-05,-7.6324428d-05 /
      data fpp(17, 6, 5,1),fpp(17, 6, 5,2),fpp(17, 6, 5,3)/
     x-3.0301612d-03,-1.5858485d-05,-1.2775731d-05 /
      data fpp(17, 6, 6,1),fpp(17, 6, 6,2),fpp(17, 6, 6,3)/
     x-9.7038620d-03, 1.0029956d-05, 1.7633523d-06 /
      data fpp(17, 6, 7,1),fpp(17, 6, 7,2),fpp(17, 6, 7,3)/
     x-1.3073577d-02, 8.3384245d-07, 1.4020322d-05 /
      data fpp(17, 6, 8,1),fpp(17, 6, 8,2),fpp(17, 6, 8,3)/
     x-1.5428019d-02,-4.5203295d-06, 1.9303360d-05 /
      data fpp(17, 6, 9,1),fpp(17, 6, 9,2),fpp(17, 6, 9,3)/
     x-1.7365906d-02,-1.2243454d-05, 2.2094239d-05 /
      data fpp(17, 6,10,1),fpp(17, 6,10,2),fpp(17, 6,10,3)/
     x-1.8785026d-02,-1.6907099d-05, 2.3545684d-05 /
      data fpp(17, 6,11,1),fpp(17, 6,11,2),fpp(17, 6,11,3)/
     x-1.9667691d-02,-1.8662342d-05, 2.4789026d-05 /
      data fpp(17, 6,12,1),fpp(17, 6,12,2),fpp(17, 6,12,3)/
     x-1.9939373d-02,-1.9479029d-05, 2.5780210d-05 /
      data fpp(17, 6,13,1),fpp(17, 6,13,2),fpp(17, 6,13,3)/
     x-1.9674564d-02,-1.8349685d-05, 2.6398132d-05 /
      data fpp(17, 6,14,1),fpp(17, 6,14,2),fpp(17, 6,14,3)/
     x-1.8856852d-02,-1.4440461d-05, 2.6853263d-05 /
      data fpp(17, 6,15,1),fpp(17, 6,15,2),fpp(17, 6,15,3)/
     x-1.7485559d-02,-7.8843497d-06, 2.7192816d-05 /
      data fpp(17, 6,16,1),fpp(17, 6,16,2),fpp(17, 6,16,3)/
     x-1.5559736d-02, 2.4705550d-06, 2.6057474d-05 /
      data fpp(17, 6,17,1),fpp(17, 6,17,2),fpp(17, 6,17,3)/
     x-1.2950592d-02, 1.1263060d-05, 2.2069290d-05 /
      data fpp(17, 6,18,1),fpp(17, 6,18,2),fpp(17, 6,18,3)/
     x-9.1363255d-03, 2.4144343d-05, 9.0013661d-06 /
      data fpp(17, 6,19,1),fpp(17, 6,19,2),fpp(17, 6,19,3)/
     x-1.9977139d-03, 5.2604270d-06,-8.7607545d-06 /
      data fpp(17, 6,20,1),fpp(17, 6,20,2),fpp(17, 6,20,3)/
     x 1.1418339d-02,-2.3460149d-05,-8.8930348d-05 /
      data fpp(17, 6,21,1),fpp(17, 6,21,2),fpp(17, 6,21,3)/
     x 1.1418339d-02,-2.3460149d-05,-8.7997578d-05 /
      data fpp(17, 6,22,1),fpp(17, 6,22,2),fpp(17, 6,22,3)/
     x-1.9977139d-03, 5.2604270d-06,-1.2491835d-05 /
      data fpp(17, 6,23,1),fpp(17, 6,23,2),fpp(17, 6,23,3)/
     x-9.1363255d-03, 2.4144343d-05, 2.2992917d-05 /
      data fpp(17, 7, 1,1),fpp(17, 7, 1,2),fpp(17, 7, 1,3)/
     x 3.0794562d-03, 3.4709524d-05,-8.5811089d-06 /
      data fpp(17, 7, 2,1),fpp(17, 7, 2,2),fpp(17, 7, 2,3)/
     x 8.3773497d-03, 9.5793024d-05,-1.4057282d-05 /
      data fpp(17, 7, 3,1),fpp(17, 7, 3,2),fpp(17, 7, 3,3)/
     x 1.3590166d-02, 1.6835157d-04,-2.5867762d-05 /
      data fpp(17, 7, 4,1),fpp(17, 7, 4,2),fpp(17, 7, 4,3)/
     x 1.3590166d-02, 1.6835157d-04,-2.5735072d-05 /
      data fpp(17, 7, 5,1),fpp(17, 7, 5,2),fpp(17, 7, 5,3)/
     x 8.3773497d-03, 9.5793024d-05,-1.4588042d-05 /
      data fpp(17, 7, 6,1),fpp(17, 7, 6,2),fpp(17, 7, 6,3)/
     x 3.0794562d-03, 3.4709524d-05,-6.5907611d-06 /
      data fpp(17, 7, 7,1),fpp(17, 7, 7,2),fpp(17, 7, 7,3)/
     x-1.6165589d-03,-2.2725501d-06,-8.2914073d-08 /
      data fpp(17, 7, 8,1),fpp(17, 7, 8,2),fpp(17, 7, 8,3)/
     x-5.6887818d-03,-2.6857549d-05, 4.6724174d-06 /
      data fpp(17, 7, 9,1),fpp(17, 7, 9,2),fpp(17, 7, 9,3)/
     x-9.0860290d-03,-4.0350785d-05, 8.7232446d-06 /
      data fpp(17, 7,10,1),fpp(17, 7,10,2),fpp(17, 7,10,3)/
     x-1.1675598d-02,-4.7268389d-05, 1.2280604d-05 /
      data fpp(17, 7,11,1),fpp(17, 7,11,2),fpp(17, 7,11,3)/
     x-1.3403922d-02,-5.0142585d-05, 1.5024339d-05 /
      data fpp(17, 7,12,1),fpp(17, 7,12,2),fpp(17, 7,12,3)/
     x-1.4257008d-02,-4.9990727d-05, 1.6704040d-05 /
      data fpp(17, 7,13,1),fpp(17, 7,13,2),fpp(17, 7,13,3)/
     x-1.4233118d-02,-4.7527160d-05, 1.7369499d-05 /
      data fpp(17, 7,14,1),fpp(17, 7,14,2),fpp(17, 7,14,3)/
     x-1.3374798d-02,-4.2638979d-05, 1.7173962d-05 /
      data fpp(17, 7,15,1),fpp(17, 7,15,2),fpp(17, 7,15,3)/
     x-1.1674605d-02,-3.4067021d-05, 1.6204651d-05 /
      data fpp(17, 7,16,1),fpp(17, 7,16,2),fpp(17, 7,16,3)/
     x-9.1585462d-03,-2.0309267d-05, 1.4001433d-05 /
      data fpp(17, 7,17,1),fpp(17, 7,17,2),fpp(17, 7,17,3)/
     x-5.5235921d-03, 2.1591901d-06, 9.3776157d-06 /
      data fpp(17, 7,18,1),fpp(17, 7,18,2),fpp(17, 7,18,3)/
     x-1.0146134d-03, 3.4152666d-05,-1.7589619d-07 /
      data fpp(17, 7,19,1),fpp(17, 7,19,2),fpp(17, 7,19,3)/
     x 4.7031786d-03, 8.7579627d-05,-1.4242031d-05 /
      data fpp(17, 7,20,1),fpp(17, 7,20,2),fpp(17, 7,20,3)/
     x 1.0584695d-02, 1.5058593d-04,-3.8105980d-05 /
      data fpp(17, 7,21,1),fpp(17, 7,21,2),fpp(17, 7,21,3)/
     x 1.0584695d-02, 1.5058593d-04,-3.8245044d-05 /
      data fpp(17, 7,22,1),fpp(17, 7,22,2),fpp(17, 7,22,3)/
     x 4.7031786d-03, 8.7579627d-05,-1.3685773d-05 /
      data fpp(17, 7,23,1),fpp(17, 7,23,2),fpp(17, 7,23,3)/
     x-1.0146134d-03, 3.4152666d-05,-2.2618635d-06 /
      data fpp(17, 8, 1,1),fpp(17, 8, 1,2),fpp(17, 8, 1,3)/
     x 8.6257141d-03, 1.0119946d-05,-5.6450537d-06 /
      data fpp(17, 8, 2,1),fpp(17, 8, 2,2),fpp(17, 8, 2,3)/
     x 1.0895467d-02, 2.8230387d-05,-6.4568925d-06 /
      data fpp(17, 8, 3,1),fpp(17, 8, 3,2),fpp(17, 8, 3,3)/
     x-1.7983460d-01, 3.4983522d-05,-8.2113762d-06 /
      data fpp(17, 8, 4,1),fpp(17, 8, 4,2),fpp(17, 8, 4,3)/
     x-1.7983460d-01, 3.4983522d-05,-8.1854252d-06 /
      data fpp(17, 8, 5,1),fpp(17, 8, 5,2),fpp(17, 8, 5,3)/
     x 1.0895467d-02, 2.8230387d-05,-6.5606967d-06 /
      data fpp(17, 8, 6,1),fpp(17, 8, 6,2),fpp(17, 8, 6,3)/
     x 8.6257141d-03, 1.0119946d-05,-5.2557880d-06 /
      data fpp(17, 8, 7,1),fpp(17, 8, 7,2),fpp(17, 8, 7,3)/
     x 5.8393335d-03,-1.0583642d-05,-4.0541511d-06 /
      data fpp(17, 8, 8,1),fpp(17, 8, 8,2),fpp(17, 8, 8,3)/
     x 2.6026821d-03,-2.6721473d-05,-2.1796075d-06 /
      data fpp(17, 8, 9,1),fpp(17, 8, 9,2),fpp(17, 8, 9,3)/
     x-7.7240541d-04,-3.8015407d-05, 9.4658126d-07 /
      data fpp(17, 8,10,1),fpp(17, 8,10,2),fpp(17, 8,10,3)/
     x-3.8846149d-03,-4.4879345d-05, 4.6512825d-06 /
      data fpp(17, 8,11,1),fpp(17, 8,11,2),fpp(17, 8,11,3)/
     x-6.2772145d-03,-4.8121319d-05, 7.8262888d-06 /
      data fpp(17, 8,12,1),fpp(17, 8,12,2),fpp(17, 8,12,3)/
     x-7.7348250d-03,-4.8212064d-05, 9.9195623d-06 /
      data fpp(17, 8,13,1),fpp(17, 8,13,2),fpp(17, 8,13,3)/
     x-8.2307925d-03,-4.5305675d-05, 1.0797462d-05 /
      data fpp(17, 8,14,1),fpp(17, 8,14,2),fpp(17, 8,14,3)/
     x-7.7265217d-03,-3.9481621d-05, 1.0772590d-05 /
      data fpp(17, 8,15,1),fpp(17, 8,15,2),fpp(17, 8,15,3)/
     x-6.5250932d-03,-3.0897567d-05, 9.7901772d-06 /
      data fpp(17, 8,16,1),fpp(17, 8,16,2),fpp(17, 8,16,3)/
     x-4.1763479d-03,-1.9369486d-05, 7.8587011d-06 /
      data fpp(17, 8,17,1),fpp(17, 8,17,2),fpp(17, 8,17,3)/
     x-1.3171322d-03,-5.2358204d-06, 4.3450185d-06 /
      data fpp(17, 8,18,1),fpp(17, 8,18,2),fpp(17, 8,18,3)/
     x 2.1565514d-03, 1.1264992d-05,-1.3467752d-06 /
      data fpp(17, 8,19,1),fpp(17, 8,19,2),fpp(17, 8,19,3)/
     x 5.9564375d-03, 2.4599063d-05,-8.6059179d-06 /
      data fpp(17, 8,20,1),fpp(17, 8,20,2),fpp(17, 8,20,3)/
     x 9.2710038d-03, 3.1496411d-05,-1.7713553d-05 /
      data fpp(17, 8,21,1),fpp(17, 8,21,2),fpp(17, 8,21,3)/
     x 9.2710038d-03, 3.1496411d-05,-1.7856381d-05 /
      data fpp(17, 8,22,1),fpp(17, 8,22,2),fpp(17, 8,22,3)/
     x 5.9564375d-03, 2.4599063d-05,-8.0346053d-06 /
      data fpp(17, 8,23,1),fpp(17, 8,23,2),fpp(17, 8,23,3)/
     x 2.1565514d-03, 1.1264992d-05,-3.4891973d-06 /
      data fpp(17, 9, 1,1),fpp(17, 9, 1,2),fpp(17, 9, 1,3)/
     x 1.1064084d-02,-9.2613090d-06, 5.4467348d-06 /
      data fpp(17, 9, 2,1),fpp(17, 9, 2,2),fpp(17, 9, 2,3)/
     x 1.1215055d-02, 1.3273427d-05, 9.1453034d-07 /
      data fpp(17, 9, 3,1),fpp(17, 9, 3,2),fpp(17, 9, 3,3)/
     x-1.9059154d-01, 5.8932348d-05,-8.6248562d-06 /
      data fpp(17, 9, 4,1),fpp(17, 9, 4,2),fpp(17, 9, 4,3)/
     x-1.9059154d-01, 5.8932348d-05,-8.9266966d-06 /
      data fpp(17, 9, 5,1),fpp(17, 9, 5,2),fpp(17, 9, 5,3)/
     x 1.1215055d-02, 1.3273427d-05, 2.1218921d-06 /
      data fpp(17, 9, 6,1),fpp(17, 9, 6,2),fpp(17, 9, 6,3)/
     x 1.1064084d-02,-9.2613090d-06, 9.1912815d-07 /
      data fpp(17, 9, 7,1),fpp(17, 9, 7,2),fpp(17, 9, 7,3)/
     x 1.0244958d-02,-1.9352882d-05,-1.8684047d-06 /
      data fpp(17, 9, 8,1),fpp(17, 9, 8,2),fpp(17, 9, 8,3)/
     x 8.5273339d-03,-2.5190559d-05,-3.5855093d-06 /
      data fpp(17, 9, 9,1),fpp(17, 9, 9,2),fpp(17, 9, 9,3)/
     x 5.9762313d-03,-2.9299586d-05,-2.5755582d-06 /
      data fpp(17, 9,10,1),fpp(17, 9,10,2),fpp(17, 9,10,3)/
     x 3.0776534d-03,-3.1970232d-05, 2.9174207d-07 /
      data fpp(17, 9,11,1),fpp(17, 9,11,2),fpp(17, 9,11,3)/
     x 5.1134113d-04,-3.3006141d-05, 3.4605899d-06 /
      data fpp(17, 9,12,1),fpp(17, 9,12,2),fpp(17, 9,12,3)/
     x-1.4058854d-03,-3.2477017d-05, 5.7318982d-06 /
      data fpp(17, 9,13,1),fpp(17, 9,13,2),fpp(17, 9,13,3)/
     x-2.3799212d-03,-3.0414141d-05, 6.8398172d-06 /
      data fpp(17, 9,14,1),fpp(17, 9,14,2),fpp(17, 9,14,3)/
     x-2.4767777d-03,-2.6702535d-05, 7.0608328d-06 /
      data fpp(17, 9,15,1),fpp(17, 9,15,2),fpp(17, 9,15,3)/
     x-1.7885269d-03,-2.1214712d-05, 6.5028514d-06 /
      data fpp(17, 9,16,1),fpp(17, 9,16,2),fpp(17, 9,16,3)/
     x-3.8535359d-04,-1.4010789d-05, 5.1957616d-06 /
      data fpp(17, 9,17,1),fpp(17, 9,17,2),fpp(17, 9,17,3)/
     x 1.6058246d-03,-5.3059086d-06, 2.9001023d-06 /
      data fpp(17, 9,18,1),fpp(17, 9,18,2),fpp(17, 9,18,3)/
     x 4.0299587d-03, 4.1153675d-06,-6.3817075d-07 /
      data fpp(17, 9,19,1),fpp(17, 9,19,2),fpp(17, 9,19,3)/
     x 6.6862483d-03, 1.3986120d-05,-4.8594193d-06 /
      data fpp(17, 9,20,1),fpp(17, 9,20,2),fpp(17, 9,20,3)/
     x 8.9303214d-03, 2.2216421d-05,-9.4501520d-06 /
      data fpp(17, 9,21,1),fpp(17, 9,21,2),fpp(17, 9,21,3)/
     x 8.9303214d-03, 2.2216421d-05,-9.5488343d-06 /
      data fpp(17, 9,22,1),fpp(17, 9,22,2),fpp(17, 9,22,3)/
     x 6.6862483d-03, 1.3986120d-05,-4.4646902d-06 /
      data fpp(17, 9,23,1),fpp(17, 9,23,2),fpp(17, 9,23,3)/
     x 4.0299587d-03, 4.1153675d-06,-2.1184049d-06 /
      data fpp(17,10, 1,1),fpp(17,10, 1,2),fpp(17,10, 1,3)/
     x-2.9073182d-04,-3.9404710d-05, 4.8486632d-05 /
      data fpp(17,10, 2,1),fpp(17,10, 2,2),fpp(17,10, 2,3)/
     x-9.5149400d-03,-5.3592094d-05, 2.2838237d-05 /
      data fpp(17,10, 3,1),fpp(17,10, 3,2),fpp(17,10, 3,3)/
     x 1.4271859d-01,-8.0440913d-05,-3.0717579d-05 /
      data fpp(17,10, 4,1),fpp(17,10, 4,2),fpp(17,10, 4,3)/
     x 1.4271859d-01,-8.0440913d-05,-3.3176382d-05 /
      data fpp(17,10, 5,1),fpp(17,10, 5,2),fpp(17,10, 5,3)/
     x-9.5149400d-03,-5.3592094d-05, 3.2673450d-05 /
      data fpp(17,10, 6,1),fpp(17,10, 6,2),fpp(17,10, 6,3)/
     x-2.9073182d-04,-3.9404710d-05, 1.1604581d-05 /
      data fpp(17,10, 7,1),fpp(17,10, 7,2),fpp(17,10, 7,3)/
     x 7.3457437d-03,-2.9556829d-05, 3.2462248d-06 /
      data fpp(17,10, 8,1),fpp(17,10, 8,2),fpp(17,10, 8,3)/
     x 9.8658231d-03,-2.3938290d-05,-3.8654806d-06 /
      data fpp(17,10, 9,1),fpp(17,10, 9,2),fpp(17,10, 9,3)/
     x 9.5034330d-03,-2.1228248d-05,-4.6803026d-06 /
      data fpp(17,10,10,1),fpp(17,10,10,2),fpp(17,10,10,3)/
     x 7.6090888d-03,-2.0259727d-05,-2.4213090d-06 /
      data fpp(17,10,11,1),fpp(17,10,11,2),fpp(17,10,11,3)/
     x 5.2908599d-03,-1.9834119d-05, 7.0953856d-07 /
      data fpp(17,10,12,1),fpp(17,10,12,2),fpp(17,10,12,3)/
     x 3.3599608d-03,-1.9099867d-05, 3.1591547d-06 /
      data fpp(17,10,13,1),fpp(17,10,13,2),fpp(17,10,13,3)/
     x 2.1325982d-03,-1.7711762d-05, 4.5938425d-06 /
      data fpp(17,10,14,1),fpp(17,10,14,2),fpp(17,10,14,3)/
     x 1.5651897d-03,-1.5588239d-05, 5.1354752d-06 /
      data fpp(17,10,15,1),fpp(17,10,15,2),fpp(17,10,15,3)/
     x 1.8331330d-03,-1.2703584d-05, 4.9842566d-06 /
      data fpp(17,10,16,1),fpp(17,10,16,2),fpp(17,10,16,3)/
     x 2.6049210d-03,-9.2053582d-06, 4.0934984d-06 /
      data fpp(17,10,17,1),fpp(17,10,17,2),fpp(17,10,17,3)/
     x 3.8623994d-03,-5.3285452d-06, 2.4317499d-06 /
      data fpp(17,10,18,1),fpp(17,10,18,2),fpp(17,10,18,3)/
     x 5.6674833d-03,-1.4344616d-06,-1.4649799d-07 /
      data fpp(17,10,19,1),fpp(17,10,19,2),fpp(17,10,19,3)/
     x 7.6252136d-03, 1.6444578d-06,-3.4057580d-06 /
      data fpp(17,10,20,1),fpp(17,10,20,2),fpp(17,10,20,3)/
     x 9.3405108d-03, 3.4299054d-06,-6.0904702d-06 /
      data fpp(17,10,21,1),fpp(17,10,21,2),fpp(17,10,21,3)/
     x 9.3405108d-03, 3.4299054d-06,-6.1857104d-06 /
      data fpp(17,10,22,1),fpp(17,10,22,2),fpp(17,10,22,3)/
     x 7.6252136d-03, 1.6444578d-06,-3.0247970d-06 /
      data fpp(17,10,23,1),fpp(17,10,23,2),fpp(17,10,23,3)/
     x 5.6674833d-03,-1.4344616d-06,-1.5751015d-06 /
      data fpp(17,11, 1,1),fpp(17,11, 1,2),fpp(17,11, 1,3)/
     x-4.3700781d-02,-1.0893851d-05, 7.9937030d-05 /
      data fpp(17,11, 2,1),fpp(17,11, 2,2),fpp(17,11, 2,3)/
     x-1.6115422d-01,-5.0950524d-06, 3.9334941d-05 /
      data fpp(17,11, 3,1),fpp(17,11, 3,2),fpp(17,11, 3,3)/
     x-4.9288585d-01, 2.1853045d-06,-4.5552793d-05 /
      data fpp(17,11, 4,1),fpp(17,11, 4,2),fpp(17,11, 4,3)/
     x-4.9288585d-01, 2.1853045d-06,-4.9257092d-05 /
      data fpp(17,11, 5,1),fpp(17,11, 5,2),fpp(17,11, 5,3)/
     x-1.6115422d-01,-5.0950524d-06, 5.4152136d-05 /
      data fpp(17,11, 6,1),fpp(17,11, 6,2),fpp(17,11, 6,3)/
     x-4.3700781d-02,-1.0893851d-05, 2.4372549d-05 /
      data fpp(17,11, 7,1),fpp(17,11, 7,2),fpp(17,11, 7,3)/
     x-9.1768844d-03,-1.4807801d-05, 6.0736683d-06 /
      data fpp(17,11, 8,1),fpp(17,11, 8,2),fpp(17,11, 8,3)/
     x 4.2692648d-03,-1.4476281d-05,-5.4972224d-06 /
      data fpp(17,11, 9,1),fpp(17,11, 9,2),fpp(17,11, 9,3)/
     x 8.8213013d-03,-1.3059422d-05,-7.9107789d-06 /
      data fpp(17,11,10,1),fpp(17,11,10,2),fpp(17,11,10,3)/
     x 9.1831090d-03,-1.2066860d-05,-5.2316622d-06 /
      data fpp(17,11,11,1),fpp(17,11,11,2),fpp(17,11,11,3)/
     x 7.8066297d-03,-1.1527384d-05,-1.5165723d-06 /
      data fpp(17,11,12,1),fpp(17,11,12,2),fpp(17,11,12,3)/
     x 6.2050753d-03,-1.1021514d-05, 1.3499515d-06 /
      data fpp(17,11,13,1),fpp(17,11,13,2),fpp(17,11,13,3)/
     x 5.0384745d-03,-1.0272812d-05, 3.1607663d-06 /
      data fpp(17,11,14,1),fpp(17,11,14,2),fpp(17,11,14,3)/
     x 4.4721521d-03,-9.2305101d-06, 4.0789831d-06 /
      data fpp(17,11,15,1),fpp(17,11,15,2),fpp(17,11,15,3)/
     x 4.4590215d-03,-8.0049520d-06, 4.1813011d-06 /
      data fpp(17,11,16,1),fpp(17,11,16,2),fpp(17,11,16,3)/
     x 4.9486863d-03,-6.6837784d-06, 3.5258124d-06 /
      data fpp(17,11,17,1),fpp(17,11,17,2),fpp(17,11,17,3)/
     x 5.9769881d-03,-5.3899105d-06, 2.0974491d-06 /
      data fpp(17,11,18,1),fpp(17,11,18,2),fpp(17,11,18,3)/
     x 7.3021400d-03,-4.3115212d-06,-1.5560890d-07 /
      data fpp(17,11,19,1),fpp(17,11,19,2),fpp(17,11,19,3)/
     x 8.7676379d-03,-3.3979510d-06,-3.0590135d-06 /
      data fpp(17,11,20,1),fpp(17,11,20,2),fpp(17,11,20,3)/
     x 1.0118736d-02,-2.4920424d-06,-4.6243371d-06 /
      data fpp(17,11,21,1),fpp(17,11,21,2),fpp(17,11,21,3)/
     x 1.0118736d-02,-2.4920424d-06,-4.7274820d-06 /
      data fpp(17,11,22,1),fpp(17,11,22,2),fpp(17,11,22,3)/
     x 8.7676379d-03,-3.3979510d-06,-2.6464337d-06 /
      data fpp(17,11,23,1),fpp(17,11,23,2),fpp(17,11,23,3)/
     x 7.3021400d-03,-4.3115212d-06,-1.7027831d-06 /
      data fpp(17,12, 1,1),fpp(17,12, 1,2),fpp(17,12, 1,3)/
     x-7.9620569d-02, 3.5106113d-05, 1.2287274d-04 /
      data fpp(17,12, 2,1),fpp(17,12, 2,2),fpp(17,12, 2,3)/
     x-1.8666718d-01, 6.4252303d-05, 6.0923022d-05 /
      data fpp(17,12, 3,1),fpp(17,12, 3,2),fpp(17,12, 3,3)/
     x-2.8150644d-01, 1.2380970d-04,-6.8562827d-05 /
      data fpp(17,12, 4,1),fpp(17,12, 4,2),fpp(17,12, 4,3)/
     x-2.8150644d-01, 1.2380970d-04,-7.4274030d-05 /
      data fpp(17,12, 5,1),fpp(17,12, 5,2),fpp(17,12, 5,3)/
     x-1.8666718d-01, 6.4252303d-05, 8.3767835d-05 /
      data fpp(17,12, 6,1),fpp(17,12, 6,2),fpp(17,12, 6,3)/
     x-7.9620569d-02, 3.5106113d-05, 3.7204691d-05 /
      data fpp(17,12, 7,1),fpp(17,12, 7,2),fpp(17,12, 7,3)/
     x-3.0887787d-02, 1.6002035d-05, 1.3749400d-05 /
      data fpp(17,12, 8,1),fpp(17,12, 8,2),fpp(17,12, 8,3)/
     x-6.4815095d-03, 4.2034153d-06,-6.5282896d-06 /
      data fpp(17,12, 9,1),fpp(17,12, 9,2),fpp(17,12, 9,3)/
     x 4.5071836d-03,-1.8760647d-06,-1.1240241d-05 /
      data fpp(17,12,10,1),fpp(17,12,10,2),fpp(17,12,10,3)/
     x 8.2739519d-03,-4.5288338d-06,-8.2587465d-06 /
      data fpp(17,12,11,1),fpp(17,12,11,2),fpp(17,12,11,3)/
     x 8.4856282d-03,-5.6063461d-06,-3.5567732d-06 /
      data fpp(17,12,12,1),fpp(17,12,12,2),fpp(17,12,12,3)/
     x 7.5447207d-03,-5.9700774d-06,-9.8160895d-08 /
      data fpp(17,12,13,1),fpp(17,12,13,2),fpp(17,12,13,3)/
     x 6.6815022d-03,-5.9669895d-06, 2.0894167d-06 /
      data fpp(17,12,14,1),fpp(17,12,14,2),fpp(17,12,14,3)/
     x 6.2422537d-03,-5.8277208d-06, 3.2604939d-06 /
      data fpp(17,12,15,1),fpp(17,12,15,2),fpp(17,12,15,3)/
     x 6.2454784d-03,-5.7186082d-06, 3.5286075d-06 /
      data fpp(17,12,16,1),fpp(17,12,16,2),fpp(17,12,16,3)/
     x 6.7289670d-03,-5.7295282d-06, 2.9950761d-06 /
      data fpp(17,12,17,1),fpp(17,12,17,2),fpp(17,12,17,3)/
     x 7.6083851d-03,-5.8598127d-06, 1.6150881d-06 /
      data fpp(17,12,18,1),fpp(17,12,18,2),fpp(17,12,18,3)/
     x 8.7229113d-03,-5.9914535d-06,-4.5542854d-07 /
      data fpp(17,12,19,1),fpp(17,12,19,2),fpp(17,12,19,3)/
     x 9.8633178d-03,-6.0166537d-06,-2.7693739d-06 /
      data fpp(17,12,20,1),fpp(17,12,20,2),fpp(17,12,20,3)/
     x 1.0845827d-02,-5.9237360d-06,-3.8450757d-06 /
      data fpp(17,12,21,1),fpp(17,12,21,2),fpp(17,12,21,3)/
     x 1.0845827d-02,-5.9237360d-06,-3.9310860d-06 /
      data fpp(17,12,22,1),fpp(17,12,22,2),fpp(17,12,22,3)/
     x 9.8633178d-03,-6.0166537d-06,-2.4253326d-06 /
      data fpp(17,12,23,1),fpp(17,12,23,2),fpp(17,12,23,3)/
     x 8.7229113d-03,-5.9914535d-06,-1.7455837d-06 /
      data fpp(17,13, 1,1),fpp(17,13, 1,2),fpp(17,13, 1,3)/
     x-1.0454505d-01, 2.9781398d-05, 1.9684525d-04 /
      data fpp(17,13, 2,1),fpp(17,13, 2,2),fpp(17,13, 2,3)/
     x-2.1499048d-01, 4.7598392d-06, 9.6422004d-05 /
      data fpp(17,13, 3,1),fpp(17,13, 3,2),fpp(17,13, 3,3)/
     x-6.2876038d-01,-7.8198085d-05,-1.1306326d-04 /
      data fpp(17,13, 4,1),fpp(17,13, 4,2),fpp(17,13, 4,3)/
     x-6.2876038d-01,-7.8198085d-05,-1.2305121d-04 /
      data fpp(17,13, 5,1),fpp(17,13, 5,2),fpp(17,13, 5,3)/
     x-2.1499048d-01, 4.7598392d-06, 1.3637379d-04 /
      data fpp(17,13, 6,1),fpp(17,13, 6,2),fpp(17,13, 6,3)/
     x-1.0454505d-01, 2.9781398d-05, 4.7026036d-05 /
      data fpp(17,13, 7,1),fpp(17,13, 7,2),fpp(17,13, 7,3)/
     x-4.9943679d-02, 2.9495663d-05, 2.7224063d-05 /
      data fpp(17,13, 8,1),fpp(17,13, 8,2),fpp(17,13, 8,3)/
     x-1.8313061d-02, 1.9700620d-05,-3.7862881d-06 /
      data fpp(17,13, 9,1),fpp(17,13, 9,2),fpp(17,13, 9,3)/
     x-1.3941189d-03, 9.7036806d-06,-1.1700911d-05 /
      data fpp(17,13,10,1),fpp(17,13,10,2),fpp(17,13,10,3)/
     x 5.8709954d-03, 3.0321948d-06,-9.9260694d-06 /
      data fpp(17,13,11,1),fpp(17,13,11,2),fpp(17,13,11,3)/
     x 7.9264173d-03,-4.6923194d-07,-4.8868117d-06 /
      data fpp(17,13,12,1),fpp(17,13,12,2),fpp(17,13,12,3)/
     x 7.8946259d-03,-2.1781764d-06,-1.1326838d-06 /
      data fpp(17,13,13,1),fpp(17,13,13,2),fpp(17,13,13,3)/
     x 7.4329818d-03,-3.0472299d-06, 1.2035468d-06 /
      data fpp(17,13,14,1),fpp(17,13,14,2),fpp(17,13,14,3)/
     x 7.1973511d-03,-3.5966067d-06, 2.4444964d-06 /
      data fpp(17,13,15,1),fpp(17,13,15,2),fpp(17,13,15,3)/
     x 7.3111213d-03,-4.1006151d-06, 2.7884675d-06 /
      data fpp(17,13,16,1),fpp(17,13,16,2),fpp(17,13,16,3)/
     x 7.8532328d-03,-4.6821088d-06, 2.3496338d-06 /
      data fpp(17,13,17,1),fpp(17,13,17,2),fpp(17,13,17,3)/
     x 8.7012241d-03,-5.3288388d-06, 1.1089975d-06 /
      data fpp(17,13,18,1),fpp(17,13,18,2),fpp(17,13,18,3)/
     x 9.6710294d-03,-5.8746647d-06,-6.6562384d-07 /
      data fpp(17,13,19,1),fpp(17,13,19,2),fpp(17,13,19,3)/
     x 1.0537445d-02,-6.2074343d-06,-2.3405022d-06 /
      data fpp(17,13,20,1),fpp(17,13,20,2),fpp(17,13,20,3)/
     x 1.1203005d-02,-6.5010138d-06,-3.2083675d-06 /
      data fpp(17,13,21,1),fpp(17,13,21,2),fpp(17,13,21,3)/
     x 1.1203005d-02,-6.5010138d-06,-3.2686464d-06 /
      data fpp(17,13,22,1),fpp(17,13,22,2),fpp(17,13,22,3)/
     x 1.0537445d-02,-6.2074343d-06,-2.0993868d-06 /
      data fpp(17,13,23,1),fpp(17,13,23,2),fpp(17,13,23,3)/
     x 9.6710294d-03,-5.8746647d-06,-1.5698066d-06 /
      data fpp(17,14, 1,1),fpp(17,14, 1,2),fpp(17,14, 1,3)/
     x-1.2880982d-01, 1.1992295d-05, 1.7914572d-04 /
      data fpp(17,14, 2,1),fpp(17,14, 2,2),fpp(17,14, 2,3)/
     x-2.5245527d-01,-3.0815660d-05, 8.5492055d-05 /
      data fpp(17,14, 3,1),fpp(17,14, 3,2),fpp(17,14, 3,3)/
     x-6.9861365d-01,-1.0226936d-04,-1.1015594d-04 /
      data fpp(17,14, 4,1),fpp(17,14, 4,2),fpp(17,14, 4,3)/
     x-6.9861365d-01,-1.0226936d-04,-1.1897320d-04 /
      data fpp(17,14, 5,1),fpp(17,14, 5,2),fpp(17,14, 5,3)/
     x-2.5245527d-01,-3.0815660d-05, 1.2076108d-04 /
      data fpp(17,14, 6,1),fpp(17,14, 6,2),fpp(17,14, 6,3)/
     x-1.2880982d-01, 1.1992295d-05, 4.6886867d-05 /
      data fpp(17,14, 7,1),fpp(17,14, 7,2),fpp(17,14, 7,3)/
     x-6.7464081d-02, 2.7739314d-05, 3.0511447d-05 /
      data fpp(17,14, 8,1),fpp(17,14, 8,2),fpp(17,14, 8,3)/
     x-2.9292278d-02, 2.4946104d-05, 3.9334290d-07 /
      data fpp(17,14, 9,1),fpp(17,14, 9,2),fpp(17,14, 9,3)/
     x-7.0782382d-03, 1.6155342d-05,-8.8108190d-06 /
      data fpp(17,14,10,1),fpp(17,14,10,2),fpp(17,14,10,3)/
     x 3.1980723d-03, 8.5160544d-06,-8.5540668d-06 /
      data fpp(17,14,11,1),fpp(17,14,11,2),fpp(17,14,11,3)/
     x 6.8276527d-03, 3.6792738d-06,-4.6669138d-06 /
      data fpp(17,14,12,1),fpp(17,14,12,2),fpp(17,14,12,3)/
     x 7.6573108d-03, 9.4878302d-07,-1.4162779d-06 /
      data fpp(17,14,13,1),fpp(17,14,13,2),fpp(17,14,13,3)/
     x 7.6217897d-03,-6.6009087d-07, 6.1202542d-07 /
      data fpp(17,14,14,1),fpp(17,14,14,2),fpp(17,14,14,3)/
     x 7.5548397d-03,-1.7098522d-06, 1.6741762d-06 /
      data fpp(17,14,15,1),fpp(17,14,15,2),fpp(17,14,15,3)/
     x 7.7652804d-03,-2.5029314d-06, 1.9792697d-06 /
      data fpp(17,14,16,1),fpp(17,14,16,2),fpp(17,14,16,3)/
     x 8.2804798d-03,-3.1720367d-06, 1.6287450d-06 /
      data fpp(17,14,17,1),fpp(17,14,17,2),fpp(17,14,17,3)/
     x 9.0421579d-03,-3.7488322d-06, 6.8575027d-07 /
      data fpp(17,14,18,1),fpp(17,14,18,2),fpp(17,14,18,3)/
     x 9.8309486d-03,-4.2298878d-06,-6.3374610d-07 /
      data fpp(17,14,19,1),fpp(17,14,19,2),fpp(17,14,19,3)/
     x 1.0554853d-02,-4.5836090d-06,-1.8767659d-06 /
      data fpp(17,14,20,1),fpp(17,14,20,2),fpp(17,14,20,3)/
     x 1.1023534d-02,-4.6842087d-06,-2.4251904d-06 /
      data fpp(17,14,21,1),fpp(17,14,21,2),fpp(17,14,21,3)/
     x 1.1023534d-02,-4.6842087d-06,-2.4720459d-06 /
      data fpp(17,14,22,1),fpp(17,14,22,2),fpp(17,14,22,3)/
     x 1.0554853d-02,-4.5836090d-06,-1.6893440d-06 /
      data fpp(17,14,23,1),fpp(17,14,23,2),fpp(17,14,23,3)/
     x 9.8309486d-03,-4.2298878d-06,-1.3365780d-06 /
      data fpp(17,15, 1,1),fpp(17,15, 1,2),fpp(17,15, 1,3)/
     x-1.6905220d-01, 5.3193421d-05, 8.1624801d-05 /
      data fpp(17,15, 2,1),fpp(17,15, 2,2),fpp(17,15, 2,3)/
     x-2.8627997d-01, 8.2844801d-05, 3.6130398d-05 /
      data fpp(17,15, 3,1),fpp(17,15, 3,2),fpp(17,15, 3,3)/
     x-4.2824322d-01, 9.9225510d-05,-5.9490394d-05 /
      data fpp(17,15, 4,1),fpp(17,15, 4,2),fpp(17,15, 4,3)/
     x-4.2824322d-01, 9.9225510d-05,-6.2758017d-05 /
      data fpp(17,15, 5,1),fpp(17,15, 5,2),fpp(17,15, 5,3)/
     x-2.8627997d-01, 8.2844801d-05, 4.9200892d-05 /
      data fpp(17,15, 6,1),fpp(17,15, 6,2),fpp(17,15, 6,3)/
     x-1.6905220d-01, 5.3193421d-05, 3.2610451d-05 /
      data fpp(17,15, 7,1),fpp(17,15, 7,2),fpp(17,15, 7,3)/
     x-8.5005813d-02, 3.0553082d-05, 1.9755304d-05 /
      data fpp(17,15, 8,1),fpp(17,15, 8,2),fpp(17,15, 8,3)/
     x-3.5830698d-02, 1.9396964d-05, 2.6983316d-06 /
      data fpp(17,15, 9,1),fpp(17,15, 9,2),fpp(17,15, 9,3)/
     x-9.8743759d-03, 1.3124950d-05,-3.6866308d-06 /
      data fpp(17,15,10,1),fpp(17,15,10,2),fpp(17,15,10,3)/
     x 1.5565255d-03, 8.8215876d-06,-4.3438085d-06 /
      data fpp(17,15,11,1),fpp(17,15,11,2),fpp(17,15,11,3)/
     x 5.8633927d-03, 5.5641366d-06,-2.6081352d-06 /
      data fpp(17,15,12,1),fpp(17,15,12,2),fpp(17,15,12,3)/
     x 7.2087001d-03, 3.2130443d-06,-7.6965070d-07 /
      data fpp(17,15,13,1),fpp(17,15,13,2),fpp(17,15,13,3)/
     x 7.5285309d-03, 1.5655934d-06, 4.9073798d-07 /
      data fpp(17,15,14,1),fpp(17,15,14,2),fpp(17,15,14,3)/
     x 7.5961768d-03, 3.9201565d-07, 1.1226988d-06 /
      data fpp(17,15,15,1),fpp(17,15,15,2),fpp(17,15,15,3)/
     x 7.7683114d-03,-4.0165926d-07, 1.2764669d-06 /
      data fpp(17,15,16,1),fpp(17,15,16,2),fpp(17,15,16,3)/
     x 8.1737610d-03,-8.8174430d-07, 9.9543348d-07 /
      data fpp(17,15,17,1),fpp(17,15,17,2),fpp(17,15,17,3)/
     x 8.7292777d-03,-1.0958322d-06, 3.7579914d-07 /
      data fpp(17,15,18,1),fpp(17,15,18,2),fpp(17,15,18,3)/
     x 9.2947083d-03,-1.1217842d-06,-4.7063003d-07 /
      data fpp(17,15,19,1),fpp(17,15,19,2),fpp(17,15,19,3)/
     x 9.8156313d-03,-1.0241296d-06,-1.2052790d-06 /
      data fpp(17,15,20,1),fpp(17,15,20,2),fpp(17,15,20,3)/
     x 1.0137026d-02,-9.6415125d-07,-1.5902540d-06 /
      data fpp(17,15,21,1),fpp(17,15,21,2),fpp(17,15,21,3)/
     x 1.0137026d-02,-9.6415125d-07,-1.6165986d-06 /
      data fpp(17,15,22,1),fpp(17,15,22,2),fpp(17,15,22,3)/
     x 9.8156313d-03,-1.0241296d-06,-1.0999004d-06 /
      data fpp(17,15,23,1),fpp(17,15,23,2),fpp(17,15,23,3)/
     x 9.2947083d-03,-1.1217842d-06,-8.6579980d-07 /
      data fpp(17,16, 1,1),fpp(17,16, 1,2),fpp(17,16, 1,3)/
     x-1.6267450d-01,-6.5345979d-05,-9.8745155d-06 /
      data fpp(17,16, 2,1),fpp(17,16, 2,2),fpp(17,16, 2,3)/
     x-5.1473347d-01,-8.1833545d-05,-1.1731969d-05 /
      data fpp(17,16, 3,1),fpp(17,16, 3,2),fpp(17,16, 3,3)/
     x-6.1502474d-01,-1.2602683d-05,-1.6853609d-05 /
      data fpp(17,16, 4,1),fpp(17,16, 4,2),fpp(17,16, 4,3)/
     x-6.1502474d-01,-1.2602683d-05,-1.4856189d-05 /
      data fpp(17,16, 5,1),fpp(17,16, 5,2),fpp(17,16, 5,3)/
     x-5.1473347d-01,-8.1833545d-05,-1.9721646d-05 /
      data fpp(17,16, 6,1),fpp(17,16, 6,2),fpp(17,16, 6,3)/
     x-1.6267450d-01,-6.5345979d-05, 2.0086774d-05 /
      data fpp(17,16, 7,1),fpp(17,16, 7,2),fpp(17,16, 7,3)/
     x-6.0755327d-02,-3.6257640d-05, 1.2934549d-05 /
      data fpp(17,16, 8,1),fpp(17,16, 8,2),fpp(17,16, 8,3)/
     x-2.2597018d-02,-1.6619959d-05, 5.4550299d-06 /
      data fpp(17,16, 9,1),fpp(17,16, 9,2),fpp(17,16, 9,3)/
     x 1.5025597d-02,-4.3291412d-06, 1.8873313d-06 /
      data fpp(17,16,10,1),fpp(17,16,10,2),fpp(17,16,10,3)/
     x 2.5466738d-03, 1.6475951d-06, 3.2764467d-07 /
      data fpp(17,16,11,1),fpp(17,16,11,2),fpp(17,16,11,3)/
     x 5.7536936d-03, 3.6321799d-06, 1.5008996d-07 /
      data fpp(17,16,12,1),fpp(17,16,12,2),fpp(17,16,12,3)/
     x 6.9852439d-03, 3.7010397d-06, 4.3399550d-07 /
      data fpp(17,16,13,1),fpp(17,16,13,2),fpp(17,16,13,3)/
     x 7.3970927d-03, 3.1457172d-06, 7.5392802d-07 /
      data fpp(17,16,14,1),fpp(17,16,14,2),fpp(17,16,14,3)/
     x 7.5428735d-03, 2.5597896d-06, 9.0029240d-07 /
      data fpp(17,16,15,1),fpp(17,16,15,2),fpp(17,16,15,3)/
     x 7.6616257d-03, 2.1715685d-06, 8.4690239d-07 /
      data fpp(17,16,16,1),fpp(17,16,16,2),fpp(17,16,16,3)/
     x 7.8744687d-03, 2.0790139d-06, 6.1409804d-07 /
      data fpp(17,16,17,1),fpp(17,16,17,2),fpp(17,16,17,3)/
     x 8.1353714d-03, 2.2821612d-06, 2.3670546d-07 /
      data fpp(17,16,18,1),fpp(17,16,18,2),fpp(17,16,18,3)/
     x 8.4532857d-03, 2.6930246d-06,-1.8691987d-07 /
      data fpp(17,16,19,1),fpp(17,16,19,2),fpp(17,16,19,3)/
     x 8.7170063d-03, 3.1061275d-06,-5.6302597d-07 /
      data fpp(17,16,20,1),fpp(17,16,20,2),fpp(17,16,20,3)/
     x 8.8987073d-03, 3.3748137d-06,-8.0097623d-07 /
      data fpp(17,16,21,1),fpp(17,16,21,2),fpp(17,16,21,3)/
     x 8.8987073d-03, 3.3748137d-06,-8.1355832d-07 /
      data fpp(17,16,22,1),fpp(17,16,22,2),fpp(17,16,22,3)/
     x 8.7170063d-03, 3.1061275d-06,-5.1269762d-07 /
      data fpp(17,16,23,1),fpp(17,16,23,2),fpp(17,16,23,3)/
     x 8.4532857d-03, 2.6930246d-06,-3.7565119d-07 /
      data fpp(17,17, 1,1),fpp(17,17, 1,2),fpp(17,17, 1,3)/
     x-1.5102597d-01,-5.1417506d-05, 2.4318322d-06 /
      data fpp(17,17, 2,1),fpp(17,17, 2,2),fpp(17,17, 2,3)/
     x 3.6894965d-03,-4.9078623d-05,-2.2326644d-06 /
      data fpp(17,17, 3,1),fpp(17,17, 3,2),fpp(17,17, 3,3)/
     x 1.5404735d-01,-8.1106778d-05,-1.2233174d-05 /
      data fpp(17,17, 4,1),fpp(17,17, 4,2),fpp(17,17, 4,3)/
     x 1.5404735d-01,-8.1106778d-05,-1.2224144d-05 /
      data fpp(17,17, 5,1),fpp(17,17, 5,2),fpp(17,17, 5,3)/
     x 3.6894965d-03,-4.9078623d-05,-2.2687844d-06 /
      data fpp(17,17, 6,1),fpp(17,17, 6,2),fpp(17,17, 6,3)/
     x-1.5102597d-01,-5.1417506d-05, 2.5672820d-06 /
      data fpp(17,17, 7,1),fpp(17,17, 7,2),fpp(17,17, 7,3)/
     x-4.4688145d-04,-4.6712520d-05, 4.1796564d-06 /
      data fpp(17,17, 8,1),fpp(17,17, 8,2),fpp(17,17, 8,3)/
     x 2.9146440d-04,-3.2963126d-05, 3.6700922d-06 /
      data fpp(17,17, 9,1),fpp(17,17, 9,2),fpp(17,17, 9,3)/
     x 4.1753424d-03,-1.9538385d-05, 2.7339746d-06 /
      data fpp(17,17,10,1),fpp(17,17,10,2),fpp(17,17,10,3)/
     x 5.8687242d-03,-9.3399679d-06, 1.9360093d-06 /
      data fpp(17,17,11,1),fpp(17,17,11,2),fpp(17,17,11,3)/
     x 6.8020308d-03,-2.6868561d-06, 1.4199883d-06 /
      data fpp(17,17,12,1),fpp(17,17,12,2),fpp(17,17,12,3)/
     x 7.2684694d-03, 1.2007970d-06, 1.1320376d-06 /
      data fpp(17,17,13,1),fpp(17,17,13,2),fpp(17,17,13,3)/
     x 7.4913179d-03, 3.3115377d-06, 9.5786137d-07 /
      data fpp(17,17,14,1),fpp(17,17,14,2),fpp(17,17,14,3)/
     x 7.5899854d-03, 4.4708259d-06, 8.2051694d-07 /
      data fpp(17,17,15,1),fpp(17,17,15,2),fpp(17,17,15,3)/
     x 7.6348753d-03, 5.2153854d-06, 6.6207086d-07 /
      data fpp(17,17,16,1),fpp(17,17,16,2),fpp(17,17,16,3)/
     x 7.6900101d-03, 5.8376886d-06, 4.8519961d-07 /
      data fpp(17,17,17,1),fpp(17,17,17,2),fpp(17,17,17,3)/
     x 7.7683262d-03, 6.4511874d-06, 2.8313069d-07 /
      data fpp(17,17,18,1),fpp(17,17,18,2),fpp(17,17,18,3)/
     x 7.8696838d-03, 7.0416857d-06, 9.8277616d-08 /
      data fpp(17,17,19,1),fpp(17,17,19,2),fpp(17,17,19,3)/
     x 7.9262228d-03, 7.5416195d-06,-7.0241157d-08 /
      data fpp(17,17,20,1),fpp(17,17,20,2),fpp(17,17,20,3)/
     x 8.0018697d-03, 7.8948963d-06,-1.7731299d-07 /
      data fpp(17,17,21,1),fpp(17,17,21,2),fpp(17,17,21,3)/
     x 8.0018697d-03, 7.8948963d-06,-1.8294045d-07 /
      data fpp(17,17,22,1),fpp(17,17,22,2),fpp(17,17,22,3)/
     x 7.9262228d-03, 7.5416195d-06,-4.7731299d-08 /
      data fpp(17,17,23,1),fpp(17,17,23,2),fpp(17,17,23,3)/
     x 7.8696838d-03, 7.0416857d-06, 1.3865649d-08 /
      data fpp(17,18, 1,1),fpp(17,18, 1,2),fpp(17,18, 1,3)/
     x 9.6138107d-03, 3.6500016d-06,-1.0170334d-06 /
      data fpp(17,18, 2,1),fpp(17,18, 2,2),fpp(17,18, 2,3)/
     x 1.0564216d-02, 1.4568035d-05,-1.3139333d-06 /
      data fpp(17,18, 3,1),fpp(17,18, 3,2),fpp(17,18, 3,3)/
     x 1.1493050d-02, 3.2811794d-05,-1.9592335d-06 /
      data fpp(17,18, 4,1),fpp(17,18, 4,2),fpp(17,18, 4,3)/
     x 1.1493050d-02, 3.2811794d-05,-1.9433330d-06 /
      data fpp(17,18, 5,1),fpp(17,18, 5,2),fpp(17,18, 5,3)/
     x 1.0564216d-02, 1.4568035d-05,-1.3775352d-06 /
      data fpp(17,18, 6,1),fpp(17,18, 6,2),fpp(17,18, 6,3)/
     x 9.6138107d-03, 3.6500016d-06,-7.7852627d-07 /
      data fpp(17,18, 7,1),fpp(17,18, 7,2),fpp(17,18, 7,3)/
     x 9.2581425d-03,-3.5602800d-06,-2.2435973d-07 /
      data fpp(17,18, 8,1),fpp(17,18, 8,2),fpp(17,18, 8,3)/
     x 8.8227267d-03,-7.6115353d-06, 1.9396520d-07 /
      data fpp(17,18, 9,1),fpp(17,18, 9,2),fpp(17,18, 9,3)/
     x 8.4677224d-03,-8.5673186d-06, 4.4449894d-07 /
      data fpp(17,18,10,1),fpp(17,18,10,2),fpp(17,18,10,3)/
     x 8.2587393d-03,-7.5117235d-06, 5.7203903d-07 /
      data fpp(17,18,11,1),fpp(17,18,11,2),fpp(17,18,11,3)/
     x 8.0983631d-03,-5.3887554d-06, 6.0934492d-07 /
      data fpp(17,18,12,1),fpp(17,18,12,2),fpp(17,18,12,3)/
     x 7.9960339d-03,-2.8162277d-06, 5.9658127d-07 /
      data fpp(17,18,13,1),fpp(17,18,13,2),fpp(17,18,13,3)/
     x 7.9348405d-03,-1.3186791d-07, 5.5633000d-07 /
      data fpp(17,18,14,1),fpp(17,18,14,2),fpp(17,18,14,3)/
     x 7.8718004d-03, 2.4949069d-06, 5.0209873d-07 /
      data fpp(17,18,15,1),fpp(17,18,15,2),fpp(17,18,15,3)/
     x 7.8539436d-03, 4.9808899d-06, 4.3527509d-07 /
      data fpp(17,18,16,1),fpp(17,18,16,2),fpp(17,18,16,3)/
     x 7.8216766d-03, 7.2702318d-06, 3.7280092d-07 /
      data fpp(17,18,17,1),fpp(17,18,17,2),fpp(17,18,17,3)/
     x 7.7844321d-03, 9.2990893d-06, 3.0552122d-07 /
      data fpp(17,18,18,1),fpp(17,18,18,2),fpp(17,18,18,3)/
     x 7.7841340d-03, 1.0996233d-05, 2.4711419d-07 /
      data fpp(17,18,19,1),fpp(17,18,19,2),fpp(17,18,19,3)/
     x 7.7580475d-03, 1.2279394d-05, 2.1802202d-07 /
      data fpp(17,18,20,1),fpp(17,18,20,2),fpp(17,18,20,3)/
     x 7.7592618d-03, 1.3057601d-05, 1.6479773d-07 /
      data fpp(17,18,21,1),fpp(17,18,21,2),fpp(17,18,21,3)/
     x 7.7592618d-03, 1.3057601d-05, 1.6459579d-07 /
      data fpp(17,18,22,1),fpp(17,18,22,2),fpp(17,18,22,3)/
     x 7.7580475d-03, 1.2279394d-05, 2.1882977d-07 /
      data fpp(17,18,23,1),fpp(17,18,23,2),fpp(17,18,23,3)/
     x 7.7841340d-03, 1.0996233d-05, 2.4408511d-07 /
      data fpp(17,19, 1,1),fpp(17,19, 1,2),fpp(17,19, 1,3)/
     x 8.4076254d-03, 4.6963499d-05,-1.9349947d-20 /
      data fpp(17,19, 2,1),fpp(17,19, 2,2),fpp(17,19, 2,3)/
     x 8.4076254d-03, 6.9388482d-05,-2.8108659d-21 /
      data fpp(17,19, 3,1),fpp(17,19, 3,2),fpp(17,19, 3,3)/
     x 8.4076254d-03, 9.4609603d-05,-8.9854833d-21 /
      data fpp(17,19, 4,1),fpp(17,19, 4,2),fpp(17,19, 4,3)/
     x 8.4076254d-03, 9.4609603d-05, 7.4752610d-21 /
      data fpp(17,19, 5,1),fpp(17,19, 5,2),fpp(17,19, 5,3)/
     x 8.4076254d-03, 6.9388482d-05, 4.8782976d-21 /
      data fpp(17,19, 6,1),fpp(17,19, 6,2),fpp(17,19, 6,3)/
     x 8.4076254d-03, 4.6963499d-05,-4.9411908d-21 /
      data fpp(17,19, 7,1),fpp(17,19, 7,2),fpp(17,19, 7,3)/
     x 8.4076254d-03, 2.4275640d-05,-1.0058643d-20 /
      data fpp(17,19, 8,1),fpp(17,19, 8,2),fpp(17,19, 8,3)/
     x 8.4076254d-03, 5.8272677d-06,-4.8177622d-21 /
      data fpp(17,19, 9,1),fpp(17,19, 9,2),fpp(17,19, 9,3)/
     x 8.4076254d-03,-5.0763407d-06, 4.9245636d-21 /
      data fpp(17,19,10,1),fpp(17,19,10,2),fpp(17,19,10,3)/
     x 8.4076254d-03,-9.3451383d-06, 1.8751746d-20 /
      data fpp(17,19,11,1),fpp(17,19,11,2),fpp(17,19,11,3)/
     x 8.4076254d-03,-9.1241223d-06,-4.5606185d-21 /
      data fpp(17,19,12,1),fpp(17,19,12,2),fpp(17,19,12,3)/
     x 8.4076254d-03,-6.3998861d-06, 1.4410056d-20 /
      data fpp(17,19,13,1),fpp(17,19,13,2),fpp(17,19,13,3)/
     x 8.4076254d-03,-2.5440660d-06, 1.3255504d-20 /
      data fpp(17,19,14,1),fpp(17,19,14,2),fpp(17,19,14,3)/
     x 8.4076254d-03, 1.6295466d-06,-4.0373592d-21 /
      data fpp(17,19,15,1),fpp(17,19,15,2),fpp(17,19,15,3)/
     x 8.4076254d-03, 5.6830551d-06, 6.8053593d-21 /
      data fpp(17,19,16,1),fpp(17,19,16,2),fpp(17,19,16,3)/
     x 8.4076254d-03, 9.3673841d-06,-7.5052452d-21 /
      data fpp(17,19,17,1),fpp(17,19,17,2),fpp(17,19,17,3)/
     x 8.4076254d-03, 1.2524455d-05, 9.7511124d-21 /
      data fpp(17,19,18,1),fpp(17,19,18,2),fpp(17,19,18,3)/
     x 8.4076254d-03, 1.5063384d-05,-1.2437648d-20 /
      data fpp(17,19,19,1),fpp(17,19,19,2),fpp(17,19,19,3)/
     x 8.4076254d-03, 1.6930803d-05,-1.4945894d-20 /
      data fpp(17,19,20,1),fpp(17,19,20,2),fpp(17,19,20,3)/
     x 8.4076254d-03, 1.8036699d-05, 6.8996468d-21 /
      data fpp(17,19,21,1),fpp(17,19,21,2),fpp(17,19,21,3)/
     x 8.4076254d-03, 1.8036699d-05,-4.4694914d-21 /
      data fpp(17,19,22,1),fpp(17,19,22,2),fpp(17,19,22,3)/
     x 8.4076254d-03, 1.6930803d-05, 1.6719273d-20 /
      data fpp(17,19,23,1),fpp(17,19,23,2),fpp(17,19,23,3)/
     x 8.4076254d-03, 1.5063384d-05, 5.5060133d-20 /
      data fpp(18, 1, 1,1),fpp(18, 1, 1,2),fpp(18, 1, 1,3)/
     x-5.0080996d+00, 1.7574848d-03,-3.0343788d-19 /
      data fpp(18, 1, 2,1),fpp(18, 1, 2,2),fpp(18, 1, 2,3)/
     x-5.0080996d+00, 2.2593560d-03,-4.1186546d-19 /
      data fpp(18, 1, 3,1),fpp(18, 1, 3,2),fpp(18, 1, 3,3)/
     x-5.0080996d+00, 2.8021580d-03,-3.6031281d-19 /
      data fpp(18, 1, 4,1),fpp(18, 1, 4,2),fpp(18, 1, 4,3)/
     x-5.0080996d+00, 2.8021580d-03, 1.7341029d-19 /
      data fpp(18, 1, 5,1),fpp(18, 1, 5,2),fpp(18, 1, 5,3)/
     x-5.0080996d+00, 2.2593560d-03, 1.1192244d-19 /
      data fpp(18, 1, 6,1),fpp(18, 1, 6,2),fpp(18, 1, 6,3)/
     x-5.0080996d+00, 1.7574848d-03,-2.6810020d-19 /
      data fpp(18, 1, 7,1),fpp(18, 1, 7,2),fpp(18, 1, 7,3)/
     x-5.0080996d+00, 1.4824316d-03,-5.7108777d-19 /
      data fpp(18, 1, 8,1),fpp(18, 1, 8,2),fpp(18, 1, 8,3)/
     x-5.0080996d+00, 1.2910667d-03,-4.6818697d-19 /
      data fpp(18, 1, 9,1),fpp(18, 1, 9,2),fpp(18, 1, 9,3)/
     x-5.0080996d+00, 1.1071187d-03,-1.5840323d-20 /
      data fpp(18, 1,10,1),fpp(18, 1,10,2),fpp(18, 1,10,3)/
     x-5.0080996d+00, 1.0414502d-03, 6.7156516d-19 /
      data fpp(18, 1,11,1),fpp(18, 1,11,2),fpp(18, 1,11,3)/
     x-5.0080996d+00, 1.0046480d-03,-3.9111485d-19 /
      data fpp(18, 1,12,1),fpp(18, 1,12,2),fpp(18, 1,12,3)/
     x-5.0080996d+00, 9.9069500d-04, 2.9568164d-19 /
      data fpp(18, 1,13,1),fpp(18, 1,13,2),fpp(18, 1,13,3)/
     x-5.0080996d+00, 9.9813452d-04, 1.1565097d-20 /
      data fpp(18, 1,14,1),fpp(18, 1,14,2),fpp(18, 1,14,3)/
     x-5.0080996d+00, 1.0288614d-03, 2.6461190d-19 /
      data fpp(18, 1,15,1),fpp(18, 1,15,2),fpp(18, 1,15,3)/
     x-5.0080996d+00, 1.0896641d-03,-7.8908157d-20 /
      data fpp(18, 1,16,1),fpp(18, 1,16,2),fpp(18, 1,16,3)/
     x-5.0080996d+00, 1.2711724d-03,-4.6600247d-19 /
      data fpp(18, 1,17,1),fpp(18, 1,17,2),fpp(18, 1,17,3)/
     x-5.0080996d+00, 1.4632909d-03, 1.7521719d-19 /
      data fpp(18, 1,18,1),fpp(18, 1,18,2),fpp(18, 1,18,3)/
     x-5.0080996d+00, 1.7418644d-03,-1.6964062d-19 /
      data fpp(18, 1,19,1),fpp(18, 1,19,2),fpp(18, 1,19,3)/
     x-5.0080996d+00, 2.2410329d-03,-3.0773215d-19 /
      data fpp(18, 1,20,1),fpp(18, 1,20,2),fpp(18, 1,20,3)/
     x-5.0080996d+00, 2.7787926d-03, 2.6928036d-19 /
      data fpp(18, 1,21,1),fpp(18, 1,21,2),fpp(18, 1,21,3)/
     x-5.0080996d+00, 2.7787926d-03,-2.2010668d-19 /
      data fpp(18, 1,22,1),fpp(18, 1,22,2),fpp(18, 1,22,3)/
     x-5.0080996d+00, 2.2410329d-03, 3.8638997d-19 /
      data fpp(18, 1,23,1),fpp(18, 1,23,2),fpp(18, 1,23,3)/
     x-5.0080996d+00, 1.7418644d-03, 1.2687271d-18 /
      data fpp(18, 2, 1,1),fpp(18, 2, 1,2),fpp(18, 2, 1,3)/
     x 1.9979908d-01, 9.3902533d-04,-9.3241700d-06 /
      data fpp(18, 2, 2,1),fpp(18, 2, 2,2),fpp(18, 2, 2,3)/
     x 2.7332779d-01, 1.1323470d-03,-1.4075160d-05 /
      data fpp(18, 2, 3,1),fpp(18, 2, 3,2),fpp(18, 2, 3,3)/
     x 2.0013933d-01, 1.3413031d-03,-2.4453190d-05 /
      data fpp(18, 2, 4,1),fpp(18, 2, 4,2),fpp(18, 2, 4,3)/
     x 2.0013933d-01, 1.3413031d-03,-2.4107851d-05 /
      data fpp(18, 2, 5,1),fpp(18, 2, 5,2),fpp(18, 2, 5,3)/
     x 2.7332779d-01, 1.1323470d-03,-1.5456517d-05 /
      data fpp(18, 2, 6,1),fpp(18, 2, 6,2),fpp(18, 2, 6,3)/
     x 1.9979908d-01, 9.3902533d-04,-4.1440827d-06 /
      data fpp(18, 2, 7,1),fpp(18, 2, 7,2),fpp(18, 2, 7,3)/
     x 1.2918612d-01, 8.3828185d-04,-7.6871527d-06 /
      data fpp(18, 2, 8,1),fpp(18, 2, 8,2),fpp(18, 2, 8,3)/
     x 7.6168899d-02, 7.7016154d-04, 3.8300693d-05 /
      data fpp(18, 2, 9,1),fpp(18, 2, 9,2),fpp(18, 2, 9,3)/
     x-6.9720712d-02, 6.9914663d-04,-2.2347621d-05 /
      data fpp(18, 2,10,1),fpp(18, 2,10,2),fpp(18, 2,10,3)/
     x-8.1763247d-02, 6.8070170d-04, 2.3957791d-05 /
      data fpp(18, 2,11,1),fpp(18, 2,11,2),fpp(18, 2,11,3)/
     x-1.6839532d-01, 6.7096902d-04, 1.4758456d-05 /
      data fpp(18, 2,12,1),fpp(18, 2,12,2),fpp(18, 2,12,3)/
     x-2.4977846d-02, 6.6658399d-04, 1.9434383d-05 /
      data fpp(18, 2,13,1),fpp(18, 2,13,2),fpp(18, 2,13,3)/
     x 5.8156215d-02, 6.6667195d-04, 1.4952011d-05 /
      data fpp(18, 2,14,1),fpp(18, 2,14,2),fpp(18, 2,14,3)/
     x-8.2920743d-02, 6.7231126d-04, 2.4293574d-05 /
      data fpp(18, 2,15,1),fpp(18, 2,15,2),fpp(18, 2,15,3)/
     x-7.2313466d-02, 6.8721577d-04,-2.2036308d-05 /
      data fpp(18, 2,16,1),fpp(18, 2,16,2),fpp(18, 2,16,3)/
     x 7.1976792d-02, 7.5580526d-04, 3.8489658d-05 /
      data fpp(18, 2,17,1),fpp(18, 2,17,2),fpp(18, 2,17,3)/
     x 1.2475880d-01, 8.2299526d-04,-7.5903229d-06 /
      data fpp(18, 2,18,1),fpp(18, 2,18,2),fpp(18, 2,18,3)/
     x 1.9795902d-01, 9.2418929d-04,-4.5823663d-06 /
      data fpp(18, 2,19,1),fpp(18, 2,19,2),fpp(18, 2,19,3)/
     x 1.7292851d-01, 1.1153863d-03,-1.6104212d-05 /
      data fpp(18, 2,20,1),fpp(18, 2,20,2),fpp(18, 2,20,3)/
     x 1.9968547d-01, 1.3219208d-03,-2.5230785d-05 /
      data fpp(18, 2,21,1),fpp(18, 2,21,2),fpp(18, 2,21,3)/
     x 1.9968547d-01, 1.3219208d-03,-2.5575538d-05 /
      data fpp(18, 2,22,1),fpp(18, 2,22,2),fpp(18, 2,22,3)/
     x 1.7292851d-01, 1.1153863d-03,-1.4725204d-05 /
      data fpp(18, 2,23,1),fpp(18, 2,23,2),fpp(18, 2,23,3)/
     x 1.9795902d-01, 9.2418929d-04,-9.7536482d-06 /
      data fpp(18, 3, 1,1),fpp(18, 3, 1,2),fpp(18, 3, 1,3)/
     x 1.9437264d-01,-3.3400814d-04, 1.3261320d-04 /
      data fpp(18, 3, 2,1),fpp(18, 3, 2,2),fpp(18, 3, 2,3)/
     x 4.4767006d-01,-5.6649816d-04, 2.3295600d-05 /
      data fpp(18, 3, 3,1),fpp(18, 3, 3,2),fpp(18, 3, 3,3)/
     x 9.1152472d-01,-7.0588424d-04,-2.0937960d-04 /
      data fpp(18, 3, 4,1),fpp(18, 3, 4,2),fpp(18, 3, 4,3)/
     x 9.1152472d-01,-7.0588424d-04,-2.1213900d-04 /
      data fpp(18, 3, 5,1),fpp(18, 3, 5,2),fpp(18, 3, 5,3)/
     x 4.4767006d-01,-5.6649816d-04, 3.4333189d-05 /
      data fpp(18, 3, 6,1),fpp(18, 3, 6,2),fpp(18, 3, 6,3)/
     x 1.9437264d-01,-3.3400814d-04, 9.1222243d-05 /
      data fpp(18, 3, 7,1),fpp(18, 3, 7,2),fpp(18, 3, 7,3)/
     x-3.7604634d-02,-1.9882496d-04, 2.1161839d-05 /
      data fpp(18, 3, 8,1),fpp(18, 3, 8,2),fpp(18, 3, 8,3)/
     x-1.2552774d-02,-6.4042887d-05, 4.4726403d-05 /
      data fpp(18, 3, 9,1),fpp(18, 3, 9,2),fpp(18, 3, 9,3)/
     x-2.7160560d-02, 6.1154802d-05, 3.2522551d-05 /
      data fpp(18, 3,10,1),fpp(18, 3,10,2),fpp(18, 3,10,3)/
     x-3.0075054d-02, 1.2334706d-04, 3.6473394d-05 /
      data fpp(18, 3,11,1),fpp(18, 3,11,2),fpp(18, 3,11,3)/
     x-3.0109664d-02, 1.6100993d-04, 3.7253871d-05 /
      data fpp(18, 3,12,1),fpp(18, 3,12,2),fpp(18, 3,12,3)/
     x-2.9823750d-02, 1.7324902d-04, 3.8179120d-05 /
      data fpp(18, 3,13,1),fpp(18, 3,13,2),fpp(18, 3,13,3)/
     x-2.9785578d-02, 1.5905566d-04, 3.7777649d-05 /
      data fpp(18, 3,14,1),fpp(18, 3,14,2),fpp(18, 3,14,3)/
     x-2.9490201d-02, 1.1912158d-04, 3.7534283d-05 /
      data fpp(18, 3,15,1),fpp(18, 3,15,2),fpp(18, 3,15,3)/
     x-2.6076570d-02, 5.3984819d-05, 3.4199218d-05 /
      data fpp(18, 3,16,1),fpp(18, 3,16,2),fpp(18, 3,16,3)/
     x-1.2636637d-02,-7.5013408d-05, 4.6528845d-05 /
      data fpp(18, 3,17,1),fpp(18, 3,17,2),fpp(18, 3,17,3)/
     x-3.8778794d-02,-2.1349392d-04, 2.3879404d-05 /
      data fpp(18, 3,18,1),fpp(18, 3,18,2),fpp(18, 3,18,3)/
     x 1.8655701d-01,-3.4974552d-04, 8.9745541d-05 /
      data fpp(18, 3,19,1),fpp(18, 3,19,2),fpp(18, 3,19,3)/
     x 4.2075228d-01,-5.6726588d-04, 3.2428432d-05 /
      data fpp(18, 3,20,1),fpp(18, 3,20,2),fpp(18, 3,20,3)/
     x 9.8486720d-01,-6.9120397d-04,-2.1439527d-04 /
      data fpp(18, 3,21,1),fpp(18, 3,21,2),fpp(18, 3,21,3)/
     x 9.8486720d-01,-6.9120397d-04,-2.1164841d-04 /
      data fpp(18, 3,22,1),fpp(18, 3,22,2),fpp(18, 3,22,3)/
     x 4.2075228d-01,-5.6726588d-04, 2.1440973d-05 /
      data fpp(18, 3,23,1),fpp(18, 3,23,2),fpp(18, 3,23,3)/
     x 1.8655701d-01,-3.4974552d-04, 1.3094851d-04 /
      data fpp(18, 4, 1,1),fpp(18, 4, 1,2),fpp(18, 4, 1,3)/
     x-1.7591735d-02,-1.6032760d-05, 2.7039122d-04 /
      data fpp(18, 4, 2,1),fpp(18, 4, 2,2),fpp(18, 4, 2,3)/
     x 2.2896003d-01,-2.6391639d-04, 8.7261569d-05 /
      data fpp(18, 4, 3,1),fpp(18, 4, 3,2),fpp(18, 4, 3,3)/
     x 1.1872645d+00,-7.0090813d-04,-2.9758549d-04 /
      data fpp(18, 4, 4,1),fpp(18, 4, 4,2),fpp(18, 4, 4,3)/
     x 1.1872645d+00,-7.0090813d-04,-3.1083931d-04 /
      data fpp(18, 4, 5,1),fpp(18, 4, 5,2),fpp(18, 4, 5,3)/
     x 2.2896003d-01,-2.6391639d-04, 1.4027685d-04 /
      data fpp(18, 4, 6,1),fpp(18, 4, 6,2),fpp(18, 4, 6,3)/
     x-1.7591735d-02,-1.6032760d-05, 7.1583925d-05 /
      data fpp(18, 4, 7,1),fpp(18, 4, 7,2),fpp(18, 4, 7,3)/
     x-1.3544054d-02, 1.3941801d-04, 6.4793452d-05 /
      data fpp(18, 4, 8,1),fpp(18, 4, 8,2),fpp(18, 4, 8,3)/
     x-3.5261937d-02, 1.9830001d-04, 4.1476266d-05 /
      data fpp(18, 4, 9,1),fpp(18, 4, 9,2),fpp(18, 4, 9,3)/
     x-3.4335891d-02, 2.2823216d-04, 4.1131484d-05 /
      data fpp(18, 4,10,1),fpp(18, 4,10,2),fpp(18, 4,10,3)/
     x-3.2870709d-02, 2.5411407d-04, 4.0207797d-05 /
      data fpp(18, 4,11,1),fpp(18, 4,11,2),fpp(18, 4,11,3)/
     x-3.2011644d-02, 2.6803125d-04, 3.9765326d-05 /
      data fpp(18, 4,12,1),fpp(18, 4,12,2),fpp(18, 4,12,3)/
     x-3.1625832d-02, 2.7219791d-04, 3.9542898d-05 /
      data fpp(18, 4,13,1),fpp(18, 4,13,2),fpp(18, 4,13,3)/
     x-3.1570352d-02, 2.6797739d-04, 4.0467083d-05 /
      data fpp(18, 4,14,1),fpp(18, 4,14,2),fpp(18, 4,14,3)/
     x-3.1930606d-02, 2.5417041d-04, 4.1702772d-05 /
      data fpp(18, 4,15,1),fpp(18, 4,15,2),fpp(18, 4,15,3)/
     x-3.2730353d-02, 2.2849296d-04, 4.3443830d-05 /
      data fpp(18, 4,16,1),fpp(18, 4,16,2),fpp(18, 4,16,3)/
     x-3.2643395d-02, 1.9824837d-04, 4.5275909d-05 /
      data fpp(18, 4,17,1),fpp(18, 4,17,2),fpp(18, 4,17,3)/
     x-2.3770780d-02, 1.3669440d-04, 6.8870533d-05 /
      data fpp(18, 4,18,1),fpp(18, 4,18,2),fpp(18, 4,18,3)/
     x-1.0563774d-02,-2.6771194d-05, 8.0287960d-05 /
      data fpp(18, 4,19,1),fpp(18, 4,19,2),fpp(18, 4,19,3)/
     x 2.1295292d-01,-3.0039875d-04, 1.3734763d-04 /
      data fpp(18, 4,20,1),fpp(18, 4,20,2),fpp(18, 4,20,3)/
     x 1.2181581d+00,-7.5744296d-04,-3.1907047d-04 /
      data fpp(18, 4,21,1),fpp(18, 4,21,2),fpp(18, 4,21,3)/
     x 1.2181581d+00,-7.5744296d-04,-3.0625141d-04 /
      data fpp(18, 4,22,1),fpp(18, 4,22,2),fpp(18, 4,22,3)/
     x 2.1295292d-01,-3.0039875d-04, 8.6071403d-05 /
      data fpp(18, 4,23,1),fpp(18, 4,23,2),fpp(18, 4,23,3)/
     x-1.0563774d-02,-2.6771194d-05, 2.7257380d-04 /
      data fpp(18, 5, 1,1),fpp(18, 5, 1,2),fpp(18, 5, 1,3)/
     x-2.8762105d-02, 6.1575181d-05, 1.0700643d-04 /
      data fpp(18, 5, 2,1),fpp(18, 5, 2,2),fpp(18, 5, 2,3)/
     x-2.8960687d-02, 1.5426371d-04, 2.1465134d-05 /
      data fpp(18, 5, 3,1),fpp(18, 5, 3,2),fpp(18, 5, 3,3)/
     x 2.5923610d-02, 3.1733674d-04,-1.5852297d-04 /
      data fpp(18, 5, 4,1),fpp(18, 5, 4,2),fpp(18, 5, 4,3)/
     x 2.5923610d-02, 3.1733674d-04,-1.6432366d-04 /
      data fpp(18, 5, 5,1),fpp(18, 5, 5,2),fpp(18, 5, 5,3)/
     x-2.8960687d-02, 1.5426371d-04, 4.4667897d-05 /
      data fpp(18, 5, 6,1),fpp(18, 5, 6,2),fpp(18, 5, 6,3)/
     x-2.8762105d-02, 6.1575181d-05, 1.9996072d-05 /
      data fpp(18, 5, 7,1),fpp(18, 5, 7,2),fpp(18, 5, 7,3)/
     x-2.7296938d-02, 3.0108920d-05, 3.1959817d-05 /
      data fpp(18, 5, 8,1),fpp(18, 5, 8,2),fpp(18, 5, 8,3)/
     x-2.6380825d-02, 4.0294853d-05, 3.1012662d-05 /
      data fpp(18, 5, 9,1),fpp(18, 5, 9,2),fpp(18, 5, 9,3)/
     x-2.6322095d-02, 5.3488542d-05, 3.2683535d-05 /
      data fpp(18, 5,10,1),fpp(18, 5,10,2),fpp(18, 5,10,3)/
     x-2.6756400d-02, 5.8450657d-05, 3.1945196d-05 /
      data fpp(18, 5,11,1),fpp(18, 5,11,2),fpp(18, 5,11,3)/
     x-2.7183544d-02, 5.9787057d-05, 3.1307680d-05 /
      data fpp(18, 5,12,1),fpp(18, 5,12,2),fpp(18, 5,12,3)/
     x-2.7267707d-02, 6.0113317d-05, 3.1344085d-05 /
      data fpp(18, 5,13,1),fpp(18, 5,13,2),fpp(18, 5,13,3)/
     x-2.6900294d-02, 6.0366774d-05, 3.2321980d-05 /
      data fpp(18, 5,14,1),fpp(18, 5,14,2),fpp(18, 5,14,3)/
     x-2.6187518d-02, 5.9882768d-05, 3.3947993d-05 /
      data fpp(18, 5,15,1),fpp(18, 5,15,2),fpp(18, 5,15,3)/
     x-2.5379389d-02, 5.6561346d-05, 3.5694046d-05 /
      data fpp(18, 5,16,1),fpp(18, 5,16,2),fpp(18, 5,16,3)/
     x-2.4780454d-02, 4.6569920d-05, 3.5123821d-05 /
      data fpp(18, 5,17,1),fpp(18, 5,17,2),fpp(18, 5,17,3)/
     x-2.4255542d-02, 4.2142304d-05, 3.7296671d-05 /
      data fpp(18, 5,18,1),fpp(18, 5,18,2),fpp(18, 5,18,3)/
     x-2.2369278d-02, 8.2730302d-05, 2.5587497d-05 /
      data fpp(18, 5,19,1),fpp(18, 5,19,2),fpp(18, 5,19,3)/
     x-1.6443071d-02, 1.9263086d-04, 4.7199341d-05 /
      data fpp(18, 5,20,1),fpp(18, 5,20,2),fpp(18, 5,20,3)/
     x 6.5233175d-04, 3.6784582d-04,-1.7300286d-04 /
      data fpp(18, 5,21,1),fpp(18, 5,21,2),fpp(18, 5,21,3)/
     x 6.5233175d-04, 3.6784582d-04,-1.6709909d-04 /
      data fpp(18, 5,22,1),fpp(18, 5,22,2),fpp(18, 5,22,3)/
     x-1.6443071d-02, 1.9263086d-04, 2.3584239d-05 /
      data fpp(18, 5,23,1),fpp(18, 5,23,2),fpp(18, 5,23,3)/
     x-2.2369278d-02, 8.2730302d-05, 1.1414413d-04 /
      data fpp(18, 6, 1,1),fpp(18, 6, 1,2),fpp(18, 6, 1,3)/
     x-5.0825064d-03, 3.2064037d-05, 2.1551431d-06 /
      data fpp(18, 6, 2,1),fpp(18, 6, 2,2),fpp(18, 6, 2,3)/
     x 3.5246984d-03, 6.5067531d-05,-1.7031786d-05 /
      data fpp(18, 6, 3,1),fpp(18, 6, 3,2),fpp(18, 6, 3,3)/
     x 1.6185620d-02, 1.3479117d-04,-5.8041998d-05 /
      data fpp(18, 6, 4,1),fpp(18, 6, 4,2),fpp(18, 6, 4,3)/
     x 1.6185620d-02, 1.3479117d-04,-5.8225113d-05 /
      data fpp(18, 6, 5,1),fpp(18, 6, 5,2),fpp(18, 6, 5,3)/
     x 3.5246984d-03, 6.5067531d-05,-1.6299329d-05 /
      data fpp(18, 6, 6,1),fpp(18, 6, 6,2),fpp(18, 6, 6,3)/
     x-5.0825064d-03, 3.2064037d-05,-5.9157289d-07 /
      data fpp(18, 6, 7,1),fpp(18, 6, 7,2),fpp(18, 6, 7,3)/
     x-1.0533898d-02, 1.6692309d-05, 1.0571620d-05 /
      data fpp(18, 6, 8,1),fpp(18, 6, 8,2),fpp(18, 6, 8,3)/
     x-1.4408592d-02, 3.3105782d-06, 1.5797092d-05 /
      data fpp(18, 6, 9,1),fpp(18, 6, 9,2),fpp(18, 6, 9,3)/
     x-1.7272651d-02,-6.5743331d-06, 1.8376012d-05 /
      data fpp(18, 6,10,1),fpp(18, 6,10,2),fpp(18, 6,10,3)/
     x-1.9296218d-02,-1.1546698d-05, 1.9808861d-05 /
      data fpp(18, 6,11,1),fpp(18, 6,11,2),fpp(18, 6,11,3)/
     x-2.0480784d-02,-1.3175480d-05, 2.1080542d-05 /
      data fpp(18, 6,12,1),fpp(18, 6,12,2),fpp(18, 6,12,3)/
     x-2.0923575d-02,-1.3043185d-05, 2.2066969d-05 /
      data fpp(18, 6,13,1),fpp(18, 6,13,2),fpp(18, 6,13,3)/
     x-2.0674504d-02,-1.1888488d-05, 2.2603582d-05 /
      data fpp(18, 6,14,1),fpp(18, 6,14,2),fpp(18, 6,14,3)/
     x-1.9722046d-02,-8.8714857d-06, 2.2890703d-05 /
      data fpp(18, 6,15,1),fpp(18, 6,15,2),fpp(18, 6,15,3)/
     x-1.7998727d-02,-2.3563446d-06, 2.3005607d-05 /
      data fpp(18, 6,16,1),fpp(18, 6,16,2),fpp(18, 6,16,3)/
     x-1.5432889d-02, 9.1559484d-06, 2.1778869d-05 /
      data fpp(18, 6,17,1),fpp(18, 6,17,2),fpp(18, 6,17,3)/
     x-1.1827749d-02, 2.3788380d-05, 1.7498918d-05 /
      data fpp(18, 6,18,1),fpp(18, 6,18,2),fpp(18, 6,18,3)/
     x-6.5449074d-03, 3.8749985d-05, 5.4554594d-06 /
      data fpp(18, 6,19,1),fpp(18, 6,19,2),fpp(18, 6,19,3)/
     x 1.7627275d-03, 6.6491297d-05,-1.3130755d-05 /
      data fpp(18, 6,20,1),fpp(18, 6,20,2),fpp(18, 6,20,3)/
     x 1.3989559d-02, 1.2799768d-04,-6.9170438d-05 /
      data fpp(18, 6,21,1),fpp(18, 6,21,2),fpp(18, 6,21,3)/
     x 1.3989559d-02, 1.2799768d-04,-6.8811309d-05 /
      data fpp(18, 6,22,1),fpp(18, 6,22,2),fpp(18, 6,22,3)/
     x 1.7627275d-03, 6.6491297d-05,-1.4567269d-05 /
      data fpp(18, 6,23,1),fpp(18, 6,23,2),fpp(18, 6,23,3)/
     x-6.5449074d-03, 3.8749985d-05, 1.0842384d-05 /
      data fpp(18, 7, 1,1),fpp(18, 7, 1,2),fpp(18, 7, 1,3)/
     x 3.3400729d-03, 3.0308672d-05,-7.8587496d-06 /
      data fpp(18, 7, 2,1),fpp(18, 7, 2,2),fpp(18, 7, 2,3)/
     x 7.9983423d-03, 6.6528163d-05,-1.1768501d-05 /
      data fpp(18, 7, 3,1),fpp(18, 7, 3,2),fpp(18, 7, 3,3)/
     x 1.1984246d-02, 9.2698581d-05,-2.0223247d-05 /
      data fpp(18, 7, 4,1),fpp(18, 7, 4,2),fpp(18, 7, 4,3)/
     x 1.1984246d-02, 9.2698581d-05,-2.0089009d-05 /
      data fpp(18, 7, 5,1),fpp(18, 7, 5,2),fpp(18, 7, 5,3)/
     x 7.9983423d-03, 6.6528163d-05,-1.2305453d-05 /
      data fpp(18, 7, 6,1),fpp(18, 7, 6,2),fpp(18, 7, 6,3)/
     x 3.3400729d-03, 3.0308672d-05,-5.8451778d-06 /
      data fpp(18, 7, 7,1),fpp(18, 7, 7,2),fpp(18, 7, 7,3)/
     x-1.1340145d-03,-9.6215581d-07,-4.1583556d-07 /
      data fpp(18, 7, 8,1),fpp(18, 7, 8,2),fpp(18, 7, 8,3)/
     x-5.1830177d-03,-2.1905166d-05, 3.5845200d-06 /
      data fpp(18, 7, 9,1),fpp(18, 7, 9,2),fpp(18, 7, 9,3)/
     x-8.6283878d-03,-3.4517210d-05, 6.9817555d-06 /
      data fpp(18, 7,10,1),fpp(18, 7,10,2),fpp(18, 7,10,3)/
     x-1.1326609d-02,-4.1597863d-05, 9.9664578d-06 /
      data fpp(18, 7,11,1),fpp(18, 7,11,2),fpp(18, 7,11,3)/
     x-1.3176489d-02,-4.4903136d-05, 1.2288413d-05 /
      data fpp(18, 7,12,1),fpp(18, 7,12,2),fpp(18, 7,12,3)/
     x-1.4129220d-02,-4.5242579d-05, 1.3755890d-05 /
      data fpp(18, 7,13,1),fpp(18, 7,13,2),fpp(18, 7,13,3)/
     x-1.4178555d-02,-4.2794822d-05, 1.4390029d-05 /
      data fpp(18, 7,14,1),fpp(18, 7,14,2),fpp(18, 7,14,3)/
     x-1.3333031d-02,-3.7644826d-05, 1.4261996d-05 /
      data fpp(18, 7,15,1),fpp(18, 7,15,2),fpp(18, 7,15,3)/
     x-1.1607921d-02,-2.9369968d-05, 1.3377989d-05 /
      data fpp(18, 7,16,1),fpp(18, 7,16,2),fpp(18, 7,16,3)/
     x-8.9514806d-03,-1.6761714d-05, 1.1414048d-05 /
      data fpp(18, 7,17,1),fpp(18, 7,17,2),fpp(18, 7,17,3)/
     x-5.4444846d-03, 2.3361769d-06, 7.2538187d-06 /
      data fpp(18, 7,18,1),fpp(18, 7,18,2),fpp(18, 7,18,3)/
     x-8.2494936d-04, 3.0121756d-05,-8.4732303d-07 /
      data fpp(18, 7,19,1),fpp(18, 7,19,2),fpp(18, 7,19,3)/
     x 4.4842747d-03, 6.3307950d-05,-1.2498527d-05 /
      data fpp(18, 7,20,1),fpp(18, 7,20,2),fpp(18, 7,20,3)/
     x 9.4957190d-03, 8.9049475d-05,-3.0086570d-05 /
      data fpp(18, 7,21,1),fpp(18, 7,21,2),fpp(18, 7,21,3)/
     x 9.4957190d-03, 8.9049475d-05,-3.0250025d-05 /
      data fpp(18, 7,22,1),fpp(18, 7,22,2),fpp(18, 7,22,3)/
     x 4.4842747d-03, 6.3307950d-05,-1.1844707d-05 /
      data fpp(18, 7,23,1),fpp(18, 7,23,2),fpp(18, 7,23,3)/
     x-8.2494936d-04, 3.0121756d-05,-3.2991465d-06 /
      data fpp(18, 8, 1,1),fpp(18, 8, 1,2),fpp(18, 8, 1,3)/
     x 7.0680509d-03, 1.0453277d-05,-4.4877640d-06 /
      data fpp(18, 8, 2,1),fpp(18, 8, 2,2),fpp(18, 8, 2,3)/
     x 8.9285384d-03, 2.9515816d-05,-5.1094719d-06 /
      data fpp(18, 8, 3,1),fpp(18, 8, 3,2),fpp(18, 8, 3,3)/
     x 5.2005979d-02, 4.6972505d-05,-6.4543482d-06 /
      data fpp(18, 8, 4,1),fpp(18, 8, 4,2),fpp(18, 8, 4,3)/
     x 5.2005979d-02, 4.6972505d-05,-6.4322195d-06 /
      data fpp(18, 8, 5,1),fpp(18, 8, 5,2),fpp(18, 8, 5,3)/
     x 8.9285384d-03, 2.9515816d-05,-5.1979867d-06 /
      data fpp(18, 8, 6,1),fpp(18, 8, 6,2),fpp(18, 8, 6,3)/
     x 7.0680509d-03, 1.0453277d-05,-4.1558337d-06 /
      data fpp(18, 8, 7,1),fpp(18, 8, 7,2),fpp(18, 8, 7,3)/
     x 4.6946440d-03,-6.9396857d-06,-3.1926787d-06 /
      data fpp(18, 8, 8,1),fpp(18, 8, 8,2),fpp(18, 8, 8,3)/
     x 1.9356308d-03,-2.0959913d-05,-1.7394516d-06 /
      data fpp(18, 8, 9,1),fpp(18, 8, 9,2),fpp(18, 8, 9,3)/
     x-9.8468208d-04,-3.0940827d-05, 6.8248524d-07 /
      data fpp(18, 8,10,1),fpp(18, 8,10,2),fpp(18, 8,10,3)/
     x-3.6946189d-03,-3.7221848d-05, 3.5935107d-06 /
      data fpp(18, 8,11,1),fpp(18, 8,11,2),fpp(18, 8,11,3)/
     x-5.8753523d-03,-4.0329977d-05, 6.1414721d-06 /
      data fpp(18, 8,12,1),fpp(18, 8,12,2),fpp(18, 8,12,3)/
     x-7.2834369d-03,-4.0586501d-05, 7.8706010d-06 /
      data fpp(18, 8,13,1),fpp(18, 8,13,2),fpp(18, 8,13,3)/
     x-7.7945111d-03,-3.8206224d-05, 8.6361238d-06 /
      data fpp(18, 8,14,1),fpp(18, 8,14,2),fpp(18, 8,14,3)/
     x-7.4016811d-03,-3.3233212d-05, 8.6329039d-06 /
      data fpp(18, 8,15,1),fpp(18, 8,15,2),fpp(18, 8,15,3)/
     x-6.0818716d-03,-2.5633783d-05, 7.9162607d-06 /
      data fpp(18, 8,16,1),fpp(18, 8,16,2),fpp(18, 8,16,3)/
     x-4.1335378d-03,-1.5465094d-05, 6.2860534d-06 /
      data fpp(18, 8,17,1),fpp(18, 8,17,2),fpp(18, 8,17,3)/
     x-1.5283206d-03,-2.8990874d-06, 3.3715259d-06 /
      data fpp(18, 8,18,1),fpp(18, 8,18,2),fpp(18, 8,18,3)/
     x 1.5792791d-03, 1.1102991d-05,-1.3221569d-06 /
      data fpp(18, 8,19,1),fpp(18, 8,19,2),fpp(18, 8,19,3)/
     x 4.8515367d-03, 2.5162904d-05,-7.1008982d-06 /
      data fpp(18, 8,20,1),fpp(18, 8,20,2),fpp(18, 8,20,3)/
     x 7.5476857d-03, 3.7312424d-05,-1.3816250d-05 /
      data fpp(18, 8,21,1),fpp(18, 8,21,2),fpp(18, 8,21,3)/
     x 7.5476857d-03, 3.7312424d-05,-1.3941800d-05 /
      data fpp(18, 8,22,1),fpp(18, 8,22,2),fpp(18, 8,22,3)/
     x 4.8515367d-03, 2.5162904d-05,-6.5987000d-06 /
      data fpp(18, 8,23,1),fpp(18, 8,23,2),fpp(18, 8,23,3)/
     x 1.5792791d-03, 1.1102991d-05,-3.2054000d-06 /
      data fpp(18, 9, 1,1),fpp(18, 9, 1,2),fpp(18, 9, 1,3)/
     x 8.6528153d-03,-4.9937795d-06, 3.8191727d-06 /
      data fpp(18, 9, 2,1),fpp(18, 9, 2,2),fpp(18, 9, 2,3)/
     x 9.3687458d-03, 1.0066571d-05, 4.2015455d-07 /
      data fpp(18, 9, 3,1),fpp(18, 9, 3,2),fpp(18, 9, 3,3)/
     x 5.4668574d-02, 2.7949400d-05,-6.7537909d-06 /
      data fpp(18, 9, 4,1),fpp(18, 9, 4,2),fpp(18, 9, 4,3)/
     x 5.4668574d-02, 2.7949400d-05,-6.9457045d-06 /
      data fpp(18, 9, 5,1),fpp(18, 9, 5,2),fpp(18, 9, 5,3)/
     x 9.3687458d-03, 1.0066571d-05, 1.1878088d-06 /
      data fpp(18, 9, 6,1),fpp(18, 9, 6,2),fpp(18, 9, 6,3)/
     x 8.6528153d-03,-4.9937795d-06, 9.4046920d-07 /
      data fpp(18, 9, 7,1),fpp(18, 9, 7,2),fpp(18, 9, 7,3)/
     x 7.9274153d-03,-1.3927101d-05,-1.1216856d-06 /
      data fpp(18, 9, 8,1),fpp(18, 9, 8,2),fpp(18, 9, 8,3)/
     x 6.5536943d-03,-1.9445180d-05,-2.6277267d-06 /
      data fpp(18, 9, 9,1),fpp(18, 9, 9,2),fpp(18, 9, 9,3)/
     x 4.5388106d-03,-2.3273482d-05,-2.0294075d-06 /
      data fpp(18, 9,10,1),fpp(18, 9,10,2),fpp(18, 9,10,3)/
     x 2.2715259d-03,-2.5730746d-05, 1.3735679d-07 /
      data fpp(18, 9,11,1),fpp(18, 9,11,2),fpp(18, 9,11,3)/
     x 1.6397357d-04,-2.6810955d-05, 2.5839804d-06 /
      data fpp(18, 9,12,1),fpp(18, 9,12,2),fpp(18, 9,12,3)/
     x-1.4105699d-03,-2.6573417d-05, 4.4007218d-06 /
      data fpp(18, 9,13,1),fpp(18, 9,13,2),fpp(18, 9,13,3)/
     x-2.3338194d-03,-2.5024281d-05, 5.2771325d-06 /
      data fpp(18, 9,14,1),fpp(18, 9,14,2),fpp(18, 9,14,3)/
     x-2.4681769d-03,-2.2040326d-05, 5.5167482d-06 /
      data fpp(18, 9,15,1),fpp(18, 9,15,2),fpp(18, 9,15,3)/
     x-1.8726773d-03,-1.7578900d-05, 5.1158748d-06 /
      data fpp(18, 9,16,1),fpp(18, 9,16,2),fpp(18, 9,16,3)/
     x-6.1864331d-04,-1.1605911d-05, 4.1217525d-06 /
      data fpp(18, 9,17,1),fpp(18, 9,17,2),fpp(18, 9,17,3)/
     x 1.0741178d-03,-4.4558274d-06, 2.2291153d-06 /
      data fpp(18, 9,18,1),fpp(18, 9,18,2),fpp(18, 9,18,3)/
     x 3.1359888d-03, 3.3462815d-06,-6.3621363d-07 /
      data fpp(18, 9,19,1),fpp(18, 9,19,2),fpp(18, 9,19,3)/
     x 5.2815022d-03, 1.0640436d-05,-3.9622608d-06 /
      data fpp(18, 9,20,1),fpp(18, 9,20,2),fpp(18, 9,20,3)/
     x 7.0247765d-03, 1.5524830d-05,-7.1667432d-06 /
      data fpp(18, 9,21,1),fpp(18, 9,21,2),fpp(18, 9,21,3)/
     x 7.0247765d-03, 1.5524830d-05,-7.2536399d-06 /
      data fpp(18, 9,22,1),fpp(18, 9,22,2),fpp(18, 9,22,3)/
     x 5.2815022d-03, 1.0640436d-05,-3.6146743d-06 /
      data fpp(18, 9,23,1),fpp(18, 9,23,2),fpp(18, 9,23,3)/
     x 3.1359888d-03, 3.3462815d-06,-1.9396628d-06 /
      data fpp(18,10, 1,1),fpp(18,10, 1,2),fpp(18,10, 1,3)/
     x 3.6108666d-03,-2.0580159d-05, 2.9727671d-05 /
      data fpp(18,10, 2,1),fpp(18,10, 2,2),fpp(18,10, 2,3)/
     x 1.5411035d-03,-1.5554101d-05, 1.3005658d-05 /
      data fpp(18,10, 3,1),fpp(18,10, 3,2),fpp(18,10, 3,3)/
     x-2.2426959d-02, 1.0555897d-05,-2.2110303d-05 /
      data fpp(18,10, 4,1),fpp(18,10, 4,2),fpp(18,10, 4,3)/
     x-2.2426959d-02, 1.0555897d-05,-2.3364919d-05 /
      data fpp(18,10, 5,1),fpp(18,10, 5,2),fpp(18,10, 5,3)/
     x 1.5411035d-03,-1.5554101d-05, 1.8024120d-05 /
      data fpp(18,10, 6,1),fpp(18,10, 6,2),fpp(18,10, 6,3)/
     x 3.6108666d-03,-2.0580159d-05, 1.0908439d-05 /
      data fpp(18,10, 7,1),fpp(18,10, 7,2),fpp(18,10, 7,3)/
     x 6.4228874d-03,-1.9041909d-05, 3.7541258d-06 /
      data fpp(18,10, 8,1),fpp(18,10, 8,2),fpp(18,10, 8,3)/
     x 7.6459335d-03,-1.7035365d-05,-2.1049417d-06 /
      data fpp(18,10, 9,1),fpp(18,10, 9,2),fpp(18,10, 9,3)/
     x 7.2295207d-03,-1.5993245d-05,-3.3563589d-06 /
      data fpp(18,10,10,1),fpp(18,10,10,2),fpp(18,10,10,3)/
     x 5.7939697d-03,-1.5753170d-05,-1.8876228d-06 /
      data fpp(18,10,11,1),fpp(18,10,11,2),fpp(18,10,11,3)/
     x 4.0503688d-03,-1.5674202d-05, 4.3685010d-07 /
      data fpp(18,10,12,1),fpp(18,10,12,2),fpp(18,10,12,3)/
     x 2.5220138d-03,-1.5257830d-05, 2.3182224d-06 /
      data fpp(18,10,13,1),fpp(18,10,13,2),fpp(18,10,13,3)/
     x 1.4869572d-03,-1.4246653d-05, 3.4362603d-06 /
      data fpp(18,10,14,1),fpp(18,10,14,2),fpp(18,10,14,3)/
     x 1.1027189d-03,-1.2579483d-05, 3.9287365d-06 /
      data fpp(18,10,15,1),fpp(18,10,15,2),fpp(18,10,15,3)/
     x 1.2809018d-03,-1.0244616d-05, 3.8887937d-06 /
      data fpp(18,10,16,1),fpp(18,10,16,2),fpp(18,10,16,3)/
     x 1.9877729d-03,-7.4352613d-06, 3.2260885d-06 /
      data fpp(18,10,17,1),fpp(18,10,17,2),fpp(18,10,17,3)/
     x 3.1275402d-03,-4.3216030d-06, 1.8488521d-06 /
      data fpp(18,10,18,1),fpp(18,10,18,2),fpp(18,10,18,3)/
     x 4.5760176d-03,-1.2141166d-06,-2.2949685d-07 /
      data fpp(18,10,19,1),fpp(18,10,19,2),fpp(18,10,19,3)/
     x 6.1402733d-03, 1.4913539d-06,-2.8448647d-06 /
      data fpp(18,10,20,1),fpp(18,10,20,2),fpp(18,10,20,3)/
     x 7.4679728d-03, 3.4402545d-06,-4.4590444d-06 /
      data fpp(18,10,21,1),fpp(18,10,21,2),fpp(18,10,21,3)/
     x 7.4679728d-03, 3.4402545d-06,-4.5474345d-06 /
      data fpp(18,10,22,1),fpp(18,10,22,2),fpp(18,10,22,3)/
     x 6.1402733d-03, 1.4913539d-06,-2.4913044d-06 /
      data fpp(18,10,23,1),fpp(18,10,23,2),fpp(18,10,23,3)/
     x 4.5760176d-03,-1.2141166d-06,-1.5553478d-06 /
      data fpp(18,11, 1,1),fpp(18,11, 1,2),fpp(18,11, 1,3)/
     x-1.6552168d-02,-7.4195847d-06, 9.1028785d-05 /
      data fpp(18,11, 2,1),fpp(18,11, 2,2),fpp(18,11, 2,3)/
     x-3.2966642d-02,-5.4381673d-06, 4.3700431d-05 /
      data fpp(18,11, 3,1),fpp(18,11, 3,2),fpp(18,11, 3,3)/
     x-6.5693347d-02,-3.9298616d-07,-5.5074508d-05 /
      data fpp(18,11, 4,1),fpp(18,11, 4,2),fpp(18,11, 4,3)/
     x-6.5693347d-02,-3.9298616d-07,-5.9699692d-05 /
      data fpp(18,11, 5,1),fpp(18,11, 5,2),fpp(18,11, 5,3)/
     x-3.2966642d-02,-5.4381673d-06, 6.2201170d-05 /
      data fpp(18,11, 6,1),fpp(18,11, 6,2),fpp(18,11, 6,3)/
     x-1.6552168d-02,-7.4195847d-06, 2.1651013d-05 /
      data fpp(18,11, 7,1),fpp(18,11, 7,2),fpp(18,11, 7,3)/
     x-2.7494769d-03,-9.5772625d-06, 1.0398778d-05 /
      data fpp(18,11, 8,1),fpp(18,11, 8,2),fpp(18,11, 8,3)/
     x 4.1482469d-03,-9.8833587d-06,-2.2921250d-06 /
      data fpp(18,11, 9,1),fpp(18,11, 9,2),fpp(18,11, 9,3)/
     x 6.8022187d-03,-9.4375380d-06,-5.0282782d-06 /
      data fpp(18,11,10,1),fpp(18,11,10,2),fpp(18,11,10,3)/
     x 6.9459135d-03,-9.1285761d-06,-3.7967624d-06 /
      data fpp(18,11,11,1),fpp(18,11,11,2),fpp(18,11,11,3)/
     x 5.9169368d-03,-8.9402382d-06,-1.2166721d-06 /
      data fpp(18,11,12,1),fpp(18,11,12,2),fpp(18,11,12,3)/
     x 4.7100546d-03,-8.6532636d-06, 9.1145076d-07 /
      data fpp(18,11,13,1),fpp(18,11,13,2),fpp(18,11,13,3)/
     x 3.8132475d-03,-8.1391056d-06, 2.3168690d-06 /
      data fpp(18,11,14,1),fpp(18,11,14,2),fpp(18,11,14,3)/
     x 3.3779906d-03,-7.3697429d-06, 3.0930731d-06 /
      data fpp(18,11,15,1),fpp(18,11,15,2),fpp(18,11,15,3)/
     x 3.4182673d-03,-6.4346369d-06, 3.2448387d-06 /
      data fpp(18,11,16,1),fpp(18,11,16,2),fpp(18,11,16,3)/
     x 3.8980095d-03,-5.4050437d-06, 2.7495722d-06 /
      data fpp(18,11,17,1),fpp(18,11,17,2),fpp(18,11,17,3)/
     x 4.7683456d-03,-4.3997606d-06, 1.5788725d-06 /
      data fpp(18,11,18,1),fpp(18,11,18,2),fpp(18,11,18,3)/
     x 5.9514458d-03,-3.5358151d-06,-1.9706225d-07 /
      data fpp(18,11,19,1),fpp(18,11,19,2),fpp(18,11,19,3)/
     x 7.1857792d-03,-2.8118514d-06,-2.5966235d-06 /
      data fpp(18,11,20,1),fpp(18,11,20,2),fpp(18,11,20,3)/
     x 8.2487147d-03,-2.0698484d-06,-3.3184437d-06 /
      data fpp(18,11,21,1),fpp(18,11,21,2),fpp(18,11,21,3)/
     x 8.2487147d-03,-2.0698484d-06,-3.4163572d-06 /
      data fpp(18,11,22,1),fpp(18,11,22,2),fpp(18,11,22,3)/
     x 7.1857792d-03,-2.8118514d-06,-2.2049694d-06 /
      data fpp(18,11,23,1),fpp(18,11,23,2),fpp(18,11,23,3)/
     x 5.9514458d-03,-3.5358151d-06,-1.6657653d-06 /
      data fpp(18,12, 1,1),fpp(18,12, 1,2),fpp(18,12, 1,3)/
     x-4.1222956d-02, 2.2724498d-05, 1.5704314d-04 /
      data fpp(18,12, 2,1),fpp(18,12, 2,2),fpp(18,12, 2,3)/
     x-8.9410703d-02, 3.2164770d-05, 7.6279718d-05 /
      data fpp(18,12, 3,1),fpp(18,12, 3,2),fpp(18,12, 3,3)/
     x-2.7229633d-01, 1.6534048d-05,-9.2022014d-05 /
      data fpp(18,12, 4,1),fpp(18,12, 4,2),fpp(18,12, 4,3)/
     x-2.7229633d-01, 1.6534048d-05,-1.0035682d-04 /
      data fpp(18,12, 5,1),fpp(18,12, 5,2),fpp(18,12, 5,3)/
     x-8.9410703d-02, 3.2164770d-05, 1.0961893d-04 /
      data fpp(18,12, 6,1),fpp(18,12, 6,2),fpp(18,12, 6,3)/
     x-4.1222956d-02, 2.2724498d-05, 3.2021096d-05 /
      data fpp(18,12, 7,1),fpp(18,12, 7,2),fpp(18,12, 7,3)/
     x-1.6173089d-02, 1.1780959d-05, 1.9648685d-05 /
      data fpp(18,12, 8,1),fpp(18,12, 8,2),fpp(18,12, 8,3)/
     x-2.6627197d-03, 3.7088000d-06,-1.7818344d-06 /
      data fpp(18,12, 9,1),fpp(18,12, 9,2),fpp(18,12, 9,3)/
     x 3.9402624d-03,-9.3460281d-07,-6.6233470d-06 /
      data fpp(18,12,10,1),fpp(18,12,10,2),fpp(18,12,10,3)/
     x 6.2868353d-03,-3.1605261d-06,-5.6427775d-06 /
      data fpp(18,12,11,1),fpp(18,12,11,2),fpp(18,12,11,3)/
     x 6.3573534d-03,-4.1668457d-06,-2.6235431d-06 /
      data fpp(18,12,12,1),fpp(18,12,12,2),fpp(18,12,12,3)/
     x 5.6846508d-03,-4.5371160d-06,-1.7705001d-07 /
      data fpp(18,12,13,1),fpp(18,12,13,2),fpp(18,12,13,3)/
     x 5.0608472d-03,-4.5809242d-06, 1.5077432d-06 /
      data fpp(18,12,14,1),fpp(18,12,14,2),fpp(18,12,14,3)/
     x 4.7558919d-03,-4.5255458d-06, 2.4740774d-06 /
      data fpp(18,12,15,1),fpp(18,12,15,2),fpp(18,12,15,3)/
     x 4.8121964d-03,-4.4928366d-06, 2.7319474d-06 /
      data fpp(18,12,16,1),fpp(18,12,16,2),fpp(18,12,16,3)/
     x 5.2406524d-03,-4.5445638d-06, 2.3001331d-06 /
      data fpp(18,12,17,1),fpp(18,12,17,2),fpp(18,12,17,3)/
     x 6.0418199d-03,-4.6593547d-06, 1.2135200d-06 /
      data fpp(18,12,18,1),fpp(18,12,18,2),fpp(18,12,18,3)/
     x 7.0522195d-03,-4.7726229d-06,-3.8021331d-07 /
      data fpp(18,12,19,1),fpp(18,12,19,2),fpp(18,12,19,3)/
     x 8.0390785d-03,-4.8119485d-06,-2.2786668d-06 /
      data fpp(18,12,20,1),fpp(18,12,20,2),fpp(18,12,20,3)/
     x 8.8186607d-03,-4.7428608d-06,-2.8171195d-06 /
      data fpp(18,12,21,1),fpp(18,12,21,2),fpp(18,12,21,3)/
     x 8.8186607d-03,-4.7428608d-06,-2.8953082d-06 /
      data fpp(18,12,22,1),fpp(18,12,22,2),fpp(18,12,22,3)/
     x 8.0390785d-03,-4.8119485d-06,-1.9659119d-06 /
      data fpp(18,12,23,1),fpp(18,12,23,2),fpp(18,12,23,3)/
     x 7.0522195d-03,-4.7726229d-06,-1.5530440d-06 /
      data fpp(18,13, 1,1),fpp(18,13, 1,2),fpp(18,13, 1,3)/
     x-5.7716609d-02, 2.1107593d-05, 1.8280207d-04 /
      data fpp(18,13, 2,1),fpp(18,13, 2,2),fpp(18,13, 2,3)/
     x-1.0758910d-01, 8.6508678d-07, 8.6425865d-05 /
      data fpp(18,13, 3,1),fpp(18,13, 3,2),fpp(18,13, 3,3)/
     x-1.6918137d-01,-3.8005206d-05,-1.1482953d-04 /
      data fpp(18,13, 4,1),fpp(18,13, 4,2),fpp(18,13, 4,3)/
     x-1.6918137d-01,-3.8005206d-05,-1.2404335d-04 /
      data fpp(18,13, 5,1),fpp(18,13, 5,2),fpp(18,13, 5,3)/
     x-1.0758910d-01, 8.6508678d-07, 1.2328114d-04 /
      data fpp(18,13, 6,1),fpp(18,13, 6,2),fpp(18,13, 6,3)/
     x-5.7716609d-02, 2.1107593d-05, 4.4594801d-05 /
      data fpp(18,13, 7,1),fpp(18,13, 7,2),fpp(18,13, 7,3)/
     x-2.8039838d-02, 2.2525427d-05, 2.8825658d-05 /
      data fpp(18,13, 8,1),fpp(18,13, 8,2),fpp(18,13, 8,3)/
     x-9.9125971d-03, 1.5502159d-05, 1.7125648d-06 /
      data fpp(18,13, 9,1),fpp(18,13, 9,2),fpp(18,13, 9,3)/
     x 1.2224741d-04, 7.8479493d-06,-6.2459177d-06 /
      data fpp(18,13,10,1),fpp(18,13,10,2),fpp(18,13,10,3)/
     x 4.6344931d-03, 2.6666806d-06,-6.3568941d-06 /
      data fpp(18,13,11,1),fpp(18,13,11,2),fpp(18,13,11,3)/
     x 5.9315447d-03,-1.3837890d-07,-3.3965059d-06 /
      data fpp(18,13,12,1),fpp(18,13,12,2),fpp(18,13,12,3)/
     x 5.8701561d-03,-1.5542726d-06,-9.0108216d-07 /
      data fpp(18,13,13,1),fpp(18,13,13,2),fpp(18,13,13,3)/
     x 5.5648232d-03,-2.2711976d-06, 8.3883456d-07 /
      data fpp(18,13,14,1),fpp(18,13,14,2),fpp(18,13,14,3)/
     x 5.4485692d-03,-2.7100739d-06, 1.8597439d-06 /
      data fpp(18,13,15,1),fpp(18,13,15,2),fpp(18,13,15,3)/
     x 5.6017718d-03,-3.1280166d-06, 2.1561898d-06 /
      data fpp(18,13,16,1),fpp(18,13,16,2),fpp(18,13,16,3)/
     x 6.0507449d-03,-3.6087012d-06, 1.7914969d-06 /
      data fpp(18,13,17,1),fpp(18,13,17,2),fpp(18,13,17,3)/
     x 6.7937898d-03,-4.1248205d-06, 8.3582260d-07 /
      data fpp(18,13,18,1),fpp(18,13,18,2),fpp(18,13,18,3)/
     x 7.6640904d-03,-4.5716933d-06,-5.2078731d-07 /
      data fpp(18,13,19,1),fpp(18,13,19,2),fpp(18,13,19,3)/
     x 8.4720566d-03,-4.9043545d-06,-1.8486734d-06 /
      data fpp(18,13,20,1),fpp(18,13,20,2),fpp(18,13,20,3)/
     x 9.0439744d-03,-5.2927085d-06,-2.4105192d-06 /
      data fpp(18,13,21,1),fpp(18,13,21,2),fpp(18,13,21,3)/
     x 9.0439744d-03,-5.2927085d-06,-2.4611058d-06 /
      data fpp(18,13,22,1),fpp(18,13,22,2),fpp(18,13,22,3)/
     x 8.4720566d-03,-4.9043545d-06,-1.6463269d-06 /
      data fpp(18,13,23,1),fpp(18,13,23,2),fpp(18,13,23,3)/
     x 7.6640904d-03,-4.5716933d-06,-1.2795865d-06 /
      data fpp(18,14, 1,1),fpp(18,14, 1,2),fpp(18,14, 1,3)/
     x-7.0511619d-02, 1.1933130d-05, 1.6013300d-04 /
      data fpp(18,14, 2,1),fpp(18,14, 2,2),fpp(18,14, 2,3)/
     x-1.2457090d-01,-1.1307117d-05, 7.3039503d-05 /
      data fpp(18,14, 3,1),fpp(18,14, 3,2),fpp(18,14, 3,3)/
     x-1.7399542d-01,-4.9067225d-05,-1.0918101d-04 /
      data fpp(18,14, 4,1),fpp(18,14, 4,2),fpp(18,14, 4,3)/
     x-1.7399542d-01,-4.9067225d-05,-1.1689572d-04 /
      data fpp(18,14, 5,1),fpp(18,14, 5,2),fpp(18,14, 5,3)/
     x-1.2457090d-01,-1.1307117d-05, 1.0389832d-04 /
      data fpp(18,14, 6,1),fpp(18,14, 6,2),fpp(18,14, 6,3)/
     x-7.0511619d-02, 1.1933130d-05, 4.4412444d-05 /
      data fpp(18,14, 7,1),fpp(18,14, 7,2),fpp(18,14, 7,3)/
     x-3.6939544d-02, 2.0523333d-05, 3.0619907d-05 /
      data fpp(18,14, 8,1),fpp(18,14, 8,2),fpp(18,14, 8,3)/
     x-1.5434761d-02, 1.8204565d-05, 5.6919282d-06 /
      data fpp(18,14, 9,1),fpp(18,14, 9,2),fpp(18,14, 9,3)/
     x-3.0247291d-03, 1.2100806d-05,-3.3056198d-06 /
      data fpp(18,14,10,1),fpp(18,14,10,2),fpp(18,14,10,3)/
     x 2.9200392d-03, 6.6238036d-06,-4.8714489d-06 /
      data fpp(18,14,11,1),fpp(18,14,11,2),fpp(18,14,11,3)/
     x 5.1384535d-03, 2.9923613d-06,-2.9605844d-06 /
      data fpp(18,14,12,1),fpp(18,14,12,2),fpp(18,14,12,3)/
     x 5.6332037d-03, 8.3620627d-07,-9.9221328d-07 /
      data fpp(18,14,13,1),fpp(18,14,13,2),fpp(18,14,13,3)/
     x 5.6208087d-03,-4.4628532d-07, 4.2543755d-07 /
      data fpp(18,14,14,1),fpp(18,14,14,2),fpp(18,14,14,3)/
     x 5.6390961d-03,-1.2661586d-06, 1.2644631d-06 /
      data fpp(18,14,15,1),fpp(18,14,15,2),fpp(18,14,15,3)/
     x 5.8552157d-03,-1.8710970d-06, 1.5247101d-06 /
      data fpp(18,14,16,1),fpp(18,14,16,2),fpp(18,14,16,3)/
     x 6.3116069d-03,-2.3806315d-06, 1.2466964d-06 /
      data fpp(18,14,17,1),fpp(18,14,17,2),fpp(18,14,17,3)/
     x 6.9489014d-03,-2.8293634d-06, 5.1450415d-07 /
      data fpp(18,14,18,1),fpp(18,14,18,2),fpp(18,14,18,3)/
     x 7.6674171d-03,-3.2026040d-06,-4.9671303d-07 /
      data fpp(18,14,19,1),fpp(18,14,19,2),fpp(18,14,19,3)/
     x 8.3085628d-03,-3.4526334d-06,-1.4796520d-06 /
      data fpp(18,14,20,1),fpp(18,14,20,2),fpp(18,14,20,3)/
     x 8.7881849d-03,-3.4683054d-06,-1.8046789d-06 /
      data fpp(18,14,21,1),fpp(18,14,21,2),fpp(18,14,21,3)/
     x 8.7881849d-03,-3.4683054d-06,-1.8441374d-06 /
      data fpp(18,14,22,1),fpp(18,14,22,2),fpp(18,14,22,3)/
     x 8.3085628d-03,-3.4526334d-06,-1.3218179d-06 /
      data fpp(18,14,23,1),fpp(18,14,23,2),fpp(18,14,23,3)/
     x 7.6674171d-03,-3.2026040d-06,-1.0885911d-06 /
      data fpp(18,15, 1,1),fpp(18,15, 1,2),fpp(18,15, 1,3)/
     x-7.3694963d-02, 4.6958879d-06, 9.6976974d-05 /
      data fpp(18,15, 2,1),fpp(18,15, 2,2),fpp(18,15, 2,3)/
     x-1.4922162d-01,-5.1546178d-06, 4.1286551d-05 /
      data fpp(18,15, 3,1),fpp(18,15, 3,2),fpp(18,15, 3,3)/
     x-2.9877201d-01,-2.4295896d-05,-7.5577179d-05 /
      data fpp(18,15, 4,1),fpp(18,15, 4,2),fpp(18,15, 4,3)/
     x-2.9877201d-01,-2.4295896d-05,-7.9904739d-05 /
      data fpp(18,15, 5,1),fpp(18,15, 5,2),fpp(18,15, 5,3)/
     x-1.4922162d-01,-5.1546178d-06, 5.8596792d-05 /
      data fpp(18,15, 6,1),fpp(18,15, 6,2),fpp(18,15, 6,3)/
     x-7.3694963d-02, 4.6958879d-06, 3.2063572d-05 /
      data fpp(18,15, 7,1),fpp(18,15, 7,2),fpp(18,15, 7,3)/
     x-3.7371371d-02, 7.4852394d-06, 2.2512919d-05 /
      data fpp(18,15, 8,1),fpp(18,15, 8,2),fpp(18,15, 8,3)/
     x-1.5629080d-02, 8.4655806d-06, 7.5567505d-06 /
      data fpp(18,15, 9,1),fpp(18,15, 9,2),fpp(18,15, 9,3)/
     x-3.6260260d-03, 7.9008283d-06, 6.7807868d-07 /
      data fpp(18,15,10,1),fpp(18,15,10,2),fpp(18,15,10,3)/
     x 2.1623182d-03, 6.2081051d-06,-1.5930652d-06 /
      data fpp(18,15,11,1),fpp(18,15,11,2),fpp(18,15,11,3)/
     x 4.5552239d-03, 4.2369336d-06,-1.2598178d-06 /
      data fpp(18,15,12,1),fpp(18,15,12,2),fpp(18,15,12,3)/
     x 5.3458131d-03, 2.5594475d-06,-3.5166370d-07 /
      data fpp(18,15,13,1),fpp(18,15,13,2),fpp(18,15,13,3)/
     x 5.5146683d-03, 1.2723389d-06, 4.0447258d-07 /
      data fpp(18,15,14,1),fpp(18,15,14,2),fpp(18,15,14,3)/
     x 5.5879553d-03, 3.4070824d-07, 8.5177338d-07 /
      data fpp(18,15,15,1),fpp(18,15,15,2),fpp(18,15,15,3)/
     x 5.7727315d-03,-2.6559557d-07, 9.7643389d-07 /
      data fpp(18,15,16,1),fpp(18,15,16,2),fpp(18,15,16,3)/
     x 6.1065737d-03,-6.1477277d-07, 7.6249107d-07 /
      data fpp(18,15,17,1),fpp(18,15,17,2),fpp(18,15,17,3)/
     x 6.5722730d-03,-7.5772582d-07, 2.8160184d-07 /
      data fpp(18,15,18,1),fpp(18,15,18,2),fpp(18,15,18,3)/
     x 7.1009940d-03,-7.4989063d-07,-3.6489844d-07 /
      data fpp(18,15,19,1),fpp(18,15,19,2),fpp(18,15,19,3)/
     x 7.5526900d-03,-6.5311206d-07,-9.3400808d-07 /
      data fpp(18,15,20,1),fpp(18,15,20,2),fpp(18,15,20,3)/
     x 7.8843319d-03,-5.9807011d-07,-1.1730692d-06 /
      data fpp(18,15,21,1),fpp(18,15,21,2),fpp(18,15,21,3)/
     x 7.8843319d-03,-5.9807011d-07,-1.1947883d-06 /
      data fpp(18,15,22,1),fpp(18,15,22,2),fpp(18,15,22,3)/
     x 7.5526900d-03,-6.5311206d-07,-8.4713192d-07 /
      data fpp(18,15,23,1),fpp(18,15,23,2),fpp(18,15,23,3)/
     x 7.1009940d-03,-7.4989063d-07,-6.9068404d-07 /
      data fpp(18,16, 1,1),fpp(18,16, 1,2),fpp(18,16, 1,3)/
     x-1.5358240d-02,-4.3538681d-05, 2.3441567d-05 /
      data fpp(18,16, 2,1),fpp(18,16, 2,2),fpp(18,16, 2,3)/
     x 1.7222685d-02,-4.4658412d-05, 5.7778654d-06 /
      data fpp(18,16, 3,1),fpp(18,16, 3,2),fpp(18,16, 3,3)/
     x-6.5801265d-02,-9.2451929d-06,-3.1721029d-05 /
      data fpp(18,16, 4,1),fpp(18,16, 4,2),fpp(18,16, 4,3)/
     x-6.5801265d-02,-9.2451929d-06,-3.2336846d-05 /
      data fpp(18,16, 5,1),fpp(18,16, 5,2),fpp(18,16, 5,3)/
     x 1.7222685d-02,-4.4658412d-05, 8.2411315d-06 /
      data fpp(18,16, 6,1),fpp(18,16, 6,2),fpp(18,16, 6,3)/
     x-1.5358240d-02,-4.3538681d-05, 1.4204320d-05 /
      data fpp(18,16, 7,1),fpp(18,16, 7,2),fpp(18,16, 7,3)/
     x-1.4532755d-02,-2.9164291d-05, 1.1861590d-05 /
      data fpp(18,16, 8,1),fpp(18,16, 8,2),fpp(18,16, 8,3)/
     x-6.0256696d-03,-1.4908888d-05, 6.8453201d-06 /
      data fpp(18,16, 9,1),fpp(18,16, 9,2),fpp(18,16, 9,3)/
     x-4.5178116d-03,-4.9381189d-06, 3.2611295d-06 /
      data fpp(18,16,10,1),fpp(18,16,10,2),fpp(18,16,10,3)/
     x 3.1157439d-03, 3.9777595d-07, 1.3441620d-06 /
      data fpp(18,16,11,1),fpp(18,16,11,2),fpp(18,16,11,3)/
     x 4.6503226d-03, 2.4759044d-06, 6.8022268d-07 /
      data fpp(18,16,12,1),fpp(18,16,12,2),fpp(18,16,12,3)/
     x 5.2719195d-03, 2.8280038d-06, 5.9694733d-07 /
      data fpp(18,16,13,1),fpp(18,16,13,2),fpp(18,16,13,3)/
     x 5.4707654d-03, 2.5089298d-06, 6.7598799d-07 /
      data fpp(18,16,14,1),fpp(18,16,14,2),fpp(18,16,14,3)/
     x 5.5335928d-03, 2.0633256d-06, 7.1910069d-07 /
      data fpp(18,16,15,1),fpp(18,16,15,2),fpp(18,16,15,3)/
     x 5.6114142d-03, 1.7394792d-06, 6.5360925d-07 /
      data fpp(18,16,16,1),fpp(18,16,16,2),fpp(18,16,16,3)/
     x 5.7770067d-03, 1.6657226d-06, 4.7046231d-07 /
      data fpp(18,16,17,1),fpp(18,16,17,2),fpp(18,16,17,3)/
     x 6.0165387d-03, 1.8402667d-06, 1.8854150d-07 /
      data fpp(18,16,18,1),fpp(18,16,18,2),fpp(18,16,18,3)/
     x 6.2754077d-03, 2.1761666d-06,-1.4462832d-07 /
      data fpp(18,16,19,1),fpp(18,16,19,2),fpp(18,16,19,3)/
     x 6.5332698d-03, 2.5010816d-06,-4.1402821d-07 /
      data fpp(18,16,20,1),fpp(18,16,20,2),fpp(18,16,20,3)/
     x 6.7036586d-03, 2.6985858d-06,-5.8725883d-07 /
      data fpp(18,16,21,1),fpp(18,16,21,2),fpp(18,16,21,3)/
     x 6.7036586d-03, 2.6985858d-06,-5.9620941d-07 /
      data fpp(18,16,22,1),fpp(18,16,22,2),fpp(18,16,22,3)/
     x 6.5332698d-03, 2.5010816d-06,-3.7822588d-07 /
      data fpp(18,16,23,1),fpp(18,16,23,2),fpp(18,16,23,3)/
     x 6.2754077d-03, 2.1761666d-06,-2.7888706d-07 /
      data fpp(18,17, 1,1),fpp(18,17, 1,2),fpp(18,17, 1,3)/
     x 3.9002069d-02,-1.8875163d-05, 2.0637360d-07 /
      data fpp(18,17, 2,1),fpp(18,17, 2,2),fpp(18,17, 2,3)/
     x 9.8481503d-03,-4.7173530d-07,-2.5087472d-06 /
      data fpp(18,17, 3,1),fpp(18,17, 3,2),fpp(18,17, 3,3)/
     x-1.6952805d-02, 1.9792667d-05,-8.3513848d-06 /
      data fpp(18,17, 4,1),fpp(18,17, 4,2),fpp(18,17, 4,3)/
     x-1.6952805d-02, 1.9792667d-05,-8.3084721d-06 /
      data fpp(18,17, 5,1),fpp(18,17, 5,2),fpp(18,17, 5,3)/
     x 9.8481503d-03,-4.7173530d-07,-2.6803981d-06 /
      data fpp(18,17, 6,1),fpp(18,17, 6,2),fpp(18,17, 6,3)/
     x 3.9002069d-02,-1.8875163d-05, 8.5006437d-07 /
      data fpp(18,17, 7,1),fpp(18,17, 7,2),fpp(18,17, 7,3)/
     x 4.6538771d-03,-2.4352076d-05, 2.6401406d-06 /
      data fpp(18,17, 8,1),fpp(18,17, 8,2),fpp(18,17, 8,3)/
     x 4.8182047d-03,-2.0656030d-05, 2.7973732d-06 /
      data fpp(18,17, 9,1),fpp(18,17, 9,2),fpp(18,17, 9,3)/
     x 4.8359275d-03,-1.3726353d-05, 2.3103666d-06 /
      data fpp(18,17,10,1),fpp(18,17,10,2),fpp(18,17,10,3)/
     x 5.2174772d-03,-7.1452089d-06, 1.7371606d-06 /
      data fpp(18,17,11,1),fpp(18,17,11,2),fpp(18,17,11,3)/
     x 5.4804173d-03,-2.2905512d-06, 1.2949912d-06 /
      data fpp(18,17,12,1),fpp(18,17,12,2),fpp(18,17,12,3)/
     x 5.6017375d-03, 7.9253745d-07, 1.0088745d-06 /
      data fpp(18,17,13,1),fpp(18,17,13,2),fpp(18,17,13,3)/
     x 5.6386405d-03, 2.5759420d-06, 8.2551078d-07 /
      data fpp(18,17,14,1),fpp(18,17,14,2),fpp(18,17,14,3)/
     x 5.6184875d-03, 3.5739893d-06, 6.7508238d-07 /
      data fpp(18,17,15,1),fpp(18,17,15,2),fpp(18,17,15,3)/
     x 5.6104629d-03, 4.1976787d-06, 5.3615970d-07 /
      data fpp(18,17,16,1),fpp(18,17,16,2),fpp(18,17,16,3)/
     x 5.6236508d-03, 4.6798824d-06, 3.8427883d-07 /
      data fpp(18,17,17,1),fpp(18,17,17,2),fpp(18,17,17,3)/
     x 5.6633364d-03, 5.1326590d-06, 2.3672498d-07 /
      data fpp(18,17,18,1),fpp(18,17,18,2),fpp(18,17,18,3)/
     x 5.7120131d-03, 5.5572244d-06, 7.2821265d-08 /
      data fpp(18,17,19,1),fpp(18,17,19,2),fpp(18,17,19,3)/
     x 5.7968075d-03, 5.9307857d-06,-3.0010035d-08 /
      data fpp(18,17,20,1),fpp(18,17,20,2),fpp(18,17,20,3)/
     x 5.8423902d-03, 6.1897269d-06,-1.2078113d-07 /
      data fpp(18,17,21,1),fpp(18,17,21,2),fpp(18,17,21,3)/
     x 5.8423902d-03, 6.1897269d-06,-1.2365161d-07 /
      data fpp(18,17,22,1),fpp(18,17,22,2),fpp(18,17,22,3)/
     x 5.7968075d-03, 5.9307857d-06,-1.8528113d-08 /
      data fpp(18,17,23,1),fpp(18,17,23,2),fpp(18,17,23,3)/
     x 5.7120131d-03, 5.5572244d-06, 2.9764056d-08 /
      data fpp(18,18, 1,1),fpp(18,18, 1,2),fpp(18,18, 1,3)/
     x 8.1725591d-03, 3.4853322d-06,-8.2750235d-07 /
      data fpp(18,18, 2,1),fpp(18,18, 2,2),fpp(18,18, 2,3)/
     x 8.5663234d-03, 1.0059353d-05,-1.0394953d-06 /
      data fpp(18,18, 3,1),fpp(18,18, 3,2),fpp(18,18, 3,3)/
     x 8.8134267d-03, 1.7362524d-05,-1.5005164d-06 /
      data fpp(18,18, 4,1),fpp(18,18, 4,2),fpp(18,18, 4,3)/
     x 8.8134267d-03, 1.7362524d-05,-1.4887031d-06 /
      data fpp(18,18, 5,1),fpp(18,18, 5,2),fpp(18,18, 5,3)/
     x 8.5663234d-03, 1.0059353d-05,-1.0867487d-06 /
      data fpp(18,18, 6,1),fpp(18,18, 6,2),fpp(18,18, 6,3)/
     x 8.1725591d-03, 3.4853322d-06,-6.5030220d-07 /
      data fpp(18,18, 7,1),fpp(18,18, 7,2),fpp(18,18, 7,3)/
     x 7.6326497d-03,-1.7614070d-06,-2.2404253d-07 /
      data fpp(18,18, 8,1),fpp(18,18, 8,2),fpp(18,18, 8,3)/
     x 7.1865256d-03,-4.9409914d-06, 1.0647231d-07 /
      data fpp(18,18, 9,1),fpp(18,18, 9,2),fpp(18,18, 9,3)/
     x 6.8376919d-03,-6.0184707d-06, 3.2615329d-07 /
      data fpp(18,18,10,1),fpp(18,18,10,2),fpp(18,18,10,3)/
     x 6.5585989d-03,-5.5309403d-06, 4.4291451d-07 /
      data fpp(18,18,11,1),fpp(18,18,11,2),fpp(18,18,11,3)/
     x 6.3489488d-03,-4.0896997d-06, 4.8218865d-07 /
      data fpp(18,18,12,1),fpp(18,18,12,2),fpp(18,18,12,3)/
     x 6.1901569d-03,-2.1701536d-06, 4.8433090d-07 /
      data fpp(18,18,13,1),fpp(18,18,13,2),fpp(18,18,13,3)/
     x 6.0613093d-03,-8.0697709d-08, 4.4848776d-07 /
      data fpp(18,18,14,1),fpp(18,18,14,2),fpp(18,18,14,3)/
     x 5.9692850d-03, 2.0127174d-06, 4.0971807d-07 /
      data fpp(18,18,15,1),fpp(18,18,15,2),fpp(18,18,15,3)/
     x 5.8865760d-03, 4.0058061d-06, 3.5463996d-07 /
      data fpp(18,18,16,1),fpp(18,18,16,2),fpp(18,18,16,3)/
     x 5.8299086d-03, 5.8407479d-06, 3.0172208d-07 /
      data fpp(18,18,17,1),fpp(18,18,17,2),fpp(18,18,17,3)/
     x 5.7953146d-03, 7.4610974d-06, 2.5047173d-07 /
      data fpp(18,18,18,1),fpp(18,18,18,2),fpp(18,18,18,3)/
     x 5.7655570d-03, 8.8109359d-06, 2.0239101d-07 /
      data fpp(18,18,19,1),fpp(18,18,19,2),fpp(18,18,19,3)/
     x 5.7619018d-03, 9.8177755d-06, 1.8196424d-07 /
      data fpp(18,18,20,1),fpp(18,18,20,2),fpp(18,18,20,3)/
     x 5.7425083d-03, 1.0426507d-05, 1.3775203d-07 /
      data fpp(18,18,21,1),fpp(18,18,21,2),fpp(18,18,21,3)/
     x 5.7425083d-03, 1.0426507d-05, 1.3776179d-07 /
      data fpp(18,18,22,1),fpp(18,18,22,2),fpp(18,18,22,3)/
     x 5.7619018d-03, 9.8177755d-06, 1.8192520d-07 /
      data fpp(18,18,23,1),fpp(18,18,23,2),fpp(18,18,23,3)/
     x 5.7655570d-03, 8.8109359d-06, 2.0253740d-07 /
      data fpp(18,19, 1,1),fpp(18,19, 1,2),fpp(18,19, 1,3)/
     x 6.5055013d-03, 2.6503834d-05, 9.2306868d-22 /
      data fpp(18,19, 2,1),fpp(18,19, 2,2),fpp(18,19, 2,3)/
     x 6.5055013d-03, 3.0206324d-05, 8.5206367d-22 /
      data fpp(18,19, 3,1),fpp(18,19, 3,2),fpp(18,19, 3,3)/
     x 6.5055013d-03, 2.3923238d-05,-7.2097965d-21 /
      data fpp(18,19, 4,1),fpp(18,19, 4,2),fpp(18,19, 4,3)/
     x 6.5055013d-03, 2.3923238d-05, 5.2889298d-21 /
      data fpp(18,19, 5,1),fpp(18,19, 5,2),fpp(18,19, 5,3)/
     x 6.5055013d-03, 3.0206324d-05, 1.6843091d-21 /
      data fpp(18,19, 6,1),fpp(18,19, 6,2),fpp(18,19, 6,3)/
     x 6.5055013d-03, 2.6503834d-05,-4.5670012d-21 /
      data fpp(18,19, 7,1),fpp(18,19, 7,2),fpp(18,19, 7,3)/
     x 6.5055013d-03, 1.5749703d-05,-1.1408166d-20 /
      data fpp(18,19, 8,1),fpp(18,19, 8,2),fpp(18,19, 8,3)/
     x 6.5055013d-03, 4.6419957d-06,-4.9276241d-21 /
      data fpp(18,19, 9,1),fpp(18,19, 9,2),fpp(18,19, 9,3)/
     x 6.5055013d-03,-3.0237647d-06,-3.6078386d-21 /
      data fpp(18,19,10,1),fpp(18,19,10,2),fpp(18,19,10,3)/
     x 6.5055013d-03,-6.5330298d-06, 1.3705124d-20 /
      data fpp(18,19,11,1),fpp(18,19,11,2),fpp(18,19,11,3)/
     x 6.5055013d-03,-6.7366502d-06,-7.1172098d-21 /
      data fpp(18,19,12,1),fpp(18,19,12,2),fpp(18,19,12,3)/
     x 6.5055013d-03,-4.8679232d-06, 1.3092382d-21 /
      data fpp(18,19,13,1),fpp(18,19,13,2),fpp(18,19,13,3)/
     x 6.5055013d-03,-1.9591511d-06, 2.5058614d-21 /
      data fpp(18,19,14,1),fpp(18,19,14,2),fpp(18,19,14,3)/
     x 6.5055013d-03, 1.3291413d-06,-5.0525953d-21 /
      data fpp(18,19,15,1),fpp(18,19,15,2),fpp(18,19,15,3)/
     x 6.5055013d-03, 4.5710970d-06, 5.3112374d-22 /
      data fpp(18,19,16,1),fpp(18,19,16,2),fpp(18,19,16,3)/
     x 6.5055013d-03, 7.5311261d-06,-1.3390640d-21 /
      data fpp(18,19,17,1),fpp(18,19,17,2),fpp(18,19,17,3)/
     x 6.5055013d-03, 1.0064951d-05, 6.4430329d-21 /
      data fpp(18,19,18,1),fpp(18,19,18,2),fpp(18,19,18,3)/
     x 6.5055013d-03, 1.2101032d-05,-6.6424100d-21 /
      data fpp(18,19,19,1),fpp(18,19,19,2),fpp(18,19,19,3)/
     x 6.5055013d-03, 1.3574112d-05,-9.3139748d-21 /
      data fpp(18,19,20,1),fpp(18,19,20,2),fpp(18,19,20,3)/
     x 6.5055013d-03, 1.4450247d-05, 4.5078341d-21 /
      data fpp(18,19,21,1),fpp(18,19,21,2),fpp(18,19,21,3)/
     x 6.5055013d-03, 1.4450247d-05,-8.7592725d-21 /
      data fpp(18,19,22,1),fpp(18,19,22,2),fpp(18,19,22,3)/
     x 6.5055013d-03, 1.3574112d-05, 6.5344985d-21 /
      data fpp(18,19,23,1),fpp(18,19,23,2),fpp(18,19,23,3)/
     x 6.5055013d-03, 1.2101032d-05, 1.7983688d-20 /
      data fpp(19, 1, 1,1),fpp(19, 1, 1,2),fpp(19, 1, 1,3)/
     x 1.4946598d+00, 4.3435493d-04, 2.4147920d-19 /
      data fpp(19, 1, 2,1),fpp(19, 1, 2,2),fpp(19, 1, 2,3)/
     x 1.4946598d+00, 5.6677758d-04,-5.4264590d-20 /
      data fpp(19, 1, 3,1),fpp(19, 1, 3,2),fpp(19, 1, 3,3)/
     x 1.4946598d+00, 7.8172587d-04,-2.9685127d-19 /
      data fpp(19, 1, 4,1),fpp(19, 1, 4,2),fpp(19, 1, 4,3)/
     x 1.4946598d+00, 7.8172587d-04, 4.3441577d-20 /
      data fpp(19, 1, 5,1),fpp(19, 1, 5,2),fpp(19, 1, 5,3)/
     x 1.4946598d+00, 5.6677758d-04, 1.0075051d-19 /
      data fpp(19, 1, 6,1),fpp(19, 1, 6,2),fpp(19, 1, 6,3)/
     x 1.4946598d+00, 4.3435493d-04,-3.1396153d-19 /
      data fpp(19, 1, 7,1),fpp(19, 1, 7,2),fpp(19, 1, 7,3)/
     x 1.4946598d+00, 3.3324711d-04,-3.2622242d-19 /
      data fpp(19, 1, 8,1),fpp(19, 1, 8,2),fpp(19, 1, 8,3)/
     x 1.4946598d+00, 2.7039462d-04,-2.9185900d-19 /
      data fpp(19, 1, 9,1),fpp(19, 1, 9,2),fpp(19, 1, 9,3)/
     x 1.4946598d+00, 2.3397270d-04,-4.2971918d-20 /
      data fpp(19, 1,10,1),fpp(19, 1,10,2),fpp(19, 1,10,3)/
     x 1.4946598d+00, 2.1335126d-04, 4.6118554d-19 /
      data fpp(19, 1,11,1),fpp(19, 1,11,2),fpp(19, 1,11,3)/
     x 1.4946598d+00, 2.0234404d-04,-3.3457895d-19 /
      data fpp(19, 1,12,1),fpp(19, 1,12,2),fpp(19, 1,12,3)/
     x 1.4946598d+00, 1.9768912d-04, 1.1291262d-19 /
      data fpp(19, 1,13,1),fpp(19, 1,13,2),fpp(19, 1,13,3)/
     x 1.4946598d+00, 1.9837428d-04, 1.9798016d-19 /
      data fpp(19, 1,14,1),fpp(19, 1,14,2),fpp(19, 1,14,3)/
     x 1.4946598d+00, 2.0579427d-04, 1.2340816d-19 /
      data fpp(19, 1,15,1),fpp(19, 1,15,2),fpp(19, 1,15,3)/
     x 1.4946598d+00, 2.2353560d-04,-1.4863256d-20 /
      data fpp(19, 1,16,1),fpp(19, 1,16,2),fpp(19, 1,16,3)/
     x 1.4946598d+00, 2.5798246d-04,-2.1840898d-19 /
      data fpp(19, 1,17,1),fpp(19, 1,17,2),fpp(19, 1,17,3)/
     x 1.4946598d+00, 3.1941510d-04, 2.6377805d-19 /
      data fpp(19, 1,18,1),fpp(19, 1,18,2),fpp(19, 1,18,3)/
     x 1.4946598d+00, 4.1826501d-04,-4.2822195d-19 /
      data fpp(19, 1,19,1),fpp(19, 1,19,2),fpp(19, 1,19,3)/
     x 1.4946598d+00, 6.5414747d-04,-3.2490696d-19 /
      data fpp(19, 1,20,1),fpp(19, 1,20,2),fpp(19, 1,20,3)/
     x 1.4946598d+00, 7.7919063d-04, 1.4992412d-19 /
      data fpp(19, 1,21,1),fpp(19, 1,21,2),fpp(19, 1,21,3)/
     x 1.4946598d+00, 7.7919063d-04,-4.7257849d-20 /
      data fpp(19, 1,22,1),fpp(19, 1,22,2),fpp(19, 1,22,3)/
     x 1.4946598d+00, 6.5414747d-04, 7.0047314d-20 /
      data fpp(19, 1,23,1),fpp(19, 1,23,2),fpp(19, 1,23,3)/
     x 1.4946598d+00, 4.1826501d-04, 1.0166347d-18 /
      data fpp(19, 2, 1,1),fpp(19, 2, 1,2),fpp(19, 2, 1,3)/
     x-2.6678161d-01, 2.4371014d-04,-7.9144113d-05 /
      data fpp(19, 2, 2,1),fpp(19, 2, 2,2),fpp(19, 2, 2,3)/
     x-2.8624569d-01, 2.7746284d-04,-5.4838274d-05 /
      data fpp(19, 2, 3,1),fpp(19, 2, 3,2),fpp(19, 2, 3,3)/
     x-1.0471937d-01, 3.5485526d-04,-6.2127897d-06 /
      data fpp(19, 2, 4,1),fpp(19, 2, 4,2),fpp(19, 2, 4,3)/
     x-1.0471937d-01, 3.5485526d-04,-1.6049376d-07 /
      data fpp(19, 2, 5,1),fpp(19, 2, 5,2),fpp(19, 2, 5,3)/
     x-2.8624569d-01, 2.7746284d-04,-7.9047458d-05 /
      data fpp(19, 2, 6,1),fpp(19, 2, 6,2),fpp(19, 2, 6,3)/
     x-2.6678161d-01, 2.4371014d-04, 1.1640326d-05 /
      data fpp(19, 2, 7,1),fpp(19, 2, 7,2),fpp(19, 2, 7,3)/
     x-2.3009293d-01, 2.2118378d-04, 8.9015350d-07 /
      data fpp(19, 2, 8,1),fpp(19, 2, 8,2),fpp(19, 2, 8,3)/
     x-1.9475781d-01, 2.1240675d-04, 1.1379060d-05 /
      data fpp(19, 2, 9,1),fpp(19, 2, 9,2),fpp(19, 2, 9,3)/
     x-1.1083397d-01, 2.1196160d-04, 1.3725607d-05 /
      data fpp(19, 2,10,1),fpp(19, 2,10,2),fpp(19, 2,10,3)/
     x-9.5688976d-02, 2.1454947d-04, 1.6614512d-05 /
      data fpp(19, 2,11,1),fpp(19, 2,11,2),fpp(19, 2,11,3)/
     x-6.5081768d-02, 2.1678593d-04, 1.8012346d-05 /
      data fpp(19, 2,12,1),fpp(19, 2,12,2),fpp(19, 2,12,3)/
     x-1.0134783d-01, 2.1683376d-04, 1.8550103d-05 /
      data fpp(19, 2,13,1),fpp(19, 2,13,2),fpp(19, 2,13,3)/
     x-1.2572823d-01, 2.1413644d-04, 1.8211243d-05 /
      data fpp(19, 2,14,1),fpp(19, 2,14,2),fpp(19, 2,14,3)/
     x-9.3844331d-02, 2.0945647d-04, 1.6448924d-05 /
      data fpp(19, 2,15,1),fpp(19, 2,15,2),fpp(19, 2,15,3)/
     x-1.0788903d-01, 2.0480480d-04, 1.5431062d-05 /
      data fpp(19, 2,16,1),fpp(19, 2,16,2),fpp(19, 2,16,3)/
     x-1.9119140d-01, 2.0367507d-04, 6.6308300d-06 /
      data fpp(19, 2,17,1),fpp(19, 2,17,2),fpp(19, 2,17,3)/
     x-2.2785440d-01, 2.1121880d-04, 2.1309618d-05 /
      data fpp(19, 2,18,1),fpp(19, 2,18,2),fpp(19, 2,18,3)/
     x-2.7069115d-01, 2.3218198d-04,-5.8971303d-05 /
      data fpp(19, 2,19,1),fpp(19, 2,19,2),fpp(19, 2,19,3)/
     x-1.5878827d-01, 3.1759706d-04, 2.4873594d-05 /
      data fpp(19, 2,20,1),fpp(19, 2,20,2),fpp(19, 2,20,3)/
     x-1.1329893d-01, 3.4941175d-04,-3.6815074d-05 /
      data fpp(19, 2,21,1),fpp(19, 2,21,2),fpp(19, 2,21,3)/
     x-1.1329893d-01, 3.4941175d-04,-3.1468574d-05 /
      data fpp(19, 2,22,1),fpp(19, 2,22,2),fpp(19, 2,22,3)/
     x-1.5878827d-01, 3.1759706d-04, 3.4875926d-06 /
      data fpp(19, 2,23,1),fpp(19, 2,23,2),fpp(19, 2,23,3)/
     x-2.7069115d-01, 2.3218198d-04, 2.1226204d-05 /
      data fpp(19, 3, 1,1),fpp(19, 3, 1,2),fpp(19, 3, 1,3)/
     x-8.7325363d-02,-1.0355502d-05,-7.0180764d-06 /
      data fpp(19, 3, 2,1),fpp(19, 3, 2,2),fpp(19, 3, 2,3)/
     x-9.9700402d-03,-3.7332937d-05,-3.4776347d-05 /
      data fpp(19, 3, 3,1),fpp(19, 3, 3,2),fpp(19, 3, 3,3)/
     x 1.9149708d-01, 4.6639078d-05,-9.5262535d-05 /
      data fpp(19, 3, 4,1),fpp(19, 3, 4,2),fpp(19, 3, 4,3)/
     x 1.9149708d-01, 4.6639078d-05,-9.3505221d-05 /
      data fpp(19, 3, 5,1),fpp(19, 3, 5,2),fpp(19, 3, 5,3)/
     x-9.9700402d-03,-3.7332937d-05,-4.1805603d-05 /
      data fpp(19, 3, 6,1),fpp(19, 3, 6,2),fpp(19, 3, 6,3)/
     x-8.7325363d-02,-1.0355502d-05, 1.9341632d-05 /
      data fpp(19, 3, 7,1),fpp(19, 3, 7,2),fpp(19, 3, 7,3)/
     x-4.7957635d-02, 6.3581773d-05, 2.4427077d-05 /
      data fpp(19, 3, 8,1),fpp(19, 3, 8,2),fpp(19, 3, 8,3)/
     x-6.2682767d-02, 1.3625837d-04, 2.8102062d-05 /
      data fpp(19, 3, 9,1),fpp(19, 3, 9,2),fpp(19, 3, 9,3)/
     x-5.5600520d-02, 1.9547891d-04, 2.9730674d-05 /
      data fpp(19, 3,10,1),fpp(19, 3,10,2),fpp(19, 3,10,3)/
     x-5.0746322d-02, 2.3946285d-04, 3.1463240d-05 /
      data fpp(19, 3,11,1),fpp(19, 3,11,2),fpp(19, 3,11,3)/
     x-4.8094421d-02, 2.6678426d-04, 3.2354366d-05 /
      data fpp(19, 3,12,1),fpp(19, 3,12,2),fpp(19, 3,12,3)/
     x-4.7086685d-02, 2.7567583d-04, 3.2715297d-05 /
      data fpp(19, 3,13,1),fpp(19, 3,13,2),fpp(19, 3,13,3)/
     x-4.7441933d-02, 2.6533796d-04, 3.2762445d-05 /
      data fpp(19, 3,14,1),fpp(19, 3,14,2),fpp(19, 3,14,3)/
     x-4.9358918d-02, 2.3637786d-04, 3.2104924d-05 /
      data fpp(19, 3,15,1),fpp(19, 3,15,2),fpp(19, 3,15,3)/
     x-5.3349908d-02, 1.9048520d-04, 3.1195858d-05 /
      data fpp(19, 3,16,1),fpp(19, 3,16,2),fpp(19, 3,16,3)/
     x-5.8940407d-02, 1.2914124d-04, 2.8061644d-05 /
      data fpp(19, 3,17,1),fpp(19, 3,17,2),fpp(19, 3,17,3)/
     x-4.3088678d-02, 5.4423700d-05, 3.1391566d-05 /
      data fpp(19, 3,18,1),fpp(19, 3,18,2),fpp(19, 3,18,3)/
     x-8.2367206d-02,-2.1352916d-05, 2.2040905d-06 /
      data fpp(19, 3,19,1),fpp(19, 3,19,2),fpp(19, 3,19,3)/
     x 1.9128647d-02,-8.3747697d-05,-1.1389928d-05 /
      data fpp(19, 3,20,1),fpp(19, 3,20,2),fpp(19, 3,20,3)/
     x 1.4810776d-01, 2.0116387d-05,-1.0821038d-04 /
      data fpp(19, 3,21,1),fpp(19, 3,21,2),fpp(19, 3,21,3)/
     x 1.4810776d-01, 2.0116387d-05,-1.0671091d-04 /
      data fpp(19, 3,22,1),fpp(19, 3,22,2),fpp(19, 3,22,3)/
     x 1.9128647d-02,-8.3747697d-05,-1.7387813d-05 /
      data fpp(19, 3,23,1),fpp(19, 3,23,2),fpp(19, 3,23,3)/
     x-8.2367206d-02,-2.1352916d-05, 2.4696156d-05 /
      data fpp(19, 4, 1,1),fpp(19, 4, 1,2),fpp(19, 4, 1,3)/
     x-2.5791125d-02,-4.2448136d-05, 1.4828264d-04 /
      data fpp(19, 4, 2,1),fpp(19, 4, 2,2),fpp(19, 4, 2,3)/
     x-5.0588189d-02,-2.6294509d-04, 3.9338220d-05 /
      data fpp(19, 4, 3,1),fpp(19, 4, 3,2),fpp(19, 4, 3,3)/
     x-2.6961708d-01,-6.7686758d-04,-1.8968552d-04 /
      data fpp(19, 4, 4,1),fpp(19, 4, 4,2),fpp(19, 4, 4,3)/
     x-2.6961708d-01,-6.7686758d-04,-1.9743555d-04 /
      data fpp(19, 4, 5,1),fpp(19, 4, 5,2),fpp(19, 4, 5,3)/
     x-5.0588189d-02,-2.6294509d-04, 7.0338320d-05 /
      data fpp(19, 4, 6,1),fpp(19, 4, 6,2),fpp(19, 4, 6,3)/
     x-2.5791125d-02,-4.2448136d-05, 3.2032265d-05 /
      data fpp(19, 4, 7,1),fpp(19, 4, 7,2),fpp(19, 4, 7,3)/
     x-4.2939815d-02, 6.5365129d-05, 3.9486620d-05 /
      data fpp(19, 4, 8,1),fpp(19, 4, 8,2),fpp(19, 4, 8,3)/
     x-3.7727860d-02, 1.2367178d-04, 3.2945254d-05 /
      data fpp(19, 4, 9,1),fpp(19, 4, 9,2),fpp(19, 4, 9,3)/
     x-3.6341332d-02, 1.5964675d-04, 3.3908363d-05 /
      data fpp(19, 4,10,1),fpp(19, 4,10,2),fpp(19, 4,10,3)/
     x-3.5818983d-02, 1.8137311d-04, 3.3339296d-05 /
      data fpp(19, 4,11,1),fpp(19, 4,11,2),fpp(19, 4,11,3)/
     x-3.5779523d-02, 1.9233505d-04, 3.2648455d-05 /
      data fpp(19, 4,12,1),fpp(19, 4,12,2),fpp(19, 4,12,3)/
     x-3.5696196d-02, 1.9557692d-04, 3.2416885d-05 /
      data fpp(19, 4,13,1),fpp(19, 4,13,2),fpp(19, 4,13,3)/
     x-3.5382495d-02, 1.9250171d-04, 3.3236005d-05 /
      data fpp(19, 4,14,1),fpp(19, 4,14,2),fpp(19, 4,14,3)/
     x-3.4961185d-02, 1.8189209d-04, 3.4529094d-05 /
      data fpp(19, 4,15,1),fpp(19, 4,15,2),fpp(19, 4,15,3)/
     x-3.4833877d-02, 1.6072642d-04, 3.5707619d-05 /
      data fpp(19, 4,16,1),fpp(19, 4,16,2),fpp(19, 4,16,3)/
     x-3.5123636d-02, 1.2539995d-04, 3.5292429d-05 /
      data fpp(19, 4,17,1),fpp(19, 4,17,2),fpp(19, 4,17,3)/
     x-3.4224115d-02, 6.7724400d-05, 4.2356664d-05 /
      data fpp(19, 4,18,1),fpp(19, 4,18,2),fpp(19, 4,18,3)/
     x-1.6691663d-02,-3.8806310d-05, 3.4374915d-05 /
      data fpp(19, 4,19,1),fpp(19, 4,19,2),fpp(19, 4,19,3)/
     x-2.4684964d-02,-2.5831227d-04, 7.2485674d-05 /
      data fpp(19, 4,20,1),fpp(19, 4,20,2),fpp(19, 4,20,3)/
     x-2.4864376d-01,-6.6087129d-04,-2.0277561d-04 /
      data fpp(19, 4,21,1),fpp(19, 4,21,2),fpp(19, 4,21,3)/
     x-2.4864376d-01,-6.6087129d-04,-1.9486900d-04 /
      data fpp(19, 4,22,1),fpp(19, 4,22,2),fpp(19, 4,22,3)/
     x-2.4684964d-02,-2.5831227d-04, 4.0859214d-05 /
      data fpp(19, 4,23,1),fpp(19, 4,23,2),fpp(19, 4,23,3)/
     x-1.6691663d-02,-3.8806310d-05, 1.5297414d-04 /
      data fpp(19, 5, 1,1),fpp(19, 5, 1,2),fpp(19, 5, 1,3)/
     x-1.2335892d-02, 6.1864045d-05, 3.5014053d-05 /
      data fpp(19, 5, 2,1),fpp(19, 5, 2,2),fpp(19, 5, 2,3)/
     x 3.6092195d-03, 1.2521331d-04,-7.2071053d-06 /
      data fpp(19, 5, 3,1),fpp(19, 5, 3,2),fpp(19, 5, 3,3)/
     x 3.2580476d-02, 2.8746522d-04,-9.6749631d-05 /
      data fpp(19, 5, 4,1),fpp(19, 5, 4,2),fpp(19, 5, 4,3)/
     x 3.2580476d-02, 2.8746522d-04,-9.8379553d-05 /
      data fpp(19, 5, 5,1),fpp(19, 5, 5,2),fpp(19, 5, 5,3)/
     x 3.6092195d-03, 1.2521331d-04,-6.8741829d-07 /
      data fpp(19, 5, 6,1),fpp(19, 5, 6,2),fpp(19, 5, 6,3)/
     x-1.2335892d-02, 6.1864045d-05, 1.0565226d-05 /
      data fpp(19, 5, 7,1),fpp(19, 5, 7,2),fpp(19, 5, 7,3)/
     x-1.8837406d-02, 4.8799711d-05, 2.0856513d-05 /
      data fpp(19, 5, 8,1),fpp(19, 5, 8,2),fpp(19, 5, 8,3)/
     x-2.2320154d-02, 5.2226516d-05, 2.3908722d-05 /
      data fpp(19, 5, 9,1),fpp(19, 5, 9,2),fpp(19, 5, 9,3)/
     x-2.4804364d-02, 5.6538076d-05, 2.5396600d-05 /
      data fpp(19, 5,10,1),fpp(19, 5,10,2),fpp(19, 5,10,3)/
     x-2.6613762d-02, 5.8368689d-05, 2.5140879d-05 /
      data fpp(19, 5,11,1),fpp(19, 5,11,2),fpp(19, 5,11,3)/
     x-2.7707211d-02, 5.8845549d-05, 2.4855885d-05 /
      data fpp(19, 5,12,1),fpp(19, 5,12,2),fpp(19, 5,12,3)/
     x-2.8042462d-02, 5.9138503d-05, 2.5045580d-05 /
      data fpp(19, 5,13,1),fpp(19, 5,13,2),fpp(19, 5,13,3)/
     x-2.7607282d-02, 5.9619196d-05, 2.5777796d-05 /
      data fpp(19, 5,14,1),fpp(19, 5,14,2),fpp(19, 5,14,3)/
     x-2.6427420d-02, 6.0055781d-05, 2.6949237d-05 /
      data fpp(19, 5,15,1),fpp(19, 5,15,2),fpp(19, 5,15,3)/
     x-2.4546640d-02, 5.9529136d-05, 2.8047258d-05 /
      data fpp(19, 5,16,1),fpp(19, 5,16,2),fpp(19, 5,16,3)/
     x-2.1946713d-02, 5.7194963d-05, 2.7313732d-05 /
      data fpp(19, 5,17,1),fpp(19, 5,17,2),fpp(19, 5,17,3)/
     x-1.8191550d-02, 5.6392698d-05, 2.5093815d-05 /
      data fpp(19, 5,18,1),fpp(19, 5,18,2),fpp(19, 5,18,3)/
     x-1.1229072d-02, 7.1818158d-05, 1.4415008d-05 /
      data fpp(19, 5,19,1),fpp(19, 5,19,2),fpp(19, 5,19,3)/
     x 4.8145050d-03, 1.3582277d-04, 3.1721539d-06 /
      data fpp(19, 5,20,1),fpp(19, 5,20,2),fpp(19, 5,20,3)/
     x 4.2734515d-02, 2.9193079d-04,-1.0630362d-04 /
      data fpp(19, 5,21,1),fpp(19, 5,21,2),fpp(19, 5,21,3)/
     x 4.2734515d-02, 2.9193079d-04,-1.0441221d-04 /
      data fpp(19, 5,22,1),fpp(19, 5,22,2),fpp(19, 5,22,3)/
     x 4.8145050d-03, 1.3582277d-04,-4.3935123d-06 /
      data fpp(19, 5,23,1),fpp(19, 5,23,2),fpp(19, 5,23,3)/
     x-1.1229072d-02, 7.1818158d-05, 4.2786256d-05 /
      data fpp(19, 6, 1,1),fpp(19, 6, 1,2),fpp(19, 6, 1,3)/
     x-5.3907074d-04, 3.8171955d-05,-4.1305247d-06 /
      data fpp(19, 6, 2,1),fpp(19, 6, 2,2),fpp(19, 6, 2,3)/
     x 7.7144462d-03, 6.3135862d-05,-1.5184951d-05 /
      data fpp(19, 6, 3,1),fpp(19, 6, 3,2),fpp(19, 6, 3,3)/
     x 1.6458876d-02, 7.9192679d-05,-3.8929673d-05 /
      data fpp(19, 6, 4,1),fpp(19, 6, 4,2),fpp(19, 6, 4,3)/
     x 1.6458876d-02, 7.9192679d-05,-3.8830505d-05 /
      data fpp(19, 6, 5,1),fpp(19, 6, 5,2),fpp(19, 6, 5,3)/
     x 7.7144462d-03, 6.3135862d-05,-1.5581623d-05 /
      data fpp(19, 6, 6,1),fpp(19, 6, 6,2),fpp(19, 6, 6,3)/
     x-5.3907074d-04, 3.8171955d-05,-2.6430046d-06 /
      data fpp(19, 6, 7,1),fpp(19, 6, 7,2),fpp(19, 6, 7,3)/
     x-6.9879565d-03, 1.8238025d-05, 6.5456409d-06 /
      data fpp(19, 6, 8,1),fpp(19, 6, 8,2),fpp(19, 6, 8,3)/
     x-1.1902680d-02, 3.6981569d-06, 1.1188441d-05 /
      data fpp(19, 6, 9,1),fpp(19, 6, 9,2),fpp(19, 6, 9,3)/
     x-1.5583891d-02,-5.9090562d-06, 1.3440595d-05 /
      data fpp(19, 6,10,1),fpp(19, 6,10,2),fpp(19, 6,10,3)/
     x-1.8125922d-02,-1.0903869d-05, 1.4843178d-05 /
      data fpp(19, 6,11,1),fpp(19, 6,11,2),fpp(19, 6,11,3)/
     x-1.9638928d-02,-1.2541245d-05, 1.6082692d-05 /
      data fpp(19, 6,12,1),fpp(19, 6,12,2),fpp(19, 6,12,3)/
     x-2.0245167d-02,-1.2412928d-05, 1.7006053d-05 /
      data fpp(19, 6,13,1),fpp(19, 6,13,2),fpp(19, 6,13,3)/
     x-2.0035276d-02,-1.1248494d-05, 1.7443097d-05 /
      data fpp(19, 6,14,1),fpp(19, 6,14,2),fpp(19, 6,14,3)/
     x-1.8961945d-02,-8.3852137d-06, 1.7531561d-05 /
      data fpp(19, 6,15,1),fpp(19, 6,15,2),fpp(19, 6,15,3)/
     x-1.6927204d-02,-2.3629619d-06, 1.7364660d-05 /
      data fpp(19, 6,16,1),fpp(19, 6,16,2),fpp(19, 6,16,3)/
     x-1.3800545d-02, 7.8482008d-06, 1.6059800d-05 /
      data fpp(19, 6,17,1),fpp(19, 6,17,2),fpp(19, 6,17,3)/
     x-9.3804407d-03, 2.2226807d-05, 1.1900140d-05 /
      data fpp(19, 6,18,1),fpp(19, 6,18,2),fpp(19, 6,18,3)/
     x-3.2727585d-03, 4.0781680d-05, 1.6856415d-06 /
      data fpp(19, 6,19,1),fpp(19, 6,19,2),fpp(19, 6,19,3)/
     x 5.0160508d-03, 6.3021175d-05,-1.4106705d-05 /
      data fpp(19, 6,20,1),fpp(19, 6,20,2),fpp(19, 6,20,3)/
     x 1.4292579d-02, 7.8118142d-05,-4.6982820d-05 /
      data fpp(19, 6,21,1),fpp(19, 6,21,2),fpp(19, 6,21,3)/
     x 1.4292579d-02, 7.8118142d-05,-4.7004188d-05 /
      data fpp(19, 6,22,1),fpp(19, 6,22,2),fpp(19, 6,22,3)/
     x 5.0160508d-03, 6.3021175d-05,-1.4021232d-05 /
      data fpp(19, 6,23,1),fpp(19, 6,23,2),fpp(19, 6,23,3)/
     x-3.2727585d-03, 4.0781680d-05, 1.3651160d-06 /
      data fpp(19, 7, 1,1),fpp(19, 7, 1,2),fpp(19, 7, 1,3)/
     x 3.2701195d-03, 2.5898136d-05,-6.2177595d-06 /
      data fpp(19, 7, 2,1),fpp(19, 7, 2,2),fpp(19, 7, 2,3)/
     x 6.9339590d-03, 5.1711244d-05,-8.6459810d-06 /
      data fpp(19, 7, 3,1),fpp(19, 7, 3,2),fpp(19, 7, 3,3)/
     x 9.7390683d-03, 7.6572062d-05,-1.3912317d-05 /
      data fpp(19, 7, 4,1),fpp(19, 7, 4,2),fpp(19, 7, 4,3)/
     x 9.7390683d-03, 7.6572062d-05,-1.3802060d-05 /
      data fpp(19, 7, 5,1),fpp(19, 7, 5,2),fpp(19, 7, 5,3)/
     x 6.9339590d-03, 5.1711244d-05,-9.0870077d-06 /
      data fpp(19, 7, 6,1),fpp(19, 7, 6,2),fpp(19, 7, 6,3)/
     x 3.2701195d-03, 2.5898136d-05,-4.5639092d-06 /
      data fpp(19, 7, 7,1),fpp(19, 7, 7,2),fpp(19, 7, 7,3)/
     x-5.6891237d-04, 3.3781879d-06,-6.0535543d-07 /
      data fpp(19, 7, 8,1),fpp(19, 7, 8,2),fpp(19, 7, 8,3)/
     x-4.1974199d-03,-1.3361144d-05, 2.3893309d-06 /
      data fpp(19, 7, 9,1),fpp(19, 7, 9,2),fpp(19, 7, 9,3)/
     x-7.3913547d-03,-2.4435851d-05, 4.9200318d-06 /
      data fpp(19, 7,10,1),fpp(19, 7,10,2),fpp(19, 7,10,3)/
     x-9.9875726d-03,-3.1241212d-05, 7.1205420d-06 /
      data fpp(19, 7,11,1),fpp(19, 7,11,2),fpp(19, 7,11,3)/
     x-1.1849090d-02,-3.4840571d-05, 8.8558001d-06 /
      data fpp(19, 7,12,1),fpp(19, 7,12,2),fpp(19, 7,12,3)/
     x-1.2847926d-02,-3.5508792d-05, 1.0016257d-05 /
      data fpp(19, 7,13,1),fpp(19, 7,13,2),fpp(19, 7,13,3)/
     x-1.2922738d-02,-3.3285219d-05, 1.0587170d-05 /
      data fpp(19, 7,14,1),fpp(19, 7,14,2),fpp(19, 7,14,3)/
     x-1.2106699d-02,-2.8428926d-05, 1.0533062d-05 /
      data fpp(19, 7,15,1),fpp(19, 7,15,2),fpp(19, 7,15,3)/
     x-1.0433859d-02,-2.0941289d-05, 9.8305811d-06 /
      data fpp(19, 7,16,1),fpp(19, 7,16,2),fpp(19, 7,16,3)/
     x-7.9193671d-03,-1.0029766d-05, 8.1646133d-06 /
      data fpp(19, 7,17,1),fpp(19, 7,17,2),fpp(19, 7,17,3)/
     x-4.4926567d-03, 5.4500749d-06, 4.8929656d-06 /
      data fpp(19, 7,18,1),fpp(19, 7,18,2),fpp(19, 7,18,3)/
     x-3.8709319d-04, 2.5833123d-05,-1.3124756d-06 /
      data fpp(19, 7,19,1),fpp(19, 7,19,2),fpp(19, 7,19,3)/
     x 4.1702987d-03, 4.9720528d-05,-9.6750633d-06 /
      data fpp(19, 7,20,1),fpp(19, 7,20,2),fpp(19, 7,20,3)/
     x 8.0344735d-03, 7.3458646d-05,-2.0851271d-05 /
      data fpp(19, 7,21,1),fpp(19, 7,21,2),fpp(19, 7,21,3)/
     x 8.0344735d-03, 7.3458646d-05,-2.1000655d-05 /
      data fpp(19, 7,22,1),fpp(19, 7,22,2),fpp(19, 7,22,3)/
     x 4.1702987d-03, 4.9720528d-05,-9.0775271d-06 /
      data fpp(19, 7,23,1),fpp(19, 7,23,2),fpp(19, 7,23,3)/
     x-3.8709319d-04, 2.5833123d-05,-3.5532364d-06 /
      data fpp(19, 8, 1,1),fpp(19, 8, 1,2),fpp(19, 8, 1,3)/
     x 5.0793544d-03, 8.9074997d-06,-3.1298946d-06 /
      data fpp(19, 8, 2,1),fpp(19, 8, 2,2),fpp(19, 8, 2,3)/
     x 6.4912274d-03, 2.2783163d-05,-3.5427108d-06 /
      data fpp(19, 8, 3,1),fpp(19, 8, 3,2),fpp(19, 8, 3,3)/
     x-3.9468661d-03, 3.3265075d-05,-4.4372623d-06 /
      data fpp(19, 8, 4,1),fpp(19, 8, 4,2),fpp(19, 8, 4,3)/
     x-3.9468661d-03, 3.3265075d-05,-4.4198576d-06 /
      data fpp(19, 8, 5,1),fpp(19, 8, 5,2),fpp(19, 8, 5,3)/
     x 6.4912274d-03, 2.2783163d-05,-3.6123295d-06 /
      data fpp(19, 8, 6,1),fpp(19, 8, 6,2),fpp(19, 8, 6,3)/
     x 5.0793544d-03, 8.9074997d-06,-2.8688242d-06 /
      data fpp(19, 8, 7,1),fpp(19, 8, 7,2),fpp(19, 8, 7,3)/
     x 3.2616310d-03,-4.1747767d-06,-2.2043737d-06 /
      data fpp(19, 8, 8,1),fpp(19, 8, 8,2),fpp(19, 8, 8,3)/
     x 1.1327759d-03,-1.4747582d-05,-1.2076812d-06 /
      data fpp(19, 8, 9,1),fpp(19, 8, 9,2),fpp(19, 8, 9,3)/
     x-1.1094561d-03,-2.2515540d-05, 4.3509828d-07 /
      data fpp(19, 8,10,1),fpp(19, 8,10,2),fpp(19, 8,10,3)/
     x-3.2581937d-03,-2.7613282d-05, 2.4132880d-06 /
      data fpp(19, 8,11,1),fpp(19, 8,11,2),fpp(19, 8,11,3)/
     x-5.0306828d-03,-3.0226473d-05, 4.1977496d-06 /
      data fpp(19, 8,12,1),fpp(19, 8,12,2),fpp(19, 8,12,3)/
     x-6.2186603d-03,-3.0603905d-05, 5.4617136d-06 /
      data fpp(19, 8,13,1),fpp(19, 8,13,2),fpp(19, 8,13,3)/
     x-6.6944347d-03,-2.8944630d-05, 6.0613959d-06 /
      data fpp(19, 8,14,1),fpp(19, 8,14,2),fpp(19, 8,14,3)/
     x-6.4067152d-03,-2.5205082d-05, 6.0887029d-06 /
      data fpp(19, 8,15,1),fpp(19, 8,15,2),fpp(19, 8,15,3)/
     x-5.4103658d-03,-1.9285883d-05, 5.6137925d-06 /
      data fpp(19, 8,16,1),fpp(19, 8,16,2),fpp(19, 8,16,3)/
     x-3.7473087d-03,-1.1295137d-05, 4.4021270d-06 /
      data fpp(19, 8,17,1),fpp(19, 8,17,2),fpp(19, 8,17,3)/
     x-1.5175099d-03,-1.4931063d-06, 2.2896994d-06 /
      data fpp(19, 8,18,1),fpp(19, 8,18,2),fpp(19, 8,18,3)/
     x 1.0113686d-03, 9.4498282d-06,-1.1289245d-06 /
      data fpp(19, 8,19,1),fpp(19, 8,19,2),fpp(19, 8,19,3)/
     x 3.5439194d-03, 1.9910715d-05,-5.1540012d-06 /
      data fpp(19, 8,20,1),fpp(19, 8,20,2),fpp(19, 8,20,3)/
     x 5.5103785d-03, 2.6957276d-05,-9.4130705d-06 /
      data fpp(19, 8,21,1),fpp(19, 8,21,2),fpp(19, 8,21,3)/
     x 5.5103785d-03, 2.6957276d-05,-9.5097878d-06 /
      data fpp(19, 8,22,1),fpp(19, 8,22,2),fpp(19, 8,22,3)/
     x 3.5439194d-03, 1.9910715d-05,-4.7671321d-06 /
      data fpp(19, 8,23,1),fpp(19, 8,23,2),fpp(19, 8,23,3)/
     x 1.0113686d-03, 9.4498282d-06,-2.5796840d-06 /
      data fpp(19, 9, 1,1),fpp(19, 9, 1,2),fpp(19, 9, 1,3)/
     x 6.0778929d-03,-1.6241353d-06, 2.3017455d-06 /
      data fpp(19, 9, 2,1),fpp(19, 9, 2,2),fpp(19, 9, 2,3)/
     x 6.7441439d-03, 8.6561040d-06, 9.4008967d-08 /
      data fpp(19, 9, 3,1),fpp(19, 9, 3,2),fpp(19, 9, 3,3)/
     x-4.3942189d-03, 2.0323637d-05,-4.5797814d-06 /
      data fpp(19, 9, 4,1),fpp(19, 9, 4,2),fpp(19, 9, 4,3)/
     x-4.3942189d-03, 2.0323637d-05,-4.6796603d-06 /
      data fpp(19, 9, 5,1),fpp(19, 9, 5,2),fpp(19, 9, 5,3)/
     x 6.7441439d-03, 8.6561040d-06, 4.9352477d-07 /
      data fpp(19, 9, 6,1),fpp(19, 9, 6,2),fpp(19, 9, 6,3)/
     x 6.0778929d-03,-1.6241353d-06, 8.0356127d-07 /
      data fpp(19, 9, 7,1),fpp(19, 9, 7,2),fpp(19, 9, 7,3)/
     x 5.3386435d-03,-8.5550810d-06,-5.2776985d-07 /
      data fpp(19, 9, 8,1),fpp(19, 9, 8,2),fpp(19, 9, 8,3)/
     x 4.2761296d-03,-1.3112528d-05,-1.6924819d-06 /
      data fpp(19, 9, 9,1),fpp(19, 9, 9,2),fpp(19, 9, 9,3)/
     x 2.8864772d-03,-1.6175990d-05,-1.3963027d-06 /
      data fpp(19, 9,10,1),fpp(19, 9,10,2),fpp(19, 9,10,3)/
     x 1.3298115d-03,-1.8133660d-05, 3.5692674d-08 /
      data fpp(19, 9,11,1),fpp(19, 9,11,2),fpp(19, 9,11,3)/
     x-1.6080598d-04,-1.9129536d-05, 1.6735320d-06 /
      data fpp(19, 9,12,1),fpp(19, 9,12,2),fpp(19, 9,12,3)/
     x-1.3741768d-03,-1.9147588d-05, 2.8941793d-06 /
      data fpp(19, 9,13,1),fpp(19, 9,13,2),fpp(19, 9,13,3)/
     x-2.0939878d-03,-1.8126261d-05, 3.5317508d-06 /
      data fpp(19, 9,14,1),fpp(19, 9,14,2),fpp(19, 9,14,3)/
     x-2.2382251d-03,-1.6004746d-05, 3.7268175d-06 /
      data fpp(19, 9,15,1),fpp(19, 9,15,2),fpp(19, 9,15,3)/
     x-1.7820577d-03,-1.2771179d-05, 3.5329793d-06 /
      data fpp(19, 9,16,1),fpp(19, 9,16,2),fpp(19, 9,16,3)/
     x-8.4761992d-04,-8.4316867d-06, 2.8292653d-06 /
      data fpp(19, 9,17,1),fpp(19, 9,17,2),fpp(19, 9,17,3)/
     x 5.1572408d-04,-3.1916498d-06, 1.5059594d-06 /
      data fpp(19, 9,18,1),fpp(19, 9,18,2),fpp(19, 9,18,3)/
     x 2.0667317d-03, 2.4455642d-06,-5.4910305d-07 /
      data fpp(19, 9,19,1),fpp(19, 9,19,2),fpp(19, 9,19,3)/
     x 3.6208271d-03, 7.7006123d-06,-2.8435472d-06 /
      data fpp(19, 9,20,1),fpp(19, 9,20,2),fpp(19, 9,20,3)/
     x 4.8405309d-03, 1.1618251d-05,-4.6727081d-06 /
      data fpp(19, 9,21,1),fpp(19, 9,21,2),fpp(19, 9,21,3)/
     x 4.8405309d-03, 1.1618251d-05,-4.7411022d-06 /
      data fpp(19, 9,22,1),fpp(19, 9,22,2),fpp(19, 9,22,3)/
     x 3.6208271d-03, 7.7006123d-06,-2.5699708d-06 /
      data fpp(19, 9,23,1),fpp(19, 9,23,2),fpp(19, 9,23,3)/
     x 2.0667317d-03, 2.4455642d-06,-1.5750146d-06 /
      data fpp(19,10, 1,1),fpp(19,10, 1,2),fpp(19,10, 1,3)/
     x 4.4142660d-03,-8.7229587d-06, 1.5629009d-05 /
      data fpp(19,10, 2,1),fpp(19,10, 2,2),fpp(19,10, 2,3)/
     x 5.5562818d-03,-2.1655791d-06, 6.1899819d-06 /
      data fpp(19,10, 3,1),fpp(19,10, 3,2),fpp(19,10, 3,3)/
     x 1.7870803d-02, 1.0954376d-05,-1.3736937d-05 /
      data fpp(19,10, 4,1),fpp(19,10, 4,2),fpp(19,10, 4,3)/
     x 1.7870803d-02, 1.0954376d-05,-1.4261181d-05 /
      data fpp(19,10, 5,1),fpp(19,10, 5,2),fpp(19,10, 5,3)/
     x 5.5562818d-03,-2.1655791d-06, 8.2869591d-06 /
      data fpp(19,10, 6,1),fpp(19,10, 6,2),fpp(19,10, 6,3)/
     x 4.4142660d-03,-8.7229587d-06, 7.7653445d-06 /
      data fpp(19,10, 7,1),fpp(19,10, 7,2),fpp(19,10, 7,3)/
     x 4.8598795d-03,-1.0396899d-05, 3.3776628d-06 /
      data fpp(19,10, 8,1),fpp(19,10, 8,2),fpp(19,10, 8,3)/
     x 5.1196728d-03,-1.0508308d-05,-8.1599587d-07 /
      data fpp(19,10, 9,1),fpp(19,10, 9,2),fpp(19,10, 9,3)/
     x 4.6893089d-03,-1.0592499d-05,-2.0936793d-06 /
      data fpp(19,10,10,1),fpp(19,10,10,2),fpp(19,10,10,3)/
     x 3.7340419d-03,-1.0822079d-05,-1.2912868d-06 /
      data fpp(19,10,11,1),fpp(19,10,11,2),fpp(19,10,11,3)/
     x 2.5915307d-03,-1.0975381d-05, 2.2082634d-07 /
      data fpp(19,10,12,1),fpp(19,10,12,2),fpp(19,10,12,3)/
     x 1.5233136d-03,-1.0831744d-05, 1.4339814d-06 /
      data fpp(19,10,13,1),fpp(19,10,13,2),fpp(19,10,13,3)/
     x 7.6507702d-04,-1.0204328d-05, 2.1792482d-06 /
      data fpp(19,10,14,1),fpp(19,10,14,2),fpp(19,10,14,3)/
     x 4.4081067d-04,-9.0439348d-06, 2.5630260d-06 /
      data fpp(19,10,15,1),fpp(19,10,15,2),fpp(19,10,15,3)/
     x 6.1157195d-04,-7.3714020d-06, 2.6226480d-06 /
      data fpp(19,10,16,1),fpp(19,10,16,2),fpp(19,10,16,3)/
     x 1.1908096d-03,-5.3421163d-06, 2.2283822d-06 /
      data fpp(19,10,17,1),fpp(19,10,17,2),fpp(19,10,17,3)/
     x 2.0632663d-03,-3.1522943d-06, 1.2378233d-06 /
      data fpp(19,10,18,1),fpp(19,10,18,2),fpp(19,10,18,3)/
     x 3.1382856d-03,-9.6208495d-07,-2.7367523d-07 /
      data fpp(19,10,19,1),fpp(19,10,19,2),fpp(19,10,19,3)/
     x 4.2622799d-03, 9.6483568d-07,-2.1051223d-06 /
      data fpp(19,10,20,1),fpp(19,10,20,2),fpp(19,10,20,3)/
     x 5.1764167d-03, 2.2657191d-06,-2.7298354d-06 /
      data fpp(19,10,21,1),fpp(19,10,21,2),fpp(19,10,21,3)/
     x 5.1764167d-03, 2.2657191d-06,-2.8029326d-06 /
      data fpp(19,10,22,1),fpp(19,10,22,2),fpp(19,10,22,3)/
     x 4.2622799d-03, 9.6483568d-07,-1.8127335d-06 /
      data fpp(19,10,23,1),fpp(19,10,23,2),fpp(19,10,23,3)/
     x 3.1382856d-03,-9.6208495d-07,-1.3701332d-06 /
      data fpp(19,11, 1,1),fpp(19,11, 1,2),fpp(19,11, 1,3)/
     x-2.3089186d-03,-2.8080301d-06, 4.2832589d-05 /
      data fpp(19,11, 2,1),fpp(19,11, 2,2),fpp(19,11, 2,3)/
     x-2.2217171d-03, 8.0421241d-07, 1.8637821d-05 /
      data fpp(19,11, 3,1),fpp(19,11, 3,2),fpp(19,11, 3,3)/
     x 2.3771725d-02, 6.6888570d-06,-3.2267875d-05 /
      data fpp(19,11, 4,1),fpp(19,11, 4,2),fpp(19,11, 4,3)/
     x 2.3771725d-02, 6.6888570d-06,-3.3913286d-05 /
      data fpp(19,11, 5,1),fpp(19,11, 5,2),fpp(19,11, 5,3)/
     x-2.2217171d-03, 8.0421241d-07, 2.5219465d-05 /
      data fpp(19,11, 6,1),fpp(19,11, 6,2),fpp(19,11, 6,3)/
     x-2.3089186d-03,-2.8080301d-06, 1.8151425d-05 /
      data fpp(19,11, 7,1),fpp(19,11, 7,2),fpp(19,11, 7,3)/
     x 7.7617915d-04,-4.8773226d-06, 8.8728343d-06 /
      data fpp(19,11, 8,1),fpp(19,11, 8,2),fpp(19,11, 8,3)/
     x 3.3696672d-03,-5.6642424d-06, 1.8323774d-07 /
      data fpp(19,11, 9,1),fpp(19,11, 9,2),fpp(19,11, 9,3)/
     x 4.5250700d-03,-5.9060135d-06,-2.7237852d-06 /
      data fpp(19,11,10,1),fpp(19,11,10,2),fpp(19,11,10,3)/
     x 4.4515488d-03,-6.0480226d-06,-2.3860968d-06 /
      data fpp(19,11,11,1),fpp(19,11,11,2),fpp(19,11,11,3)/
     x 3.8157910d-03,-6.0769388d-06,-8.4782758d-07 /
      data fpp(19,11,12,1),fpp(19,11,12,2),fpp(19,11,12,3)/
     x 3.0297679d-03,-5.9614366d-06, 5.1540710d-07 /
      data fpp(19,11,13,1),fpp(19,11,13,2),fpp(19,11,13,3)/
     x 2.3901921d-03,-5.6884282d-06, 1.4081992d-06 /
      data fpp(19,11,14,1),fpp(19,11,14,2),fpp(19,11,14,3)/
     x 2.0852632d-03,-5.2095149d-06, 1.9697962d-06 /
      data fpp(19,11,15,1),fpp(19,11,15,2),fpp(19,11,15,3)/
     x 2.1597612d-03,-4.5792131d-06, 2.1606159d-06 /
      data fpp(19,11,16,1),fpp(19,11,16,2),fpp(19,11,16,3)/
     x 2.5808442d-03,-3.8658480d-06, 1.8797403d-06 /
      data fpp(19,11,17,1),fpp(19,11,17,2),fpp(19,11,17,3)/
     x 3.2741893d-03,-3.1651728d-06, 1.0424230d-06 /
      data fpp(19,11,18,1),fpp(19,11,18,2),fpp(19,11,18,3)/
     x 4.1537539d-03,-2.5572244d-06,-2.3543239d-07 /
      data fpp(19,11,19,1),fpp(19,11,19,2),fpp(19,11,19,3)/
     x 5.0923106d-03,-1.9719550d-06,-1.9486935d-06 /
      data fpp(19,11,20,1),fpp(19,11,20,2),fpp(19,11,20,3)/
     x 5.8551268d-03,-1.2651279d-06,-1.9417937d-06 /
      data fpp(19,11,21,1),fpp(19,11,21,2),fpp(19,11,21,3)/
     x 5.8551268d-03,-1.2651279d-06,-2.0232722d-06 /
      data fpp(19,11,22,1),fpp(19,11,22,2),fpp(19,11,22,3)/
     x 5.0923106d-03,-1.9719550d-06,-1.6227794d-06 /
      data fpp(19,11,23,1),fpp(19,11,23,2),fpp(19,11,23,3)/
     x 4.1537539d-03,-2.5572244d-06,-1.4576103d-06 /
      data fpp(19,12, 1,1),fpp(19,12, 1,2),fpp(19,12, 1,3)/
     x-1.1313100d-02, 1.1849079d-05, 7.3100797d-05 /
      data fpp(19,12, 2,1),fpp(19,12, 2,2),fpp(19,12, 2,3)/
     x-9.4928721d-03, 1.0996729d-05, 3.2148905d-05 /
      data fpp(19,12, 3,1),fpp(19,12, 3,2),fpp(19,12, 3,3)/
     x 6.5865396d-02,-1.3258045d-06,-5.3934419d-05 /
      data fpp(19,12, 4,1),fpp(19,12, 4,2),fpp(19,12, 4,3)/
     x 6.5865396d-02,-1.3258045d-06,-5.6858197d-05 /
      data fpp(19,12, 5,1),fpp(19,12, 5,2),fpp(19,12, 5,3)/
     x-9.4928721d-03, 1.0996729d-05, 4.3844017d-05 /
      data fpp(19,12, 6,1),fpp(19,12, 6,2),fpp(19,12, 6,3)/
     x-1.1313100d-02, 1.1849079d-05, 2.9244129d-05 /
      data fpp(19,12, 7,1),fpp(19,12, 7,2),fpp(19,12, 7,3)/
     x-5.3378461d-03, 7.4661893d-06, 1.5669469d-05 /
      data fpp(19,12, 8,1),fpp(19,12, 8,2),fpp(19,12, 8,3)/
     x-1.3992796d-04, 2.8592770d-06, 1.7379958d-06 /
      data fpp(19,12, 9,1),fpp(19,12, 9,2),fpp(19,12, 9,3)/
     x 2.9576697d-03,-2.1144693d-07,-3.1334523d-06 /
      data fpp(19,12,10,1),fpp(19,12,10,2),fpp(19,12,10,3)/
     x 4.0945811d-03,-1.8618303d-06,-3.2441866d-06 /
      data fpp(19,12,11,1),fpp(19,12,11,2),fpp(19,12,11,3)/
     x 4.0717365d-03,-2.6488636d-06,-1.6918012d-06 /
      data fpp(19,12,12,1),fpp(19,12,12,2),fpp(19,12,12,3)/
     x 3.6380169d-03,-2.9605096d-06,-1.8860861d-07 /
      data fpp(19,12,13,1),fpp(19,12,13,2),fpp(19,12,13,3)/
     x 3.2295078d-03,-3.0479595d-06, 8.9223564d-07 /
      data fpp(19,12,14,1),fpp(19,12,14,2),fpp(19,12,14,3)/
     x 3.0355247d-03,-3.0700057d-06, 1.5636660d-06 /
      data fpp(19,12,15,1),fpp(19,12,15,2),fpp(19,12,15,3)/
     x 3.1290263d-03,-3.0937454d-06, 1.8111002d-06 /
      data fpp(19,12,16,1),fpp(19,12,16,2),fpp(19,12,16,3)/
     x 3.4951808d-03,-3.1584916d-06, 1.5419331d-06 /
      data fpp(19,12,17,1),fpp(19,12,17,2),fpp(19,12,17,3)/
     x 4.1116770d-03,-3.2430146d-06, 7.8116722d-07 /
      data fpp(19,12,18,1),fpp(19,12,18,2),fpp(19,12,18,3)/
     x 4.9106608d-03,-3.3110176d-06,-2.9860202d-07 /
      data fpp(19,12,19,1),fpp(19,12,19,2),fpp(19,12,19,3)/
     x 5.7008597d-03,-3.3550155d-06,-1.6507591d-06 /
      data fpp(19,12,20,1),fpp(19,12,20,2),fpp(19,12,20,3)/
     x 6.3039132d-03,-3.3372077d-06,-1.6963615d-06 /
      data fpp(19,12,21,1),fpp(19,12,21,2),fpp(19,12,21,3)/
     x 6.3039132d-03,-3.3372077d-06,-1.7595360d-06 /
      data fpp(19,12,22,1),fpp(19,12,22,2),fpp(19,12,22,3)/
     x 5.7008597d-03,-3.3550155d-06,-1.3980611d-06 /
      data fpp(19,12,23,1),fpp(19,12,23,2),fpp(19,12,23,3)/
     x 4.9106608d-03,-3.3110176d-06,-1.2462194d-06 /
      data fpp(19,13, 1,1),fpp(19,13, 1,2),fpp(19,13, 1,3)/
     x-1.6574607d-02, 1.2405714d-05, 8.2473811d-05 /
      data fpp(19,13, 2,1),fpp(19,13, 2,2),fpp(19,13, 2,3)/
     x-1.2036001d-02,-2.2211302d-06, 3.4721378d-05 /
      data fpp(19,13, 3,1),fpp(19,13, 3,2),fpp(19,13, 3,3)/
     x 3.9921479d-02,-2.8139639d-05,-6.5851322d-05 /
      data fpp(19,13, 4,1),fpp(19,13, 4,2),fpp(19,13, 4,3)/
     x 3.9921479d-02,-2.8139639d-05,-6.8920722d-05 /
      data fpp(19,13, 5,1),fpp(19,13, 5,2),fpp(19,13, 5,3)/
     x-1.2036001d-02,-2.2211302d-06, 4.6998977d-05 /
      data fpp(19,13, 6,1),fpp(19,13, 6,2),fpp(19,13, 6,3)/
     x-1.6574607d-02, 1.2405714d-05, 3.6432815d-05 /
      data fpp(19,13, 7,1),fpp(19,13, 7,2),fpp(19,13, 7,3)/
     x-1.0224755d-02, 1.4516565d-05, 2.1637763d-05 /
      data fpp(19,13, 8,1),fpp(19,13, 8,2),fpp(19,13, 8,3)/
     x-3.5859687d-03, 1.0397134d-05, 4.6661315d-06 /
      data fpp(19,13, 9,1),fpp(19,13, 9,2),fpp(19,13, 9,3)/
     x 9.5525457d-04, 5.5098012d-06,-2.2862893d-06 /
      data fpp(19,13,10,1),fpp(19,13,10,2),fpp(19,13,10,3)/
     x 3.1610260d-03, 2.0653437d-06,-3.2789744d-06 /
      data fpp(19,13,11,1),fpp(19,13,11,2),fpp(19,13,11,3)/
     x 3.7605728d-03, 8.8393031d-08,-2.0518133d-06 /
      data fpp(19,13,12,1),fpp(19,13,12,2),fpp(19,13,12,3)/
     x 3.6897291d-03,-9.2852489d-07,-6.4577254d-07 /
      data fpp(19,13,13,1),fpp(19,13,13,2),fpp(19,13,13,3)/
     x 3.5186015d-03,-1.4337338d-06, 4.7090342d-07 /
      data fpp(19,13,14,1),fpp(19,13,14,2),fpp(19,13,14,3)/
     x 3.4798684d-03,-1.7584624d-06, 1.1801588d-06 /
      data fpp(19,13,15,1),fpp(19,13,15,2),fpp(19,13,15,3)/
     x 3.6366799d-03,-2.0718052d-06, 1.4324612d-06 /
      data fpp(19,13,16,1),fpp(19,13,16,2),fpp(19,13,16,3)/
     x 3.9953619d-03,-2.4181856d-06, 1.1839963d-06 /
      data fpp(19,13,17,1),fpp(19,13,17,2),fpp(19,13,17,3)/
     x 4.5532178d-03,-2.7747688d-06, 5.2755341d-07 /
      data fpp(19,13,18,1),fpp(19,13,18,2),fpp(19,13,18,3)/
     x 5.2490124d-03,-3.0927053d-06,-3.6020999d-07 /
      data fpp(19,13,19,1),fpp(19,13,19,2),fpp(19,13,19,3)/
     x 5.9048482d-03,-3.3879830d-06,-1.2707135d-06 /
      data fpp(19,13,20,1),fpp(19,13,20,2),fpp(19,13,20,3)/
     x 6.3780821d-03,-3.7820413d-06,-1.5109361d-06 /
      data fpp(19,13,21,1),fpp(19,13,21,2),fpp(19,13,21,3)/
     x 6.3780821d-03,-3.7820413d-06,-1.5488349d-06 /
      data fpp(19,13,22,1),fpp(19,13,22,2),fpp(19,13,22,3)/
     x 5.9048482d-03,-3.3879830d-06,-1.1191186d-06 /
      data fpp(19,13,23,1),fpp(19,13,23,2),fpp(19,13,23,3)/
     x 5.2490124d-03,-3.0927053d-06,-9.2869069d-07 /
      data fpp(19,14, 1,1),fpp(19,14, 1,2),fpp(19,14, 1,3)/
     x-1.6638056d-02, 3.0820632d-06, 6.4141904d-05 /
      data fpp(19,14, 2,1),fpp(19,14, 2,2),fpp(19,14, 2,3)/
     x-6.3701461d-03,-1.4538209d-05, 2.4494191d-05 /
      data fpp(19,14, 3,1),fpp(19,14, 3,2),fpp(19,14, 3,3)/
     x 4.9570501d-02,-3.5935639d-05,-5.9278669d-05 /
      data fpp(19,14, 4,1),fpp(19,14, 4,2),fpp(19,14, 4,3)/
     x 4.9570501d-02,-3.5935639d-05,-6.1355090d-05 /
      data fpp(19,14, 5,1),fpp(19,14, 5,2),fpp(19,14, 5,3)/
     x-6.3701461d-03,-1.4538209d-05, 3.2799877d-05 /
      data fpp(19,14, 6,1),fpp(19,14, 6,2),fpp(19,14, 6,3)/
     x-1.6638056d-02, 3.0820632d-06, 3.2995583d-05 /
      data fpp(19,14, 7,1),fpp(19,14, 7,2),fpp(19,14, 7,3)/
     x-1.1828801d-02, 1.0673549d-05, 2.2135792d-05 /
      data fpp(19,14, 8,1),fpp(19,14, 8,2),fpp(19,14, 8,3)/
     x-5.2359459d-03, 1.0740186d-05, 7.4312477d-06 /
      data fpp(19,14, 9,1),fpp(19,14, 9,2),fpp(19,14, 9,3)/
     x-3.6207747d-04, 7.6862420d-06, 2.7216659d-08 /
      data fpp(19,14,10,1),fpp(19,14,10,2),fpp(19,14,10,3)/
     x 2.2978213d-03, 4.4664557d-06,-1.9901144d-06 /
      data fpp(19,14,11,1),fpp(19,14,11,2),fpp(19,14,11,3)/
     x 3.3000531d-03, 2.1212914d-06,-1.5647592d-06 /
      data fpp(19,14,12,1),fpp(19,14,12,2),fpp(19,14,12,3)/
     x 3.4944472d-03, 6.3860919d-07,-6.3684898d-07 /
      data fpp(19,14,13,1),fpp(19,14,13,2),fpp(19,14,13,3)/
     x 3.4894447d-03,-2.4110538d-07, 2.1215507d-07 /
      data fpp(19,14,14,1),fpp(19,14,14,2),fpp(19,14,14,3)/
     x 3.5631200d-03,-7.8014480d-07, 8.0822868d-07 /
      data fpp(19,14,15,1),fpp(19,14,15,2),fpp(19,14,15,3)/
     x 3.7657608d-03,-1.1890337d-06, 1.0189302d-06 /
      data fpp(19,14,16,1),fpp(19,14,16,2),fpp(19,14,16,3)/
     x 4.0876572d-03,-1.5567660d-06, 8.2205056d-07 /
      data fpp(19,14,17,1),fpp(19,14,17,2),fpp(19,14,17,3)/
     x 4.5655567d-03,-1.8699102d-06, 3.1886758d-07 /
      data fpp(19,14,18,1),fpp(19,14,18,2),fpp(19,14,18,3)/
     x 5.1246440d-03,-2.1081611d-06,-3.5152086d-07 /
      data fpp(19,14,19,1),fpp(19,14,19,2),fpp(19,14,19,3)/
     x 5.6548887d-03,-2.2450527d-06,-1.0007841d-06 /
      data fpp(19,14,20,1),fpp(19,14,20,2),fpp(19,14,20,3)/
     x 6.0370275d-03,-2.2106270d-06,-1.1173426d-06 /
      data fpp(19,14,21,1),fpp(19,14,21,2),fpp(19,14,21,3)/
     x 6.0370275d-03,-2.2106270d-06,-1.1455801d-06 /
      data fpp(19,14,22,1),fpp(19,14,22,2),fpp(19,14,22,3)/
     x 5.6548887d-03,-2.2450527d-06,-8.8783426d-07 /
      data fpp(19,14,23,1),fpp(19,14,23,2),fpp(19,14,23,3)/
     x 5.1246440d-03,-2.1081611d-06,-7.7508287d-07 /
      data fpp(19,15, 1,1),fpp(19,15, 1,2),fpp(19,15, 1,3)/
     x-7.9953214d-03,-1.0225967d-05, 3.1471956d-05 /
      data fpp(19,15, 2,1),fpp(19,15, 2,2),fpp(19,15, 2,3)/
     x 1.4845386d-02,-1.6762035d-05, 9.1725885d-06 /
      data fpp(19,15, 3,1),fpp(19,15, 3,2),fpp(19,15, 3,3)/
     x 9.3825518d-02,-1.7075804d-05,-3.8168310d-05 /
      data fpp(19,15, 4,1),fpp(19,15, 4,2),fpp(19,15, 4,3)/
     x 9.3825518d-02,-1.7075804d-05,-3.8944365d-05 /
      data fpp(19,15, 5,1),fpp(19,15, 5,2),fpp(19,15, 5,3)/
     x 1.4845386d-02,-1.6762035d-05, 1.2276809d-05 /
      data fpp(19,15, 6,1),fpp(19,15, 6,2),fpp(19,15, 6,3)/
     x-7.9953214d-03,-1.0225967d-05, 1.9831128d-05 /
      data fpp(19,15, 7,1),fpp(19,15, 7,2),fpp(19,15, 7,3)/
     x-7.7415554d-03,-2.9467633d-06, 1.5978681d-05 /
      data fpp(19,15, 8,1),fpp(19,15, 8,2),fpp(19,15, 8,3)/
     x-3.5792686d-03, 1.9081214d-06, 7.7901502d-06 /
      data fpp(19,15, 9,1),fpp(19,15, 9,2),fpp(19,15, 9,3)/
     x-1.3662862d-05, 3.8192307d-06, 2.4267186d-06 /
      data fpp(19,15,10,1),fpp(19,15,10,2),fpp(19,15,10,3)/
     x 2.1112555d-03, 3.7148337d-06, 1.2497521d-07 /
      data fpp(19,15,11,1),fpp(19,15,11,2),fpp(19,15,11,3)/
     x 3.0503250d-03, 2.7784412d-06,-3.3461947d-07 /
      data fpp(19,15,12,1),fpp(19,15,12,2),fpp(19,15,12,3)/
     x 3.3214896d-03, 1.7460881d-06,-1.1249732d-07 /
      data fpp(19,15,13,1),fpp(19,15,13,2),fpp(19,15,13,3)/
     x 3.3720850d-03, 8.8615531d-07, 2.4460873d-07 /
      data fpp(19,15,14,1),fpp(19,15,14,2),fpp(19,15,14,3)/
     x 3.4526979d-03, 2.7104156d-07, 5.4406238d-07 /
      data fpp(19,15,15,1),fpp(19,15,15,2),fpp(19,15,15,3)/
     x 3.6286873d-03,-1.1406003d-07, 6.4514174d-07 /
      data fpp(19,15,16,1),fpp(19,15,16,2),fpp(19,15,16,3)/
     x 3.8989135d-03,-3.1275056d-07, 5.1137067d-07 /
      data fpp(19,15,17,1),fpp(19,15,17,2),fpp(19,15,17,3)/
     x 4.2462383d-03,-4.0159036d-07, 1.8337558d-07 /
      data fpp(19,15,18,1),fpp(19,15,18,2),fpp(19,15,18,3)/
     x 4.6168810d-03,-4.0265020d-07,-2.6087300d-07 /
      data fpp(19,15,19,1),fpp(19,15,19,2),fpp(19,15,19,3)/
     x 4.9806126d-03,-3.1580633d-07,-6.1588357d-07 /
      data fpp(19,15,20,1),fpp(19,15,20,2),fpp(19,15,20,3)/
     x 5.2375432d-03,-2.6345078d-07,-7.1359272d-07 /
      data fpp(19,15,21,1),fpp(19,15,21,2),fpp(19,15,21,3)/
     x 5.2375432d-03,-2.6345078d-07,-7.2828005d-07 /
      data fpp(19,15,22,1),fpp(19,15,22,2),fpp(19,15,22,3)/
     x 4.9806126d-03,-3.1580633d-07,-5.5713427d-07 /
      data fpp(19,15,23,1),fpp(19,15,23,2),fpp(19,15,23,3)/
     x 4.6168810d-03,-4.0265020d-07,-4.8118286d-07 /
      data fpp(19,16, 1,1),fpp(19,16, 1,2),fpp(19,16, 1,3)/
     x 7.2379725d-04,-2.0762194d-05, 6.7388511d-06 /
      data fpp(19,16, 2,1),fpp(19,16, 2,2),fpp(19,16, 2,3)/
     x-4.1997057d-04,-1.4293650d-05,-7.2220215d-07 /
      data fpp(19,16, 3,1),fpp(19,16, 3,2),fpp(19,16, 3,3)/
     x 3.7720714d-02, 1.0808546d-06,-1.6684042d-05 /
      data fpp(19,16, 4,1),fpp(19,16, 4,2),fpp(19,16, 4,3)/
     x 3.7720714d-02, 1.0808546d-06,-1.6729772d-05 /
      data fpp(19,16, 5,1),fpp(19,16, 5,2),fpp(19,16, 5,3)/
     x-4.1997057d-04,-1.4293650d-05,-5.3928593d-07 /
      data fpp(19,16, 6,1),fpp(19,16, 6,2),fpp(19,16, 6,3)/
     x 7.2379725d-04,-2.0762194d-05, 6.0529152d-06 /
      data fpp(19,16, 7,1),fpp(19,16, 7,2),fpp(19,16, 7,3)/
     x 6.3940017d-04,-1.7426496d-05, 7.3176250d-06 /
      data fpp(19,16, 8,1),fpp(19,16, 8,2),fpp(19,16, 8,3)/
     x 1.1102441d-03,-1.0362672d-05, 5.2845848d-06 /
      data fpp(19,16, 9,1),fpp(19,16, 9,2),fpp(19,16, 9,3)/
     x 3.2856409d-03,-4.1351649d-06, 3.0560357d-06 /
      data fpp(19,16,10,1),fpp(19,16,10,2),fpp(19,16,10,3)/
     x 2.8664046d-03,-3.0579048d-07, 1.5592724d-06 /
      data fpp(19,16,11,1),fpp(19,16,11,2),fpp(19,16,11,3)/
     x 3.2631289d-03, 1.4169436d-06, 8.2887482d-07 /
      data fpp(19,16,12,1),fpp(19,16,12,2),fpp(19,16,12,3)/
     x 3.3734392d-03, 1.8570382d-06, 5.5522836d-07 /
      data fpp(19,16,13,1),fpp(19,16,13,2),fpp(19,16,13,3)/
     x 3.3660536d-03, 1.7184841d-06, 4.8421176d-07 /
      data fpp(19,16,14,1),fpp(19,16,14,2),fpp(19,16,14,3)/
     x 3.3661084d-03, 1.4239786d-06, 4.7192462d-07 /
      data fpp(19,16,15,1),fpp(19,16,15,2),fpp(19,16,15,3)/
     x 3.4408688d-03, 1.2192738d-06, 4.3608978d-07 /
      data fpp(19,16,16,1),fpp(19,16,16,2),fpp(19,16,16,3)/
     x 3.5703320d-03, 1.1877682d-06, 3.0971627d-07 /
      data fpp(19,16,17,1),fpp(19,16,17,2),fpp(19,16,17,3)/
     x 3.7612900d-03, 1.3462716d-06, 1.3104514d-07 /
      data fpp(19,16,18,1),fpp(19,16,18,2),fpp(19,16,18,3)/
     x 3.9731172d-03, 1.6067619d-06,-8.3896847d-08 /
      data fpp(19,16,19,1),fpp(19,16,19,2),fpp(19,16,19,3)/
     x 4.1544297d-03, 1.8162780d-06,-2.5745776d-07 /
      data fpp(19,16,20,1),fpp(19,16,20,2),fpp(19,16,20,3)/
     x 4.2886666d-03, 1.9324301d-06,-3.5027212d-07 /
      data fpp(19,16,21,1),fpp(19,16,21,2),fpp(19,16,21,3)/
     x 4.2886666d-03, 1.9324301d-06,-3.5645476d-07 /
      data fpp(19,16,22,1),fpp(19,16,22,2),fpp(19,16,22,3)/
     x 4.1544297d-03, 1.8162780d-06,-2.3272721d-07 /
      data fpp(19,16,23,1),fpp(19,16,23,2),fpp(19,16,23,3)/
     x 3.9731172d-03, 1.6067619d-06,-1.7663639d-07 /
      data fpp(19,17, 1,1),fpp(19,17, 1,2),fpp(19,17, 1,3)/
     x-1.6329191d-03,-6.8832554d-06,-5.7823922d-07 /
      data fpp(19,17, 2,1),fpp(19,17, 2,2),fpp(19,17, 2,3)/
     x 9.1998348d-03, 2.7046366d-06,-1.9795216d-06 /
      data fpp(19,17, 3,1),fpp(19,17, 3,2),fpp(19,17, 3,3)/
     x 1.9374448d-02, 1.2608385d-05,-5.0036745d-06 /
      data fpp(19,17, 4,1),fpp(19,17, 4,2),fpp(19,17, 4,3)/
     x 1.9374448d-02, 1.2608385d-05,-4.9662156d-06 /
      data fpp(19,17, 5,1),fpp(19,17, 5,2),fpp(19,17, 5,3)/
     x 9.1998348d-03, 2.7046366d-06,-2.1293571d-06 /
      data fpp(19,17, 6,1),fpp(19,17, 6,2),fpp(19,17, 6,3)/
     x-1.6329191d-03,-6.8832554d-06,-1.6355819d-08 /
      data fpp(19,17, 7,1),fpp(19,17, 7,2),fpp(19,17, 7,3)/
     x 5.7183307d-03,-1.1665251d-05, 1.3607804d-06 /
      data fpp(19,17, 8,1),fpp(19,17, 8,2),fpp(19,17, 8,3)/
     x 4.6883415d-03,-1.1439435d-05, 1.7492342d-06 /
      data fpp(19,17, 9,1),fpp(19,17, 9,2),fpp(19,17, 9,3)/
     x 4.2933467d-03,-8.4045710d-06, 1.6202829d-06 /
      data fpp(19,17,10,1),fpp(19,17,10,2),fpp(19,17,10,3)/
     x 4.0359266d-03,-4.7476718d-06, 1.2976342d-06 /
      data fpp(19,17,11,1),fpp(19,17,11,2),fpp(19,17,11,3)/
     x 3.8605885d-03,-1.6842156d-06, 9.8918034d-07 /
      data fpp(19,17,12,1),fpp(19,17,12,2),fpp(19,17,12,3)/
     x 3.7185620d-03, 4.3775894d-07, 7.6364446d-07 /
      data fpp(19,17,13,1),fpp(19,17,13,2),fpp(19,17,13,3)/
     x 3.5769863d-03, 1.7259081d-06, 5.8824182d-07 /
      data fpp(19,17,14,1),fpp(19,17,14,2),fpp(19,17,14,3)/
     x 3.4850513d-03, 2.4630442d-06, 4.7138825d-07 /
      data fpp(19,17,15,1),fpp(19,17,15,2),fpp(19,17,15,3)/
     x 3.4285402d-03, 2.8989647d-06, 3.6420517d-07 /
      data fpp(19,17,16,1),fpp(19,17,16,2),fpp(19,17,16,3)/
     x 3.4178240d-03, 3.2296778d-06, 2.6179106d-07 /
      data fpp(19,17,17,1),fpp(19,17,17,2),fpp(19,17,17,3)/
     x 3.4499944d-03, 3.5305038d-06, 1.6663059d-07 /
      data fpp(19,17,18,1),fpp(19,17,18,2),fpp(19,17,18,3)/
     x 3.4968340d-03, 3.8096026d-06, 6.1686584d-08 /
      data fpp(19,17,19,1),fpp(19,17,19,2),fpp(19,17,19,3)/
     x 3.5398266d-03, 4.0666944d-06, 6.2307446d-10 /
      data fpp(19,17,20,1),fpp(19,17,20,2),fpp(19,17,20,3)/
     x 3.5741196d-03, 4.2277304d-06,-5.8178882d-08 /
      data fpp(19,17,21,1),fpp(19,17,21,2),fpp(19,17,21,3)/
     x 3.5741196d-03, 4.2277304d-06,-5.9774891d-08 /
      data fpp(19,17,22,1),fpp(19,17,22,2),fpp(19,17,22,3)/
     x 3.5398266d-03, 4.0666944d-06, 7.0071118d-09 /
      data fpp(19,17,23,1),fpp(19,17,23,2),fpp(19,17,23,3)/
     x 3.4968340d-03, 3.8096026d-06, 3.7746444d-08 /
      data fpp(19,18, 1,1),fpp(19,18, 1,2),fpp(19,18, 1,3)/
     x 6.0089292d-03, 3.2832158d-06,-5.7593378d-07 /
      data fpp(19,18, 2,1),fpp(19,18, 2,2),fpp(19,18, 2,3)/
     x 6.3727779d-03, 7.7771038d-06,-7.0813243d-07 /
      data fpp(19,18, 3,1),fpp(19,18, 3,2),fpp(19,18, 3,3)/
     x 6.6432108d-03, 1.1863604d-05,-9.9553648d-07 /
      data fpp(19,18, 4,1),fpp(19,18, 4,2),fpp(19,18, 4,3)/
     x 6.6432108d-03, 1.1863604d-05,-9.8832435d-07 /
      data fpp(19,18, 5,1),fpp(19,18, 5,2),fpp(19,18, 5,3)/
     x 6.3727779d-03, 7.7771038d-06,-7.3698095d-07 /
      data fpp(19,18, 6,1),fpp(19,18, 6,2),fpp(19,18, 6,3)/
     x 6.0089292d-03, 3.2832158d-06,-4.6775184d-07 /
      data fpp(19,18, 7,1),fpp(19,18, 7,2),fpp(19,18, 7,3)/
     x 5.6424061d-03,-3.7049973d-07,-1.8201167d-07 /
      data fpp(19,18, 8,1),fpp(19,18, 8,2),fpp(19,18, 8,3)/
     x 5.2664302d-03,-2.6795901d-06, 4.3798543d-08 /
      data fpp(19,18, 9,1),fpp(19,18, 9,2),fpp(19,18, 9,3)/
     x 4.9258788d-03,-3.6345511d-06, 2.0481750d-07 /
      data fpp(19,18,10,1),fpp(19,18,10,2),fpp(19,18,10,3)/
     x 4.6321773d-03,-3.5095223d-06, 2.9493145d-07 /
      data fpp(19,18,11,1),fpp(19,18,11,2),fpp(19,18,11,3)/
     x 4.3845954d-03,-2.6660813d-06, 3.3145670d-07 /
      data fpp(19,18,12,1),fpp(19,18,12,2),fpp(19,18,12,3)/
     x 4.1787876d-03,-1.4240740d-06, 3.3524174d-07 /
      data fpp(19,18,13,1),fpp(19,18,13,2),fpp(19,18,13,3)/
     x 4.0057420d-03,-1.2116604d-08, 3.1357635d-07 /
      data fpp(19,18,14,1),fpp(19,18,14,2),fpp(19,18,14,3)/
     x 3.8645164d-03, 1.4198445d-06, 2.8245288d-07 /
      data fpp(19,18,15,1),fpp(19,18,15,2),fpp(19,18,15,3)/
     x 3.7587842d-03, 2.7908672d-06, 2.4861214d-07 /
      data fpp(19,18,16,1),fpp(19,18,16,2),fpp(19,18,16,3)/
     x 3.6725204d-03, 4.0435206d-06, 2.1109855d-07 /
      data fpp(19,18,17,1),fpp(19,18,17,2),fpp(19,18,17,3)/
     x 3.6093299d-03, 5.1417132d-06, 1.7299365d-07 /
      data fpp(19,18,18,1),fpp(19,18,18,2),fpp(19,18,18,3)/
     x 3.5653874d-03, 6.0508278d-06, 1.5292687d-07 /
      data fpp(19,18,19,1),fpp(19,18,19,2),fpp(19,18,19,3)/
     x 3.5282958d-03, 6.7149445d-06, 1.2129889d-07 /
      data fpp(19,18,20,1),fpp(19,18,20,2),fpp(19,18,20,3)/
     x 3.5254645d-03, 7.1246485d-06, 1.0587757d-07 /
      data fpp(19,18,21,1),fpp(19,18,21,2),fpp(19,18,21,3)/
     x 3.5254645d-03, 7.1246485d-06, 1.0471785d-07 /
      data fpp(19,18,22,1),fpp(19,18,22,2),fpp(19,18,22,3)/
     x 3.5282958d-03, 6.7149445d-06, 1.2593776d-07 /
      data fpp(19,18,23,1),fpp(19,18,23,2),fpp(19,18,23,3)/
     x 3.5653874d-03, 6.0508278d-06, 1.3553112d-07 /
      data fpp(19,19, 1,1),fpp(19,19, 1,2),fpp(19,19, 1,3)/
     x 4.3999121d-03, 1.4510392d-05,-1.5183606d-21 /
      data fpp(19,19, 2,1),fpp(19,19, 2,2),fpp(19,19, 2,3)/
     x 4.3999121d-03, 1.6256948d-05,-5.1285692d-22 /
      data fpp(19,19, 3,1),fpp(19,19, 3,2),fpp(19,19, 3,3)/
     x 4.3999121d-03, 1.4625198d-05,-1.3823385d-21 /
      data fpp(19,19, 4,1),fpp(19,19, 4,2),fpp(19,19, 4,3)/
     x 4.3999121d-03, 1.4625198d-05, 2.8909503d-21 /
      data fpp(19,19, 5,1),fpp(19,19, 5,2),fpp(19,19, 5,3)/
     x 4.3999121d-03, 1.6256948d-05, 1.1447395d-21 /
      data fpp(19,19, 6,1),fpp(19,19, 6,2),fpp(19,19, 6,3)/
     x 4.3999121d-03, 1.4510392d-05,-2.7576248d-21 /
      data fpp(19,19, 7,1),fpp(19,19, 7,2),fpp(19,19, 7,3)/
     x 4.3999121d-03, 9.3432499d-06,-5.9693822d-21 /
      data fpp(19,19, 8,1),fpp(19,19, 8,2),fpp(19,19, 8,3)/
     x 4.3999121d-03, 3.2697951d-06,-1.3118614d-21 /
      data fpp(19,19, 9,1),fpp(19,19, 9,2),fpp(19,19, 9,3)/
     x 4.3999121d-03,-1.4472244d-06,-9.2640017d-22 /
      data fpp(19,19,10,1),fpp(19,19,10,2),fpp(19,19,10,3)/
     x 4.3999121d-03,-3.8942388d-06, 5.7235243d-21 /
      data fpp(19,19,11,1),fpp(19,19,11,2),fpp(19,19,11,3)/
     x 4.3999121d-03,-4.2534594d-06,-4.8786245d-21 /
      data fpp(19,19,12,1),fpp(19,19,12,2),fpp(19,19,12,3)/
     x 4.3999121d-03,-3.1594630d-06, 3.7154687d-21 /
      data fpp(19,19,13,1),fpp(19,19,13,2),fpp(19,19,13,3)/
     x 4.3999121d-03,-1.2514417d-06, 2.1627402d-21 /
      data fpp(19,19,14,1),fpp(19,19,14,2),fpp(19,19,14,3)/
     x 4.3999121d-03, 9.7157775d-07,-2.6810281d-24 /
      data fpp(19,19,15,1),fpp(19,19,15,2),fpp(19,19,15,3)/
     x 4.3999121d-03, 3.1935664d-06, 1.0784997d-22 /
      data fpp(19,19,16,1),fpp(19,19,16,2),fpp(19,19,16,3)/
     x 4.3999121d-03, 5.2082397d-06,-1.1141555d-21 /
      data fpp(19,19,17,1),fpp(19,19,17,2),fpp(19,19,17,3)/
     x 4.3999121d-03, 6.9166434d-06, 5.3004023d-21 /
      data fpp(19,19,18,1),fpp(19,19,18,2),fpp(19,19,18,3)/
     x 4.3999121d-03, 8.2810861d-06,-2.5655621d-21 /
      data fpp(19,19,19,1),fpp(19,19,19,2),fpp(19,19,19,3)/
     x 4.3999121d-03, 9.2495278d-06,-2.3014118d-21 /
      data fpp(19,19,20,1),fpp(19,19,20,2),fpp(19,19,20,3)/
     x 4.3999121d-03, 9.8496758d-06, 1.7705300d-21 /
      data fpp(19,19,21,1),fpp(19,19,21,2),fpp(19,19,21,3)/
     x 4.3999121d-03, 9.8496758d-06,-3.8282238d-21 /
      data fpp(19,19,22,1),fpp(19,19,22,2),fpp(19,19,22,3)/
     x 4.3999121d-03, 9.2495278d-06, 3.5019492d-21 /
      data fpp(19,19,23,1),fpp(19,19,23,2),fpp(19,19,23,3)/
     x 4.3999121d-03, 8.2810861d-06, 9.9827340d-21 /
      data fpp(20, 1, 1,1),fpp(20, 1, 1,2),fpp(20, 1, 1,3)/
     x-3.5115960d-01,-7.7220246d-05, 3.7352818d-19 /
      data fpp(20, 1, 2,1),fpp(20, 1, 2,2),fpp(20, 1, 2,3)/
     x-3.5115960d-01,-6.2056652d-06,-4.0049220d-20 /
      data fpp(20, 1, 3,1),fpp(20, 1, 3,2),fpp(20, 1, 3,3)/
     x-3.5115960d-01, 1.1687276d-04,-2.1560088d-19 /
      data fpp(20, 1, 4,1),fpp(20, 1, 4,2),fpp(20, 1, 4,3)/
     x-3.5115960d-01, 1.1687276d-04, 1.5357288d-19 /
      data fpp(20, 1, 5,1),fpp(20, 1, 5,2),fpp(20, 1, 5,3)/
     x-3.5115960d-01,-6.2056652d-06, 6.6702820d-20 /
      data fpp(20, 1, 6,1),fpp(20, 1, 6,2),fpp(20, 1, 6,3)/
     x-3.5115960d-01,-7.7220246d-05,-1.3281900d-19 /
      data fpp(20, 1, 7,1),fpp(20, 1, 7,2),fpp(20, 1, 7,3)/
     x-3.5115960d-01,-1.2052468d-04,-2.3326491d-19 /
      data fpp(20, 1, 8,1),fpp(20, 1, 8,2),fpp(20, 1, 8,3)/
     x-3.5115960d-01,-1.4596027d-04,-1.4630994d-20 /
      data fpp(20, 1, 9,1),fpp(20, 1, 9,2),fpp(20, 1, 9,3)/
     x-3.5115960d-01,-1.5977005d-04, 1.1657332d-20 /
      data fpp(20, 1,10,1),fpp(20, 1,10,2),fpp(20, 1,10,3)/
     x-3.5115960d-01,-1.6656734d-04, 2.7056488d-19 /
      data fpp(20, 1,11,1),fpp(20, 1,11,2),fpp(20, 1,11,3)/
     x-3.5115960d-01,-1.6965151d-04,-3.1484697d-19 /
      data fpp(20, 1,12,1),fpp(20, 1,12,2),fpp(20, 1,12,3)/
     x-3.5115960d-01,-1.7125740d-04, 1.9499576d-19 /
      data fpp(20, 1,13,1),fpp(20, 1,13,2),fpp(20, 1,13,3)/
     x-3.5115960d-01,-1.7217312d-04, 9.2386965d-20 /
      data fpp(20, 1,14,1),fpp(20, 1,14,2),fpp(20, 1,14,3)/
     x-3.5115960d-01,-1.7131014d-04, 1.7052032d-19 /
      data fpp(20, 1,15,1),fpp(20, 1,15,2),fpp(20, 1,15,3)/
     x-3.5115960d-01,-1.6613393d-04, 3.6754592d-20 /
      data fpp(20, 1,16,1),fpp(20, 1,16,2),fpp(20, 1,16,3)/
     x-3.5115960d-01,-1.5316251d-04,-1.1944652d-19 /
      data fpp(20, 1,17,1),fpp(20, 1,17,2),fpp(20, 1,17,3)/
     x-3.5115960d-01,-1.2787446d-04, 6.7836962d-20 /
      data fpp(20, 1,18,1),fpp(20, 1,18,2),fpp(20, 1,18,3)/
     x-3.5115960d-01,-8.4714237d-05,-1.6471899d-19 /
      data fpp(20, 1,19,1),fpp(20, 1,19,2),fpp(20, 1,19,3)/
     x-3.5115960d-01,-1.5488617d-05,-1.6635523d-19 /
      data fpp(20, 1,20,1),fpp(20, 1,20,2),fpp(20, 1,20,3)/
     x-3.5115960d-01, 1.0427424d-04, 1.6978129d-19 /
      data fpp(20, 1,21,1),fpp(20, 1,21,2),fpp(20, 1,21,3)/
     x-3.5115960d-01, 1.0427424d-04,-1.1756109d-19 /
      data fpp(20, 1,22,1),fpp(20, 1,22,2),fpp(20, 1,22,3)/
     x-3.5115960d-01,-1.5488617d-05, 2.1847059d-19 /
      data fpp(20, 1,23,1),fpp(20, 1,23,2),fpp(20, 1,23,3)/
     x-3.5115960d-01,-8.4714237d-05, 6.9174345d-19 /
      data fpp(20, 2, 1,1),fpp(20, 2, 1,2),fpp(20, 2, 1,3)/
     x-1.5534597d-01,-3.6918508d-05, 9.1394767d-06 /
      data fpp(20, 2, 2,1),fpp(20, 2, 2,2),fpp(20, 2, 2,3)/
     x-2.3867838d-01,-2.8556670d-05,-7.5349534d-06 /
      data fpp(20, 2, 3,1),fpp(20, 2, 3,2),fpp(20, 2, 3,3)/
     x-4.7328851d-01, 2.8964830d-06,-4.2971663d-05 /
      data fpp(20, 2, 4,1),fpp(20, 2, 4,2),fpp(20, 2, 4,3)/
     x-4.7328851d-01, 2.8964830d-06,-4.3486534d-05 /
      data fpp(20, 2, 5,1),fpp(20, 2, 5,2),fpp(20, 2, 5,3)/
     x-2.3867838d-01,-2.8556670d-05,-5.4754689d-06 /
      data fpp(20, 2, 6,1),fpp(20, 2, 6,2),fpp(20, 2, 6,3)/
     x-1.5534597d-01,-3.6918508d-05, 1.4164099d-06 /
      data fpp(20, 2, 7,1),fpp(20, 2, 7,2),fpp(20, 2, 7,3)/
     x-1.0922774d-01,-3.5548635d-05, 7.4778293d-06 /
      data fpp(20, 2, 8,1),fpp(20, 2, 8,2),fpp(20, 2, 8,3)/
     x-8.4064310d-02,-2.9261462d-05, 1.0528273d-05 /
      data fpp(20, 2, 9,1),fpp(20, 2, 9,2),fpp(20, 2, 9,3)/
     x-8.7656749d-02,-2.1137891d-05, 1.2959080d-05 /
      data fpp(20, 2,10,1),fpp(20, 2,10,2),fpp(20, 2,10,3)/
     x-7.8847518d-02,-1.3681322d-05, 1.4579409d-05 /
      data fpp(20, 2,11,1),fpp(20, 2,11,2),fpp(20, 2,11,3)/
     x-8.0984278d-02,-8.7509824d-06, 1.5555285d-05 /
      data fpp(20, 2,12,1),fpp(20, 2,12,2),fpp(20, 2,12,3)/
     x-6.7117496d-02,-7.5312048d-06, 1.5905449d-05 /
      data fpp(20, 2,13,1),fpp(20, 2,13,2),fpp(20, 2,13,3)/
     x-6.1176619d-02,-1.0403755d-05, 1.5622917d-05 /
      data fpp(20, 2,14,1),fpp(20, 2,14,2),fpp(20, 2,14,3)/
     x-7.7261933d-02,-1.6809724d-05, 1.4692882d-05 /
      data fpp(20, 2,15,1),fpp(20, 2,15,2),fpp(20, 2,15,3)/
     x-8.4970422d-02,-2.5387145d-05, 1.3103554d-05 /
      data fpp(20, 2,16,1),fpp(20, 2,16,2),fpp(20, 2,16,3)/
     x-7.9557839d-02,-3.4146989d-05, 1.0658903d-05 /
      data fpp(20, 2,17,1),fpp(20, 2,17,2),fpp(20, 2,17,3)/
     x-1.0118788d-01,-4.0567089d-05, 7.6628327d-06 /
      data fpp(20, 2,18,1),fpp(20, 2,18,2),fpp(20, 2,18,3)/
     x-1.4010110d-01,-4.1811526d-05, 1.5357656d-06 /
      data fpp(20, 2,19,1),fpp(20, 2,19,2),fpp(20, 2,19,3)/
     x-3.1422876d-01,-3.3824767d-05,-4.2238952d-06 /
      data fpp(20, 2,20,1),fpp(20, 2,20,2),fpp(20, 2,20,3)/
     x-4.5423640d-01,-3.6154794d-06,-4.4766185d-05 /
      data fpp(20, 2,21,1),fpp(20, 2,21,2),fpp(20, 2,21,3)/
     x-4.5423640d-01,-3.6154794d-06,-4.4141498d-05 /
      data fpp(20, 2,22,1),fpp(20, 2,22,2),fpp(20, 2,22,3)/
     x-3.1422876d-01,-3.3824767d-05,-6.7226435d-06 /
      data fpp(20, 2,23,1),fpp(20, 2,23,2),fpp(20, 2,23,3)/
     x-1.4010110d-01,-4.1811526d-05, 1.0906072d-05 /
      data fpp(20, 3, 1,1),fpp(20, 3, 1,2),fpp(20, 3, 1,3)/
     x-7.3931185d-02, 3.5276278d-05, 6.1264451d-05 /
      data fpp(20, 3, 2,1),fpp(20, 3, 2,2),fpp(20, 3, 2,3)/
     x-1.5704323d-01,-4.1507656d-05, 7.4725978d-06 /
      data fpp(20, 3, 3,1),fpp(20, 3, 3,2),fpp(20, 3, 3,3)/
     x-4.0872636d-01,-1.4937469d-04,-1.0575284d-04 /
      data fpp(20, 3, 4,1),fpp(20, 3, 4,2),fpp(20, 3, 4,3)/
     x-4.0872636d-01,-1.4937469d-04,-1.0932777d-04 /
      data fpp(20, 3, 5,1),fpp(20, 3, 5,2),fpp(20, 3, 5,3)/
     x-1.5704323d-01,-4.1507656d-05, 2.1772318d-05 /
      data fpp(20, 3, 6,1),fpp(20, 3, 6,2),fpp(20, 3, 6,3)/
     x-7.3931185d-02, 3.5276278d-05, 7.6404984d-06 /
      data fpp(20, 3, 7,1),fpp(20, 3, 7,2),fpp(20, 3, 7,3)/
     x-6.4191491d-02, 1.0303522d-04, 2.0613688d-05 /
      data fpp(20, 3, 8,1),fpp(20, 3, 8,2),fpp(20, 3, 8,3)/
     x-4.8089491d-02, 1.6157012d-04, 2.1930750d-05 /
      data fpp(20, 3, 9,1),fpp(20, 3, 9,2),fpp(20, 3, 9,3)/
     x-4.3564026d-02, 2.0896962d-04, 2.4599311d-05 /
      data fpp(20, 3,10,1),fpp(20, 3,10,2),fpp(20, 3,10,3)/
     x-4.1412990d-02, 2.4418863d-04, 2.5724006d-05 /
      data fpp(20, 3,11,1),fpp(20, 3,11,2),fpp(20, 3,11,3)/
     x-4.0459320d-02, 2.6592744d-04, 2.6296665d-05 /
      data fpp(20, 3,12,1),fpp(20, 3,12,2),fpp(20, 3,12,3)/
     x-4.0062845d-02, 2.7301022d-04, 2.6481334d-05 /
      data fpp(20, 3,13,1),fpp(20, 3,13,2),fpp(20, 3,13,3)/
     x-3.9966688d-02, 2.6498014d-04, 2.6585999d-05 /
      data fpp(20, 3,14,1),fpp(20, 3,14,2),fpp(20, 3,14,3)/
     x-4.0334128d-02, 2.4223303d-04, 2.6282671d-05 /
      data fpp(20, 3,15,1),fpp(20, 3,15,2),fpp(20, 3,15,3)/
     x-4.1697133d-02, 2.0594851d-04, 2.5369318d-05 /
      data fpp(20, 3,16,1),fpp(20, 3,16,2),fpp(20, 3,16,3)/
     x-4.5061733d-02, 1.5757046d-04, 2.2744058d-05 /
      data fpp(20, 3,17,1),fpp(20, 3,17,2),fpp(20, 3,17,3)/
     x-5.8679826d-02, 9.8526813d-05, 2.1468451d-05 /
      data fpp(20, 3,18,1),fpp(20, 3,18,2),fpp(20, 3,18,3)/
     x-6.2801518d-02, 3.1496341d-05, 7.6621401d-06 /
      data fpp(20, 3,19,1),fpp(20, 3,19,2),fpp(20, 3,19,3)/
     x-1.5750020d-01,-4.2100316d-05, 2.3470989d-05 /
      data fpp(20, 3,20,1),fpp(20, 3,20,2),fpp(20, 3,20,3)/
     x-3.6055159d-01,-1.4471832d-04,-1.1139210d-04 /
      data fpp(20, 3,21,1),fpp(20, 3,21,2),fpp(20, 3,21,3)/
     x-3.6055159d-01,-1.4471832d-04,-1.0765420d-04 /
      data fpp(20, 3,22,1),fpp(20, 3,22,2),fpp(20, 3,22,3)/
     x-1.5750020d-01,-4.2100316d-05, 8.5194153d-06 /
      data fpp(20, 3,23,1),fpp(20, 3,23,2),fpp(20, 3,23,3)/
     x-6.2801518d-02, 3.1496341d-05, 6.3730542d-05 /
      data fpp(20, 4, 1,1),fpp(20, 4, 1,2),fpp(20, 4, 1,3)/
     x-1.7277097d-02,-4.1546046d-06, 4.8412503d-05 /
      data fpp(20, 4, 2,1),fpp(20, 4, 2,2),fpp(20, 4, 2,3)/
     x 1.8686063d-02,-8.7358705d-05,-1.3300068d-06 /
      data fpp(20, 4, 3,1),fpp(20, 4, 3,2),fpp(20, 4, 3,3)/
     x 1.4919712d-01,-1.6761372d-04,-1.0660848d-04 /
      data fpp(20, 4, 4,1),fpp(20, 4, 4,2),fpp(20, 4, 4,3)/
     x 1.4919712d-01,-1.6761372d-04,-1.0890557d-04 /
      data fpp(20, 4, 5,1),fpp(20, 4, 5,2),fpp(20, 4, 5,3)/
     x 1.8686063d-02,-8.7358705d-05, 7.8583610d-06 /
      data fpp(20, 4, 6,1),fpp(20, 4, 6,2),fpp(20, 4, 6,3)/
     x-1.7277097d-02,-4.1546046d-06, 1.3956124d-05 /
      data fpp(20, 4, 7,1),fpp(20, 4, 7,2),fpp(20, 4, 7,3)/
     x-2.2390020d-02, 5.3991747d-05, 2.3119142d-05 /
      data fpp(20, 4, 8,1),fpp(20, 4, 8,2),fpp(20, 4, 8,3)/
     x-2.7399957d-02, 9.2936990d-05, 2.4583306d-05 /
      data fpp(20, 4, 9,1),fpp(20, 4, 9,2),fpp(20, 4, 9,3)/
     x-2.9612114d-02, 1.1891342d-04, 2.6195633d-05 /
      data fpp(20, 4,10,1),fpp(20, 4,10,2),fpp(20, 4,10,3)/
     x-3.1273359d-02, 1.3461481d-04, 2.6130162d-05 /
      data fpp(20, 4,11,1),fpp(20, 4,11,2),fpp(20, 4,11,3)/
     x-3.2316932d-02, 1.4238323d-04, 2.5655718d-05 /
      data fpp(20, 4,12,1),fpp(20, 4,12,2),fpp(20, 4,12,3)/
     x-3.2616052d-02, 1.4469834d-04, 2.5536966d-05 /
      data fpp(20, 4,13,1),fpp(20, 4,13,2),fpp(20, 4,13,3)/
     x-3.2093003d-02, 1.4271319d-04, 2.6168419d-05 /
      data fpp(20, 4,14,1),fpp(20, 4,14,2),fpp(20, 4,14,3)/
     x-3.0797987d-02, 1.3537759d-04, 2.7163360d-05 /
      data fpp(20, 4,15,1),fpp(20, 4,15,2),fpp(20, 4,15,3)/
     x-2.8847473d-02, 1.2022312d-04, 2.7712143d-05 /
      data fpp(20, 4,16,1),fpp(20, 4,16,2),fpp(20, 4,16,3)/
     x-2.6228729d-02, 9.4831146d-05, 2.6436070d-05 /
      data fpp(20, 4,17,1),fpp(20, 4,17,2),fpp(20, 4,17,3)/
     x-2.1839428d-02, 5.6367838d-05, 2.5375579d-05 /
      data fpp(20, 4,18,1),fpp(20, 4,18,2),fpp(20, 4,18,3)/
     x-1.4669574d-02,-1.6138373d-06, 1.5485615d-05 /
      data fpp(20, 4,19,1),fpp(20, 4,19,2),fpp(20, 4,19,3)/
     x 1.9020270d-02,-8.5587969d-05, 1.1249961d-05 /
      data fpp(20, 4,20,1),fpp(20, 4,20,2),fpp(20, 4,20,3)/
     x 1.5053027d-01,-1.6957523d-04,-1.1392746d-04 /
      data fpp(20, 4,21,1),fpp(20, 4,21,2),fpp(20, 4,21,3)/
     x 1.5053027d-01,-1.6957523d-04,-1.1135560d-04 /
      data fpp(20, 4,22,1),fpp(20, 4,22,2),fpp(20, 4,22,3)/
     x 1.9020270d-02,-8.5587969d-05, 9.6252903d-07 /
      data fpp(20, 4,23,1),fpp(20, 4,23,2),fpp(20, 4,23,3)/
     x-1.4669574d-02,-1.6138373d-06, 5.4063485d-05 /
      data fpp(20, 5, 1,1),fpp(20, 5, 1,2),fpp(20, 5, 1,3)/
     x-1.9076613d-03, 5.1812140d-05, 5.9461846d-06 /
      data fpp(20, 5, 2,1),fpp(20, 5, 2,2),fpp(20, 5, 2,3)/
     x 1.3350476d-02, 7.4130475d-05,-1.4691869d-05 /
      data fpp(20, 5, 3,1),fpp(20, 5, 3,2),fpp(20, 5, 3,3)/
     x 3.6827820d-02, 1.1656358d-04,-5.8784708d-05 /
      data fpp(20, 5, 4,1),fpp(20, 5, 4,2),fpp(20, 5, 4,3)/
     x 3.6827820d-02, 1.1656358d-04,-5.9014942d-05 /
      data fpp(20, 5, 5,1),fpp(20, 5, 5,2),fpp(20, 5, 5,3)/
     x 1.3350476d-02, 7.4130475d-05,-1.3770931d-05 /
      data fpp(20, 5, 6,1),fpp(20, 5, 6,2),fpp(20, 5, 6,3)/
     x-1.9076613d-03, 5.1812140d-05, 2.4926671d-06 /
      data fpp(20, 5, 7,1),fpp(20, 5, 7,2),fpp(20, 5, 7,3)/
     x-1.1046770d-02, 4.6985791d-05, 1.2692263d-05 /
      data fpp(20, 5, 8,1),fpp(20, 5, 8,2),fpp(20, 5, 8,3)/
     x-1.6878560d-02, 4.8483921d-05, 1.7040281d-05 /
      data fpp(20, 5, 9,1),fpp(20, 5, 9,2),fpp(20, 5, 9,3)/
     x-2.0873783d-02, 5.0190703d-05, 1.8704613d-05 /
      data fpp(20, 5,10,1),fpp(20, 5,10,2),fpp(20, 5,10,3)/
     x-2.3515221d-02, 5.1022119d-05, 1.8925268d-05 /
      data fpp(20, 5,11,1),fpp(20, 5,11,2),fpp(20, 5,11,3)/
     x-2.5007614d-02, 5.1591647d-05, 1.9072316d-05 /
      data fpp(20, 5,12,1),fpp(20, 5,12,2),fpp(20, 5,12,3)/
     x-2.5509114d-02, 5.2072435d-05, 1.9415468d-05 /
      data fpp(20, 5,13,1),fpp(20, 5,13,2),fpp(20, 5,13,3)/
     x-2.5103910d-02, 5.2353108d-05, 1.9887812d-05 /
      data fpp(20, 5,14,1),fpp(20, 5,14,2),fpp(20, 5,14,3)/
     x-2.3729469d-02, 5.2608617d-05, 2.0529285d-05 /
      data fpp(20, 5,15,1),fpp(20, 5,15,2),fpp(20, 5,15,3)/
     x-2.1254050d-02, 5.2731024d-05, 2.1031049d-05 /
      data fpp(20, 5,16,1),fpp(20, 5,16,2),fpp(20, 5,16,3)/
     x-1.7492695d-02, 5.2118956d-05, 1.9960518d-05 /
      data fpp(20, 5,17,1),fpp(20, 5,17,2),fpp(20, 5,17,3)/
     x-1.1971591d-02, 5.1589837d-05, 1.6108878d-05 /
      data fpp(20, 5,18,1),fpp(20, 5,18,2),fpp(20, 5,18,3)/
     x-3.2610994d-03, 5.6505008d-05, 5.5559708d-06 /
      data fpp(20, 5,19,1),fpp(20, 5,19,2),fpp(20, 5,19,3)/
     x 1.1425051d-02, 7.7120193d-05,-1.1620761d-05 /
      data fpp(20, 5,20,1),fpp(20, 5,20,2),fpp(20, 5,20,3)/
     x 3.1569608d-02, 1.1778525d-04,-6.5134927d-05 /
      data fpp(20, 5,21,1),fpp(20, 5,21,2),fpp(20, 5,21,3)/
     x 3.1569608d-02, 1.1778525d-04,-6.4764838d-05 /
      data fpp(20, 5,22,1),fpp(20, 5,22,2),fpp(20, 5,22,3)/
     x 1.1425051d-02, 7.7120193d-05,-1.3101118d-05 /
      data fpp(20, 5,23,1),fpp(20, 5,23,2),fpp(20, 5,23,3)/
     x-3.2610994d-03, 5.6505008d-05, 1.1107309d-05 /
      data fpp(20, 6, 1,1),fpp(20, 6, 1,2),fpp(20, 6, 1,3)/
     x 1.8054560d-03, 3.5838044d-05,-5.3150326d-06 /
      data fpp(20, 6, 2,1),fpp(20, 6, 2,2),fpp(20, 6, 2,3)/
     x 8.5375167d-03, 5.6222804d-05,-1.1865435d-05 /
      data fpp(20, 6, 3,1),fpp(20, 6, 3,2),fpp(20, 6, 3,3)/
     x 1.4612208d-02, 7.4133418d-05,-2.5985228d-05 /
      data fpp(20, 6, 4,1),fpp(20, 6, 4,2),fpp(20, 6, 4,3)/
     x 1.4612208d-02, 7.4133418d-05,-2.5839598d-05 /
      data fpp(20, 6, 5,1),fpp(20, 6, 5,2),fpp(20, 6, 5,3)/
     x 8.5375167d-03, 5.6222804d-05,-1.2447955d-05 /
      data fpp(20, 6, 6,1),fpp(20, 6, 6,2),fpp(20, 6, 6,3)/
     x 1.8054560d-03, 3.5838044d-05,-3.1305813d-06 /
      data fpp(20, 6, 7,1),fpp(20, 6, 7,2),fpp(20, 6, 7,3)/
     x-4.1809430d-03, 1.8447089d-05, 3.8562805d-06 /
      data fpp(20, 6, 8,1),fpp(20, 6, 8,2),fpp(20, 6, 8,3)/
     x-9.0806862d-03, 5.2553241d-06, 7.5894593d-06 /
      data fpp(20, 6, 9,1),fpp(20, 6, 9,2),fpp(20, 6, 9,3)/
     x-1.2858450d-02,-3.5662327d-06, 9.4898822d-06 /
      data fpp(20, 6,10,1),fpp(20, 6,10,2),fpp(20, 6,10,3)/
     x-1.5533426d-02,-8.3552883d-06, 1.0779012d-05 /
      data fpp(20, 6,11,1),fpp(20, 6,11,2),fpp(20, 6,11,3)/
     x-1.7183505d-02,-1.0265817d-05, 1.1876070d-05 /
      data fpp(20, 6,12,1),fpp(20, 6,12,2),fpp(20, 6,12,3)/
     x-1.7895755d-02,-1.0400077d-05, 1.2654709d-05 /
      data fpp(20, 6,13,1),fpp(20, 6,13,2),fpp(20, 6,13,3)/
     x-1.7697726d-02,-9.1776192d-06, 1.3033095d-05 /
      data fpp(20, 6,14,1),fpp(20, 6,14,2),fpp(20, 6,14,3)/
     x-1.6596840d-02,-6.3200537d-06, 1.3014910d-05 /
      data fpp(20, 6,15,1),fpp(20, 6,15,2),fpp(20, 6,15,3)/
     x-1.4479124d-02,-8.8321252d-07, 1.2673266d-05 /
      data fpp(20, 6,16,1),fpp(20, 6,16,2),fpp(20, 6,16,3)/
     x-1.1231599d-02, 8.0630311d-06, 1.1406028d-05 /
      data fpp(20, 6,17,1),fpp(20, 6,17,2),fpp(20, 6,17,3)/
     x-6.7504880d-03, 2.0706816d-05, 7.7926241d-06 /
      data fpp(20, 6,18,1),fpp(20, 6,18,2),fpp(20, 6,18,3)/
     x-8.7739204d-04, 3.6911804d-05,-2.7652393d-07 /
      data fpp(20, 6,19,1),fpp(20, 6,19,2),fpp(20, 6,19,3)/
     x 6.2330692d-03, 5.6023196d-05,-1.2116528d-05 /
      data fpp(20, 6,20,1),fpp(20, 6,20,2),fpp(20, 6,20,3)/
     x 1.3146794d-02, 7.3326237d-05,-3.1561363d-05 /
      data fpp(20, 6,21,1),fpp(20, 6,21,2),fpp(20, 6,21,3)/
     x 1.3146794d-02, 7.3326237d-05,-3.1692648d-05 /
      data fpp(20, 6,22,1),fpp(20, 6,22,2),fpp(20, 6,22,3)/
     x 6.2330692d-03, 5.6023196d-05,-1.1591386d-05 /
      data fpp(20, 6,23,1),fpp(20, 6,23,2),fpp(20, 6,23,3)/
     x-8.7739204d-04, 3.6911804d-05,-2.2458069d-06 /
      data fpp(20, 7, 1,1),fpp(20, 7, 1,2),fpp(20, 7, 1,3)/
     x 2.9061158d-03, 2.0757683d-05,-4.6176238d-06 /
      data fpp(20, 7, 2,1),fpp(20, 7, 2,2),fpp(20, 7, 2,3)/
     x 5.7124881d-03, 3.7842307d-05,-6.1442523d-06 /
      data fpp(20, 7, 3,1),fpp(20, 7, 3,2),fpp(20, 7, 3,3)/
     x 7.7528137d-03, 5.1968752d-05,-9.4633669d-06 /
      data fpp(20, 7, 4,1),fpp(20, 7, 4,2),fpp(20, 7, 4,3)/
     x 7.7528137d-03, 5.1968752d-05,-9.3797731d-06 /
      data fpp(20, 7, 5,1),fpp(20, 7, 5,2),fpp(20, 7, 5,3)/
     x 5.7124881d-03, 3.7842307d-05,-6.4786275d-06 /
      data fpp(20, 7, 6,1),fpp(20, 7, 6,2),fpp(20, 7, 6,3)/
     x 2.9061158d-03, 2.0757683d-05,-3.3637168d-06 /
      data fpp(20, 7, 7,1),fpp(20, 7, 7,2),fpp(20, 7, 7,3)/
     x-1.7700270d-04, 4.8178511d-06,-5.7450510d-07 /
      data fpp(20, 7, 8,1),fpp(20, 7, 8,2),fpp(20, 7, 8,3)/
     x-3.1939695d-03,-7.7772180d-06, 1.5937372d-06 /
      data fpp(20, 7, 9,1),fpp(20, 7, 9,2),fpp(20, 7, 9,3)/
     x-5.9328601d-03,-1.6713772d-05, 3.3975562d-06 /
      data fpp(20, 7,10,1),fpp(20, 7,10,2),fpp(20, 7,10,3)/
     x-8.2297675d-03,-2.2652966d-05, 4.9400381d-06 /
      data fpp(20, 7,11,1),fpp(20, 7,11,2),fpp(20, 7,11,3)/
     x-9.8938192d-03,-2.5972379d-05, 6.2002915d-06 /
      data fpp(20, 7,12,1),fpp(20, 7,12,2),fpp(20, 7,12,3)/
     x-1.0792408d-02,-2.6708125d-05, 7.1047958d-06 /
      data fpp(20, 7,13,1),fpp(20, 7,13,2),fpp(20, 7,13,3)/
     x-1.0870494d-02,-2.4912631d-05, 7.5725253d-06 /
      data fpp(20, 7,14,1),fpp(20, 7,14,2),fpp(20, 7,14,3)/
     x-1.0140173d-02,-2.0782402d-05, 7.5631032d-06 /
      data fpp(20, 7,15,1),fpp(20, 7,15,2),fpp(20, 7,15,3)/
     x-8.6433105d-03,-1.4482174d-05, 7.0250620d-06 /
      data fpp(20, 7,16,1),fpp(20, 7,16,2),fpp(20, 7,16,3)/
     x-6.3977175d-03,-5.7050800d-06, 5.7306489d-06 /
      data fpp(20, 7,17,1),fpp(20, 7,17,2),fpp(20, 7,17,3)/
     x-3.4582219d-03, 6.1508995d-06, 3.2023425d-06 /
      data fpp(20, 7,18,1),fpp(20, 7,18,2),fpp(20, 7,18,3)/
     x 8.6655432d-05, 2.0925774d-05,-1.2840188d-06 /
      data fpp(20, 7,19,1),fpp(20, 7,19,2),fpp(20, 7,19,3)/
     x 3.7211971d-03, 3.6845023d-05,-7.1682673d-06 /
      data fpp(20, 7,20,1),fpp(20, 7,20,2),fpp(20, 7,20,3)/
     x 6.6797203d-03, 5.0321804d-05,-1.4214912d-05 /
      data fpp(20, 7,21,1),fpp(20, 7,21,2),fpp(20, 7,21,3)/
     x 6.6797203d-03, 5.0321804d-05,-1.4338131d-05 /
      data fpp(20, 7,22,1),fpp(20, 7,22,2),fpp(20, 7,22,3)/
     x 3.7211971d-03, 3.6845023d-05,-6.6753912d-06 /
      data fpp(20, 7,23,1),fpp(20, 7,23,2),fpp(20, 7,23,3)/
     x 8.6655432d-05, 2.0925774d-05,-3.1323044d-06 /
      data fpp(20, 8, 1,1),fpp(20, 8, 1,2),fpp(20, 8, 1,3)/
     x 3.5478649d-03, 6.8852236d-06,-2.1583293d-06 /
      data fpp(20, 8, 2,1),fpp(20, 8, 2,2),fpp(20, 8, 2,3)/
     x 4.6132189d-03, 1.6819967d-05,-2.4198414d-06 /
      data fpp(20, 8, 3,1),fpp(20, 8, 3,2),fpp(20, 8, 3,3)/
     x 8.8281516d-03, 2.4789573d-05,-2.9883051d-06 /
      data fpp(20, 8, 4,1),fpp(20, 8, 4,2),fpp(20, 8, 4,3)/
     x 8.8281516d-03, 2.4789573d-05,-2.9741639d-06 /
      data fpp(20, 8, 5,1),fpp(20, 8, 5,2),fpp(20, 8, 5,3)/
     x 4.6132189d-03, 1.6819967d-05,-2.4764064d-06 /
      data fpp(20, 8, 6,1),fpp(20, 8, 6,2),fpp(20, 8, 6,3)/
     x 3.5478649d-03, 6.8852236d-06,-1.9462104d-06 /
      data fpp(20, 8, 7,1),fpp(20, 8, 7,2),fpp(20, 8, 7,3)/
     x 2.1788318d-03,-2.4864939d-06,-1.5047521d-06 /
      data fpp(20, 8, 8,1),fpp(20, 8, 8,2),fpp(20, 8, 8,3)/
     x 6.1993209d-04,-1.0176452d-05,-7.9478120d-07 /
      data fpp(20, 8, 9,1),fpp(20, 8, 9,2),fpp(20, 8, 9,3)/
     x-1.0774934d-03,-1.5972678d-05, 2.7387690d-07 /
      data fpp(20, 8,10,1),fpp(20, 8,10,2),fpp(20, 8,10,3)/
     x-2.7126063d-03,-1.9820849d-05, 1.5892736d-06 /
      data fpp(20, 8,11,1),fpp(20, 8,11,2),fpp(20, 8,11,3)/
     x-4.0952500d-03,-2.1828668d-05, 2.8010287d-06 /
      data fpp(20, 8,12,1),fpp(20, 8,12,2),fpp(20, 8,12,3)/
     x-5.0285886d-03,-2.2195421d-05, 3.7126115d-06 /
      data fpp(20, 8,13,1),fpp(20, 8,13,2),fpp(20, 8,13,3)/
     x-5.4010833d-03,-2.1071857d-05, 4.1765253d-06 /
      data fpp(20, 8,14,1),fpp(20, 8,14,2),fpp(20, 8,14,3)/
     x-5.1914579d-03,-1.8406339d-05, 4.2112875d-06 /
      data fpp(20, 8,15,1),fpp(20, 8,15,2),fpp(20, 8,15,3)/
     x-4.3899986d-03,-1.4040093d-05, 3.8723249d-06 /
      data fpp(20, 8,16,1),fpp(20, 8,16,2),fpp(20, 8,16,3)/
     x-3.0638940d-03,-8.0187111d-06, 3.0454131d-06 /
      data fpp(20, 8,17,1),fpp(20, 8,17,2),fpp(20, 8,17,3)/
     x-1.3616399d-03,-6.5841400d-07, 1.5080228d-06 /
      data fpp(20, 8,18,1),fpp(20, 8,18,2),fpp(20, 8,18,3)/
     x 6.2857980d-04, 7.4550986d-06,-8.7550410d-07 /
      data fpp(20, 8,19,1),fpp(20, 8,19,2),fpp(20, 8,19,3)/
     x 2.5594525d-03, 1.5224713d-05,-3.6400063d-06 /
      data fpp(20, 8,20,1),fpp(20, 8,20,2),fpp(20, 8,20,3)/
     x 4.0308005d-03, 2.0868549d-05,-6.3084705d-06 /
      data fpp(20, 8,21,1),fpp(20, 8,21,2),fpp(20, 8,21,3)/
     x 4.0308005d-03, 2.0868549d-05,-6.3805853d-06 /
      data fpp(20, 8,22,1),fpp(20, 8,22,2),fpp(20, 8,22,3)/
     x 2.5594525d-03, 1.5224713d-05,-3.3515471d-06 /
      data fpp(20, 8,23,1),fpp(20, 8,23,2),fpp(20, 8,23,3)/
     x 6.2857980d-04, 7.4550986d-06,-1.9572265d-06 /
      data fpp(20, 9, 1,1),fpp(20, 9, 1,2),fpp(20, 9, 1,3)/
     x 4.1822797d-03,-4.7257732d-07, 1.4136554d-06 /
      data fpp(20, 9, 2,1),fpp(20, 9, 2,2),fpp(20, 9, 2,3)/
     x 4.8680118d-03, 6.5018241d-06,-8.1087773d-10 /
      data fpp(20, 9, 3,1),fpp(20, 9, 3,2),fpp(20, 9, 3,3)/
     x 9.2549684d-03, 1.3698956d-05,-3.0004119d-06 /
      data fpp(20, 9, 4,1),fpp(20, 9, 4,2),fpp(20, 9, 4,3)/
     x 9.2549684d-03, 1.3698956d-05,-3.0553588d-06 /
      data fpp(20, 9, 5,1),fpp(20, 9, 5,2),fpp(20, 9, 5,3)/
     x 4.8680118d-03, 6.5018241d-06, 2.1897652d-07 /
      data fpp(20, 9, 6,1),fpp(20, 9, 6,2),fpp(20, 9, 6,3)/
     x 4.1822797d-03,-4.7257732d-07, 5.8945270d-07 /
      data fpp(20, 9, 7,1),fpp(20, 9, 7,2),fpp(20, 9, 7,3)/
     x 3.5246775d-03,-5.5338756d-06,-2.9078732d-07 /
      data fpp(20, 9, 8,1),fpp(20, 9, 8,2),fpp(20, 9, 8,3)/
     x 2.7484541d-03,-8.8949730d-06,-1.1063034d-06 /
      data fpp(20, 9, 9,1),fpp(20, 9, 9,2),fpp(20, 9, 9,3)/
     x 1.7886139d-03,-1.1117517d-05,-9.2999895d-07 /
      data fpp(20, 9,10,1),fpp(20, 9,10,2),fpp(20, 9,10,3)/
     x 6.9589482d-04,-1.2609637d-05, 2.2992273d-09 /
      data fpp(20, 9,11,1),fpp(20, 9,11,2),fpp(20, 9,11,3)/
     x-3.8741631d-04,-1.3462951d-05, 1.0468020d-06 /
      data fpp(20, 9,12,1),fpp(20, 9,12,2),fpp(20, 9,12,3)/
     x-1.2593896d-03,-1.3588190d-05, 1.8524926d-06 /
      data fpp(20, 9,13,1),fpp(20, 9,13,2),fpp(20, 9,13,3)/
     x-1.7835628d-03,-1.2893942d-05, 2.3192275d-06 /
      data fpp(20, 9,14,1),fpp(20, 9,14,2),fpp(20, 9,14,3)/
     x-1.8922559d-03,-1.1378241d-05, 2.4965974d-06 /
      data fpp(20, 9,15,1),fpp(20, 9,15,2),fpp(20, 9,15,3)/
     x-1.5724251d-03,-9.0854559d-06, 2.3823829d-06 /
      data fpp(20, 9,16,1),fpp(20, 9,16,2),fpp(20, 9,16,3)/
     x-8.5087703d-04,-6.0380758d-06, 1.9238710d-06 /
      data fpp(20, 9,17,1),fpp(20, 9,17,2),fpp(20, 9,17,3)/
     x 1.2965249d-04,-2.3472435d-06, 9.7413322d-07 /
      data fpp(20, 9,18,1),fpp(20, 9,18,2),fpp(20, 9,18,3)/
     x 1.3037512d-03, 1.6518313d-06,-4.3240386d-07 /
      data fpp(20, 9,19,1),fpp(20, 9,19,2),fpp(20, 9,19,3)/
     x 2.4351894d-03, 5.3061237d-06,-1.9865178d-06 /
      data fpp(20, 9,20,1),fpp(20, 9,20,2),fpp(20, 9,20,3)/
     x 3.2797667d-03, 7.8580004d-06,-2.9855249d-06 /
      data fpp(20, 9,21,1),fpp(20, 9,21,2),fpp(20, 9,21,3)/
     x 3.2797667d-03, 7.8580004d-06,-3.0371663d-06 /
      data fpp(20, 9,22,1),fpp(20, 9,22,2),fpp(20, 9,22,3)/
     x 2.4351894d-03, 5.3061237d-06,-1.7799525d-06 /
      data fpp(20, 9,23,1),fpp(20, 9,23,2),fpp(20, 9,23,3)/
     x 1.3037512d-03, 1.6518313d-06,-1.2070238d-06 /
      data fpp(20,10, 1,1),fpp(20,10, 1,2),fpp(20,10, 1,3)/
     x 3.7254029d-03,-4.0469143d-06, 8.7579655d-06 /
      data fpp(20,10, 2,1),fpp(20,10, 2,2),fpp(20,10, 2,3)/
     x 4.9071027d-03, 6.0673633d-07, 3.2030689d-06 /
      data fpp(20,10, 3,1),fpp(20,10, 3,2),fpp(20,10, 3,3)/
     x 4.7904122d-03, 7.6966049d-06,-8.5622413d-06 /
      data fpp(20,10, 4,1),fpp(20,10, 4,2),fpp(20,10, 4,3)/
     x 4.7904122d-03, 7.6966049d-06,-8.8038106d-06 /
      data fpp(20,10, 5,1),fpp(20,10, 5,2),fpp(20,10, 5,3)/
     x 4.9071027d-03, 6.0673633d-07, 4.1693464d-06 /
      data fpp(20,10, 6,1),fpp(20,10, 6,2),fpp(20,10, 6,3)/
     x 3.7254029d-03,-4.0469143d-06, 5.1344251d-06 /
      data fpp(20,10, 7,1),fpp(20,10, 7,2),fpp(20,10, 7,3)/
     x 3.4975947d-03,-5.9720038d-06, 2.5749531d-06 /
      data fpp(20,10, 8,1),fpp(20,10, 8,2),fpp(20,10, 8,3)/
     x 3.3753752d-03,-6.6836559d-06,-3.3823742d-07 /
      data fpp(20,10, 9,1),fpp(20,10, 9,2),fpp(20,10, 9,3)/
     x 2.9999104d-03,-7.0872550d-06,-1.3480034d-06 /
      data fpp(20,10,10,1),fpp(20,10,10,2),fpp(20,10,10,3)/
     x 2.3631962d-03,-7.4106034d-06,-8.5774908d-07 /
      data fpp(20,10,11,1),fpp(20,10,11,2),fpp(20,10,11,3)/
     x 1.5835082d-03,-7.6355296d-06, 9.2999693d-08 /
      data fpp(20,10,12,1),fpp(20,10,12,2),fpp(20,10,12,3)/
     x 8.4473172d-04,-7.6198172d-06, 8.5775031d-07 /
      data fpp(20,10,13,1),fpp(20,10,13,2),fpp(20,10,13,3)/
     x 3.0606799d-04,-7.2303760d-06, 1.3419991d-06 /
      data fpp(20,10,14,1),fpp(20,10,14,2),fpp(20,10,14,3)/
     x 8.7371790d-05,-6.4186971d-06, 1.6462534d-06 /
      data fpp(20,10,15,1),fpp(20,10,15,2),fpp(20,10,15,3)/
     x 2.0614375d-04,-5.2380838d-06, 1.7329873d-06 /
      data fpp(20,10,16,1),fpp(20,10,16,2),fpp(20,10,16,3)/
     x 6.3565517d-04,-3.8049859d-06, 1.5017972d-06 /
      data fpp(20,10,17,1),fpp(20,10,17,2),fpp(20,10,17,3)/
     x 1.2993946d-03,-2.2646120d-06, 8.2182376d-07 /
      data fpp(20,10,18,1),fpp(20,10,18,2),fpp(20,10,18,3)/
     x 2.0775064d-03,-7.5442391d-07,-2.5909225d-07 /
      data fpp(20,10,19,1),fpp(20,10,19,2),fpp(20,10,19,3)/
     x 2.8639403d-03, 6.0679175d-07,-1.5074548d-06 /
      data fpp(20,10,20,1),fpp(20,10,20,2),fpp(20,10,20,3)/
     x 3.4796938d-03, 1.5854495d-06,-1.6130887d-06 /
      data fpp(20,10,21,1),fpp(20,10,21,2),fpp(20,10,21,3)/
     x 3.4796938d-03, 1.5854495d-06,-1.6700064d-06 /
      data fpp(20,10,22,1),fpp(20,10,22,2),fpp(20,10,22,3)/
     x 2.8639403d-03, 6.0679175d-07,-1.2797839d-06 /
      data fpp(20,10,23,1),fpp(20,10,23,2),fpp(20,10,23,3)/
     x 2.0775064d-03,-7.5442391d-07,-1.1128581d-06 /
      data fpp(20,11, 1,1),fpp(20,11, 1,2),fpp(20,11, 1,3)/
     x 1.1211761d-03,-1.0097655d-06, 2.2017425d-05 /
      data fpp(20,11, 2,1),fpp(20,11, 2,2),fpp(20,11, 2,3)/
     x 3.6801768d-03, 1.3792306d-06, 8.7931506d-06 /
      data fpp(20,11, 3,1),fpp(20,11, 3,2),fpp(20,11, 3,3)/
     x 6.2064467d-03, 4.2226251d-06,-1.9162027d-05 /
      data fpp(20,11, 4,1),fpp(20,11, 4,2),fpp(20,11, 4,3)/
     x 6.2064467d-03, 4.2226251d-06,-1.9831494d-05 /
      data fpp(20,11, 5,1),fpp(20,11, 5,2),fpp(20,11, 5,3)/
     x 3.6801768d-03, 1.3792306d-06, 1.1471018d-05 /
      data fpp(20,11, 6,1),fpp(20,11, 6,2),fpp(20,11, 6,3)/
     x 1.1211761d-03,-1.0097655d-06, 1.1975424d-05 /
      data fpp(20,11, 7,1),fpp(20,11, 7,2),fpp(20,11, 7,3)/
     x 1.5714269d-03,-2.5341093d-06, 6.5972879d-06 /
      data fpp(20,11, 8,1),fpp(20,11, 8,2),fpp(20,11, 8,3)/
     x 2.4997510d-03,-3.3404034d-06, 7.7942477d-07 /
      data fpp(20,11, 9,1),fpp(20,11, 9,2),fpp(20,11, 9,3)/
     x 2.9441680d-03,-3.7814631d-06,-1.5849870d-06 /
      data fpp(20,11,10,1),fpp(20,11,10,2),fpp(20,11,10,3)/
     x 2.9212245d-03,-4.0199495d-06,-1.5374768d-06 /
      data fpp(20,11,11,1),fpp(20,11,11,2),fpp(20,11,11,3)/
     x 2.4332326d-03,-4.0909308d-06,-5.6310567d-07 /
      data fpp(20,11,12,1),fpp(20,11,12,2),fpp(20,11,12,3)/
     x 1.9042073d-03,-4.0645408d-06, 2.7989952d-07 /
      data fpp(20,11,13,1),fpp(20,11,13,2),fpp(20,11,13,3)/
     x 1.4593174d-03,-3.9285542d-06, 8.2350757d-07 /
      data fpp(20,11,14,1),fpp(20,11,14,2),fpp(20,11,14,3)/
     x 1.2276234d-03,-3.6449709d-06, 1.2020702d-06 /
      data fpp(20,11,15,1),fpp(20,11,15,2),fpp(20,11,15,3)/
     x 1.2960212d-03,-3.2202090d-06, 1.3942117d-06 /
      data fpp(20,11,16,1),fpp(20,11,16,2),fpp(20,11,16,3)/
     x 1.6252804d-03,-2.7299805d-06, 1.2610830d-06 /
      data fpp(20,11,17,1),fpp(20,11,17,2),fpp(20,11,17,3)/
     x 2.1548971d-03,-2.2503086d-06, 6.9545620d-07 /
      data fpp(20,11,18,1),fpp(20,11,18,2),fpp(20,11,18,3)/
     x 2.8002052d-03,-1.8141357d-06,-2.2690782d-07 /
      data fpp(20,11,19,1),fpp(20,11,19,2),fpp(20,11,19,3)/
     x 3.4516451d-03,-1.3612907d-06,-1.4138249d-06 /
      data fpp(20,11,20,1),fpp(20,11,20,2),fpp(20,11,20,3)/
     x 3.9641113d-03,-7.8979837d-07,-1.0717925d-06 /
      data fpp(20,11,21,1),fpp(20,11,21,2),fpp(20,11,21,3)/
     x 3.9641113d-03,-7.8979837d-07,-1.1357101d-06 /
      data fpp(20,11,22,1),fpp(20,11,22,2),fpp(20,11,22,3)/
     x 3.4516451d-03,-1.3612907d-06,-1.1581542d-06 /
      data fpp(20,11,23,1),fpp(20,11,23,2),fpp(20,11,23,3)/
     x 2.8002052d-03,-1.8141357d-06,-1.1856729d-06 /
      data fpp(20,12, 1,1),fpp(20,12, 1,2),fpp(20,12, 1,3)/
     x-2.1779760d-03, 6.5139762d-06, 3.5844613d-05 /
      data fpp(20,12, 2,1),fpp(20,12, 2,2),fpp(20,12, 2,3)/
     x 1.4555241d-03, 4.2983414d-06, 1.4333774d-05 /
      data fpp(20,12, 3,1),fpp(20,12, 3,2),fpp(20,12, 3,3)/
     x-2.5119223d-03,-3.1671052d-06,-3.1127708d-05 /
      data fpp(20,12, 4,1),fpp(20,12, 4,2),fpp(20,12, 4,3)/
     x-2.5119223d-03,-3.1671052d-06,-3.2235762d-05 /
      data fpp(20,12, 5,1),fpp(20,12, 5,2),fpp(20,12, 5,3)/
     x 1.4555241d-03, 4.2983414d-06, 1.8765988d-05 /
      data fpp(20,12, 6,1),fpp(20,12, 6,2),fpp(20,12, 6,3)/
     x-2.1779760d-03, 6.5139762d-06, 1.9223808d-05 /
      data fpp(20,12, 7,1),fpp(20,12, 7,2),fpp(20,12, 7,3)/
     x-1.3555269d-03, 4.7624410d-06, 1.1216779d-05 /
      data fpp(20,12, 8,1),fpp(20,12, 8,2),fpp(20,12, 8,3)/
     x 6.4909824d-04, 2.0992695d-06, 2.2750767d-06 /
      data fpp(20,12, 9,1),fpp(20,12, 9,2),fpp(20,12, 9,3)/
     x 2.0757254d-03, 6.1107513d-08,-1.5370857d-06 /
      data fpp(20,12,10,1),fpp(20,12,10,2),fpp(20,12,10,3)/
     x 2.6148402d-03,-1.1095986d-06,-1.9767338d-06 /
      data fpp(20,12,11,1),fpp(20,12,11,2),fpp(20,12,11,3)/
     x 2.5823671d-03,-1.6627471d-06,-1.0799790d-06 /
      data fpp(20,12,12,1),fpp(20,12,12,2),fpp(20,12,12,3)/
     x 2.3166148d-03,-1.8980196d-06,-1.4735004d-07 /
      data fpp(20,12,13,1),fpp(20,12,13,2),fpp(20,12,13,3)/
     x 2.0211216d-03,-2.0154071d-06, 4.9337919d-07 /
      data fpp(20,12,14,1),fpp(20,12,14,2),fpp(20,12,14,3)/
     x 1.8753427d-03,-2.0714194d-06, 9.2783327d-07 /
      data fpp(20,12,15,1),fpp(20,12,15,2),fpp(20,12,15,3)/
     x 1.9583650d-03,-2.1070801d-06, 1.1412877d-06 /
      data fpp(20,12,16,1),fpp(20,12,16,2),fpp(20,12,16,3)/
     x 2.2652912d-03,-2.1410920d-06, 1.0230157d-06 /
      data fpp(20,12,17,1),fpp(20,12,17,2),fpp(20,12,17,3)/
     x 2.7381386d-03,-2.1861536d-06, 5.2664926d-07 /
      data fpp(20,12,18,1),fpp(20,12,18,2),fpp(20,12,18,3)/
     x 3.3051375d-03,-2.2370333d-06,-2.3761278d-07 /
      data fpp(20,12,19,1),fpp(20,12,19,2),fpp(20,12,19,3)/
     x 3.8774826d-03,-2.2656290d-06,-1.1661981d-06 /
      data fpp(20,12,20,1),fpp(20,12,20,2),fpp(20,12,20,3)/
     x 4.3123534d-03,-2.2482560d-06,-9.6559469d-07 /
      data fpp(20,12,21,1),fpp(20,12,21,2),fpp(20,12,21,3)/
     x 4.3123534d-03,-2.2482560d-06,-1.0141169d-06 /
      data fpp(20,12,22,1),fpp(20,12,22,2),fpp(20,12,22,3)/
     x 3.8774826d-03,-2.2656290d-06,-9.7210947d-07 /
      data fpp(20,12,23,1),fpp(20,12,23,2),fpp(20,12,23,3)/
     x 3.3051375d-03,-2.2370333d-06,-9.6544527d-07 /
      data fpp(20,13, 1,1),fpp(20,13, 1,2),fpp(20,13, 1,3)/
     x-3.4316296d-03, 7.0298606d-06, 3.9114364d-05 /
      data fpp(20,13, 2,1),fpp(20,13, 2,2),fpp(20,13, 2,3)/
     x 2.8331051d-03,-2.8165960d-06, 1.4608272d-05 /
      data fpp(20,13, 3,1),fpp(20,13, 3,2),fpp(20,13, 3,3)/
     x 1.2168784d-02,-1.7930204d-05,-3.7283452d-05 /
      data fpp(20,13, 4,1),fpp(20,13, 4,2),fpp(20,13, 4,3)/
     x 1.2168784d-02,-1.7930204d-05,-3.8370779d-05 /
      data fpp(20,13, 5,1),fpp(20,13, 5,2),fpp(20,13, 5,3)/
     x 2.8331051d-03,-2.8165960d-06, 1.8957577d-05 /
      data fpp(20,13, 6,1),fpp(20,13, 6,2),fpp(20,13, 6,3)/
     x-3.4316296d-03, 7.0298606d-06, 2.2804471d-05 /
      data fpp(20,13, 7,1),fpp(20,13, 7,2),fpp(20,13, 7,3)/
     x-3.3611429d-03, 9.0683451d-06, 1.4798541d-05 /
      data fpp(20,13, 8,1),fpp(20,13, 8,2),fpp(20,13, 8,3)/
     x-1.0501946d-03, 6.7993252d-06, 4.3533661d-06 /
      data fpp(20,13, 9,1),fpp(20,13, 9,2),fpp(20,13, 9,3)/
     x 1.0034010d-03, 3.7710331d-06,-6.7600512d-07 /
      data fpp(20,13,10,1),fpp(20,13,10,2),fpp(20,13,10,3)/
     x 2.0614029d-03, 1.5103439d-06,-1.8113456d-06 /
      data fpp(20,13,11,1),fpp(20,13,11,2),fpp(20,13,11,3)/
     x 2.3594975d-03, 1.6391935d-07,-1.2766126d-06 /
      data fpp(20,13,12,1),fpp(20,13,12,2),fpp(20,13,12,3)/
     x 2.3175940d-03,-5.3538070d-07,-4.4420411d-07 /
      data fpp(20,13,13,1),fpp(20,13,13,2),fpp(20,13,13,3)/
     x 2.2074376d-03,-8.9181733d-07, 2.4542904d-07 /
      data fpp(20,13,14,1),fpp(20,13,14,2),fpp(20,13,14,3)/
     x 2.1652903d-03,-1.1433515d-06, 6.9248797d-07 /
      data fpp(20,13,15,1),fpp(20,13,15,2),fpp(20,13,15,3)/
     x 2.2915084d-03,-1.3714706d-06, 8.9661908d-07 /
      data fpp(20,13,16,1),fpp(20,13,16,2),fpp(20,13,16,3)/
     x 2.5811410d-03,-1.6116515d-06, 7.7303570d-07 /
      data fpp(20,13,17,1),fpp(20,13,17,2),fpp(20,13,17,3)/
     x 3.0066721d-03,-1.8450771d-06, 3.4923813d-07 /
      data fpp(20,13,18,1),fpp(20,13,18,2),fpp(20,13,18,3)/
     x 3.4998600d-03,-2.0537311d-06,-2.4398821d-07 /
      data fpp(20,13,19,1),fpp(20,13,19,2),fpp(20,13,19,3)/
     x 3.9818840d-03,-2.2961934d-06,-8.5528527d-07 /
      data fpp(20,13,20,1),fpp(20,13,20,2),fpp(20,13,20,3)/
     x 4.3303637d-03,-2.6311775d-06,-9.0687070d-07 /
      data fpp(20,13,21,1),fpp(20,13,21,2),fpp(20,13,21,3)/
     x 4.3303637d-03,-2.6311775d-06,-9.3474525d-07 /
      data fpp(20,13,22,1),fpp(20,13,22,2),fpp(20,13,22,3)/
     x 3.9818840d-03,-2.2961934d-06,-7.4378707d-07 /
      data fpp(20,13,23,1),fpp(20,13,23,2),fpp(20,13,23,3)/
     x 3.4998600d-03,-2.0537311d-06,-6.6210646d-07 /
      data fpp(20,14, 1,1),fpp(20,14, 1,2),fpp(20,14, 1,3)/
     x-2.1028222d-03,-2.4741861d-07, 2.8709248d-05 /
      data fpp(20,14, 2,1),fpp(20,14, 2,2),fpp(20,14, 2,3)/
     x 4.8248208d-03,-1.1019957d-05, 8.9845044d-06 /
      data fpp(20,14, 3,1),fpp(20,14, 3,2),fpp(20,14, 3,3)/
     x 1.2380081d-02,-2.2222077d-05,-3.2919265d-05 /
      data fpp(20,14, 4,1),fpp(20,14, 4,2),fpp(20,14, 4,3)/
     x 1.2380081d-02,-2.2222077d-05,-3.3555456d-05 /
      data fpp(20,14, 5,1),fpp(20,14, 5,2),fpp(20,14, 5,3)/
     x 4.8248208d-03,-1.1019957d-05, 1.1529269d-05 /
      data fpp(20,14, 6,1),fpp(20,14, 6,2),fpp(20,14, 6,3)/
     x-2.1028222d-03,-2.4741861d-07, 1.9166382d-05 /
      data fpp(20,14, 7,1),fpp(20,14, 7,2),fpp(20,14, 7,3)/
     x-3.1919189d-03, 5.4161784d-06, 1.4567204d-05 /
      data fpp(20,14, 8,1),fpp(20,14, 8,2),fpp(20,14, 8,3)/
     x-1.4814558d-03, 6.3194295d-06, 6.0008035d-06 /
      data fpp(20,14, 9,1),fpp(20,14, 9,2),fpp(20,14, 9,3)/
     x 4.5970567d-04, 4.8707602d-06, 9.5758226d-07 /
      data fpp(20,14,10,1),fpp(20,14,10,2),fpp(20,14,10,3)/
     x 1.6220092d-03, 2.9702232d-06,-8.1913256d-07 /
      data fpp(20,14,11,1),fpp(20,14,11,2),fpp(20,14,11,3)/
     x 2.0613340d-03, 1.4510697d-06,-8.9705203d-07 /
      data fpp(20,14,12,1),fpp(20,14,12,2),fpp(20,14,12,3)/
     x 2.1490076d-03, 4.6354242d-07,-4.3465932d-07 /
      data fpp(20,14,13,1),fpp(20,14,13,2),fpp(20,14,13,3)/
     x 2.1547461d-03,-1.1732356d-07, 9.1689314d-08 /
      data fpp(20,14,14,1),fpp(20,14,14,2),fpp(20,14,14,3)/
     x 2.2017573d-03,-4.7117450d-07, 4.8190206d-07 /
      data fpp(20,14,15,1),fpp(20,14,15,2),fpp(20,14,15,3)/
     x 2.3550743d-03,-7.5903748d-07, 6.3870243d-07 /
      data fpp(20,14,16,1),fpp(20,14,16,2),fpp(20,14,16,3)/
     x 2.6444309d-03,-1.0183021d-06, 5.3328820d-07 /
      data fpp(20,14,17,1),fpp(20,14,17,2),fpp(20,14,17,3)/
     x 2.9622049d-03,-1.2335382d-06, 2.0414475d-07 /
      data fpp(20,14,18,1),fpp(20,14,18,2),fpp(20,14,18,3)/
     x 3.3473403d-03,-1.3920425d-06,-2.3986720d-07 /
      data fpp(20,14,19,1),fpp(20,14,19,2),fpp(20,14,19,3)/
     x 3.7252158d-03,-1.4675973d-06,-6.4867593d-07 /
      data fpp(20,14,20,1),fpp(20,14,20,2),fpp(20,14,20,3)/
     x 3.9903717d-03,-1.4470339d-06,-6.6942907d-07 /
      data fpp(20,14,21,1),fpp(20,14,21,2),fpp(20,14,21,3)/
     x 3.9903717d-03,-1.4470339d-06,-6.8837483d-07 /
      data fpp(20,14,22,1),fpp(20,14,22,2),fpp(20,14,22,3)/
     x 3.7252158d-03,-1.4675973d-06,-5.7289291d-07 /
      data fpp(20,14,23,1),fpp(20,14,23,2),fpp(20,14,23,3)/
     x 3.3473403d-03,-1.3920425d-06,-5.2405355d-07 /
      data fpp(20,15, 1,1),fpp(20,15, 1,2),fpp(20,15, 1,3)/
     x 1.0695817d-03,-8.9081862d-06, 1.2885771d-05 /
      data fpp(20,15, 2,1),fpp(20,15, 2,2),fpp(20,15, 2,3)/
     x 3.3534104d-03,-1.1897575d-05, 2.0659582d-06 /
      data fpp(20,15, 3,1),fpp(20,15, 3,2),fpp(20,15, 3,3)/
     x-4.1367294d-03,-1.0967488d-05,-2.1023604d-05 /
      data fpp(20,15, 4,1),fpp(20,15, 4,2),fpp(20,15, 4,3)/
     x-4.1367294d-03,-1.0967488d-05,-2.1191168d-05 /
      data fpp(20,15, 5,1),fpp(20,15, 5,2),fpp(20,15, 5,3)/
     x 3.3534104d-03,-1.1897575d-05, 2.7362154d-06 /
      data fpp(20,15, 6,1),fpp(20,15, 6,2),fpp(20,15, 6,3)/
     x 1.0695817d-03,-8.9081862d-06, 1.0372306d-05 /
      data fpp(20,15, 7,1),fpp(20,15, 7,2),fpp(20,15, 7,3)/
     x-5.4907423d-04,-3.9730589d-06, 1.0026560d-05 /
      data fpp(20,15, 8,1),fpp(20,15, 8,2),fpp(20,15, 8,3)/
     x-8.7179338d-05, 1.0956734d-08, 5.7414552d-06 /
      data fpp(20,15, 9,1),fpp(20,15, 9,2),fpp(20,15, 9,3)/
     x 9.3401074d-04, 1.9459261d-06, 2.3116194d-06 /
      data fpp(20,15,10,1),fpp(20,15,10,2),fpp(20,15,10,3)/
     x 1.6659930d-03, 2.2627634d-06, 5.4006705d-07 /
      data fpp(20,15,11,1),fpp(20,15,11,2),fpp(20,15,11,3)/
     x 1.9634760d-03, 1.7958018d-06,-4.9887642d-08 /
      data fpp(20,15,12,1),fpp(20,15,12,2),fpp(20,15,12,3)/
     x 2.0215619d-03, 1.1472110d-06,-7.0516486d-08 /
      data fpp(20,15,13,1),fpp(20,15,13,2),fpp(20,15,13,3)/
     x 2.0436584d-03, 6.0511156d-07, 1.2795359d-07 /
      data fpp(20,15,14,1),fpp(20,15,14,2),fpp(20,15,14,3)/
     x 2.1145866d-03, 2.2004952d-07, 3.2670214d-07 /
      data fpp(20,15,15,1),fpp(20,15,15,2),fpp(20,15,15,3)/
     x 2.2458526d-03,-1.4379459d-08, 4.0723784d-07 /
      data fpp(20,15,16,1),fpp(20,15,16,2),fpp(20,15,16,3)/
     x 2.4511054d-03,-1.4714004d-07, 3.3634649d-07 /
      data fpp(20,15,17,1),fpp(20,15,17,2),fpp(20,15,17,3)/
     x 2.6894406d-03,-2.1077015d-07, 1.1337621d-07 /
      data fpp(20,15,18,1),fpp(20,15,18,2),fpp(20,15,18,3)/
     x 2.9648152d-03,-2.0209912d-07,-1.7185132d-07 /
      data fpp(20,15,19,1),fpp(20,15,19,2),fpp(20,15,19,3)/
     x 3.2048596d-03,-1.3141729d-07,-3.9197094d-07 /
      data fpp(20,15,20,1),fpp(20,15,20,2),fpp(20,15,20,3)/
     x 3.3788285d-03,-7.0687062d-08,-4.1426492d-07 /
      data fpp(20,15,21,1),fpp(20,15,21,2),fpp(20,15,21,3)/
     x 3.3788285d-03,-7.0687062d-08,-4.2421978d-07 /
      data fpp(20,15,22,1),fpp(20,15,22,2),fpp(20,15,22,3)/
     x 3.2048596d-03,-1.3141729d-07,-3.5215149d-07 /
      data fpp(20,15,23,1),fpp(20,15,23,2),fpp(20,15,23,3)/
     x 2.9648152d-03,-2.0209912d-07,-3.2117425d-07 /
      data fpp(20,16, 1,1),fpp(20,16, 1,2),fpp(20,16, 1,3)/
     x 5.9230510d-03,-1.1309837d-05, 2.3221311d-06 /
      data fpp(20,16, 2,1),fpp(20,16, 2,2),fpp(20,16, 2,3)/
     x 1.1943863d-02,-6.8557428d-06,-1.4397622d-06 /
      data fpp(20,16, 3,1),fpp(20,16, 3,2),fpp(20,16, 3,3)/
     x 7.0384093d-03, 8.7202762d-07,-9.5170824d-06 /
      data fpp(20,16, 4,1),fpp(20,16, 4,2),fpp(20,16, 4,3)/
     x 7.0384093d-03, 8.7202762d-07,-9.4888718d-06 /
      data fpp(20,16, 5,1),fpp(20,16, 5,2),fpp(20,16, 5,3)/
     x 1.1943863d-02,-6.8557428d-06,-1.5526044d-06 /
      data fpp(20,16, 6,1),fpp(20,16, 6,2),fpp(20,16, 6,3)/
     x 5.9230510d-03,-1.1309837d-05, 2.7452896d-06 /
      data fpp(20,16, 7,1),fpp(20,16, 7,2),fpp(20,16, 7,3)/
     x 3.2218206d-03,-1.0487943d-05, 4.2634462d-06 /
      data fpp(20,16, 8,1),fpp(20,16, 8,2),fpp(20,16, 8,3)/
     x 2.3980265d-03,-6.7832564d-06, 3.5229258d-06 /
      data fpp(20,16, 9,1),fpp(20,16, 9,2),fpp(20,16, 9,3)/
     x 1.8752481d-03,-2.9824647d-06, 2.2728507d-06 /
      data fpp(20,16,10,1),fpp(20,16,10,2),fpp(20,16,10,3)/
     x 2.2453045d-03,-4.2327679d-07, 1.2636716d-06 /
      data fpp(20,16,11,1),fpp(20,16,11,2),fpp(20,16,11,3)/
     x 2.1904950d-03, 8.2172324d-07, 6.6446314d-07 /
      data fpp(20,16,12,1),fpp(20,16,12,2),fpp(20,16,12,3)/
     x 2.1009904d-03, 1.1936135d-06, 3.9247591d-07 /
      data fpp(20,16,13,1),fpp(20,16,13,2),fpp(20,16,13,3)/
     x 2.0250202d-03, 1.1288773d-06, 2.9763323d-07 /
      data fpp(20,16,14,1),fpp(20,16,14,2),fpp(20,16,14,3)/
     x 2.0219735d-03, 9.6497642d-07, 2.9499117d-07 /
      data fpp(20,16,15,1),fpp(20,16,15,2),fpp(20,16,15,3)/
     x 2.0784440d-03, 8.5255532d-07, 2.6840207d-07 /
      data fpp(20,16,16,1),fpp(20,16,16,2),fpp(20,16,16,3)/
     x 2.1949986d-03, 8.6886228d-07, 2.0940054d-07 /
      data fpp(20,16,17,1),fpp(20,16,17,2),fpp(20,16,17,3)/
     x 2.3316345d-03, 1.0026188d-06, 8.7995775d-08 /
      data fpp(20,16,18,1),fpp(20,16,18,2),fpp(20,16,18,3)/
     x 2.4721237d-03, 1.1804389d-06,-4.5383638d-08 /
      data fpp(20,16,19,1),fpp(20,16,19,2),fpp(20,16,19,3)/
     x 2.6023449d-03, 1.3152665d-06,-1.4646122d-07 /
      data fpp(20,16,20,1),fpp(20,16,20,2),fpp(20,16,20,3)/
     x 2.6883417d-03, 1.3697821d-06,-1.9677147d-07 /
      data fpp(20,16,21,1),fpp(20,16,21,2),fpp(20,16,21,3)/
     x 2.6883417d-03, 1.3697821d-06,-2.0045499d-07 /
      data fpp(20,16,22,1),fpp(20,16,22,2),fpp(20,16,22,3)/
     x 2.6023449d-03, 1.3152665d-06,-1.3172715d-07 /
      data fpp(20,16,23,1),fpp(20,16,23,2),fpp(20,16,23,3)/
     x 2.4721237d-03, 1.1804389d-06,-1.0063643d-07 /
      data fpp(20,17, 1,1),fpp(20,17, 1,2),fpp(20,17, 1,3)/
     x 8.6962741d-03,-3.1584670d-06,-5.8840833d-07 /
      data fpp(20,17, 2,1),fpp(20,17, 2,2),fpp(20,17, 2,3)/
     x 7.2525107d-03, 2.3125461d-06,-1.3696833d-06 /
      data fpp(20,17, 3,1),fpp(20,17, 3,2),fpp(20,17, 3,3)/
     x 5.7483441d-03, 7.6773772d-06,-3.0588583d-06 /
      data fpp(20,17, 4,1),fpp(20,17, 4,2),fpp(20,17, 4,3)/
     x 5.7483441d-03, 7.6773772d-06,-3.0325834d-06 /
      data fpp(20,17, 5,1),fpp(20,17, 5,2),fpp(20,17, 5,3)/
     x 7.2525107d-03, 2.3125461d-06,-1.4747829d-06 /
      data fpp(20,17, 6,1),fpp(20,17, 6,2),fpp(20,17, 6,3)/
     x 8.6962741d-03,-3.1584670d-06,-1.9428505d-07 /
      data fpp(20,17, 7,1),fpp(20,17, 7,2),fpp(20,17, 7,3)/
     x 4.7994667d-03,-6.3351692d-06, 7.2792308d-07 /
      data fpp(20,17, 8,1),fpp(20,17, 8,2),fpp(20,17, 8,3)/
     x 3.9817627d-03,-6.7119310d-06, 1.0865927d-06 /
      data fpp(20,17, 9,1),fpp(20,17, 9,2),fpp(20,17, 9,3)/
     x 3.3640190d-03,-5.2260672d-06, 1.0757060d-06 /
      data fpp(20,17,10,1),fpp(20,17,10,2),fpp(20,17,10,3)/
     x 2.9454830d-03,-3.1016562d-06, 8.9258310d-07 /
      data fpp(20,17,11,1),fpp(20,17,11,2),fpp(20,17,11,3)/
     x 2.6372289d-03,-1.1646947d-06, 6.8796155d-07 /
      data fpp(20,17,12,1),fpp(20,17,12,2),fpp(20,17,12,3)/
     x 2.3840145d-03, 2.4033482d-07, 5.0757071d-07 /
      data fpp(20,17,13,1),fpp(20,17,13,2),fpp(20,17,13,3)/
     x 2.2134142d-03, 1.1253792d-06, 3.8975562d-07 /
      data fpp(20,17,14,1),fpp(20,17,14,2),fpp(20,17,14,3)/
     x 2.0946408d-03, 1.6260448d-06, 2.9740680d-07 /
      data fpp(20,17,15,1),fpp(20,17,15,2),fpp(20,17,15,3)/
     x 2.0420429d-03, 1.9321582d-06, 2.3261718d-07 /
      data fpp(20,17,16,1),fpp(20,17,16,2),fpp(20,17,16,3)/
     x 2.0383867d-03, 2.1616909d-06, 1.7612447d-07 /
      data fpp(20,17,17,1),fpp(20,17,17,2),fpp(20,17,17,3)/
     x 2.0566858d-03, 2.3742949d-06, 1.0688495d-07 /
      data fpp(20,17,18,1),fpp(20,17,18,2),fpp(20,17,18,3)/
     x 2.1006510d-03, 2.5843434d-06, 5.6335750d-08 /
      data fpp(20,17,19,1),fpp(20,17,19,2),fpp(20,17,19,3)/
     x 2.1438862d-03, 2.7663513d-06, 1.5772056d-08 /
      data fpp(20,17,20,1),fpp(20,17,20,2),fpp(20,17,20,3)/
     x 2.1744647d-03, 2.8835587d-06,-1.7423973d-08 /
      data fpp(20,17,21,1),fpp(20,17,21,2),fpp(20,17,21,3)/
     x 2.1744647d-03, 2.8835587d-06,-1.8614110d-08 /
      data fpp(20,17,22,1),fpp(20,17,22,2),fpp(20,17,22,3)/
     x 2.1438862d-03, 2.7663513d-06, 2.0532603d-08 /
      data fpp(20,17,23,1),fpp(20,17,23,2),fpp(20,17,23,3)/
     x 2.1006510d-03, 2.5843434d-06, 3.8483699d-08 /
      data fpp(20,18, 1,1),fpp(20,18, 1,2),fpp(20,18, 1,3)/
     x 4.4117240d-03, 2.4457049d-06,-3.7537280d-07 /
      data fpp(20,18, 2,1),fpp(20,18, 2,2),fpp(20,18, 2,3)/
     x 4.6558984d-03, 5.2555582d-06,-4.6125441d-07 /
      data fpp(20,18, 3,1),fpp(20,18, 3,2),fpp(20,18, 3,3)/
     x 4.8137301d-03, 7.6464637d-06,-6.4760957d-07 /
      data fpp(20,18, 4,1),fpp(20,18, 4,2),fpp(20,18, 4,3)/
     x 4.8137301d-03, 7.6464637d-06,-6.4354409d-07 /
      data fpp(20,18, 5,1),fpp(20,18, 5,2),fpp(20,18, 5,3)/
     x 4.6558984d-03, 5.2555582d-06,-4.7751633d-07 /
      data fpp(20,18, 6,1),fpp(20,18, 6,2),fpp(20,18, 6,3)/
     x 4.4117240d-03, 2.4457049d-06,-3.1439060d-07 /
      data fpp(20,18, 7,1),fpp(20,18, 7,2),fpp(20,18, 7,3)/
     x 4.1043926d-03, 5.6619770d-08,-1.3092126d-07 /
      data fpp(20,18, 8,1),fpp(20,18, 8,2),fpp(20,18, 8,3)/
     x 3.7944202d-03,-1.5170197d-06, 2.2075650d-08 /
      data fpp(20,18, 9,1),fpp(20,18, 9,2),fpp(20,18, 9,3)/
     x 3.4854594d-03,-2.2252665d-06, 1.2661866d-07 /
      data fpp(20,18,10,1),fpp(20,18,10,2),fpp(20,18,10,3)/
     x 3.2060251d-03,-2.2120982d-06, 1.9144971d-07 /
      data fpp(20,18,11,1),fpp(20,18,11,2),fpp(20,18,11,3)/
     x 2.9593362d-03,-1.7009444d-06, 2.1758251d-07 /
      data fpp(20,18,12,1),fpp(20,18,12,2),fpp(20,18,12,3)/
     x 2.7413593d-03,-9.0095280d-07, 2.1622025d-07 /
      data fpp(20,18,13,1),fpp(20,18,13,2),fpp(20,18,13,3)/
     x 2.5690562d-03, 2.1605947d-08, 2.0753650d-07 /
      data fpp(20,18,14,1),fpp(20,18,14,2),fpp(20,18,14,3)/
     x 2.4259829d-03, 9.6084434d-07, 1.8363376d-07 /
      data fpp(20,18,15,1),fpp(20,18,15,2),fpp(20,18,15,3)/
     x 2.3116203d-03, 1.8528119d-06, 1.6192845d-07 /
      data fpp(20,18,16,1),fpp(20,18,16,2),fpp(20,18,16,3)/
     x 2.2333432d-03, 2.6643740d-06, 1.4065243d-07 /
      data fpp(20,18,17,1),fpp(20,18,17,2),fpp(20,18,17,3)/
     x 2.1740323d-03, 3.3722014d-06, 1.1546182d-07 /
      data fpp(20,18,18,1),fpp(20,18,18,2),fpp(20,18,18,3)/
     x 2.1462266d-03, 3.9501876d-06, 1.0550028d-07 /
      data fpp(20,18,19,1),fpp(20,18,19,2),fpp(20,18,19,3)/
     x 2.1249151d-03, 4.3713282d-06, 8.6537055d-08 /
      data fpp(20,18,20,1),fpp(20,18,20,2),fpp(20,18,20,3)/
     x 2.1023003d-03, 4.6279832d-06, 7.6351499d-08 /
      data fpp(20,18,21,1),fpp(20,18,21,2),fpp(20,18,21,3)/
     x 2.1023003d-03, 4.6279832d-06, 7.5676975d-08 /
      data fpp(20,18,22,1),fpp(20,18,22,2),fpp(20,18,22,3)/
     x 2.1249151d-03, 4.3713282d-06, 8.9235150d-08 /
      data fpp(20,18,23,1),fpp(20,18,23,2),fpp(20,18,23,3)/
     x 2.1462266d-03, 3.9501876d-06, 9.5382425d-08 /
      data fpp(20,19, 1,1),fpp(20,19, 1,2),fpp(20,19, 1,3)/
     x 2.9148501d-03, 8.7776476d-06, 3.4734442d-21 /
      data fpp(20,19, 2,1),fpp(20,19, 2,2),fpp(20,19, 2,3)/
     x 2.9148501d-03, 9.9772209d-06,-9.5669639d-23 /
      data fpp(20,19, 3,1),fpp(20,19, 3,2),fpp(20,19, 3,3)/
     x 2.9148501d-03, 9.5687682d-06,-1.0877426d-21 /
      data fpp(20,19, 4,1),fpp(20,19, 4,2),fpp(20,19, 4,3)/
     x 2.9148501d-03, 9.5687682d-06, 6.2565700d-22 /
      data fpp(20,19, 5,1),fpp(20,19, 5,2),fpp(20,19, 5,3)/
     x 2.9148501d-03, 9.9772209d-06, 7.5980238d-22 /
      data fpp(20,19, 6,1),fpp(20,19, 6,2),fpp(20,19, 6,3)/
     x 2.9148501d-03, 8.7776476d-06,-2.2471417d-21 /
      data fpp(20,19, 7,1),fpp(20,19, 7,2),fpp(20,19, 7,3)/
     x 2.9148501d-03, 5.8086901d-06,-1.8452502d-21 /
      data fpp(20,19, 8,1),fpp(20,19, 8,2),fpp(20,19, 8,3)/
     x 2.9148501d-03, 2.2140099d-06,-9.0264545d-22 /
      data fpp(20,19, 9,1),fpp(20,19, 9,2),fpp(20,19, 9,3)/
     x 2.9148501d-03,-7.2286674d-07, 5.6319682d-22 /
      data fpp(20,19,10,1),fpp(20,19,10,2),fpp(20,19,10,3)/
     x 2.9148501d-03,-2.3419509d-06, 1.2950199d-21 /
      data fpp(20,19,11,1),fpp(20,19,11,2),fpp(20,19,11,3)/
     x 2.9148501d-03,-2.6515278d-06,-1.4552655d-21 /
      data fpp(20,19,12,1),fpp(20,19,12,2),fpp(20,19,12,3)/
     x 2.9148501d-03,-1.9885236d-06, 1.0987843d-21 /
      data fpp(20,19,13,1),fpp(20,19,13,2),fpp(20,19,13,3)/
     x 2.9148501d-03,-7.6780297d-07, 6.6815763d-22 /
      data fpp(20,19,14,1),fpp(20,19,14,2),fpp(20,19,14,3)/
     x 2.9148501d-03, 6.7457783d-07,-3.3668414d-22 /
      data fpp(20,19,15,1),fpp(20,19,15,2),fpp(20,19,15,3)/
     x 2.9148501d-03, 2.1045940d-06,-3.4228700d-22 /
      data fpp(20,19,16,1),fpp(20,19,16,2),fpp(20,19,16,3)/
     x 2.9148501d-03, 3.3928130d-06,-3.7942719d-23 /
      data fpp(20,19,17,1),fpp(20,19,17,2),fpp(20,19,17,3)/
     x 2.9148501d-03, 4.4768993d-06, 2.3637108d-21 /
      data fpp(20,19,18,1),fpp(20,19,18,2),fpp(20,19,18,3)/
     x 2.9148501d-03, 5.3269062d-06,-2.4112282d-21 /
      data fpp(20,19,19,1),fpp(20,19,19,2),fpp(20,19,19,3)/
     x 2.9148501d-03, 5.9323359d-06,-1.1046905d-21 /
      data fpp(20,19,20,1),fpp(20,19,20,2),fpp(20,19,20,3)/
     x 2.9148501d-03, 6.3065084d-06, 8.3406761d-22 /
      data fpp(20,19,21,1),fpp(20,19,21,2),fpp(20,19,21,3)/
     x 2.9148501d-03, 6.3065084d-06,-8.9439353d-22 /
      data fpp(20,19,22,1),fpp(20,19,22,2),fpp(20,19,22,3)/
     x 2.9148501d-03, 5.9323359d-06, 6.6026439d-22 /
      data fpp(20,19,23,1),fpp(20,19,23,2),fpp(20,19,23,3)/
     x 2.9148501d-03, 5.3269062d-06, 5.5386238d-21 /
      data fpp(21, 1, 1,1),fpp(21, 1, 1,2),fpp(21, 1, 1,3)/
     x 1.3400331d-01,-8.6266150d-05, 6.6749155d-20 /
      data fpp(21, 1, 2,1),fpp(21, 1, 2,2),fpp(21, 1, 2,3)/
     x 1.3400331d-01,-4.0485232d-07,-6.6790782d-20 /
      data fpp(21, 1, 3,1),fpp(21, 1, 3,2),fpp(21, 1, 3,3)/
     x 1.3400331d-01, 9.6187975d-05,-5.7867757d-20 /
      data fpp(21, 1, 4,1),fpp(21, 1, 4,2),fpp(21, 1, 4,3)/
     x 1.3400331d-01, 9.6187975d-05, 1.4942596d-19 /
      data fpp(21, 1, 5,1),fpp(21, 1, 5,2),fpp(21, 1, 5,3)/
     x 1.3400331d-01,-4.0485232d-07, 2.7776087d-21 /
      data fpp(21, 1, 6,1),fpp(21, 1, 6,2),fpp(21, 1, 6,3)/
     x 1.3400331d-01,-8.6266150d-05,-7.5888976d-20 /
      data fpp(21, 1, 7,1),fpp(21, 1, 7,2),fpp(21, 1, 7,3)/
     x 1.3400331d-01,-1.4767010d-04,-1.7298318d-19 /
      data fpp(21, 1, 8,1),fpp(21, 1, 8,2),fpp(21, 1, 8,3)/
     x 1.3400331d-01,-1.8743385d-04,-1.0709375d-19 /
      data fpp(21, 1, 9,1),fpp(21, 1, 9,2),fpp(21, 1, 9,3)/
     x 1.3400331d-01,-2.1137682d-04, 2.0914316d-20 /
      data fpp(21, 1,10,1),fpp(21, 1,10,2),fpp(21, 1,10,3)/
     x 1.3400331d-01,-2.2466890d-04, 1.0636911d-19 /
      data fpp(21, 1,11,1),fpp(21, 1,11,2),fpp(21, 1,11,3)/
     x 1.3400331d-01,-2.3129768d-04,-8.6124992d-20 /
      data fpp(21, 1,12,1),fpp(21, 1,12,2),fpp(21, 1,12,3)/
     x 1.3400331d-01,-2.3399152d-04, 1.7196385d-19 /
      data fpp(21, 1,13,1),fpp(21, 1,13,2),fpp(21, 1,13,3)/
     x 1.3400331d-01,-2.3368935d-04, 1.7831345d-19 /
      data fpp(21, 1,14,1),fpp(21, 1,14,2),fpp(21, 1,14,3)/
     x 1.3400331d-01,-2.2924300d-04, 5.0321871d-20 /
      data fpp(21, 1,15,1),fpp(21, 1,15,2),fpp(21, 1,15,3)/
     x 1.3400331d-01,-2.1777200d-04,-4.0024929d-20 /
      data fpp(21, 1,16,1),fpp(21, 1,16,2),fpp(21, 1,16,3)/
     x 1.3400331d-01,-1.9516484d-04,-1.7156002d-19 /
      data fpp(21, 1,17,1),fpp(21, 1,17,2),fpp(21, 1,17,3)/
     x 1.3400331d-01,-1.5629605d-04, 1.7253874d-19 /
      data fpp(21, 1,18,1),fpp(21, 1,18,2),fpp(21, 1,18,3)/
     x 1.3400331d-01,-9.5469944d-05,-1.7618711d-19 /
      data fpp(21, 1,19,1),fpp(21, 1,19,2),fpp(21, 1,19,3)/
     x 1.3400331d-01,-9.3745967d-06,-1.0692836d-19 /
      data fpp(21, 1,20,1),fpp(21, 1,20,2),fpp(21, 1,20,3)/
     x 1.3400331d-01, 9.0295916d-05, 8.1695007d-20 /
      data fpp(21, 1,21,1),fpp(21, 1,21,2),fpp(21, 1,21,3)/
     x 1.3400331d-01, 9.0295916d-05,-1.5119612d-19 /
      data fpp(21, 1,22,1),fpp(21, 1,22,2),fpp(21, 1,22,3)/
     x 1.3400331d-01,-9.3745967d-06, 2.4906753d-19 /
      data fpp(21, 1,23,1),fpp(21, 1,23,2),fpp(21, 1,23,3)/
     x 1.3400331d-01,-9.5469944d-05, 2.9888340d-19 /
      data fpp(21, 2, 1,1),fpp(21, 2, 1,2),fpp(21, 2, 1,3)/
     x 2.4997279d-02,-4.8884699d-05,-5.2228641d-06 /
      data fpp(21, 2, 2,1),fpp(21, 2, 2,2),fpp(21, 2, 2,3)/
     x 6.6735440d-02,-2.6004295d-05,-1.0893272d-05 /
      data fpp(21, 2, 3,1),fpp(21, 2, 3,2),fpp(21, 2, 3,3)/
     x 1.4231659d-01, 4.1150496d-06,-2.3108049d-05 /
      data fpp(21, 2, 4,1),fpp(21, 2, 4,2),fpp(21, 2, 4,3)/
     x 1.4231659d-01, 4.1150496d-06,-2.2996218d-05 /
      data fpp(21, 2, 5,1),fpp(21, 2, 5,2),fpp(21, 2, 5,3)/
     x 6.6735440d-02,-2.6004295d-05,-1.1340595d-05 /
      data fpp(21, 2, 6,1),fpp(21, 2, 6,2),fpp(21, 2, 6,3)/
     x 2.4997279d-02,-4.8884699d-05,-3.5454008d-06 /
      data fpp(21, 2, 7,1),fpp(21, 2, 7,2),fpp(21, 2, 7,3)/
     x 1.6880760d-03,-6.1055795d-05, 2.6441986d-06 /
      data fpp(21, 2, 8,1),fpp(21, 2, 8,2),fpp(21, 2, 8,3)/
     x-1.0446728d-02,-6.5023308d-05, 6.7566065d-06 /
      data fpp(21, 2, 9,1),fpp(21, 2, 9,2),fpp(21, 2, 9,3)/
     x-1.3930303d-02,-6.4210352d-05, 9.5933752d-06 /
      data fpp(21, 2,10,1),fpp(21, 2,10,2),fpp(21, 2,10,3)/
     x-1.7303948d-02,-6.1586201d-05, 1.1425892d-05 /
      data fpp(21, 2,11,1),fpp(21, 2,11,2),fpp(21, 2,11,3)/
     x-1.7840957d-02,-5.9370635d-05, 1.2479055d-05 /
      data fpp(21, 2,12,1),fpp(21, 2,12,2),fpp(21, 2,12,3)/
     x-2.0210773d-02,-5.8969961d-05, 1.2841888d-05 /
      data fpp(21, 2,13,1),fpp(21, 2,13,2),fpp(21, 2,13,3)/
     x-2.0744555d-02,-6.0833294d-05, 1.2551391d-05 /
      data fpp(21, 2,14,1),fpp(21, 2,14,2),fpp(21, 2,14,3)/
     x-1.7138840d-02,-6.4382995d-05, 1.1568546d-05 /
      data fpp(21, 2,15,1),fpp(21, 2,15,2),fpp(21, 2,15,3)/
     x-1.3844349d-02,-6.8109998d-05, 9.7844261d-06 /
      data fpp(21, 2,16,1),fpp(21, 2,16,2),fpp(21, 2,16,3)/
     x-1.0728698d-02,-6.9703311d-05, 6.9837498d-06 /
      data fpp(21, 2,17,1),fpp(21, 2,17,2),fpp(21, 2,17,3)/
     x 4.7098634d-04,-6.6177897d-05, 2.9065746d-06 /
      data fpp(21, 2,18,1),fpp(21, 2,18,2),fpp(21, 2,18,3)/
     x 2.1887200d-02,-5.4150113d-05,-3.3160481d-06 /
      data fpp(21, 2,19,1),fpp(21, 2,19,2),fpp(21, 2,19,3)/
     x 7.7216202d-02,-3.0951807d-05,-1.1224382d-05 /
      data fpp(21, 2,20,1),fpp(21, 2,20,2),fpp(21, 2,20,3)/
     x 1.3849540d-01, 6.3316860d-07,-2.3696423d-05 /
      data fpp(21, 2,21,1),fpp(21, 2,21,2),fpp(21, 2,21,3)/
     x 1.3849540d-01, 6.3316860d-07,-2.3795539d-05 /
      data fpp(21, 2,22,1),fpp(21, 2,22,2),fpp(21, 2,22,3)/
     x 7.7216202d-02,-3.0951807d-05,-1.0827917d-05 /
      data fpp(21, 2,23,1),fpp(21, 2,23,2),fpp(21, 2,23,3)/
     x 2.1887200d-02,-5.4150113d-05,-4.8027913d-06 /
      data fpp(21, 3, 1,1),fpp(21, 3, 1,2),fpp(21, 3, 1,3)/
     x-8.8510297d-03,-9.8105258d-07, 1.3056727d-05 /
      data fpp(21, 3, 2,1),fpp(21, 3, 2,2),fpp(21, 3, 2,3)/
     x 2.7086211d-02,-7.4677966d-05,-1.2075455d-05 /
      data fpp(21, 3, 3,1),fpp(21, 3, 3,2),fpp(21, 3, 3,3)/
     x 1.2625619d-01,-1.4504217d-04,-6.5542909d-05 /
      data fpp(21, 3, 4,1),fpp(21, 3, 4,2),fpp(21, 3, 4,3)/
     x 1.2625619d-01,-1.4504217d-04,-6.6220547d-05 /
      data fpp(21, 3, 5,1),fpp(21, 3, 5,2),fpp(21, 3, 5,3)/
     x 2.7086211d-02,-7.4677966d-05,-9.3649008d-06 /
      data fpp(21, 3, 6,1),fpp(21, 3, 6,2),fpp(21, 3, 6,3)/
     x-8.8510297d-03,-9.8105258d-07, 2.8921501d-06 /
      data fpp(21, 3, 7,1),fpp(21, 3, 7,2),fpp(21, 3, 7,3)/
     x-1.9151093d-02, 6.6309281d-05, 1.2928300d-05 /
      data fpp(21, 3, 8,1),fpp(21, 3, 8,2),fpp(21, 3, 8,3)/
     x-2.5398393d-02, 1.2340108d-04, 1.7226649d-05 /
      data fpp(21, 3, 9,1),fpp(21, 3, 9,2),fpp(21, 3, 9,3)/
     x-2.8094090d-02, 1.6889023d-04, 2.0033105d-05 /
      data fpp(21, 3,10,1),fpp(21, 3,10,2),fpp(21, 3,10,3)/
     x-2.9750566d-02, 2.0212970d-04, 2.1398931d-05 /
      data fpp(21, 3,11,1),fpp(21, 3,11,2),fpp(21, 3,11,3)/
     x-3.0696771d-02, 2.2238422d-04, 2.1967169d-05 /
      data fpp(21, 3,12,1),fpp(21, 3,12,2),fpp(21, 3,12,3)/
     x-3.0925750d-02, 2.2903736d-04, 2.2174392d-05 /
      data fpp(21, 3,13,1),fpp(21, 3,13,2),fpp(21, 3,13,3)/
     x-3.0428658d-02, 2.2185453d-04, 2.2235262d-05 /
      data fpp(21, 3,14,1),fpp(21, 3,14,2),fpp(21, 3,14,3)/
     x-2.9220983d-02, 2.0106098d-04, 2.1904560d-05 /
      data fpp(21, 3,15,1),fpp(21, 3,15,2),fpp(21, 3,15,3)/
     x-2.7299473d-02, 1.6733999d-04, 2.0754499d-05 /
      data fpp(21, 3,16,1),fpp(21, 3,16,2),fpp(21, 3,16,3)/
     x-2.4410726d-02, 1.2153209d-04, 1.8041442d-05 /
      data fpp(21, 3,17,1),fpp(21, 3,17,2),fpp(21, 3,17,3)/
     x-1.8312853d-02, 6.4511639d-05, 1.3855731d-05 /
      data fpp(21, 3,18,1),fpp(21, 3,18,2),fpp(21, 3,18,3)/
     x-9.2265987d-03,-2.0416047d-06, 3.5576346d-06 /
      data fpp(21, 3,19,1),fpp(21, 3,19,2),fpp(21, 3,19,3)/
     x 2.6488006d-02,-7.4652177d-05,-7.3562692d-06 /
      data fpp(21, 3,20,1),fpp(21, 3,20,2),fpp(21, 3,20,3)/
     x 1.1411132d-01,-1.4538259d-04,-6.8950558d-05 /
      data fpp(21, 3,21,1),fpp(21, 3,21,2),fpp(21, 3,21,3)/
     x 1.1411132d-01,-1.4538259d-04,-6.8104192d-05 /
      data fpp(21, 3,22,1),fpp(21, 3,22,2),fpp(21, 3,22,3)/
     x 2.6488006d-02,-7.4652177d-05,-1.0741731d-05 /
      data fpp(21, 3,23,1),fpp(21, 3,23,2),fpp(21, 3,23,3)/
     x-9.2265987d-03,-2.0416047d-06, 1.6253115d-05 /
      data fpp(21, 4, 1,1),fpp(21, 4, 1,2),fpp(21, 4, 1,3)/
     x 8.0217317d-04, 1.0094910d-05, 1.3967726d-05 /
      data fpp(21, 4, 2,1),fpp(21, 4, 2,2),fpp(21, 4, 2,3)/
     x 2.4121968d-02,-4.2591840d-05,-1.2962452d-05 /
      data fpp(21, 4, 3,1),fpp(21, 4, 3,2),fpp(21, 4, 3,3)/
     x 5.3380041d-02,-9.4404356d-05,-7.0345918d-05 /
      data fpp(21, 4, 4,1),fpp(21, 4, 4,2),fpp(21, 4, 4,3)/
     x 5.3380041d-02,-9.4404356d-05,-7.0913021d-05 /
      data fpp(21, 4, 5,1),fpp(21, 4, 5,2),fpp(21, 4, 5,3)/
     x 2.4121968d-02,-4.2591840d-05,-1.0694038d-05 /
      data fpp(21, 4, 6,1),fpp(21, 4, 6,2),fpp(21, 4, 6,3)/
     x 8.0217317d-04, 1.0094910d-05, 5.4611714d-06 /
      data fpp(21, 4, 7,1),fpp(21, 4, 7,2),fpp(21, 4, 7,3)/
     x-1.2710179d-02, 5.1046670d-05, 1.5339352d-05 /
      data fpp(21, 4, 8,1),fpp(21, 4, 8,2),fpp(21, 4, 8,3)/
     x-1.9478424d-02, 8.0776993d-05, 1.9245421d-05 /
      data fpp(21, 4, 9,1),fpp(21, 4, 9,2),fpp(21, 4, 9,3)/
     x-2.3847431d-02, 1.0122142d-04, 2.1234962d-05 /
      data fpp(21, 4,10,1),fpp(21, 4,10,2),fpp(21, 4,10,3)/
     x-2.6704732d-02, 1.1362939d-04, 2.1550729d-05 /
      data fpp(21, 4,11,1),fpp(21, 4,11,2),fpp(21, 4,11,3)/
     x-2.8356057d-02, 1.1974175d-04, 2.1334122d-05 /
      data fpp(21, 4,12,1),fpp(21, 4,12,2),fpp(21, 4,12,3)/
     x-2.8870448d-02, 1.2159451d-04, 2.1332783d-05 /
      data fpp(21, 4,13,1),fpp(21, 4,13,2),fpp(21, 4,13,3)/
     x-2.8276245d-02, 1.2013118d-04, 2.1812746d-05 /
      data fpp(21, 4,14,1),fpp(21, 4,14,2),fpp(21, 4,14,3)/
     x-2.6558286d-02, 1.1446107d-04, 2.2504232d-05 /
      data fpp(21, 4,15,1),fpp(21, 4,15,2),fpp(21, 4,15,3)/
     x-2.3651819d-02, 1.0253203d-04, 2.2630325d-05 /
      data fpp(21, 4,16,1),fpp(21, 4,16,2),fpp(21, 4,16,3)/
     x-1.9290902d-02, 8.2558953d-05, 2.0954468d-05 /
      data fpp(21, 4,17,1),fpp(21, 4,17,2),fpp(21, 4,17,3)/
     x-1.2451690d-02, 5.3201341d-05, 1.7361802d-05 /
      data fpp(21, 4,18,1),fpp(21, 4,18,2),fpp(21, 4,18,3)/
     x 3.8536292d-04, 1.2306532d-05, 7.1823231d-06 /
      data fpp(21, 4,19,1),fpp(21, 4,19,2),fpp(21, 4,19,3)/
     x 2.2906099d-02,-4.0921487d-05,-8.4410947d-06 /
      data fpp(21, 4,20,1),fpp(21, 4,20,2),fpp(21, 4,20,3)/
     x 5.0939288d-02,-9.4162808d-05,-7.5249944d-05 /
      data fpp(21, 4,21,1),fpp(21, 4,21,2),fpp(21, 4,21,3)/
     x 5.0939288d-02,-9.4162808d-05,-7.4511619d-05 /
      data fpp(21, 4,22,1),fpp(21, 4,22,2),fpp(21, 4,22,3)/
     x 2.2906099d-02,-4.0921487d-05,-1.1394394d-05 /
      data fpp(21, 4,23,1),fpp(21, 4,23,2),fpp(21, 4,23,3)/
     x 3.8536292d-04, 1.2306532d-05, 1.8257197d-05 /
      data fpp(21, 5, 1,1),fpp(21, 5, 1,2),fpp(21, 5, 1,3)/
     x 2.2621442d-03, 4.2213414d-05,-1.0390066d-06 /
      data fpp(21, 5, 2,1),fpp(21, 5, 2,2),fpp(21, 5, 2,3)/
     x 1.4883791d-02, 5.1875325d-05,-1.4291987d-05 /
      data fpp(21, 5, 3,1),fpp(21, 5, 3,2),fpp(21, 5, 3,3)/
     x 2.8655188d-02, 6.9455597d-05,-4.2713046d-05 /
      data fpp(21, 5, 4,1),fpp(21, 5, 4,2),fpp(21, 5, 4,3)/
     x 2.8655188d-02, 6.9455597d-05,-4.2674869d-05 /
      data fpp(21, 5, 5,1),fpp(21, 5, 5,2),fpp(21, 5, 5,3)/
     x 1.4883791d-02, 5.1875325d-05,-1.4444696d-05 /
      data fpp(21, 5, 6,1),fpp(21, 5, 6,2),fpp(21, 5, 6,3)/
     x 2.2621442d-03, 4.2213414d-05,-4.6634797d-07 /
      data fpp(21, 5, 7,1),fpp(21, 5, 7,2),fpp(21, 5, 7,3)/
     x-6.7950388d-03, 4.0580040d-05, 8.8400877d-06 /
      data fpp(21, 5, 8,1),fpp(21, 5, 8,2),fpp(21, 5, 8,3)/
     x-1.3191968d-02, 4.1794948d-05, 1.3165997d-05 /
      data fpp(21, 5, 9,1),fpp(21, 5, 9,2),fpp(21, 5, 9,3)/
     x-1.7694541d-02, 4.2880079d-05, 1.4863924d-05 /
      data fpp(21, 5,10,1),fpp(21, 5,10,2),fpp(21, 5,10,3)/
     x-2.0663254d-02, 4.3588741d-05, 1.5320307d-05 /
      data fpp(21, 5,11,1),fpp(21, 5,11,2),fpp(21, 5,11,3)/
     x-2.2326117d-02, 4.4352787d-05, 1.5690846d-05 /
      data fpp(21, 5,12,1),fpp(21, 5,12,2),fpp(21, 5,12,3)/
     x-2.2915739d-02, 4.4934606d-05, 1.6092307d-05 /
      data fpp(21, 5,13,1),fpp(21, 5,13,2),fpp(21, 5,13,3)/
     x-2.2544527d-02, 4.5046753d-05, 1.6425924d-05 /
      data fpp(21, 5,14,1),fpp(21, 5,14,2),fpp(21, 5,14,3)/
     x-2.1121524d-02, 4.5002748d-05, 1.6765996d-05 /
      data fpp(21, 5,15,1),fpp(21, 5,15,2),fpp(21, 5,15,3)/
     x-1.8434792d-02, 4.5049881d-05, 1.6950092d-05 /
      data fpp(21, 5,16,1),fpp(21, 5,16,2),fpp(21, 5,16,3)/
     x-1.4276455d-02, 4.4678099d-05, 1.5747634d-05 /
      data fpp(21, 5,17,1),fpp(21, 5,17,2),fpp(21, 5,17,3)/
     x-8.2747177d-03, 4.3868999d-05, 1.1715370d-05 /
      data fpp(21, 5,18,1),fpp(21, 5,18,2),fpp(21, 5,18,3)/
     x 4.2410554d-04, 4.5161478d-05, 1.9568851d-06 /
      data fpp(21, 5,19,1),fpp(21, 5,19,2),fpp(21, 5,19,3)/
     x 1.2967989d-02, 5.3448123d-05,-1.3368910d-05 /
      data fpp(21, 5,20,1),fpp(21, 5,20,2),fpp(21, 5,20,3)/
     x 2.7800186d-02, 6.9741823d-05,-4.7493243d-05 /
      data fpp(21, 5,21,1),fpp(21, 5,21,2),fpp(21, 5,21,3)/
     x 2.7800186d-02, 6.9741823d-05,-4.7464815d-05 /
      data fpp(21, 5,22,1),fpp(21, 5,22,2),fpp(21, 5,22,3)/
     x 1.2967989d-02, 5.3448123d-05,-1.3482624d-05 /
      data fpp(21, 5,23,1),fpp(21, 5,23,2),fpp(21, 5,23,3)/
     x 4.2410554d-04, 4.5161478d-05, 2.3833122d-06 /
      data fpp(21, 6, 1,1),fpp(21, 6, 1,2),fpp(21, 6, 1,3)/
     x 2.7513261d-03, 3.2455433d-05,-5.0082020d-06 /
      data fpp(21, 6, 2,1),fpp(21, 6, 2,2),fpp(21, 6, 2,3)/
     x 8.4057473d-03, 4.8798538d-05,-9.6750960d-06 /
      data fpp(21, 6, 3,1),fpp(21, 6, 3,2),fpp(21, 6, 3,3)/
     x 1.3130643d-02, 6.2743969d-05,-1.9753414d-05 /
      data fpp(21, 6, 4,1),fpp(21, 6, 4,2),fpp(21, 6, 4,3)/
     x 1.3130643d-02, 6.2743969d-05,-1.9617210d-05 /
      data fpp(21, 6, 5,1),fpp(21, 6, 5,2),fpp(21, 6, 5,3)/
     x 8.4057473d-03, 4.8798538d-05,-1.0219913d-05 /
      data fpp(21, 6, 6,1),fpp(21, 6, 6,2),fpp(21, 6, 6,3)/
     x 2.7513261d-03, 3.2455433d-05,-2.9651365d-06 /
      data fpp(21, 6, 7,1),fpp(21, 6, 7,2),fpp(21, 6, 7,3)/
     x-2.6133501d-03, 1.7735169d-05, 2.6524594d-06 /
      data fpp(21, 6, 8,1),fpp(21, 6, 8,2),fpp(21, 6, 8,3)/
     x-7.2025485d-03, 6.1792133d-06, 5.7472990d-06 /
      data fpp(21, 6, 9,1),fpp(21, 6, 9,2),fpp(21, 6, 9,3)/
     x-1.0816913d-02,-1.6977373d-06, 7.4123447d-06 /
      data fpp(21, 6,10,1),fpp(21, 6,10,2),fpp(21, 6,10,3)/
     x-1.3428986d-02,-6.2063517d-06, 8.5773222d-06 /
      data fpp(21, 6,11,1),fpp(21, 6,11,2),fpp(21, 6,11,3)/
     x-1.5094084d-02,-8.2888942d-06, 9.5303664d-06 /
      data fpp(21, 6,12,1),fpp(21, 6,12,2),fpp(21, 6,12,3)/
     x-1.5838473d-02,-8.6169300d-06, 1.0199212d-05 /
      data fpp(21, 6,13,1),fpp(21, 6,13,2),fpp(21, 6,13,3)/
     x-1.5663455d-02,-7.3861906d-06, 1.0530785d-05 /
      data fpp(21, 6,14,1),fpp(21, 6,14,2),fpp(21, 6,14,3)/
     x-1.4557882d-02,-4.5340578d-06, 1.0503649d-05 /
      data fpp(21, 6,15,1),fpp(21, 6,15,2),fpp(21, 6,15,3)/
     x-1.2483574d-02, 4.4444594d-07, 1.0106619d-05 /
      data fpp(21, 6,16,1),fpp(21, 6,16,2),fpp(21, 6,16,3)/
     x-9.3261885d-03, 8.3326525d-06, 8.9078735d-06 /
      data fpp(21, 6,17,1),fpp(21, 6,17,2),fpp(21, 6,17,3)/
     x-5.0068992d-03, 1.9374664d-05, 5.7838866d-06 /
      data fpp(21, 6,18,1),fpp(21, 6,18,2),fpp(21, 6,18,3)/
     x 4.0609794d-04, 3.3169557d-05,-8.7342000d-07 /
      data fpp(21, 6,19,1),fpp(21, 6,19,2),fpp(21, 6,19,3)/
     x 6.5505777d-03, 4.8624994d-05,-1.0288207d-05 /
      data fpp(21, 6,20,1),fpp(21, 6,20,2),fpp(21, 6,20,3)/
     x 1.2047164d-02, 6.2173516d-05,-2.4057753d-05 /
      data fpp(21, 6,21,1),fpp(21, 6,21,2),fpp(21, 6,21,3)/
     x 1.2047164d-02, 6.2173516d-05,-2.4199636d-05 /
      data fpp(21, 6,22,1),fpp(21, 6,22,2),fpp(21, 6,22,3)/
     x 6.5505777d-03, 4.8624994d-05,-9.7206753d-06 /
      data fpp(21, 6,23,1),fpp(21, 6,23,2),fpp(21, 6,23,3)/
     x 4.0609794d-04, 3.3169557d-05,-3.0016623d-06 /
      data fpp(21, 7, 1,1),fpp(21, 7, 1,2),fpp(21, 7, 1,3)/
     x 2.6092419d-03, 1.7264852d-05,-3.7076462d-06 /
      data fpp(21, 7, 2,1),fpp(21, 7, 2,2),fpp(21, 7, 2,3)/
     x 4.9166208d-03, 3.0298522d-05,-4.8247076d-06 /
      data fpp(21, 7, 3,1),fpp(21, 7, 3,2),fpp(21, 7, 3,3)/
     x 6.5673288d-03, 4.0744528d-05,-7.2575235d-06 /
      data fpp(21, 7, 4,1),fpp(21, 7, 4,2),fpp(21, 7, 4,3)/
     x 6.5673288d-03, 4.0744528d-05,-7.1890758d-06 /
      data fpp(21, 7, 5,1),fpp(21, 7, 5,2),fpp(21, 7, 5,3)/
     x 4.9166208d-03, 3.0298522d-05,-5.0984982d-06 /
      data fpp(21, 7, 6,1),fpp(21, 7, 6,2),fpp(21, 7, 6,3)/
     x 2.6092419d-03, 1.7264852d-05,-2.6809314d-06 /
      data fpp(21, 7, 7,1),fpp(21, 7, 7,2),fpp(21, 7, 7,3)/
     x 1.8382035d-05, 4.7772835d-06,-4.9777636d-07 /
      data fpp(21, 7, 8,1),fpp(21, 7, 8,2),fpp(21, 7, 8,3)/
     x-2.5690225d-03,-5.3958017d-06, 1.2160368d-06 /
      data fpp(21, 7, 9,1),fpp(21, 7, 9,2),fpp(21, 7, 9,3)/
     x-4.9586675d-03,-1.2917130d-05, 2.6116291d-06 /
      data fpp(21, 7,10,1),fpp(21, 7,10,2),fpp(21, 7,10,3)/
     x-6.9698036d-03,-1.8067334d-05, 3.8114466d-06 /
      data fpp(21, 7,11,1),fpp(21, 7,11,2),fpp(21, 7,11,3)/
     x-8.4422693d-03,-2.0965210d-05, 4.8225843d-06 /
      data fpp(21, 7,12,1),fpp(21, 7,12,2),fpp(21, 7,12,3)/
     x-9.2460723d-03,-2.1632886d-05, 5.5842162d-06 /
      data fpp(21, 7,13,1),fpp(21, 7,13,2),fpp(21, 7,13,3)/
     x-9.3284251d-03,-2.0163990d-05, 5.9725509d-06 /
      data fpp(21, 7,14,1),fpp(21, 7,14,2),fpp(21, 7,14,3)/
     x-8.6790871d-03,-1.6672517d-05, 5.9675801d-06 /
      data fpp(21, 7,15,1),fpp(21, 7,15,2),fpp(21, 7,15,3)/
     x-7.3326593d-03,-1.1265664d-05, 5.5331285d-06 /
      data fpp(21, 7,16,1),fpp(21, 7,16,2),fpp(21, 7,16,3)/
     x-5.3323620d-03,-3.8667086d-06, 4.4739058d-06 /
      data fpp(21, 7,17,1),fpp(21, 7,17,2),fpp(21, 7,17,3)/
     x-2.7349056d-03, 5.8023437d-06, 2.4072483d-06 /
      data fpp(21, 7,18,1),fpp(21, 7,18,2),fpp(21, 7,18,3)/
     x 2.9736262d-04, 1.7520293d-05,-1.1668989d-06 /
      data fpp(21, 7,19,1),fpp(21, 7,19,2),fpp(21, 7,19,3)/
     x 3.3835664d-03, 2.9761900d-05,-5.7496528d-06 /
      data fpp(21, 7,20,1),fpp(21, 7,20,2),fpp(21, 7,20,3)/
     x 5.8096880d-03, 3.9704114d-05,-1.0910490d-05 /
      data fpp(21, 7,21,1),fpp(21, 7,21,2),fpp(21, 7,21,3)/
     x 5.8096880d-03, 3.9704114d-05,-1.1013703d-05 /
      data fpp(21, 7,22,1),fpp(21, 7,22,2),fpp(21, 7,22,3)/
     x 3.3835664d-03, 2.9761900d-05,-5.3367990d-06 /
      data fpp(21, 7,23,1),fpp(21, 7,23,2),fpp(21, 7,23,3)/
     x 2.9736262d-04, 1.7520293d-05,-2.7151005d-06 /
      data fpp(21, 8, 1,1),fpp(21, 8, 1,2),fpp(21, 8, 1,3)/
     x 2.7166439d-03, 5.6091571d-06,-1.6688078d-06 /
      data fpp(21, 8, 2,1),fpp(21, 8, 2,2),fpp(21, 8, 2,3)/
     x 3.5670647d-03, 1.3361374d-05,-1.8578845d-06 /
      data fpp(21, 8, 3,1),fpp(21, 8, 3,2),fpp(21, 8, 3,3)/
     x 3.5645409d-03, 1.9557918d-05,-2.2696543d-06 /
      data fpp(21, 8, 4,1),fpp(21, 8, 4,2),fpp(21, 8, 4,3)/
     x 3.5645409d-03, 1.9557918d-05,-2.2580948d-06 /
      data fpp(21, 8, 5,1),fpp(21, 8, 5,2),fpp(21, 8, 5,3)/
     x 3.5670647d-03, 1.3361374d-05,-1.9041226d-06 /
      data fpp(21, 8, 6,1),fpp(21, 8, 6,2),fpp(21, 8, 6,3)/
     x 2.7166439d-03, 5.6091571d-06,-1.4954147d-06 /
      data fpp(21, 8, 7,1),fpp(21, 8, 7,2),fpp(21, 8, 7,3)/
     x 1.6383943d-03,-1.7623029d-06,-1.1382185d-06 /
      data fpp(21, 8, 8,1),fpp(21, 8, 8,2),fpp(21, 8, 8,3)/
     x 3.6617562d-04,-7.9000065d-06,-5.9971124d-07 /
      data fpp(21, 8, 9,1),fpp(21, 8, 9,2),fpp(21, 8, 9,3)/
     x-1.0083490d-03,-1.2561744d-05, 2.0106349d-07 /
      data fpp(21, 8,10,1),fpp(21, 8,10,2),fpp(21, 8,10,3)/
     x-2.3496780d-03,-1.5670314d-05, 1.1754573d-06 /
      data fpp(21, 8,11,1),fpp(21, 8,11,2),fpp(21, 8,11,3)/
     x-3.4727256d-03,-1.7308266d-05, 2.1111073d-06 /
      data fpp(21, 8,12,1),fpp(21, 8,12,2),fpp(21, 8,12,3)/
     x-4.2290667d-03,-1.7633527d-05, 2.8421135d-06 /
      data fpp(21, 8,13,1),fpp(21, 8,13,2),fpp(21, 8,13,3)/
     x-4.5379315d-03,-1.6765848d-05, 3.2244387d-06 /
      data fpp(21, 8,14,1),fpp(21, 8,14,2),fpp(21, 8,14,3)/
     x-4.3626375d-03,-1.4665876d-05, 3.2621315d-06 /
      data fpp(21, 8,15,1),fpp(21, 8,15,2),fpp(21, 8,15,3)/
     x-3.7194583d-03,-1.1187789d-05, 2.9930351d-06 /
      data fpp(21, 8,16,1),fpp(21, 8,16,2),fpp(21, 8,16,3)/
     x-2.6295671d-03,-6.3238182d-06, 2.3397282d-06 /
      data fpp(21, 8,17,1),fpp(21, 8,17,2),fpp(21, 8,17,3)/
     x-1.1755355d-03,-3.4403916d-07, 1.1480522d-06 /
      data fpp(21, 8,18,1),fpp(21, 8,18,2),fpp(21, 8,18,3)/
     x 4.4504810d-04, 6.1892715d-06,-7.2793680d-07 /
      data fpp(21, 8,19,1),fpp(21, 8,19,2),fpp(21, 8,19,3)/
     x 2.0118587d-03, 1.2381405d-05,-2.8443049d-06 /
      data fpp(21, 8,20,1),fpp(21, 8,20,2),fpp(21, 8,20,3)/
     x 3.1704300d-03, 1.6856028d-05,-4.7848434d-06 /
      data fpp(21, 8,21,1),fpp(21, 8,21,2),fpp(21, 8,21,3)/
     x 3.1704300d-03, 1.6856028d-05,-4.8423173d-06 /
      data fpp(21, 8,22,1),fpp(21, 8,22,2),fpp(21, 8,22,3)/
     x 2.0118587d-03, 1.2381405d-05,-2.6144093d-06 /
      data fpp(21, 8,23,1),fpp(21, 8,23,2),fpp(21, 8,23,3)/
     x 4.4504810d-04, 6.1892715d-06,-1.5900453d-06 /
      data fpp(21, 9, 1,1),fpp(21, 9, 1,2),fpp(21, 9, 1,3)/
     x 3.1317621d-03,-3.0548080d-07, 1.0080578d-06 /
      data fpp(21, 9, 2,1),fpp(21, 9, 2,2),fpp(21, 9, 2,3)/
     x 3.7287249d-03, 5.0259807d-06,-2.3115632d-08 /
      data fpp(21, 9, 3,1),fpp(21, 9, 3,2),fpp(21, 9, 3,3)/
     x 3.7414864d-03, 1.0347801d-05,-2.2115953d-06 /
      data fpp(21, 9, 4,1),fpp(21, 9, 4,2),fpp(21, 9, 4,3)/
     x 3.7414864d-03, 1.0347801d-05,-2.2486563d-06 /
      data fpp(21, 9, 5,1),fpp(21, 9, 5,2),fpp(21, 9, 5,3)/
     x 3.7287249d-03, 5.0259807d-06, 1.2512851d-07 /
      data fpp(21, 9, 6,1),fpp(21, 9, 6,2),fpp(21, 9, 6,3)/
     x 3.1317621d-03,-3.0548080d-07, 4.5214228d-07 /
      data fpp(21, 9, 7,1),fpp(21, 9, 7,2),fpp(21, 9, 7,3)/
     x 2.5686471d-03,-4.2620718d-06,-2.1769762d-07 /
      data fpp(21, 9, 8,1),fpp(21, 9, 8,2),fpp(21, 9, 8,3)/
     x 1.9635352d-03,-6.8761722d-06,-8.2935179d-07 /
      data fpp(21, 9, 9,1),fpp(21, 9, 9,2),fpp(21, 9, 9,3)/
     x 1.2272147d-03,-8.6258929d-06,-6.9489522d-07 /
      data fpp(21, 9,10,1),fpp(21, 9,10,2),fpp(21, 9,10,3)/
     x 3.7580864d-04,-9.8694123d-06,-1.5067313d-08 /
      data fpp(21, 9,11,1),fpp(21, 9,11,2),fpp(21, 9,11,3)/
     x-4.7670949d-04,-1.0607725d-05, 7.4316448d-07 /
      data fpp(21, 9,12,1),fpp(21, 9,12,2),fpp(21, 9,12,3)/
     x-1.1667869d-03,-1.0757005d-05, 1.3504094d-06 /
      data fpp(21, 9,13,1),fpp(21, 9,13,2),fpp(21, 9,13,3)/
     x-1.5712041d-03,-1.0212616d-05, 1.7331979d-06 /
      data fpp(21, 9,14,1),fpp(21, 9,14,2),fpp(21, 9,14,3)/
     x-1.6413828d-03,-8.9939787d-06, 1.9047991d-06 /
      data fpp(21, 9,15,1),fpp(21, 9,15,2),fpp(21, 9,15,3)/
     x-1.3897879d-03,-7.1811805d-06, 1.8256059d-06 /
      data fpp(21, 9,16,1),fpp(21, 9,16,2),fpp(21, 9,16,3)/
     x-8.3918498d-04,-4.8100188d-06, 1.4607774d-06 /
      data fpp(21, 9,17,1),fpp(21, 9,17,2),fpp(21, 9,17,3)/
     x-3.1848580d-05,-1.9421871d-06, 7.2528453d-07 /
      data fpp(21, 9,18,1),fpp(21, 9,18,2),fpp(21, 9,18,3)/
     x 8.9114664d-04, 1.1806211d-06,-3.7191553d-07 /
      data fpp(21, 9,19,1),fpp(21, 9,19,2),fpp(21, 9,19,3)/
     x 1.7828124d-03, 4.0404797d-06,-1.5476224d-06 /
      data fpp(21, 9,20,1),fpp(21, 9,20,2),fpp(21, 9,20,3)/
     x 2.4453700d-03, 6.0317728d-06,-2.1795948d-06 /
      data fpp(21, 9,21,1),fpp(21, 9,21,2),fpp(21, 9,21,3)/
     x 2.4453700d-03, 6.0317728d-06,-2.2214043d-06 /
      data fpp(21, 9,22,1),fpp(21, 9,22,2),fpp(21, 9,22,3)/
     x 1.7828124d-03, 4.0404797d-06,-1.3803845d-06 /
      data fpp(21, 9,23,1),fpp(21, 9,23,2),fpp(21, 9,23,3)/
     x 8.9114664d-04, 1.1806211d-06,-9.9905776d-07 /
      data fpp(21,10, 1,1),fpp(21,10, 1,2),fpp(21,10, 1,3)/
     x 3.1165864d-03,-2.5512339d-06, 6.0829782d-06 /
      data fpp(21,10, 2,1),fpp(21,10, 2,2),fpp(21,10, 2,3)/
     x 4.2800638d-03, 9.5670281d-07, 2.1440436d-06 /
      data fpp(21,10, 3,1),fpp(21,10, 3,2),fpp(21,10, 3,3)/
     x 6.5167337d-03, 5.7288787d-06,-6.2111526d-06 /
      data fpp(21,10, 4,1),fpp(21,10, 4,2),fpp(21,10, 4,3)/
     x 6.5167337d-03, 5.7288787d-06,-6.3605639d-06 /
      data fpp(21,10, 5,1),fpp(21,10, 5,2),fpp(21,10, 5,3)/
     x 4.2800638d-03, 9.5670281d-07, 2.7416885d-06 /
      data fpp(21,10, 6,1),fpp(21,10, 6,2),fpp(21,10, 6,3)/
     x 3.1165864d-03,-2.5512339d-06, 3.8418100d-06 /
      data fpp(21,10, 7,1),fpp(21,10, 7,2),fpp(21,10, 7,3)/
     x 2.6622073d-03,-4.2654099d-06, 2.0210714d-06 /
      data fpp(21,10, 8,1),fpp(21,10, 8,2),fpp(21,10, 8,3)/
     x 2.4386146d-03,-5.0233047d-06,-2.1409568d-07 /
      data fpp(21,10, 9,1),fpp(21,10, 9,2),fpp(21,10, 9,3)/
     x 2.1314847d-03,-5.4346839d-06,-1.0086887d-06 /
      data fpp(21,10,10,1),fpp(21,10,10,2),fpp(21,10,10,3)/
     x 1.6579560d-03,-5.6920375d-06,-6.4714961d-07 /
      data fpp(21,10,11,1),fpp(21,10,11,2),fpp(21,10,11,3)/
     x 1.0651628d-03,-5.9668352d-06, 3.3287098d-08 /
      data fpp(21,10,12,1),fpp(21,10,12,2),fpp(21,10,12,3)/
     x 4.9637096d-04,-5.9924518d-06, 5.8600121d-07 /
      data fpp(21,10,13,1),fpp(21,10,13,2),fpp(21,10,13,3)/
     x 8.7044493d-05,-5.7016870d-06, 9.5870805d-07 /
      data fpp(21,10,14,1),fpp(21,10,14,2),fpp(21,10,14,3)/
     x-8.3074959d-05,-5.0742090d-06, 1.2191666d-06 /
      data fpp(21,10,15,1),fpp(21,10,15,2),fpp(21,10,15,3)/
     x 6.9233563d-06,-4.1514892d-06, 1.3046256d-06 /
      data fpp(21,10,16,1),fpp(21,10,16,2),fpp(21,10,16,3)/
     x 3.4550967d-04,-3.0321067d-06, 1.1403310d-06 /
      data fpp(21,10,17,1),fpp(21,10,17,2),fpp(21,10,17,3)/
     x 8.7312767d-04,-1.8292126d-06, 6.0805043d-07 /
      data fpp(21,10,18,1),fpp(21,10,18,2),fpp(21,10,18,3)/
     x 1.5000393d-03,-6.3975606d-07,-2.3653270d-07 /
      data fpp(21,10,19,1),fpp(21,10,19,2),fpp(21,10,19,3)/
     x 2.1068788d-03, 4.3067612d-07,-1.1859196d-06 /
      data fpp(21,10,20,1),fpp(21,10,20,2),fpp(21,10,20,3)/
     x 2.5569060d-03, 1.2028804d-06,-1.1037887d-06 /
      data fpp(21,10,21,1),fpp(21,10,21,2),fpp(21,10,21,3)/
     x 2.5569060d-03, 1.2028804d-06,-1.1506739d-06 /
      data fpp(21,10,22,1),fpp(21,10,22,2),fpp(21,10,22,3)/
     x 2.1068788d-03, 4.3067612d-07,-9.9837887d-07 /
      data fpp(21,10,23,1),fpp(21,10,23,2),fpp(21,10,23,3)/
     x 1.5000393d-03,-6.3975606d-07,-9.3981056d-07 /
      data fpp(21,11, 1,1),fpp(21,11, 1,2),fpp(21,11, 1,3)/
     x 1.9574975d-03,-5.1158364d-07, 1.4621796d-05 /
      data fpp(21,11, 2,1),fpp(21,11, 2,2),fpp(21,11, 2,3)/
     x 4.3266917d-03, 1.1072080d-06, 5.5719072d-06 /
      data fpp(21,11, 3,1),fpp(21,11, 3,2),fpp(21,11, 3,3)/
     x 9.6851790d-03, 2.7966841d-06,-1.3599425d-05 /
      data fpp(21,11, 4,1),fpp(21,11, 4,2),fpp(21,11, 4,3)/
     x 9.6851790d-03, 2.7966841d-06,-1.3986678d-05 /
      data fpp(21,11, 5,1),fpp(21,11, 5,2),fpp(21,11, 5,3)/
     x 4.3266917d-03, 1.1072080d-06, 7.1209197d-06 /
      data fpp(21,11, 6,1),fpp(21,11, 6,2),fpp(21,11, 6,3)/
     x 1.9574975d-03,-5.1158364d-07, 8.8129994d-06 /
      data fpp(21,11, 7,1),fpp(21,11, 7,2),fpp(21,11, 7,3)/
     x 1.6135966d-03,-1.6742887d-06, 5.1770828d-06 /
      data fpp(21,11, 8,1),fpp(21,11, 8,2),fpp(21,11, 8,3)/
     x 1.9167441d-03,-2.4006090d-06, 7.5466948d-07 /
      data fpp(21,11, 9,1),fpp(21,11, 9,2),fpp(21,11, 9,3)/
     x 2.1065551d-03,-2.8333714d-06,-1.1097607d-06 /
      data fpp(21,11,10,1),fpp(21,11,10,2),fpp(21,11,10,3)/
     x 1.9515541d-03,-3.1284379d-06,-1.2236267d-06 /
      data fpp(21,11,11,1),fpp(21,11,11,2),fpp(21,11,11,3)/
     x 1.7201507d-03,-3.1269345d-06,-3.7973252d-07 /
      data fpp(21,11,12,1),fpp(21,11,12,2),fpp(21,11,12,3)/
     x 1.3243116d-03,-3.1271877d-06, 1.6255678d-07 /
      data fpp(21,11,13,1),fpp(21,11,13,2),fpp(21,11,13,3)/
     x 9.7812484d-04,-3.0526358d-06, 5.5750542d-07 /
      data fpp(21,11,14,1),fpp(21,11,14,2),fpp(21,11,14,3)/
     x 8.0898827d-04,-2.8451852d-06, 8.5342155d-07 /
      data fpp(21,11,15,1),fpp(21,11,15,2),fpp(21,11,15,3)/
     x 8.5525208d-04,-2.5228626d-06, 1.0208084d-06 /
      data fpp(21,11,16,1),fpp(21,11,16,2),fpp(21,11,16,3)/
     x 1.1273318d-03,-2.1415545d-06, 9.5534492d-07 /
      data fpp(21,11,17,1),fpp(21,11,17,2),fpp(21,11,17,3)/
     x 1.5592306d-03,-1.7749627d-06, 5.2781195d-07 /
      data fpp(21,11,18,1),fpp(21,11,18,2),fpp(21,11,18,3)/
     x 2.0633429d-03,-1.4355969d-06,-2.1059273d-07 /
      data fpp(21,11,19,1),fpp(21,11,19,2),fpp(21,11,19,3)/
     x 2.5583086d-03,-1.0531842d-06,-1.1194410d-06 /
      data fpp(21,11,20,1),fpp(21,11,20,2),fpp(21,11,20,3)/
     x 2.9267533d-03,-5.5929437d-07,-6.8764320d-07 /
      data fpp(21,11,21,1),fpp(21,11,21,2),fpp(21,11,21,3)/
     x 2.9267533d-03,-5.5929437d-07,-7.4034988d-07 /
      data fpp(21,11,22,1),fpp(21,11,22,2),fpp(21,11,22,3)/
     x 2.5583086d-03,-1.0531842d-06,-9.0861432d-07 /
      data fpp(21,11,23,1),fpp(21,11,23,2),fpp(21,11,23,3)/
     x 2.0633429d-03,-1.4355969d-06,-1.0011928d-06 /
      data fpp(21,12, 1,1),fpp(21,12, 1,2),fpp(21,12, 1,3)/
     x 4.6453052d-04, 4.4895685d-06, 2.3162530d-05 /
      data fpp(21,12, 2,1),fpp(21,12, 2,2),fpp(21,12, 2,3)/
     x 4.7716876d-03, 2.4204650d-06, 8.7639395d-06 /
      data fpp(21,12, 3,1),fpp(21,12, 3,2),fpp(21,12, 3,3)/
     x 1.5696517d-02,-2.8876153d-06,-2.1738288d-05 /
      data fpp(21,12, 4,1),fpp(21,12, 4,2),fpp(21,12, 4,3)/
     x 1.5696517d-02,-2.8876153d-06,-2.2354105d-05 /
      data fpp(21,12, 5,1),fpp(21,12, 5,2),fpp(21,12, 5,3)/
     x 4.7716876d-03, 2.4204650d-06, 1.1227207d-05 /
      data fpp(21,12, 6,1),fpp(21,12, 6,2),fpp(21,12, 6,3)/
     x 4.6453052d-04, 4.4895685d-06, 1.3925276d-05 /
      data fpp(21,12, 7,1),fpp(21,12, 7,2),fpp(21,12, 7,3)/
     x-3.5596313d-05, 3.5525649d-06, 8.6536874d-06 /
      data fpp(21,12, 8,1),fpp(21,12, 8,2),fpp(21,12, 8,3)/
     x 7.8940076d-04, 1.6717406d-06, 2.0579739d-06 /
      data fpp(21,12, 9,1),fpp(21,12, 9,2),fpp(21,12, 9,3)/
     x 1.5298685d-03, 1.1216951d-07,-1.0275830d-06 /
      data fpp(21,12,10,1),fpp(21,12,10,2),fpp(21,12,10,3)/
     x 1.8489273d-03,-7.4221099d-07,-1.4576421d-06 /
      data fpp(21,12,11,1),fpp(21,12,11,2),fpp(21,12,11,3)/
     x 1.8355595d-03,-1.2054269d-06,-7.8584878d-07 /
      data fpp(21,12,12,1),fpp(21,12,12,2),fpp(21,12,12,3)/
     x 1.6349007d-03,-1.4067975d-06,-1.2696282d-07 /
      data fpp(21,12,13,1),fpp(21,12,13,2),fpp(21,12,13,3)/
     x 1.4101305d-03,-1.5217700d-06, 3.1570006d-07 /
      data fpp(21,12,14,1),fpp(21,12,14,2),fpp(21,12,14,3)/
     x 1.2899994d-03,-1.5930502d-06, 6.2816257d-07 /
      data fpp(21,12,15,1),fpp(21,12,15,2),fpp(21,12,15,3)/
     x 1.3546356d-03,-1.6210602d-06, 8.1364966d-07 /
      data fpp(21,12,16,1),fpp(21,12,16,2),fpp(21,12,16,3)/
     x 1.6157728d-03,-1.6376753d-06, 7.6723881d-07 /
      data fpp(21,12,17,1),fpp(21,12,17,2),fpp(21,12,17,3)/
     x 2.0117913d-03,-1.6489367d-06, 4.1339512d-07 /
      data fpp(21,12,18,1),fpp(21,12,18,2),fpp(21,12,18,3)/
     x 2.4583215d-03,-1.6878563d-06,-1.9481929d-07 /
      data fpp(21,12,19,1),fpp(21,12,19,2),fpp(21,12,19,3)/
     x 2.8812975d-03,-1.7139394d-06,-9.1211796d-07 /
      data fpp(21,12,20,1),fpp(21,12,20,2),fpp(21,12,20,3)/
     x 3.1873633d-03,-1.7017029d-06,-6.3870888d-07 /
      data fpp(21,12,21,1),fpp(21,12,21,2),fpp(21,12,21,3)/
     x 3.1873633d-03,-1.7017029d-06,-6.7881439d-07 /
      data fpp(21,12,22,1),fpp(21,12,22,2),fpp(21,12,22,3)/
     x 2.8812975d-03,-1.7139394d-06,-7.5169589d-07 /
      data fpp(21,12,23,1),fpp(21,12,23,2),fpp(21,12,23,3)/
     x 2.4583215d-03,-1.6878563d-06,-7.9640206d-07 /
      data fpp(21,13, 1,1),fpp(21,13, 1,2),fpp(21,13, 1,3)/
     x 2.5505890d-04, 4.8673098d-06, 2.4834211d-05 /
      data fpp(21,13, 2,1),fpp(21,13, 2,2),fpp(21,13, 2,3)/
     x 6.4284751d-03,-2.3830681d-06, 8.6250770d-06 /
      data fpp(21,13, 3,1),fpp(21,13, 3,2),fpp(21,13, 3,3)/
     x 1.8093863d-02,-1.2840223d-05,-2.5776520d-05 /
      data fpp(21,13, 4,1),fpp(21,13, 4,2),fpp(21,13, 4,3)/
     x 1.8093863d-02,-1.2840223d-05,-2.6357980d-05 /
      data fpp(21,13, 5,1),fpp(21,13, 5,2),fpp(21,13, 5,3)/
     x 6.4284751d-03,-2.3830681d-06, 1.0950919d-05 /
      data fpp(21,13, 6,1),fpp(21,13, 6,2),fpp(21,13, 6,3)/
     x 2.5505890d-04, 4.8673098d-06, 1.6112304d-05 /
      data fpp(21,13, 7,1),fpp(21,13, 7,2),fpp(21,13, 7,3)/
     x-1.0271534d-03, 6.6100293d-06, 1.1137864d-05 /
      data fpp(21,13, 8,1),fpp(21,13, 8,2),fpp(21,13, 8,3)/
     x-1.8007383d-04, 5.0976467d-06, 3.6622399d-06 /
      data fpp(21,13, 9,1),fpp(21,13, 9,2),fpp(21,13, 9,3)/
     x 8.7011333d-04, 2.9006934d-06,-2.6282344d-07 /
      data fpp(21,13,10,1),fpp(21,13,10,2),fpp(21,13,10,3)/
     x 1.4614467d-03, 1.1832818d-06,-1.2849461d-06 /
      data fpp(21,13,11,1),fpp(21,13,11,2),fpp(21,13,11,3)/
     x 1.6566531d-03, 1.7264216d-07,-9.3339210d-07 /
      data fpp(21,13,12,1),fpp(21,13,12,2),fpp(21,13,12,3)/
     x 1.6324361d-03,-3.5962229d-07,-3.3348547d-07 /
      data fpp(21,13,13,1),fpp(21,13,13,2),fpp(21,13,13,3)/
     x 1.5349096d-03,-6.5828437d-07, 1.3733397d-07 /
      data fpp(21,13,14,1),fpp(21,13,14,2),fpp(21,13,14,3)/
     x 1.4987456d-03,-8.6861387d-07, 4.6214958d-07 /
      data fpp(21,13,15,1),fpp(21,13,15,2),fpp(21,13,15,3)/
     x 1.5924379d-03,-1.0488964d-06, 6.2406770d-07 /
      data fpp(21,13,16,1),fpp(21,13,16,2),fpp(21,13,16,3)/
     x 1.8412522d-03,-1.2077443d-06, 5.7557963d-07 /
      data fpp(21,13,17,1),fpp(21,13,17,2),fpp(21,13,17,3)/
     x 2.1918126d-03,-1.3972905d-06, 2.7161378d-07 /
      data fpp(21,13,18,1),fpp(21,13,18,2),fpp(21,13,18,3)/
     x 2.5821812d-03,-1.5569778d-06,-1.7403475d-07 /
      data fpp(21,13,19,1),fpp(21,13,19,2),fpp(21,13,19,3)/
     x 2.9383078d-03,-1.7630583d-06,-6.4947479d-07 /
      data fpp(21,13,20,1),fpp(21,13,20,2),fpp(21,13,20,3)/
     x 3.1910583d-03,-2.0478940d-06,-6.3006608d-07 /
      data fpp(21,13,21,1),fpp(21,13,21,2),fpp(21,13,21,3)/
     x 3.1910583d-03,-2.0478940d-06,-6.5306437d-07 /
      data fpp(21,13,22,1),fpp(21,13,22,2),fpp(21,13,22,3)/
     x 2.9383078d-03,-1.7630583d-06,-5.5748161d-07 /
      data fpp(21,13,23,1),fpp(21,13,23,2),fpp(21,13,23,3)/
     x 2.5821812d-03,-1.5569778d-06,-5.1900920d-07 /
      data fpp(21,14, 1,1),fpp(21,14, 1,2),fpp(21,14, 1,3)/
     x 1.6411956d-03,-7.6280766d-07, 1.7777608d-05 /
      data fpp(21,14, 2,1),fpp(21,14, 2,2),fpp(21,14, 2,3)/
     x 8.4211154d-03,-8.2961927d-06, 4.8732834d-06 /
      data fpp(21,14, 3,1),fpp(21,14, 3,2),fpp(21,14, 3,3)/
     x 1.9428843d-02,-1.5729492d-05,-2.2600742d-05 /
      data fpp(21,14, 4,1),fpp(21,14, 4,2),fpp(21,14, 4,3)/
     x 1.9428843d-02,-1.5729492d-05,-2.2912416d-05 /
      data fpp(21,14, 5,1),fpp(21,14, 5,2),fpp(21,14, 5,3)/
     x 8.4211154d-03,-8.2961927d-06, 6.1199803d-06 /
      data fpp(21,14, 6,1),fpp(21,14, 6,2),fpp(21,14, 6,3)/
     x 1.6411956d-03,-7.6280766d-07, 1.3102495d-05 /
      data fpp(21,14, 7,1),fpp(21,14, 7,2),fpp(21,14, 7,3)/
     x-5.0720370d-04, 3.5473178d-06, 1.0704040d-05 /
      data fpp(21,14, 8,1),fpp(21,14, 8,2),fpp(21,14, 8,3)/
     x-2.1380213d-04, 4.4936728d-06, 4.8073436d-06 /
      data fpp(21,14, 9,1),fpp(21,14, 9,2),fpp(21,14, 9,3)/
     x 6.2458784d-04, 3.6030570d-06, 1.0025854d-06 /
      data fpp(21,14,10,1),fpp(21,14,10,2),fpp(21,14,10,3)/
     x 1.1982223d-03, 2.2550836d-06,-4.8968505d-07 /
      data fpp(21,14,11,1),fpp(21,14,11,2),fpp(21,14,11,3)/
     x 1.4382503d-03, 1.1148583d-06,-6.4584516d-07 /
      data fpp(21,14,12,1),fpp(21,14,12,2),fpp(21,14,12,3)/
     x 1.4932912d-03, 3.6728665d-07,-3.3493431d-07 /
      data fpp(21,14,13,1),fpp(21,14,13,2),fpp(21,14,13,3)/
     x 1.4971027d-03,-6.3092568d-08, 4.1582392d-08 /
      data fpp(21,14,14,1),fpp(21,14,14,2),fpp(21,14,14,3)/
     x 1.5265335d-03,-3.3249429d-07, 3.1860474d-07 /
      data fpp(21,14,15,1),fpp(21,14,15,2),fpp(21,14,15,3)/
     x 1.6359874d-03,-5.6735419d-07, 4.5999864d-07 /
      data fpp(21,14,16,1),fpp(21,14,16,2),fpp(21,14,16,3)/
     x 1.8213594d-03,-7.9734757d-07, 3.6140069d-07 /
      data fpp(21,14,17,1),fpp(21,14,17,2),fpp(21,14,17,3)/
     x 2.1306402d-03,-9.3390145d-07, 1.7039859d-07 /
      data fpp(21,14,18,1),fpp(21,14,18,2),fpp(21,14,18,3)/
     x 2.4413324d-03,-1.0422324d-06,-1.7299505d-07 /
      data fpp(21,14,19,1),fpp(21,14,19,2),fpp(21,14,19,3)/
     x 2.7115877d-03,-1.1038275d-06,-4.7441838d-07 /
      data fpp(21,14,20,1),fpp(21,14,20,2),fpp(21,14,20,3)/
     x 2.9026002d-03,-1.1047212d-06,-4.6733144d-07 /
      data fpp(21,14,21,1),fpp(21,14,21,2),fpp(21,14,21,3)/
     x 2.9026002d-03,-1.1047212d-06,-4.8179650d-07 /
      data fpp(21,14,22,1),fpp(21,14,22,2),fpp(21,14,22,3)/
     x 2.7115877d-03,-1.1038275d-06,-4.1655814d-07 /
      data fpp(21,14,23,1),fpp(21,14,23,2),fpp(21,14,23,3)/
     x 2.4413324d-03,-1.0422324d-06,-3.8997093d-07 /
      data fpp(21,15, 1,1),fpp(21,15, 1,2),fpp(21,15, 1,3)/
     x 3.9500735d-03,-6.9880792d-06, 7.6506262d-06 /
      data fpp(21,15, 2,1),fpp(21,15, 2,2),fpp(21,15, 2,3)/
     x 9.7898683d-03,-8.8441611d-06, 6.1224760d-07 /
      data fpp(21,15, 3,1),fpp(21,15, 3,2),fpp(21,15, 3,3)/
     x 1.8910369d-02,-8.0138073d-06,-1.4437617d-05 /
      data fpp(21,15, 4,1),fpp(21,15, 4,2),fpp(21,15, 4,3)/
     x 1.8910369d-02,-8.0138073d-06,-1.4494274d-05 /
      data fpp(21,15, 5,1),fpp(21,15, 5,2),fpp(21,15, 5,3)/
     x 9.7898683d-03,-8.8441611d-06, 8.3887741d-07 /
      data fpp(21,15, 6,1),fpp(21,15, 6,2),fpp(21,15, 6,3)/
     x 3.9500735d-03,-6.9880792d-06, 6.8007644d-06 /
      data fpp(21,15, 7,1),fpp(21,15, 7,2),fpp(21,15, 7,3)/
     x 1.4577043d-03,-3.4353006d-06, 7.1840650d-06 /
      data fpp(21,15, 8,1),fpp(21,15, 8,2),fpp(21,15, 8,3)/
     x 9.2479952d-04,-3.3233773d-07, 4.4289756d-06 /
      data fpp(21,15, 9,1),fpp(21,15, 9,2),fpp(21,15, 9,3)/
     x 1.0954406d-03, 1.2930787d-06, 1.9380328d-06 /
      data fpp(21,15,10,1),fpp(21,15,10,2),fpp(21,15,10,3)/
     x 1.2981516d-03, 1.6403837d-06, 5.2089338d-07 /
      data fpp(21,15,11,1),fpp(21,15,11,2),fpp(21,15,11,3)/
     x 1.3821327d-03, 1.3319247d-06,-7.6062856d-09 /
      data fpp(21,15,12,1),fpp(21,15,12,2),fpp(21,15,12,3)/
     x 1.3949561d-03, 8.6447568d-07,-6.4468237d-08 /
      data fpp(21,15,13,1),fpp(21,15,13,2),fpp(21,15,13,3)/
     x 1.4035804d-03, 4.6665464d-07, 7.9479235d-08 /
      data fpp(21,15,14,1),fpp(21,15,14,2),fpp(21,15,14,3)/
     x 1.4430200d-03, 1.8259101d-07, 2.1455130d-07 /
      data fpp(21,15,15,1),fpp(21,15,15,2),fpp(21,15,15,3)/
     x 1.5477062d-03, 1.8313138d-08, 2.9231557d-07 /
      data fpp(21,15,16,1),fpp(21,15,16,2),fpp(21,15,16,3)/
     x 1.7011025d-03,-7.2865430d-08, 2.3618641d-07 /
      data fpp(21,15,17,1),fpp(21,15,17,2),fpp(21,15,17,3)/
     x 1.9034396d-03,-1.3510376d-07, 8.8938790d-08 /
      data fpp(21,15,18,1),fpp(21,15,18,2),fpp(21,15,18,3)/
     x 2.1056026d-03,-1.3009241d-07,-1.2994157d-07 /
      data fpp(21,15,19,1),fpp(21,15,19,2),fpp(21,15,19,3)/
     x 2.2897831d-03,-5.5631868d-08,-2.7717251d-07 /
      data fpp(21,15,20,1),fpp(21,15,20,2),fpp(21,15,20,3)/
     x 2.4145426d-03, 1.0778894d-08,-2.7936839d-07 /
      data fpp(21,15,21,1),fpp(21,15,21,2),fpp(21,15,21,3)/
     x 2.4145426d-03, 1.0778894d-08,-2.8630856d-07 /
      data fpp(21,15,22,1),fpp(21,15,22,2),fpp(21,15,22,3)/
     x 2.2897831d-03,-5.5631868d-08,-2.4941184d-07 /
      data fpp(21,15,23,1),fpp(21,15,23,2),fpp(21,15,23,3)/
     x 2.1056026d-03,-1.3009241d-07,-2.3404408d-07 /
      data fpp(21,16, 1,1),fpp(21,16, 1,2),fpp(21,16, 1,3)/
     x 5.3140491d-03,-7.8488757d-06, 1.1994742d-06 /
      data fpp(21,16, 2,1),fpp(21,16, 2,2),fpp(21,16, 2,3)/
     x 7.7056386d-03,-4.6631630d-06,-1.2914484d-06 /
      data fpp(21,16, 3,1),fpp(21,16, 3,2),fpp(21,16, 3,3)/
     x 1.1851882d-02, 4.0872154d-07,-6.6476805d-06 /
      data fpp(21,16, 4,1),fpp(21,16, 4,2),fpp(21,16, 4,3)/
     x 1.1851882d-02, 4.0872154d-07,-6.6152342d-06 /
      data fpp(21,16, 5,1),fpp(21,16, 5,2),fpp(21,16, 5,3)/
     x 7.7056386d-03,-4.6631630d-06,-1.4212337d-06 /
      data fpp(21,16, 6,1),fpp(21,16, 6,2),fpp(21,16, 6,3)/
     x 5.3140491d-03,-7.8488757d-06, 1.6861691d-06 /
      data fpp(21,16, 7,1),fpp(21,16, 7,2),fpp(21,16, 7,3)/
     x 3.5117968d-03,-7.5181153d-06, 2.9745572d-06 /
      data fpp(21,16, 8,1),fpp(21,16, 8,2),fpp(21,16, 8,3)/
     x 2.5095013d-03,-5.0243218d-06, 2.6216021d-06 /
      data fpp(21,16, 9,1),fpp(21,16, 9,2),fpp(21,16, 9,3)/
     x 2.0852984d-03,-2.2953716d-06, 1.7670344d-06 /
      data fpp(21,16,10,1),fpp(21,16,10,2),fpp(21,16,10,3)/
     x 1.7588705d-03,-3.8661830d-07, 9.9626019d-07 /
      data fpp(21,16,11,1),fpp(21,16,11,2),fpp(21,16,11,3)/
     x 1.5778316d-03, 5.7744286d-07, 5.1792483d-07 /
      data fpp(21,16,12,1),fpp(21,16,12,2),fpp(21,16,12,3)/
     x 1.4448890d-03, 8.7281064d-07, 2.8004051d-07 /
      data fpp(21,16,13,1),fpp(21,16,13,2),fpp(21,16,13,3)/
     x 1.3808188d-03, 8.4847401d-07, 2.0991313d-07 /
      data fpp(21,16,14,1),fpp(21,16,14,2),fpp(21,16,14,3)/
     x 1.3709698d-03, 7.4813024d-07, 2.0630696d-07 /
      data fpp(21,16,15,1),fpp(21,16,15,2),fpp(21,16,15,3)/
     x 1.4164768d-03, 6.7410163d-07, 1.8885903d-07 /
      data fpp(21,16,16,1),fpp(21,16,16,2),fpp(21,16,16,3)/
     x 1.5045089d-03, 6.9880929d-07, 1.5425692d-07 /
      data fpp(21,16,17,1),fpp(21,16,17,2),fpp(21,16,17,3)/
     x 1.6098927d-03, 8.0831647d-07, 6.4113299d-08 /
      data fpp(21,16,18,1),fpp(21,16,18,2),fpp(21,16,18,3)/
     x 1.7247060d-03, 9.5060209d-07,-2.6710115d-08 /
      data fpp(21,16,19,1),fpp(21,16,19,2),fpp(21,16,19,3)/
     x 1.8216312d-03, 1.0503549d-06,-9.5272841d-08 /
      data fpp(21,16,20,1),fpp(21,16,20,2),fpp(21,16,20,3)/
     x 1.8852916d-03, 1.0856057d-06,-1.2619852d-07 /
      data fpp(21,16,21,1),fpp(21,16,21,2),fpp(21,16,21,3)/
     x 1.8852916d-03, 1.0856057d-06,-1.2876802d-07 /
      data fpp(21,16,22,1),fpp(21,16,22,2),fpp(21,16,22,3)/
     x 1.8216312d-03, 1.0503549d-06,-8.4994852d-08 /
      data fpp(21,16,23,1),fpp(21,16,23,2),fpp(21,16,23,3)/
     x 1.7247060d-03, 9.5060209d-07,-6.5252574d-08 /
      data fpp(21,17, 1,1),fpp(21,17, 1,2),fpp(21,17, 1,3)/
     x 4.5280081d-03,-2.0204181d-06,-4.9136389d-07 /
      data fpp(21,17, 2,1),fpp(21,17, 2,2),fpp(21,17, 2,3)/
     x 5.9226944d-03, 1.7928131d-06,-1.0312722d-06 /
      data fpp(21,17, 3,1),fpp(21,17, 3,2),fpp(21,17, 3,3)/
     x 7.0916065d-03, 5.4489211d-06,-2.1995472d-06 /
      data fpp(21,17, 4,1),fpp(21,17, 4,2),fpp(21,17, 4,3)/
     x 7.0916065d-03, 5.4489211d-06,-2.1797222d-06 /
      data fpp(21,17, 5,1),fpp(21,17, 5,2),fpp(21,17, 5,3)/
     x 5.9226944d-03, 1.7928131d-06,-1.1105721d-06 /
      data fpp(21,17, 6,1),fpp(21,17, 6,2),fpp(21,17, 6,3)/
     x 4.5280081d-03,-2.0204181d-06,-1.9398944d-07 /
      data fpp(21,17, 7,1),fpp(21,17, 7,2),fpp(21,17, 7,3)/
     x 4.0401703d-03,-4.3582382d-06, 4.9452985d-07 /
      data fpp(21,17, 8,1),fpp(21,17, 8,2),fpp(21,17, 8,3)/
     x 3.2736743d-03,-4.7703749d-06, 7.8987005d-07 /
      data fpp(21,17, 9,1),fpp(21,17, 9,2),fpp(21,17, 9,3)/
     x 2.6898850d-03,-3.8115923d-06, 7.9798996d-07 /
      data fpp(21,17,10,1),fpp(21,17,10,2),fpp(21,17,10,3)/
     x 2.2486949d-03,-2.3079105d-06, 6.7417009d-07 /
      data fpp(21,17,11,1),fpp(21,17,11,2),fpp(21,17,11,3)/
     x 1.9129730d-03,-8.9369615d-07, 5.0732966d-07 /
      data fpp(21,17,12,1),fpp(21,17,12,2),fpp(21,17,12,3)/
     x 1.6770845d-03, 1.6228175d-07, 3.7451128d-07 /
      data fpp(21,17,13,1),fpp(21,17,13,2),fpp(21,17,13,3)/
     x 1.5124493d-03, 8.3144930d-07, 2.8062524d-07 /
      data fpp(21,17,14,1),fpp(21,17,14,2),fpp(21,17,14,3)/
     x 1.4192192d-03, 1.2168880d-06, 2.1298778d-07 /
      data fpp(21,17,15,1),fpp(21,17,15,2),fpp(21,17,15,3)/
     x 1.3769751d-03, 1.4612803d-06, 1.6942364d-07 /
      data fpp(21,17,16,1),fpp(21,17,16,2),fpp(21,17,16,3)/
     x 1.3713307d-03, 1.6456283d-06, 1.2931764d-07 /
      data fpp(21,17,17,1),fpp(21,17,17,2),fpp(21,17,17,3)/
     x 1.3915794d-03, 1.8158379d-06, 8.1305776d-08 /
      data fpp(21,17,18,1),fpp(21,17,18,2),fpp(21,17,18,3)/
     x 1.4214942d-03, 1.9856841d-06, 4.9459249d-08 /
      data fpp(21,17,19,1),fpp(21,17,19,2),fpp(21,17,19,3)/
     x 1.4508292d-03, 2.1242121d-06, 2.0857227d-08 /
      data fpp(21,17,20,1),fpp(21,17,20,2),fpp(21,17,20,3)/
     x 1.4714973d-03, 2.2107985d-06,-8.8815598d-10 /
      data fpp(21,17,21,1),fpp(21,17,21,2),fpp(21,17,21,3)/
     x 1.4714973d-03, 2.2107985d-06,-1.7641454d-09 /
      data fpp(21,17,22,1),fpp(21,17,22,2),fpp(21,17,22,3)/
     x 1.4508292d-03, 2.1242121d-06, 2.4361184d-08 /
      data fpp(21,17,23,1),fpp(21,17,23,2),fpp(21,17,23,3)/
     x 1.4214942d-03, 1.9856841d-06, 3.6319408d-08 /
      data fpp(21,18, 1,1),fpp(21,18, 1,2),fpp(21,18, 1,3)/
     x 3.4279861d-03, 1.8665480d-06,-2.7447269d-07 /
      data fpp(21,18, 2,1),fpp(21,18, 2,2),fpp(21,18, 2,3)/
     x 3.6513412d-03, 3.8999105d-06,-3.3855462d-07 /
      data fpp(21,18, 3,1),fpp(21,18, 3,2),fpp(21,18, 3,3)/
     x 3.7915334d-03, 5.5875940d-06,-4.7730882d-07 /
      data fpp(21,18, 4,1),fpp(21,18, 4,2),fpp(21,18, 4,3)/
     x 3.7915334d-03, 5.5875940d-06,-4.7479623d-07 /
      data fpp(21,18, 5,1),fpp(21,18, 5,2),fpp(21,18, 5,3)/
     x 3.6513412d-03, 3.8999105d-06,-3.4860500d-07 /
      data fpp(21,18, 6,1),fpp(21,18, 6,2),fpp(21,18, 6,3)/
     x 3.4279861d-03, 1.8665480d-06,-2.3678378d-07 /
      data fpp(21,18, 7,1),fpp(21,18, 7,2),fpp(21,18, 7,3)/
     x 3.1694280d-03, 1.0506805d-07,-9.6259896d-08 /
      data fpp(21,18, 8,1),fpp(21,18, 8,2),fpp(21,18, 8,3)/
     x 2.8882536d-03,-1.0761786d-06, 9.8233589d-09 /
      data fpp(21,18, 9,1),fpp(21,18, 9,2),fpp(21,18, 9,3)/
     x 2.6188847d-03,-1.6162594d-06, 9.2966460d-08 /
      data fpp(21,18,10,1),fpp(21,18,10,2),fpp(21,18,10,3)/
     x 2.3666085d-03,-1.6197399d-06, 1.4031080d-07 /
      data fpp(21,18,11,1),fpp(21,18,11,2),fpp(21,18,11,3)/
     x 2.1414261d-03,-1.2446582d-06, 1.5579034d-07 /
      data fpp(21,18,12,1),fpp(21,18,12,2),fpp(21,18,12,3)/
     x 1.9550221d-03,-6.5193764d-07, 1.6052786d-07 /
      data fpp(21,18,13,1),fpp(21,18,13,2),fpp(21,18,13,3)/
     x 1.7961062d-03, 3.1728770d-08, 1.5009824d-07 /
      data fpp(21,18,14,1),fpp(21,18,14,2),fpp(21,18,14,3)/
     x 1.6733110d-03, 7.2631771d-07, 1.3307917d-07 /
      data fpp(21,18,15,1),fpp(21,18,15,2),fpp(21,18,15,3)/
     x 1.5837219d-03, 1.3827770d-06, 1.2158508d-07 /
      data fpp(21,18,16,1),fpp(21,18,16,2),fpp(21,18,16,3)/
     x 1.5145034d-03, 1.9766776d-06, 1.0058051d-07 /
      data fpp(21,18,17,1),fpp(21,18,17,2),fpp(21,18,17,3)/
     x 1.4708436d-03, 2.4943320d-06, 9.4092872d-08 /
      data fpp(21,18,18,1),fpp(21,18,18,2),fpp(21,18,18,3)/
     x 1.4307860d-03, 2.9086617d-06, 7.5048000d-08 /
      data fpp(21,18,19,1),fpp(21,18,19,2),fpp(21,18,19,3)/
     x 1.4129808d-03, 3.2147965d-06, 6.7715129d-08 /
      data fpp(21,18,20,1),fpp(21,18,20,2),fpp(21,18,20,3)/
     x 1.4103016d-03, 3.4032004d-06, 6.2091485d-08 /
      data fpp(21,18,21,1),fpp(21,18,21,2),fpp(21,18,21,3)/
     x 1.4103016d-03, 3.4032004d-06, 6.1867980d-08 /
      data fpp(21,18,22,1),fpp(21,18,22,2),fpp(21,18,22,3)/
     x 1.4129808d-03, 3.2147965d-06, 6.8609149d-08 /
      data fpp(21,18,23,1),fpp(21,18,23,2),fpp(21,18,23,3)/
     x 1.4307860d-03, 2.9086617d-06, 7.1695426d-08 /
      data fpp(21,19, 1,1),fpp(21,19, 1,2),fpp(21,19, 1,3)/
     x 2.0758811d-03, 6.3082260d-06, 1.5844040d-21 /
      data fpp(21,19, 2,1),fpp(21,19, 2,2),fpp(21,19, 2,3)/
     x 2.0758811d-03, 7.2495447d-06,-9.2725876d-24 /
      data fpp(21,19, 3,1),fpp(21,19, 3,2),fpp(21,19, 3,3)/
     x 2.0758811d-03, 7.1267030d-06,-3.8750100d-22 /
      data fpp(21,19, 4,1),fpp(21,19, 4,2),fpp(21,19, 4,3)/
     x 2.0758811d-03, 7.1267030d-06, 3.0893762d-22 /
      data fpp(21,19, 5,1),fpp(21,19, 5,2),fpp(21,19, 5,3)/
     x 2.0758811d-03, 7.2495447d-06, 1.5784492d-22 /
      data fpp(21,19, 6,1),fpp(21,19, 6,2),fpp(21,19, 6,3)/
     x 2.0758811d-03, 6.3082260d-06,-9.2839363d-22 /
      data fpp(21,19, 7,1),fpp(21,19, 7,2),fpp(21,19, 7,3)/
     x 2.0758811d-03, 4.1959660d-06,-1.6773643d-21 /
      data fpp(21,19, 8,1),fpp(21,19, 8,2),fpp(21,19, 8,3)/
     x 2.0758811d-03, 1.6350893d-06,-4.1257001d-23 /
      data fpp(21,19, 9,1),fpp(21,19, 9,2),fpp(21,19, 9,3)/
     x 2.0758811d-03,-4.8137032d-07,-6.0980072d-22 /
      data fpp(21,19,10,1),fpp(21,19,10,2),fpp(21,19,10,3)/
     x 2.0758811d-03,-1.6771301d-06, 8.3281279d-22 /
      data fpp(21,19,11,1),fpp(21,19,11,2),fpp(21,19,11,3)/
     x 2.0758811d-03,-1.9156709d-06,-2.0857070d-22 /
      data fpp(21,19,12,1),fpp(21,19,12,2),fpp(21,19,12,3)/
     x 2.0758811d-03,-1.4365312d-06,-3.0119203d-23 /
      data fpp(21,19,13,1),fpp(21,19,13,2),fpp(21,19,13,3)/
     x 2.0758811d-03,-5.4436439d-07, 7.4763988d-22 /
      data fpp(21,19,14,1),fpp(21,19,14,2),fpp(21,19,14,3)/
     x 2.0758811d-03, 5.0984114d-07,-3.4422314d-22 /
      data fpp(21,19,15,1),fpp(21,19,15,2),fpp(21,19,15,3)/
     x 2.0758811d-03, 1.5516115d-06,-5.6646611d-22 /
      data fpp(21,19,16,1),fpp(21,19,16,2),fpp(21,19,16,3)/
     x 2.0758811d-03, 2.4836612d-06,-5.0218624d-22 /
      data fpp(21,19,17,1),fpp(21,19,17,2),fpp(21,19,17,3)/
     x 2.0758811d-03, 3.2668340d-06, 1.1326857d-21 /
      data fpp(21,19,18,1),fpp(21,19,18,2),fpp(21,19,18,3)/
     x 2.0758811d-03, 3.8636692d-06,-1.0890619d-21 /
      data fpp(21,19,19,1),fpp(21,19,19,2),fpp(21,19,19,3)/
     x 2.0758811d-03, 4.3006017d-06,-6.3440407d-22 /
      data fpp(21,19,20,1),fpp(21,19,20,2),fpp(21,19,20,3)/
     x 2.0758811d-03, 4.5763998d-06, 3.7086101d-22 /
      data fpp(21,19,21,1),fpp(21,19,21,2),fpp(21,19,21,3)/
     x 2.0758811d-03, 4.5763998d-06,-4.2156968d-22 /
      data fpp(21,19,22,1),fpp(21,19,22,2),fpp(21,19,22,3)/
     x 2.0758811d-03, 4.3006017d-06, 3.0520544d-22 /
      data fpp(21,19,23,1),fpp(21,19,23,2),fpp(21,19,23,3)/
     x 2.0758811d-03, 3.8636692d-06, 1.9768582d-21 /
      data fpp(22, 1, 1,1),fpp(22, 1, 1,2),fpp(22, 1, 1,3)/
     x 1.9391780d-02,-3.4414836d-05, 1.3123775d-20 /
      data fpp(22, 1, 2,1),fpp(22, 1, 2,2),fpp(22, 1, 2,3)/
     x 1.9391780d-02, 1.1031082d-05,-2.6671822d-20 /
      data fpp(22, 1, 3,1),fpp(22, 1, 3,2),fpp(22, 1, 3,3)/
     x 1.9391780d-02, 4.6181446d-05,-4.7937147d-20 /
      data fpp(22, 1, 4,1),fpp(22, 1, 4,2),fpp(22, 1, 4,3)/
     x 1.9391780d-02, 4.6181446d-05, 2.5129444d-20 /
      data fpp(22, 1, 5,1),fpp(22, 1, 5,2),fpp(22, 1, 5,3)/
     x 1.9391780d-02, 1.1031082d-05, 2.1488741d-20 /
      data fpp(22, 1, 6,1),fpp(22, 1, 6,2),fpp(22, 1, 6,3)/
     x 1.9391780d-02,-3.4414836d-05,-2.8319928d-20 /
      data fpp(22, 1, 7,1),fpp(22, 1, 7,2),fpp(22, 1, 7,3)/
     x 1.9391780d-02,-7.9256716d-05,-1.0620440d-19 /
      data fpp(22, 1, 8,1),fpp(22, 1, 8,2),fpp(22, 1, 8,3)/
     x 1.9391780d-02,-1.1692408d-04,-6.7551906d-20 /
      data fpp(22, 1, 9,1),fpp(22, 1, 9,2),fpp(22, 1, 9,3)/
     x 1.9391780d-02,-1.4501665d-04, 5.4287314d-20 /
      data fpp(22, 1,10,1),fpp(22, 1,10,2),fpp(22, 1,10,3)/
     x 1.9391780d-02,-1.6372257d-04, 9.0754646d-20 /
      data fpp(22, 1,11,1),fpp(22, 1,11,2),fpp(22, 1,11,3)/
     x 1.9391780d-02,-1.7439139d-04,-4.5344360d-20 /
      data fpp(22, 1,12,1),fpp(22, 1,12,2),fpp(22, 1,12,3)/
     x 1.9391780d-02,-1.7839193d-04, 7.9811407d-20 /
      data fpp(22, 1,13,1),fpp(22, 1,13,2),fpp(22, 1,13,3)/
     x 1.9391780d-02,-1.7623376d-04, 4.1309661d-20 /
      data fpp(22, 1,14,1),fpp(22, 1,14,2),fpp(22, 1,14,3)/
     x 1.9391780d-02,-1.6721511d-04,-6.3793344d-21 /
      data fpp(22, 1,15,1),fpp(22, 1,15,2),fpp(22, 1,15,3)/
     x 1.9391780d-02,-1.4977530d-04, 3.0520068d-21 /
      data fpp(22, 1,16,1),fpp(22, 1,16,2),fpp(22, 1,16,3)/
     x 1.9391780d-02,-1.2238925d-04,-3.5744229d-20 /
      data fpp(22, 1,17,1),fpp(22, 1,17,2),fpp(22, 1,17,3)/
     x 1.9391780d-02,-8.4706310d-05, 7.4442745d-20 /
      data fpp(22, 1,18,1),fpp(22, 1,18,2),fpp(22, 1,18,3)/
     x 1.9391780d-02,-3.9050815d-05,-7.5637087d-20 /
      data fpp(22, 1,19,1),fpp(22, 1,19,2),fpp(22, 1,19,3)/
     x 1.9391780d-02, 7.8881762d-06,-8.8505843d-20 /
      data fpp(22, 1,20,1),fpp(22, 1,20,2),fpp(22, 1,20,3)/
     x 1.9391780d-02, 4.4646968d-05, 7.0781550d-20 /
      data fpp(22, 1,21,1),fpp(22, 1,21,2),fpp(22, 1,21,3)/
     x 1.9391780d-02, 4.4646968d-05,-5.2889973d-20 /
      data fpp(22, 1,22,1),fpp(22, 1,22,2),fpp(22, 1,22,3)/
     x 1.9391780d-02, 7.8881762d-06, 9.1347051d-20 /
      data fpp(22, 1,23,1),fpp(22, 1,23,2),fpp(22, 1,23,3)/
     x 1.9391780d-02,-3.9050815d-05, 2.2376770d-19 /
      data fpp(22, 2, 1,1),fpp(22, 2, 1,2),fpp(22, 2, 1,3)/
     x 3.1375209d-02,-2.5310327d-05,-4.1134386d-06 /
      data fpp(22, 2, 2,1),fpp(22, 2, 2,2),fpp(22, 2, 2,3)/
     x 3.0778120d-02,-1.0807164d-05,-5.3356229d-06 /
      data fpp(22, 2, 3,1),fpp(22, 2, 3,2),fpp(22, 2, 3,3)/
     x 1.9245339d-02, 8.5110805d-07,-7.9940700d-06 /
      data fpp(22, 2, 4,1),fpp(22, 2, 4,2),fpp(22, 2, 4,3)/
     x 1.9245339d-02, 8.5110805d-07,-7.9249785d-06 /
      data fpp(22, 2, 5,1),fpp(22, 2, 5,2),fpp(22, 2, 5,3)/
     x 3.0778120d-02,-1.0807164d-05,-5.6119888d-06 /
      data fpp(22, 2, 6,1),fpp(22, 2, 6,2),fpp(22, 2, 6,3)/
     x 3.1375209d-02,-2.5310327d-05,-3.0770661d-06 /
      data fpp(22, 2, 7,1),fpp(22, 2, 7,2),fpp(22, 2, 7,3)/
     x 2.7655682d-02,-3.8750569d-05,-3.2574670d-07 /
      data fpp(22, 2, 8,1),fpp(22, 2, 8,2),fpp(22, 2, 8,3)/
     x 2.2665762d-02,-4.9037833d-05, 2.0880529d-06 /
      data fpp(22, 2, 9,1),fpp(22, 2, 9,2),fpp(22, 2, 9,3)/
     x 1.7349548d-02,-5.5823694d-05, 4.0095351d-06 /
      data fpp(22, 2,10,1),fpp(22, 2,10,2),fpp(22, 2,10,3)/
     x 1.3926462d-02,-5.9761866d-05, 5.3638067d-06 /
      data fpp(22, 2,11,1),fpp(22, 2,11,2),fpp(22, 2,11,3)/
     x 1.1539990d-02,-6.1811225d-05, 6.1732382d-06 /
      data fpp(22, 2,12,1),fpp(22, 2,12,2),fpp(22, 2,12,3)/
     x 1.1338764d-02,-6.2748137d-05, 6.4592407d-06 /
      data fpp(22, 2,13,1),fpp(22, 2,13,2),fpp(22, 2,13,3)/
     x 1.2305003d-02,-6.2839489d-05, 6.2277992d-06 /
      data fpp(22, 2,14,1),fpp(22, 2,14,2),fpp(22, 2,14,3)/
     x 1.3854724d-02,-6.1713786d-05, 5.4695627d-06 /
      data fpp(22, 2,15,1),fpp(22, 2,15,2),fpp(22, 2,15,3)/
     x 1.7269146d-02,-5.8489400d-05, 4.1439501d-06 /
      data fpp(22, 2,16,1),fpp(22, 2,16,2),fpp(22, 2,16,3)/
     x 2.2643890d-02,-5.2107495d-05, 2.2246367d-06 /
      data fpp(22, 2,17,1),fpp(22, 2,17,2),fpp(22, 2,17,3)/
     x 2.7852389d-02,-4.1826380d-05,-2.2649707d-07 /
      data fpp(22, 2,18,1),fpp(22, 2,18,2),fpp(22, 2,18,3)/
     x 3.2106277d-02,-2.7960369d-05,-3.0586485d-06 /
      data fpp(22, 2,19,1),fpp(22, 2,19,2),fpp(22, 2,19,3)/
     x 2.8019737d-02,-1.2679352d-05,-5.7069091d-06 /
      data fpp(22, 2,20,1),fpp(22, 2,20,2),fpp(22, 2,20,3)/
     x 2.0559846d-02,-2.0193646d-07,-8.1457153d-06 /
      data fpp(22, 2,21,1),fpp(22, 2,21,2),fpp(22, 2,21,3)/
     x 2.0559846d-02,-2.0193646d-07,-8.2173997d-06 /
      data fpp(22, 2,22,1),fpp(22, 2,22,2),fpp(22, 2,22,3)/
     x 2.8019737d-02,-1.2679352d-05,-5.4201715d-06 /
      data fpp(22, 2,23,1),fpp(22, 2,23,2),fpp(22, 2,23,3)/
     x 3.2106277d-02,-2.7960369d-05,-4.1339142d-06 /
      data fpp(22, 3, 1,1),fpp(22, 3, 1,2),fpp(22, 3, 1,3)/
     x 2.0792557d-02,-2.4759855d-05,-6.8258623d-06 /
      data fpp(22, 3, 2,1),fpp(22, 3, 2,2),fpp(22, 3, 2,3)/
     x 3.1105902d-02,-5.4964428d-05,-1.2099275d-05 /
      data fpp(22, 3, 3,1),fpp(22, 3, 3,2),fpp(22, 3, 3,3)/
     x 2.6813220d-02,-7.5313878d-05,-2.3497036d-05 /
      data fpp(22, 3, 4,1),fpp(22, 3, 4,2),fpp(22, 3, 4,3)/
     x 2.6813220d-02,-7.5313878d-05,-2.3326253d-05 /
      data fpp(22, 3, 5,1),fpp(22, 3, 5,2),fpp(22, 3, 5,3)/
     x 3.1105902d-02,-5.4964428d-05,-1.2782408d-05 /
      data fpp(22, 3, 6,1),fpp(22, 3, 6,2),fpp(22, 3, 6,3)/
     x 2.0792557d-02,-2.4759855d-05,-4.2641148d-06 /
      data fpp(22, 3, 7,1),fpp(22, 3, 7,2),fpp(22, 3, 7,3)/
     x 9.0000564d-03, 1.0062991d-05, 2.8208671d-06 /
      data fpp(22, 3, 8,1),fpp(22, 3, 8,2),fpp(22, 3, 8,3)/
     x 5.6969828d-04, 4.4167415d-05, 7.4646463d-06 /
      data fpp(22, 3, 9,1),fpp(22, 3, 9,2),fpp(22, 3, 9,3)/
     x-5.6529369d-03, 7.3621428d-05, 1.0322548d-05 /
      data fpp(22, 3,10,1),fpp(22, 3,10,2),fpp(22, 3,10,3)/
     x-9.8024180d-03, 9.5924032d-05, 1.1851163d-05 /
      data fpp(22, 3,11,1),fpp(22, 3,11,2),fpp(22, 3,11,3)/
     x-1.2183314d-02, 1.0966029d-04, 1.2574801d-05 /
      data fpp(22, 3,12,1),fpp(22, 3,12,2),fpp(22, 3,12,3)/
     x-1.2978762d-02, 1.1424048d-04, 1.2843632d-05 /
      data fpp(22, 3,13,1),fpp(22, 3,13,2),fpp(22, 3,13,3)/
     x-1.2245483d-02, 1.0953771d-04, 1.2784672d-05 /
      data fpp(22, 3,14,1),fpp(22, 3,14,2),fpp(22, 3,14,3)/
     x-9.9371972d-03, 9.5674252d-05, 1.2265679d-05 /
      data fpp(22, 3,15,1),fpp(22, 3,15,2),fpp(22, 3,15,3)/
     x-5.8994211d-03, 7.3232900d-05, 1.0890612d-05 /
      data fpp(22, 3,16,1),fpp(22, 3,16,2),fpp(22, 3,16,3)/
     x 1.6912540d-04, 4.3635232d-05, 8.1318746d-06 /
      data fpp(22, 3,17,1),fpp(22, 3,17,2),fpp(22, 3,17,3)/
     x 8.4371191d-03, 9.4018298d-06, 3.4718899d-06 /
      data fpp(22, 3,18,1),fpp(22, 3,18,2),fpp(22, 3,18,3)/
     x 2.0265084d-02,-2.5471708d-05,-3.8274341d-06 /
      data fpp(22, 3,19,1),fpp(22, 3,19,2),fpp(22, 3,19,3)/
     x 3.0476062d-02,-5.5588766d-05,-1.2798153d-05 /
      data fpp(22, 3,20,1),fpp(22, 3,20,2),fpp(22, 3,20,3)/
     x 2.9802151d-02,-7.5699222d-05,-2.4431952d-05 /
      data fpp(22, 3,21,1),fpp(22, 3,21,2),fpp(22, 3,21,3)/
     x 2.9802151d-02,-7.5699222d-05,-2.4600067d-05 /
      data fpp(22, 3,22,1),fpp(22, 3,22,2),fpp(22, 3,22,3)/
     x 3.0476062d-02,-5.5588766d-05,-1.2125695d-05 /
      data fpp(22, 3,23,1),fpp(22, 3,23,2),fpp(22, 3,23,3)/
     x 2.0265084d-02,-2.5471708d-05,-6.3491524d-06 /
      data fpp(22, 4, 1,1),fpp(22, 4, 1,2),fpp(22, 4, 1,3)/
     x 1.0693554d-02, 5.7297482d-06,-5.1451872d-06 /
      data fpp(22, 4, 2,1),fpp(22, 4, 2,2),fpp(22, 4, 2,3)/
     x 2.2695263d-02,-2.1005126d-05,-1.2462626d-05 /
      data fpp(22, 4, 3,1),fpp(22, 4, 3,2),fpp(22, 4, 3,3)/
     x 3.4961039d-02,-4.3557595d-05,-2.8236310d-05 /
      data fpp(22, 4, 4,1),fpp(22, 4, 4,2),fpp(22, 4, 4,3)/
     x 3.4961039d-02,-4.3557595d-05,-2.8072756d-05 /
      data fpp(22, 4, 5,1),fpp(22, 4, 5,2),fpp(22, 4, 5,3)/
     x 2.2695263d-02,-2.1005126d-05,-1.3116841d-05 /
      data fpp(22, 4, 6,1),fpp(22, 4, 6,2),fpp(22, 4, 6,3)/
     x 1.0693554d-02, 5.7297482d-06,-2.6918798d-06 /
      data fpp(22, 4, 7,1),fpp(22, 4, 7,2),fpp(22, 4, 7,3)/
     x 1.0397088d-03, 2.9800604d-05, 4.9663601d-06 /
      data fpp(22, 4, 8,1),fpp(22, 4, 8,2),fpp(22, 4, 8,3)/
     x-6.4428306d-03, 4.8756172d-05, 9.2504396d-06 /
      data fpp(22, 4, 9,1),fpp(22, 4, 9,2),fpp(22, 4, 9,3)/
     x-1.1756746d-02, 6.2183983d-05, 1.1371882d-05 /
      data fpp(22, 4,10,1),fpp(22, 4,10,2),fpp(22, 4,10,3)/
     x-1.5288607d-02, 7.0571740d-05, 1.2186034d-05 /
      data fpp(22, 4,11,1),fpp(22, 4,11,2),fpp(22, 4,11,3)/
     x-1.7296267d-02, 7.5012074d-05, 1.2525984d-05 /
      data fpp(22, 4,12,1),fpp(22, 4,12,2),fpp(22, 4,12,3)/
     x-1.7991125d-02, 7.6522218d-05, 1.2740032d-05 /
      data fpp(22, 4,13,1),fpp(22, 4,13,2),fpp(22, 4,13,3)/
     x-1.7461712d-02, 7.5474637d-05, 1.2899890d-05 /
      data fpp(22, 4,14,1),fpp(22, 4,14,2),fpp(22, 4,14,3)/
     x-1.5632005d-02, 7.1458780d-05, 1.2922410d-05 /
      data fpp(22, 4,15,1),fpp(22, 4,15,2),fpp(22, 4,15,3)/
     x-1.2303119d-02, 6.3427801d-05, 1.2408471d-05 /
      data fpp(22, 4,16,1),fpp(22, 4,16,2),fpp(22, 4,16,3)/
     x-7.2179816d-03, 5.0264567d-05, 1.0493705d-05 /
      data fpp(22, 4,17,1),fpp(22, 4,17,2),fpp(22, 4,17,3)/
     x-3.0297229d-05, 3.1411061d-05, 6.2467085d-06 /
      data fpp(22, 4,18,1),fpp(22, 4,18,2),fpp(22, 4,18,3)/
     x 9.5432133d-03, 7.1231994d-06,-1.7665389d-06 /
      data fpp(22, 4,19,1),fpp(22, 4,19,2),fpp(22, 4,19,3)/
     x 2.1732415d-02,-2.0301582d-05,-1.2980553d-05 /
      data fpp(22, 4,20,1),fpp(22, 4,20,2),fpp(22, 4,20,3)/
     x 3.4941485d-02,-4.3927174d-05,-3.0161249d-05 /
      data fpp(22, 4,21,1),fpp(22, 4,21,2),fpp(22, 4,21,3)/
     x 3.4941485d-02,-4.3927174d-05,-3.0312975d-05 /
      data fpp(22, 4,22,1),fpp(22, 4,22,2),fpp(22, 4,22,3)/
     x 2.1732415d-02,-2.0301582d-05,-1.2373650d-05 /
      data fpp(22, 4,23,1),fpp(22, 4,23,2),fpp(22, 4,23,3)/
     x 9.5432133d-03, 7.1231994d-06,-4.0424250d-06 /
      data fpp(22, 5, 1,1),fpp(22, 5, 1,2),fpp(22, 5, 1,3)/
     x 5.8170608d-03, 2.5726863d-05,-4.3206188d-06 /
      data fpp(22, 5, 2,1),fpp(22, 5, 2,2),fpp(22, 5, 2,3)/
     x 1.2831596d-02, 2.6304933d-05,-9.1962624d-06 /
      data fpp(22, 5, 3,1),fpp(22, 5, 3,2),fpp(22, 5, 3,3)/
     x 1.8692347d-02, 2.7220260d-05,-1.9716332d-05 /
      data fpp(22, 5, 4,1),fpp(22, 5, 4,2),fpp(22, 5, 4,3)/
     x 1.8692347d-02, 2.7220260d-05,-1.9589874d-05 /
      data fpp(22, 5, 5,1),fpp(22, 5, 5,2),fpp(22, 5, 5,3)/
     x 1.2831596d-02, 2.6304933d-05,-9.7020934d-06 /
      data fpp(22, 5, 6,1),fpp(22, 5, 6,2),fpp(22, 5, 6,3)/
     x 5.8170608d-03, 2.5726863d-05,-2.4237526d-06 /
      data fpp(22, 5, 7,1),fpp(22, 5, 7,2),fpp(22, 5, 7,3)/
     x-7.0758324d-04, 2.5924592d-05, 3.3171037d-06 /
      data fpp(22, 5, 8,1),fpp(22, 5, 8,2),fpp(22, 5, 8,3)/
     x-6.0858650d-03, 2.6187897d-05, 6.4053379d-06 /
      data fpp(22, 5, 9,1),fpp(22, 5, 9,2),fpp(22, 5, 9,3)/
     x-1.0162571d-02, 2.6278641d-05, 7.8055449d-06 /
      data fpp(22, 5,10,1),fpp(22, 5,10,2),fpp(22, 5,10,3)/
     x-1.2956800d-02, 2.6573010d-05, 8.5064827d-06 /
      data fpp(22, 5,11,1),fpp(22, 5,11,2),fpp(22, 5,11,3)/
     x-1.4612228d-02, 2.7109415d-05, 9.0365242d-06 /
      data fpp(22, 5,12,1),fpp(22, 5,12,2),fpp(22, 5,12,3)/
     x-1.5266285d-02, 2.7504649d-05, 9.3954204d-06 /
      data fpp(22, 5,13,1),fpp(22, 5,13,2),fpp(22, 5,13,3)/
     x-1.4965359d-02, 2.7541740d-05, 9.5477943d-06 /
      data fpp(22, 5,14,1),fpp(22, 5,14,2),fpp(22, 5,14,3)/
     x-1.3649545d-02, 2.7432630d-05, 9.5094024d-06 /
      data fpp(22, 5,15,1),fpp(22, 5,15,2),fpp(22, 5,15,3)/
     x-1.1169363d-02, 2.7511895d-05, 9.2225962d-06 /
      data fpp(22, 5,16,1),fpp(22, 5,16,2),fpp(22, 5,16,3)/
     x-7.3576469d-03, 2.7616498d-05, 8.0802128d-06 /
      data fpp(22, 5,17,1),fpp(22, 5,17,2),fpp(22, 5,17,3)/
     x-2.1477539d-03, 2.7247928d-05, 4.9565525d-06 /
      data fpp(22, 5,18,1),fpp(22, 5,18,2),fpp(22, 5,18,3)/
     x 4.4165442d-03, 2.6576910d-05,-1.3504226d-06 /
      data fpp(22, 5,19,1),fpp(22, 5,19,2),fpp(22, 5,19,3)/
     x 1.1791210d-02, 2.6407094d-05,-9.8088619d-06 /
      data fpp(22, 5,20,1),fpp(22, 5,20,2),fpp(22, 5,20,3)/
     x 1.8088435d-02, 2.6677918d-05,-2.2018130d-05 /
      data fpp(22, 5,21,1),fpp(22, 5,21,2),fpp(22, 5,21,3)/
     x 1.8088435d-02, 2.6677918d-05,-2.2149180d-05 /
      data fpp(22, 5,22,1),fpp(22, 5,22,2),fpp(22, 5,22,3)/
     x 1.1791210d-02, 2.6407094d-05,-9.2846630d-06 /
      data fpp(22, 5,23,1),fpp(22, 5,23,2),fpp(22, 5,23,3)/
     x 4.4165442d-03, 2.6576910d-05,-3.3161685d-06 /
      data fpp(22, 6, 1,1),fpp(22, 6, 1,2),fpp(22, 6, 1,3)/
     x 3.0773045d-03, 2.0836802d-05,-3.3360112d-06 /
      data fpp(22, 6, 2,1),fpp(22, 6, 2,2),fpp(22, 6, 2,3)/
     x 6.4965009d-03, 2.8963396d-05,-5.3524775d-06 /
      data fpp(22, 6, 3,1),fpp(22, 6, 3,2),fpp(22, 6, 3,3)/
     x 9.0781149d-03, 3.5500557d-05,-9.7240786d-06 /
      data fpp(22, 6, 4,1),fpp(22, 6, 4,2),fpp(22, 6, 4,3)/
     x 9.0781149d-03, 3.5500557d-05,-9.6355253d-06 /
      data fpp(22, 6, 5,1),fpp(22, 6, 5,2),fpp(22, 6, 5,3)/
     x 6.4965009d-03, 2.8963396d-05,-5.7066909d-06 /
      data fpp(22, 6, 6,1),fpp(22, 6, 6,2),fpp(22, 6, 6,3)/
     x 3.0773045d-03, 2.0836802d-05,-2.0077112d-06 /
      data fpp(22, 6, 7,1),fpp(22, 6, 7,2),fpp(22, 6, 7,3)/
     x-4.8064238d-04, 1.2727028d-05, 9.5153558d-07 /
      data fpp(22, 6, 8,1),fpp(22, 6, 8,2),fpp(22, 6, 8,3)/
     x-3.6901898d-03, 5.9422405d-06, 2.7495689d-06 /
      data fpp(22, 6, 9,1),fpp(22, 6, 9,2),fpp(22, 6, 9,3)/
     x-6.3304649d-03, 1.0254527d-06, 3.8481890d-06 /
      data fpp(22, 6,10,1),fpp(22, 6,10,2),fpp(22, 6,10,3)/
     x-8.3530688d-03,-2.2577804d-06, 4.6096753d-06 /
      data fpp(22, 6,11,1),fpp(22, 6,11,2),fpp(22, 6,11,3)/
     x-9.7159616d-03,-4.1757347d-06, 5.1931098d-06 /
      data fpp(22, 6,12,1),fpp(22, 6,12,2),fpp(22, 6,12,3)/
     x-1.0355173d-02,-4.6748144d-06, 5.6078856d-06 /
      data fpp(22, 6,13,1),fpp(22, 6,13,2),fpp(22, 6,13,3)/
     x-1.0226036d-02,-3.6795957d-06, 5.8253478d-06 /
      data fpp(22, 6,14,1),fpp(22, 6,14,2),fpp(22, 6,14,3)/
     x-9.3291932d-03,-1.3392984d-06, 5.8127231d-06 /
      data fpp(22, 6,15,1),fpp(22, 6,15,2),fpp(22, 6,15,3)/
     x-7.6791426d-03, 2.1926195d-06, 5.4717598d-06 /
      data fpp(22, 6,16,1),fpp(22, 6,16,2),fpp(22, 6,16,3)/
     x-5.2608326d-03, 7.1254394d-06, 4.5802378d-06 /
      data fpp(22, 6,17,1),fpp(22, 6,17,2),fpp(22, 6,17,3)/
     x-2.0700871d-03, 1.3671228d-05, 2.6072889d-06 /
      data fpp(22, 6,18,1),fpp(22, 6,18,2),fpp(22, 6,18,3)/
     x 1.7290826d-03, 2.1377161d-05,-1.0953935d-06 /
      data fpp(22, 6,19,1),fpp(22, 6,19,2),fpp(22, 6,19,3)/
     x 5.6179547d-03, 2.9087204d-05,-6.0617148d-06 /
      data fpp(22, 6,20,1),fpp(22, 6,20,2),fpp(22, 6,20,3)/
     x 8.7116223d-03, 3.5339501d-05,-1.1911747d-05 /
      data fpp(22, 6,21,1),fpp(22, 6,21,2),fpp(22, 6,21,3)/
     x 8.7116223d-03, 3.5339501d-05,-1.2017901d-05 /
      data fpp(22, 6,22,1),fpp(22, 6,22,2),fpp(22, 6,22,3)/
     x 5.6179547d-03, 2.9087204d-05,-5.6370997d-06 /
      data fpp(22, 6,23,1),fpp(22, 6,23,2),fpp(22, 6,23,3)/
     x 1.7290826d-03, 2.1377161d-05,-2.6877001d-06 /
      data fpp(22, 7, 1,1),fpp(22, 7, 1,2),fpp(22, 7, 1,3)/
     x 1.7304764d-03, 1.0121931d-05,-2.0142156d-06 /
      data fpp(22, 7, 2,1),fpp(22, 7, 2,2),fpp(22, 7, 2,3)/
     x 3.0956665d-03, 1.6715485d-05,-2.5165688d-06 /
      data fpp(22, 7, 3,1),fpp(22, 7, 3,2),fpp(22, 7, 3,3)/
     x 4.0391538d-03, 2.1751513d-05,-3.6155091d-06 /
      data fpp(22, 7, 4,1),fpp(22, 7, 4,2),fpp(22, 7, 4,3)/
     x 4.0391538d-03, 2.1751513d-05,-3.5761883d-06 /
      data fpp(22, 7, 5,1),fpp(22, 7, 5,2),fpp(22, 7, 5,3)/
     x 3.0956665d-03, 1.6715485d-05,-2.6738520d-06 /
      data fpp(22, 7, 6,1),fpp(22, 7, 6,2),fpp(22, 7, 6,3)/
     x 1.7304764d-03, 1.0121931d-05,-1.4244039d-06 /
      data fpp(22, 7, 7,1),fpp(22, 7, 7,2),fpp(22, 7, 7,3)/
     x 1.4893138d-04, 3.5252947d-06,-2.8053251d-07 /
      data fpp(22, 7, 8,1),fpp(22, 7, 8,2),fpp(22, 7, 8,3)/
     x-1.4807491d-03,-2.2388590d-06, 5.9053393d-07 /
      data fpp(22, 7, 9,1),fpp(22, 7, 9,2),fpp(22, 7, 9,3)/
     x-3.0073870d-03,-6.8064517d-06, 1.2663968d-06 /
      data fpp(22, 7,10,1),fpp(22, 7,10,2),fpp(22, 7,10,3)/
     x-4.2958430d-03,-9.9458886d-06, 1.8798790d-06 /
      data fpp(22, 7,11,1),fpp(22, 7,11,2),fpp(22, 7,11,3)/
     x-5.2325181d-03,-1.1612476d-05, 2.4820873d-06 /
      data fpp(22, 7,12,1),fpp(22, 7,12,2),fpp(22, 7,12,3)/
     x-5.7556346d-03,-1.1979392d-05, 2.9577717d-06 /
      data fpp(22, 7,13,1),fpp(22, 7,13,2),fpp(22, 7,13,3)/
     x-5.8262123d-03,-1.1215357d-05, 3.1708259d-06 /
      data fpp(22, 7,14,1),fpp(22, 7,14,2),fpp(22, 7,14,3)/
     x-5.4224869d-03,-9.2654361d-06, 3.1269248d-06 /
      data fpp(22, 7,15,1),fpp(22, 7,15,2),fpp(22, 7,15,3)/
     x-4.5280297d-03,-5.9943729d-06, 2.8854749d-06 /
      data fpp(22, 7,16,1),fpp(22, 7,16,2),fpp(22, 7,16,3)/
     x-3.1790996d-03,-1.4462560d-06, 2.3171754d-06 /
      data fpp(22, 7,17,1),fpp(22, 7,17,2),fpp(22, 7,17,3)/
     x-1.4649756d-03, 4.1611604d-06, 1.1838233d-06 /
      data fpp(22, 7,18,1),fpp(22, 7,18,2),fpp(22, 7,18,3)/
     x 4.5512249d-04, 1.0458446d-05,-7.5246862d-07 /
      data fpp(22, 7,19,1),fpp(22, 7,19,2),fpp(22, 7,19,3)/
     x 2.3131353d-03, 1.6688088d-05,-3.1419488d-06 /
      data fpp(22, 7,20,1),fpp(22, 7,20,2),fpp(22, 7,20,3)/
     x 3.7121854d-03, 2.1432078d-05,-5.4597361d-06 /
      data fpp(22, 7,21,1),fpp(22, 7,21,2),fpp(22, 7,21,3)/
     x 3.7121854d-03, 2.1432078d-05,-5.5218174d-06 /
      data fpp(22, 7,22,1),fpp(22, 7,22,2),fpp(22, 7,22,3)/
     x 2.3131353d-03, 1.6688088d-05,-2.8936236d-06 /
      data fpp(22, 7,23,1),fpp(22, 7,23,2),fpp(22, 7,23,3)/
     x 4.5512249d-04, 1.0458446d-05,-1.6836882d-06 /
      data fpp(22, 8, 1,1),fpp(22, 8, 1,2),fpp(22, 8, 1,3)/
     x 1.3650511d-03, 2.9654729d-06,-8.4584331d-07 /
      data fpp(22, 8, 2,1),fpp(22, 8, 2,2),fpp(22, 8, 2,3)/
     x 1.8373314d-03, 6.9426638d-06,-9.1931337d-07 /
      data fpp(22, 8, 3,1),fpp(22, 8, 3,2),fpp(22, 8, 3,3)/
     x 2.2884248d-03, 1.0057391d-05,-1.0809032d-06 /
      data fpp(22, 8, 4,1),fpp(22, 8, 4,2),fpp(22, 8, 4,3)/
     x 2.2884248d-03, 1.0057391d-05,-1.0736337d-06 /
      data fpp(22, 8, 5,1),fpp(22, 8, 5,2),fpp(22, 8, 5,3)/
     x 1.8373314d-03, 6.9426638d-06,-9.4839137d-07 /
      data fpp(22, 8, 6,1),fpp(22, 8, 6,2),fpp(22, 8, 6,3)/
     x 1.3650511d-03, 2.9654729d-06,-7.3680082d-07 /
      data fpp(22, 8, 7,1),fpp(22, 8, 7,2),fpp(22, 8, 7,3)/
     x 7.4376324d-04,-9.3820710d-07,-5.4440534d-07 /
      data fpp(22, 8, 8,1),fpp(22, 8, 8,2),fpp(22, 8, 8,3)/
     x 4.7354145d-06,-4.2468044d-06,-2.9557782d-07 /
      data fpp(22, 8, 9,1),fpp(22, 8, 9,2),fpp(22, 8, 9,3)/
     x-7.9682558d-04,-6.7696457d-06, 6.4716638d-08 /
      data fpp(22, 8,10,1),fpp(22, 8,10,2),fpp(22, 8,10,3)/
     x-1.5710592d-03,-8.4906654d-06, 5.0471127d-07 /
      data fpp(22, 8,11,1),fpp(22, 8,11,2),fpp(22, 8,11,3)/
     x-2.2138682d-03,-9.4463605d-06, 9.9443827d-07 /
      data fpp(22, 8,12,1),fpp(22, 8,12,2),fpp(22, 8,12,3)/
     x-2.6495778d-03,-9.6756194d-06, 1.4035357d-06 /
      data fpp(22, 8,13,1),fpp(22, 8,13,2),fpp(22, 8,13,3)/
     x-2.8225586d-03,-9.1969771d-06, 1.6354191d-06 /
      data fpp(22, 8,14,1),fpp(22, 8,14,2),fpp(22, 8,14,3)/
     x-2.7168318d-03,-8.0209573d-06, 1.6547880d-06 /
      data fpp(22, 8,15,1),fpp(22, 8,15,2),fpp(22, 8,15,3)/
     x-2.3243174d-03,-6.1211279d-06, 1.5254291d-06 /
      data fpp(22, 8,16,1),fpp(22, 8,16,2),fpp(22, 8,16,3)/
     x-1.6764546d-03,-3.4884154d-06, 1.1774957d-06 /
      data fpp(22, 8,17,1),fpp(22, 8,17,2),fpp(22, 8,17,3)/
     x-8.2464470d-04,-2.0186952d-07, 5.4458800d-07 /
      data fpp(22, 8,18,1),fpp(22, 8,18,2),fpp(22, 8,18,3)/
     x 1.3563340d-04, 3.4130540d-06,-4.2184772d-07 /
      data fpp(22, 8,19,1),fpp(22, 8,19,2),fpp(22, 8,19,3)/
     x 1.0338148d-03, 6.7604439d-06,-1.4911971d-06 /
      data fpp(22, 8,20,1),fpp(22, 8,20,2),fpp(22, 8,20,3)/
     x 1.6880759d-03, 9.1321863d-06,-2.2953637d-06 /
      data fpp(22, 8,21,1),fpp(22, 8,21,2),fpp(22, 8,21,3)/
     x 1.6880759d-03, 9.1321863d-06,-2.3283102d-06 /
      data fpp(22, 8,22,1),fpp(22, 8,22,2),fpp(22, 8,22,3)/
     x 1.0338148d-03, 6.7604439d-06,-1.3594114d-06 /
      data fpp(22, 8,23,1),fpp(22, 8,23,2),fpp(22, 8,23,3)/
     x 1.3563340d-04, 3.4130540d-06,-9.1604431d-07 /
      data fpp(22, 9, 1,1),fpp(22, 9, 1,2),fpp(22, 9, 1,3)/
     x 1.4429542d-03,-4.0782307d-07, 4.1816695d-07 /
      data fpp(22, 9, 2,1),fpp(22, 9, 2,2),fpp(22, 9, 2,3)/
     x 1.7975655d-03, 2.1278596d-06,-2.0833901d-08 /
      data fpp(22, 9, 3,1),fpp(22, 9, 3,2),fpp(22, 9, 3,3)/
     x 2.2846507d-03, 4.5649228d-06,-9.5283135d-07 /
      data fpp(22, 9, 4,1),fpp(22, 9, 4,2),fpp(22, 9, 4,3)/
     x 2.2846507d-03, 4.5649228d-06,-9.6808901d-07 /
      data fpp(22, 9, 5,1),fpp(22, 9, 5,2),fpp(22, 9, 5,3)/
     x 1.7975655d-03, 2.1278596d-06, 4.0196748d-08 /
      data fpp(22, 9, 6,1),fpp(22, 9, 6,2),fpp(22, 9, 6,3)/
     x 1.4429542d-03,-4.0782307d-07, 1.8930202d-07 /
      data fpp(22, 9, 7,1),fpp(22, 9, 7,2),fpp(22, 9, 7,3)/
     x 1.1419170d-03,-2.3164663d-06,-1.0740481d-07 /
      data fpp(22, 9, 8,1),fpp(22, 9, 8,2),fpp(22, 9, 8,3)/
     x 8.2111976d-04,-3.6039232d-06,-3.8968276d-07 /
      data fpp(22, 9, 9,1),fpp(22, 9, 9,2),fpp(22, 9, 9,3)/
     x 4.2035318d-04,-4.5509656d-06,-3.2586414d-07 /
      data fpp(22, 9,10,1),fpp(22, 9,10,2),fpp(22, 9,10,3)/
     x-5.8622133d-05,-5.2914500d-06,-6.4860676d-08 /
      data fpp(22, 9,11,1),fpp(22, 9,11,2),fpp(22, 9,11,3)/
     x-5.2264689d-04,-5.7720817d-06, 2.6730684d-07 /
      data fpp(22, 9,12,1),fpp(22, 9,12,2),fpp(22, 9,12,3)/
     x-8.8404086d-04,-5.8861308d-06, 5.7363330d-07 /
      data fpp(22, 9,13,1),fpp(22, 9,13,2),fpp(22, 9,13,3)/
     x-1.0864033d-03,-5.5887348d-06, 8.1615995d-07 /
      data fpp(22, 9,14,1),fpp(22, 9,14,2),fpp(22, 9,14,3)/
     x-1.1152259d-03,-4.9167347d-06, 9.4372690d-07 /
      data fpp(22, 9,15,1),fpp(22, 9,15,2),fpp(22, 9,15,3)/
     x-9.7202396d-04,-3.9431154d-06, 9.2293246d-07 /
      data fpp(22, 9,16,1),fpp(22, 9,16,2),fpp(22, 9,16,3)/
     x-6.6873125d-04,-2.7020823d-06, 7.2254325d-07 /
      data fpp(22, 9,17,1),fpp(22, 9,17,2),fpp(22, 9,17,3)/
     x-2.3868497d-04,-1.2356823d-06, 3.0889455d-07 /
      data fpp(22, 9,18,1),fpp(22, 9,18,2),fpp(22, 9,18,3)/
     x 2.7128895d-04, 3.5733763d-07,-2.6012146d-07 /
      data fpp(22, 9,19,1),fpp(22, 9,19,2),fpp(22, 9,19,3)/
     x 7.6124946d-04, 1.8461364d-06,-8.1040873d-07 /
      data fpp(22, 9,20,1),fpp(22, 9,20,2),fpp(22, 9,20,3)/
     x 1.1158573d-03, 2.8911765d-06,-9.1424364d-07 /
      data fpp(22, 9,21,1),fpp(22, 9,21,2),fpp(22, 9,21,3)/
     x 1.1158573d-03, 2.8911765d-06,-9.3806473d-07 /
      data fpp(22, 9,22,1),fpp(22, 9,22,2),fpp(22, 9,22,3)/
     x 7.6124946d-04, 1.8461364d-06,-7.1512436d-07 /
      data fpp(22, 9,23,1),fpp(22, 9,23,2),fpp(22, 9,23,3)/
     x 2.7128895d-04, 3.5733763d-07,-6.1743782d-07 /
      data fpp(22,10, 1,1),fpp(22,10, 1,2),fpp(22,10, 1,3)/
     x 1.6309968d-03,-1.1061806d-06, 2.5325934d-06 /
      data fpp(22,10, 2,1),fpp(22,10, 2,2),fpp(22,10, 2,3)/
     x 2.3945802d-03, 5.4189765d-07, 8.6981310d-07 /
      data fpp(22,10, 3,1),fpp(22,10, 3,2),fpp(22,10, 3,3)/
     x 3.1925808d-03, 2.4269177d-06,-2.6638459d-06 /
      data fpp(22,10, 4,1),fpp(22,10, 4,2),fpp(22,10, 4,3)/
     x 3.1925808d-03, 2.4269177d-06,-2.7153690d-06 /
      data fpp(22,10, 5,1),fpp(22,10, 5,2),fpp(22,10, 5,3)/
     x 2.3945802d-03, 5.4189765d-07, 1.0759055d-06 /
      data fpp(22,10, 6,1),fpp(22,10, 6,2),fpp(22,10, 6,3)/
     x 1.6309968d-03,-1.1061806d-06, 1.7597470d-06 /
      data fpp(22,10, 7,1),fpp(22,10, 7,2),fpp(22,10, 7,3)/
     x 1.2339817d-03,-2.0719278d-06, 9.6910650d-07 /
      data fpp(22,10, 8,1),fpp(22,10, 8,2),fpp(22,10, 8,3)/
     x 1.0581289d-03,-2.5415026d-06,-1.1017301d-07 /
      data fpp(22,10, 9,1),fpp(22,10, 9,2),fpp(22,10, 9,3)/
     x 8.9707880d-04,-2.7764919d-06,-4.6841447d-07 /
      data fpp(22,10,10,1),fpp(22,10,10,2),fpp(22,10,10,3)/
     x 6.4404465d-04,-2.9775346d-06,-3.3816911d-07 /
      data fpp(22,10,11,1),fpp(22,10,11,2),fpp(22,10,11,3)/
     x 3.3214090d-04,-3.1533126d-06,-6.2909090d-08 /
      data fpp(22,10,12,1),fpp(22,10,12,2),fpp(22,10,12,3)/
     x 4.4668626d-05,-3.1998575d-06, 1.8180547d-07 /
      data fpp(22,10,13,1),fpp(22,10,13,2),fpp(22,10,13,3)/
     x-1.4895178d-04,-3.0500836d-06, 3.9768721d-07 /
      data fpp(22,10,14,1),fpp(22,10,14,2),fpp(22,10,14,3)/
     x-2.2833883d-04,-2.7201039d-06, 5.6744570d-07 /
      data fpp(22,10,15,1),fpp(22,10,15,2),fpp(22,10,15,3)/
     x-1.8464290d-04,-2.2624103d-06, 6.3852998d-07 /
      data fpp(22,10,16,1),fpp(22,10,16,2),fpp(22,10,16,3)/
     x-2.1689135d-05,-1.7172553d-06, 5.5043437d-07 /
      data fpp(22,10,17,1),fpp(22,10,17,2),fpp(22,10,17,3)/
     x 2.5028468d-04,-1.1074012d-06, 2.4373254d-07 /
      data fpp(22,10,18,1),fpp(22,10,18,2),fpp(22,10,18,3)/
     x 5.8848737d-04,-4.6840455d-07,-1.9936453d-07 /
      data fpp(22,10,19,1),fpp(22,10,19,2),fpp(22,10,19,3)/
     x 9.1836335d-04, 1.2301045d-07,-6.2827440d-07 /
      data fpp(22,10,20,1),fpp(22,10,20,2),fpp(22,10,20,3)/
     x 1.1495857d-03, 5.6110772d-07,-3.4153785d-07 /
      data fpp(22,10,21,1),fpp(22,10,21,2),fpp(22,10,21,3)/
     x 1.1495857d-03, 5.6110772d-07,-3.6824925d-07 /
      data fpp(22,10,22,1),fpp(22,10,22,2),fpp(22,10,22,3)/
     x 9.1836335d-04, 1.2301045d-07,-5.2142878d-07 /
      data fpp(22,10,23,1),fpp(22,10,23,2),fpp(22,10,23,3)/
     x 5.8848737d-04,-4.6840455d-07,-6.0003561d-07 /
      data fpp(22,11, 1,1),fpp(22,11, 1,2),fpp(22,11, 1,3)/
     x 1.6689365d-03,-9.9454421d-08, 5.6599278d-06 /
      data fpp(22,11, 2,1),fpp(22,11, 2,2),fpp(22,11, 2,3)/
     x 3.1951925d-03, 5.0454975d-07, 2.0221444d-06 /
      data fpp(22,11, 3,1),fpp(22,11, 3,2),fpp(22,11, 3,3)/
     x 4.9745200d-03, 9.8540624d-07,-5.7085054d-06 /
      data fpp(22,11, 4,1),fpp(22,11, 4,2),fpp(22,11, 4,3)/
     x 4.9745200d-03, 9.8540624d-07,-5.8215560d-06 /
      data fpp(22,11, 5,1),fpp(22,11, 5,2),fpp(22,11, 5,3)/
     x 3.1951925d-03, 5.0454975d-07, 2.4743470d-06 /
      data fpp(22,11, 6,1),fpp(22,11, 6,2),fpp(22,11, 6,3)/
     x 1.6689365d-03,-9.9454421d-08, 3.9641682d-06 /
      data fpp(22,11, 7,1),fpp(22,11, 7,2),fpp(22,11, 7,3)/
     x 1.0081588d-03,-6.8782266d-07, 2.5189803d-06 /
      data fpp(22,11, 8,1),fpp(22,11, 8,2),fpp(22,11, 8,3)/
     x 8.7881607d-04,-1.1220664d-06, 4.0191051d-07 /
      data fpp(22,11, 9,1),fpp(22,11, 9,2),fpp(22,11, 9,3)/
     x 8.9557845d-04,-1.3830668d-06,-5.6262238d-07 /
      data fpp(22,11,10,1),fpp(22,11,10,2),fpp(22,11,10,3)/
     x 8.7555871d-04,-1.5064114d-06,-5.5742098d-07 /
      data fpp(22,11,11,1),fpp(22,11,11,2),fpp(22,11,11,3)/
     x 6.8548496d-04,-1.5646677d-06,-2.3169370d-07 /
      data fpp(22,11,12,1),fpp(22,11,12,2),fpp(22,11,12,3)/
     x 4.8384465d-04,-1.5884392d-06, 8.1957668d-09 /
      data fpp(22,11,13,1),fpp(22,11,13,2),fpp(22,11,13,3)/
     x 3.2312349d-04,-1.5729309d-06, 1.8091063d-07 /
      data fpp(22,11,14,1),fpp(22,11,14,2),fpp(22,11,14,3)/
     x 2.4018348d-04,-1.4828496d-06, 3.3616172d-07 /
      data fpp(22,11,15,1),fpp(22,11,15,2),fpp(22,11,15,3)/
     x 2.6568568d-04,-1.3172433d-06, 4.6044251d-07 /
      data fpp(22,11,16,1),fpp(22,11,16,2),fpp(22,11,16,3)/
     x 3.9935885d-04,-1.1208965d-06, 4.5606825d-07 /
      data fpp(22,11,17,1),fpp(22,11,17,2),fpp(22,11,17,3)/
     x 6.2699539d-04,-9.4071289d-07, 2.2928450d-07 /
      data fpp(22,11,18,1),fpp(22,11,18,2),fpp(22,11,18,3)/
     x 9.0375767d-04,-7.5771943d-07,-1.7320625d-07 /
      data fpp(22,11,19,1),fpp(22,11,19,2),fpp(22,11,19,3)/
     x 1.1628778d-03,-5.1417819d-07,-5.9245950d-07 /
      data fpp(22,11,20,1),fpp(22,11,20,2),fpp(22,11,20,3)/
     x 1.3314463d-03,-2.0360737d-07,-1.3895575d-07 /
      data fpp(22,11,21,1),fpp(22,11,21,2),fpp(22,11,21,3)/
     x 1.3314463d-03,-2.0360737d-07,-1.6890299d-07 /
      data fpp(22,11,22,1),fpp(22,11,22,2),fpp(22,11,22,3)/
     x 1.1628778d-03,-5.1417819d-07,-4.7267058d-07 /
      data fpp(22,11,23,1),fpp(22,11,23,2),fpp(22,11,23,3)/
     x 9.0375767d-04,-7.5771943d-07,-6.2241471d-07 /
      data fpp(22,12, 1,1),fpp(22,12, 1,2),fpp(22,12, 1,3)/
     x 1.6813049d-03, 1.9599983d-06, 8.5306786d-06 /
      data fpp(22,12, 2,1),fpp(22,12, 2,2),fpp(22,12, 2,3)/
     x 4.1098651d-03, 7.8190334d-07, 2.9476429d-06 /
      data fpp(22,12, 3,1),fpp(22,12, 3,2),fpp(22,12, 3,3)/
     x 6.5893214d-03,-1.4725427d-06,-8.9212501d-06 /
      data fpp(22,12, 4,1),fpp(22,12, 4,2),fpp(22,12, 4,3)/
     x 6.5893214d-03,-1.4725427d-06,-9.0870711d-06 /
      data fpp(22,12, 5,1),fpp(22,12, 5,2),fpp(22,12, 5,3)/
     x 4.1098651d-03, 7.8190334d-07, 3.6109270d-06 /
      data fpp(22,12, 6,1),fpp(22,12, 6,2),fpp(22,12, 6,3)/
     x 1.6813049d-03, 1.9599983d-06, 6.0433630d-06 /
      data fpp(22,12, 7,1),fpp(22,12, 7,2),fpp(22,12, 7,3)/
     x 6.5628044d-04, 1.7332184d-06, 4.1716208d-06 /
      data fpp(22,12, 8,1),fpp(22,12, 8,2),fpp(22,12, 8,3)/
     x 5.0963858d-04, 8.6776835d-07, 1.1021536d-06 /
      data fpp(22,12, 9,1),fpp(22,12, 9,2),fpp(22,12, 9,3)/
     x 6.4487808d-04, 9.4758918d-08,-4.9223527d-07 /
      data fpp(22,12,10,1),fpp(22,12,10,2),fpp(22,12,10,3)/
     x 7.5266755d-04,-3.3881966d-07,-6.9921252d-07 /
      data fpp(22,12,11,1),fpp(22,12,11,2),fpp(22,12,11,3)/
     x 7.4068661d-04,-5.3601638d-07,-3.5291466d-07 /
      data fpp(22,12,12,1),fpp(22,12,12,2),fpp(22,12,12,3)/
     x 6.3603204d-04,-6.7038581d-07,-1.0312884d-07 /
      data fpp(22,12,13,1),fpp(22,12,13,2),fpp(22,12,13,3)/
     x 5.2078610d-04,-7.6819283d-07, 5.7430013d-08 /
      data fpp(22,12,14,1),fpp(22,12,14,2),fpp(22,12,14,3)/
     x 4.6426462d-04,-8.2249759d-07, 1.9140879d-07 /
      data fpp(22,12,15,1),fpp(22,12,15,2),fpp(22,12,15,3)/
     x 5.0447426d-04,-8.2661665d-07, 3.2293484d-07 /
      data fpp(22,12,16,1),fpp(22,12,16,2),fpp(22,12,16,3)/
     x 6.4531972d-04,-8.0115856d-07, 3.5285185d-07 /
      data fpp(22,12,17,1),fpp(22,12,17,2),fpp(22,12,17,3)/
     x 8.6532879d-04,-7.7574723d-07, 2.0965777d-07 /
      data fpp(22,12,18,1),fpp(22,12,18,2),fpp(22,12,18,3)/
     x 1.1114449d-03,-7.9071774d-07,-1.1748294d-07 /
      data fpp(22,12,19,1),fpp(22,12,19,2),fpp(22,12,19,3)/
     x 1.3277740d-03,-8.0229769d-07,-4.7172601d-07 /
      data fpp(22,12,20,1),fpp(22,12,20,2),fpp(22,12,20,3)/
     x 1.4668415d-03,-7.8467825d-07,-1.6161302d-07 /
      data fpp(22,12,21,1),fpp(22,12,21,2),fpp(22,12,21,3)/
     x 1.4668415d-03,-7.8467825d-07,-1.8529794d-07 /
      data fpp(22,12,22,1),fpp(22,12,22,2),fpp(22,12,22,3)/
     x 1.3277740d-03,-8.0229769d-07,-3.7698630d-07 /
      data fpp(22,12,23,1),fpp(22,12,23,2),fpp(22,12,23,3)/
     x 1.1114449d-03,-7.9071774d-07,-4.7275685d-07 /
      data fpp(22,13, 1,1),fpp(22,13, 1,2),fpp(22,13, 1,3)/
     x 2.0660869d-03, 2.1294612d-06, 8.8756203d-06 /
      data fpp(22,13, 2,1),fpp(22,13, 2,2),fpp(22,13, 2,3)/
     x 5.2126275d-03,-1.0461631d-06, 2.7112594d-06 /
      data fpp(22,13, 3,1),fpp(22,13, 3,2),fpp(22,13, 3,3)/
     x 8.7584713d-03,-5.2472354d-06,-1.0414658d-05 /
      data fpp(22,13, 4,1),fpp(22,13, 4,2),fpp(22,13, 4,3)/
     x 8.7584713d-03,-5.2472354d-06,-1.0560656d-05 /
      data fpp(22,13, 5,1),fpp(22,13, 5,2),fpp(22,13, 5,3)/
     x 5.2126275d-03,-1.0461631d-06, 3.2952543d-06 /
      data fpp(22,13, 6,1),fpp(22,13, 6,2),fpp(22,13, 6,3)/
     x 2.0660869d-03, 2.1294612d-06, 6.6856394d-06 /
      data fpp(22,13, 7,1),fpp(22,13, 7,2),fpp(22,13, 7,3)/
     x 5.9648654d-04, 3.0609490d-06, 5.1761883d-06 /
      data fpp(22,13, 8,1),fpp(22,13, 8,2),fpp(22,13, 8,3)/
     x 2.8348458d-04, 2.4689931d-06, 1.9076075d-06 /
      data fpp(22,13, 9,1),fpp(22,13, 9,2),fpp(22,13, 9,3)/
     x 3.9752229d-04, 1.4480311d-06,-8.0618421d-08 /
      data fpp(22,13,10,1),fpp(22,13,10,2),fpp(22,13,10,3)/
     x 5.6738808d-04, 6.3569008d-07,-6.0713385d-07 /
      data fpp(22,13,11,1),fpp(22,13,11,2),fpp(22,13,11,3)/
     x 6.5157225d-04, 1.4473327d-07,-4.1884617d-07 /
      data fpp(22,13,12,1),fpp(22,13,12,2),fpp(22,13,12,3)/
     x 6.3534124d-04,-1.3401761d-07,-1.7148149d-07 /
      data fpp(22,13,13,1),fpp(22,13,13,2),fpp(22,13,13,3)/
     x 5.7687814d-04,-3.2229780d-07,-1.7227890d-08 /
      data fpp(22,13,14,1),fpp(22,13,14,2),fpp(22,13,14,3)/
     x 5.4739613d-04,-4.5916001d-07, 1.0839305d-07 /
      data fpp(22,13,15,1),fpp(22,13,15,2),fpp(22,13,15,3)/
     x 5.9697060d-04,-5.4829014d-07, 2.1365570d-07 /
      data fpp(22,13,16,1),fpp(22,13,16,2),fpp(22,13,16,3)/
     x 7.3603742d-04,-6.1246922d-07, 2.4898414d-07 /
      data fpp(22,13,17,1),fpp(22,13,17,2),fpp(22,13,17,3)/
     x 9.3905591d-04,-6.7829819d-07, 1.4640773d-07 /
      data fpp(22,13,18,1),fpp(22,13,18,2),fpp(22,13,18,3)/
     x 1.1559485d-03,-7.5940963d-07,-6.0615047d-08 /
      data fpp(22,13,19,1),fpp(22,13,19,2),fpp(22,13,19,3)/
     x 1.3339847d-03,-9.0863106d-07,-3.0594754d-07 /
      data fpp(22,13,20,1),fpp(22,13,20,2),fpp(22,13,20,3)/
     x 1.4456912d-03,-1.0916796d-06,-2.1559480d-07 /
      data fpp(22,13,21,1),fpp(22,13,21,2),fpp(22,13,21,3)/
     x 1.4456912d-03,-1.0916796d-06,-2.2924182d-07 /
      data fpp(22,13,22,1),fpp(22,13,22,2),fpp(22,13,22,3)/
     x 1.3339847d-03,-9.0863106d-07,-2.5135948d-07 /
      data fpp(22,13,23,1),fpp(22,13,23,2),fpp(22,13,23,3)/
     x 1.1559485d-03,-7.5940963d-07,-2.6532026d-07 /
      data fpp(22,14, 1,1),fpp(22,14, 1,2),fpp(22,14, 1,3)/
     x 2.8601812d-03,-4.8184304d-07, 6.1289865d-06 /
      data fpp(22,14, 2,1),fpp(22,14, 2,2),fpp(22,14, 2,3)/
     x 5.9453486d-03,-3.5152509d-06, 1.2905270d-06 /
      data fpp(22,14, 3,1),fpp(22,14, 3,2),fpp(22,14, 3,3)/
     x 9.0316066d-03,-6.3325158d-06,-9.0410944d-06 /
      data fpp(22,14, 4,1),fpp(22,14, 4,2),fpp(22,14, 4,3)/
     x 9.0316066d-03,-6.3325158d-06,-9.1049803d-06 /
      data fpp(22,14, 5,1),fpp(22,14, 5,2),fpp(22,14, 5,3)/
     x 5.9453486d-03,-3.5152509d-06, 1.5460705d-06 /
      data fpp(22,14, 6,1),fpp(22,14, 6,2),fpp(22,14, 6,3)/
     x 2.8601812d-03,-4.8184304d-07, 5.1706982d-06 /
      data fpp(22,14, 7,1),fpp(22,14, 7,2),fpp(22,14, 7,3)/
     x 1.1081379d-03, 1.4669855d-06, 4.7771366d-06 /
      data fpp(22,14, 8,1),fpp(22,14, 8,2),fpp(22,14, 8,3)/
     x 4.8202829d-04, 2.0422594d-06, 2.3787555d-06 /
      data fpp(22,14, 9,1),fpp(22,14, 9,2),fpp(22,14, 9,3)/
     x 3.9527178d-04, 1.7271168d-06, 5.5784127d-07 /
      data fpp(22,14,10,1),fpp(22,14,10,2),fpp(22,14,10,3)/
     x 4.7097384d-04, 1.1080594d-06,-2.1812064d-07 /
      data fpp(22,14,11,1),fpp(22,14,11,2),fpp(22,14,11,3)/
     x 5.4956554d-04, 5.6308331d-07,-3.0335872d-07 /
      data fpp(22,14,12,1),fpp(22,14,12,2),fpp(22,14,12,3)/
     x 5.7758164d-04, 2.0445624d-07,-1.6444448d-07 /
      data fpp(22,14,13,1),fpp(22,14,13,2),fpp(22,14,13,3)/
     x 5.5861390d-04,-1.8615986d-08,-4.0863372d-08 /
      data fpp(22,14,14,1),fpp(22,14,14,2),fpp(22,14,14,3)/
     x 5.5220330d-04,-1.6686238d-07, 6.9897965d-08 /
      data fpp(22,14,15,1),fpp(22,14,15,2),fpp(22,14,15,3)/
     x 5.9960552d-04,-2.9822277d-07, 1.3327151d-07 /
      data fpp(22,14,16,1),fpp(22,14,16,2),fpp(22,14,16,3)/
     x 7.2202117d-04,-3.9696458d-07, 1.4701599d-07 /
      data fpp(22,14,17,1),fpp(22,14,17,2),fpp(22,14,17,3)/
     x 8.7492555d-04,-4.5906000d-07, 7.6664542d-08 /
      data fpp(22,14,18,1),fpp(22,14,18,2),fpp(22,14,18,3)/
     x 1.0473332d-03,-4.9764376d-07,-5.7674156d-08 /
      data fpp(22,14,19,1),fpp(22,14,19,2),fpp(22,14,19,3)/
     x 1.1918680d-03,-5.3117806d-07,-1.8196792d-07 /
      data fpp(22,14,20,1),fpp(22,14,20,2),fpp(22,14,20,3)/
     x 1.2709706d-03,-5.7860324d-07,-1.6845417d-07 /
      data fpp(22,14,21,1),fpp(22,14,21,2),fpp(22,14,21,3)/
     x 1.2709706d-03,-5.7860324d-07,-1.7465354d-07 /
      data fpp(22,14,22,1),fpp(22,14,22,2),fpp(22,14,22,3)/
     x 1.1918680d-03,-5.3117806d-07,-1.5717042d-07 /
      data fpp(22,14,23,1),fpp(22,14,23,2),fpp(22,14,23,3)/
     x 1.0473332d-03,-4.9764376d-07,-1.5066479d-07 /
      data fpp(22,15, 1,1),fpp(22,15, 1,2),fpp(22,15, 1,3)/
     x 3.5059616d-03,-3.2020890d-06, 2.4708285d-06 /
      data fpp(22,15, 2,1),fpp(22,15, 2,2),fpp(22,15, 2,3)/
     x 5.6210045d-03,-3.8228333d-06,-1.5365699d-07 /
      data fpp(22,15, 3,1),fpp(22,15, 3,2),fpp(22,15, 3,3)/
     x 7.0892578d-03,-3.4007016d-06,-5.7802005d-06 /
      data fpp(22,15, 4,1),fpp(22,15, 4,2),fpp(22,15, 4,3)/
     x 7.0892578d-03,-3.4007016d-06,-5.7755699d-06 /
      data fpp(22,15, 5,1),fpp(22,15, 5,2),fpp(22,15, 5,3)/
     x 5.6210045d-03,-3.8228333d-06,-1.7217964d-07 /
      data fpp(22,15, 6,1),fpp(22,15, 6,2),fpp(22,15, 6,3)/
     x 3.5059616d-03,-3.2020890d-06, 2.5402884d-06 /
      data fpp(22,15, 7,1),fpp(22,15, 7,2),fpp(22,15, 7,3)/
     x 1.9172577d-03,-1.7228912d-06, 3.0850259d-06 /
      data fpp(22,15, 8,1),fpp(22,15, 8,2),fpp(22,15, 8,3)/
     x 1.0622331d-03,-2.8203085d-07, 2.0816079d-06 /
      data fpp(22,15, 9,1),fpp(22,15, 9,2),fpp(22,15, 9,3)/
     x 6.9316199d-04, 5.4750186d-07, 9.6054249d-07 /
      data fpp(22,15,10,1),fpp(22,15,10,2),fpp(22,15,10,3)/
     x 5.6717840d-04, 7.5807249d-07, 2.5622215d-07 /
      data fpp(22,15,11,1),fpp(22,15,11,2),fpp(22,15,11,3)/
     x 5.3703808d-04, 6.2693348d-07,-1.7431074d-08 /
      data fpp(22,15,12,1),fpp(22,15,12,2),fpp(22,15,12,3)/
     x 5.3069820d-04, 4.1419267d-07,-4.8497849d-08 /
      data fpp(22,15,13,1),fpp(22,15,13,2),fpp(22,15,13,3)/
     x 5.2291148d-04, 2.4076174d-07, 1.4224703d-09 /
      data fpp(22,15,14,1),fpp(22,15,14,2),fpp(22,15,14,3)/
     x 5.2450937d-04, 1.0660953d-07, 4.8807968d-08 /
      data fpp(22,15,15,1),fpp(22,15,15,2),fpp(22,15,15,3)/
     x 5.5208170d-04, 2.5181241d-08, 8.5345659d-08 /
      data fpp(22,15,16,1),fpp(22,15,16,2),fpp(22,15,16,3)/
     x 6.2487093d-04,-3.1672475d-08, 7.7809398d-08 /
      data fpp(22,15,17,1),fpp(22,15,17,2),fpp(22,15,17,3)/
     x 7.2739291d-04,-4.7461824d-08, 2.9416751d-08 /
      data fpp(22,15,18,1),fpp(22,15,18,2),fpp(22,15,18,3)/
     x 8.4438678d-04,-1.6015347d-08,-5.1476402d-08 /
      data fpp(22,15,19,1),fpp(22,15,19,2),fpp(22,15,19,3)/
     x 9.4306344d-04, 6.3343291d-08,-9.3511142d-08 /
      data fpp(22,15,20,1),fpp(22,15,20,2),fpp(22,15,20,3)/
     x 1.0041492d-03, 1.3609258d-07,-7.8479030d-08 /
      data fpp(22,15,21,1),fpp(22,15,21,2),fpp(22,15,21,3)/
     x 1.0041492d-03, 1.3609258d-07,-8.0807340d-08 /
      data fpp(22,15,22,1),fpp(22,15,22,2),fpp(22,15,22,3)/
     x 9.4306344d-04, 6.3343291d-08,-8.4197903d-08 /
      data fpp(22,15,23,1),fpp(22,15,23,2),fpp(22,15,23,3)/
     x 8.4438678d-04,-1.6015347d-08,-8.6401049d-08 /
      data fpp(22,16, 1,1),fpp(22,16, 1,2),fpp(22,16, 1,3)/
     x 3.5054421d-03,-3.2578009d-06, 2.8290656d-07 /
      data fpp(22,16, 2,1),fpp(22,16, 2,2),fpp(22,16, 2,3)/
     x 4.8430666d-03,-1.9474158d-06,-6.6881312d-07 /
      data fpp(22,16, 3,1),fpp(22,16, 3,2),fpp(22,16, 3,3)/
     x 5.4989654d-03,-3.8677928d-08,-2.7196541d-06 /
      data fpp(22,16, 4,1),fpp(22,16, 4,2),fpp(22,16, 4,3)/
     x 5.4989654d-03,-3.8677928d-08,-2.6996312d-06 /
      data fpp(22,16, 5,1),fpp(22,16, 5,2),fpp(22,16, 5,3)/
     x 4.8430666d-03,-1.9474158d-06,-7.4890490d-07 /
      data fpp(22,16, 6,1),fpp(22,16, 6,2),fpp(22,16, 6,3)/
     x 3.5054421d-03,-3.2578009d-06, 5.8325075d-07 /
      data fpp(22,16, 7,1),fpp(22,16, 7,2),fpp(22,16, 7,3)/
     x 2.3926408d-03,-3.2394209d-06, 1.2359019d-06 /
      data fpp(22,16, 8,1),fpp(22,16, 8,2),fpp(22,16, 8,3)/
     x 1.6033858d-03,-2.2581361d-06, 1.1751416d-06 /
      data fpp(22,16, 9,1),fpp(22,16, 9,2),fpp(22,16, 9,3)/
     x 1.0838653d-03,-1.0851242d-06, 8.1353172d-07 /
      data fpp(22,16,10,1),fpp(22,16,10,2),fpp(22,16,10,3)/
     x 8.0464089d-04,-2.1634933d-07, 4.5473155d-07 /
      data fpp(22,16,11,1),fpp(22,16,11,2),fpp(22,16,11,3)/
     x 6.4227364d-04, 2.4118278d-07, 2.1754210d-07 /
      data fpp(22,16,12,1),fpp(22,16,12,2),fpp(22,16,12,3)/
     x 5.5951452d-04, 4.0077310d-07, 1.0910005d-07 /
      data fpp(22,16,13,1),fpp(22,16,13,2),fpp(22,16,13,3)/
     x 5.1369930d-04, 4.1156902d-07, 7.2057715d-08 /
      data fpp(22,16,14,1),fpp(22,16,14,2),fpp(22,16,14,3)/
     x 4.9569514d-04, 3.8842425d-07, 7.0669092d-08 /
      data fpp(22,16,15,1),fpp(22,16,15,2),fpp(22,16,15,3)/
     x 4.9688740d-04, 3.5949781d-07, 5.9265915d-08 /
      data fpp(22,16,16,1),fpp(22,16,16,2),fpp(22,16,16,3)/
     x 5.1457572d-04, 3.7365448d-07, 5.2267248d-08 /
      data fpp(22,16,17,1),fpp(22,16,17,2),fpp(22,16,17,3)/
     x 5.6684674d-04, 4.2090729d-07, 1.9665091d-08 /
      data fpp(22,16,18,1),fpp(22,16,18,2),fpp(22,16,18,3)/
     x 6.1997383d-04, 4.8970514d-07,-4.9276138d-09 /
      data fpp(22,16,19,1),fpp(22,16,19,2),fpp(22,16,19,3)/
     x 6.7089456d-04, 5.4180489d-07,-2.3954636d-08 /
      data fpp(22,16,20,1),fpp(22,16,20,2),fpp(22,16,20,3)/
     x 7.0424683d-04, 5.6823292d-07,-1.9253842d-08 /
      data fpp(22,16,21,1),fpp(22,16,21,2),fpp(22,16,21,3)/
     x 7.0424683d-04, 5.6823292d-07,-2.0261155d-08 /
      data fpp(22,16,22,1),fpp(22,16,22,2),fpp(22,16,22,3)/
     x 6.7089456d-04, 5.4180489d-07,-1.9925384d-08 /
      data fpp(22,16,23,1),fpp(22,16,23,2),fpp(22,16,23,3)/
     x 6.1997383d-04, 4.8970514d-07,-2.0037308d-08 /
      data fpp(22,17, 1,1),fpp(22,17, 1,2),fpp(22,17, 1,3)/
     x 2.7886678d-03,-8.3670746d-07,-2.3705919d-07 /
      data fpp(22,17, 2,1),fpp(22,17, 2,2),fpp(22,17, 2,3)/
     x 3.1630515d-03, 7.4049656d-07,-4.5638162d-07 /
      data fpp(22,17, 3,1),fpp(22,17, 3,2),fpp(22,17, 3,3)/
     x 3.4125641d-03, 2.1874133d-06,-9.3141433d-07 /
      data fpp(22,17, 4,1),fpp(22,17, 4,2),fpp(22,17, 4,3)/
     x 3.4125641d-03, 2.1874133d-06,-9.2256620d-07 /
      data fpp(22,17, 5,1),fpp(22,17, 5,2),fpp(22,17, 5,3)/
     x 3.1630515d-03, 7.4049656d-07,-4.9177413d-07 /
      data fpp(22,17, 6,1),fpp(22,17, 6,2),fpp(22,17, 6,3)/
     x 2.7886678d-03,-8.3670746d-07,-1.0433728d-07 /
      data fpp(22,17, 7,1),fpp(22,17, 7,2),fpp(22,17, 7,3)/
     x 2.1529364d-03,-1.8614251d-06, 2.0112326d-07 /
      data fpp(22,17, 8,1),fpp(22,17, 8,2),fpp(22,17, 8,3)/
     x 1.6814070d-03,-2.1034249d-06, 3.3784424d-07 /
      data fpp(22,17, 9,1),fpp(22,17, 9,2),fpp(22,17, 9,3)/
     x 1.2963145d-03,-1.7270050d-06, 3.4949978d-07 /
      data fpp(22,17,10,1),fpp(22,17,10,2),fpp(22,17,10,3)/
     x 1.0070612d-03,-1.0746752d-06, 2.9215664d-07 /
      data fpp(22,17,11,1),fpp(22,17,11,2),fpp(22,17,11,3)/
     x 8.0318403d-04,-4.3366459d-07, 2.1587365d-07 /
      data fpp(22,17,12,1),fpp(22,17,12,2),fpp(22,17,12,3)/
     x 6.6375768d-04, 5.8714935d-08, 1.5234876d-07 /
      data fpp(22,17,13,1),fpp(22,17,13,2),fpp(22,17,13,3)/
     x 5.7617623d-04, 3.8696219d-07, 1.1673132d-07 /
      data fpp(22,17,14,1),fpp(22,17,14,2),fpp(22,17,14,3)/
     x 5.1872984d-04, 5.8369347d-07, 8.2725974d-08 /
      data fpp(22,17,15,1),fpp(22,17,15,2),fpp(22,17,15,3)/
     x 4.8765260d-04, 7.2082751d-07, 6.8364788d-08 /
      data fpp(22,17,16,1),fpp(22,17,16,2),fpp(22,17,16,3)/
     x 4.7371928d-04, 8.1705456d-07, 5.1814874d-08 /
      data fpp(22,17,17,1),fpp(22,17,17,2),fpp(22,17,17,3)/
     x 4.7210347d-04, 9.0183265d-07, 3.6375717d-08 /
      data fpp(22,17,18,1),fpp(22,17,18,2),fpp(22,17,18,3)/
     x 4.7875577d-04, 9.7319477d-07, 3.0682259d-08 /
      data fpp(22,17,19,1),fpp(22,17,19,2),fpp(22,17,19,3)/
     x 4.8732369d-04, 1.0214371d-06, 2.0895249d-08 /
      data fpp(22,17,20,1),fpp(22,17,20,2),fpp(22,17,20,3)/
     x 4.9522173d-04, 1.0469758d-06, 1.7736745d-08 /
      data fpp(22,17,21,1),fpp(22,17,21,2),fpp(22,17,21,3)/
     x 4.9522173d-04, 1.0469758d-06, 1.7342139d-08 /
      data fpp(22,17,22,1),fpp(22,17,22,2),fpp(22,17,22,3)/
     x 4.8732369d-04, 1.0214371d-06, 2.2473675d-08 /
      data fpp(22,17,23,1),fpp(22,17,23,2),fpp(22,17,23,3)/
     x 4.7875577d-04, 9.7319477d-07, 2.4763163d-08 /
      data fpp(22,18, 1,1),fpp(22,18, 1,2),fpp(22,18, 1,3)/
     x 1.6185493d-03, 7.3663070d-07,-1.2937388d-07 /
      data fpp(22,18, 2,1),fpp(22,18, 2,2),fpp(22,18, 2,3)/
     x 1.7330852d-03, 1.5894296d-06,-1.5325224d-07 /
      data fpp(22,18, 3,1),fpp(22,18, 3,2),fpp(22,18, 3,3)/
     x 1.8162146d-03, 2.2930248d-06,-2.0561717d-07 /
      data fpp(22,18, 4,1),fpp(22,18, 4,2),fpp(22,18, 4,3)/
     x 1.8162146d-03, 2.2930248d-06,-2.0352238d-07 /
      data fpp(22,18, 5,1),fpp(22,18, 5,2),fpp(22,18, 5,3)/
     x 1.7330852d-03, 1.5894296d-06,-1.6163141d-07 /
      data fpp(22,18, 6,1),fpp(22,18, 6,2),fpp(22,18, 6,3)/
     x 1.6185493d-03, 7.3663070d-07,-9.7951998d-08 /
      data fpp(22,18, 7,1),fpp(22,18, 7,2),fpp(22,18, 7,3)/
     x 1.4706445d-03,-1.8878533d-08,-4.6560600d-08 /
      data fpp(22,18, 8,1),fpp(22,18, 8,2),fpp(22,18, 8,3)/
     x 1.3151219d-03,-5.2416431d-07, 2.1943998d-09 /
      data fpp(22,18, 9,1),fpp(22,18, 9,2),fpp(22,18, 9,3)/
     x 1.1597391d-03,-7.4885571d-07, 3.7783001d-08 /
      data fpp(22,18,10,1),fpp(22,18,10,2),fpp(22,18,10,3)/
     x 1.0178862d-03,-7.3494995d-07, 5.6673596d-08 /
      data fpp(22,18,11,1),fpp(22,18,11,2),fpp(22,18,11,3)/
     x 8.9507260d-04,-5.5252440d-07, 6.5522616d-08 /
      data fpp(22,18,12,1),fpp(22,18,12,2),fpp(22,18,12,3)/
     x 7.9019439d-04,-2.7563284d-07, 6.5235941d-08 /
      data fpp(22,18,13,1),fpp(22,18,13,2),fpp(22,18,13,3)/
     x 7.0888007d-04, 3.8582232d-08, 6.3533618d-08 /
      data fpp(22,18,14,1),fpp(22,18,14,2),fpp(22,18,14,3)/
     x 6.4433613d-04, 3.5480187d-07, 5.8629585d-08 /
      data fpp(22,18,15,1),fpp(22,18,15,2),fpp(22,18,15,3)/
     x 5.9293047d-04, 6.4519214d-07, 4.9948042d-08 /
      data fpp(22,18,16,1),fpp(22,18,16,2),fpp(22,18,16,3)/
     x 5.5645318d-04, 9.0612727d-07, 4.7578246d-08 /
      data fpp(22,18,17,1),fpp(22,18,17,2),fpp(22,18,17,3)/
     x 5.2842510d-04, 1.1257621d-06, 4.1738972d-08 /
      data fpp(22,18,18,1),fpp(22,18,18,2),fpp(22,18,18,3)/
     x 5.1370866d-04, 1.2995158d-06, 3.7465864d-08 /
      data fpp(22,18,19,1),fpp(22,18,19,2),fpp(22,18,19,3)/
     x 5.0248778d-04, 1.4264465d-06, 3.6397570d-08 /
      data fpp(22,18,20,1),fpp(22,18,20,2),fpp(22,18,20,3)/
     x 4.9263529d-04, 1.5018641d-06, 3.2943855d-08 /
      data fpp(22,18,21,1),fpp(22,18,21,2),fpp(22,18,21,3)/
     x 4.9263529d-04, 1.5018641d-06, 3.2969651d-08 /
      data fpp(22,18,22,1),fpp(22,18,22,2),fpp(22,18,22,3)/
     x 5.0248778d-04, 1.4264465d-06, 3.6294385d-08 /
      data fpp(22,18,23,1),fpp(22,18,23,2),fpp(22,18,23,3)/
     x 5.1370866d-04, 1.2995158d-06, 3.7852807d-08 /
      data fpp(22,19, 1,1),fpp(22,19, 1,2),fpp(22,19, 1,3)/
     x 8.5039288d-04, 2.5521846d-06,-7.3116050d-22 /
      data fpp(22,19, 2,1),fpp(22,19, 2,2),fpp(22,19, 2,3)/
     x 8.5039288d-04, 2.9637852d-06,-1.9916946d-23 /
      data fpp(22,19, 3,1),fpp(22,19, 3,2),fpp(22,19, 3,3)/
     x 8.5039288d-04, 3.0044876d-06, 2.3295881d-22 /
      data fpp(22,19, 4,1),fpp(22,19, 4,2),fpp(22,19, 4,3)/
     x 8.5039288d-04, 3.0044876d-06,-3.9257662d-22 /
      data fpp(22,19, 5,1),fpp(22,19, 5,2),fpp(22,19, 5,3)/
     x 8.5039288d-04, 2.9637852d-06, 3.2595183d-23 /
      data fpp(22,19, 6,1),fpp(22,19, 6,2),fpp(22,19, 6,3)/
     x 8.5039288d-04, 2.5521846d-06, 6.6362543d-22 /
      data fpp(22,19, 7,1),fpp(22,19, 7,2),fpp(22,19, 7,3)/
     x 8.5039288d-04, 1.6909393d-06, 6.9912194d-22 /
      data fpp(22,19, 8,1),fpp(22,19, 8,2),fpp(22,19, 8,3)/
     x 8.5039288d-04, 6.4808216d-07, 6.9630570d-22 /
      data fpp(22,19, 9,1),fpp(22,19, 9,2),fpp(22,19, 9,3)/
     x 8.5039288d-04,-2.3357215d-07,-7.1273680d-23 /
      data fpp(22,19,10,1),fpp(22,19,10,2),fpp(22,19,10,3)/
     x 8.5039288d-04,-7.3752503d-07,-4.0281165d-22 /
      data fpp(22,19,11,1),fpp(22,19,11,2),fpp(22,19,11,3)/
     x 8.5039288d-04,-8.3023780d-07, 2.5535703d-22 /
      data fpp(22,19,12,1),fpp(22,19,12,2),fpp(22,19,12,3)/
     x 8.5039288d-04,-6.1218358d-07,-5.1992280d-22 /
      data fpp(22,19,13,1),fpp(22,19,13,2),fpp(22,19,13,3)/
     x 8.5039288d-04,-2.1729112d-07,-4.0214280d-22 /
      data fpp(22,19,14,1),fpp(22,19,14,2),fpp(22,19,14,3)/
     x 8.5039288d-04, 2.4709907d-07,-4.8113310d-22 /
      data fpp(22,19,15,1),fpp(22,19,15,2),fpp(22,19,15,3)/
     x 8.5039288d-04, 6.9440393d-07, 7.8322015d-23 /
      data fpp(22,19,16,1),fpp(22,19,16,2),fpp(22,19,16,3)/
     x 8.5039288d-04, 1.0964364d-06, 3.8356816d-22 /
      data fpp(22,19,17,1),fpp(22,19,17,2),fpp(22,19,17,3)/
     x 8.5039288d-04, 1.4231190d-06,-6.6158435d-22 /
      data fpp(22,19,18,1),fpp(22,19,18,2),fpp(22,19,18,3)/
     x 8.5039288d-04, 1.6707421d-06, 6.8198607d-22 /
      data fpp(22,19,19,1),fpp(22,19,19,2),fpp(22,19,19,3)/
     x 8.5039288d-04, 1.8527767d-06, 5.0144794d-22 /
      data fpp(22,19,20,1),fpp(22,19,20,2),fpp(22,19,20,3)/
     x 8.5039288d-04, 1.9635680d-06,-2.6439831d-22 /
      data fpp(22,19,21,1),fpp(22,19,21,2),fpp(22,19,21,3)/
     x 8.5039288d-04, 1.9635680d-06, 4.5119419d-22 /
      data fpp(22,19,22,1),fpp(22,19,22,2),fpp(22,19,22,3)/
     x 8.5039288d-04, 1.8527767d-06,-8.4744121d-22 /
      data fpp(22,19,23,1),fpp(22,19,23,2),fpp(22,19,23,3)/
     x 8.5039288d-04, 1.6707421d-06,-1.0440242d-21 /
      data fpp(23, 1, 1,1),fpp(23, 1, 1,2),fpp(23, 1, 1,3)/
     x 2.5897571d-02,-1.1259701d-05,-2.4917689d-20 /
      data fpp(23, 1, 2,1),fpp(23, 1, 2,2),fpp(23, 1, 2,3)/
     x 2.5897571d-02, 9.4575511d-06, 6.8197101d-21 /
      data fpp(23, 1, 3,1),fpp(23, 1, 3,2),fpp(23, 1, 3,3)/
     x 2.5897571d-02, 2.4058619d-05,-1.1075708d-20 /
      data fpp(23, 1, 4,1),fpp(23, 1, 4,2),fpp(23, 1, 4,3)/
     x 2.5897571d-02, 2.4058619d-05, 3.6975923d-20 /
      data fpp(23, 1, 5,1),fpp(23, 1, 5,2),fpp(23, 1, 5,3)/
     x 2.5897571d-02, 9.4575511d-06, 8.7181779d-21 /
      data fpp(23, 1, 6,1),fpp(23, 1, 6,2),fpp(23, 1, 6,3)/
     x 2.5897571d-02,-1.1259701d-05,-1.5620716d-21 /
      data fpp(23, 1, 7,1),fpp(23, 1, 7,2),fpp(23, 1, 7,3)/
     x 2.5897571d-02,-3.4017609d-05,-3.2545640d-20 /
      data fpp(23, 1, 8,1),fpp(23, 1, 8,2),fpp(23, 1, 8,3)/
     x 2.5897571d-02,-5.5222989d-05,-2.5807817d-20 /
      data fpp(23, 1, 9,1),fpp(23, 1, 9,2),fpp(23, 1, 9,3)/
     x 2.5897571d-02,-7.2594117d-05,-1.5665344d-21 /
      data fpp(23, 1,10,1),fpp(23, 1,10,2),fpp(23, 1,10,3)/
     x 2.5897571d-02,-8.5130550d-05, 3.0340798d-20 /
      data fpp(23, 1,11,1),fpp(23, 1,11,2),fpp(23, 1,11,3)/
     x 2.5897571d-02,-9.2722250d-05,-2.6487996d-20 /
      data fpp(23, 1,12,1),fpp(23, 1,12,2),fpp(23, 1,12,3)/
     x 2.5897571d-02,-9.5563110d-05, 3.5428432d-21 /
      data fpp(23, 1,13,1),fpp(23, 1,13,2),fpp(23, 1,13,3)/
     x 2.5897571d-02,-9.3716144d-05, 7.4934478d-21 /
      data fpp(23, 1,14,1),fpp(23, 1,14,2),fpp(23, 1,14,3)/
     x 2.5897571d-02,-8.6966996d-05, 1.1057091d-20 /
      data fpp(23, 1,15,1),fpp(23, 1,15,2),fpp(23, 1,15,3)/
     x 2.5897571d-02,-7.4964558d-05,-6.2852407d-21 /
      data fpp(23, 1,16,1),fpp(23, 1,16,2),fpp(23, 1,16,3)/
     x 2.5897571d-02,-5.7734039d-05,-3.8225367d-20 /
      data fpp(23, 1,17,1),fpp(23, 1,17,2),fpp(23, 1,17,3)/
     x 2.5897571d-02,-3.6247848d-05, 3.4486549d-20 /
      data fpp(23, 1,18,1),fpp(23, 1,18,2),fpp(23, 1,18,3)/
     x 2.5897571d-02,-1.2865305d-05,-1.4016834d-20 /
      data fpp(23, 1,19,1),fpp(23, 1,19,2),fpp(23, 1,19,3)/
     x 2.5897571d-02, 8.6330569d-06,-2.4787081d-20 /
      data fpp(23, 1,20,1),fpp(23, 1,20,2),fpp(23, 1,20,3)/
     x 2.5897571d-02, 2.3899262d-05, 2.5651512d-20 /
      data fpp(23, 1,21,1),fpp(23, 1,21,2),fpp(23, 1,21,3)/
     x 2.5897571d-02, 2.3899262d-05,-3.4474726d-20 /
      data fpp(23, 1,22,1),fpp(23, 1,22,2),fpp(23, 1,22,3)/
     x 2.5897571d-02, 8.6330569d-06, 3.1007194d-20 /
      data fpp(23, 1,23,1),fpp(23, 1,23,2),fpp(23, 1,23,3)/
     x 2.5897571d-02,-1.2865305d-05, 1.2008126d-19 /
      data fpp(23, 2, 1,1),fpp(23, 2, 1,2),fpp(23, 2, 1,3)/
     x 1.9385886d-02,-1.0860598d-05,-1.9617353d-06 /
      data fpp(23, 2, 2,1),fpp(23, 2, 2,2),fpp(23, 2, 2,3)/
     x 2.2760879d-02,-4.0201021d-06,-2.4140294d-06 /
      data fpp(23, 2, 3,1),fpp(23, 2, 3,2),fpp(23, 2, 3,3)/
     x 2.8026849d-02, 9.3176126d-07,-3.4001469d-06 /
      data fpp(23, 2, 4,1),fpp(23, 2, 4,2),fpp(23, 2, 4,3)/
     x 2.8026849d-02, 9.3176126d-07,-3.3705445d-06 /
      data fpp(23, 2, 5,1),fpp(23, 2, 5,2),fpp(23, 2, 5,3)/
     x 2.2760879d-02,-4.0201021d-06,-2.5324392d-06 /
      data fpp(23, 2, 6,1),fpp(23, 2, 6,2),fpp(23, 2, 6,3)/
     x 1.9385886d-02,-1.0860598d-05,-1.5176989d-06 /
      data fpp(23, 2, 7,1),fpp(23, 2, 7,2),fpp(23, 2, 7,3)/
     x 1.6715596d-02,-1.8112782d-05,-3.4276533d-07 /
      data fpp(23, 2, 8,1),fpp(23, 2, 8,2),fpp(23, 2, 8,3)/
     x 1.4461281d-02,-2.4572023d-05, 7.8876021d-07 /
      data fpp(23, 2, 9,1),fpp(23, 2, 9,2),fpp(23, 2, 9,3)/
     x 1.2759313d-02,-2.9599766d-05, 1.7417245d-06 /
      data fpp(23, 2,10,1),fpp(23, 2,10,2),fpp(23, 2,10,3)/
     x 1.1292500d-02,-3.3054901d-05, 2.4623418d-06 /
      data fpp(23, 2,11,1),fpp(23, 2,11,2),fpp(23, 2,11,3)/
     x 1.0438598d-02,-3.5098500d-05, 2.8989084d-06 /
      data fpp(23, 2,12,1),fpp(23, 2,12,2),fpp(23, 2,12,3)/
     x 9.9845191d-03,-3.5939781d-05, 3.0600247d-06 /
      data fpp(23, 2,13,1),fpp(23, 2,13,2),fpp(23, 2,13,3)/
     x 1.0222145d-02,-3.5646711d-05, 2.9329927d-06 /
      data fpp(23, 2,14,1),fpp(23, 2,14,2),fpp(23, 2,14,3)/
     x 1.1282343d-02,-3.4074008d-05, 2.5120044d-06 /
      data fpp(23, 2,15,1),fpp(23, 2,15,2),fpp(23, 2,15,3)/
     x 1.2754965d-02,-3.0929884d-05, 1.8089898d-06 /
      data fpp(23, 2,16,1),fpp(23, 2,16,2),fpp(23, 2,16,3)/
     x 1.4463537d-02,-2.6001922d-05, 8.4803652d-07 /
      data fpp(23, 2,17,1),fpp(23, 2,17,2),fpp(23, 2,17,3)/
     x 1.6709056d-02,-1.9410304d-05,-3.0513585d-07 /
      data fpp(23, 2,18,1),fpp(23, 2,18,2),fpp(23, 2,18,3)/
     x 1.9310091d-02,-1.1829391d-05,-1.5174931d-06 /
      data fpp(23, 2,19,1),fpp(23, 2,19,2),fpp(23, 2,19,3)/
     x 2.3680850d-02,-4.5651138d-06,-2.5768917d-06 /
      data fpp(23, 2,20,1),fpp(23, 2,20,2),fpp(23, 2,20,3)/
     x 2.7943620d-02, 7.5147596d-07,-3.4569403d-06 /
      data fpp(23, 2,21,1),fpp(23, 2,21,2),fpp(23, 2,21,3)/
     x 2.7943620d-02, 7.5147596d-07,-3.4877334d-06 /
      data fpp(23, 2,22,1),fpp(23, 2,22,2),fpp(23, 2,22,3)/
     x 2.3680850d-02,-4.5651138d-06,-2.4537190d-06 /
      data fpp(23, 2,23,1),fpp(23, 2,23,2),fpp(23, 2,23,3)/
     x 1.9310091d-02,-1.1829391d-05,-1.9793905d-06 /
      data fpp(23, 3, 1,1),fpp(23, 3, 1,2),fpp(23, 3, 1,3)/
     x 1.4245601d-02,-1.7681907d-05,-4.5136812d-06 /
      data fpp(23, 3, 2,1),fpp(23, 3, 2,2),fpp(23, 3, 2,3)/
     x 1.9624582d-02,-3.0139143d-05,-6.2191376d-06 /
      data fpp(23, 3, 3,1),fpp(23, 3, 3,2),fpp(23, 3, 3,3)/
     x 2.7128534d-02,-3.8207664d-05,-9.9277683d-06 /
      data fpp(23, 3, 4,1),fpp(23, 3, 4,2),fpp(23, 3, 4,3)/
     x 2.7128534d-02,-3.8207664d-05,-9.8331262d-06 /
      data fpp(23, 3, 5,1),fpp(23, 3, 5,2),fpp(23, 3, 5,3)/
     x 1.9624582d-02,-3.0139143d-05,-6.5977060d-06 /
      data fpp(23, 3, 6,1),fpp(23, 3, 6,2),fpp(23, 3, 6,3)/
     x 1.4245601d-02,-1.7681907d-05,-3.0940499d-06 /
      data fpp(23, 3, 7,1),fpp(23, 3, 7,2),fpp(23, 3, 7,3)/
     x 9.3708671d-03,-2.2512636d-06, 3.6790565d-07 /
      data fpp(23, 3, 8,1),fpp(23, 3, 8,2),fpp(23, 3, 8,3)/
     x 4.7020004d-03, 1.4059079d-05, 3.0264273d-06 /
      data fpp(23, 3, 9,1),fpp(23, 3, 9,2),fpp(23, 3, 9,3)/
     x 9.2263792d-04, 2.9017179d-05, 4.8423851d-06 /
      data fpp(23, 3,10,1),fpp(23, 3,10,2),fpp(23, 3,10,3)/
     x-1.8325617d-03, 4.0758152d-05, 5.9480322d-06 /
      data fpp(23, 3,11,1),fpp(23, 3,11,2),fpp(23, 3,11,3)/
     x-3.5043743d-03, 4.8106250d-05, 6.5434862d-06 /
      data fpp(23, 3,12,1),fpp(23, 3,12,2),fpp(23, 3,12,3)/
     x-4.0920019d-03, 5.0562232d-05, 6.7820232d-06 /
      data fpp(23, 3,13,1),fpp(23, 3,13,2),fpp(23, 3,13,3)/
     x-3.6054111d-03, 4.8004990d-05, 6.6844212d-06 /
      data fpp(23, 3,14,1),fpp(23, 3,14,2),fpp(23, 3,14,3)/
     x-2.0270285d-03, 4.0551029d-05, 6.2122922d-06 /
      data fpp(23, 3,15,1),fpp(23, 3,15,2),fpp(23, 3,15,3)/
     x 6.6035797d-04, 2.8698095d-05, 5.1864102d-06 /
      data fpp(23, 3,16,1),fpp(23, 3,16,2),fpp(23, 3,16,3)/
     x 4.4142243d-03, 1.3637726d-05, 3.3900670d-06 /
      data fpp(23, 3,17,1),fpp(23, 3,17,2),fpp(23, 3,17,3)/
     x 9.1235768d-03,-2.7149348d-06, 6.6332164d-07 /
      data fpp(23, 3,18,1),fpp(23, 3,18,2),fpp(23, 3,18,3)/
     x 1.4088664d-02,-1.8069132d-05,-2.9713536d-06 /
      data fpp(23, 3,19,1),fpp(23, 3,19,2),fpp(23, 3,19,3)/
     x 1.9715747d-02,-3.0314602d-05,-6.7239072d-06 /
      data fpp(23, 3,20,1),fpp(23, 3,20,2),fpp(23, 3,20,3)/
     x 2.6542480d-02,-3.8137166d-05,-1.0297018d-05 /
      data fpp(23, 3,21,1),fpp(23, 3,21,2),fpp(23, 3,21,3)/
     x 2.6542480d-02,-3.8137166d-05,-1.0395994d-05 /
      data fpp(23, 3,22,1),fpp(23, 3,22,2),fpp(23, 3,22,3)/
     x 1.9715747d-02,-3.0314602d-05,-6.3280018d-06 /
      data fpp(23, 3,23,1),fpp(23, 3,23,2),fpp(23, 3,23,3)/
     x 1.4088664d-02,-1.8069132d-05,-4.4559991d-06 /
      data fpp(23, 4, 1,1),fpp(23, 4, 1,2),fpp(23, 4, 1,3)/
     x 9.1516111d-03, 7.6822782d-07,-4.4788662d-06 /
      data fpp(23, 4, 2,1),fpp(23, 4, 2,2),fpp(23, 4, 2,3)/
     x 1.4533779d-02,-1.2013327d-05,-6.9312676d-06 /
      data fpp(23, 4, 3,1),fpp(23, 4, 3,2),fpp(23, 4, 3,3)/
     x 1.8431804d-02,-2.1303104d-05,-1.2256063d-05 /
      data fpp(23, 4, 4,1),fpp(23, 4, 4,2),fpp(23, 4, 4,3)/
     x 1.8431804d-02,-2.1303104d-05,-1.2134176d-05 /
      data fpp(23, 4, 5,1),fpp(23, 4, 5,2),fpp(23, 4, 5,3)/
     x 1.4533779d-02,-1.2013327d-05,-7.4188177d-06 /
      data fpp(23, 4, 6,1),fpp(23, 4, 6,2),fpp(23, 4, 6,3)/
     x 9.1516111d-03, 7.6822782d-07,-2.6505531d-06 /
      data fpp(23, 4, 7,1),fpp(23, 4, 7,2),fpp(23, 4, 7,3)/
     x 3.6721436d-03, 1.3761836d-05, 1.4490303d-06 /
      data fpp(23, 4, 8,1),fpp(23, 4, 8,2),fpp(23, 4, 8,3)/
     x-1.0606540d-03, 2.4759706d-05, 4.0784319d-06 /
      data fpp(23, 4, 9,1),fpp(23, 4, 9,2),fpp(23, 4, 9,3)/
     x-4.7975833d-03, 3.2955048d-05, 5.5352422d-06 /
      data fpp(23, 4,10,1),fpp(23, 4,10,2),fpp(23, 4,10,3)/
     x-7.4136415d-03, 3.8490291d-05, 6.2945995d-06 /
      data fpp(23, 4,11,1),fpp(23, 4,11,2),fpp(23, 4,11,3)/
     x-8.9540741d-03, 4.1777498d-05, 6.7443598d-06 /
      data fpp(23, 4,12,1),fpp(23, 4,12,2),fpp(23, 4,12,3)/
     x-9.5194531d-03, 4.2988852d-05, 6.9759612d-06 /
      data fpp(23, 4,13,1),fpp(23, 4,13,2),fpp(23, 4,13,3)/
     x-9.1521064d-03, 4.2118752d-05, 6.9917953d-06 /
      data fpp(23, 4,14,1),fpp(23, 4,14,2),fpp(23, 4,14,3)/
     x-7.7968934d-03, 3.9113892d-05, 6.7748574d-06 /
      data fpp(23, 4,15,1),fpp(23, 4,15,2),fpp(23, 4,15,3)/
     x-5.3349065d-03, 3.3749503d-05, 6.1747749d-06 /
      data fpp(23, 4,16,1),fpp(23, 4,16,2),fpp(23, 4,16,3)/
     x-1.6923712d-03, 2.5601018d-05, 4.7960428d-06 /
      data fpp(23, 4,17,1),fpp(23, 4,17,2),fpp(23, 4,17,3)/
     x 3.0592788d-03, 1.4478044d-05, 2.0850537d-06 /
      data fpp(23, 4,18,1),fpp(23, 4,18,2),fpp(23, 4,18,3)/
     x 8.6593840d-03, 1.1559195d-06,-2.3182578d-06 /
      data fpp(23, 4,19,1),fpp(23, 4,19,2),fpp(23, 4,19,3)/
     x 1.4297040d-02,-1.2134479d-05,-7.6020227d-06 /
      data fpp(23, 4,20,1),fpp(23, 4,20,2),fpp(23, 4,20,3)/
     x 1.8365972d-02,-2.1932813d-05,-1.3083651d-05 /
      data fpp(23, 4,21,1),fpp(23, 4,21,2),fpp(23, 4,21,3)/
     x 1.8365972d-02,-2.1932813d-05,-1.3213035d-05 /
      data fpp(23, 4,22,1),fpp(23, 4,22,2),fpp(23, 4,22,3)/
     x 1.4297040d-02,-1.2134479d-05,-7.0844901d-06 /
      data fpp(23, 4,23,1),fpp(23, 4,23,2),fpp(23, 4,23,3)/
     x 8.6593840d-03, 1.1559195d-06,-4.2590049d-06 /
      data fpp(23, 5, 1,1),fpp(23, 5, 1,2),fpp(23, 5, 1,3)/
     x 4.8776126d-03, 1.4560996d-05,-2.9368019d-06 /
      data fpp(23, 5, 2,1),fpp(23, 5, 2,2),fpp(23, 5, 2,3)/
     x 8.6338270d-03, 1.3764452d-05,-4.8878963d-06 /
      data fpp(23, 5, 3,1),fpp(23, 5, 3,2),fpp(23, 5, 3,3)/
     x 1.1504225d-02, 1.2612079d-05,-9.1136131d-06 /
      data fpp(23, 5, 4,1),fpp(23, 5, 4,2),fpp(23, 5, 4,3)/
     x 1.1504225d-02, 1.2612079d-05,-9.0352126d-06 /
      data fpp(23, 5, 5,1),fpp(23, 5, 5,2),fpp(23, 5, 5,3)/
     x 8.6338270d-03, 1.3764452d-05,-5.2014985d-06 /
      data fpp(23, 5, 6,1),fpp(23, 5, 6,2),fpp(23, 5, 6,3)/
     x 4.8776126d-03, 1.4560996d-05,-1.7607936d-06 /
      data fpp(23, 5, 7,1),fpp(23, 5, 7,2),fpp(23, 5, 7,3)/
     x 1.0285717d-03, 1.4961919d-05, 1.1326729d-06 /
      data fpp(23, 5, 8,1),fpp(23, 5, 8,2),fpp(23, 5, 8,3)/
     x-2.3741718d-03, 1.5092095d-05, 2.9001019d-06 /
      data fpp(23, 5, 9,1),fpp(23, 5, 9,2),fpp(23, 5, 9,3)/
     x-5.0847738d-03, 1.5106630d-05, 3.8689195d-06 /
      data fpp(23, 5,10,1),fpp(23, 5,10,2),fpp(23, 5,10,3)/
     x-7.0695473d-03, 1.5094682d-05, 4.4242200d-06 /
      data fpp(23, 5,11,1),fpp(23, 5,11,2),fpp(23, 5,11,3)/
     x-8.3417712d-03, 1.5063757d-05, 4.7682003d-06 /
      data fpp(23, 5,12,1),fpp(23, 5,12,2),fpp(23, 5,12,3)/
     x-8.8727191d-03, 1.5106358d-05, 4.9729786d-06 /
      data fpp(23, 5,13,1),fpp(23, 5,13,2),fpp(23, 5,13,3)/
     x-8.6260347d-03, 1.5306002d-05, 5.0818851d-06 /
      data fpp(23, 5,14,1),fpp(23, 5,14,2),fpp(23, 5,14,3)/
     x-7.6106968d-03, 1.5567402d-05, 5.0294809d-06 /
      data fpp(23, 5,15,1),fpp(23, 5,15,2),fpp(23, 5,15,3)/
     x-5.8253551d-03, 1.5757891d-05, 4.7041913d-06 /
      data fpp(23, 5,16,1),fpp(23, 5,16,2),fpp(23, 5,16,3)/
     x-3.2249571d-03, 1.5778204d-05, 3.8317539d-06 /
      data fpp(23, 5,17,1),fpp(23, 5,17,2),fpp(23, 5,17,3)/
     x 1.9773323d-04, 1.5500760d-05, 1.9587931d-06 /
      data fpp(23, 5,18,1),fpp(23, 5,18,2),fpp(23, 5,18,3)/
     x 4.2153175d-03, 1.4777454d-05,-1.3469264d-06 /
      data fpp(23, 5,19,1),fpp(23, 5,19,2),fpp(23, 5,19,3)/
     x 8.2671701d-03, 1.3572517d-05,-5.4510874d-06 /
      data fpp(23, 5,20,1),fpp(23, 5,20,2),fpp(23, 5,20,3)/
     x 1.1477272d-02, 1.2078416d-05,-1.0202724d-05 /
      data fpp(23, 5,21,1),fpp(23, 5,21,2),fpp(23, 5,21,3)/
     x 1.1477272d-02, 1.2078416d-05,-1.0292284d-05 /
      data fpp(23, 5,22,1),fpp(23, 5,22,2),fpp(23, 5,22,3)/
     x 8.2671701d-03, 1.3572517d-05,-5.0928474d-06 /
      data fpp(23, 5,23,1),fpp(23, 5,23,2),fpp(23, 5,23,3)/
     x 4.2153175d-03, 1.4777454d-05,-2.6903263d-06 /
      data fpp(23, 6, 1,1),fpp(23, 6, 1,2),fpp(23, 6, 1,3)/
     x 2.1546560d-03, 1.1349787d-05,-1.8704681d-06 /
      data fpp(23, 6, 2,1),fpp(23, 6, 2,2),fpp(23, 6, 2,3)/
     x 4.0658489d-03, 1.5119518d-05,-2.7380639d-06 /
      data fpp(23, 6, 3,1),fpp(23, 6, 3,2),fpp(23, 6, 3,3)/
     x 5.4688969d-03, 1.8116788d-05,-4.6252765d-06 /
      data fpp(23, 6, 4,1),fpp(23, 6, 4,2),fpp(23, 6, 4,3)/
     x 5.4688969d-03, 1.8116788d-05,-4.5761386d-06 /
      data fpp(23, 6, 5,1),fpp(23, 6, 5,2),fpp(23, 6, 5,3)/
     x 4.0658489d-03, 1.5119518d-05,-2.9346152d-06 /
      data fpp(23, 6, 6,1),fpp(23, 6, 6,2),fpp(23, 6, 6,3)/
     x 2.1546560d-03, 1.1349787d-05,-1.1334006d-06 /
      data fpp(23, 6, 7,1),fpp(23, 6, 7,2),fpp(23, 6, 7,3)/
     x 1.1031965d-04, 7.4624896d-06, 3.2821776d-07 /
      data fpp(23, 6, 8,1),fpp(23, 6, 8,2),fpp(23, 6, 8,3)/
     x-1.7990922d-03, 4.0019129d-06, 1.2845296d-06 /
      data fpp(23, 6, 9,1),fpp(23, 6, 9,2),fpp(23, 6, 9,3)/
     x-3.4396279d-03, 1.2444322d-06, 1.8776638d-06 /
      data fpp(23, 6,10,1),fpp(23, 6,10,2),fpp(23, 6,10,3)/
     x-4.7275389d-03,-7.3902116d-07, 2.2988153d-06 /
      data fpp(23, 6,11,1),fpp(23, 6,11,2),fpp(23, 6,11,3)/
     x-5.5980692d-03,-1.8925249d-06, 2.6430749d-06 /
      data fpp(23, 6,12,1),fpp(23, 6,12,2),fpp(23, 6,12,3)/
     x-6.0096353d-03,-2.1882850d-06, 2.8968850d-06 /
      data fpp(23, 6,13,1),fpp(23, 6,13,2),fpp(23, 6,13,3)/
     x-5.9380023d-03,-1.6427597d-06, 3.0013852d-06 /
      data fpp(23, 6,14,1),fpp(23, 6,14,2),fpp(23, 6,14,3)/
     x-5.3653449d-03,-2.7750170d-07, 2.9715742d-06 /
      data fpp(23, 6,15,1),fpp(23, 6,15,2),fpp(23, 6,15,3)/
     x-4.2886555d-03, 1.8469317d-06, 2.7703180d-06 /
      data fpp(23, 6,16,1),fpp(23, 6,16,2),fpp(23, 6,16,3)/
     x-2.7336811d-03, 4.6581675d-06, 2.2551537d-06 /
      data fpp(23, 6,17,1),fpp(23, 6,17,2),fpp(23, 6,17,3)/
     x-7.5995230d-04, 8.0529164d-06, 1.1630671d-06 /
      data fpp(23, 6,18,1),fpp(23, 6,18,2),fpp(23, 6,18,3)/
     x 1.4879717d-03, 1.1770264d-05,-7.4542227d-07 /
      data fpp(23, 6,19,1),fpp(23, 6,19,2),fpp(23, 6,19,3)/
     x 3.7016034d-03, 1.5318409d-05,-3.2153781d-06 /
      data fpp(23, 6,20,1),fpp(23, 6,20,2),fpp(23, 6,20,3)/
     x 5.3879464d-03, 1.8115148d-05,-5.7070655d-06 /
      data fpp(23, 6,21,1),fpp(23, 6,21,2),fpp(23, 6,21,3)/
     x 5.3879464d-03, 1.8115148d-05,-5.7691146d-06 /
      data fpp(23, 6,22,1),fpp(23, 6,22,2),fpp(23, 6,22,3)/
     x 3.7016034d-03, 1.5318409d-05,-2.9671815d-06 /
      data fpp(23, 6,23,1),fpp(23, 6,23,2),fpp(23, 6,23,3)/
     x 1.4879717d-03, 1.1770264d-05,-1.6761592d-06 /
      data fpp(23, 7, 1,1),fpp(23, 7, 1,2),fpp(23, 7, 1,3)/
     x 9.8085249d-04, 5.3558545d-06,-1.0087440d-06 /
      data fpp(23, 7, 2,1),fpp(23, 7, 2,2),fpp(23, 7, 2,3)/
     x 1.7495131d-03, 8.5814774d-06,-1.2265120d-06 /
      data fpp(23, 7, 3,1),fpp(23, 7, 3,2),fpp(23, 7, 3,3)/
     x 2.2648559d-03, 1.0926771d-05,-1.7052080d-06 /
      data fpp(23, 7, 4,1),fpp(23, 7, 4,2),fpp(23, 7, 4,3)/
     x 2.2648559d-03, 1.0926771d-05,-1.6841199d-06 /
      data fpp(23, 7, 5,1),fpp(23, 7, 5,2),fpp(23, 7, 5,3)/
     x 1.7495131d-03, 8.5814774d-06,-1.3108643d-06 /
      data fpp(23, 7, 6,1),fpp(23, 7, 6,2),fpp(23, 7, 6,3)/
     x 9.8085249d-04, 5.3558545d-06,-6.9242274d-07 /
      data fpp(23, 7, 7,1),fpp(23, 7, 7,2),fpp(23, 7, 7,3)/
     x 6.5092443d-05, 1.9401232d-06,-1.4344471d-07 /
      data fpp(23, 7, 8,1),fpp(23, 7, 8,2),fpp(23, 7, 8,3)/
     x-8.8478103d-04,-1.1837468d-06, 2.5220156d-07 /
      data fpp(23, 7, 9,1),fpp(23, 7, 9,2),fpp(23, 7, 9,3)/
     x-1.7677846d-03,-3.6803590d-06, 5.4463846d-07 /
      data fpp(23, 7,10,1),fpp(23, 7,10,2),fpp(23, 7,10,3)/
     x-2.5036245d-03,-5.3405978d-06, 8.6324460d-07 /
      data fpp(23, 7,11,1),fpp(23, 7,11,2),fpp(23, 7,11,3)/
     x-3.0420581d-03,-6.1856572d-06, 1.2163831d-06 /
      data fpp(23, 7,12,1),fpp(23, 7,12,2),fpp(23, 7,12,3)/
     x-3.3497895d-03,-6.3712183d-06, 1.5012229d-06 /
      data fpp(23, 7,13,1),fpp(23, 7,13,2),fpp(23, 7,13,3)/
     x-3.4003257d-03,-5.9929631d-06, 1.5867253d-06 /
      data fpp(23, 7,14,1),fpp(23, 7,14,2),fpp(23, 7,14,3)/
     x-3.1637651d-03,-4.9893956d-06, 1.5358759d-06 /
      data fpp(23, 7,15,1),fpp(23, 7,15,2),fpp(23, 7,15,3)/
     x-2.6352220d-03,-3.2316179d-06, 1.4017712d-06 /
      data fpp(23, 7,16,1),fpp(23, 7,16,2),fpp(23, 7,16,3)/
     x-1.8256398d-03,-7.0887385d-07, 1.1370392d-06 /
      data fpp(23, 7,17,1),fpp(23, 7,17,2),fpp(23, 7,17,3)/
     x-7.9879216d-04, 2.3875745d-06, 5.7807191d-07 /
      data fpp(23, 7,18,1),fpp(23, 7,18,2),fpp(23, 7,18,3)/
     x 3.2534742d-04, 5.6894892d-06,-3.9532686d-07 /
      data fpp(23, 7,19,1),fpp(23, 7,19,2),fpp(23, 7,19,3)/
     x 1.3702923d-03, 8.7278468d-06,-1.6067645d-06 /
      data fpp(23, 7,20,1),fpp(23, 7,20,2),fpp(23, 7,20,3)/
     x 2.1295704d-03, 1.0896991d-05,-2.6156152d-06 /
      data fpp(23, 7,21,1),fpp(23, 7,21,2),fpp(23, 7,21,3)/
     x 2.1295704d-03, 1.0896991d-05,-2.6507722d-06 /
      data fpp(23, 7,22,1),fpp(23, 7,22,2),fpp(23, 7,22,3)/
     x 1.3702923d-03, 8.7278468d-06,-1.4661365d-06 /
      data fpp(23, 7,23,1),fpp(23, 7,23,2),fpp(23, 7,23,3)/
     x 3.2534742d-04, 5.6894892d-06,-9.2268174d-07 /
      data fpp(23, 8, 1,1),fpp(23, 8, 1,2),fpp(23, 8, 1,3)/
     x 6.5035168d-04, 1.2287949d-06,-4.1133684d-07 /
      data fpp(23, 8, 2,1),fpp(23, 8, 2,2),fpp(23, 8, 2,3)/
     x 9.3000986d-04, 3.2525729d-06,-4.2082633d-07 /
      data fpp(23, 8, 3,1),fpp(23, 8, 3,2),fpp(23, 8, 3,3)/
     x 1.0673597d-03, 4.8241302d-06,-4.4335785d-07 /
      data fpp(23, 8, 4,1),fpp(23, 8, 4,2),fpp(23, 8, 4,3)/
     x 1.0673597d-03, 4.8241302d-06,-4.3951329d-07 /
      data fpp(23, 8, 5,1),fpp(23, 8, 5,2),fpp(23, 8, 5,3)/
     x 9.3000986d-04, 3.2525729d-06,-4.3620457d-07 /
      data fpp(23, 8, 6,1),fpp(23, 8, 6,2),fpp(23, 8, 6,3)/
     x 6.5035168d-04, 1.2287949d-06,-3.5366842d-07 /
      data fpp(23, 8, 7,1),fpp(23, 8, 7,2),fpp(23, 8, 7,3)/
     x 2.8975274d-04,-7.2698223d-07,-2.6712176d-07 /
      data fpp(23, 8, 8,1),fpp(23, 8, 8,2),fpp(23, 8, 8,3)/
     x-1.3071728d-04,-2.3689259d-06,-1.6184455d-07 /
      data fpp(23, 8, 9,1),fpp(23, 8, 9,2),fpp(23, 8, 9,3)/
     x-5.7554871d-04,-3.6289962d-06,-1.5500028d-08 /
      data fpp(23, 8,10,1),fpp(23, 8,10,2),fpp(23, 8,10,3)/
     x-9.9968533d-04,-4.5385876d-06, 1.8784467d-07 /
      data fpp(23, 8,11,1),fpp(23, 8,11,2),fpp(23, 8,11,3)/
     x-1.3566014d-03,-5.0808462d-06, 4.3412136d-07 /
      data fpp(23, 8,12,1),fpp(23, 8,12,2),fpp(23, 8,12,3)/
     x-1.5958220d-03,-5.2188420d-06, 6.6766989d-07 /
      data fpp(23, 8,13,1),fpp(23, 8,13,2),fpp(23, 8,13,3)/
     x-1.6918342d-03,-4.9493878d-06, 7.8319907d-07 /
      data fpp(23, 8,14,1),fpp(23, 8,14,2),fpp(23, 8,14,3)/
     x-1.6252354d-03,-4.2929159d-06, 8.0153381d-07 /
      data fpp(23, 8,15,1),fpp(23, 8,15,2),fpp(23, 8,15,3)/
     x-1.4000721d-03,-3.2904600d-06, 7.3866568d-07 /
      data fpp(23, 8,16,1),fpp(23, 8,16,2),fpp(23, 8,16,3)/
     x-1.0278146d-03,-1.9546721d-06, 5.7580347d-07 /
      data fpp(23, 8,17,1),fpp(23, 8,17,2),fpp(23, 8,17,3)/
     x-5.4668573d-04,-3.1721455d-07, 2.4012043d-07 /
      data fpp(23, 8,18,1),fpp(23, 8,18,2),fpp(23, 8,18,3)/
     x-1.5581714d-05, 1.5197790d-06,-2.4628520d-07 /
      data fpp(23, 8,19,1),fpp(23, 8,19,2),fpp(23, 8,19,3)/
     x 4.8168233d-04, 3.2662040d-06,-7.5497963d-07 /
      data fpp(23, 8,20,1),fpp(23, 8,20,2),fpp(23, 8,20,3)/
     x 8.3886647d-04, 4.5188868d-06,-1.0177963d-06 /
      data fpp(23, 8,21,1),fpp(23, 8,21,2),fpp(23, 8,21,3)/
     x 8.3886647d-04, 4.5188868d-06,-1.0361213d-06 /
      data fpp(23, 8,22,1),fpp(23, 8,22,2),fpp(23, 8,22,3)/
     x 4.8168233d-04, 3.2662040d-06,-6.8167963d-07 /
      data fpp(23, 8,23,1),fpp(23, 8,23,2),fpp(23, 8,23,3)/
     x-1.5581714d-05, 1.5197790d-06,-5.2116019d-07 /
      data fpp(23, 9, 1,1),fpp(23, 9, 1,2),fpp(23, 9, 1,3)/
     x 6.6762093d-04,-4.4303389d-07, 1.5676296d-07 /
      data fpp(23, 9, 2,1),fpp(23, 9, 2,2),fpp(23, 9, 2,3)/
     x 8.3381292d-04, 6.3823111d-07,-3.0259251d-09 /
      data fpp(23, 9, 3,1),fpp(23, 9, 3,2),fpp(23, 9, 3,3)/
     x 9.5111064d-04, 1.6667086d-06,-3.4265926d-07 /
      data fpp(23, 9, 4,1),fpp(23, 9, 4,2),fpp(23, 9, 4,3)/
     x 9.5111064d-04, 1.6667086d-06,-3.4750925d-07 /
      data fpp(23, 9, 5,1),fpp(23, 9, 5,2),fpp(23, 9, 5,3)/
     x 8.3381292d-04, 6.3823111d-07, 1.6374033d-08 /
      data fpp(23, 9, 6,1),fpp(23, 9, 6,2),fpp(23, 9, 6,3)/
     x 6.6762093d-04,-4.4303389d-07, 8.4013121d-08 /
      data fpp(23, 9, 7,1),fpp(23, 9, 7,2),fpp(23, 9, 7,3)/
     x 5.0288469d-04,-1.3061942d-06,-6.4426517d-08 /
      data fpp(23, 9, 8,1),fpp(23, 9, 8,2),fpp(23, 9, 8,3)/
     x 3.1998575d-04,-1.9225498d-06,-1.8630705d-07 /
      data fpp(23, 9, 9,1),fpp(23, 9, 9,2),fpp(23, 9, 9,3)/
     x 9.1372531d-05,-2.4196563d-06,-1.8634527d-07 /
      data fpp(23, 9,10,1),fpp(23, 9,10,2),fpp(23, 9,10,3)/
     x-1.5812011d-04,-2.8030519d-06,-8.2311871d-08 /
      data fpp(23, 9,11,1),fpp(23, 9,11,2),fpp(23, 9,11,3)/
     x-3.9670294d-04,-3.0469581d-06, 6.5592753d-08 /
      data fpp(23, 9,12,1),fpp(23, 9,12,2),fpp(23, 9,12,3)/
     x-5.8184966d-04,-3.1074137d-06, 2.3394086d-07 /
      data fpp(23, 9,13,1),fpp(23, 9,13,2),fpp(23, 9,13,3)/
     x-6.9038254d-04,-2.9554858d-06, 3.7264380d-07 /
      data fpp(23, 9,14,1),fpp(23, 9,14,2),fpp(23, 9,14,3)/
     x-7.0891373d-04,-2.6249409d-06, 4.4748392d-07 /
      data fpp(23, 9,15,1),fpp(23, 9,15,2),fpp(23, 9,15,3)/
     x-6.3091630d-04,-2.1405421d-06, 4.5342051d-07 /
      data fpp(23, 9,16,1),fpp(23, 9,16,2),fpp(23, 9,16,3)/
     x-4.6989003d-04,-1.5344376d-06, 3.4283406d-07 /
      data fpp(23, 9,17,1),fpp(23, 9,17,2),fpp(23, 9,17,3)/
     x-2.3981153d-04,-8.1271633d-07, 1.0724327d-07 /
      data fpp(23, 9,18,1),fpp(23, 9,18,2),fpp(23, 9,18,3)/
     x 2.5297571d-05,-3.8605313d-08,-1.8980714d-07 /
      data fpp(23, 9,19,1),fpp(23, 9,19,2),fpp(23, 9,19,3)/
     x 2.8178975d-04, 6.7733735d-07,-4.2201471d-07 /
      data fpp(23, 9,20,1),fpp(23, 9,20,2),fpp(23, 9,20,3)/
     x 4.6880074d-04, 1.1774616d-06,-3.1213402d-07 /
      data fpp(23, 9,21,1),fpp(23, 9,21,2),fpp(23, 9,21,3)/
     x 4.6880074d-04, 1.1774616d-06,-3.2559059d-07 /
      data fpp(23, 9,22,1),fpp(23, 9,22,2),fpp(23, 9,22,3)/
     x 2.8178975d-04, 6.7733735d-07,-3.6818840d-07 /
      data fpp(23, 9,23,1),fpp(23, 9,23,2),fpp(23, 9,23,3)/
     x 2.5297571d-05,-3.8605313d-08,-3.9165580d-07 /
      data fpp(23,10, 1,1),fpp(23,10, 1,2),fpp(23,10, 1,3)/
     x 7.3462620d-04,-6.8665930d-07, 1.0485323d-06 /
      data fpp(23,10, 2,1),fpp(23,10, 2,2),fpp(23,10, 2,3)/
     x 1.0984154d-03, 8.5027007d-09, 3.8043538d-07 /
      data fpp(23,10, 3,1),fpp(23,10, 3,2),fpp(23,10, 3,3)/
     x 1.5641429d-03, 7.5503534d-07,-1.0402738d-06 /
      data fpp(23,10, 4,1),fpp(23,10, 4,2),fpp(23,10, 4,3)/
     x 1.5641429d-03, 7.5503534d-07,-1.0593962d-06 /
      data fpp(23,10, 5,1),fpp(23,10, 5,2),fpp(23,10, 5,3)/
     x 1.0984154d-03, 8.5027007d-09, 4.5692512d-07 /
      data fpp(23,10, 6,1),fpp(23,10, 6,2),fpp(23,10, 6,3)/
     x 7.3462620d-04,-6.8665930d-07, 7.6169578d-07 /
      data fpp(23,10, 7,1),fpp(23,10, 7,2),fpp(23,10, 7,3)/
     x 5.4986606d-04,-1.0922408d-06, 4.2029177d-07 /
      data fpp(23,10, 8,1),fpp(23,10, 8,2),fpp(23,10, 8,3)/
     x 4.6166973d-04,-1.2928750d-06,-7.2862861d-08 /
      data fpp(23,10, 9,1),fpp(23,10, 9,2),fpp(23,10, 9,3)/
     x 3.7140013d-04,-1.3923786d-06,-2.3084033d-07 /
      data fpp(23,10,10,1),fpp(23,10,10,2),fpp(23,10,10,3)/
     x 2.3466539d-04,-1.5052049d-06,-2.0377584d-07 /
      data fpp(23,10,11,1),fpp(23,10,11,2),fpp(23,10,11,3)/
     x 7.8273598d-05,-1.6133214d-06,-9.4056327d-08 /
      data fpp(23,10,12,1),fpp(23,10,12,2),fpp(23,10,12,3)/
     x-6.0645464d-05,-1.6355033d-06, 4.0001145d-08 /
      data fpp(23,10,13,1),fpp(23,10,13,2),fpp(23,10,13,3)/
     x-1.6083738d-04,-1.5526689d-06, 1.5605175d-07 /
      data fpp(23,10,14,1),fpp(23,10,14,2),fpp(23,10,14,3)/
     x-2.0356972d-04,-1.3893207d-06, 2.5979187d-07 /
      data fpp(23,10,15,1),fpp(23,10,15,2),fpp(23,10,15,3)/
     x-1.8755177d-04,-1.1913717d-06, 3.0478077d-07 /
      data fpp(23,10,16,1),fpp(23,10,16,2),fpp(23,10,16,3)/
     x-1.0995313d-04,-9.5557751d-07, 2.5508503d-07 /
      data fpp(23,10,17,1),fpp(23,10,17,2),fpp(23,10,17,3)/
     x 1.9333604d-05,-6.7992011d-07, 6.0879099d-08 /
      data fpp(23,10,18,1),fpp(23,10,18,2),fpp(23,10,18,3)/
     x 1.8761122d-04,-3.6335778d-07,-1.7460143d-07 /
      data fpp(23,10,19,1),fpp(23,10,19,2),fpp(23,10,19,3)/
     x 3.5646782d-04,-4.7553352d-08,-3.3447339d-07 /
      data fpp(23,10,20,1),fpp(23,10,20,2),fpp(23,10,20,3)/
     x 4.7675123d-04, 1.9726688d-07,-1.1505021d-08 /
      data fpp(23,10,21,1),fpp(23,10,21,2),fpp(23,10,21,3)/
     x 4.7675123d-04, 1.9726688d-07,-2.6248243d-08 /
      data fpp(23,10,22,1),fpp(23,10,22,2),fpp(23,10,22,3)/
     x 3.5646782d-04,-4.7553352d-08,-2.7550050d-07 /
      data fpp(23,10,23,1),fpp(23,10,23,2),fpp(23,10,23,3)/
     x 1.8761122d-04,-3.6335778d-07,-3.9574975d-07 /
      data fpp(23,11, 1,1),fpp(23,11, 1,2),fpp(23,11, 1,3)/
     x 7.8435647d-04,-5.6328909d-08, 2.2844304d-06 /
      data fpp(23,11, 2,1),fpp(23,11, 2,2),fpp(23,11, 2,3)/
     x 1.5477383d-03, 2.0375809d-07, 8.2863924d-07 /
      data fpp(23,11, 3,1),fpp(23,11, 3,2),fpp(23,11, 3,3)/
     x 2.5335410d-03, 3.8315003d-07,-2.2689873d-06 /
      data fpp(23,11, 4,1),fpp(23,11, 4,2),fpp(23,11, 4,3)/
     x 2.5335410d-03, 3.8315003d-07,-2.3073576d-06 /
      data fpp(23,11, 5,1),fpp(23,11, 5,2),fpp(23,11, 5,3)/
     x 1.5477383d-03, 2.0375809d-07, 9.8212054d-07 /
      data fpp(23,11, 6,1),fpp(23,11, 6,2),fpp(23,11, 6,3)/
     x 7.8435647d-04,-5.6328909d-08, 1.7088755d-06 /
      data fpp(23,11, 7,1),fpp(23,11, 7,2),fpp(23,11, 7,3)/
     x 4.4016836d-04,-3.3684253d-07, 1.0983775d-06 /
      data fpp(23,11, 8,1),fpp(23,11, 8,2),fpp(23,11, 8,3)/
     x 3.7839161d-04,-5.3795019d-07, 1.4361458d-07 /
      data fpp(23,11, 9,1),fpp(23,11, 9,2),fpp(23,11, 9,3)/
     x 3.8553106d-04,-6.6282928d-07,-2.8083579d-07 /
      data fpp(23,11,10,1),fpp(23,11,10,2),fpp(23,11,10,3)/
     x 3.3501106d-04,-7.4012840d-07,-2.9827140d-07 /
      data fpp(23,11,11,1),fpp(23,11,11,2),fpp(23,11,11,3)/
     x 2.5630946d-04,-7.7175647d-07,-1.5207859d-07 /
      data fpp(23,11,12,1),fpp(23,11,12,2),fpp(23,11,12,3)/
     x 1.5790981d-04,-7.8457308d-07,-4.1414230d-08 /
      data fpp(23,11,13,1),fpp(23,11,13,2),fpp(23,11,13,3)/
     x 7.8981206d-05,-7.8183863d-07, 3.5735513d-08 /
      data fpp(23,11,14,1),fpp(23,11,14,2),fpp(23,11,14,3)/
     x 4.4677817d-05,-7.3377637d-07, 1.2047218d-07 /
      data fpp(23,11,15,1),fpp(23,11,15,2),fpp(23,11,15,3)/
     x 5.7205181d-05,-6.4197098d-07, 2.0237577d-07 /
      data fpp(23,11,16,1),fpp(23,11,16,2),fpp(23,11,16,3)/
     x 1.1683283d-04,-5.4725236d-07, 2.1002473d-07 /
      data fpp(23,11,17,1),fpp(23,11,17,2),fpp(23,11,17,3)/
     x 2.1918779d-04,-4.6360323d-07, 6.1525312d-08 /
      data fpp(23,11,18,1),fpp(23,11,18,2),fpp(23,11,18,3)/
     x 3.5522639d-04,-3.6196359d-07,-1.5612598d-07 /
      data fpp(23,11,19,1),fpp(23,11,19,2),fpp(23,11,19,3)/
     x 4.9178010d-04,-2.0512394d-07,-3.1302140d-07 /
      data fpp(23,11,20,1),fpp(23,11,20,2),fpp(23,11,20,3)/
     x 5.8426170d-04,-1.0529120d-08, 8.8211585d-08 /
      data fpp(23,11,21,1),fpp(23,11,21,2),fpp(23,11,21,3)/
     x 5.8426170d-04,-1.0529120d-08, 7.1875945d-08 /
      data fpp(23,11,22,1),fpp(23,11,22,2),fpp(23,11,22,3)/
     x 4.9178010d-04,-2.0512394d-07,-2.4767884d-07 /
      data fpp(23,11,23,1),fpp(23,11,23,2),fpp(23,11,23,3)/
     x 3.5522639d-04,-3.6196359d-07,-4.0116058d-07 /
      data fpp(23,12, 1,1),fpp(23,12, 1,2),fpp(23,12, 1,3)/
     x 8.7184971d-04, 9.3597494d-07, 3.3712807d-06 /
      data fpp(23,12, 2,1),fpp(23,12, 2,2),fpp(23,12, 2,3)/
     x 2.0928521d-03, 4.3046494d-07, 1.1584386d-06 /
      data fpp(23,12, 3,1),fpp(23,12, 3,2),fpp(23,12, 3,3)/
     x 3.7453975d-03,-4.8163546d-07,-3.5530350d-06 /
      data fpp(23,12, 4,1),fpp(23,12, 4,2),fpp(23,12, 4,3)/
     x 3.7453975d-03,-4.8163546d-07,-3.6061143d-06 /
      data fpp(23,12, 5,1),fpp(23,12, 5,2),fpp(23,12, 5,3)/
     x 2.0928521d-03, 4.3046494d-07, 1.3707558d-06 /
      data fpp(23,12, 6,1),fpp(23,12, 6,2),fpp(23,12, 6,3)/
     x 8.7184971d-04, 9.3597494d-07, 2.5750910d-06 /
      data fpp(23,12, 7,1),fpp(23,12, 7,2),fpp(23,12, 7,3)/
     x 2.9767455d-04, 8.2561094d-07, 1.8288803d-06 /
      data fpp(23,12, 8,1),fpp(23,12, 8,2),fpp(23,12, 8,3)/
     x 1.9364492d-04, 4.0867576d-07, 4.4738799d-07 /
      data fpp(23,12, 9,1),fpp(23,12, 9,2),fpp(23,12, 9,3)/
     x 2.5621918d-04, 4.1695712d-08,-2.7643220d-07 /
      data fpp(23,12,10,1),fpp(23,12,10,2),fpp(23,12,10,3)/
     x 2.9800253d-04,-1.4828148d-07,-3.4365917d-07 /
      data fpp(23,12,11,1),fpp(23,12,11,2),fpp(23,12,11,3)/
     x 2.7289408d-04,-2.4965275d-07,-1.8493111d-07 /
      data fpp(23,12,12,1),fpp(23,12,12,2),fpp(23,12,12,3)/
     x 2.1537110d-04,-3.3220436d-07,-9.2616382d-08 /
      data fpp(23,12,13,1),fpp(23,12,13,2),fpp(23,12,13,3)/
     x 1.6432514d-04,-3.8397660d-07,-3.2603360d-08 /
      data fpp(23,12,14,1),fpp(23,12,14,2),fpp(23,12,14,3)/
     x 1.4574213d-04,-4.1557382d-07, 2.5029824d-08 /
      data fpp(23,12,15,1),fpp(23,12,15,2),fpp(23,12,15,3)/
     x 1.6746732d-04,-4.1674434d-07, 1.1248407d-07 /
      data fpp(23,12,16,1),fpp(23,12,16,2),fpp(23,12,16,3)/
     x 2.3334833d-04,-3.8341306d-07, 1.5503391d-07 /
      data fpp(23,12,17,1),fpp(23,12,17,2),fpp(23,12,17,3)/
     x 3.3489349d-04,-3.5766698d-07, 7.7380286d-08 /
      data fpp(23,12,18,1),fpp(23,12,18,2),fpp(23,12,18,3)/
     x 4.5909886d-04,-3.5478788d-07,-9.8555057d-08 /
      data fpp(23,12,19,1),fpp(23,12,19,2),fpp(23,12,19,3)/
     x 5.7720650d-04,-3.4995090d-07,-2.4116006d-07 /
      data fpp(23,12,20,1),fpp(23,12,20,2),fpp(23,12,20,3)/
     x 6.5567090d-04,-3.2315041d-07, 4.9195294d-08 /
      data fpp(23,12,21,1),fpp(23,12,21,2),fpp(23,12,21,3)/
     x 6.5567090d-04,-3.2315041d-07, 3.5994147d-08 /
      data fpp(23,12,22,1),fpp(23,12,22,2),fpp(23,12,22,3)/
     x 5.7720650d-04,-3.4995090d-07,-1.8835547d-07 /
      data fpp(23,12,23,1),fpp(23,12,23,2),fpp(23,12,23,3)/
     x 4.5909886d-04,-3.5478788d-07,-2.9657226d-07 /
      data fpp(23,13, 1,1),fpp(23,13, 1,2),fpp(23,13, 1,3)/
     x 1.1213934d-03, 1.0764292d-06, 3.4728568d-06 /
      data fpp(23,13, 2,1),fpp(23,13, 2,2),fpp(23,13, 2,3)/
     x 2.6394147d-03,-2.4561784d-07, 1.0417863d-06 /
      data fpp(23,13, 3,1),fpp(23,13, 3,2),fpp(23,13, 3,3)/
     x 4.4458521d-03,-1.9366082d-06,-4.1420021d-06 /
      data fpp(23,13, 4,1),fpp(23,13, 4,2),fpp(23,13, 4,3)/
     x 4.4458521d-03,-1.9366082d-06,-4.1868869d-06 /
      data fpp(23,13, 5,1),fpp(23,13, 5,2),fpp(23,13, 5,3)/
     x 2.6394147d-03,-2.4561784d-07, 1.2213258d-06 /
      data fpp(23,13, 6,1),fpp(23,13, 6,2),fpp(23,13, 6,3)/
     x 1.1213934d-03, 1.0764292d-06, 2.7995837d-06 /
      data fpp(23,13, 7,1),fpp(23,13, 7,2),fpp(23,13, 7,3)/
     x 3.1640719d-04, 1.4683988d-06, 2.2503392d-06 /
      data fpp(23,13, 8,1),fpp(23,13, 8,2),fpp(23,13, 8,3)/
     x 9.0135527d-05, 1.1832471d-06, 8.0505928d-07 /
      data fpp(23,13, 9,1),fpp(23,13, 9,2),fpp(23,13, 9,3)/
     x 1.3179752d-04, 7.0604643d-07,-9.4576360d-08 /
      data fpp(23,13,10,1),fpp(23,13,10,2),fpp(23,13,10,3)/
     x 2.0740096d-04, 3.2525432d-07,-3.0075384d-07 /
      data fpp(23,13,11,1),fpp(23,13,11,2),fpp(23,13,11,3)/
     x 2.2985788d-04, 9.0367487d-08,-2.0240828d-07 /
      data fpp(23,13,12,1),fpp(23,13,12,2),fpp(23,13,12,3)/
     x 2.0619891d-04,-5.8609461d-08,-1.1361303d-07 /
      data fpp(23,13,13,1),fpp(23,13,13,2),fpp(23,13,13,3)/
     x 1.7757786d-04,-1.8425498d-07,-7.5139615d-08 /
      data fpp(23,13,14,1),fpp(23,13,14,2),fpp(23,13,14,3)/
     x 1.7086985d-04,-2.6192836d-07,-2.9828515d-08 /
      data fpp(23,13,15,1),fpp(23,13,15,2),fpp(23,13,15,3)/
     x 2.0047975d-04,-2.8905164d-07, 5.0453675d-08 /
      data fpp(23,13,16,1),fpp(23,13,16,2),fpp(23,13,16,3)/
     x 2.6659811d-04,-3.1309539d-07, 9.2013815d-08 /
      data fpp(23,13,17,1),fpp(23,13,17,2),fpp(23,13,17,3)/
     x 3.6396379d-04,-3.2572886d-07, 6.7491064d-08 /
      data fpp(23,13,18,1),fpp(23,13,18,2),fpp(23,13,18,3)/
     x 4.7162458d-04,-3.7288488d-07,-3.7978073d-08 /
      data fpp(23,13,19,1),fpp(23,13,19,2),fpp(23,13,19,3)/
     x 5.7215359d-04,-4.6507246d-07,-1.3757877d-07 /
      data fpp(23,13,20,1),fpp(23,13,20,2),fpp(23,13,20,3)/
     x 6.3817690d-04,-5.8086926d-07,-1.7706835d-08 /
      data fpp(23,13,21,1),fpp(23,13,21,2),fpp(23,13,21,3)/
     x 6.3817690d-04,-5.8086926d-07,-2.5090108d-08 /
      data fpp(23,13,22,1),fpp(23,13,22,2),fpp(23,13,22,3)/
     x 5.7215359d-04,-4.6507246d-07,-1.0804568d-07 /
      data fpp(23,13,23,1),fpp(23,13,23,2),fpp(23,13,23,3)/
     x 4.7162458d-04,-3.7288488d-07,-1.4872716d-07 /
      data fpp(23,14, 1,1),fpp(23,14, 1,2),fpp(23,14, 1,3)/
     x 1.5028795d-03,-3.3691605d-08, 2.3888430d-06 /
      data fpp(23,14, 2,1),fpp(23,14, 2,2),fpp(23,14, 2,3)/
     x 2.9862902d-03,-1.2359936d-06, 4.8581397d-07 /
      data fpp(23,14, 3,1),fpp(23,14, 3,2),fpp(23,14, 3,3)/
     x 4.6055305d-03,-2.3499318d-06,-3.5820989d-06 /
      data fpp(23,14, 4,1),fpp(23,14, 4,2),fpp(23,14, 4,3)/
     x 4.6055305d-03,-2.3499318d-06,-3.5996103d-06 /
      data fpp(23,14, 5,1),fpp(23,14, 5,2),fpp(23,14, 5,3)/
     x 2.9862902d-03,-1.2359936d-06, 5.5585968d-07 /
      data fpp(23,14, 6,1),fpp(23,14, 6,2),fpp(23,14, 6,3)/
     x 1.5028795d-03,-3.3691605d-08, 2.1261716d-06 /
      data fpp(23,14, 7,1),fpp(23,14, 7,2),fpp(23,14, 7,3)/
     x 5.8425194d-04, 7.6479396d-07, 2.0394540d-06 /
      data fpp(23,14, 8,1),fpp(23,14, 8,2),fpp(23,14, 8,3)/
     x 2.0328897d-04, 1.0023357d-06, 1.0140125d-06 /
      data fpp(23,14, 9,1),fpp(23,14, 9,2),fpp(23,14, 9,3)/
     x 1.3192505d-04, 8.4211857d-07, 1.9849612d-07 /
      data fpp(23,14,10,1),fpp(23,14,10,2),fpp(23,14,10,3)/
     x 1.6508234d-04, 5.4526420d-07,-1.2799697d-07 /
      data fpp(23,14,11,1),fpp(23,14,11,2),fpp(23,14,11,3)/
     x 1.8908755d-04, 2.7818281d-07,-1.4850825d-07 /
      data fpp(23,14,12,1),fpp(23,14,12,2),fpp(23,14,12,3)/
     x 1.8038226d-04, 8.6642209d-08,-1.1197004d-07 /
      data fpp(23,14,13,1),fpp(23,14,13,2),fpp(23,14,13,3)/
     x 1.6604164d-04,-2.5003476d-08,-7.5611611d-08 /
      data fpp(23,14,14,1),fpp(23,14,14,2),fpp(23,14,14,3)/
     x 1.6225329d-04,-1.0871276d-07,-3.5583522d-08 /
      data fpp(23,14,15,1),fpp(23,14,15,2),fpp(23,14,15,3)/
     x 1.8719050d-04,-1.7904908d-07,-4.0543019d-09 /
      data fpp(23,14,16,1),fpp(23,14,16,2),fpp(23,14,16,3)/
     x 2.4175588d-04,-2.0020538d-07, 4.5800730d-08 /
      data fpp(23,14,17,1),fpp(23,14,17,2),fpp(23,14,17,3)/
     x 3.2405761d-04,-2.1741758d-07, 2.4851384d-08 /
      data fpp(23,14,18,1),fpp(23,14,18,2),fpp(23,14,18,3)/
     x 4.1093487d-04,-2.2367259d-07,-1.3206264d-08 /
      data fpp(23,14,19,1),fpp(23,14,19,2),fpp(23,14,19,3)/
     x 4.8414037d-04,-2.5575927d-07,-6.2026327d-08 /
      data fpp(23,14,20,1),fpp(23,14,20,2),fpp(23,14,20,3)/
     x 5.3351719d-04,-2.9937256d-07,-2.0688429d-08 /
      data fpp(23,14,21,1),fpp(23,14,21,2),fpp(23,14,21,3)/
     x 5.3351719d-04,-2.9937256d-07,-2.3921550d-08 /
      data fpp(23,14,22,1),fpp(23,14,22,2),fpp(23,14,22,3)/
     x 4.8414037d-04,-2.5575927d-07,-4.9093843d-08 /
      data fpp(23,14,23,1),fpp(23,14,23,2),fpp(23,14,23,3)/
     x 4.1093487d-04,-2.2367259d-07,-6.1703079d-08 /
      data fpp(23,15, 1,1),fpp(23,15, 1,2),fpp(23,15, 1,3)/
     x 1.7684801d-03,-1.2356627d-06, 9.5757484d-07 /
      data fpp(23,15, 2,1),fpp(23,15, 2,2),fpp(23,15, 2,3)/
     x 2.9077136d-03,-1.4524078d-06,-7.0649689d-08 /
      data fpp(23,15, 3,1),fpp(23,15, 3,2),fpp(23,15, 3,3)/
     x 4.1165997d-03,-1.2576647d-06,-2.2769761d-06 /
      data fpp(23,15, 4,1),fpp(23,15, 4,2),fpp(23,15, 4,3)/
     x 4.1165997d-03,-1.2576647d-06,-2.2717469d-06 /
      data fpp(23,15, 5,1),fpp(23,15, 5,2),fpp(23,15, 5,3)/
     x 2.9077136d-03,-1.4524078d-06,-9.1566476d-08 /
      data fpp(23,15, 6,1),fpp(23,15, 6,2),fpp(23,15, 6,3)/
     x 1.7684801d-03,-1.2356627d-06, 1.0360128d-06 /
      data fpp(23,15, 7,1),fpp(23,15, 7,2),fpp(23,15, 7,3)/
     x 9.4606499d-04,-6.5757463d-07, 1.2935153d-06 /
      data fpp(23,15, 8,1),fpp(23,15, 8,2),fpp(23,15, 8,3)/
     x 4.8066821d-04,-6.2589954d-08, 8.7592603d-07 /
      data fpp(23,15, 9,1),fpp(23,15, 9,2),fpp(23,15, 9,3)/
     x 2.7911141d-04, 2.8747928d-07, 3.8678058d-07 /
      data fpp(23,15,10,1),fpp(23,15,10,2),fpp(23,15,10,3)/
     x 2.1313484d-04, 3.6168887d-07, 8.4951631d-08 /
      data fpp(23,15,11,1),fpp(23,15,11,2),fpp(23,15,11,3)/
     x 1.9211499d-04, 2.9090129d-07,-3.0587107d-08 /
      data fpp(23,15,12,1),fpp(23,15,12,2),fpp(23,15,12,3)/
     x 1.7345112d-04, 1.9204062d-07,-4.6603202d-08 /
      data fpp(23,15,13,1),fpp(23,15,13,2),fpp(23,15,13,3)/
     x 1.5277367d-04, 9.8268887d-08,-4.7000083d-08 /
      data fpp(23,15,14,1),fpp(23,15,14,2),fpp(23,15,14,3)/
     x 1.4054252d-04, 3.6779385d-08,-2.9396464d-08 /
      data fpp(23,15,15,1),fpp(23,15,15,2),fpp(23,15,15,3)/
     x 1.5596702d-04,-2.7520426d-09,-9.4140609d-09 /
      data fpp(23,15,16,1),fpp(23,15,16,2),fpp(23,15,16,3)/
     x 1.8901382d-04,-3.2083089d-08, 1.0527074d-09 /
      data fpp(23,15,17,1),fpp(23,15,17,2),fpp(23,15,17,3)/
     x 2.4138878d-04,-1.6600814d-08,-7.9676866d-10 /
      data fpp(23,15,18,1),fpp(23,15,18,2),fpp(23,15,18,3)/
     x 2.9845031d-04, 3.1575253d-08,-1.5865633d-08 /
      data fpp(23,15,19,1),fpp(23,15,19,2),fpp(23,15,19,3)/
     x 3.4836311d-04, 1.0810953d-07,-1.3740700d-08 /
      data fpp(23,15,20,1),fpp(23,15,20,2),fpp(23,15,20,3)/
     x 3.8006046d-04, 1.5235950d-07, 1.0828434d-08 /
      data fpp(23,15,21,1),fpp(23,15,21,2),fpp(23,15,21,3)/
     x 3.8006046d-04, 1.5235950d-07, 1.0385048d-08 /
      data fpp(23,15,22,1),fpp(23,15,22,2),fpp(23,15,22,3)/
     x 3.4836311d-04, 1.0810953d-07,-1.1967157d-08 /
      data fpp(23,15,23,1),fpp(23,15,23,2),fpp(23,15,23,3)/
     x 2.9845031d-04, 3.1575253d-08,-2.2516422d-08 /
      data fpp(23,16, 1,1),fpp(23,16, 1,2),fpp(23,16, 1,3)/
     x 1.6425825d-03,-1.3596574d-06, 1.1275301d-07 /
      data fpp(23,16, 2,1),fpp(23,16, 2,2),fpp(23,16, 2,3)/
     x 2.2212949d-03,-8.1437523d-07,-2.6100602d-07 /
      data fpp(23,16, 3,1),fpp(23,16, 3,2),fpp(23,16, 3,3)/
     x 2.8170561d-03,-4.7409465d-08,-1.0667289d-06 /
      data fpp(23,16, 4,1),fpp(23,16, 4,2),fpp(23,16, 4,3)/
     x 2.8170561d-03,-4.7409465d-08,-1.0583102d-06 /
      data fpp(23,16, 5,1),fpp(23,16, 5,2),fpp(23,16, 5,3)/
     x 2.2212949d-03,-8.1437523d-07,-2.9468069d-07 /
      data fpp(23,16, 6,1),fpp(23,16, 6,2),fpp(23,16, 6,3)/
     x 1.6425825d-03,-1.3596574d-06, 2.3903301d-07 /
      data fpp(23,16, 7,1),fpp(23,16, 7,2),fpp(23,16, 7,3)/
     x 1.1088401d-03,-1.3624955d-06, 5.1454865d-07 /
      data fpp(23,16, 8,1),fpp(23,16, 8,2),fpp(23,16, 8,3)/
     x 7.1535538d-04,-9.6197589d-07, 4.8677238d-07 /
      data fpp(23,16, 9,1),fpp(23,16, 9,2),fpp(23,16, 9,3)/
     x 4.7204036d-04,-4.6803568d-07, 3.2836181d-07 /
      data fpp(23,16,10,1),fpp(23,16,10,2),fpp(23,16,10,3)/
     x 3.2896597d-04,-9.0019698d-08, 1.7978037d-07 /
      data fpp(23,16,11,1),fpp(23,16,11,2),fpp(23,16,11,3)/
     x 2.4987389d-04, 1.0621202d-07, 7.4516710d-08 /
      data fpp(23,16,12,1),fpp(23,16,12,2),fpp(23,16,12,3)/
     x 1.9785289d-04, 1.7719530d-07, 2.6152791d-08 /
      data fpp(23,16,13,1),fpp(23,16,13,2),fpp(23,16,13,3)/
     x 1.6198400d-04, 1.8992793d-07, 6.8721258d-09 /
      data fpp(23,16,14,1),fpp(23,16,14,2),fpp(23,16,14,3)/
     x 1.3584962d-04, 1.7159522d-07,-5.6412941d-09 /
      data fpp(23,16,15,1),fpp(23,16,15,2),fpp(23,16,15,3)/
     x 1.2877361d-04, 1.6005725d-07,-2.3069493d-09 /
      data fpp(23,16,16,1),fpp(23,16,16,2),fpp(23,16,16,3)/
     x 1.6438826d-04, 1.6653774d-07,-3.1309087d-09 /
      data fpp(23,16,17,1),fpp(23,16,17,2),fpp(23,16,17,3)/
     x 1.5472035d-04, 1.8782084d-07,-3.1694159d-09 /
      data fpp(23,16,18,1),fpp(23,16,18,2),fpp(23,16,18,3)/
     x 1.8019870d-04, 2.2337158d-07, 3.8085722d-09 /
      data fpp(23,16,19,1),fpp(23,16,19,2),fpp(23,16,19,3)/
     x 2.0119050d-04, 2.4932116d-07,-6.4872902d-11 /
      data fpp(23,16,20,1),fpp(23,16,20,2),fpp(23,16,20,3)/
     x 2.2012109d-04, 2.8393457d-07, 2.6450919d-08 /
      data fpp(23,16,21,1),fpp(23,16,21,2),fpp(23,16,21,3)/
     x 2.2012109d-04, 2.8393457d-07, 2.5679678d-08 /
      data fpp(23,16,22,1),fpp(23,16,22,2),fpp(23,16,22,3)/
     x 2.0119050d-04, 2.4932116d-07, 3.0200919d-09 /
      data fpp(23,16,23,1),fpp(23,16,23,2),fpp(23,16,23,3)/
     x 1.8019870d-04, 2.2337158d-07,-7.7600460d-09 /
      data fpp(23,17, 1,1),fpp(23,17, 1,2),fpp(23,17, 1,3)/
     x 1.1725209d-03,-4.5970762d-07,-8.6102519d-08 /
      data fpp(23,17, 2,1),fpp(23,17, 2,2),fpp(23,17, 2,3)/
     x 1.4362998d-03, 1.5590872d-07,-1.7479496d-07 /
      data fpp(23,17, 3,1),fpp(23,17, 3,2),fpp(23,17, 3,3)/
     x 1.6333371d-03, 7.1530255d-07,-3.6671763d-07 /
      data fpp(23,17, 4,1),fpp(23,17, 4,2),fpp(23,17, 4,3)/
     x 1.6333371d-03, 7.1530255d-07,-3.6344963d-07 /
      data fpp(23,17, 5,1),fpp(23,17, 5,2),fpp(23,17, 5,3)/
     x 1.4362998d-03, 1.5590872d-07,-1.8786699d-07 /
      data fpp(23,17, 6,1),fpp(23,17, 6,2),fpp(23,17, 6,3)/
     x 1.1725209d-03,-4.5970762d-07,-3.7082431d-08 /
      data fpp(23,17, 7,1),fpp(23,17, 7,2),fpp(23,17, 7,3)/
     x 9.5608416d-04,-8.6444353d-07, 8.4196709d-08 /
      data fpp(23,17, 8,1),fpp(23,17, 8,2),fpp(23,17, 8,3)/
     x 7.3589778d-04,-9.4350649d-07, 1.3829560d-07 /
      data fpp(23,17, 9,1),fpp(23,17, 9,2),fpp(23,17, 9,3)/
     x 5.5845711d-04,-7.6733655d-07, 1.4262091d-07 /
      data fpp(23,17,10,1),fpp(23,17,10,2),fpp(23,17,10,3)/
     x 4.2386043d-04,-4.8161008d-07, 1.1322077d-07 /
      data fpp(23,17,11,1),fpp(23,17,11,2),fpp(23,17,11,3)/
     x 3.2709088d-04,-1.9374939d-07, 8.2496005d-08 /
      data fpp(23,17,12,1),fpp(23,17,12,2),fpp(23,17,12,3)/
     x 2.5668483d-04, 2.9178189d-08, 5.4795209d-08 /
      data fpp(23,17,13,1),fpp(23,17,13,2),fpp(23,17,13,3)/
     x 2.0284575d-04, 1.8001940d-07, 3.4323158d-08 /
      data fpp(23,17,14,1),fpp(23,17,14,2),fpp(23,17,14,3)/
     x 1.6586141d-04, 2.7883975d-07, 2.3912159d-08 /
      data fpp(23,17,15,1),fpp(23,17,15,2),fpp(23,17,15,3)/
     x 1.3801450d-04, 3.3452305d-07, 1.4028206d-08 /
      data fpp(23,17,16,1),fpp(23,17,16,2),fpp(23,17,16,3)/
     x 1.2259215d-04, 3.6793215d-07, 9.9750182d-09 /
      data fpp(23,17,17,1),fpp(23,17,17,2),fpp(23,17,17,3)/
     x 1.1600676d-04, 3.9331747d-07, 1.2071722d-08 /
      data fpp(23,17,18,1),fpp(23,17,18,2),fpp(23,17,18,3)/
     x 1.1468270d-04, 4.0693842d-07, 1.3738096d-08 /
      data fpp(23,17,19,1),fpp(23,17,19,2),fpp(23,17,19,3)/
     x 1.1587600d-04, 4.1260584d-07, 1.6975896d-08 /
      data fpp(23,17,20,1),fpp(23,17,20,2),fpp(23,17,20,3)/
     x 1.1641579d-04, 3.9790223d-07, 2.0358322d-08 /
      data fpp(23,17,21,1),fpp(23,17,21,2),fpp(23,17,21,3)/
     x 1.1641579d-04, 3.9790223d-07, 2.0437087d-08 /
      data fpp(23,17,22,1),fpp(23,17,22,2),fpp(23,17,22,3)/
     x 1.1587600d-04, 4.1260584d-07, 1.6660832d-08 /
      data fpp(23,17,23,1),fpp(23,17,23,2),fpp(23,17,23,3)/
     x 1.1468270d-04, 4.0693842d-07, 1.4919584d-08 /
      data fpp(23,18, 1,1),fpp(23,18, 1,2),fpp(23,18, 1,3)/
     x 6.9861657d-04, 1.9848789d-07,-4.8746545d-08 /
      data fpp(23,18, 2,1),fpp(23,18, 2,2),fpp(23,18, 2,3)/
     x 7.5631805d-04, 5.3274037d-07,-5.9006910d-08 /
      data fpp(23,18, 3,1),fpp(23,18, 3,2),fpp(23,18, 3,3)/
     x 7.9240836d-04, 8.1019927d-07,-8.1225816d-08 /
      data fpp(23,18, 4,1),fpp(23,18, 4,2),fpp(23,18, 4,3)/
     x 7.9240836d-04, 8.1019927d-07,-8.0819098d-08 /
      data fpp(23,18, 5,1),fpp(23,18, 5,2),fpp(23,18, 5,3)/
     x 7.5631805d-04, 5.3274037d-07,-6.0633781d-08 /
      data fpp(23,18, 6,1),fpp(23,18, 6,2),fpp(23,18, 6,3)/
     x 6.9861657d-04, 1.9848789d-07,-4.2645776d-08 /
      data fpp(23,18, 7,1),fpp(23,18, 7,2),fpp(23,18, 7,3)/
     x 6.3439396d-04,-8.7730420d-08,-1.4783113d-08 /
      data fpp(23,18, 8,1),fpp(23,18, 8,2),fpp(23,18, 8,3)/
     x 5.6325875d-04,-2.7399815d-07,-2.2177080d-10 /
      data fpp(23,18, 9,1),fpp(23,18, 9,2),fpp(23,18, 9,3)/
     x 4.9415902d-04,-3.4461813d-07, 1.5670196d-08 /
      data fpp(23,18,10,1),fpp(23,18,10,2),fpp(23,18,10,3)/
     x 4.2824675d-04,-3.1753998d-07, 2.1540985d-08 /
      data fpp(23,18,11,1),fpp(23,18,11,2),fpp(23,18,11,3)/
     x 3.6948357d-04,-2.2521446d-07, 2.4165863d-08 /
      data fpp(23,18,12,1),fpp(23,18,12,2),fpp(23,18,12,3)/
     x 3.2020032d-04,-9.5908054d-08, 2.5795562d-08 /
      data fpp(23,18,13,1),fpp(23,18,13,2),fpp(23,18,13,3)/
     x 2.7637350d-04, 4.3994456d-08, 2.2651887d-08 /
      data fpp(23,18,14,1),fpp(23,18,14,2),fpp(23,18,14,3)/
     x 2.3974450d-04, 1.7704579d-07, 2.1596890d-08 /
      data fpp(23,18,15,1),fpp(23,18,15,2),fpp(23,18,15,3)/
     x 2.1095621d-04, 2.9585056d-07, 1.6960554d-08 /
      data fpp(23,18,16,1),fpp(23,18,16,2),fpp(23,18,16,3)/
     x 1.8848386d-04, 3.9573367d-07, 1.8560893d-08 /
      data fpp(23,18,17,1),fpp(23,18,17,2),fpp(23,18,17,3)/
     x 1.7145605d-04, 4.7090930d-07, 1.6795875d-08 /
      data fpp(23,18,18,1),fpp(23,18,18,2),fpp(23,18,18,3)/
     x 1.5757939d-04, 5.2487474d-07, 1.6255607d-08 /
      data fpp(23,18,19,1),fpp(23,18,19,2),fpp(23,18,19,3)/
     x 1.4826810d-04, 5.6025547d-07, 1.4181697d-08 /
      data fpp(23,18,20,1),fpp(23,18,20,2),fpp(23,18,20,3)/
     x 1.4475721d-04, 5.8445651d-07, 1.7017604d-08 /
      data fpp(23,18,21,1),fpp(23,18,21,2),fpp(23,18,21,3)/
     x 1.4475721d-04, 5.8445651d-07, 1.6856338d-08 /
      data fpp(23,18,22,1),fpp(23,18,22,2),fpp(23,18,22,3)/
     x 1.4826810d-04, 5.6025547d-07, 1.4826760d-08 /
      data fpp(23,18,23,1),fpp(23,18,23,2),fpp(23,18,23,3)/
     x 1.5757939d-04, 5.2487474d-07, 1.3836620d-08 /
      data fpp(23,19, 1,1),fpp(23,19, 1,2),fpp(23,19, 1,3)/
     x 3.4494738d-04, 9.2575605d-07, 6.1994184d-22 /
      data fpp(23,19, 2,1),fpp(23,19, 2,2),fpp(23,19, 2,3)/
     x 3.4494738d-04, 1.0791298d-06,-6.0974289d-23 /
      data fpp(23,19, 3,1),fpp(23,19, 3,2),fpp(23,19, 3,3)/
     x 3.4494738d-04, 1.0959004d-06, 8.9081308d-22 /
      data fpp(23,19, 4,1),fpp(23,19, 4,2),fpp(23,19, 4,3)/
     x 3.4494738d-04, 1.0959004d-06,-3.7286492d-22 /
      data fpp(23,19, 5,1),fpp(23,19, 5,2),fpp(23,19, 5,3)/
     x 3.4494738d-04, 1.0791298d-06,-3.6565596d-22 /
      data fpp(23,19, 6,1),fpp(23,19, 6,2),fpp(23,19, 6,3)/
     x 3.4494738d-04, 9.2575605d-07, 2.8773033d-22 /
      data fpp(23,19, 7,1),fpp(23,19, 7,2),fpp(23,19, 7,3)/
     x 3.4494738d-04, 6.0936521d-07, 1.2768678d-21 /
      data fpp(23,19, 8,1),fpp(23,19, 8,2),fpp(23,19, 8,3)/
     x 3.4494738d-04, 2.0949907d-07, 1.1282567d-21 /
      data fpp(23,19, 9,1),fpp(23,19, 9,2),fpp(23,19, 9,3)/
     x 3.4494738d-04,-1.2819094d-07,-3.4618379d-23 /
      data fpp(23,19,10,1),fpp(23,19,10,2),fpp(23,19,10,3)/
     x 3.4494738d-04,-3.1223001d-07,-1.0999413d-21 /
      data fpp(23,19,11,1),fpp(23,19,11,2),fpp(23,19,11,3)/
     x 3.4494738d-04,-3.3339277d-07, 3.8525979d-22 /
      data fpp(23,19,12,1),fpp(23,19,12,2),fpp(23,19,12,3)/
     x 3.4494738d-04,-2.2754597d-07,-6.1547987d-22 /
      data fpp(23,19,13,1),fpp(23,19,13,2),fpp(23,19,13,3)/
     x 3.4494738d-04,-5.5997228d-08,-8.7943715d-22 /
      data fpp(23,19,14,1),fpp(23,19,14,2),fpp(23,19,14,3)/
     x 3.4494738d-04, 1.3497711d-07,-6.7765864d-22 /
      data fpp(23,19,15,1),fpp(23,19,15,2),fpp(23,19,15,3)/
     x 3.4494738d-04, 3.1807472d-07, 1.5693340d-22 /
      data fpp(23,19,16,1),fpp(23,19,16,2),fpp(23,19,16,3)/
     x 3.4494738d-04, 4.7313316d-07, 9.9528515d-22 /
      data fpp(23,19,17,1),fpp(23,19,17,2),fpp(23,19,17,3)/
     x 3.4494738d-04, 5.8504535d-07,-9.9613488d-22 /
      data fpp(23,19,18,1),fpp(23,19,18,2),fpp(23,19,18,3)/
     x 3.4494738d-04, 6.6156263d-07, 8.6224638d-22 /
      data fpp(23,19,19,1),fpp(23,19,19,2),fpp(23,19,19,3)/
     x 3.4494738d-04, 7.1237226d-07, 5.9088368d-22 /
      data fpp(23,19,20,1),fpp(23,19,20,2),fpp(23,19,20,3)/
     x 3.4494738d-04, 7.5027175d-07,-7.8823880d-22 /
      data fpp(23,19,21,1),fpp(23,19,21,2),fpp(23,19,21,3)/
     x 3.4494738d-04, 7.5027175d-07, 3.1406644d-22 /
      data fpp(23,19,22,1),fpp(23,19,22,2),fpp(23,19,22,3)/
     x 3.4494738d-04, 7.1237226d-07,-1.4602043d-21 /
      data fpp(23,19,23,1),fpp(23,19,23,2),fpp(23,19,23,3)/
     x 3.4494738d-04, 6.6156263d-07,-9.9267775d-22 /
      data fpp(24, 1, 1,1),fpp(24, 1, 1,2),fpp(24, 1, 1,3)/
     x 1.0246735d-02,-3.7233310d-06, 1.7399176d-20 /
      data fpp(24, 1, 2,1),fpp(24, 1, 2,2),fpp(24, 1, 2,3)/
     x 1.0246735d-02, 5.3974174d-06, 5.3903609d-21 /
      data fpp(24, 1, 3,1),fpp(24, 1, 3,2),fpp(24, 1, 3,3)/
     x 1.0246735d-02, 1.1581307d-05,-9.7997252d-21 /
      data fpp(24, 1, 4,1),fpp(24, 1, 4,2),fpp(24, 1, 4,3)/
     x 1.0246735d-02, 1.1581307d-05, 1.0477025d-20 /
      data fpp(24, 1, 5,1),fpp(24, 1, 5,2),fpp(24, 1, 5,3)/
     x 1.0246735d-02, 5.3974174d-06,-4.1470334d-21 /
      data fpp(24, 1, 6,1),fpp(24, 1, 6,2),fpp(24, 1, 6,3)/
     x 1.0246735d-02,-3.7233310d-06,-3.5593382d-21 /
      data fpp(24, 1, 7,1),fpp(24, 1, 7,2),fpp(24, 1, 7,3)/
     x 1.0246735d-02,-1.4216727d-05,-1.6054518d-20 /
      data fpp(24, 1, 8,1),fpp(24, 1, 8,2),fpp(24, 1, 8,3)/
     x 1.0246735d-02,-2.4495690d-05,-1.1992566d-20 /
      data fpp(24, 1, 9,1),fpp(24, 1, 9,2),fpp(24, 1, 9,3)/
     x 1.0246735d-02,-3.3345001d-05,-2.2606808d-21 /
      data fpp(24, 1,10,1),fpp(24, 1,10,2),fpp(24, 1,10,3)/
     x 1.0246735d-02,-4.0054311d-05, 2.0276442d-20 /
      data fpp(24, 1,11,1),fpp(24, 1,11,2),fpp(24, 1,11,3)/
     x 1.0246735d-02,-4.4270935d-05,-1.8337113d-20 /
      data fpp(24, 1,12,1),fpp(24, 1,12,2),fpp(24, 1,12,3)/
     x 1.0246735d-02,-4.5850726d-05, 1.4506725d-20 /
      data fpp(24, 1,13,1),fpp(24, 1,13,2),fpp(24, 1,13,3)/
     x 1.0246735d-02,-4.4707588d-05, 4.8686522d-21 /
      data fpp(24, 1,14,1),fpp(24, 1,14,2),fpp(24, 1,14,3)/
     x 1.0246735d-02,-4.0823321d-05,-1.0571627d-22 /
      data fpp(24, 1,15,1),fpp(24, 1,15,2),fpp(24, 1,15,3)/
     x 1.0246735d-02,-3.4277706d-05,-2.1055291d-22 /
      data fpp(24, 1,16,1),fpp(24, 1,16,2),fpp(24, 1,16,3)/
     x 1.0246735d-02,-2.5380108d-05,-2.0211111d-20 /
      data fpp(24, 1,17,1),fpp(24, 1,17,2),fpp(24, 1,17,3)/
     x 1.0246735d-02,-1.4867110d-05, 9.8940986d-21 /
      data fpp(24, 1,18,1),fpp(24, 1,18,2),fpp(24, 1,18,3)/
     x 1.0246735d-02,-4.0110534d-06,-1.3564008d-20 /
      data fpp(24, 1,19,1),fpp(24, 1,19,2),fpp(24, 1,19,3)/
     x 1.0246735d-02, 5.4938733d-06,-1.3017701d-20 /
      data fpp(24, 1,20,1),fpp(24, 1,20,2),fpp(24, 1,20,3)/
     x 1.0246735d-02, 1.1982087d-05, 7.8759224d-21 /
      data fpp(24, 1,21,1),fpp(24, 1,21,2),fpp(24, 1,21,3)/
     x 1.0246735d-02, 1.1982087d-05,-1.2967130d-20 /
      data fpp(24, 1,22,1),fpp(24, 1,22,2),fpp(24, 1,22,3)/
     x 1.0246735d-02, 5.4938733d-06, 8.6780887d-21 /
      data fpp(24, 1,23,1),fpp(24, 1,23,2),fpp(24, 1,23,3)/
     x 1.0246735d-02,-4.0110534d-06, 6.0431762d-20 /
      data fpp(24, 2, 1,1),fpp(24, 2, 1,2),fpp(24, 2, 1,3)/
     x 1.0486048d-02,-4.6373381d-06,-9.0885040d-07 /
      data fpp(24, 2, 2,1),fpp(24, 2, 2,2),fpp(24, 2, 2,3)/
     x 1.0948765d-02,-1.5978348d-06,-1.0977992d-06 /
      data fpp(24, 2, 3,1),fpp(24, 2, 3,2),fpp(24, 2, 3,3)/
     x 1.0693665d-02, 5.1238622d-07,-1.5099528d-06 /
      data fpp(24, 2, 4,1),fpp(24, 2, 4,2),fpp(24, 2, 4,3)/
     x 1.0693665d-02, 5.1238622d-07,-1.4972420d-06 /
      data fpp(24, 2, 5,1),fpp(24, 2, 5,2),fpp(24, 2, 5,3)/
     x 1.0948765d-02,-1.5978348d-06,-1.1486424d-06 /
      data fpp(24, 2, 6,1),fpp(24, 2, 6,2),fpp(24, 2, 6,3)/
     x 1.0486048d-02,-4.6373381d-06,-7.1818839d-07 /
      data fpp(24, 2, 7,1),fpp(24, 2, 7,2),fpp(24, 2, 7,3)/
     x 9.6923325d-03,-8.0335460d-06,-1.9660405d-07 /
      data fpp(24, 2, 8,1),fpp(24, 2, 8,2),fpp(24, 2, 8,3)/
     x 8.7931137d-03,-1.1253620d-05, 3.1660460d-07 /
      data fpp(24, 2, 9,1),fpp(24, 2, 9,2),fpp(24, 2, 9,3)/
     x 7.9212016d-03,-1.3932998d-05, 7.7818564d-07 /
      data fpp(24, 2,10,1),fpp(24, 2,10,2),fpp(24, 2,10,3)/
     x 7.2587392d-03,-1.5907377d-05, 1.1246529d-06 /
      data fpp(24, 2,11,1),fpp(24, 2,11,2),fpp(24, 2,11,3)/
     x 6.8232166d-03,-1.7137130d-05, 1.3532030d-06 /
      data fpp(24, 2,12,1),fpp(24, 2,12,2),fpp(24, 2,12,3)/
     x 6.7023602d-03,-1.7633548d-05, 1.4305353d-06 /
      data fpp(24, 2,13,1),fpp(24, 2,13,2),fpp(24, 2,13,3)/
     x 6.8616182d-03,-1.7381823d-05, 1.3666558d-06 /
      data fpp(24, 2,14,1),fpp(24, 2,14,2),fpp(24, 2,14,3)/
     x 7.2607040d-03,-1.6344358d-05, 1.1548415d-06 /
      data fpp(24, 2,15,1),fpp(24, 2,15,2),fpp(24, 2,15,3)/
     x 7.9301934d-03,-1.4475587d-05, 8.0597802d-07 /
      data fpp(24, 2,16,1),fpp(24, 2,16,2),fpp(24, 2,16,3)/
     x 8.8179606d-03,-1.1787784d-05, 3.4924638d-07 /
      data fpp(24, 2,17,1),fpp(24, 2,17,2),fpp(24, 2,17,3)/
     x 9.7425870d-03,-8.4527794d-06,-1.8096354d-07 /
      data fpp(24, 2,18,1),fpp(24, 2,18,2),fpp(24, 2,18,3)/
     x 1.0578957d-02,-4.8618933d-06,-7.1739220d-07 /
      data fpp(24, 2,19,1),fpp(24, 2,19,2),fpp(24, 2,19,3)/
     x 1.0884065d-02,-1.6067465d-06,-1.1674676d-06 /
      data fpp(24, 2,20,1),fpp(24, 2,20,2),fpp(24, 2,20,3)/
     x 1.0840076d-02, 6.7782561d-07,-1.5307372d-06 /
      data fpp(24, 2,21,1),fpp(24, 2,21,2),fpp(24, 2,21,3)/
     x 1.0840076d-02, 6.7782561d-07,-1.5440545d-06 /
      data fpp(24, 2,22,1),fpp(24, 2,22,2),fpp(24, 2,22,3)/
     x 1.0884065d-02,-1.6067465d-06,-1.1141987d-06 /
      data fpp(24, 2,23,1),fpp(24, 2,23,2),fpp(24, 2,23,3)/
     x 1.0578957d-02,-4.8618933d-06,-9.1715064d-07 /
      data fpp(24, 3, 1,1),fpp(24, 3, 1,2),fpp(24, 3, 1,3)/
     x 8.6778397d-03,-9.8993167d-06,-2.3098938d-06 /
      data fpp(24, 3, 2,1),fpp(24, 3, 2,2),fpp(24, 3, 2,3)/
     x 1.0726972d-02,-1.5320078d-05,-2.9407124d-06 /
      data fpp(24, 3, 3,1),fpp(24, 3, 3,2),fpp(24, 3, 3,3)/
     x 1.1492646d-02,-1.8856852d-05,-4.3172565d-06 /
      data fpp(24, 3, 4,1),fpp(24, 3, 4,2),fpp(24, 3, 4,3)/
     x 1.1492646d-02,-1.8856852d-05,-4.2738743d-06 /
      data fpp(24, 3, 5,1),fpp(24, 3, 5,2),fpp(24, 3, 5,3)/
     x 1.0726972d-02,-1.5320078d-05,-3.1142414d-06 /
      data fpp(24, 3, 6,1),fpp(24, 3, 6,2),fpp(24, 3, 6,3)/
     x 8.6778397d-03,-9.8993167d-06,-1.6591600d-06 /
      data fpp(24, 3, 7,1),fpp(24, 3, 7,2),fpp(24, 3, 7,3)/
     x 6.2276751d-03,-3.0950888d-06,-1.0111866d-07 /
      data fpp(24, 3, 8,1),fpp(24, 3, 8,2),fpp(24, 3, 8,3)/
     x 3.9191001d-03, 4.3081709d-06, 1.2056346d-06 /
      data fpp(24, 3, 9,1),fpp(24, 3, 9,2),fpp(24, 3, 9,3)/
     x 1.9527852d-03, 1.1322991d-05, 2.1785802d-06 /
      data fpp(24, 3,10,1),fpp(24, 3,10,2),fpp(24, 3,10,3)/
     x 4.8386468d-04, 1.7019820d-05, 2.8300446d-06 /
      data fpp(24, 3,11,1),fpp(24, 3,11,2),fpp(24, 3,11,3)/
     x-4.2238891d-04, 2.0701454d-05, 3.2172416d-06 /
      data fpp(24, 3,12,1),fpp(24, 3,12,2),fpp(24, 3,12,3)/
     x-7.4683049d-04, 2.1950918d-05, 3.3749892d-06 /
      data fpp(24, 3,13,1),fpp(24, 3,13,2),fpp(24, 3,13,3)/
     x-4.8167274d-04, 2.0616881d-05, 3.2988017d-06 /
      data fpp(24, 3,14,1),fpp(24, 3,14,2),fpp(24, 3,14,3)/
     x 3.7411139d-04, 1.6842753d-05, 2.9778038d-06 /
      data fpp(24, 3,15,1),fpp(24, 3,15,2),fpp(24, 3,15,3)/
     x 1.8107892d-03, 1.1066055d-05, 2.3579829d-06 /
      data fpp(24, 3,16,1),fpp(24, 3,16,2),fpp(24, 3,16,3)/
     x 3.7739776d-03, 3.9992456d-06, 1.3842647d-06 /
      data fpp(24, 3,17,1),fpp(24, 3,17,2),fpp(24, 3,17,3)/
     x 6.1117738d-03,-3.3957720d-06, 2.4958359d-08 /
      data fpp(24, 3,18,1),fpp(24, 3,18,2),fpp(24, 3,18,3)/
     x 8.6282617d-03,-1.0117374d-05,-1.6280981d-06 /
      data fpp(24, 3,19,1),fpp(24, 3,19,2),fpp(24, 3,19,3)/
     x 1.0742549d-02,-1.5392887d-05,-3.1965658d-06 /
      data fpp(24, 3,20,1),fpp(24, 3,20,2),fpp(24, 3,20,3)/
     x 1.1738329d-02,-1.8821390d-05,-4.4736385d-06 /
      data fpp(24, 3,21,1),fpp(24, 3,21,2),fpp(24, 3,21,3)/
     x 1.1738329d-02,-1.8821390d-05,-4.5198015d-06 /
      data fpp(24, 3,22,1),fpp(24, 3,22,2),fpp(24, 3,22,3)/
     x 1.0742549d-02,-1.5392887d-05,-3.0119139d-06 /
      data fpp(24, 3,23,1),fpp(24, 3,23,2),fpp(24, 3,23,3)/
     x 8.6282617d-03,-1.0117374d-05,-2.3205431d-06 /
      data fpp(24, 4, 1,1),fpp(24, 4, 1,2),fpp(24, 4, 1,3)/
     x 5.7376016d-03, 5.6604706d-08,-2.5270389d-06 /
      data fpp(24, 4, 2,1),fpp(24, 4, 2,2),fpp(24, 4, 2,3)/
     x 8.3152219d-03,-5.4978519d-06,-3.4074223d-06 /
      data fpp(24, 4, 3,1),fpp(24, 4, 3,2),fpp(24, 4, 3,3)/
     x 1.0246144d-02,-9.1749791d-06,-5.3292721d-06 /
      data fpp(24, 4, 4,1),fpp(24, 4, 4,2),fpp(24, 4, 4,3)/
     x 1.0246144d-02,-9.1749791d-06,-5.2674726d-06 /
      data fpp(24, 4, 5,1),fpp(24, 4, 5,2),fpp(24, 4, 5,3)/
     x 8.3152219d-03,-5.4978519d-06,-3.6546204d-06 /
      data fpp(24, 4, 6,1),fpp(24, 4, 6,2),fpp(24, 4, 6,3)/
     x 5.7376016d-03, 5.6604706d-08,-1.6000457d-06 /
      data fpp(24, 4, 7,1),fpp(24, 4, 7,2),fpp(24, 4, 7,3)/
     x 3.0037166d-03, 6.1999014d-06, 3.3480308d-07 /
      data fpp(24, 4, 8,1),fpp(24, 4, 8,2),fpp(24, 4, 8,3)/
     x 4.8304645d-04, 1.1750937d-05, 1.7128333d-06 /
      data fpp(24, 4, 9,1),fpp(24, 4, 9,2),fpp(24, 4, 9,3)/
     x-1.5873203d-03, 1.6125032d-05, 2.5758636d-06 /
      data fpp(24, 4,10,1),fpp(24, 4,10,2),fpp(24, 4,10,3)/
     x-3.1264272d-03, 1.9216097d-05, 3.0797123d-06 /
      data fpp(24, 4,11,1),fpp(24, 4,11,2),fpp(24, 4,11,3)/
     x-4.1010366d-03, 2.1073314d-05, 3.3572873d-06 /
      data fpp(24, 4,12,1),fpp(24, 4,12,2),fpp(24, 4,12,3)/
     x-4.4734628d-03, 2.1749876d-05, 3.4951385d-06 /
      data fpp(24, 4,13,1),fpp(24, 4,13,2),fpp(24, 4,13,3)/
     x-4.2234622d-03, 2.1260297d-05, 3.5001585d-06 /
      data fpp(24, 4,14,1),fpp(24, 4,14,2),fpp(24, 4,14,3)/
     x-3.3548211d-03, 1.9551346d-05, 3.3542273d-06 /
      data fpp(24, 4,15,1),fpp(24, 4,15,2),fpp(24, 4,15,3)/
     x-1.8892554d-03, 1.6519366d-05, 2.9249323d-06 /
      data fpp(24, 4,16,1),fpp(24, 4,16,2),fpp(24, 4,16,3)/
     x 1.5626647d-04, 1.2104802d-05, 2.0820434d-06 /
      data fpp(24, 4,17,1),fpp(24, 4,17,2),fpp(24, 4,17,3)/
     x 2.7091820d-03, 6.4118675d-06, 6.2089416d-07 /
      data fpp(24, 4,18,1),fpp(24, 4,18,2),fpp(24, 4,18,3)/
     x 5.5448507d-03, 4.3387320d-08,-1.4876200d-06 /
      data fpp(24, 4,19,1),fpp(24, 4,19,2),fpp(24, 4,19,3)/
     x 8.2642250d-03,-5.7797046d-06,-3.8264141d-06 /
      data fpp(24, 4,20,1),fpp(24, 4,20,2),fpp(24, 4,20,3)/
     x 1.0356227d-02,-9.6382670d-06,-5.6827238d-06 /
      data fpp(24, 4,21,1),fpp(24, 4,21,2),fpp(24, 4,21,3)/
     x 1.0356227d-02,-9.6382670d-06,-5.7526217d-06 /
      data fpp(24, 4,22,1),fpp(24, 4,22,2),fpp(24, 4,22,3)/
     x 8.2642250d-03,-5.7797046d-06,-3.5468224d-06 /
      data fpp(24, 4,23,1),fpp(24, 4,23,2),fpp(24, 4,23,3)/
     x 5.5448507d-03, 4.3387320d-08,-2.5360888d-06 /
      data fpp(24, 5, 1,1),fpp(24, 5, 1,2),fpp(24, 5, 1,3)/
     x 2.9228886d-03, 7.2608978d-06,-1.6112338d-06 /
      data fpp(24, 5, 2,1),fpp(24, 5, 2,2),fpp(24, 5, 2,3)/
     x 4.7298963d-03, 6.4774858d-06,-2.4015324d-06 /
      data fpp(24, 5, 3,1),fpp(24, 5, 3,2),fpp(24, 5, 3,3)/
     x 6.0523550d-03, 5.5467683d-06,-4.1186367d-06 /
      data fpp(24, 5, 4,1),fpp(24, 5, 4,2),fpp(24, 5, 4,3)/
     x 6.0523550d-03, 5.5467683d-06,-4.0773238d-06 /
      data fpp(24, 5, 5,1),fpp(24, 5, 5,2),fpp(24, 5, 5,3)/
     x 4.7298963d-03, 6.4774858d-06,-2.5667840d-06 /
      data fpp(24, 5, 6,1),fpp(24, 5, 6,2),fpp(24, 5, 6,3)/
     x 2.9228886d-03, 7.2608978d-06,-9.9154032d-07 /
      data fpp(24, 5, 7,1),fpp(24, 5, 7,2),fpp(24, 5, 7,3)/
     x 9.9009625d-04, 7.7314832d-06, 3.7094524d-07 /
      data fpp(24, 5, 8,1),fpp(24, 5, 8,2),fpp(24, 5, 8,3)/
     x-7.9984790d-04, 7.9860823d-06, 1.2837594d-06 /
      data fpp(24, 5, 9,1),fpp(24, 5, 9,2),fpp(24, 5, 9,3)/
     x-2.3039336d-03, 8.0628815d-06, 1.8440174d-06 /
      data fpp(24, 5,10,1),fpp(24, 5,10,2),fpp(24, 5,10,3)/
     x-3.4554112d-03, 7.9597930d-06, 2.1521712d-06 /
      data fpp(24, 5,11,1),fpp(24, 5,11,2),fpp(24, 5,11,3)/
     x-4.2038872d-03, 7.7992916d-06, 2.3272977d-06 /
      data fpp(24, 5,12,1),fpp(24, 5,12,2),fpp(24, 5,12,3)/
     x-4.5124382d-03, 7.7675772d-06, 2.4466381d-06 /
      data fpp(24, 5,13,1),fpp(24, 5,13,2),fpp(24, 5,13,3)/
     x-4.3673018d-03, 7.9399292d-06, 2.5021500d-06 /
      data fpp(24, 5,14,1),fpp(24, 5,14,2),fpp(24, 5,14,3)/
     x-3.7612679d-03, 8.2178612d-06, 2.4847618d-06 /
      data fpp(24, 5,15,1),fpp(24, 5,15,2),fpp(24, 5,15,3)/
     x-2.7076164d-03, 8.4044816d-06, 2.2888027d-06 /
      data fpp(24, 5,16,1),fpp(24, 5,16,2),fpp(24, 5,16,3)/
     x-1.2345247d-03, 8.3375461d-06, 1.7640274d-06 /
      data fpp(24, 5,17,1),fpp(24, 5,17,2),fpp(24, 5,17,3)/
     x 6.0082095d-04, 7.9883020d-06, 7.5908777d-07 /
      data fpp(24, 5,18,1),fpp(24, 5,18,2),fpp(24, 5,18,3)/
     x 2.6549858d-03, 7.3338242d-06,-8.3437845d-07 /
      data fpp(24, 5,19,1),fpp(24, 5,19,2),fpp(24, 5,19,3)/
     x 4.6305093d-03, 6.3457056d-06,-2.7555740d-06 /
      data fpp(24, 5,20,1),fpp(24, 5,20,2),fpp(24, 5,20,3)/
     x 6.1016764d-03, 5.2404577d-06,-4.6193257d-06 /
      data fpp(24, 5,21,1),fpp(24, 5,21,2),fpp(24, 5,21,3)/
     x 6.1016764d-03, 5.2404577d-06,-4.6692360d-06 /
      data fpp(24, 5,22,1),fpp(24, 5,22,2),fpp(24, 5,22,3)/
     x 4.6305093d-03, 6.3457056d-06,-2.5559326d-06 /
      data fpp(24, 5,23,1),fpp(24, 5,23,2),fpp(24, 5,23,3)/
     x 2.6549858d-03, 7.3338242d-06,-1.5830337d-06 /
      data fpp(24, 6, 1,1),fpp(24, 6, 1,2),fpp(24, 6, 1,3)/
     x 1.2112714d-03, 5.7598040d-06,-9.2535376d-07 /
      data fpp(24, 6, 2,1),fpp(24, 6, 2,2),fpp(24, 6, 2,3)/
     x 2.1257033d-03, 7.3319086d-06,-1.3077925d-06 /
      data fpp(24, 6, 3,1),fpp(24, 6, 3,2),fpp(24, 6, 3,3)/
     x 2.7614974d-03, 8.5039058d-06,-2.1414763d-06 /
      data fpp(24, 6, 4,1),fpp(24, 6, 4,2),fpp(24, 6, 4,3)/
     x 2.7614974d-03, 8.5039058d-06,-2.1166748d-06 /
      data fpp(24, 6, 5,1),fpp(24, 6, 5,2),fpp(24, 6, 5,3)/
     x 2.1257033d-03, 7.3319086d-06,-1.4069983d-06 /
      data fpp(24, 6, 6,1),fpp(24, 6, 6,2),fpp(24, 6, 6,3)/
     x 1.2112714d-03, 5.7598040d-06,-5.5333186d-07 /
      data fpp(24, 6, 7,1),fpp(24, 6, 7,2),fpp(24, 6, 7,3)/
     x 1.7856376d-04, 3.9861659d-06, 1.5232578d-07 /
      data fpp(24, 6, 8,1),fpp(24, 6, 8,2),fpp(24, 6, 8,3)/
     x-8.3984153d-04, 2.2047341d-06, 5.8002875d-07 /
      data fpp(24, 6, 9,1),fpp(24, 6, 9,2),fpp(24, 6, 9,3)/
     x-1.7342233d-03, 6.8544213d-07, 8.3955920d-07 /
      data fpp(24, 6,10,1),fpp(24, 6,10,2),fpp(24, 6,10,3)/
     x-2.4319755d-03,-3.6126885d-07, 1.0597344d-06 /
      data fpp(24, 6,11,1),fpp(24, 6,11,2),fpp(24, 6,11,3)/
     x-2.9005616d-03,-9.0447991d-07, 1.2695031d-06 /
      data fpp(24, 6,12,1),fpp(24, 6,12,2),fpp(24, 6,12,3)/
     x-3.1230858d-03,-1.0341848d-06, 1.4222532d-06 /
      data fpp(24, 6,13,1),fpp(24, 6,13,2),fpp(24, 6,13,3)/
     x-3.0875552d-03,-7.9601408d-07, 1.4534841d-06 /
      data fpp(24, 6,14,1),fpp(24, 6,14,2),fpp(24, 6,14,3)/
     x-2.7758273d-03,-1.4479133d-07, 1.4098106d-06 /
      data fpp(24, 6,15,1),fpp(24, 6,15,2),fpp(24, 6,15,3)/
     x-2.1806355d-03, 9.7670798d-07, 1.3072737d-06 /
      data fpp(24, 6,16,1),fpp(24, 6,16,2),fpp(24, 6,16,3)/
     x-1.3172432d-03, 2.5330137d-06, 1.0710945d-06 /
      data fpp(24, 6,17,1),fpp(24, 6,17,2),fpp(24, 6,17,3)/
     x-2.4690368d-04, 4.3069246d-06, 5.5234817d-07 /
      data fpp(24, 6,18,1),fpp(24, 6,18,2),fpp(24, 6,18,3)/
     x 9.1343063d-04, 6.0213158d-06,-3.8248719d-07 /
      data fpp(24, 6,19,1),fpp(24, 6,19,2),fpp(24, 6,19,3)/
     x 1.9892316d-03, 7.4748823d-06,-1.5843994d-06 /
      data fpp(24, 6,20,1),fpp(24, 6,20,2),fpp(24, 6,20,3)/
     x 2.7653921d-03, 8.5244363d-06,-2.6639152d-06 /
      data fpp(24, 6,21,1),fpp(24, 6,21,2),fpp(24, 6,21,3)/
     x 2.7653921d-03, 8.5244363d-06,-2.6970547d-06 /
      data fpp(24, 6,22,1),fpp(24, 6,22,2),fpp(24, 6,22,3)/
     x 1.9892316d-03, 7.4748823d-06,-1.4518415d-06 /
      data fpp(24, 6,23,1),fpp(24, 6,23,2),fpp(24, 6,23,3)/
     x 9.1343063d-04, 6.0213158d-06,-8.7957924d-07 /
      data fpp(24, 7, 1,1),fpp(24, 7, 1,2),fpp(24, 7, 1,3)/
     x 4.4691363d-04, 2.4778862d-06,-4.8085242d-07 /
      data fpp(24, 7, 2,1),fpp(24, 7, 2,2),fpp(24, 7, 2,3)/
     x 8.3588120d-04, 4.1068799d-06,-5.6079515d-07 /
      data fpp(24, 7, 3,1),fpp(24, 7, 3,2),fpp(24, 7, 3,3)/
     x 1.0926227d-03, 5.2816085d-06,-7.3796697d-07 /
      data fpp(24, 7, 4,1),fpp(24, 7, 4,2),fpp(24, 7, 4,3)/
     x 1.0926227d-03, 5.2816085d-06,-7.2770151d-07 /
      data fpp(24, 7, 5,1),fpp(24, 7, 5,2),fpp(24, 7, 5,3)/
     x 8.3588120d-04, 4.1068799d-06,-6.0185702d-07 /
      data fpp(24, 7, 6,1),fpp(24, 7, 6,2),fpp(24, 7, 6,3)/
     x 4.4691363d-04, 2.4778862d-06,-3.2687043d-07 /
      data fpp(24, 7, 7,1),fpp(24, 7, 7,2),fpp(24, 7, 7,3)/
     x-1.5701152d-05, 7.4985309d-07,-8.2661278d-08 /
      data fpp(24, 7, 8,1),fpp(24, 7, 8,2),fpp(24, 7, 8,3)/
     x-4.9292675d-04,-7.9701881d-07, 8.7515538d-08 /
      data fpp(24, 7, 9,1),fpp(24, 7, 9,2),fpp(24, 7, 9,3)/
     x-9.3987463d-04,-2.0146500d-06, 2.0659912d-07 /
      data fpp(24, 7,10,1),fpp(24, 7,10,2),fpp(24, 7,10,3)/
     x-1.3208590d-03,-2.8427176d-06, 3.7008796d-07 /
      data fpp(24, 7,11,1),fpp(24, 7,11,2),fpp(24, 7,11,3)/
     x-1.6072495d-03,-3.2933719d-06, 5.6304902d-07 /
      data fpp(24, 7,12,1),fpp(24, 7,12,2),fpp(24, 7,12,3)/
     x-1.7708074d-03,-3.3968378d-06, 7.1971596d-07 /
      data fpp(24, 7,13,1),fpp(24, 7,13,2),fpp(24, 7,13,3)/
     x-1.7908847d-03,-3.1898729d-06, 7.5208715d-07 /
      data fpp(24, 7,14,1),fpp(24, 7,14,2),fpp(24, 7,14,3)/
     x-1.6600526d-03,-2.6586959d-06, 7.0593544d-07 /
      data fpp(24, 7,15,1),fpp(24, 7,15,2),fpp(24, 7,15,3)/
     x-1.3758825d-03,-1.7573135d-06, 6.5417108d-07 /
      data fpp(24, 7,16,1),fpp(24, 7,16,2),fpp(24, 7,16,3)/
     x-9.5674110d-04,-4.9960081d-07, 5.3538023d-07 /
      data fpp(24, 7,17,1),fpp(24, 7,17,2),fpp(24, 7,17,3)/
     x-4.3265581d-04, 1.0519996d-06, 2.7030799d-07 /
      data fpp(24, 7,18,1),fpp(24, 7,18,2),fpp(24, 7,18,3)/
     x 1.3948784d-04, 2.7329127d-06,-2.0061220d-07 /
      data fpp(24, 7,19,1),fpp(24, 7,19,2),fpp(24, 7,19,3)/
     x 6.6809556d-04, 4.2727653d-06,-7.7585917d-07 /
      data fpp(24, 7,20,1),fpp(24, 7,20,2),fpp(24, 7,20,3)/
     x 1.0415330d-03, 5.3497972d-06,-1.1839511d-06 /
      data fpp(24, 7,21,1),fpp(24, 7,21,2),fpp(24, 7,21,3)/
     x 1.0415330d-03, 5.3497972d-06,-1.2022171d-06 /
      data fpp(24, 7,22,1),fpp(24, 7,22,2),fpp(24, 7,22,3)/
     x 6.6809556d-04, 4.2727653d-06,-7.0279511d-07 /
      data fpp(24, 7,23,1),fpp(24, 7,23,2),fpp(24, 7,23,3)/
     x 1.3948784d-04, 2.7329127d-06,-4.7460245d-07 /
      data fpp(24, 8, 1,1),fpp(24, 8, 1,2),fpp(24, 8, 1,3)/
     x 2.2874217d-04, 2.9465103d-07,-2.0956353d-07 /
      data fpp(24, 8, 2,1),fpp(24, 8, 2,2),fpp(24, 8, 2,3)/
     x 3.7302919d-04, 1.2605720d-06,-1.8037293d-07 /
      data fpp(24, 8, 3,1),fpp(24, 8, 3,2),fpp(24, 8, 3,3)/
     x 4.7653626d-04, 2.0196603d-06,-1.1894474d-07 /
      data fpp(24, 8, 4,1),fpp(24, 8, 4,2),fpp(24, 8, 4,3)/
     x 4.7653626d-04, 2.0196603d-06,-1.1697933d-07 /
      data fpp(24, 8, 5,1),fpp(24, 8, 5,2),fpp(24, 8, 5,3)/
     x 3.7302919d-04, 1.2605720d-06,-1.8823458d-07 /
      data fpp(24, 8, 6,1),fpp(24, 8, 6,2),fpp(24, 8, 6,3)/
     x 2.2874217d-04, 2.9465103d-07,-1.8008237d-07 /
      data fpp(24, 8, 7,1),fpp(24, 8, 7,2),fpp(24, 8, 7,3)/
     x 5.0825806d-05,-6.1957831d-07,-1.5343594d-07 /
      data fpp(24, 8, 8,1),fpp(24, 8, 8,2),fpp(24, 8, 8,3)/
     x-1.4666628d-04,-1.3746589d-06,-1.0617385d-07 /
      data fpp(24, 8, 9,1),fpp(24, 8, 9,2),fpp(24, 8, 9,3)/
     x-3.5457957d-04,-1.9688420d-06,-4.5868645d-08 /
      data fpp(24, 8,10,1),fpp(24, 8,10,2),fpp(24, 8,10,3)/
     x-5.5259952d-04,-2.4038606d-06, 4.9648433d-08 /
      data fpp(24, 8,11,1),fpp(24, 8,11,2),fpp(24, 8,11,3)/
     x-7.1892610d-04,-2.6620324d-06, 1.8927491d-07 /
      data fpp(24, 8,12,1),fpp(24, 8,12,2),fpp(24, 8,12,3)/
     x-8.3593408d-04,-2.7304639d-06, 3.0925191d-07 /
      data fpp(24, 8,13,1),fpp(24, 8,13,2),fpp(24, 8,13,3)/
     x-8.8610472d-04,-2.5964944d-06, 3.6171745d-07 /
      data fpp(24, 8,14,1),fpp(24, 8,14,2),fpp(24, 8,14,3)/
     x-8.5742648d-04,-2.2704251d-06, 3.6787829d-07 /
      data fpp(24, 8,15,1),fpp(24, 8,15,2),fpp(24, 8,15,3)/
     x-7.4899424d-04,-1.7774541d-06, 3.4476940d-07 /
      data fpp(24, 8,16,1),fpp(24, 8,16,2),fpp(24, 8,16,3)/
     x-5.6988720d-04,-1.1346104d-06, 2.6904410d-07 /
      data fpp(24, 8,17,1),fpp(24, 8,17,2),fpp(24, 8,17,3)/
     x-3.3901238d-04,-3.6092308d-07, 9.1054188d-08 /
      data fpp(24, 8,18,1),fpp(24, 8,18,2),fpp(24, 8,18,3)/
     x-8.2906548d-05, 5.0103342d-07,-1.5326086d-07 /
      data fpp(24, 8,19,1),fpp(24, 8,19,2),fpp(24, 8,19,3)/
     x 1.5705594d-04, 1.3420565d-06,-3.7801077d-07 /
      data fpp(24, 8,20,1),fpp(24, 8,20,2),fpp(24, 8,20,3)/
     x 3.3005825d-04, 1.9663749d-06,-3.9869608d-07 /
      data fpp(24, 8,21,1),fpp(24, 8,21,2),fpp(24, 8,21,3)/
     x 3.3005825d-04, 1.9663749d-06,-4.0890637d-07 /
      data fpp(24, 8,22,1),fpp(24, 8,22,2),fpp(24, 8,22,3)/
     x 1.5705594d-04, 1.3420565d-06,-3.3716961d-07 /
      data fpp(24, 8,23,1),fpp(24, 8,23,2),fpp(24, 8,23,3)/
     x-8.2906548d-05, 5.0103342d-07,-3.0641520d-07 /
      data fpp(24, 9, 1,1),fpp(24, 9, 1,2),fpp(24, 9, 1,3)/
     x 2.3776204d-04,-4.2249038d-07, 5.0042370d-08 /
      data fpp(24, 9, 2,1),fpp(24, 9, 2,2),fpp(24, 9, 2,3)/
     x 3.3198277d-04, 3.0832283d-08, 1.5415260d-08 /
      data fpp(24, 9, 3,1),fpp(24, 9, 3,2),fpp(24, 9, 3,3)/
     x 4.2210670d-04, 4.5775031d-07,-5.7703410d-08 /
      data fpp(24, 9, 4,1),fpp(24, 9, 4,2),fpp(24, 9, 4,3)/
     x 4.2210670d-04, 4.5775031d-07,-5.9597401d-08 /
      data fpp(24, 9, 5,1),fpp(24, 9, 5,2),fpp(24, 9, 5,3)/
     x 3.3198277d-04, 3.0832283d-08, 2.2991225d-08 /
      data fpp(24, 9, 6,1),fpp(24, 9, 6,2),fpp(24, 9, 6,3)/
     x 2.3776204d-04,-4.2249038d-07, 2.1632499d-08 /
      data fpp(24, 9, 7,1),fpp(24, 9, 7,2),fpp(24, 9, 7,3)/
     x 1.5134418d-04,-7.9753984d-07,-5.5521222d-08 /
      data fpp(24, 9, 8,1),fpp(24, 9, 8,2),fpp(24, 9, 8,3)/
     x 6.3737245d-05,-1.0843456d-06,-1.2354761d-07 /
      data fpp(24, 9, 9,1),fpp(24, 9, 9,2),fpp(24, 9, 9,3)/
     x-2.9843309d-05,-1.2939821d-06,-1.2228833d-07 /
      data fpp(24, 9,10,1),fpp(24, 9,10,2),fpp(24, 9,10,3)/
     x-1.2969742d-04,-1.4558400d-06,-7.7299054d-08 /
      data fpp(24, 9,11,1),fpp(24, 9,11,2),fpp(24, 9,11,3)/
     x-2.2334136d-04,-1.5564986d-06, 1.1484549d-08 /
      data fpp(24, 9,12,1),fpp(24, 9,12,2),fpp(24, 9,12,3)/
     x-3.0456051d-04,-1.5813066d-06, 1.0336086d-07 /
      data fpp(24, 9,13,1),fpp(24, 9,13,2),fpp(24, 9,13,3)/
     x-3.6166650d-04,-1.5141494d-06, 1.6907201d-07 /
      data fpp(24, 9,14,1),fpp(24, 9,14,2),fpp(24, 9,14,3)/
     x-3.8111922d-04,-1.3636038d-06, 2.1035108d-07 /
      data fpp(24, 9,15,1),fpp(24, 9,15,2),fpp(24, 9,15,3)/
     x-3.5871084d-04,-1.1588701d-06, 2.0752366d-07 /
      data fpp(24, 9,16,1),fpp(24, 9,16,2),fpp(24, 9,16,3)/
     x-2.9090863d-04,-8.8995743d-07, 1.5355428d-07 /
      data fpp(24, 9,17,1),fpp(24, 9,17,2),fpp(24, 9,17,3)/
     x-1.8926892d-04,-5.6230730d-07, 1.2259234d-08 /
      data fpp(24, 9,18,1),fpp(24, 9,18,2),fpp(24, 9,18,3)/
     x-6.7679232d-05,-1.9504640d-07,-1.3659121d-07 /
      data fpp(24, 9,19,1),fpp(24, 9,19,2),fpp(24, 9,19,3)/
     x 4.8391557d-05, 1.3300863d-07,-2.2189438d-07 /
      data fpp(24, 9,20,1),fpp(24, 9,20,2),fpp(24, 9,20,3)/
     x 1.3133972d-04, 3.5070321d-07,-5.5831248d-08 /
      data fpp(24, 9,21,1),fpp(24, 9,21,2),fpp(24, 9,21,3)/
     x 1.3133972d-04, 3.5070321d-07,-6.3559063d-08 /
      data fpp(24, 9,22,1),fpp(24, 9,22,2),fpp(24, 9,22,3)/
     x 4.8391557d-05, 1.3300863d-07,-1.9098312d-07 /
      data fpp(24, 9,23,1),fpp(24, 9,23,2),fpp(24, 9,23,3)/
     x-6.7679232d-05,-1.9504640d-07,-2.5250844d-07 /
      data fpp(24,10, 1,1),fpp(24,10, 1,2),fpp(24,10, 1,3)/
     x 2.8329836d-04,-4.2868951d-07, 4.3224995d-07 /
      data fpp(24,10, 2,1),fpp(24,10, 2,2),fpp(24,10, 2,3)/
     x 4.4535809d-04,-1.6590109d-07, 1.8700010d-07 /
      data fpp(24,10, 3,1),fpp(24,10, 3,2),fpp(24,10, 3,3)/
     x 6.1884739d-04, 9.7338455d-08,-3.3425035d-07 /
      data fpp(24,10, 4,1),fpp(24,10, 4,2),fpp(24,10, 4,3)/
     x 6.1884739d-04, 9.7338455d-08,-3.4174900d-07 /
      data fpp(24,10, 5,1),fpp(24,10, 5,2),fpp(24,10, 5,3)/
     x 4.4535809d-04,-1.6590109d-07, 2.1699468d-07 /
      data fpp(24,10, 6,1),fpp(24,10, 6,2),fpp(24,10, 6,3)/
     x 2.8329836d-04,-4.2868951d-07, 3.1977027d-07 /
      data fpp(24,10, 7,1),fpp(24,10, 7,2),fpp(24,10, 7,3)/
     x 1.9055409d-04,-5.8226232d-07, 1.4792426d-07 /
      data fpp(24,10, 8,1),fpp(24,10, 8,2),fpp(24,10, 8,3)/
     x 1.4559217d-04,-6.4795884d-07,-5.9467288d-08 /
      data fpp(24,10, 9,1),fpp(24,10, 9,2),fpp(24,10, 9,3)/
     x 1.0372068d-04,-7.0322947d-07,-1.5005510d-07 /
      data fpp(24,10,10,1),fpp(24,10,10,2),fpp(24,10,10,3)/
     x 5.4093791d-05,-7.6077932d-07,-1.3231230d-07 /
      data fpp(24,10,11,1),fpp(24,10,11,2),fpp(24,10,11,3)/
     x-2.0352941d-06,-8.1397308d-07,-7.6695695d-08 /
      data fpp(24,10,12,1),fpp(24,10,12,2),fpp(24,10,12,3)/
     x-5.6486770d-05,-8.2030967d-07, 7.0950805d-09 /
      data fpp(24,10,13,1),fpp(24,10,13,2),fpp(24,10,13,3)/
     x-1.0289871d-04,-7.7290783d-07, 7.2315373d-08 /
      data fpp(24,10,14,1),fpp(24,10,14,2),fpp(24,10,14,3)/
     x-1.3338228d-04,-6.9915982d-07, 1.1164343d-07 /
      data fpp(24,10,15,1),fpp(24,10,15,2),fpp(24,10,15,3)/
     x-1.3555001d-04,-6.0706554d-07, 1.4111092d-07 /
      data fpp(24,10,16,1),fpp(24,10,16,2),fpp(24,10,16,3)/
     x-1.0969836d-04,-5.1355985d-07, 1.0391290d-07 /
      data fpp(24,10,17,1),fpp(24,10,17,2),fpp(24,10,17,3)/
     x-5.6419096d-05,-3.9584771d-07,-1.0762504d-08 /
      data fpp(24,10,18,1),fpp(24,10,18,2),fpp(24,10,18,3)/
     x 1.2267767d-05,-2.6084783d-07,-1.4486288d-07 /
      data fpp(24,10,19,1),fpp(24,10,19,2),fpp(24,10,19,3)/
     x 8.2165361d-05,-1.1009105d-07,-1.8378598d-07 /
      data fpp(24,10,20,1),fpp(24,10,20,2),fpp(24,10,20,3)/
     x 1.3060939d-04, 1.4812250d-08, 1.0000679d-07 /
      data fpp(24,10,21,1),fpp(24,10,21,2),fpp(24,10,21,3)/
     x 1.3060939d-04, 1.4812250d-08, 9.1872624d-08 /
      data fpp(24,10,22,1),fpp(24,10,22,2),fpp(24,10,22,3)/
     x 8.2165361d-05,-1.1009105d-07,-1.5124932d-07 /
      data fpp(24,10,23,1),fpp(24,10,23,2),fpp(24,10,23,3)/
     x 1.2267767d-05,-2.6084783d-07,-2.6687534d-07 /
      data fpp(24,11, 1,1),fpp(24,11, 1,2),fpp(24,11, 1,3)/
     x 3.0563762d-04,-2.8751565d-08, 9.2051505d-07 /
      data fpp(24,11, 2,1),fpp(24,11, 2,2),fpp(24,11, 2,3)/
     x 6.1945417d-04, 9.2772091d-08, 3.6796990d-07 /
      data fpp(24,11, 3,1),fpp(24,11, 3,2),fpp(24,11, 3,3)/
     x 9.7611600d-04, 1.8489587d-07,-8.0839466d-07 /
      data fpp(24,11, 4,1),fpp(24,11, 4,2),fpp(24,11, 4,3)/
     x 9.7611600d-04, 1.8489587d-07,-8.2180096d-07 /
      data fpp(24,11, 5,1),fpp(24,11, 5,2),fpp(24,11, 5,3)/
     x 6.1945417d-04, 9.2772091d-08, 4.2159511d-07 /
      data fpp(24,11, 6,1),fpp(24,11, 6,2),fpp(24,11, 6,3)/
     x 3.0563762d-04,-2.8751565d-08, 7.1942051d-07 /
      data fpp(24,11, 7,1),fpp(24,11, 7,2),fpp(24,11, 7,3)/
     x 1.5196780d-04,-1.6141087d-07, 4.3872285d-07 /
      data fpp(24,11, 8,1),fpp(24,11, 8,2),fpp(24,11, 8,3)/
     x 1.1561748d-04,-2.6581909d-07, 2.1688101d-08 /
      data fpp(24,11, 9,1),fpp(24,11, 9,2),fpp(24,11, 9,3)/
     x 1.1109729d-04,-3.2709998d-07,-1.7147525d-07 /
      data fpp(24,11,10,1),fpp(24,11,10,2),fpp(24,11,10,3)/
     x 9.7997036d-05,-3.7304270d-07,-1.7578709d-07 /
      data fpp(24,11,11,1),fpp(24,11,11,2),fpp(24,11,11,3)/
     x 6.5277216d-05,-3.8960906d-07,-1.0937638d-07 /
      data fpp(24,11,12,1),fpp(24,11,12,2),fpp(24,11,12,3)/
     x 3.1716107d-05,-3.8145470d-07,-3.4707380d-08 /
      data fpp(24,11,13,1),fpp(24,11,13,2),fpp(24,11,13,3)/
     x 1.7516894d-06,-3.7421926d-07, 8.2059005d-09 /
      data fpp(24,11,14,1),fpp(24,11,14,2),fpp(24,11,14,3)/
     x-2.0494746d-05,-3.4575695d-07, 3.7883778d-08 /
      data fpp(24,11,15,1),fpp(24,11,15,2),fpp(24,11,15,3)/
     x-2.4106410d-05,-3.0686777d-07, 8.0258989d-08 /
      data fpp(24,11,16,1),fpp(24,11,16,2),fpp(24,11,16,3)/
     x-5.0901497d-06,-2.5980318d-07, 8.5080267d-08 /
      data fpp(24,11,17,1),fpp(24,11,17,2),fpp(24,11,17,3)/
     x 3.4653460d-05,-2.1830185d-07,-1.2580057d-08 /
      data fpp(24,11,18,1),fpp(24,11,18,2),fpp(24,11,18,3)/
     x 8.9736763d-05,-1.5356229d-07,-1.3676004d-07 /
      data fpp(24,11,19,1),fpp(24,11,19,2),fpp(24,11,19,3)/
     x 1.4600179d-04,-5.2644445d-08,-1.7237979d-07 /
      data fpp(24,11,20,1),fpp(24,11,20,2),fpp(24,11,20,3)/
     x 1.8350695d-04, 7.0047787d-08, 1.5427921d-07 /
      data fpp(24,11,21,1),fpp(24,11,21,2),fpp(24,11,21,3)/
     x 1.8350695d-04, 7.0047787d-08, 1.4535228d-07 /
      data fpp(24,11,22,1),fpp(24,11,22,2),fpp(24,11,22,3)/
     x 1.4600179d-04,-5.2644445d-08,-1.3667208d-07 /
      data fpp(24,11,23,1),fpp(24,11,23,2),fpp(24,11,23,3)/
     x 8.9736763d-05,-1.5356229d-07,-2.7066396d-07 /
      data fpp(24,12, 1,1),fpp(24,12, 1,2),fpp(24,12, 1,3)/
     x 3.3209624d-04, 4.5969577d-07, 1.3513186d-06 /
      data fpp(24,12, 2,1),fpp(24,12, 2,2),fpp(24,12, 2,3)/
     x 8.2432666d-04, 2.8081273d-07, 5.0036278d-07 /
      data fpp(24,12, 3,1),fpp(24,12, 3,2),fpp(24,12, 3,3)/
     x 1.3538886d-03,-6.2921931d-08,-1.3127697d-06 /
      data fpp(24,12, 4,1),fpp(24,12, 4,2),fpp(24,12, 4,3)/
     x 1.3538886d-03,-6.2921931d-08,-1.3308722d-06 /
      data fpp(24,12, 5,1),fpp(24,12, 5,2),fpp(24,12, 5,3)/
     x 8.2432666d-04, 2.8081273d-07, 5.7277268d-07 /
      data fpp(24,12, 6,1),fpp(24,12, 6,2),fpp(24,12, 6,3)/
     x 3.3209624d-04, 4.5969577d-07, 1.0797815d-06 /
      data fpp(24,12, 7,1),fpp(24,12, 7,2),fpp(24,12, 7,3)/
     x 8.7421376d-05, 3.8190581d-07, 7.4810133d-07 /
      data fpp(24,12, 8,1),fpp(24,12, 8,2),fpp(24,12, 8,3)/
     x 3.3381741d-05, 1.8123521d-07, 1.4581319d-07 /
      data fpp(24,12, 9,1),fpp(24,12, 9,2),fpp(24,12, 9,3)/
     x 5.5845206d-05, 7.6293825d-09,-1.7335409d-07 /
      data fpp(24,12,10,1),fpp(24,12,10,2),fpp(24,12,10,3)/
     x 6.8922345d-05,-7.5049886d-08,-1.9039683d-07 /
      data fpp(24,12,11,1),fpp(24,12,11,2),fpp(24,12,11,3)/
     x 6.1337086d-05,-1.1759070d-07,-1.1505859d-07 /
      data fpp(24,12,12,1),fpp(24,12,12,2),fpp(24,12,12,3)/
     x 4.3283566d-05,-1.6187152d-07,-6.9368812d-08 /
      data fpp(24,12,13,1),fpp(24,12,13,2),fpp(24,12,13,3)/
     x 2.6713337d-05,-1.7821515d-07,-3.3466163d-08 /
      data fpp(24,12,14,1),fpp(24,12,14,2),fpp(24,12,14,3)/
     x 1.5966865d-05,-1.9781237d-07,-2.4766537d-08 /
      data fpp(24,12,15,1),fpp(24,12,15,2),fpp(24,12,15,3)/
     x 2.0856440d-05,-1.9946340d-07, 3.0532310d-08 /
      data fpp(24,12,16,1),fpp(24,12,16,2),fpp(24,12,16,3)/
     x 4.1286946d-05,-1.8722742d-07, 5.8637297d-08 /
      data fpp(24,12,17,1),fpp(24,12,17,2),fpp(24,12,17,3)/
     x 7.7497237d-05,-1.7694489d-07, 4.9185028d-09 /
      data fpp(24,12,18,1),fpp(24,12,18,2),fpp(24,12,18,3)/
     x 1.2655963d-04,-1.7490301d-07,-9.6311308d-08 /
      data fpp(24,12,19,1),fpp(24,12,19,2),fpp(24,12,19,3)/
     x 1.7940001d-04,-1.5333117d-07,-1.2967327d-07 /
      data fpp(24,12,20,1),fpp(24,12,20,2),fpp(24,12,20,3)/
     x 2.1607494d-04,-1.2100340d-07, 1.2300439d-07 /
      data fpp(24,12,21,1),fpp(24,12,21,2),fpp(24,12,21,3)/
     x 2.1607494d-04,-1.2100340d-07, 1.1582346d-07 /
      data fpp(24,12,22,1),fpp(24,12,22,2),fpp(24,12,22,3)/
     x 1.7940001d-04,-1.5333117d-07,-1.0094956d-07 /
      data fpp(24,12,23,1),fpp(24,12,23,2),fpp(24,12,23,3)/
     x 1.2655963d-04,-1.7490301d-07,-2.0402522d-07 /
      data fpp(24,13, 1,1),fpp(24,13, 1,2),fpp(24,13, 1,3)/
     x 4.2993966d-04, 5.7796847d-07, 1.3963083d-06 /
      data fpp(24,13, 2,1),fpp(24,13, 2,2),fpp(24,13, 2,3)/
     x 1.0369136d-03, 6.1976994d-08, 4.5488334d-07 /
      data fpp(24,13, 3,1),fpp(24,13, 3,2),fpp(24,13, 3,3)/
     x 1.6797204d-03,-5.9920815d-07,-1.5538417d-06 /
      data fpp(24,13, 4,1),fpp(24,13, 4,2),fpp(24,13, 4,3)/
     x 1.6797204d-03,-5.9920815d-07,-1.5689166d-06 /
      data fpp(24,13, 5,1),fpp(24,13, 5,2),fpp(24,13, 5,3)/
     x 1.0369136d-03, 6.1976994d-08, 5.1518300d-07 /
      data fpp(24,13, 6,1),fpp(24,13, 6,2),fpp(24,13, 6,3)/
     x 4.2993966d-04, 5.7796847d-07, 1.1701846d-06 /
      data fpp(24,13, 7,1),fpp(24,13, 7,2),fpp(24,13, 7,3)/
     x 9.3884698d-05, 7.1578763d-07, 9.3007863d-07 /
      data fpp(24,13, 8,1),fpp(24,13, 8,2),fpp(24,13, 8,3)/
     x-3.2266844d-06, 5.6687827d-07, 2.9950089d-07 /
      data fpp(24,13, 9,1),fpp(24,13, 9,2),fpp(24,13, 9,3)/
     x 6.4876223d-06, 3.4458245d-07,-8.8082183d-08 /
      data fpp(24,13,10,1),fpp(24,13,10,2),fpp(24,13,10,3)/
     x 2.8608085d-05, 1.6324224d-07,-1.6317216d-07 /
      data fpp(24,13,11,1),fpp(24,13,11,2),fpp(24,13,11,3)/
     x 3.2196220d-05, 4.3971843d-08,-1.2322920d-07 /
      data fpp(24,13,12,1),fpp(24,13,12,2),fpp(24,13,12,3)/
     x 2.5463134d-05,-3.3059218d-08,-7.5911058d-08 /
      data fpp(24,13,13,1),fpp(24,13,13,2),fpp(24,13,13,3)/
     x 1.6010426d-05,-1.1292014d-07,-7.7126570d-08 /
      data fpp(24,13,14,1),fpp(24,13,14,2),fpp(24,13,14,3)/
     x 1.4724484d-05,-1.5299355d-07,-5.9582662d-08 /
      data fpp(24,13,15,1),fpp(24,13,15,2),fpp(24,13,15,3)/
     x 2.6710406d-05,-1.5527865d-07,-8.5427806d-09 /
      data fpp(24,13,16,1),fpp(24,13,16,2),fpp(24,13,16,3)/
     x 5.0370157d-05,-1.5528714d-07, 2.7753785d-08 /
      data fpp(24,13,17,1),fpp(24,13,17,2),fpp(24,13,17,3)/
     x 8.4288927d-05,-1.5991857d-07, 1.1527641d-08 /
      data fpp(24,13,18,1),fpp(24,13,18,2),fpp(24,13,18,3)/
     x 1.2795314d-04,-1.8482567d-07,-3.7864349d-08 /
      data fpp(24,13,19,1),fpp(24,13,19,2),fpp(24,13,19,3)/
     x 1.7180097d-04,-2.4603086d-07,-7.0070245d-08 /
      data fpp(24,13,20,1),fpp(24,13,20,2),fpp(24,13,20,3)/
     x 2.0400121d-04,-3.1203419d-07, 6.6145329d-08 /
      data fpp(24,13,21,1),fpp(24,13,21,2),fpp(24,13,21,3)/
     x 2.0400121d-04,-3.1203419d-07, 6.1599135d-08 /
      data fpp(24,13,22,1),fpp(24,13,22,2),fpp(24,13,22,3)/
     x 1.7180097d-04,-2.4603086d-07,-5.1885467d-08 /
      data fpp(24,13,23,1),fpp(24,13,23,2),fpp(24,13,23,3)/
     x 1.2795314d-04,-1.8482567d-07,-1.0605727d-07 /
      data fpp(24,14, 1,1),fpp(24,14, 1,2),fpp(24,14, 1,3)/
     x 5.8910077d-04, 1.4443036d-07, 9.7506190d-07 /
      data fpp(24,14, 2,1),fpp(24,14, 2,2),fpp(24,14, 2,3)/
     x 1.1630908d-03,-3.2472070d-07, 2.3537620d-07 /
      data fpp(24,14, 3,1),fpp(24,14, 3,2),fpp(24,14, 3,3)/
     x 1.7206715d-03,-7.6224549d-07,-1.3465667d-06 /
      data fpp(24,14, 4,1),fpp(24,14, 4,2),fpp(24,14, 4,3)/
     x 1.7206715d-03,-7.6224549d-07,-1.3519880d-06 /
      data fpp(24,14, 5,1),fpp(24,14, 5,2),fpp(24,14, 5,3)/
     x 1.1630908d-03,-3.2472070d-07, 2.5706143d-07 /
      data fpp(24,14, 6,1),fpp(24,14, 6,2),fpp(24,14, 6,3)/
     x 5.8910077d-04, 1.4443036d-07, 8.9374228d-07 /
      data fpp(24,14, 7,1),fpp(24,14, 7,2),fpp(24,14, 7,3)/
     x 2.1485430d-04, 4.4494365d-07, 8.4196945d-07 /
      data fpp(24,14, 8,1),fpp(24,14, 8,2),fpp(24,14, 8,3)/
     x 5.3615848d-05, 5.1525171d-07, 4.0037991d-07 /
      data fpp(24,14, 9,1),fpp(24,14, 9,2),fpp(24,14, 9,3)/
     x 1.5428010d-05, 4.2004082d-07, 4.6510905d-08 /
      data fpp(24,14,10,1),fpp(24,14,10,2),fpp(24,14,10,3)/
     x 1.1096821d-05, 2.6808091d-07,-8.2423529d-08 /
      data fpp(24,14,11,1),fpp(24,14,11,2),fpp(24,14,11,3)/
     x 1.1684278d-05, 1.2770333d-07,-9.4816789d-08 /
      data fpp(24,14,12,1),fpp(24,14,12,2),fpp(24,14,12,3)/
     x 4.0893293d-06, 1.8108391d-08,-8.4309316d-08 /
      data fpp(24,14,13,1),fpp(24,14,13,2),fpp(24,14,13,3)/
     x-3.5804791d-06,-4.2104301d-08,-8.3945948d-08 /
      data fpp(24,14,14,1),fpp(24,14,14,2),fpp(24,14,14,3)/
     x-1.2164827d-06,-7.8213423d-08,-5.9906890d-08 /
      data fpp(24,14,15,1),fpp(24,14,15,2),fpp(24,14,15,3)/
     x 1.0032475d-05,-1.0942201d-07,-4.8426490d-08 /
      data fpp(24,14,16,1),fpp(24,14,16,2),fpp(24,14,16,3)/
     x 3.4155317d-05,-1.2162402d-07, 7.6128505d-09 /
      data fpp(24,14,17,1),fpp(24,14,17,2),fpp(24,14,17,3)/
     x 6.3243988d-05,-9.5380812d-08,-6.0249120d-09 /
      data fpp(24,14,18,1),fpp(24,14,18,2),fpp(24,14,18,3)/
     x 9.7727335d-05,-9.3794306d-08,-7.5132023d-09 /
      data fpp(24,14,19,1),fpp(24,14,19,2),fpp(24,14,19,3)/
     x 1.3077054d-04,-1.1054540d-07,-1.7922279d-08 /
      data fpp(24,14,20,1),fpp(24,14,20,2),fpp(24,14,20,3)/
     x 1.5416061d-04,-1.4285982d-07, 4.3202317d-08 /
      data fpp(24,14,21,1),fpp(24,14,21,2),fpp(24,14,21,3)/
     x 1.5416061d-04,-1.4285982d-07, 4.1354189d-08 /
      data fpp(24,14,22,1),fpp(24,14,22,2),fpp(24,14,22,3)/
     x 1.3077054d-04,-1.1054540d-07,-1.0529768d-08 /
      data fpp(24,14,23,1),fpp(24,14,23,2),fpp(24,14,23,3)/
     x 9.7727335d-05,-9.3794306d-08,-3.5235116d-08 /
      data fpp(24,15, 1,1),fpp(24,15, 1,2),fpp(24,15, 1,3)/
     x 6.9531784d-04,-4.0568990d-07, 4.1323855d-07 /
      data fpp(24,15, 2,1),fpp(24,15, 2,2),fpp(24,15, 2,3)/
     x 1.1033411d-03,-4.7909418d-07, 1.2522907d-08 /
      data fpp(24,15, 3,1),fpp(24,15, 3,2),fpp(24,15, 3,3)/
     x 1.4379434d-03,-3.9580991d-07,-8.4733017d-07 /
      data fpp(24,15, 4,1),fpp(24,15, 4,2),fpp(24,15, 4,3)/
     x 1.4379434d-03,-3.9580991d-07,-8.4527093d-07 /
      data fpp(24,15, 5,1),fpp(24,15, 5,2),fpp(24,15, 5,3)/
     x 1.1033411d-03,-4.7909418d-07, 4.2859551d-09 /
      data fpp(24,15, 6,1),fpp(24,15, 6,2),fpp(24,15, 6,3)/
     x 6.9531784d-04,-4.0568990d-07, 4.4412711d-07 /
      data fpp(24,15, 7,1),fpp(24,15, 7,2),fpp(24,15, 7,3)/
     x 3.7288235d-04,-1.8556225d-07, 5.3520559d-07 /
      data fpp(24,15, 8,1),fpp(24,15, 8,2),fpp(24,15, 8,3)/
     x 1.8069409d-04, 4.8114872d-08, 3.5505054d-07 /
      data fpp(24,15, 9,1),fpp(24,15, 9,2),fpp(24,15, 9,3)/
     x 8.6392354d-05, 1.7125425d-07, 1.3859226d-07 /
      data fpp(24,15,10,1),fpp(24,15,10,2),fpp(24,15,10,3)/
     x 4.1882253d-05, 1.8043412d-07, 1.4580434d-08 /
      data fpp(24,15,11,1),fpp(24,15,11,2),fpp(24,15,11,3)/
     x 1.4501957d-05, 1.2921485d-07,-4.0913994d-08 /
      data fpp(24,15,12,1),fpp(24,15,12,2),fpp(24,15,12,3)/
     x-5.3026637d-06, 6.8625652d-08,-5.4924457d-08 /
      data fpp(24,15,13,1),fpp(24,15,13,2),fpp(24,15,13,3)/
     x-1.8006172d-05, 1.7337340d-08,-6.3388179d-08 /
      data fpp(24,15,14,1),fpp(24,15,14,2),fpp(24,15,14,3)/
     x-6.6794542d-06,-2.0152757d-08,-5.7522827d-08 /
      data fpp(24,15,15,1),fpp(24,15,15,2),fpp(24,15,15,3)/
     x-1.4349766d-05,-3.1033330d-08,-4.2520514d-08 /
      data fpp(24,15,16,1),fpp(24,15,16,2),fpp(24,15,16,3)/
     x 1.4738008d-06, 5.3783233d-08,-2.4395117d-08 /
      data fpp(24,15,17,1),fpp(24,15,17,2),fpp(24,15,17,3)/
     x 2.3051961d-05,-4.5581803d-09,-1.5899020d-08 /
      data fpp(24,15,18,1),fpp(24,15,18,2),fpp(24,15,18,3)/
     x 4.7411976d-05, 5.0002894d-08,-2.0088054d-09 /
      data fpp(24,15,19,1),fpp(24,15,19,2),fpp(24,15,19,3)/
     x 6.8284117d-05, 1.0021244d-07, 1.1934241d-08 /
      data fpp(24,15,20,1),fpp(24,15,20,2),fpp(24,15,20,3)/
     x 8.2008952d-05, 1.2747349d-07, 4.4271841d-08 /
      data fpp(24,15,21,1),fpp(24,15,21,2),fpp(24,15,21,3)/
     x 8.2008952d-05, 1.2747349d-07, 4.4217356d-08 /
      data fpp(24,15,22,1),fpp(24,15,22,2),fpp(24,15,22,3)/
     x 6.8284117d-05, 1.0021244d-07, 1.2152184d-08 /
      data fpp(24,15,23,1),fpp(24,15,23,2),fpp(24,15,23,3)/
     x 4.7411976d-05, 5.0002894d-08,-2.8260921d-09 /
      data fpp(24,16, 1,1),fpp(24,16, 1,2),fpp(24,16, 1,3)/
     x 6.5942790d-04,-5.3167075d-07, 7.4905167d-08 /
      data fpp(24,16, 2,1),fpp(24,16, 2,2),fpp(24,16, 2,3)/
     x 8.9255382d-04,-3.1490259d-07,-7.1810334d-08 /
      data fpp(24,16, 3,1),fpp(24,16, 3,2),fpp(24,16, 3,3)/
     x 1.0528103d-03,-1.8514869d-08,-3.8766383d-07 /
      data fpp(24,16, 4,1),fpp(24,16, 4,2),fpp(24,16, 4,3)/
     x 1.0528103d-03,-1.8514869d-08,-3.8510334d-07 /
      data fpp(24,16, 5,1),fpp(24,16, 5,2),fpp(24,16, 5,3)/
     x 8.9255382d-04,-3.1490259d-07,-8.2052318d-08 /
      data fpp(24,16, 6,1),fpp(24,16, 6,2),fpp(24,16, 6,3)/
     x 6.5942790d-04,-5.3167075d-07, 1.1331261d-07 /
      data fpp(24,16, 7,1),fpp(24,16, 7,2),fpp(24,16, 7,3)/
     x 4.4639879d-04,-5.3069465d-07, 2.2280188d-07 /
      data fpp(24,16, 8,1),fpp(24,16, 8,2),fpp(24,16, 8,3)/
     x 2.8239265d-04,-3.7171120d-07, 1.9547986d-07 /
      data fpp(24,16, 9,1),fpp(24,16, 9,2),fpp(24,16, 9,3)/
     x 1.6957325d-04,-1.6905784d-07, 1.2927868d-07 /
      data fpp(24,16,10,1),fpp(24,16,10,2),fpp(24,16,10,3)/
     x 9.4695215d-05,-2.3817393d-08, 6.1405407d-08 /
      data fpp(24,16,11,1),fpp(24,16,11,2),fpp(24,16,11,3)/
     x 4.3030788d-05, 4.5437255d-08, 9.0996865d-09 /
      data fpp(24,16,12,1),fpp(24,16,12,2),fpp(24,16,12,3)/
     x 7.4739181d-06, 6.7389000d-08,-1.3804153d-08 /
      data fpp(24,16,13,1),fpp(24,16,13,2),fpp(24,16,13,3)/
     x-1.6835303d-05, 6.2754940d-08,-2.5883073d-08 /
      data fpp(24,16,14,1),fpp(24,16,14,2),fpp(24,16,14,3)/
     x-2.8693628d-05, 5.6824450d-08,-5.6663556d-08 /
      data fpp(24,16,15,1),fpp(24,16,15,2),fpp(24,16,15,3)/
     x-3.2781837d-05, 4.7555326d-08, 6.0537296d-08 /
      data fpp(24,16,16,1),fpp(24,16,16,2),fpp(24,16,16,3)/
     x-5.8528741d-05,-8.7508908d-08,-1.6748563d-07 /
      data fpp(24,16,17,1),fpp(24,16,17,2),fpp(24,16,17,3)/
     x-1.9328161d-05, 7.1613533d-08, 8.1405216d-08 /
      data fpp(24,16,18,1),fpp(24,16,18,2),fpp(24,16,18,3)/
     x-8.7686311d-06, 9.1782729d-08,-2.6135237d-08 /
      data fpp(24,16,19,1),fpp(24,16,19,2),fpp(24,16,19,3)/
     x 2.7434480d-06, 1.1769563d-07, 2.3135730d-08 /
      data fpp(24,16,20,1),fpp(24,16,20,2),fpp(24,16,20,3)/
     x 8.8688179d-06, 1.3696587d-07, 3.5592315d-08 /
      data fpp(24,16,21,1),fpp(24,16,21,2),fpp(24,16,21,3)/
     x 8.8688179d-06, 1.3696587d-07, 3.7655190d-08 /
      data fpp(24,16,22,1),fpp(24,16,22,2),fpp(24,16,22,3)/
     x 2.7434480d-06, 1.1769563d-07, 1.4884232d-08 /
      data fpp(24,16,23,1),fpp(24,16,23,2),fpp(24,16,23,3)/
     x-8.7686311d-06, 9.1782729d-08, 4.8078842d-09 /
      data fpp(24,17, 1,1),fpp(24,17, 1,2),fpp(24,17, 1,3)/
     x 4.8924865d-04,-2.3362711d-07,-1.8064877d-08 /
      data fpp(24,17, 2,1),fpp(24,17, 2,2),fpp(24,17, 2,3)/
     x 5.7654952d-04,-1.2954560d-09,-5.2370245d-08 /
      data fpp(24,17, 3,1),fpp(24,17, 3,2),fpp(24,17, 3,3)/
     x 6.3808745d-04, 2.1786939d-07,-1.2645414d-07 /
      data fpp(24,17, 4,1),fpp(24,17, 4,2),fpp(24,17, 4,3)/
     x 6.3808745d-04, 2.1786939d-07,-1.2545245d-07 /
      data fpp(24,17, 5,1),fpp(24,17, 5,2),fpp(24,17, 5,3)/
     x 5.7654952d-04,-1.2954560d-09,-5.6377001d-08 /
      data fpp(24,17, 6,1),fpp(24,17, 6,2),fpp(24,17, 6,3)/
     x 4.8924865d-04,-2.3362711d-07,-3.0395437d-09 /
      data fpp(24,17, 7,1),fpp(24,17, 7,2),fpp(24,17, 7,3)/
     x 3.8272697d-04,-3.7965913d-07, 4.4535176d-08 /
      data fpp(24,17, 8,1),fpp(24,17, 8,2),fpp(24,17, 8,3)/
     x 2.8540189d-04,-3.9727006d-07, 5.8898841d-08 /
      data fpp(24,17, 9,1),fpp(24,17, 9,2),fpp(24,17, 9,3)/
     x 2.0185709d-04,-3.1702289d-07, 5.5869460d-08 /
      data fpp(24,17,10,1),fpp(24,17,10,2),fpp(24,17,10,3)/
     x 1.3429710d-04,-1.9316455d-07, 4.1623318d-08 /
      data fpp(24,17,11,1),fpp(24,17,11,2),fpp(24,17,11,3)/
     x 7.9652450d-05,-7.0963876d-08, 2.3637269d-08 /
      data fpp(24,17,12,1),fpp(24,17,12,2),fpp(24,17,12,3)/
     x 3.7503022d-05, 2.1818346d-08, 7.8276069d-09 /
      data fpp(24,17,13,1),fpp(24,17,13,2),fpp(24,17,13,3)/
     x 6.8407535d-06, 8.5642901d-08,-9.4769645d-10 /
      data fpp(24,17,14,1),fpp(24,17,14,2),fpp(24,17,14,3)/
     x-1.5775485d-05, 1.1685496d-07,-1.0036821d-08 /
      data fpp(24,17,15,1),fpp(24,17,15,2),fpp(24,17,15,3)/
     x-2.9310620d-05, 1.3481203d-07,-6.9050192d-09 /
      data fpp(24,17,16,1),fpp(24,17,16,2),fpp(24,17,16,3)/
     x-3.7687877d-05, 2.2425240d-07,-1.0343102d-08 /
      data fpp(24,17,17,1),fpp(24,17,17,2),fpp(24,17,17,3)/
     x-4.0930521d-05, 1.3210405d-07, 2.7742802d-10 /
      data fpp(24,17,18,1),fpp(24,17,18,2),fpp(24,17,18,3)/
     x-4.2286575d-05, 1.2286619d-07, 3.2333901d-09 /
      data fpp(24,17,19,1),fpp(24,17,19,2),fpp(24,17,19,3)/
     x-4.1227699d-05, 1.0700502d-07, 1.0789012d-08 /
      data fpp(24,17,20,1),fpp(24,17,20,2),fpp(24,17,20,3)/
     x-3.9284883d-05, 9.2663035d-08, 1.9610564d-08 /
      data fpp(24,17,21,1),fpp(24,17,21,2),fpp(24,17,21,3)/
     x-3.9284883d-05, 9.2663035d-08, 1.9773803d-08 /
      data fpp(24,17,22,1),fpp(24,17,22,2),fpp(24,17,22,3)/
     x-4.1227699d-05, 1.0700502d-07, 1.0136056d-08 /
      data fpp(24,17,23,1),fpp(24,17,23,2),fpp(24,17,23,3)/
     x-4.2286575d-05, 1.2286619d-07, 5.6819718d-09 /
      data fpp(24,18, 1,1),fpp(24,18, 1,2),fpp(24,18, 1,3)/
     x 2.6458438d-04, 2.6179173d-08,-1.1215569d-08 /
      data fpp(24,18, 2,1),fpp(24,18, 2,2),fpp(24,18, 2,3)/
     x 2.8884261d-04, 1.4608442d-07,-1.6068863d-08 /
      data fpp(24,18, 3,1),fpp(24,18, 3,2),fpp(24,18, 3,3)/
     x 3.0375199d-04, 2.4503732d-07,-2.6508980d-08 /
      data fpp(24,18, 4,1),fpp(24,18, 4,2),fpp(24,18, 4,3)/
     x 3.0375199d-04, 2.4503732d-07,-2.6438630d-08 /
      data fpp(24,18, 5,1),fpp(24,18, 5,2),fpp(24,18, 5,3)/
     x 2.8884261d-04, 1.4608442d-07,-1.6350262d-08 /
      data fpp(24,18, 6,1),fpp(24,18, 6,2),fpp(24,18, 6,3)/
     x 2.6458438d-04, 2.6179173d-08,-1.0160322d-08 /
      data fpp(24,18, 7,1),fpp(24,18, 7,2),fpp(24,18, 7,3)/
     x 2.3257966d-04,-7.4668820d-08,-3.0084490d-09 /
      data fpp(24,18, 8,1),fpp(24,18, 8,2),fpp(24,18, 8,3)/
     x 1.9744310d-04,-1.3320855d-07, 4.1941182d-09 /
      data fpp(24,18, 9,1),fpp(24,18, 9,2),fpp(24,18, 9,3)/
     x 1.6122484d-04,-1.4685060d-07, 4.2319764d-09 /
      data fpp(24,18,10,1),fpp(24,18,10,2),fpp(24,18,10,3)/
     x 1.2752683d-04,-1.2152441d-07, 8.8779764d-09 /
      data fpp(24,18,11,1),fpp(24,18,11,2),fpp(24,18,11,3)/
     x 9.6593135d-05,-7.3581750d-08, 8.2561181d-09 /
      data fpp(24,18,12,1),fpp(24,18,12,2),fpp(24,18,12,3)/
     x 6.7404332d-05,-1.6662385d-08, 6.0975511d-09 /
      data fpp(24,18,13,1),fpp(24,18,13,2),fpp(24,18,13,3)/
     x 4.3225933d-05, 3.8673457d-08, 3.3536776d-09 /
      data fpp(24,18,14,1),fpp(24,18,14,2),fpp(24,18,14,3)/
     x 2.3885874d-05, 8.7755727d-08, 4.4877385d-09 /
      data fpp(24,18,15,1),fpp(24,18,15,2),fpp(24,18,15,3)/
     x 8.0446968d-06, 1.2119656d-07, 2.6953682d-09 /
      data fpp(24,18,16,1),fpp(24,18,16,2),fpp(24,18,16,3)/
     x-4.7886342d-06, 1.2649931d-07, 2.7307885d-09 /
      data fpp(24,18,17,1),fpp(24,18,17,2),fpp(24,18,17,3)/
     x-1.4249304d-05, 1.4997027d-07, 4.3814779d-09 /
      data fpp(24,18,18,1),fpp(24,18,18,2),fpp(24,18,18,3)/
     x-2.0826221d-05, 1.4875252d-07, 3.7433000d-09 /
      data fpp(24,18,19,1),fpp(24,18,19,2),fpp(24,18,19,3)/
     x-2.5160166d-05, 1.4428428d-07, 4.6453223d-09 /
      data fpp(24,18,20,1),fpp(24,18,20,2),fpp(24,18,20,3)/
     x-2.7664119d-05, 1.4038199d-07, 7.6754109d-09 /
      data fpp(24,18,21,1),fpp(24,18,21,2),fpp(24,18,21,3)/
     x-2.7664119d-05, 1.4038199d-07, 7.6511062d-09 /
      data fpp(24,18,22,1),fpp(24,18,22,2),fpp(24,18,22,3)/
     x-2.5160166d-05, 1.4428428d-07, 4.7425411d-09 /
      data fpp(24,18,23,1),fpp(24,18,23,2),fpp(24,18,23,3)/
     x-2.0826221d-05, 1.4875252d-07, 3.3787295d-09 /
      data fpp(24,19, 1,1),fpp(24,19, 1,2),fpp(24,19, 1,3)/
     x 8.1017612d-05, 2.9691041d-07,-4.3855309d-22 /
      data fpp(24,19, 2,1),fpp(24,19, 2,2),fpp(24,19, 2,3)/
     x 8.1017612d-05, 3.4095779d-07, 1.5753517d-23 /
      data fpp(24,19, 3,1),fpp(24,19, 3,2),fpp(24,19, 3,3)/
     x 8.1017612d-05, 3.3198134d-07, 3.3785846d-22 /
      data fpp(24,19, 4,1),fpp(24,19, 4,2),fpp(24,19, 4,3)/
     x 8.1017612d-05, 3.3198134d-07,-5.1541201d-22 /
      data fpp(24,19, 5,1),fpp(24,19, 5,2),fpp(24,19, 5,3)/
     x 8.1017612d-05, 3.4095779d-07,-1.3086009d-22 /
      data fpp(24,19, 6,1),fpp(24,19, 6,2),fpp(24,19, 6,3)/
     x 8.1017612d-05, 2.9691041d-07, 6.6841832d-23 /
      data fpp(24,19, 7,1),fpp(24,19, 7,2),fpp(24,19, 7,3)/
     x 8.1017612d-05, 1.8633441d-07, 1.1398888d-21 /
      data fpp(24,19, 8,1),fpp(24,19, 8,2),fpp(24,19, 8,3)/
     x 8.1017612d-05, 4.8104277d-08, 2.1889260d-22 /
      data fpp(24,19, 9,1),fpp(24,19, 9,2),fpp(24,19, 9,3)/
     x 8.1017612d-05,-6.7574698d-08,-4.5379912d-22 /
      data fpp(24,19,10,1),fpp(24,19,10,2),fpp(24,19,10,3)/
     x 8.1017612d-05,-1.1873779d-07,-1.3785834d-21 /
      data fpp(24,19,11,1),fpp(24,19,11,2),fpp(24,19,11,3)/
     x 8.1017612d-05,-1.0870913d-07, 4.6084336d-22 /
      data fpp(24,19,12,1),fpp(24,19,12,2),fpp(24,19,12,3)/
     x 8.1017612d-05,-5.7168808d-08,-7.7210831d-22 /
      data fpp(24,19,13,1),fpp(24,19,13,2),fpp(24,19,13,3)/
     x 8.1017612d-05, 1.1663272d-08,-7.6428788d-22 /
      data fpp(24,19,14,1),fpp(24,19,14,2),fpp(24,19,14,3)/
     x 8.1017612d-05, 8.4122137d-08,-2.2925460d-22 /
      data fpp(24,19,15,1),fpp(24,19,15,2),fpp(24,19,15,3)/
     x 8.1017612d-05, 1.3640172d-07,-2.2745008d-22 /
      data fpp(24,19,16,1),fpp(24,19,16,2),fpp(24,19,16,3)/
     x 8.1017612d-05, 1.4575034d-07, 4.8792810d-22 /
      data fpp(24,19,17,1),fpp(24,19,17,2),fpp(24,19,17,3)/
     x 8.1017612d-05, 1.8001486d-07,-8.2863874d-22 /
      data fpp(24,19,18,1),fpp(24,19,18,2),fpp(24,19,18,3)/
     x 8.1017612d-05, 1.7612374d-07, 1.2766434d-21 /
      data fpp(24,19,19,1),fpp(24,19,19,2),fpp(24,19,19,3)/
     x 8.1017612d-05, 1.6785786d-07, 4.6948273d-22 /
      data fpp(24,19,20,1),fpp(24,19,20,2),fpp(24,19,20,3)/
     x 8.1017612d-05, 1.6180901d-07,-6.7485532d-22 /
      data fpp(24,19,21,1),fpp(24,19,21,2),fpp(24,19,21,3)/
     x 8.1017612d-05, 1.6180901d-07, 5.6275058d-22 /
      data fpp(24,19,22,1),fpp(24,19,22,2),fpp(24,19,22,3)/
     x 8.1017612d-05, 1.6785786d-07,-9.4243075d-22 /
      data fpp(24,19,23,1),fpp(24,19,23,2),fpp(24,19,23,3)/
     x 8.1017612d-05, 1.7612374d-07,-2.2931161d-21 /
      data fpp(25, 1, 1,1),fpp(25, 1, 1,2),fpp(25, 1, 1,3)/
     x 2.5788091d-03,-5.4646303d-07, 1.6463964d-21 /
      data fpp(25, 1, 2,1),fpp(25, 1, 2,2),fpp(25, 1, 2,3)/
     x 2.5788091d-03, 9.6625654d-07,-1.7822685d-21 /
      data fpp(25, 1, 3,1),fpp(25, 1, 3,2),fpp(25, 1, 3,3)/
     x 2.5788091d-03, 1.9312819d-06,-1.2698355d-21 /
      data fpp(25, 1, 4,1),fpp(25, 1, 4,2),fpp(25, 1, 4,3)/
     x 2.5788091d-03, 1.9312819d-06, 8.3326223d-22 /
      data fpp(25, 1, 5,1),fpp(25, 1, 5,2),fpp(25, 1, 5,3)/
     x 2.5788091d-03, 9.6625654d-07,-1.2643440d-22 /
      data fpp(25, 1, 6,1),fpp(25, 1, 6,2),fpp(25, 1, 6,3)/
     x 2.5788091d-03,-5.4646303d-07,-1.3263645d-21 /
      data fpp(25, 1, 7,1),fpp(25, 1, 7,2),fpp(25, 1, 7,3)/
     x 2.5788091d-03,-2.4240334d-06,-2.3226547d-21 /
      data fpp(25, 1, 8,1),fpp(25, 1, 8,2),fpp(25, 1, 8,3)/
     x 2.5788091d-03,-4.3886020d-06, 1.0868733d-23 /
      data fpp(25, 1, 9,1),fpp(25, 1, 9,2),fpp(25, 1, 9,3)/
     x 2.5788091d-03,-6.1656614d-06,-2.9200222d-22 /
      data fpp(25, 1,10,1),fpp(25, 1,10,2),fpp(25, 1,10,3)/
     x 2.5788091d-03,-7.5562834d-06, 6.4504379d-22 /
      data fpp(25, 1,11,1),fpp(25, 1,11,2),fpp(25, 1,11,3)/
     x 2.5788091d-03,-8.4361511d-06,-8.1310109d-23 /
      data fpp(25, 1,12,1),fpp(25, 1,12,2),fpp(25, 1,12,3)/
     x 2.5788091d-03,-8.7534893d-06, 1.6264436d-21 /
      data fpp(25, 1,13,1),fpp(25, 1,13,2),fpp(25, 1,13,3)/
     x 2.5788091d-03,-8.4862630d-06, 1.2973262d-21 /
      data fpp(25, 1,14,1),fpp(25, 1,14,2),fpp(25, 1,14,3)/
     x 2.5788091d-03,-7.6329992d-06, 6.8249754d-23 /
      data fpp(25, 1,15,1),fpp(25, 1,15,2),fpp(25, 1,15,3)/
     x 2.5788091d-03,-6.2324639d-06,-4.0778701d-22 /
      data fpp(25, 1,16,1),fpp(25, 1,16,2),fpp(25, 1,16,3)/
     x 2.5788091d-03,-4.3872483d-06, 1.8614145d-22 /
      data fpp(25, 1,17,1),fpp(25, 1,17,2),fpp(25, 1,17,3)/
     x 2.5788091d-03,-2.3108942d-06, 1.1426719d-21 /
      data fpp(25, 1,18,1),fpp(25, 1,18,2),fpp(25, 1,18,3)/
     x 2.5788091d-03,-2.9954744d-07,-6.1721915d-22 /
      data fpp(25, 1,19,1),fpp(25, 1,19,2),fpp(25, 1,19,3)/
     x 2.5788091d-03, 1.3371119d-06,-1.0011277d-21 /
      data fpp(25, 1,20,1),fpp(25, 1,20,2),fpp(25, 1,20,3)/
     x 2.5788091d-03, 2.4026596d-06, 1.4888485d-21 /
      data fpp(25, 1,21,1),fpp(25, 1,21,2),fpp(25, 1,21,3)/
     x 2.5788091d-03, 2.4026596d-06,-1.0913193d-21 /
      data fpp(25, 1,22,1),fpp(25, 1,22,2),fpp(25, 1,22,3)/
     x 2.5788091d-03, 1.3371119d-06, 2.3757918d-22 /
      data fpp(25, 1,23,1),fpp(25, 1,23,2),fpp(25, 1,23,3)/
     x 2.5788091d-03,-2.9954744d-07, 2.9357141d-21 /
      data fpp(25, 2, 1,1),fpp(25, 2, 1,2),fpp(25, 2, 1,3)/
     x 2.2559127d-03,-7.8307395d-07,-1.7643502d-07 /
      data fpp(25, 2, 2,1),fpp(25, 2, 2,2),fpp(25, 2, 2,3)/
     x 2.4790656d-03,-2.8051308d-07,-2.0862995d-07 /
      data fpp(25, 2, 3,1),fpp(25, 2, 3,2),fpp(25, 2, 3,3)/
     x 2.8205794d-03, 4.8436148d-08,-2.7904516d-07 /
      data fpp(25, 2, 4,1),fpp(25, 2, 4,2),fpp(25, 2, 4,3)/
     x 2.8205794d-03, 4.8436148d-08,-2.7654955d-07 /
      data fpp(25, 2, 5,1),fpp(25, 2, 5,2),fpp(25, 2, 5,3)/
     x 2.4790656d-03,-2.8051308d-07,-2.1861239d-07 /
      data fpp(25, 2, 6,1),fpp(25, 2, 6,2),fpp(25, 2, 6,3)/
     x 2.2559127d-03,-7.8307395d-07,-1.3900089d-07 /
      data fpp(25, 2, 7,1),fpp(25, 2, 7,2),fpp(25, 2, 7,3)/
     x 2.0674043d-03,-1.3889332d-06,-4.7384062d-08 /
      data fpp(25, 2, 8,1),fpp(25, 2, 8,2),fpp(25, 2, 8,3)/
     x 1.8962183d-03,-2.0027960d-06, 5.2537135d-08 /
      data fpp(25, 2, 9,1),fpp(25, 2, 9,2),fpp(25, 2, 9,3)/
     x 1.7539387d-03,-2.5436771d-06, 1.4323552d-07 /
      data fpp(25, 2,10,1),fpp(25, 2,10,2),fpp(25, 2,10,3)/
     x 1.6271325d-03,-2.9604332d-06, 2.1452078d-07 /
      data fpp(25, 2,11,1),fpp(25, 2,11,2),fpp(25, 2,11,3)/
     x 1.5480509d-03,-3.2236978d-06, 2.5868138d-07 /
      data fpp(25, 2,12,1),fpp(25, 2,12,2),fpp(25, 2,12,3)/
     x 1.5112599d-03,-3.3240214d-06, 2.8075372d-07 /
      data fpp(25, 2,13,1),fpp(25, 2,13,2),fpp(25, 2,13,3)/
     x 1.5344731d-03,-3.2554739d-06, 2.6230376d-07 /
      data fpp(25, 2,14,1),fpp(25, 2,14,2),fpp(25, 2,14,3)/
     x 1.6275164d-03,-3.0130016d-06, 2.2403125d-07 /
      data fpp(25, 2,15,1),fpp(25, 2,15,2),fpp(25, 2,15,3)/
     x 1.7543372d-03,-2.5980721d-06, 1.4957126d-07 /
      data fpp(25, 2,16,1),fpp(25, 2,16,2),fpp(25, 2,16,3)/
     x 1.8973496d-03,-2.0285035d-06, 5.9683721d-08 /
      data fpp(25, 2,17,1),fpp(25, 2,17,2),fpp(25, 2,17,3)/
     x 2.0687112d-03,-1.3612116d-06,-4.0306142d-08 /
      data fpp(25, 2,18,1),fpp(25, 2,18,2),fpp(25, 2,18,3)/
     x 2.2526832d-03,-6.8890512d-07,-1.3845915d-07 /
      data fpp(25, 2,19,1),fpp(25, 2,19,2),fpp(25, 2,19,3)/
     x 2.5389816d-03,-1.2222372d-07,-2.2185725d-07 /
      data fpp(25, 2,20,1),fpp(25, 2,20,2),fpp(25, 2,20,3)/
     x 2.8147622d-03, 2.5768080d-07,-2.8211184d-07 /
      data fpp(25, 2,21,1),fpp(25, 2,21,2),fpp(25, 2,21,3)/
     x 2.8147622d-03, 2.5768080d-07,-2.8473586d-07 /
      data fpp(25, 2,22,1),fpp(25, 2,22,2),fpp(25, 2,22,3)/
     x 2.5389816d-03,-1.2222372d-07,-2.1136118d-07 /
      data fpp(25, 2,23,1),fpp(25, 2,23,2),fpp(25, 2,23,3)/
     x 2.2526832d-03,-6.8890512d-07,-1.7781941d-07 /
      data fpp(25, 3, 1,1),fpp(25, 3, 1,2),fpp(25, 3, 1,3)/
     x 2.0018805d-03,-1.9492412d-06,-4.7780396d-07 /
      data fpp(25, 3, 2,1),fpp(25, 3, 2,2),fpp(25, 3, 2,3)/
     x 2.3899940d-03,-2.8682042d-06,-5.6389207d-07 /
      data fpp(25, 3, 3,1),fpp(25, 3, 3,2),fpp(25, 3, 3,3)/
     x 2.8707962d-03,-3.4510265d-06,-7.5262775d-07 /
      data fpp(25, 3, 4,1),fpp(25, 3, 4,2),fpp(25, 3, 4,3)/
     x 2.8707962d-03,-3.4510265d-06,-7.4517072d-07 /
      data fpp(25, 3, 5,1),fpp(25, 3, 5,2),fpp(25, 3, 5,3)/
     x 2.3899940d-03,-2.8682042d-06,-5.9372019d-07 /
      data fpp(25, 3, 6,1),fpp(25, 3, 6,2),fpp(25, 3, 6,3)/
     x 2.0018805d-03,-1.9492412d-06,-3.6594852d-07 /
      data fpp(25, 3, 7,1),fpp(25, 3, 7,2),fpp(25, 3, 7,3)/
     x 1.5849412d-03,-7.5023380d-07,-8.4485734d-08 /
      data fpp(25, 3, 8,1),fpp(25, 3, 8,2),fpp(25, 3, 8,3)/
     x 1.1268994d-03, 6.0378608d-07, 1.8789146d-07 /
      data fpp(25, 3, 9,1),fpp(25, 3, 9,2),fpp(25, 3, 9,3)/
     x 6.9732531d-04, 1.9343699d-06, 4.0091991d-07 /
      data fpp(25, 3,10,1),fpp(25, 3,10,2),fpp(25, 3,10,3)/
     x 3.4188680d-04, 3.0480162d-06, 5.5442889d-07 /
      data fpp(25, 3,11,1),fpp(25, 3,11,2),fpp(25, 3,11,3)/
     x 1.0335391d-04, 3.7749425d-06, 6.3936451d-07 /
      data fpp(25, 3,12,1),fpp(25, 3,12,2),fpp(25, 3,12,3)/
     x 1.5092407d-05, 4.0195749d-06, 6.8011306d-07 /
      data fpp(25, 3,13,1),fpp(25, 3,13,2),fpp(25, 3,13,3)/
     x 8.9323785d-05, 3.7361588d-06, 6.6018326d-07 /
      data fpp(25, 3,14,1),fpp(25, 3,14,2),fpp(25, 3,14,3)/
     x 3.1898012d-04, 2.9750055d-06, 5.9115391d-07 /
      data fpp(25, 3,15,1),fpp(25, 3,15,2),fpp(25, 3,15,3)/
     x 6.7245329d-04, 1.8347524d-06, 4.4920110d-07 /
      data fpp(25, 3,16,1),fpp(25, 3,16,2),fpp(25, 3,16,3)/
     x 1.1061551d-03, 4.8326208d-07, 2.2804170d-07 /
      data fpp(25, 3,17,1),fpp(25, 3,17,2),fpp(25, 3,17,3)/
     x 1.5750903d-03,-8.7825926d-07,-5.3367897d-08 /
      data fpp(25, 3,18,1),fpp(25, 3,18,2),fpp(25, 3,18,3)/
     x 2.0022829d-03,-2.0688321d-06,-3.6857011d-07 /
      data fpp(25, 3,19,1),fpp(25, 3,19,2),fpp(25, 3,19,3)/
     x 2.4068802d-03,-2.9722170d-06,-6.1435165d-07 /
      data fpp(25, 3,20,1),fpp(25, 3,20,2),fpp(25, 3,20,3)/
     x 2.8389716d-03,-3.5593828d-06,-7.9202327d-07 /
      data fpp(25, 3,21,1),fpp(25, 3,21,2),fpp(25, 3,21,3)/
     x 2.8389716d-03,-3.5593828d-06,-7.9975435d-07 /
      data fpp(25, 3,22,1),fpp(25, 3,22,2),fpp(25, 3,22,3)/
     x 2.4068802d-03,-2.9722170d-06,-5.8342733d-07 /
      data fpp(25, 3,23,1),fpp(25, 3,23,2),fpp(25, 3,23,3)/
     x 2.0022829d-03,-2.0688321d-06,-4.8453634d-07 /
      data fpp(25, 4, 1,1),fpp(25, 4, 1,2),fpp(25, 4, 1,3)/
     x 1.3659897d-03, 1.3803870d-07,-5.3902241d-07 /
      data fpp(25, 4, 2,1),fpp(25, 4, 2,2),fpp(25, 4, 2,3)/
     x 1.7912450d-03,-7.6267007d-07,-6.6495518d-07 /
      data fpp(25, 4, 3,1),fpp(25, 4, 3,2),fpp(25, 4, 3,3)/
     x 2.0384644d-03,-1.2923301d-06,-9.4115686d-07 /
      data fpp(25, 4, 4,1),fpp(25, 4, 4,2),fpp(25, 4, 4,3)/
     x 2.0384644d-03,-1.2923301d-06,-9.3005182d-07 /
      data fpp(25, 4, 5,1),fpp(25, 4, 5,2),fpp(25, 4, 5,3)/
     x 1.7912450d-03,-7.6267007d-07,-7.0937533d-07 /
      data fpp(25, 4, 6,1),fpp(25, 4, 6,2),fpp(25, 4, 6,3)/
     x 1.3659897d-03, 1.3803870d-07,-3.7244685d-07 /
      data fpp(25, 4, 7,1),fpp(25, 4, 7,2),fpp(25, 4, 7,3)/
     x 8.3897830d-04, 1.2758684d-06,-8.8372855d-09 /
      data fpp(25, 4, 8,1),fpp(25, 4, 8,2),fpp(25, 4, 8,3)/
     x 2.9618764d-04, 2.4376517d-06, 2.8779599d-07 /
      data fpp(25, 4, 9,1),fpp(25, 4, 9,2),fpp(25, 4, 9,3)/
     x-2.0184731d-04, 3.4161976d-06, 4.8365334d-07 /
      data fpp(25, 4,10,1),fpp(25, 4,10,2),fpp(25, 4,10,3)/
     x-5.9749749d-04, 4.1123682d-06, 6.0359067d-07 /
      data fpp(25, 4,11,1),fpp(25, 4,11,2),fpp(25, 4,11,3)/
     x-8.5085329d-04, 4.5219280d-06, 6.7798399d-07 /
      data fpp(25, 4,12,1),fpp(25, 4,12,2),fpp(25, 4,12,3)/
     x-9.4788509d-04, 4.6637219d-06, 7.0447338d-07 /
      data fpp(25, 4,13,1),fpp(25, 4,13,2),fpp(25, 4,13,3)/
     x-8.8076017d-04, 4.5648388d-06, 7.1612248d-07 /
      data fpp(25, 4,14,1),fpp(25, 4,14,2),fpp(25, 4,14,3)/
     x-6.5068987d-04, 4.1749796d-06, 6.7303671d-07 /
      data fpp(25, 4,15,1),fpp(25, 4,15,2),fpp(25, 4,15,3)/
     x-2.6578048d-04, 3.4730627d-06, 5.7573068d-07 /
      data fpp(25, 4,16,1),fpp(25, 4,16,2),fpp(25, 4,16,3)/
     x 2.3698620d-04, 2.4594551d-06, 3.7204057d-07 /
      data fpp(25, 4,17,1),fpp(25, 4,17,2),fpp(25, 4,17,3)/
     x 8.0141471d-04, 1.2382487d-06, 5.4107033d-08 /
      data fpp(25, 4,18,1),fpp(25, 4,18,2),fpp(25, 4,18,3)/
     x 1.3557560d-03, 1.8233480d-08,-3.6646870d-07 /
      data fpp(25, 4,19,1),fpp(25, 4,19,2),fpp(25, 4,19,3)/
     x 1.8112052d-03,-9.5490835d-07,-7.6623222d-07 /
      data fpp(25, 4,20,1),fpp(25, 4,20,2),fpp(25, 4,20,3)/
     x 2.0693343d-03,-1.5241496d-06,-1.0146024d-06 /
      data fpp(25, 4,21,1),fpp(25, 4,21,2),fpp(25, 4,21,3)/
     x 2.0693343d-03,-1.5241496d-06,-1.0280767d-06 /
      data fpp(25, 4,22,1),fpp(25, 4,22,2),fpp(25, 4,22,3)/
     x 1.8112052d-03,-9.5490835d-07,-7.1233524d-07 /
      data fpp(25, 4,23,1),fpp(25, 4,23,2),fpp(25, 4,23,3)/
     x 1.3557560d-03, 1.8233480d-08,-5.6858238d-07 /
      data fpp(25, 5, 1,1),fpp(25, 5, 1,2),fpp(25, 5, 1,3)/
     x 6.6532773d-04, 1.4750864d-06,-3.2549266d-07 /
      data fpp(25, 5, 2,1),fpp(25, 5, 2,2),fpp(25, 5, 2,3)/
     x 9.9879747d-04, 1.0828845d-06,-4.6801469d-07 /
      data fpp(25, 5, 3,1),fpp(25, 5, 3,2),fpp(25, 5, 3,3)/
     x 1.2116227d-03, 6.8834682d-07,-7.7844860d-07 /
      data fpp(25, 5, 4,1),fpp(25, 5, 4,2),fpp(25, 5, 4,3)/
     x 1.2116227d-03, 6.8834682d-07,-7.6964686d-07 /
      data fpp(25, 5, 5,1),fpp(25, 5, 5,2),fpp(25, 5, 5,3)/
     x 9.9879747d-04, 1.0828845d-06,-5.0322162d-07 /
      data fpp(25, 5, 6,1),fpp(25, 5, 6,2),fpp(25, 5, 6,3)/
     x 6.6532773d-04, 1.4750864d-06,-1.9346667d-07 /
      data fpp(25, 5, 7,1),fpp(25, 5, 7,2),fpp(25, 5, 7,3)/
     x 2.6182537d-04, 1.7127602d-06, 7.7088292d-08 /
      data fpp(25, 5, 8,1),fpp(25, 5, 8,2),fpp(25, 5, 8,3)/
     x-1.5737040d-04, 1.7716071d-06, 2.3311350d-07 /
      data fpp(25, 5, 9,1),fpp(25, 5, 9,2),fpp(25, 5, 9,3)/
     x-5.3101224d-04, 1.7408398d-06, 3.2845771d-07 /
      data fpp(25, 5,10,1),fpp(25, 5,10,2),fpp(25, 5,10,3)/
     x-8.1459268d-04, 1.6945108d-06, 3.9705566d-07 /
      data fpp(25, 5,11,1),fpp(25, 5,11,2),fpp(25, 5,11,3)/
     x-9.9305274d-04, 1.6633457d-06, 4.5931963d-07 /
      data fpp(25, 5,12,1),fpp(25, 5,12,2),fpp(25, 5,12,3)/
     x-1.0673259d-03, 1.6675374d-06, 4.9566580d-07 /
      data fpp(25, 5,13,1),fpp(25, 5,13,2),fpp(25, 5,13,3)/
     x-1.0338771d-03, 1.6984861d-06, 4.9801717d-07 /
      data fpp(25, 5,14,1),fpp(25, 5,14,2),fpp(25, 5,14,3)/
     x-8.8644774d-04, 1.7690760d-06, 4.8226554d-07 /
      data fpp(25, 5,15,1),fpp(25, 5,15,2),fpp(25, 5,15,3)/
     x-6.1827334d-04, 1.8409970d-06, 4.4092068d-07 /
      data fpp(25, 5,16,1),fpp(25, 5,16,2),fpp(25, 5,16,3)/
     x-2.4234732d-04, 1.8829174d-06, 3.4605175d-07 /
      data fpp(25, 5,17,1),fpp(25, 5,17,2),fpp(25, 5,17,3)/
     x 2.0047053d-04, 1.8172645d-06, 1.5487231d-07 /
      data fpp(25, 5,18,1),fpp(25, 5,18,2),fpp(25, 5,18,3)/
     x 6.4278391d-04, 1.5698982d-06,-1.7354100d-07 /
      data fpp(25, 5,19,1),fpp(25, 5,19,2),fpp(25, 5,19,3)/
     x 1.0170870d-03, 1.1518504d-06,-5.7070830d-07 /
      data fpp(25, 5,20,1),fpp(25, 5,20,2),fpp(25, 5,20,3)/
     x 1.2643349d-03, 7.4598116d-07,-8.7362579d-07 /
      data fpp(25, 5,21,1),fpp(25, 5,21,2),fpp(25, 5,21,3)/
     x 1.2643349d-03, 7.4598116d-07,-8.8576847d-07 /
      data fpp(25, 5,22,1),fpp(25, 5,22,2),fpp(25, 5,22,3)/
     x 1.0170870d-03, 1.1518504d-06,-5.2213758d-07 /
      data fpp(25, 5,23,1),fpp(25, 5,23,2),fpp(25, 5,23,3)/
     x 6.4278391d-04, 1.5698982d-06,-3.5568121d-07 /
      data fpp(25, 6, 1,1),fpp(25, 6, 1,2),fpp(25, 6, 1,3)/
     x 2.1485765d-04, 1.1676158d-06,-1.8721630d-07 /
      data fpp(25, 6, 2,1),fpp(25, 6, 2,2),fpp(25, 6, 2,3)/
     x 4.0936573d-04, 1.4591321d-06,-2.4706740d-07 /
      data fpp(25, 6, 3,1),fpp(25, 6, 3,2),fpp(25, 6, 3,3)/
     x 5.3825938d-04, 1.6469428d-06,-3.7851412d-07 /
      data fpp(25, 6, 4,1),fpp(25, 6, 4,2),fpp(25, 6, 4,3)/
     x 5.3825938d-04, 1.6469428d-06,-3.7292395d-07 /
      data fpp(25, 6, 5,1),fpp(25, 6, 5,2),fpp(25, 6, 5,3)/
     x 4.0936573d-04, 1.4591321d-06,-2.6942806d-07 /
      data fpp(25, 6, 6,1),fpp(25, 6, 6,2),fpp(25, 6, 6,3)/
     x 2.1485765d-04, 1.1676158d-06,-1.0336379d-07 /
      data fpp(25, 6, 7,1),fpp(25, 6, 7,2),fpp(25, 6, 7,3)/
     x-1.1251102d-05, 7.9509081d-07, 2.8883229d-08 /
      data fpp(25, 6, 8,1),fpp(25, 6, 8,2),fpp(25, 6, 8,3)/
     x-2.3492934d-04, 4.0591972d-07, 9.5830874d-08 /
      data fpp(25, 6, 9,1),fpp(25, 6, 9,2),fpp(25, 6, 9,3)/
     x-4.3531601d-04, 5.4443134d-08, 1.3379328d-07 /
      data fpp(25, 6,10,1),fpp(25, 6,10,2),fpp(25, 6,10,3)/
     x-6.0210409d-04,-2.1041159d-07, 1.7299602d-07 /
      data fpp(25, 6,11,1),fpp(25, 6,11,2),fpp(25, 6,11,3)/
     x-7.1948061d-04,-3.5731059d-07, 2.4222264d-07 /
      data fpp(25, 6,12,1),fpp(25, 6,12,2),fpp(25, 6,12,3)/
     x-7.7672503d-04,-3.9587149d-07, 2.8011342d-07 /
      data fpp(25, 6,13,1),fpp(25, 6,13,2),fpp(25, 6,13,3)/
     x-7.6253340d-04,-3.2478311d-07, 2.8132369d-07 /
      data fpp(25, 6,14,1),fpp(25, 6,14,2),fpp(25, 6,14,3)/
     x-6.8024563d-04,-1.5728373d-07, 2.5659181d-07 /
      data fpp(25, 6,15,1),fpp(25, 6,15,2),fpp(25, 6,15,3)/
     x-5.3276578d-04, 1.2494925d-07, 2.5230906d-07 /
      data fpp(25, 6,16,1),fpp(25, 6,16,2),fpp(25, 6,16,3)/
     x-3.3223000d-04, 4.8487539d-07, 2.1617194d-07 /
      data fpp(25, 6,17,1),fpp(25, 6,17,2),fpp(25, 6,17,3)/
     x-9.0712810d-05, 8.7669341d-07, 1.1900317d-07 /
      data fpp(25, 6,18,1),fpp(25, 6,18,2),fpp(25, 6,18,3)/
     x 1.6732227d-04, 1.2381738d-06,-8.6184623d-08 /
      data fpp(25, 6,19,1),fpp(25, 6,19,2),fpp(25, 6,19,3)/
     x 4.0270348d-04, 1.5255068d-06,-3.2626468d-07 /
      data fpp(25, 6,20,1),fpp(25, 6,20,2),fpp(25, 6,20,3)/
     x 5.6525046d-04, 1.6962249d-06,-4.8675666d-07 /
      data fpp(25, 6,21,1),fpp(25, 6,21,2),fpp(25, 6,21,3)/
     x 5.6525046d-04, 1.6962249d-06,-4.9459767d-07 /
      data fpp(25, 6,22,1),fpp(25, 6,22,2),fpp(25, 6,22,3)/
     x 4.0270348d-04, 1.5255068d-06,-2.9490067d-07 /
      data fpp(25, 6,23,1),fpp(25, 6,23,2),fpp(25, 6,23,3)/
     x 1.6732227d-04, 1.2381738d-06,-2.0379967d-07 /
      data fpp(25, 7, 1,1),fpp(25, 7, 1,2),fpp(25, 7, 1,3)/
     x 1.8632872d-05, 2.6245037d-07,-1.3341571d-07 /
      data fpp(25, 7, 2,1),fpp(25, 7, 2,2),fpp(25, 7, 2,3)/
     x 9.9999870d-05, 6.5858720d-07,-1.0766858d-07 /
      data fpp(25, 7, 3,1),fpp(25, 7, 3,2),fpp(25, 7, 3,3)/
     x 1.5750394d-04, 9.8588203d-07,-5.3909958d-08 /
      data fpp(25, 7, 4,1),fpp(25, 7, 4,2),fpp(25, 7, 4,3)/
     x 1.5750394d-04, 9.8588203d-07,-5.1435836d-08 /
      data fpp(25, 7, 5,1),fpp(25, 7, 5,2),fpp(25, 7, 5,3)/
     x 9.9999870d-05, 6.5858720d-07,-1.1756507d-07 /
      data fpp(25, 7, 6,1),fpp(25, 7, 6,2),fpp(25, 7, 6,3)/
     x 1.8632872d-05, 2.6245037d-07,-9.6303880d-08 /
      data fpp(25, 7, 7,1),fpp(25, 7, 7,2),fpp(25, 7, 7,3)/
     x-7.0642766d-05,-9.9123455d-08,-4.9219407d-08 /
      data fpp(25, 7, 8,1),fpp(25, 7, 8,2),fpp(25, 7, 8,3)/
     x-1.6202922d-04,-3.9528601d-07,-1.8818490d-08 /
      data fpp(25, 7, 9,1),fpp(25, 7, 9,2),fpp(25, 7, 9,3)/
     x-2.4928382d-04,-6.2061236d-07, 1.0493369d-08 /
      data fpp(25, 7,10,1),fpp(25, 7,10,2),fpp(25, 7,10,3)/
     x-3.2721076d-04,-7.6886448d-07, 4.8845015d-08 /
      data fpp(25, 7,11,1),fpp(25, 7,11,2),fpp(25, 7,11,3)/
     x-3.8802248d-04,-8.4610330d-07, 1.1212657d-07 /
      data fpp(25, 7,12,1),fpp(25, 7,12,2),fpp(25, 7,12,3)/
     x-4.2448307d-04,-8.5805143d-07, 1.5064870d-07 /
      data fpp(25, 7,13,1),fpp(25, 7,13,2),fpp(25, 7,13,3)/
     x-4.3078299d-04,-8.2535364d-07, 1.4327864d-07 /
      data fpp(25, 7,14,1),fpp(25, 7,14,2),fpp(25, 7,14,3)/
     x-4.0155953d-04,-7.1994111d-07, 1.2823676d-07 /
      data fpp(25, 7,15,1),fpp(25, 7,15,2),fpp(25, 7,15,3)/
     x-3.4294149d-04,-5.4679404d-07, 1.2377433d-07 /
      data fpp(25, 7,16,1),fpp(25, 7,16,2),fpp(25, 7,16,3)/
     x-2.5855677d-04,-3.0041894d-07, 1.0266592d-07 /
      data fpp(25, 7,17,1),fpp(25, 7,17,2),fpp(25, 7,17,3)/
     x-1.5483650d-04, 3.9618986d-09, 3.5562006d-08 /
      data fpp(25, 7,18,1),fpp(25, 7,18,2),fpp(25, 7,18,3)/
     x-4.1137229d-05, 3.5940647d-07,-7.6913941d-08 /
      data fpp(25, 7,19,1),fpp(25, 7,19,2),fpp(25, 7,19,3)/
     x 6.8167174d-05, 7.2612245d-07,-1.7790624d-07 /
      data fpp(25, 7,20,1),fpp(25, 7,20,2),fpp(25, 7,20,3)/
     x 1.4981577d-04, 1.0251191d-06,-1.5946109d-07 /
      data fpp(25, 7,21,1),fpp(25, 7,21,2),fpp(25, 7,21,3)/
     x 1.4981577d-04, 1.0251191d-06,-1.6466362d-07 /
      data fpp(25, 7,22,1),fpp(25, 7,22,2),fpp(25, 7,22,3)/
     x 6.8167174d-05, 7.2612245d-07,-1.5709611d-07 /
      data fpp(25, 7,23,1),fpp(25, 7,23,2),fpp(25, 7,23,3)/
     x-4.1137229d-05, 3.5940647d-07,-1.5495195d-07 /
      data fpp(25, 8, 1,1),fpp(25, 8, 1,2),fpp(25, 8, 1,3)/
     x-2.7402339d-05,-2.1941731d-07,-7.4028175d-08 /
      data fpp(25, 8, 2,1),fpp(25, 8, 2,2),fpp(25, 8, 2,3)/
     x 5.0749016d-07,-3.7480864d-08,-2.6943650d-08 /
      data fpp(25, 8, 3,1),fpp(25, 8, 3,2),fpp(25, 8, 3,3)/
     x 1.8511366d-05, 9.7529101d-08, 7.3802775d-08 /
      data fpp(25, 8, 4,1),fpp(25, 8, 4,2),fpp(25, 8, 4,3)/
     x 1.8511366d-05, 9.7529101d-08, 7.4063501d-08 /
      data fpp(25, 8, 5,1),fpp(25, 8, 5,2),fpp(25, 8, 5,3)/
     x 5.0749016d-07,-3.7480864d-08,-2.7986556d-08 /
      data fpp(25, 8, 6,1),fpp(25, 8, 6,2),fpp(25, 8, 6,3)/
     x-2.7402339d-05,-2.1941731d-07,-7.0117276d-08 /
      data fpp(25, 8, 7,1),fpp(25, 8, 7,2),fpp(25, 8, 7,3)/
     x-5.7353788d-05,-3.9259699d-07,-7.5544340d-08 /
      data fpp(25, 8, 8,1),fpp(25, 8, 8,2),fpp(25, 8, 8,3)/
     x-8.9842505d-05,-5.2277566d-07,-7.1705362d-08 /
      data fpp(25, 8, 9,1),fpp(25, 8, 9,2),fpp(25, 8, 9,3)/
     x-1.1788694d-04,-6.0199370d-07,-3.9634210d-08 /
      data fpp(25, 8,10,1),fpp(25, 8,10,2),fpp(25, 8,10,3)/
     x-1.4455877d-04,-6.5013050d-07,-3.7577964d-09 /
      data fpp(25, 8,11,1),fpp(25, 8,11,2),fpp(25, 8,11,3)/
     x-1.6912101d-04,-6.7427620d-07, 4.8665396d-08 /
      data fpp(25, 8,12,1),fpp(25, 8,12,2),fpp(25, 8,12,3)/
     x-1.9108675d-04,-6.8392280d-07, 6.7096212d-08 /
      data fpp(25, 8,13,1),fpp(25, 8,13,2),fpp(25, 8,13,3)/
     x-2.0436876d-04,-6.5780232d-07, 7.8949755d-08 /
      data fpp(25, 8,14,1),fpp(25, 8,14,2),fpp(25, 8,14,3)/
     x-2.0730284d-04,-6.1095183d-07, 6.7104767d-08 /
      data fpp(25, 8,15,1),fpp(25, 8,15,2),fpp(25, 8,15,3)/
     x-1.9518124d-04,-5.3577311d-07, 6.6631176d-08 /
      data fpp(25, 8,16,1),fpp(25, 8,16,2),fpp(25, 8,16,3)/
     x-1.6983112d-04,-4.2919963d-07, 3.8370528d-08 /
      data fpp(25, 8,17,1),fpp(25, 8,17,2),fpp(25, 8,17,3)/
     x-1.3041998d-04,-2.8054100d-07,-1.0113289d-08 /
      data fpp(25, 8,18,1),fpp(25, 8,18,2),fpp(25, 8,18,3)/
     x-8.4889500d-05,-1.0779973d-07,-6.9917372d-08 /
      data fpp(25, 8,19,1),fpp(25, 8,19,2),fpp(25, 8,19,3)/
     x-4.2408990d-05, 5.8003415d-08,-9.4217224d-08 /
      data fpp(25, 8,20,1),fpp(25, 8,20,2),fpp(25, 8,20,3)/
     x-1.2207969d-05, 1.7329865d-07,-9.2137313d-09 /
      data fpp(25, 8,21,1),fpp(25, 8,21,2),fpp(25, 8,21,3)/
     x-1.2207969d-05, 1.7329865d-07,-1.2250194d-08 /
      data fpp(25, 8,22,1),fpp(25, 8,22,2),fpp(25, 8,22,3)/
     x-4.2408990d-05, 5.8003415d-08,-8.2071373d-08 /
      data fpp(25, 8,23,1),fpp(25, 8,23,2),fpp(25, 8,23,3)/
     x-8.4889500d-05,-1.0779973d-07,-1.1546431d-07 /
      data fpp(25, 9, 1,1),fpp(25, 9, 1,2),fpp(25, 9, 1,3)/
     x-2.5296587d-05,-3.0278113d-07,-1.5490285d-08 /
      data fpp(25, 9, 2,1),fpp(25, 9, 2,2),fpp(25, 9, 2,3)/
     x-9.4547612d-06,-2.6266374d-07, 1.8480569d-08 /
      data fpp(25, 9, 3,1),fpp(25, 9, 3,2),fpp(25, 9, 3,3)/
     x 2.3245794d-06,-2.1799843d-07, 9.1568007d-08 /
      data fpp(25, 9, 4,1),fpp(25, 9, 4,2),fpp(25, 9, 4,3)/
     x 2.3245794d-06,-2.1799843d-07, 9.1055693d-08 /
      data fpp(25, 9, 5,1),fpp(25, 9, 5,2),fpp(25, 9, 5,3)/
     x-9.4547612d-06,-2.6266374d-07, 2.0529826d-08 /
      data fpp(25, 9, 6,1),fpp(25, 9, 6,2),fpp(25, 9, 6,3)/
     x-2.5296587d-05,-3.0278113d-07,-2.3174996d-08 /
      data fpp(25, 9, 7,1),fpp(25, 9, 7,2),fpp(25, 9, 7,3)/
     x-3.7074887d-05,-3.2848857d-07,-5.9829843d-08 /
      data fpp(25, 9, 8,1),fpp(25, 9, 8,2),fpp(25, 9, 8,3)/
     x-4.4604611d-05,-3.5161134d-07,-7.3505634d-08 /
      data fpp(25, 9, 9,1),fpp(25, 9, 9,2),fpp(25, 9, 9,3)/
     x-5.0356339d-05,-3.7341284d-07,-6.0147621d-08 /
      data fpp(25, 9,10,1),fpp(25, 9,10,2),fpp(25, 9,10,3)/
     x-5.6847682d-05,-3.9861351d-07,-2.7903881d-08 /
      data fpp(25, 9,11,1),fpp(25, 9,11,2),fpp(25, 9,11,3)/
     x-6.8224458d-05,-4.2879190d-07, 3.7631438d-09 /
      data fpp(25, 9,12,1),fpp(25, 9,12,2),fpp(25, 9,12,3)/
     x-8.1193634d-05,-4.3825737d-07, 2.4851305d-08 /
      data fpp(25, 9,13,1),fpp(25, 9,13,2),fpp(25, 9,13,3)/
     x-9.3809227d-05,-4.2543707d-07, 4.0831635d-08 /
      data fpp(25, 9,14,1),fpp(25, 9,14,2),fpp(25, 9,14,3)/
     x-1.0418549d-04,-3.8825156d-07, 3.9822154d-08 /
      data fpp(25, 9,15,1),fpp(25, 9,15,2),fpp(25, 9,15,3)/
     x-1.0660933d-04,-3.4011352d-07, 3.9879749d-08 /
      data fpp(25, 9,16,1),fpp(25, 9,16,2),fpp(25, 9,16,3)/
     x-1.0252909d-04,-2.9278253d-07, 1.6658849d-08 /
      data fpp(25, 9,17,1),fpp(25, 9,17,2),fpp(25, 9,17,3)/
     x-9.0487469d-05,-2.4379789d-07,-2.8515146d-08 /
      data fpp(25, 9,18,1),fpp(25, 9,18,2),fpp(25, 9,18,3)/
     x-7.5411090d-05,-1.9220756d-07,-6.4598266d-08 /
      data fpp(25, 9,19,1),fpp(25, 9,19,2),fpp(25, 9,19,3)/
     x-6.2269545d-05,-1.5413611d-07,-6.1091792d-08 /
      data fpp(25, 9,20,1),fpp(25, 9,20,2),fpp(25, 9,20,3)/
     x-5.4819534d-05,-1.4031370d-07, 5.0965432d-08 /
      data fpp(25, 9,21,1),fpp(25, 9,21,2),fpp(25, 9,21,3)/
     x-5.4819534d-05,-1.4031370d-07, 4.8649599d-08 /
      data fpp(25, 9,22,1),fpp(25, 9,22,2),fpp(25, 9,22,3)/
     x-6.2269545d-05,-1.5413611d-07,-5.1828457d-08 /
      data fpp(25, 9,23,1),fpp(25, 9,23,2),fpp(25, 9,23,3)/
     x-7.5411090d-05,-1.9220756d-07,-9.9335772d-08 /
      data fpp(25,10, 1,1),fpp(25,10, 1,2),fpp(25,10, 1,3)/
     x-1.4808187d-05,-1.5345817d-07, 5.9276609d-08 /
      data fpp(25,10, 2,1),fpp(25,10, 2,2),fpp(25,10, 2,3)/
     x 1.3718020d-05,-1.1786417d-07, 6.1446781d-08 /
      data fpp(25,10, 3,1),fpp(25,10, 3,2),fpp(25,10, 3,3)/
     x 4.6386357d-05,-8.9535368d-08, 6.6936265d-08 /
      data fpp(25,10, 4,1),fpp(25,10, 4,2),fpp(25,10, 4,3)/
     x 4.6386357d-05,-8.9535368d-08, 6.5467814d-08 /
      data fpp(25,10, 5,1),fpp(25,10, 5,2),fpp(25,10, 5,3)/
     x 1.3718020d-05,-1.1786417d-07, 6.7320585d-08 /
      data fpp(25,10, 6,1),fpp(25,10, 6,2),fpp(25,10, 6,3)/
     x-1.4808187d-05,-1.5345817d-07, 3.7249846d-08 /
      data fpp(25,10, 7,1),fpp(25,10, 7,2),fpp(25,10, 7,3)/
     x-3.0595300d-05,-1.8944872d-07,-3.0319970d-08 /
      data fpp(25,10, 8,1),fpp(25,10, 8,2),fpp(25,10, 8,3)/
     x-3.4611377d-05,-2.0077896d-07,-6.5969968d-08 /
      data fpp(25,10, 9,1),fpp(25,10, 9,2),fpp(25,10, 9,3)/
     x-3.2462112d-05,-2.1435494d-07,-7.7800159d-08 /
      data fpp(25,10,10,1),fpp(25,10,10,2),fpp(25,10,10,3)/
     x-2.9414067d-05,-2.2741546d-07,-5.4829397d-08 /
      data fpp(25,10,11,1),fpp(25,10,11,2),fpp(25,10,11,3)/
     x-3.0030917d-05,-2.3255619d-07,-2.0882255d-08 /
      data fpp(25,10,12,1),fpp(25,10,12,2),fpp(25,10,12,3)/
     x-3.6016959d-05,-2.3304773d-07, 6.3584148d-09 /
      data fpp(25,10,13,1),fpp(25,10,13,2),fpp(25,10,13,3)/
     x-4.5285184d-05,-2.2044941d-07, 2.5448595d-08 /
      data fpp(25,10,14,1),fpp(25,10,14,2),fpp(25,10,14,3)/
     x-5.5468296d-05,-2.0004195d-07, 2.3847203d-08 /
      data fpp(25,10,15,1),fpp(25,10,15,2),fpp(25,10,15,3)/
     x-6.4174082d-05,-1.7977280d-07, 1.7162591d-08 /
      data fpp(25,10,16,1),fpp(25,10,16,2),fpp(25,10,16,3)/
     x-6.5328355d-05,-1.5167024d-07, 3.5024311d-09 /
      data fpp(25,10,17,1),fpp(25,10,17,2),fpp(25,10,17,3)/
     x-6.1809515d-05,-1.2426743d-07,-3.7172316d-08 /
      data fpp(25,10,18,1),fpp(25,10,18,2),fpp(25,10,18,3)/
     x-5.5608907d-05,-9.5370046d-08,-7.0813169d-08 /
      data fpp(25,10,19,1),fpp(25,10,19,2),fpp(25,10,19,3)/
     x-5.3329995d-05,-7.1458980d-08,-5.7575010d-08 /
      data fpp(25,10,20,1),fpp(25,10,20,2),fpp(25,10,20,3)/
     x-5.4203791d-05,-5.0043836d-08, 9.1113209d-08 /
      data fpp(25,10,21,1),fpp(25,10,21,2),fpp(25,10,21,3)/
     x-5.4203791d-05,-5.0043836d-08, 8.8447877d-08 /
      data fpp(25,10,22,1),fpp(25,10,22,2),fpp(25,10,22,3)/
     x-5.3329995d-05,-7.1458980d-08,-4.6913679d-08 /
      data fpp(25,10,23,1),fpp(25,10,23,2),fpp(25,10,23,3)/
     x-5.5608907d-05,-9.5370046d-08,-1.1079316d-07 /
      data fpp(25,11, 1,1),fpp(25,11, 1,2),fpp(25,11, 1,3)/
     x-1.7291087d-05,-1.3861905d-09, 1.4009100d-07 /
      data fpp(25,11, 2,1),fpp(25,11, 2,2),fpp(25,11, 2,3)/
     x 3.2368334d-05, 6.2120412d-08, 1.0031800d-07 /
      data fpp(25,11, 3,1),fpp(25,11, 3,2),fpp(25,11, 3,3)/
     x 8.8881492d-05, 1.1413991d-07, 1.6637002d-08 /
      data fpp(25,11, 4,1),fpp(25,11, 4,2),fpp(25,11, 4,3)/
     x 8.8881492d-05, 1.1413991d-07, 1.3929994d-08 /
      data fpp(25,11, 5,1),fpp(25,11, 5,2),fpp(25,11, 5,3)/
     x 3.2368334d-05, 6.2120412d-08, 1.1114603d-07 /
      data fpp(25,11, 6,1),fpp(25,11, 6,2),fpp(25,11, 6,3)/
     x-1.7291087d-05,-1.3861905d-09, 9.9485870d-08 /
      data fpp(25,11, 7,1),fpp(25,11, 7,2),fpp(25,11, 7,3)/
     x-4.1787588d-05,-4.7716550d-08, 2.4910487d-08 /
      data fpp(25,11, 8,1),fpp(25,11, 8,2),fpp(25,11, 8,3)/
     x-4.5248240d-05,-9.3272809d-08,-6.1127818d-08 /
      data fpp(25,11, 9,1),fpp(25,11, 9,2),fpp(25,11, 9,3)/
     x-3.7657415d-05,-1.1316739d-07,-9.2399213d-08 /
      data fpp(25,11,10,1),fpp(25,11,10,2),fpp(25,11,10,3)/
     x-2.9496639d-05,-1.1372463d-07,-7.3275328d-08 /
      data fpp(25,11,11,1),fpp(25,11,11,2),fpp(25,11,11,3)/
     x-2.0986377d-05,-9.8983342d-08,-4.0499475d-08 /
      data fpp(25,11,12,1),fpp(25,11,12,2),fpp(25,11,12,3)/
     x-1.8703227d-05,-8.1551717d-08, 1.2732274d-09 /
      data fpp(25,11,13,1),fpp(25,11,13,2),fpp(25,11,13,3)/
     x-2.3145671d-05,-7.2765308d-08, 1.7406565d-08 /
      data fpp(25,11,14,1),fpp(25,11,14,2),fpp(25,11,14,3)/
     x-3.1654671d-05,-7.7580664d-08, 7.1005121d-09 /
      data fpp(25,11,15,1),fpp(25,11,15,2),fpp(25,11,15,3)/
     x-4.2683360d-05,-8.0795263d-08, 2.1913863d-09 /
      data fpp(25,11,16,1),fpp(25,11,16,2),fpp(25,11,16,3)/
     x-4.9745964d-05,-8.4536497d-08,-9.8660575d-09 /
      data fpp(25,11,17,1),fpp(25,11,17,2),fpp(25,11,17,3)/
     x-4.9754273d-05,-7.5132399d-08,-4.0727156d-08 /
      data fpp(25,11,18,1),fpp(25,11,18,2),fpp(25,11,18,3)/
     x-4.7223486d-05,-5.6312261d-08,-7.9225317d-08 /
      data fpp(25,11,19,1),fpp(25,11,19,2),fpp(25,11,19,3)/
     x-4.5495418d-05,-1.0027972d-08,-5.6371575d-08 /
      data fpp(25,11,20,1),fpp(25,11,20,2),fpp(25,11,20,3)/
     x-4.7051702d-05, 4.0489048d-08, 1.1271162d-07 /
      data fpp(25,11,21,1),fpp(25,11,21,2),fpp(25,11,21,3)/
     x-4.7051702d-05, 4.0489048d-08, 1.1005093d-07 /
      data fpp(25,11,22,1),fpp(25,11,22,2),fpp(25,11,22,3)/
     x-4.5495418d-05,-1.0027972d-08,-4.5728838d-08 /
      data fpp(25,11,23,1),fpp(25,11,23,2),fpp(25,11,23,3)/
     x-4.7223486d-05,-5.6312261d-08,-1.1913558d-07 /
      data fpp(25,12, 1,1),fpp(25,12, 1,2),fpp(25,12, 1,3)/
     x-2.4013558d-05, 1.2900293d-07, 2.1334184d-07 /
      data fpp(25,12, 2,1),fpp(25,12, 2,2),fpp(25,12, 2,3)/
     x 4.2193974d-05, 1.3338252d-07, 1.2631633d-07 /
      data fpp(25,12, 3,1),fpp(25,12, 3,2),fpp(25,12, 3,3)/
     x 1.2503545d-04, 1.0697575d-07,-5.8607146d-08 /
      data fpp(25,12, 4,1),fpp(25,12, 4,2),fpp(25,12, 4,3)/
     x 1.2503545d-04, 1.0697575d-07,-6.1336725d-08 /
      data fpp(25,12, 5,1),fpp(25,12, 5,2),fpp(25,12, 5,3)/
     x 4.2193974d-05, 1.3338252d-07, 1.3723464d-07 /
      data fpp(25,12, 6,1),fpp(25,12, 6,2),fpp(25,12, 6,3)/
     x-2.4013558d-05, 1.2900293d-07, 1.7239815d-07 /
      data fpp(25,12, 7,1),fpp(25,12, 7,2),fpp(25,12, 7,3)/
     x-5.7701402d-05, 8.0314920d-08, 7.9172771d-08 /
      data fpp(25,12, 8,1),fpp(25,12, 8,2),fpp(25,12, 8,3)/
     x-5.0567684d-05, 3.3870197d-08,-3.3089230d-08 /
      data fpp(25,12, 9,1),fpp(25,12, 9,2),fpp(25,12, 9,3)/
     x-4.9645208d-05,-4.9755023d-09,-9.0815850d-08 /
      data fpp(25,12,10,1),fpp(25,12,10,2),fpp(25,12,10,3)/
     x-3.6568298d-05,-1.9685996d-08,-7.7647371d-08 /
      data fpp(25,12,11,1),fpp(25,12,11,2),fpp(25,12,11,3)/
     x-2.5858295d-05,-2.5510442d-08,-5.4594668d-08 /
      data fpp(25,12,12,1),fpp(25,12,12,2),fpp(25,12,12,3)/
     x-1.7336247d-05,-1.6745403d-08,-9.9739581d-09 /
      data fpp(25,12,13,1),fpp(25,12,13,2),fpp(25,12,13,3)/
     x-1.5902580d-05,-1.6489362d-08,-1.5095000d-09 /
      data fpp(25,12,14,1),fpp(25,12,14,2),fpp(25,12,14,3)/
     x-2.1771659d-05,-1.7635398d-08,-7.9880421d-09 /
      data fpp(25,12,15,1),fpp(25,12,15,2),fpp(25,12,15,3)/
     x-3.2902981d-05,-3.1046144d-08,-1.4538331d-08 /
      data fpp(25,12,16,1),fpp(25,12,16,2),fpp(25,12,16,3)/
     x-4.1335004d-05,-4.4183769d-08,-1.1858632d-08 /
      data fpp(25,12,17,1),fpp(25,12,17,2),fpp(25,12,17,3)/
     x-4.4138458d-05,-6.1202978d-08,-4.0027141d-08 /
      data fpp(25,12,18,1),fpp(25,12,18,2),fpp(25,12,18,3)/
     x-4.1628328d-05,-6.3380910d-08,-6.2032805d-08 /
      data fpp(25,12,19,1),fpp(25,12,19,2),fpp(25,12,19,3)/
     x-3.9603273d-05,-5.6429131d-08,-4.7841640d-08 /
      data fpp(25,12,20,1),fpp(25,12,20,2),fpp(25,12,20,3)/
     x-3.9460261d-05,-3.9912355d-08, 1.0339937d-07 /
      data fpp(25,12,21,1),fpp(25,12,21,2),fpp(25,12,21,3)/
     x-3.9460261d-05,-3.9912355d-08, 1.0072272d-07 /
      data fpp(25,12,22,1),fpp(25,12,22,2),fpp(25,12,22,3)/
     x-3.9603273d-05,-5.6429131d-08,-3.7135063d-08 /
      data fpp(25,12,23,1),fpp(25,12,23,2),fpp(25,12,23,3)/
     x-4.1628328d-05,-6.3380910d-08,-1.0218247d-07 /
      data fpp(25,13, 1,1),fpp(25,13, 1,2),fpp(25,13, 1,3)/
     x-1.9315650d-05, 1.8737446d-07, 2.3140513d-07 /
      data fpp(25,13, 2,1),fpp(25,13, 2,2),fpp(25,13, 2,3)/
     x 5.2151747d-05, 1.1834951d-07, 1.2168974d-07 /
      data fpp(25,13, 3,1),fpp(25,13, 3,2),fpp(25,13, 3,3)/
     x 1.3351284d-04, 2.7957114d-08,-1.1216409d-07 /
      data fpp(25,13, 4,1),fpp(25,13, 4,2),fpp(25,13, 4,3)/
     x 1.3351284d-04, 2.7957114d-08,-1.1435261d-07 /
      data fpp(25,13, 5,1),fpp(25,13, 5,2),fpp(25,13, 5,3)/
     x 5.2151747d-05, 1.1834951d-07, 1.3044385d-07 /
      data fpp(25,13, 6,1),fpp(25,13, 6,2),fpp(25,13, 6,3)/
     x-1.9315650d-05, 1.8737446d-07, 1.9857721d-07 /
      data fpp(25,13, 7,1),fpp(25,13, 7,2),fpp(25,13, 7,3)/
     x-5.8257689d-05, 1.9445687d-07, 1.3124729d-07 /
      data fpp(25,13, 8,1),fpp(25,13, 8,2),fpp(25,13, 8,3)/
     x-6.6587710d-05, 1.4379202d-07, 2.4336069d-09 /
      data fpp(25,13, 9,1),fpp(25,13, 9,2),fpp(25,13, 9,3)/
     x-5.8361628d-05, 9.1069398d-08,-6.2981722d-08 /
      data fpp(25,13,10,1),fpp(25,13,10,2),fpp(25,13,10,3)/
     x-4.6724734d-05, 4.2468620d-08,-7.4506718d-08 /
      data fpp(25,13,11,1),fpp(25,13,11,2),fpp(25,13,11,3)/
     x-3.5117600d-05, 1.5025111d-08,-5.2991407d-08 /
      data fpp(25,13,12,1),fpp(25,13,12,2),fpp(25,13,12,3)/
     x-2.6488856d-05,-1.3466672d-08,-3.1527653d-08 /
      data fpp(25,13,13,1),fpp(25,13,13,2),fpp(25,13,13,3)/
     x-2.2820207d-05,-2.9277246d-08,-2.4897980d-08 /
      data fpp(25,13,14,1),fpp(25,13,14,2),fpp(25,13,14,3)/
     x-2.5808374d-05,-5.5877742d-08,-2.4880428d-08 /
      data fpp(25,13,15,1),fpp(25,13,15,2),fpp(25,13,15,3)/
     x-3.3971093d-05,-4.7020163d-08,-3.1580307d-08 /
      data fpp(25,13,16,1),fpp(25,13,16,2),fpp(25,13,16,3)/
     x-3.9609524d-05,-4.4728427d-08,-1.6798345d-08 /
      data fpp(25,13,17,1),fpp(25,13,17,2),fpp(25,13,17,3)/
     x-4.1248677d-05,-4.0055687d-08,-2.7226313d-08 /
      data fpp(25,13,18,1),fpp(25,13,18,2),fpp(25,13,18,3)/
     x-3.9471699d-05,-5.0164100d-08,-3.6296404d-08 /
      data fpp(25,13,19,1),fpp(25,13,19,2),fpp(25,13,19,3)/
     x-3.5879700d-05,-6.4255502d-08,-2.5588072d-08 /
      data fpp(25,13,20,1),fpp(25,13,20,2),fpp(25,13,20,3)/
     x-3.1692091d-05,-7.2839629d-08, 7.8648693d-08 /
      data fpp(25,13,21,1),fpp(25,13,21,2),fpp(25,13,21,3)/
     x-3.1692091d-05,-7.2839629d-08, 7.6847957d-08 /
      data fpp(25,13,22,1),fpp(25,13,22,2),fpp(25,13,22,3)/
     x-3.5879700d-05,-6.4255502d-08,-1.8385131d-08 /
      data fpp(25,13,23,1),fpp(25,13,23,2),fpp(25,13,23,3)/
     x-3.9471699d-05,-5.0164100d-08,-6.3307435d-08 /
      data fpp(25,14, 1,1),fpp(25,14, 1,2),fpp(25,14, 1,3)/
     x 3.0579463d-06, 1.2949922d-07, 1.8037213d-07 /
      data fpp(25,14, 2,1),fpp(25,14, 2,2),fpp(25,14, 2,3)/
     x 6.9582588d-05, 6.5219451d-08, 8.9255737d-08 /
      data fpp(25,14, 3,1),fpp(25,14, 3,2),fpp(25,14, 3,3)/
     x 1.3962037d-04,-2.8042008d-09,-1.0539508d-07 /
      data fpp(25,14, 4,1),fpp(25,14, 4,2),fpp(25,14, 4,3)/
     x 1.3962037d-04,-2.8042008d-09,-1.0644263d-07 /
      data fpp(25,14, 5,1),fpp(25,14, 5,2),fpp(25,14, 5,3)/
     x 6.9582588d-05, 6.5219451d-08, 9.3445930d-08 /
      data fpp(25,14, 6,1),fpp(25,14, 6,2),fpp(25,14, 6,3)/
     x 3.0579463d-06, 1.2949922d-07, 1.6465891d-07 /
      data fpp(25,14, 7,1),fpp(25,14, 7,2),fpp(25,14, 7,3)/
     x-3.9088869d-05, 1.6185760d-07, 1.2991843d-07 /
      data fpp(25,14, 8,1),fpp(25,14, 8,2),fpp(25,14, 8,3)/
     x-5.5492026d-05, 1.5296172d-07, 4.1667365d-08 /
      data fpp(25,14, 9,1),fpp(25,14, 9,2),fpp(25,14, 9,3)/
     x-5.7646555d-05, 1.0869791d-07,-3.2587892d-08 /
      data fpp(25,14,10,1),fpp(25,14,10,2),fpp(25,14,10,3)/
     x-4.2631630d-05, 5.9811517d-08,-4.9315797d-08 /
      data fpp(25,14,11,1),fpp(25,14,11,2),fpp(25,14,11,3)/
     x-4.4996606d-05, 7.4100000d-09,-5.2148920d-08 /
      data fpp(25,14,12,1),fpp(25,14,12,2),fpp(25,14,12,3)/
     x-3.9459117d-05,-2.5387909d-08,-4.2088523d-08 /
      data fpp(25,14,13,1),fpp(25,14,13,2),fpp(25,14,13,3)/
     x-3.6279384d-05,-4.6401656d-08,-3.7496989d-08 /
      data fpp(25,14,14,1),fpp(25,14,14,2),fpp(25,14,14,3)/
     x-3.8477199d-05, 2.5146368d-08,-4.7923521d-08 /
      data fpp(25,14,15,1),fpp(25,14,15,2),fpp(25,14,15,3)/
     x-4.0892676d-05,-3.2873206d-08,-3.4808925d-08 /
      data fpp(25,14,16,1),fpp(25,14,16,2),fpp(25,14,16,3)/
     x-4.5143890d-05,-1.6902524d-08,-2.2840777d-08 /
      data fpp(25,14,17,1),fpp(25,14,17,2),fpp(25,14,17,3)/
     x-4.5160772d-05,-6.5742718d-09,-2.3827968d-08 /
      data fpp(25,14,18,1),fpp(25,14,18,2),fpp(25,14,18,3)/
     x-4.3249438d-05, 6.0373087d-09,-1.3847352d-08 /
      data fpp(25,14,19,1),fpp(25,14,19,2),fpp(25,14,19,3)/
     x-3.9781796d-05, 7.4511413d-09, 1.2173744d-09 /
      data fpp(25,14,20,1),fpp(25,14,20,2),fpp(25,14,20,3)/
     x-3.6240425d-05,-4.7291298d-09, 5.6977854d-08 /
      data fpp(25,14,21,1),fpp(25,14,21,2),fpp(25,14,21,3)/
     x-3.6240425d-05,-4.7291298d-09, 5.6457751d-08 /
      data fpp(25,14,22,1),fpp(25,14,22,2),fpp(25,14,22,3)/
     x-3.9781796d-05, 7.4511413d-09, 3.2977854d-09 /
      data fpp(25,14,23,1),fpp(25,14,23,2),fpp(25,14,23,3)/
     x-4.3249438d-05, 6.0373087d-09,-2.1648893d-08 /
      data fpp(25,15, 1,1),fpp(25,15, 1,2),fpp(25,15, 1,3)/
     x 3.2206408d-05, 3.2628662d-08, 9.7403337d-08 /
      data fpp(25,15, 2,1),fpp(25,15, 2,2),fpp(25,15, 2,3)/
     x 8.4719977d-05, 2.8772689d-08, 4.9193326d-08 /
      data fpp(25,15, 3,1),fpp(25,15, 3,2),fpp(25,15, 3,3)/
     x 1.4146981d-04, 4.3259689d-08,-5.4176641d-08 /
      data fpp(25,15, 4,1),fpp(25,15, 4,2),fpp(25,15, 4,3)/
     x 1.4146981d-04, 4.3259689d-08,-5.4066739d-08 /
      data fpp(25,15, 5,1),fpp(25,15, 5,2),fpp(25,15, 5,3)/
     x 8.4719977d-05, 2.8772689d-08, 4.8753715d-08 /
      data fpp(25,15, 6,1),fpp(25,15, 6,2),fpp(25,15, 6,3)/
     x 3.2206408d-05, 3.2628662d-08, 9.9051878d-08 /
      data fpp(25,15, 7,1),fpp(25,15, 7,2),fpp(25,15, 7,3)/
     x-7.6795541d-06, 5.2112744d-08, 8.9038774d-08 /
      data fpp(25,15, 8,1),fpp(25,15, 8,2),fpp(25,15, 8,3)/
     x-3.1216373d-05, 7.2361085d-08, 4.8793028d-08 /
      data fpp(25,15, 9,1),fpp(25,15, 9,2),fpp(25,15, 9,3)/
     x-4.3532769d-05, 6.8138958d-08,-2.2108861d-09 /
      data fpp(25,15,10,1),fpp(25,15,10,2),fpp(25,15,10,3)/
     x-4.7414177d-05, 4.2285312d-08,-2.7949484d-08 /
      data fpp(25,15,11,1),fpp(25,15,11,2),fpp(25,15,11,3)/
     x-4.7163368d-05, 1.5334890d-08,-2.9991179d-08 /
      data fpp(25,15,12,1),fpp(25,15,12,2),fpp(25,15,12,3)/
     x-4.7417567d-05,-1.6981693d-08,-6.2085799d-08 /
      data fpp(25,15,13,1),fpp(25,15,13,2),fpp(25,15,13,3)/
     x-4.7568320d-05,-3.7116131d-08, 3.8334374d-08 /
      data fpp(25,15,14,1),fpp(25,15,14,2),fpp(25,15,14,3)/
     x-7.4832897d-05,-1.7070773d-07,-1.6925170d-07 /
      data fpp(25,15,15,1),fpp(25,15,15,2),fpp(25,15,15,3)/
     x-5.2934210d-05,-4.9487014d-08, 3.8672410d-08 /
      data fpp(25,15,16,1),fpp(25,15,16,2),fpp(25,15,16,3)/
     x-5.4528311d-05,-3.1661478d-08,-5.1437943d-08 /
      data fpp(25,15,17,1),fpp(25,15,17,2),fpp(25,15,17,3)/
     x-5.5450276d-05, 3.5277448d-10,-1.2920636d-08 /
      data fpp(25,15,18,1),fpp(25,15,18,2),fpp(25,15,18,3)/
     x-5.4461083d-05, 3.2014865d-08,-4.8795119d-09 /
      data fpp(25,15,19,1),fpp(25,15,19,2),fpp(25,15,19,3)/
     x-5.3233907d-05, 5.2450937d-08, 1.4438684d-08 /
      data fpp(25,15,20,1),fpp(25,15,20,2),fpp(25,15,20,3)/
     x-5.0857083d-05, 6.1756148d-08, 4.3124777d-08 /
      data fpp(25,15,21,1),fpp(25,15,21,2),fpp(25,15,21,3)/
     x-5.0857083d-05, 6.1756148d-08, 4.3406328d-08 /
      data fpp(25,15,22,1),fpp(25,15,22,2),fpp(25,15,22,3)/
     x-5.3233907d-05, 5.2450937d-08, 1.3312478d-08 /
      data fpp(25,15,23,1),fpp(25,15,23,2),fpp(25,15,23,3)/
     x-5.4461083d-05, 3.2014865d-08,-6.5623883d-10 /
      data fpp(25,16, 1,1),fpp(25,16, 1,2),fpp(25,16, 1,3)/
     x 4.3225060d-05,-2.0013868d-08, 4.0974233d-08 /
      data fpp(25,16, 2,1),fpp(25,16, 2,2),fpp(25,16, 2,3)/
     x 7.0891086d-05, 1.1689795d-08, 2.5051534d-08 /
      data fpp(25,16, 3,1),fpp(25,16, 3,2),fpp(25,16, 3,3)/
     x 1.0224099d-04, 5.7765444d-08,-9.1803687d-09 /
      data fpp(25,16, 4,1),fpp(25,16, 4,2),fpp(25,16, 4,3)/
     x 1.0224099d-04, 5.7765444d-08,-8.9846607d-09 /
      data fpp(25,16, 5,1),fpp(25,16, 5,2),fpp(25,16, 5,3)/
     x 7.0891086d-05, 1.1689795d-08, 2.4268702d-08 /
      data fpp(25,16, 6,1),fpp(25,16, 6,2),fpp(25,16, 6,3)/
     x 4.3225060d-05,-2.0013868d-08, 4.3909853d-08 /
      data fpp(25,16, 7,1),fpp(25,16, 7,2),fpp(25,16, 7,3)/
     x 1.4383563d-05,-2.2308570d-08, 4.6091885d-08 /
      data fpp(25,16, 8,1),fpp(25,16, 8,2),fpp(25,16, 8,3)/
     x-9.0556281d-06,-1.0406064d-08, 2.9722608d-08 /
      data fpp(25,16, 9,1),fpp(25,16, 9,2),fpp(25,16, 9,3)/
     x-2.5939938d-05, 8.7462588d-09, 9.0176835d-09 /
      data fpp(25,16,10,1),fpp(25,16,10,2),fpp(25,16,10,3)/
     x-3.6968632d-05, 1.7047236d-08,-5.7933421d-09 /
      data fpp(25,16,11,1),fpp(25,16,11,2),fpp(25,16,11,3)/
     x-4.4029310d-05, 3.2504420d-09,-2.1844315d-08 /
      data fpp(25,16,12,1),fpp(25,16,12,2),fpp(25,16,12,3)/
     x-4.9348200d-05,-8.6853194d-09,-2.6829397d-08 /
      data fpp(25,16,13,1),fpp(25,16,13,2),fpp(25,16,13,3)/
     x-5.3886093d-05,-2.1133821d-08,-3.2838097d-08 /
      data fpp(25,16,14,1),fpp(25,16,14,2),fpp(25,16,14,3)/
     x-5.8043927d-05, 5.1684546d-08,-3.3818214d-08 /
      data fpp(25,16,15,1),fpp(25,16,15,2),fpp(25,16,15,3)/
     x-6.0841293d-05,-2.7178739d-08,-2.9889047d-08 /
      data fpp(25,16,16,1),fpp(25,16,16,2),fpp(25,16,16,3)/
     x-4.7007905d-05,-2.4451562d-08,-2.6625598d-08 /
      data fpp(25,16,17,1),fpp(25,16,17,2),fpp(25,16,17,3)/
     x-6.5575694d-05,-1.2836826d-08,-1.3608560d-08 /
      data fpp(25,16,18,1),fpp(25,16,18,2),fpp(25,16,18,3)/
     x-6.6193456d-05,-2.0967679d-09,-2.9401600d-09 /
      data fpp(25,16,19,1),fpp(25,16,19,2),fpp(25,16,19,3)/
     x-6.6225593d-05, 1.0745110d-08, 1.3369200d-08 /
      data fpp(25,16,20,1),fpp(25,16,20,2),fpp(25,16,20,3)/
     x-6.5866998d-05, 1.5704538d-08, 2.7463358d-08 /
      data fpp(25,16,21,1),fpp(25,16,21,2),fpp(25,16,21,3)/
     x-6.5866998d-05, 1.5704538d-08, 2.7925325d-08 /
      data fpp(25,16,22,1),fpp(25,16,22,2),fpp(25,16,22,3)/
     x-6.6225593d-05, 1.0745110d-08, 1.1521336d-08 /
      data fpp(25,16,23,1),fpp(25,16,23,2),fpp(25,16,23,3)/
     x-6.6193456d-05,-2.0967679d-09, 3.9893321d-09 /
      data fpp(25,17, 1,1),fpp(25,17, 1,2),fpp(25,17, 1,3)/
     x 2.5593594d-05,-1.8573189d-08, 1.9866282d-08 /
      data fpp(25,17, 2,1),fpp(25,17, 2,2),fpp(25,17, 2,3)/
     x 4.1601572d-05, 8.4681322d-09, 1.5767436d-08 /
      data fpp(25,17, 3,1),fpp(25,17, 3,2),fpp(25,17, 3,3)/
     x 5.3069096d-05, 2.5678534d-08, 7.0639757d-09 /
      data fpp(25,17, 4,1),fpp(25,17, 4,2),fpp(25,17, 4,3)/
     x 5.3069096d-05, 2.5678534d-08, 6.9243551d-09 /
      data fpp(25,17, 5,1),fpp(25,17, 5,2),fpp(25,17, 5,3)/
     x 4.1601572d-05, 8.4681322d-09, 1.6325918d-08 /
      data fpp(25,17, 6,1),fpp(25,17, 6,2),fpp(25,17, 6,3)/
     x 2.5593594d-05,-1.8573189d-08, 1.7771973d-08 /
      data fpp(25,17, 7,1),fpp(25,17, 7,2),fpp(25,17, 7,3)/
     x 1.0576997d-05,-3.4878462d-08, 1.4586190d-08 /
      data fpp(25,17, 8,1),fpp(25,17, 8,2),fpp(25,17, 8,3)/
     x-3.7545684d-06,-3.0736829d-08, 1.3883268d-08 /
      data fpp(25,17, 9,1),fpp(25,17, 9,2),fpp(25,17, 9,3)/
     x-1.7799828d-05,-1.9123993d-08, 7.8807389d-09 /
      data fpp(25,17,10,1),fpp(25,17,10,2),fpp(25,17,10,3)/
     x-2.9821508d-05,-8.4742559d-09,-3.4062234d-09 /
      data fpp(25,17,11,1),fpp(25,17,11,2),fpp(25,17,11,3)/
     x-3.8902790d-05, 7.6633425d-09,-6.2558451d-09 /
      data fpp(25,17,12,1),fpp(25,17,12,2),fpp(25,17,12,3)/
     x-4.6451478d-05, 9.7229706d-09,-1.3570396d-08 /
      data fpp(25,17,13,1),fpp(25,17,13,2),fpp(25,17,13,3)/
     x-5.3545137d-05, 7.6514132d-09,-1.7462571d-08 /
      data fpp(25,17,14,1),fpp(25,17,14,2),fpp(25,17,14,3)/
     x-5.8404250d-05,-1.8030455d-08,-1.8579320d-08 /
      data fpp(25,17,15,1),fpp(25,17,15,2),fpp(25,17,15,3)/
     x-6.2675393d-05,-3.7980319d-09,-1.6220147d-08 /
      data fpp(25,17,16,1),fpp(25,17,16,2),fpp(25,17,16,3)/
     x-6.5832444d-05,-1.4532272d-08,-1.2540090d-08 /
      data fpp(25,17,17,1),fpp(25,17,17,2),fpp(25,17,17,3)/
     x-6.9011817d-05,-3.3005470d-08,-1.1619493d-08 /
      data fpp(25,17,18,1),fpp(25,17,18,2),fpp(25,17,18,3)/
     x-7.0281625d-05,-4.7627793d-08,-9.8193688d-10 /
      data fpp(25,17,19,1),fpp(25,17,19,2),fpp(25,17,19,3)/
     x-7.1654904d-05,-6.5431376d-08, 3.5472409d-09 /
      data fpp(25,17,20,1),fpp(25,17,20,2),fpp(25,17,20,3)/
     x-7.2353245d-05,-7.6574299d-08, 1.0792973d-08 /
      data fpp(25,17,21,1),fpp(25,17,21,2),fpp(25,17,21,3)/
     x-7.2353245d-05,-7.6574299d-08, 1.0847459d-08 /
      data fpp(25,17,22,1),fpp(25,17,22,2),fpp(25,17,22,3)/
     x-7.1654904d-05,-6.5431376d-08, 3.3292973d-09 /
      data fpp(25,17,23,1),fpp(25,17,23,2),fpp(25,17,23,3)/
     x-7.0281625d-05,-4.7627793d-08,-1.6464867d-10 /
      data fpp(25,18, 1,1),fpp(25,18, 1,2),fpp(25,18, 1,3)/
     x-7.2614328d-06,-3.1693374d-08, 3.3698143d-09 /
      data fpp(25,18, 2,1),fpp(25,18, 2,2),fpp(25,18, 2,3)/
     x-2.6868475d-06,-2.7562323d-08, 4.7603715d-09 /
      data fpp(25,18, 3,1),fpp(25,18, 3,2),fpp(25,18, 3,3)/
     x 1.1398546d-06,-1.6479581d-08, 7.5886998d-09 /
      data fpp(25,18, 4,1),fpp(25,18, 4,2),fpp(25,18, 4,3)/
     x 1.1398546d-06,-1.6479581d-08, 7.8537147d-09 /
      data fpp(25,18, 5,1),fpp(25,18, 5,2),fpp(25,18, 5,3)/
     x-2.6868475d-06,-2.7562323d-08, 3.7003119d-09 /
      data fpp(25,18, 6,1),fpp(25,18, 6,2),fpp(25,18, 6,3)/
     x-7.2614328d-06,-3.1693374d-08, 7.3450376d-09 /
      data fpp(25,18, 7,1),fpp(25,18, 7,2),fpp(25,18, 7,3)/
     x-1.2935957d-05,-3.0177582d-08, 2.9195378d-09 /
      data fpp(25,18, 8,1),fpp(25,18, 8,2),fpp(25,18, 8,3)/
     x-1.8358663d-05,-2.2646620d-08, 4.9768112d-09 /
      data fpp(25,18, 9,1),fpp(25,18, 9,2),fpp(25,18, 9,3)/
     x-2.4554023d-05,-1.0250288d-08, 1.1732174d-09 /
      data fpp(25,18,10,1),fpp(25,18,10,2),fpp(25,18,10,3)/
     x-3.0903854d-05, 4.8497874d-09, 2.3303191d-09 /
      data fpp(25,18,11,1),fpp(25,18,11,2),fpp(25,18,11,3)/
     x-3.7721189d-05, 1.4096188d-08,-4.4944939d-09 /
      data fpp(25,18,12,1),fpp(25,18,12,2),fpp(25,18,12,3)/
     x-4.1913157d-05, 2.3793437d-08,-2.3523434d-09 /
      data fpp(25,18,13,1),fpp(25,18,13,2),fpp(25,18,13,3)/
     x-4.6464550d-05, 2.6528168d-08,-4.0961326d-09 /
      data fpp(25,18,14,1),fpp(25,18,14,2),fpp(25,18,14,3)/
     x-5.1129872d-05, 2.6437273d-08,-5.2631264d-09 /
      data fpp(25,18,15,1),fpp(25,18,15,2),fpp(25,18,15,3)/
     x-5.5212195d-05, 6.3708663d-09,-4.8513618d-09 /
      data fpp(25,18,16,1),fpp(25,18,16,2),fpp(25,18,16,3)/
     x-5.8276029d-05,-1.3419351d-08,-5.3314265d-09 /
      data fpp(25,18,17,1),fpp(25,18,17,2),fpp(25,18,17,3)/
     x-6.0980115d-05,-3.5141294d-08,-3.8229322d-09 /
      data fpp(25,18,18,1),fpp(25,18,18,2),fpp(25,18,18,3)/
     x-6.3111032d-05,-5.9392059d-08,-3.3768446d-09 /
      data fpp(25,18,19,1),fpp(25,18,19,2),fpp(25,18,19,3)/
     x-6.4053551d-05,-7.9019607d-08,-6.6968928d-10 /
      data fpp(25,18,20,1),fpp(25,18,20,2),fpp(25,18,20,3)/
     x-6.4986247d-05,-9.3407343d-08, 5.5601751d-11 /
      data fpp(25,18,21,1),fpp(25,18,21,2),fpp(25,18,21,3)/
     x-6.4986247d-05,-9.3407343d-08, 1.6803939d-10 /
      data fpp(25,18,22,1),fpp(25,18,22,2),fpp(25,18,22,3)/
     x-6.4053551d-05,-7.9019607d-08,-1.1194398d-09 /
      data fpp(25,18,23,1),fpp(25,18,23,2),fpp(25,18,23,3)/
     x-6.3111032d-05,-5.9392059d-08,-1.6902801d-09 /
      data fpp(25,19, 1,1),fpp(25,19, 1,2),fpp(25,19, 1,3)/
     x-4.0526523d-05,-4.0653313d-08,-6.8511285d-22 /
      data fpp(25,19, 2,1),fpp(25,19, 2,2),fpp(25,19, 2,3)/
     x-4.0526523d-05,-5.4218838d-08, 2.3010384d-22 /
      data fpp(25,19, 3,1),fpp(25,19, 3,2),fpp(25,19, 3,3)/
     x-4.0526523d-05,-5.5760209d-08, 1.6893195d-22 /
      data fpp(25,19, 4,1),fpp(25,19, 4,2),fpp(25,19, 4,3)/
     x-4.0526523d-05,-5.5760209d-08,-4.9763472d-22 /
      data fpp(25,19, 5,1),fpp(25,19, 5,2),fpp(25,19, 5,3)/
     x-4.0526523d-05,-5.4218838d-08, 1.1194129d-22 /
      data fpp(25,19, 6,1),fpp(25,19, 6,2),fpp(25,19, 6,3)/
     x-4.0526523d-05,-4.0653313d-08, 2.7804717d-22 /
      data fpp(25,19, 7,1),fpp(25,19, 7,2),fpp(25,19, 7,3)/
     x-4.0526523d-05,-3.0411209d-08, 7.0123666d-22 /
      data fpp(25,19, 8,1),fpp(25,19, 8,2),fpp(25,19, 8,3)/
     x-4.0526523d-05,-2.2676690d-08, 3.7634796d-22 /
      data fpp(25,19, 9,1),fpp(25,19, 9,2),fpp(25,19, 9,3)/
     x-4.0526523d-05,-1.1874856d-08,-3.8595329d-23 /
      data fpp(25,19,10,1),fpp(25,19,10,2),fpp(25,19,10,3)/
     x-4.0526523d-05, 7.0751063d-09,-5.7340176d-22 /
      data fpp(25,19,11,1),fpp(25,19,11,2),fpp(25,19,11,3)/
     x-4.0526523d-05, 1.9951906d-08, 7.1837817d-22 /
      data fpp(25,19,12,1),fpp(25,19,12,2),fpp(25,19,12,3)/
     x-4.0526523d-05, 3.9103282d-08,-5.6481119d-22 /
      data fpp(25,19,13,1),fpp(25,19,13,2),fpp(25,19,13,3)/
     x-4.0526523d-05, 4.8235916d-08,-3.2535701d-22 /
      data fpp(25,19,14,1),fpp(25,19,14,2),fpp(25,19,14,3)/
     x-4.0526523d-05, 3.8281364d-08,-3.0623269d-22 /
      data fpp(25,19,15,1),fpp(25,19,15,2),fpp(25,19,15,3)/
     x-4.0526523d-05, 2.0314567d-08, 1.5954800d-22 /
      data fpp(25,19,16,1),fpp(25,19,16,2),fpp(25,19,16,3)/
     x-4.0526523d-05,-9.7903245d-09, 3.4804727d-22 /
      data fpp(25,19,17,1),fpp(25,19,17,2),fpp(25,19,17,3)/
     x-4.0526523d-05,-4.2429353d-08,-4.9794813d-22 /
      data fpp(25,19,18,1),fpp(25,19,18,2),fpp(25,19,18,3)/
     x-4.0526523d-05,-8.0803970d-08, 4.1859844d-22 /
      data fpp(25,19,19,1),fpp(25,19,19,2),fpp(25,19,19,3)/
     x-4.0526523d-05,-1.1049020d-07, 3.2691903d-22 /
      data fpp(25,19,20,1),fpp(25,19,20,2),fpp(25,19,20,3)/
     x-4.0526523d-05,-1.3179633d-07,-2.4698682d-22 /
      data fpp(25,19,21,1),fpp(25,19,21,2),fpp(25,19,21,3)/
     x-4.0526523d-05,-1.3179633d-07, 1.5957328d-22 /
      data fpp(25,19,22,1),fpp(25,19,22,2),fpp(25,19,22,3)/
     x-4.0526523d-05,-1.1049020d-07,-3.0310711d-22 /
      data fpp(25,19,23,1),fpp(25,19,23,2),fpp(25,19,23,3)/
     x-4.0526523d-05,-8.0803970d-08,-1.7663669d-21 /
      data fpp(26, 1, 1,1),fpp(26, 1, 1,2),fpp(26, 1, 1,3)/
     x 1.1004754d-03,-2.9236424d-07, 1.4661256d-22 /
      data fpp(26, 1, 2,1),fpp(26, 1, 2,2),fpp(26, 1, 2,3)/
     x 1.1004754d-03, 2.5661806d-07,-1.5448650d-23 /
      data fpp(26, 1, 3,1),fpp(26, 1, 3,2),fpp(26, 1, 3,3)/
     x 1.1004754d-03, 5.8612657d-07, 1.7618940d-22 /
      data fpp(26, 1, 4,1),fpp(26, 1, 4,2),fpp(26, 1, 4,3)/
     x 1.1004754d-03, 5.8612657d-07,-9.6504661d-23 /
      data fpp(26, 1, 5,1),fpp(26, 1, 5,2),fpp(26, 1, 5,3)/
     x 1.1004754d-03, 2.5661806d-07, 1.2748330d-22 /
      data fpp(26, 1, 6,1),fpp(26, 1, 6,2),fpp(26, 1, 6,3)/
     x 1.1004754d-03,-2.9236424d-07, 1.6191436d-22 /
      data fpp(26, 1, 7,1),fpp(26, 1, 7,2),fpp(26, 1, 7,3)/
     x 1.1004754d-03,-9.8928166d-07, 1.4608580d-22 /
      data fpp(26, 1, 8,1),fpp(26, 1, 8,2),fpp(26, 1, 8,3)/
     x 1.1004754d-03,-1.7471424d-06, 1.3652620d-22 /
      data fpp(26, 1, 9,1),fpp(26, 1, 9,2),fpp(26, 1, 9,3)/
     x 1.1004754d-03,-2.4529645d-06, 8.2127489d-23 /
      data fpp(26, 1,10,1),fpp(26, 1,10,2),fpp(26, 1,10,3)/
     x 1.1004754d-03,-3.0138038d-06,-2.2217085d-22 /
      data fpp(26, 1,11,1),fpp(26, 1,11,2),fpp(26, 1,11,3)/
     x 1.1004754d-03,-3.3735617d-06, 1.8652958d-22 /
      data fpp(26, 1,12,1),fpp(26, 1,12,2),fpp(26, 1,12,3)/
     x 1.1004754d-03,-3.5073208d-06,-1.8357518d-22 /
      data fpp(26, 1,13,1),fpp(26, 1,13,2),fpp(26, 1,13,3)/
     x 1.1004754d-03,-3.3894606d-06, 1.5388685d-23 /
      data fpp(26, 1,14,1),fpp(26, 1,14,2),fpp(26, 1,14,3)/
     x 1.1004754d-03,-3.0336843d-06, 4.9121731d-23 /
      data fpp(26, 1,15,1),fpp(26, 1,15,2),fpp(26, 1,15,3)/
     x 1.1004754d-03,-2.4502603d-06, 1.4383126d-23 /
      data fpp(26, 1,16,1),fpp(26, 1,16,2),fpp(26, 1,16,3)/
     x 1.1004754d-03,-1.7011199d-06, 9.3361658d-23 /
      data fpp(26, 1,17,1),fpp(26, 1,17,2),fpp(26, 1,17,3)/
     x 1.1004754d-03,-8.7488231d-07,-9.0410157d-23 /
      data fpp(26, 1,18,1),fpp(26, 1,18,2),fpp(26, 1,18,3)/
     x 1.1004754d-03,-1.0599133d-07, 1.3616921d-22 /
      data fpp(26, 1,19,1),fpp(26, 1,19,2),fpp(26, 1,19,3)/
     x 1.1004754d-03, 5.1906089d-07, 3.2604613d-22 /
      data fpp(26, 1,20,1),fpp(26, 1,20,2),fpp(26, 1,20,3)/
     x 1.1004754d-03, 9.0416028d-07,-6.5349997d-23 /
      data fpp(26, 1,21,1),fpp(26, 1,21,2),fpp(26, 1,21,3)/
     x 1.1004754d-03, 9.0416028d-07, 9.0186170d-23 /
      data fpp(26, 1,22,1),fpp(26, 1,22,2),fpp(26, 1,22,3)/
     x 1.1004754d-03, 5.1906089d-07,-3.4301828d-22 /
      data fpp(26, 1,23,1),fpp(26, 1,23,2),fpp(26, 1,23,3)/
     x 1.1004754d-03,-1.0599133d-07,-1.6547597d-22 /
      data fpp(26, 2, 1,1),fpp(26, 2, 1,2),fpp(26, 2, 1,3)/
     x 1.1552276d-03,-2.8427151d-07,-6.6281561d-08 /
      data fpp(26, 2, 2,1),fpp(26, 2, 2,2),fpp(26, 2, 2,3)/
     x 1.2212762d-03,-1.0223613d-07,-7.9436878d-08 /
      data fpp(26, 2, 3,1),fpp(26, 2, 3,2),fpp(26, 2, 3,3)/
     x 1.2279929d-03, 7.7468572d-09,-1.0797093d-07 /
      data fpp(26, 2, 4,1),fpp(26, 2, 4,2),fpp(26, 2, 4,3)/
     x 1.2279929d-03, 7.7468572d-09,-1.0736878d-07 /
      data fpp(26, 2, 5,1),fpp(26, 2, 5,2),fpp(26, 2, 5,3)/
     x 1.2212762d-03,-1.0223613d-07,-8.1845479d-08 /
      data fpp(26, 2, 6,1),fpp(26, 2, 6,2),fpp(26, 2, 6,3)/
     x 1.1552276d-03,-2.8427151d-07,-5.7249305d-08 /
      data fpp(26, 2, 7,1),fpp(26, 2, 7,2),fpp(26, 2, 7,3)/
     x 1.0609090d-03,-5.0743668d-07,-1.9157299d-08 /
      data fpp(26, 2, 8,1),fpp(26, 2, 8,2),fpp(26, 2, 8,3)/
     x 9.5606253d-04,-7.4371522d-07, 1.9878501d-08 /
      data fpp(26, 2, 9,1),fpp(26, 2, 9,2),fpp(26, 2, 9,3)/
     x 8.5476438d-04,-9.5907093d-07, 5.3643294d-08 /
      data fpp(26, 2,10,1),fpp(26, 2,10,2),fpp(26, 2,10,3)/
     x 7.7572678d-04,-1.1273924d-06, 8.3548324d-08 /
      data fpp(26, 2,11,1),fpp(26, 2,11,2),fpp(26, 2,11,3)/
     x 7.2326147d-04,-1.2358766d-06, 1.0416341d-07 /
      data fpp(26, 2,12,1),fpp(26, 2,12,2),fpp(26, 2,12,3)/
     x 7.0572023d-04,-1.2793585d-06, 1.0579804d-07 /
      data fpp(26, 2,13,1),fpp(26, 2,13,2),fpp(26, 2,13,3)/
     x 7.2432482d-04,-1.2480789d-06, 1.0864443d-07 /
      data fpp(26, 2,14,1),fpp(26, 2,14,2),fpp(26, 2,14,3)/
     x 7.7189356d-04,-1.1466314d-06, 8.3624228d-08 /
      data fpp(26, 2,15,1),fpp(26, 2,15,2),fpp(26, 2,15,3)/
     x 8.5119004d-04,-9.7147942d-07, 6.0858656d-08 /
      data fpp(26, 2,16,1),fpp(26, 2,16,2),fpp(26, 2,16,3)/
     x 9.5238108d-04,-7.3876016d-07, 2.0941148d-08 /
      data fpp(26, 2,17,1),fpp(26, 2,17,2),fpp(26, 2,17,3)/
     x 1.0581590d-03,-4.7123538d-07,-1.2623249d-08 /
      data fpp(26, 2,18,1),fpp(26, 2,18,2),fpp(26, 2,18,3)/
     x 1.1543870d-03,-2.1401734d-07,-6.0448150d-08 /
      data fpp(26, 2,19,1),fpp(26, 2,19,2),fpp(26, 2,19,3)/
     x 1.2107814d-03, 3.8782140d-09,-8.1584149d-08 /
      data fpp(26, 2,20,1),fpp(26, 2,20,2),fpp(26, 2,20,3)/
     x 1.2304747d-03, 1.3967944d-07,-1.1121525d-07 /
      data fpp(26, 2,21,1),fpp(26, 2,21,2),fpp(26, 2,21,3)/
     x 1.2304747d-03, 1.3967944d-07,-1.1156216d-07 /
      data fpp(26, 2,22,1),fpp(26, 2,22,2),fpp(26, 2,22,3)/
     x 1.2107814d-03, 3.8782140d-09,-8.0196525d-08 /
      data fpp(26, 2,23,1),fpp(26, 2,23,2),fpp(26, 2,23,3)/
     x 1.1543870d-03,-2.1401734d-07,-6.5651737d-08 /
      data fpp(26, 3, 1,1),fpp(26, 3, 1,2),fpp(26, 3, 1,3)/
     x 1.0206374d-03,-6.0454971d-07,-1.9108470d-07 /
      data fpp(26, 3, 2,1),fpp(26, 3, 2,2),fpp(26, 3, 2,3)/
     x 1.2428924d-03,-9.3367356d-07,-2.1933061d-07 /
      data fpp(26, 3, 3,1),fpp(26, 3, 3,2),fpp(26, 3, 3,3)/
     x 1.3495313d-03,-1.1211140d-06,-2.8159287d-07 /
      data fpp(26, 3, 4,1),fpp(26, 3, 4,2),fpp(26, 3, 4,3)/
     x 1.3495313d-03,-1.1211140d-06,-2.7855607d-07 /
      data fpp(26, 3, 5,1),fpp(26, 3, 5,2),fpp(26, 3, 5,3)/
     x 1.2428924d-03,-9.3367356d-07,-2.3147782d-07 /
      data fpp(26, 3, 6,1),fpp(26, 3, 6,2),fpp(26, 3, 6,3)/
     x 1.0206374d-03,-6.0454971d-07,-1.4553266d-07 /
      data fpp(26, 3, 7,1),fpp(26, 3, 7,2),fpp(26, 3, 7,3)/
     x 7.4500266d-04,-1.6097161d-07,-4.4391554d-08 /
      data fpp(26, 3, 8,1),fpp(26, 3, 8,2),fpp(26, 3, 8,3)/
     x 4.6760340d-04, 3.6600328d-07, 6.5098874d-08 /
      data fpp(26, 3, 9,1),fpp(26, 3, 9,2),fpp(26, 3, 9,3)/
     x 2.2047768d-04, 8.9524825d-07, 1.4999606d-07 /
      data fpp(26, 3,10,1),fpp(26, 3,10,2),fpp(26, 3,10,3)/
     x 2.8949832d-05, 1.3373735d-06, 2.1691689d-07 /
      data fpp(26, 3,11,1),fpp(26, 3,11,2),fpp(26, 3,11,3)/
     x-9.2145617d-05, 1.6270680d-06, 2.5433637d-07 /
      data fpp(26, 3,12,1),fpp(26, 3,12,2),fpp(26, 3,12,3)/
     x-1.3649346d-04, 1.7247547d-06, 2.7173764d-07 /
      data fpp(26, 3,13,1),fpp(26, 3,13,2),fpp(26, 3,13,3)/
     x-1.0059723d-04, 1.6077761d-06, 2.6671307d-07 /
      data fpp(26, 3,14,1),fpp(26, 3,14,2),fpp(26, 3,14,3)/
     x 1.2696514d-05, 1.2962097d-06, 2.3341009d-07 /
      data fpp(26, 3,15,1),fpp(26, 3,15,2),fpp(26, 3,15,3)/
     x 2.0010180d-04, 8.2817797d-07, 1.7364656d-07 /
      data fpp(26, 3,16,1),fpp(26, 3,16,2),fpp(26, 3,16,3)/
     x 4.4791396d-04, 2.8216057d-07, 8.6003660d-08 /
      data fpp(26, 3,17,1),fpp(26, 3,17,2),fpp(26, 3,17,3)/
     x 7.2871064d-04,-2.5817617d-07,-3.1661201d-08 /
      data fpp(26, 3,18,1),fpp(26, 3,18,2),fpp(26, 3,18,3)/
     x 1.0117788d-03,-7.0593929d-07,-1.4535886d-07 /
      data fpp(26, 3,19,1),fpp(26, 3,19,2),fpp(26, 3,19,3)/
     x 1.2400213d-03,-1.0385737d-06,-2.4490337d-07 /
      data fpp(26, 3,20,1),fpp(26, 3,20,2),fpp(26, 3,20,3)/
     x 1.3623113d-03,-1.2348780d-06,-3.0302767d-07 /
      data fpp(26, 3,21,1),fpp(26, 3,21,2),fpp(26, 3,21,3)/
     x 1.3623113d-03,-1.2348780d-06,-3.0646532d-07 /
      data fpp(26, 3,22,1),fpp(26, 3,22,2),fpp(26, 3,22,3)/
     x 1.2400213d-03,-1.0385737d-06,-2.3115277d-07 /
      data fpp(26, 3,23,1),fpp(26, 3,23,2),fpp(26, 3,23,3)/
     x 1.0117788d-03,-7.0593929d-07,-1.9692362d-07 /
      data fpp(26, 4, 1,1),fpp(26, 4, 1,2),fpp(26, 4, 1,3)/
     x 6.7965884d-04, 2.2447036d-07,-2.0704411d-07 /
      data fpp(26, 4, 2,1),fpp(26, 4, 2,2),fpp(26, 4, 2,3)/
     x 9.5768639d-04,-1.1106963d-07,-2.5541177d-07 /
      data fpp(26, 4, 3,1),fpp(26, 4, 3,2),fpp(26, 4, 3,3)/
     x 1.1481246d-03,-3.2329086d-07,-3.6130879d-07 /
      data fpp(26, 4, 4,1),fpp(26, 4, 4,2),fpp(26, 4, 4,3)/
     x 1.1481246d-03,-3.2329086d-07,-3.5736774d-07 /
      data fpp(26, 4, 5,1),fpp(26, 4, 5,2),fpp(26, 4, 5,3)/
     x 9.5768639d-04,-1.1106963d-07,-2.7117595d-07 /
      data fpp(26, 4, 6,1),fpp(26, 4, 6,2),fpp(26, 4, 6,3)/
     x 6.7965884d-04, 2.2447036d-07,-1.4792845d-07 /
      data fpp(26, 4, 7,1),fpp(26, 4, 7,2),fpp(26, 4, 7,3)/
     x 3.5749692d-04, 6.5932311d-07,-7.1102541d-09 /
      data fpp(26, 4, 8,1),fpp(26, 4, 8,2),fpp(26, 4, 8,3)/
     x 3.7181243d-05, 1.1037021d-06, 1.0436947d-07 /
      data fpp(26, 4, 9,1),fpp(26, 4, 9,2),fpp(26, 4, 9,3)/
     x-2.4027547d-04, 1.4880779d-06, 1.7763239d-07 /
      data fpp(26, 4,10,1),fpp(26, 4,10,2),fpp(26, 4,10,3)/
     x-4.5096056d-04, 1.7778983d-06, 2.3510096d-07 /
      data fpp(26, 4,11,1),fpp(26, 4,11,2),fpp(26, 4,11,3)/
     x-5.8520714d-04, 1.9516047d-06, 2.6796376d-07 /
      data fpp(26, 4,12,1),fpp(26, 4,12,2),fpp(26, 4,12,3)/
     x-6.3696392d-04, 2.0123396d-06, 2.8304398d-07 /
      data fpp(26, 4,13,1),fpp(26, 4,13,2),fpp(26, 4,13,3)/
     x-6.0371459d-04, 1.9629744d-06, 2.8586030d-07 /
      data fpp(26, 4,14,1),fpp(26, 4,14,2),fpp(26, 4,14,3)/
     x-4.8381851d-04, 1.7937924d-06, 2.6551480d-07 /
      data fpp(26, 4,15,1),fpp(26, 4,15,2),fpp(26, 4,15,3)/
     x-2.8000623d-04, 1.5047675d-06, 2.2408048d-07 /
      data fpp(26, 4,16,1),fpp(26, 4,16,2),fpp(26, 4,16,3)/
     x-1.6501160d-06, 1.0981179d-06, 1.4616328d-07 /
      data fpp(26, 4,17,1),fpp(26, 4,17,2),fpp(26, 4,17,3)/
     x 3.2714784d-04, 6.2194005d-07, 1.9266403d-08 /
      data fpp(26, 4,18,1),fpp(26, 4,18,2),fpp(26, 4,18,3)/
     x 6.6456257d-04, 1.4577452d-07,-1.4522889d-07 /
      data fpp(26, 4,19,1),fpp(26, 4,19,2),fpp(26, 4,19,3)/
     x 9.5791903d-04,-2.3558322d-07,-3.0235084d-07 /
      data fpp(26, 4,20,1),fpp(26, 4,20,2),fpp(26, 4,20,3)/
     x 1.1615413d-03,-4.7416727d-07,-3.9736777d-07 /
      data fpp(26, 4,21,1),fpp(26, 4,21,2),fpp(26, 4,21,3)/
     x 1.1615413d-03,-4.7416727d-07,-4.0272128d-07 /
      data fpp(26, 4,22,1),fpp(26, 4,22,2),fpp(26, 4,22,3)/
     x 9.5791903d-04,-2.3558322d-07,-2.8093678d-07 /
      data fpp(26, 4,23,1),fpp(26, 4,23,2),fpp(26, 4,23,3)/
     x 6.6456257d-04, 1.4577452d-07,-2.2553161d-07 /
      data fpp(26, 5, 1,1),fpp(26, 5, 1,2),fpp(26, 5, 1,3)/
     x 3.0225630d-04, 5.9466827d-07,-1.3627935d-07 /
      data fpp(26, 5, 2,1),fpp(26, 5, 2,2),fpp(26, 5, 2,3)/
     x 5.1342252d-04, 3.6995208d-07,-1.8694129d-07 /
      data fpp(26, 5, 3,1),fpp(26, 5, 3,2),fpp(26, 5, 3,3)/
     x 6.6315351d-04, 1.5827743d-07,-2.9795548d-07 /
      data fpp(26, 5, 4,1),fpp(26, 5, 4,2),fpp(26, 5, 4,3)/
     x 6.6315351d-04, 1.5827743d-07,-2.9366291d-07 /
      data fpp(26, 5, 5,1),fpp(26, 5, 5,2),fpp(26, 5, 5,3)/
     x 5.1342252d-04, 3.6995208d-07,-2.0411157d-07 /
      data fpp(26, 5, 6,1),fpp(26, 5, 6,2),fpp(26, 5, 6,3)/
     x 3.0225630d-04, 5.9466827d-07,-7.1890795d-08 /
      data fpp(26, 5, 7,1),fpp(26, 5, 7,2),fpp(26, 5, 7,3)/
     x 6.5655260d-05, 7.2767915d-07, 2.9674753d-08 /
      data fpp(26, 5, 8,1),fpp(26, 5, 8,2),fpp(26, 5, 8,3)/
     x-1.6088178d-04, 7.6318836d-07, 9.1191783d-08 /
      data fpp(26, 5, 9,1),fpp(26, 5, 9,2),fpp(26, 5, 9,3)/
     x-3.5885933d-04, 7.4244007d-07, 1.2155812d-07 /
      data fpp(26, 5,10,1),fpp(26, 5,10,2),fpp(26, 5,10,3)/
     x-5.1602150d-04, 6.9503332d-07, 1.4857575d-07 /
      data fpp(26, 5,11,1),fpp(26, 5,11,2),fpp(26, 5,11,3)/
     x-6.2190910d-04, 6.5851306d-07, 1.7813888d-07 /
      data fpp(26, 5,12,1),fpp(26, 5,12,2),fpp(26, 5,12,3)/
     x-6.6676807d-04, 6.4788681d-07, 1.9486874d-07 /
      data fpp(26, 5,13,1),fpp(26, 5,13,2),fpp(26, 5,13,3)/
     x-6.4533358d-04, 6.8032629d-07, 1.9438615d-07 /
      data fpp(26, 5,14,1),fpp(26, 5,14,2),fpp(26, 5,14,3)/
     x-5.5797766d-04, 7.3862061d-07, 1.9158664d-07 /
      data fpp(26, 5,15,1),fpp(26, 5,15,2),fpp(26, 5,15,3)/
     x-4.1152721d-04, 7.9675187d-07, 1.7326728d-07 /
      data fpp(26, 5,16,1),fpp(26, 5,16,2),fpp(26, 5,16,3)/
     x-2.1206668d-04, 8.3336795d-07, 1.4734423d-07 /
      data fpp(26, 5,17,1),fpp(26, 5,17,2),fpp(26, 5,17,3)/
     x 2.5534902d-05, 8.0041597d-07, 6.5355786d-08 /
      data fpp(26, 5,18,1),fpp(26, 5,18,2),fpp(26, 5,18,3)/
     x 2.8092498d-04, 6.6884121d-07,-7.2767376d-08 /
      data fpp(26, 5,19,1),fpp(26, 5,19,2),fpp(26, 5,19,3)/
     x 5.1605938d-04, 4.5090662d-07,-2.3628628d-07 /
      data fpp(26, 5,20,1),fpp(26, 5,20,2),fpp(26, 5,20,3)/
     x 6.8263776d-04, 2.4554714d-07,-3.3808749d-07 /
      data fpp(26, 5,21,1),fpp(26, 5,21,2),fpp(26, 5,21,3)/
     x 6.8263776d-04, 2.4554714d-07,-3.4359438d-07 /
      data fpp(26, 5,22,1),fpp(26, 5,22,2),fpp(26, 5,22,3)/
     x 5.1605938d-04, 4.5090662d-07,-2.1425875d-07 /
      data fpp(26, 5,23,1),fpp(26, 5,23,2),fpp(26, 5,23,3)/
     x 2.8092498d-04, 6.6884121d-07,-1.5537063d-07 /
      data fpp(26, 6, 1,1),fpp(26, 6, 1,2),fpp(26, 6, 1,3)/
     x 6.3511213d-05, 3.9085657d-07,-1.0102419d-07 /
      data fpp(26, 6, 2,1),fpp(26, 6, 2,2),fpp(26, 6, 2,3)/
     x 1.7679909d-04, 5.2126132d-07,-1.0495162d-07 /
      data fpp(26, 6, 3,1),fpp(26, 6, 3,2),fpp(26, 6, 3,3)/
     x 2.5944894d-04, 6.1418115d-07,-1.1516932d-07 /
      data fpp(26, 6, 4,1),fpp(26, 6, 4,2),fpp(26, 6, 4,3)/
     x 2.5944894d-04, 6.1418115d-07,-1.1201623d-07 /
      data fpp(26, 6, 5,1),fpp(26, 6, 5,2),fpp(26, 6, 5,3)/
     x 1.7679909d-04, 5.2126132d-07,-1.1756399d-07 /
      data fpp(26, 6, 6,1),fpp(26, 6, 6,2),fpp(26, 6, 6,3)/
     x 6.3511213d-05, 3.9085657d-07,-5.3727813d-08 /
      data fpp(26, 6, 7,1),fpp(26, 6, 7,2),fpp(26, 6, 7,3)/
     x-5.9220904d-05, 2.4596027d-07,-3.5247601d-09 /
      data fpp(26, 6, 8,1),fpp(26, 6, 8,2),fpp(26, 6, 8,3)/
     x-1.7714089d-04, 9.7544456d-08, 3.1826853d-08 /
      data fpp(26, 6, 9,1),fpp(26, 6, 9,2),fpp(26, 6, 9,3)/
     x-2.8325727d-04,-4.7838198d-08, 3.8217348d-08 /
      data fpp(26, 6,10,1),fpp(26, 6,10,2),fpp(26, 6,10,3)/
     x-3.6862452d-04,-1.4803158d-07, 6.1303754d-08 /
      data fpp(26, 6,11,1),fpp(26, 6,11,2),fpp(26, 6,11,3)/
     x-4.2879314d-04,-1.9965700d-07, 9.4567638d-08 /
      data fpp(26, 6,12,1),fpp(26, 6,12,2),fpp(26, 6,12,3)/
     x-4.5747828d-04,-1.9988686d-07, 1.2442570d-07 /
      data fpp(26, 6,13,1),fpp(26, 6,13,2),fpp(26, 6,13,3)/
     x-4.5408931d-04,-1.7827956d-07, 1.0972958d-07 /
      data fpp(26, 6,14,1),fpp(26, 6,14,2),fpp(26, 6,14,3)/
     x-4.1327161d-04,-1.1027485d-07, 1.0265599d-07 /
      data fpp(26, 6,15,1),fpp(26, 6,15,2),fpp(26, 6,15,3)/
     x-3.3933434d-04, 2.2496336d-10, 9.7646443d-08 /
      data fpp(26, 6,16,1),fpp(26, 6,16,2),fpp(26, 6,16,3)/
     x-2.3453371d-04, 1.4041033d-07, 8.8758232d-08 /
      data fpp(26, 6,17,1),fpp(26, 6,17,2),fpp(26, 6,17,3)/
     x-1.0551578d-04, 2.9239607d-07, 3.9320630d-08 /
      data fpp(26, 6,18,1),fpp(26, 6,18,2),fpp(26, 6,18,3)/
     x 3.7205123d-05, 4.3686064d-07,-5.4040751d-08 /
      data fpp(26, 6,19,1),fpp(26, 6,19,2),fpp(26, 6,19,3)/
     x 1.7411590d-04, 5.6795674d-07,-1.4715762d-07 /
      data fpp(26, 6,20,1),fpp(26, 6,20,2),fpp(26, 6,20,3)/
     x 2.7571304d-04, 6.6197873d-07,-1.6132875d-07 /
      data fpp(26, 6,21,1),fpp(26, 6,21,2),fpp(26, 6,21,3)/
     x 2.7571304d-04, 6.6197873d-07,-1.6543494d-07 /
      data fpp(26, 6,22,1),fpp(26, 6,22,2),fpp(26, 6,22,3)/
     x 1.7411590d-04, 5.6795674d-07,-1.3073288d-07 /
      data fpp(26, 6,23,1),fpp(26, 6,23,2),fpp(26, 6,23,3)/
     x 3.7205123d-05, 4.3686064d-07,-1.1563356d-07 /
      data fpp(26, 7, 1,1),fpp(26, 7, 1,2),fpp(26, 7, 1,3)/
     x-2.0424488d-05, 1.9054375d-09,-8.4351435d-08 /
      data fpp(26, 7, 2,1),fpp(26, 7, 2,2),fpp(26, 7, 2,3)/
     x 2.5038380d-05, 1.9100264d-07,-4.7797131d-08 /
      data fpp(26, 7, 3,1),fpp(26, 7, 3,2),fpp(26, 7, 3,3)/
     x 5.8130963d-05, 3.6099798d-07, 2.9539957d-08 /
      data fpp(26, 7, 4,1),fpp(26, 7, 4,2),fpp(26, 7, 4,3)/
     x 5.8130963d-05, 3.6099798d-07, 3.1278693d-08 /
      data fpp(26, 7, 5,1),fpp(26, 7, 5,2),fpp(26, 7, 5,3)/
     x 2.5038380d-05, 1.9100264d-07,-5.4752075d-08 /
      data fpp(26, 7, 6,1),fpp(26, 7, 6,2),fpp(26, 7, 6,3)/
     x-2.0424488d-05, 1.9054375d-09,-5.8270392d-08 /
      data fpp(26, 7, 7,1),fpp(26, 7, 7,2),fpp(26, 7, 7,3)/
     x-7.2741099d-05,-1.6352025d-07,-4.8166356d-08 /
      data fpp(26, 7, 8,1),fpp(26, 7, 8,2),fpp(26, 7, 8,3)/
     x-1.2277115d-04,-2.8936619d-07,-3.1064185d-08 /
      data fpp(26, 7, 9,1),fpp(26, 7, 9,2),fpp(26, 7, 9,3)/
     x-1.6694781d-04,-3.5908728d-07,-7.5769044d-09 /
      data fpp(26, 7,10,1),fpp(26, 7,10,2),fpp(26, 7,10,3)/
     x-2.0461746d-04,-3.9690701d-07, 1.3371803d-08 /
      data fpp(26, 7,11,1),fpp(26, 7,11,2),fpp(26, 7,11,3)/
     x-2.3416612d-04,-3.9988507d-07, 5.6089694d-08 /
      data fpp(26, 7,12,1),fpp(26, 7,12,2),fpp(26, 7,12,3)/
     x-2.5348678d-04,-4.0033937d-07, 6.8269423d-08 /
      data fpp(26, 7,13,1),fpp(26, 7,13,2),fpp(26, 7,13,3)/
     x-2.5833264d-04,-3.8720805d-07, 6.6832614d-08 /
      data fpp(26, 7,14,1),fpp(26, 7,14,2),fpp(26, 7,14,3)/
     x-2.4893754d-04,-3.6952121d-07, 4.8400123d-08 /
      data fpp(26, 7,15,1),fpp(26, 7,15,2),fpp(26, 7,15,3)/
     x-2.2218605d-04,-3.1765173d-07, 4.5566896d-08 /
      data fpp(26, 7,16,1),fpp(26, 7,16,2),fpp(26, 7,16,3)/
     x-1.7837717d-04,-2.3100927d-07, 3.3332294d-08 /
      data fpp(26, 7,17,1),fpp(26, 7,17,2),fpp(26, 7,17,3)/
     x-1.1966937d-04,-1.0400025d-07,-4.8960724d-09 /
      data fpp(26, 7,18,1),fpp(26, 7,18,2),fpp(26, 7,18,3)/
     x-5.1352307d-05, 6.1716248d-08,-5.5748004d-08 /
      data fpp(26, 7,19,1),fpp(26, 7,19,2),fpp(26, 7,19,3)/
     x 1.4005830d-05, 2.4126643d-07,-8.4111910d-08 /
      data fpp(26, 7,20,1),fpp(26, 7,20,2),fpp(26, 7,20,3)/
     x 6.1239385d-05, 3.9453794d-07,-2.1804357d-08 /
      data fpp(26, 7,21,1),fpp(26, 7,21,2),fpp(26, 7,21,3)/
     x 6.1239385d-05, 3.9453794d-07,-2.4530975d-08 /
      data fpp(26, 7,22,1),fpp(26, 7,22,2),fpp(26, 7,22,3)/
     x 1.4005830d-05, 2.4126643d-07,-7.3205436d-08 /
      data fpp(26, 7,23,1),fpp(26, 7,23,2),fpp(26, 7,23,3)/
     x-5.1352307d-05, 6.1716248d-08,-9.6647282d-08 /
      data fpp(26, 8, 1,1),fpp(26, 8, 1,2),fpp(26, 8, 1,3)/
     x-3.1470296d-05,-2.1847832d-07,-4.6299302d-08 /
      data fpp(26, 8, 2,1),fpp(26, 8, 2,2),fpp(26, 8, 2,3)/
     x-1.8303327d-05,-1.5727190d-07,-7.4013969d-09 /
      data fpp(26, 8, 3,1),fpp(26, 8, 3,2),fpp(26, 8, 3,3)/
     x-9.3407098d-06,-1.2617307d-07, 7.5904889d-08 /
      data fpp(26, 8, 4,1),fpp(26, 8, 4,2),fpp(26, 8, 4,3)/
     x-9.3407098d-06,-1.2617307d-07, 7.5986031d-08 /
      data fpp(26, 8, 5,1),fpp(26, 8, 5,2),fpp(26, 8, 5,3)/
     x-1.8303327d-05,-1.5727190d-07,-7.7259645d-09 /
      data fpp(26, 8, 6,1),fpp(26, 8, 6,2),fpp(26, 8, 6,3)/
     x-3.1470296d-05,-2.1847832d-07,-4.5082173d-08 /
      data fpp(26, 8, 7,1),fpp(26, 8, 7,2),fpp(26, 8, 7,3)/
     x-4.7928886d-05,-2.7587929d-07,-6.3945343d-08 /
      data fpp(26, 8, 8,1),fpp(26, 8, 8,2),fpp(26, 8, 8,3)/
     x-6.2812399d-05,-3.0807971d-07,-4.7136454d-08 /
      data fpp(26, 8, 9,1),fpp(26, 8, 9,2),fpp(26, 8, 9,3)/
     x-7.9919239d-05,-3.2781269d-07,-2.9508841d-08 /
      data fpp(26, 8,10,1),fpp(26, 8,10,2),fpp(26, 8,10,3)/
     x-9.7448327d-05,-3.4034036d-07, 3.1718167d-09 /
      data fpp(26, 8,11,1),fpp(26, 8,11,2),fpp(26, 8,11,3)/
     x-1.1662177d-04,-3.6080274d-07, 2.2821574d-08 /
      data fpp(26, 8,12,1),fpp(26, 8,12,2),fpp(26, 8,12,3)/
     x-1.3121133d-04,-3.6475567d-07, 3.1541887d-08 /
      data fpp(26, 8,13,1),fpp(26, 8,13,2),fpp(26, 8,13,3)/
     x-1.3957803d-04,-3.5488824d-07, 3.1010877d-08 /
      data fpp(26, 8,14,1),fpp(26, 8,14,2),fpp(26, 8,14,3)/
     x-1.3852999d-04,-3.2564031d-07, 3.0414605d-08 /
      data fpp(26, 8,15,1),fpp(26, 8,15,2),fpp(26, 8,15,3)/
     x-1.3052408d-04,-2.9561805d-07, 2.1330703d-08 /
      data fpp(26, 8,16,1),fpp(26, 8,16,2),fpp(26, 8,16,3)/
     x-1.1283889d-04,-2.5437324d-07, 1.0262582d-08 /
      data fpp(26, 8,17,1),fpp(26, 8,17,2),fpp(26, 8,17,3)/
     x-8.9855346d-05,-2.0039506d-07,-2.0381033d-08 /
      data fpp(26, 8,18,1),fpp(26, 8,18,2),fpp(26, 8,18,3)/
     x-6.2849906d-05,-1.3772563d-07,-4.8738452d-08 /
      data fpp(26, 8,19,1),fpp(26, 8,19,2),fpp(26, 8,19,3)/
     x-3.8057944d-05,-7.5022467d-08,-4.2665159d-08 /
      data fpp(26, 8,20,1),fpp(26, 8,20,2),fpp(26, 8,20,3)/
     x-2.1668679d-05,-3.8130509d-08, 2.7399087d-08 /
      data fpp(26, 8,21,1),fpp(26, 8,21,2),fpp(26, 8,21,3)/
     x-2.1668679d-05,-3.8130509d-08, 2.6135320d-08 /
      data fpp(26, 8,22,1),fpp(26, 8,22,2),fpp(26, 8,22,3)/
     x-3.8057944d-05,-7.5022467d-08,-3.7610091d-08 /
      data fpp(26, 8,23,1),fpp(26, 8,23,2),fpp(26, 8,23,3)/
     x-6.2849906d-05,-1.3772563d-07,-6.7694954d-08 /
      data fpp(26, 9, 1,1),fpp(26, 9, 1,2),fpp(26, 9, 1,3)/
     x-2.2544558d-05,-2.1399214d-07,-2.0737928d-08 /
      data fpp(26, 9, 2,1),fpp(26, 9, 2,2),fpp(26, 9, 2,3)/
     x-1.8036966d-05,-2.2191506d-07, 1.3475857d-08 /
      data fpp(26, 9, 3,1),fpp(26, 9, 3,2),fpp(26, 9, 3,3)/
     x-1.2160877d-05,-2.1630569d-07, 8.6834502d-08 /
      data fpp(26, 9, 4,1),fpp(26, 9, 4,2),fpp(26, 9, 4,3)/
     x-1.2160877d-05,-2.1630569d-07, 8.6758566d-08 /
      data fpp(26, 9, 5,1),fpp(26, 9, 5,2),fpp(26, 9, 5,3)/
     x-1.8036966d-05,-2.2191506d-07, 1.3779602d-08 /
      data fpp(26, 9, 6,1),fpp(26, 9, 6,2),fpp(26, 9, 6,3)/
     x-2.2544558d-05,-2.1399214d-07,-2.1876974d-08 /
      data fpp(26, 9, 7,1),fpp(26, 9, 7,2),fpp(26, 9, 7,3)/
     x-2.7439037d-05,-2.0296261d-07,-5.2271705d-08 /
      data fpp(26, 9, 8,1),fpp(26, 9, 8,2),fpp(26, 9, 8,3)/
     x-3.1446828d-05,-2.0031498d-07,-5.1036204d-08 /
      data fpp(26, 9, 9,1),fpp(26, 9, 9,2),fpp(26, 9, 9,3)/
     x-3.7775347d-05,-2.1366198d-07,-3.7583478d-08 /
      data fpp(26, 9,10,1),fpp(26, 9,10,2),fpp(26, 9,10,3)/
     x-4.6319064d-05,-2.2773153d-07,-1.4629885d-08 /
      data fpp(26, 9,11,1),fpp(26, 9,11,2),fpp(26, 9,11,3)/
     x-5.7170535d-05,-2.4490398d-07, 6.1030189d-09 /
      data fpp(26, 9,12,1),fpp(26, 9,12,2),fpp(26, 9,12,3)/
     x-6.8917173d-05,-2.5863794d-07, 8.2178096d-09 /
      data fpp(26, 9,13,1),fpp(26, 9,13,2),fpp(26, 9,13,3)/
     x-7.7011639d-05,-2.5123899d-07, 1.5025743d-08 /
      data fpp(26, 9,14,1),fpp(26, 9,14,2),fpp(26, 9,14,3)/
     x-7.9048623d-05,-2.2991754d-07, 1.5679219d-08 /
      data fpp(26, 9,15,1),fpp(26, 9,15,2),fpp(26, 9,15,3)/
     x-7.6922324d-05,-1.9787607d-07, 1.2257380d-08 /
      data fpp(26, 9,16,1),fpp(26, 9,16,2),fpp(26, 9,16,3)/
     x-6.9008200d-05,-1.6749778d-07, 1.2912622d-09 /
      data fpp(26, 9,17,1),fpp(26, 9,17,2),fpp(26, 9,17,3)/
     x-5.8937342d-05,-1.4441951d-07,-2.3422428d-08 /
      data fpp(26, 9,18,1),fpp(26, 9,18,2),fpp(26, 9,18,3)/
     x-4.9374996d-05,-1.2881374d-07,-3.9601549d-08 /
      data fpp(26, 9,19,1),fpp(26, 9,19,2),fpp(26, 9,19,3)/
     x-4.3565847d-05,-1.3317656d-07,-2.8171376d-08 /
      data fpp(26, 9,20,1),fpp(26, 9,20,2),fpp(26, 9,20,3)/
     x-4.1762238d-05,-1.4601591d-07, 4.4287052d-08 /
      data fpp(26, 9,21,1),fpp(26, 9,21,2),fpp(26, 9,21,3)/
     x-4.1762238d-05,-1.4601591d-07, 4.3224532d-08 /
      data fpp(26, 9,22,1),fpp(26, 9,22,2),fpp(26, 9,22,3)/
     x-4.3565847d-05,-1.3317656d-07,-2.3921295d-08 /
      data fpp(26, 9,23,1),fpp(26, 9,23,2),fpp(26, 9,23,3)/
     x-4.9374996d-05,-1.2881374d-07,-5.5539353d-08 /
      data fpp(26,10, 1,1),fpp(26,10, 1,2),fpp(26,10, 1,3)/
     x-2.1747602d-05,-1.0155311d-07, 1.5020422d-08 /
      data fpp(26,10, 2,1),fpp(26,10, 2,2),fpp(26,10, 2,3)/
     x-9.4242952d-06,-8.3067879d-08, 3.8459157d-08 /
      data fpp(26,10, 3,1),fpp(26,10, 3,2),fpp(26,10, 3,3)/
     x 4.3870756d-06,-7.0604156d-08, 8.9142951d-08 /
      data fpp(26,10, 4,1),fpp(26,10, 4,2),fpp(26,10, 4,3)/
     x 4.3870756d-06,-7.0604156d-08, 8.8341569d-08 /
      data fpp(26,10, 5,1),fpp(26,10, 5,2),fpp(26,10, 5,3)/
     x-9.4242952d-06,-8.3067879d-08, 4.1664684d-08 /
      data fpp(26,10, 6,1),fpp(26,10, 6,2),fpp(26,10, 6,3)/
     x-2.1747602d-05,-1.0155311d-07, 2.9996939d-09 /
      data fpp(26,10, 7,1),fpp(26,10, 7,2),fpp(26,10, 7,3)/
     x-2.7136379d-05,-1.2427028d-07,-4.1663460d-08 /
      data fpp(26,10, 8,1),fpp(26,10, 8,2),fpp(26,10, 8,3)/
     x-2.7116079d-05,-1.4466037d-07,-5.8345854d-08 /
      data fpp(26,10, 9,1),fpp(26,10, 9,2),fpp(26,10, 9,3)/
     x-2.4668694d-05,-1.3153940d-07,-4.8953125d-08 /
      data fpp(26,10,10,1),fpp(26,10,10,2),fpp(26,10,10,3)/
     x-2.6503180d-05,-1.4073351d-07,-3.3841648d-08 /
      data fpp(26,10,11,1),fpp(26,10,11,2),fpp(26,10,11,3)/
     x-3.0543913d-05,-1.3558133d-07,-7.6802851d-09 /
      data fpp(26,10,12,1),fpp(26,10,12,2),fpp(26,10,12,3)/
     x-3.6924705d-05,-1.3069258d-07, 4.5627880d-09 /
      data fpp(26,10,13,1),fpp(26,10,13,2),fpp(26,10,13,3)/
     x-4.3291478d-05,-1.2815580d-07, 1.3429133d-08 /
      data fpp(26,10,14,1),fpp(26,10,14,2),fpp(26,10,14,3)/
     x-4.7225664d-05,-1.1668951d-07, 7.7206793d-09 /
      data fpp(26,10,15,1),fpp(26,10,15,2),fpp(26,10,15,3)/
     x-4.8255486d-05,-1.0687769d-07, 3.6881494d-09 /
      data fpp(26,10,16,1),fpp(26,10,16,2),fpp(26,10,16,3)/
     x-4.7433148d-05,-9.5635631d-08,-1.0473277d-08 /
      data fpp(26,10,17,1),fpp(26,10,17,2),fpp(26,10,17,3)/
     x-4.3104717d-05,-7.9926884d-08,-2.7795041d-08 /
      data fpp(26,10,18,1),fpp(26,10,18,2),fpp(26,10,18,3)/
     x-4.0082088d-05,-6.7019423d-08,-4.6346559d-08 /
      data fpp(26,10,19,1),fpp(26,10,19,2),fpp(26,10,19,3)/
     x-3.9950754d-05,-5.2271275d-08,-2.6818725d-08 /
      data fpp(26,10,20,1),fpp(26,10,20,2),fpp(26,10,20,3)/
     x-4.3996038d-05,-4.3805854d-08, 6.3621457d-08 /
      data fpp(26,10,21,1),fpp(26,10,21,2),fpp(26,10,21,3)/
     x-4.3996038d-05,-4.3805854d-08, 6.2544990d-08 /
      data fpp(26,10,22,1),fpp(26,10,22,2),fpp(26,10,22,3)/
     x-3.9950754d-05,-5.2271275d-08,-2.2512854d-08 /
      data fpp(26,10,23,1),fpp(26,10,23,2),fpp(26,10,23,3)/
     x-4.0082088d-05,-6.7019423d-08,-6.2493573d-08 /
      data fpp(26,11, 1,1),fpp(26,11, 1,2),fpp(26,11, 1,3)/
     x-2.8728715d-05,-3.7954042d-09, 5.0951360d-08 /
      data fpp(26,11, 2,1),fpp(26,11, 2,2),fpp(26,11, 2,3)/
     x-3.9183351d-06, 4.4186573d-08, 6.0097280d-08 /
      data fpp(26,11, 3,1),fpp(26,11, 3,2),fpp(26,11, 3,3)/
     x 2.4879042d-05, 7.8722317d-08, 8.0659520d-08 /
      data fpp(26,11, 4,1),fpp(26,11, 4,2),fpp(26,11, 4,3)/
     x 2.4879042d-05, 7.8722317d-08, 7.8972799d-08 /
      data fpp(26,11, 5,1),fpp(26,11, 5,2),fpp(26,11, 5,3)/
     x-3.9183351d-06, 4.4186573d-08, 6.6844167d-08 /
      data fpp(26,11, 6,1),fpp(26,11, 6,2),fpp(26,11, 6,3)/
     x-2.8728715d-05,-3.7954042d-09, 2.5650533d-08 /
      data fpp(26,11, 7,1),fpp(26,11, 7,2),fpp(26,11, 7,3)/
     x-3.7610079d-05,-3.7956256d-08,-1.9446297d-08 /
      data fpp(26,11, 8,1),fpp(26,11, 8,2),fpp(26,11, 8,3)/
     x-3.4145518d-05,-1.9043527d-08,-5.5865343d-08 /
      data fpp(26,11, 9,1),fpp(26,11, 9,2),fpp(26,11, 9,3)/
     x-2.7450101d-05,-7.6180419d-08,-6.9092331d-08 /
      data fpp(26,11,10,1),fpp(26,11,10,2),fpp(26,11,10,3)/
     x-2.1414235d-05,-5.5334443d-08,-3.9765333d-08 /
      data fpp(26,11,11,1),fpp(26,11,11,2),fpp(26,11,11,3)/
     x-2.0236172d-05,-4.6770684d-08,-2.3846338d-08 /
      data fpp(26,11,12,1),fpp(26,11,12,2),fpp(26,11,12,3)/
     x-2.2012854d-05,-3.4591727d-08, 3.1506859d-09 /
      data fpp(26,11,13,1),fpp(26,11,13,2),fpp(26,11,13,3)/
     x-2.5429354d-05,-2.2137802d-08, 1.7243595d-08 /
      data fpp(26,11,14,1),fpp(26,11,14,2),fpp(26,11,14,3)/
     x-3.0682482d-05,-3.5324402d-08,-1.2506462d-10 /
      data fpp(26,11,15,1),fpp(26,11,15,2),fpp(26,11,15,3)/
     x-3.4087017d-05,-4.6613185d-08,-4.7433362d-09 /
      data fpp(26,11,16,1),fpp(26,11,16,2),fpp(26,11,16,3)/
     x-3.5743919d-05,-5.5959692d-08,-1.6901591d-08 /
      data fpp(26,11,17,1),fpp(26,11,17,2),fpp(26,11,17,3)/
     x-3.5981283d-05,-5.7872951d-08,-3.5650301d-08 /
      data fpp(26,11,18,1),fpp(26,11,18,2),fpp(26,11,18,3)/
     x-3.5332611d-05,-4.7108571d-08,-5.0497204d-08 /
      data fpp(26,11,19,1),fpp(26,11,19,2),fpp(26,11,19,3)/
     x-3.8231073d-05,-2.3738337d-08,-3.2360882d-08 /
      data fpp(26,11,20,1),fpp(26,11,20,2),fpp(26,11,20,3)/
     x-4.3903691d-05, 3.2393237d-09, 7.7940732d-08 /
      data fpp(26,11,21,1),fpp(26,11,21,2),fpp(26,11,21,3)/
     x-4.3903691d-05, 3.2393237d-09, 7.6358244d-08 /
      data fpp(26,11,22,1),fpp(26,11,22,2),fpp(26,11,22,3)/
     x-3.8231073d-05,-2.3738337d-08,-2.6030927d-08 /
      data fpp(26,11,23,1),fpp(26,11,23,2),fpp(26,11,23,3)/
     x-3.5332611d-05,-4.7108571d-08,-7.4234537d-08 /
      data fpp(26,12, 1,1),fpp(26,12, 1,2),fpp(26,12, 1,3)/
     x-3.4111120d-05, 7.4734731d-08, 8.0266387d-08 /
      data fpp(26,12, 2,1),fpp(26,12, 2,2),fpp(26,12, 2,3)/
     x 3.7828247d-06, 8.6321587d-08, 7.1467226d-08 /
      data fpp(26,12, 3,1),fpp(26,12, 3,2),fpp(26,12, 3,3)/
     x 4.7210109d-05, 9.1714890d-08, 5.3864709d-08 /
      data fpp(26,12, 4,1),fpp(26,12, 4,2),fpp(26,12, 4,3)/
     x 4.7210109d-05, 9.1714890d-08, 5.1672261d-08 /
      data fpp(26,12, 5,1),fpp(26,12, 5,2),fpp(26,12, 5,3)/
     x 3.7828247d-06, 8.6321587d-08, 8.0237016d-08 /
      data fpp(26,12, 6,1),fpp(26,12, 6,2),fpp(26,12, 6,3)/
     x-3.4111120d-05, 7.4734731d-08, 4.7379673d-08 /
      data fpp(26,12, 7,1),fpp(26,12, 7,2),fpp(26,12, 7,3)/
     x-4.8234342d-05, 4.8095310d-08, 5.4244290d-08 /
      data fpp(26,12, 8,1),fpp(26,12, 8,2),fpp(26,12, 8,3)/
     x-5.8557381d-05,-4.9165517d-08,-1.1435683d-07 /
      data fpp(26,12, 9,1),fpp(26,12, 9,2),fpp(26,12, 9,3)/
     x-3.4619164d-05, 4.2610763d-09,-1.6816954d-08 /
      data fpp(26,12,10,1),fpp(26,12,10,2),fpp(26,12,10,3)/
     x-2.6434900d-05,-2.1928721d-08,-6.4375350d-08 /
      data fpp(26,12,11,1),fpp(26,12,11,2),fpp(26,12,11,3)/
     x-2.1524402d-05,-7.3359309d-09,-3.1681647d-08 /
      data fpp(26,12,12,1),fpp(26,12,12,2),fpp(26,12,12,3)/
     x-1.9749650d-05, 5.0594935d-09,-8.9806124d-10 /
      data fpp(26,12,13,1),fpp(26,12,13,2),fpp(26,12,13,3)/
     x-2.0411191d-05,-5.2929906d-09,-7.2610777d-10 /
      data fpp(26,12,14,1),fpp(26,12,14,2),fpp(26,12,14,3)/
     x-2.2503777d-05,-6.0128802d-09,-2.1975077d-09 /
      data fpp(26,12,15,1),fpp(26,12,15,2),fpp(26,12,15,3)/
     x-2.5494993d-05,-1.2669571d-08,-1.4483861d-08 /
      data fpp(26,12,16,1),fpp(26,12,16,2),fpp(26,12,16,3)/
     x-2.8963869d-05,-2.2525601d-08,-1.7867047d-08 /
      data fpp(26,12,17,1),fpp(26,12,17,2),fpp(26,12,17,3)/
     x-3.0563726d-05,-3.6581314d-08,-3.4047952d-08 /
      data fpp(26,12,18,1),fpp(26,12,18,2),fpp(26,12,18,3)/
     x-3.2149298d-05,-4.4546292d-08,-4.3941144d-08 /
      data fpp(26,12,19,1),fpp(26,12,19,2),fpp(26,12,19,3)/
     x-3.4780380d-05,-4.4775379d-08,-3.0187472d-08 /
      data fpp(26,12,20,1),fpp(26,12,20,2),fpp(26,12,20,3)/
     x-3.8188308d-05,-2.9151441d-08, 7.4691032d-08 /
      data fpp(26,12,21,1),fpp(26,12,21,2),fpp(26,12,21,3)/
     x-3.8188308d-05,-2.9151441d-08, 7.3020639d-08 /
      data fpp(26,12,22,1),fpp(26,12,22,2),fpp(26,12,22,3)/
     x-3.4780380d-05,-4.4775379d-08,-2.3505897d-08 /
      data fpp(26,12,23,1),fpp(26,12,23,2),fpp(26,12,23,3)/
     x-3.2149298d-05,-4.4546292d-08,-6.8997052d-08 /
      data fpp(26,13, 1,1),fpp(26,13, 1,2),fpp(26,13, 1,3)/
     x-2.8785414d-05, 1.1885648d-07, 9.6128727d-08 /
      data fpp(26,13, 2,1),fpp(26,13, 2,2),fpp(26,13, 2,3)/
     x 1.9262254d-05, 1.0252708d-07, 7.3242547d-08 /
      data fpp(26,13, 3,1),fpp(26,13, 3,2),fpp(26,13, 3,3)/
     x 7.0682231d-05, 7.0418125d-08, 2.4901087d-08 /
      data fpp(26,13, 4,1),fpp(26,13, 4,2),fpp(26,13, 4,3)/
     x 7.0682231d-05, 7.0418125d-08, 2.3675467d-08 /
      data fpp(26,13, 5,1),fpp(26,13, 5,2),fpp(26,13, 5,3)/
     x 1.9262254d-05, 1.0252708d-07, 7.8145025d-08 /
      data fpp(26,13, 6,1),fpp(26,13, 6,2),fpp(26,13, 6,3)/
     x-2.8785414d-05, 1.1885648d-07, 7.7744433d-08 /
      data fpp(26,13, 7,1),fpp(26,13, 7,2),fpp(26,13, 7,3)/
     x-5.1823260d-05, 1.0957502d-07, 3.6877242d-08 /
      data fpp(26,13, 8,1),fpp(26,13, 8,2),fpp(26,13, 8,3)/
     x-5.2420370d-05, 1.2570560d-07,-2.1253402d-08 /
      data fpp(26,13, 9,1),fpp(26,13, 9,2),fpp(26,13, 9,3)/
     x-4.3205475d-05, 4.7136114d-08,-4.7863634d-08 /
      data fpp(26,13,10,1),fpp(26,13,10,2),fpp(26,13,10,3)/
     x-3.3667764d-05, 6.5049326d-08,-5.1292062d-08 /
      data fpp(26,13,11,1),fpp(26,13,11,2),fpp(26,13,11,3)/
     x-2.6486838d-05, 4.1144075d-09,-3.4968119d-08 /
      data fpp(26,13,12,1),fpp(26,13,12,2),fpp(26,13,12,3)/
     x-2.2793135d-05,-1.5646247d-08,-2.4835461d-08 /
      data fpp(26,13,13,1),fpp(26,13,13,2),fpp(26,13,13,3)/
     x-1.9899610d-05,-1.0690236d-08,-9.6900353d-09 /
      data fpp(26,13,14,1),fpp(26,13,14,2),fpp(26,13,14,3)/
     x-1.9798722d-05,-1.2624078d-08,-1.4404398d-08 /
      data fpp(26,13,15,1),fpp(26,13,15,2),fpp(26,13,15,3)/
     x-2.2394252d-05,-2.2708530d-08,-2.2692375d-08 /
      data fpp(26,13,16,1),fpp(26,13,16,2),fpp(26,13,16,3)/
     x-2.6283169d-05,-2.7937904d-08,-2.0826104d-08 /
      data fpp(26,13,17,1),fpp(26,13,17,2),fpp(26,13,17,3)/
     x-2.9085790d-05,-2.3801794d-08,-2.6003208d-08 /
      data fpp(26,13,18,1),fpp(26,13,18,2),fpp(26,13,18,3)/
     x-2.9876079d-05,-2.6706259d-08,-3.1161062d-08 /
      data fpp(26,13,19,1),fpp(26,13,19,2),fpp(26,13,19,3)/
     x-2.9923734d-05,-2.5160147d-08,-1.1352543d-08 /
      data fpp(26,13,20,1),fpp(26,13,20,2),fpp(26,13,20,3)/
     x-3.1849882d-05,-3.0633559d-08, 5.8571235d-08 /
      data fpp(26,13,21,1),fpp(26,13,21,2),fpp(26,13,21,3)/
     x-3.1849882d-05,-3.0633559d-08, 5.7962568d-08 /
      data fpp(26,13,22,1),fpp(26,13,22,2),fpp(26,13,22,3)/
     x-2.9923734d-05,-2.5160147d-08,-8.9178765d-09 /
      data fpp(26,13,23,1),fpp(26,13,23,2),fpp(26,13,23,3)/
     x-2.9876079d-05,-2.6706259d-08,-4.0291062d-08 /
      data fpp(26,14, 1,1),fpp(26,14, 1,2),fpp(26,14, 1,3)/
     x-1.4549213d-05, 9.7839344d-08, 8.0560995d-08 /
      data fpp(26,14, 2,1),fpp(26,14, 2,2),fpp(26,14, 2,3)/
     x 3.0722912d-05, 7.9570094d-08, 5.9878010d-08 /
      data fpp(26,14, 3,1),fpp(26,14, 3,2),fpp(26,14, 3,3)/
     x 7.6934864d-05, 5.8612612d-08, 1.5926964d-08 /
      data fpp(26,14, 4,1),fpp(26,14, 4,2),fpp(26,14, 4,3)/
     x 7.6934864d-05, 5.8612612d-08, 1.5280104d-08 /
      data fpp(26,14, 5,1),fpp(26,14, 5,2),fpp(26,14, 5,3)/
     x 3.0722912d-05, 7.9570094d-08, 6.2465448d-08 /
      data fpp(26,14, 6,1),fpp(26,14, 6,2),fpp(26,14, 6,3)/
     x-1.4549213d-05, 9.7839344d-08, 7.0858103d-08 /
      data fpp(26,14, 7,1),fpp(26,14, 7,2),fpp(26,14, 7,3)/
     x-4.1575383d-05, 1.0160462d-07, 5.0102139d-08 /
      data fpp(26,14, 8,1),fpp(26,14, 8,2),fpp(26,14, 8,3)/
     x-4.9079541d-05, 7.4343134d-08,-1.3266658d-08 /
      data fpp(26,14, 9,1),fpp(26,14, 9,2),fpp(26,14, 9,3)/
     x-4.3776687d-05, 5.9194468d-08, 1.4964495d-08 /
      data fpp(26,14,10,1),fpp(26,14,10,2),fpp(26,14,10,3)/
     x-4.9603860d-05,-4.0268583d-08,-1.0659132d-07 /
      data fpp(26,14,11,1),fpp(26,14,11,2),fpp(26,14,11,3)/
     x-3.0588918d-05,-3.1216991d-09, 3.4007845d-09 /
      data fpp(26,14,12,1),fpp(26,14,12,2),fpp(26,14,12,3)/
     x-2.4623958d-05,-2.0474507d-08,-3.9011818d-08 /
      data fpp(26,14,13,1),fpp(26,14,13,2),fpp(26,14,13,3)/
     x-2.2362735d-05,-3.5946066d-08,-2.1353512d-08 /
      data fpp(26,14,14,1),fpp(26,14,14,2),fpp(26,14,14,3)/
     x-2.2303839d-05,-3.9490810d-08,-3.1574134d-08 /
      data fpp(26,14,15,1),fpp(26,14,15,2),fpp(26,14,15,3)/
     x-2.4308894d-05,-2.2496308d-08,-2.6349951d-08 /
      data fpp(26,14,16,1),fpp(26,14,16,2),fpp(26,14,16,3)/
     x-2.6647292d-05,-3.7227821d-09,-1.9026061d-08 /
      data fpp(26,14,17,1),fpp(26,14,17,2),fpp(26,14,17,3)/
     x-2.9523342d-05,-2.1151044d-10,-2.3545803d-08 /
      data fpp(26,14,18,1),fpp(26,14,18,2),fpp(26,14,18,3)/
     x-3.0758038d-05, 1.3371329d-08,-1.2790725d-08 /
      data fpp(26,14,19,1),fpp(26,14,19,2),fpp(26,14,19,3)/
     x-3.1250298d-05, 1.3415968d-08, 2.7087052d-09 /
      data fpp(26,14,20,1),fpp(26,14,20,2),fpp(26,14,20,3)/
     x-3.2078670d-05, 1.3685676d-08, 4.3955905d-08 /
      data fpp(26,14,21,1),fpp(26,14,21,2),fpp(26,14,21,3)/
     x-3.2078670d-05, 1.3685676d-08, 4.3777933d-08 /
      data fpp(26,14,22,1),fpp(26,14,22,2),fpp(26,14,22,3)/
     x-3.1250298d-05, 1.3415968d-08, 3.4205905d-09 /
      data fpp(26,14,23,1),fpp(26,14,23,2),fpp(26,14,23,3)/
     x-3.0758038d-05, 1.3371329d-08,-1.5460295d-08 /
      data fpp(26,15, 1,1),fpp(26,15, 1,2),fpp(26,15, 1,3)/
     x 1.2587257d-07, 5.9786143d-08, 5.1576698d-08 /
      data fpp(26,15, 2,1),fpp(26,15, 2,2),fpp(26,15, 2,3)/
     x 3.1797989d-05, 5.9192544d-08, 4.1846604d-08 /
      data fpp(26,15, 3,1),fpp(26,15, 3,2),fpp(26,15, 3,3)/
     x 6.0094252d-05, 6.7131427d-08, 2.1036886d-08 /
      data fpp(26,15, 4,1),fpp(26,15, 4,2),fpp(26,15, 4,3)/
     x 6.0094252d-05, 6.7131427d-08, 2.0966041d-08 /
      data fpp(26,15, 5,1),fpp(26,15, 5,2),fpp(26,15, 5,3)/
     x 3.1797989d-05, 5.9192544d-08, 4.2129982d-08 /
      data fpp(26,15, 6,1),fpp(26,15, 6,2),fpp(26,15, 6,3)/
     x 1.2587257d-07, 5.9786143d-08, 5.0514032d-08 /
      data fpp(26,15, 7,1),fpp(26,15, 7,2),fpp(26,15, 7,3)/
     x-2.2887381d-05, 6.0006496d-08, 3.7813890d-08 /
      data fpp(26,15, 8,1),fpp(26,15, 8,2),fpp(26,15, 8,3)/
     x-3.4889940d-05, 5.6921867d-08, 8.2304065d-09 /
      data fpp(26,15, 9,1),fpp(26,15, 9,2),fpp(26,15, 9,3)/
     x-3.6388094d-05, 4.0086013d-08,-1.0735517d-08 /
      data fpp(26,15,10,1),fpp(26,15,10,2),fpp(26,15,10,3)/
     x-3.4479441d-05, 6.0025007d-08,-2.5288340d-08 /
      data fpp(26,15,11,1),fpp(26,15,11,2),fpp(26,15,11,3)/
     x-3.1623709d-05,-3.6276110d-09,-3.2111122d-08 /
      data fpp(26,15,12,1),fpp(26,15,12,2),fpp(26,15,12,3)/
     x-2.7689271d-05,-2.2455726d-08,-2.6267171d-08 /
      data fpp(26,15,13,1),fpp(26,15,13,2),fpp(26,15,13,3)/
     x-2.6577734d-05,-3.7525502d-08,-3.0820194d-08 /
      data fpp(26,15,14,1),fpp(26,15,14,2),fpp(26,15,14,3)/
     x-9.2437066d-06,-3.9412684d-08,-3.0452053d-08 /
      data fpp(26,15,15,1),fpp(26,15,15,2),fpp(26,15,15,3)/
     x-2.8095208d-05,-3.7306238d-08,-2.7371592d-08 /
      data fpp(26,15,16,1),fpp(26,15,16,2),fpp(26,15,16,3)/
     x-3.0977736d-05,-2.9170967d-08,-2.8061577d-08 /
      data fpp(26,15,17,1),fpp(26,15,17,2),fpp(26,15,17,3)/
     x-3.2602269d-05, 6.4783567d-10,-1.0382101d-08 /
      data fpp(26,15,18,1),fpp(26,15,18,2),fpp(26,15,18,3)/
     x-3.5657453d-05, 1.5220942d-08,-8.4100208d-09 /
      data fpp(26,15,19,1),fpp(26,15,19,2),fpp(26,15,19,3)/
     x-3.6764794d-05, 3.1496274d-08, 1.4022184d-08 /
      data fpp(26,15,20,1),fpp(26,15,20,2),fpp(26,15,20,3)/
     x-3.8875407d-05, 2.9890855d-08, 3.0321286d-08 /
      data fpp(26,15,21,1),fpp(26,15,21,2),fpp(26,15,21,3)/
     x-3.8875407d-05, 2.9890855d-08, 3.1025050d-08 /
      data fpp(26,15,22,1),fpp(26,15,22,2),fpp(26,15,22,3)/
     x-3.6764794d-05, 3.1496274d-08, 1.1207129d-08 /
      data fpp(26,15,23,1),fpp(26,15,23,2),fpp(26,15,23,3)/
     x-3.5657453d-05, 1.5220942d-08, 2.1464357d-09 /
      data fpp(26,16, 1,1),fpp(26,16, 1,2),fpp(26,16, 1,3)/
     x 5.7938492d-06, 2.3016085d-08, 3.2949447d-08 /
      data fpp(26,16, 2,1),fpp(26,16, 2,2),fpp(26,16, 2,3)/
     x 2.3945839d-05, 3.7659731d-08, 2.9601106d-08 /
      data fpp(26,16, 3,1),fpp(26,16, 3,2),fpp(26,16, 3,3)/
     x 3.6133400d-05, 5.0861679d-08, 2.2646129d-08 /
      data fpp(26,16, 4,1),fpp(26,16, 4,2),fpp(26,16, 4,3)/
     x 3.6133400d-05, 5.0861679d-08, 2.2261060d-08 /
      data fpp(26,16, 5,1),fpp(26,16, 5,2),fpp(26,16, 5,3)/
     x 2.3945839d-05, 3.7659731d-08, 3.1141381d-08 /
      data fpp(26,16, 6,1),fpp(26,16, 6,2),fpp(26,16, 6,3)/
     x 5.7938492d-06, 2.3016085d-08, 2.7173415d-08 /
      data fpp(26,16, 7,1),fpp(26,16, 7,2),fpp(26,16, 7,3)/
     x-9.4989690d-06, 1.8369393d-08, 2.2164960d-08 /
      data fpp(26,16, 8,1),fpp(26,16, 8,2),fpp(26,16, 8,3)/
     x-1.9651524d-05, 2.1969396d-08, 1.0166747d-08 /
      data fpp(26,16, 9,1),fpp(26,16, 9,2),fpp(26,16, 9,3)/
     x-2.5106880d-05, 2.0461481d-08,-2.8319471d-09 /
      data fpp(26,16,10,1),fpp(26,16,10,2),fpp(26,16,10,3)/
     x-2.7578636d-05, 4.1685548d-09,-1.0838958d-08 /
      data fpp(26,16,11,1),fpp(26,16,11,2),fpp(26,16,11,3)/
     x-2.8285713d-05,-3.6785684d-10,-1.9812219d-08 /
      data fpp(26,16,12,1),fpp(26,16,12,2),fpp(26,16,12,3)/
     x-2.8458637d-05,-1.5702589d-08,-2.3912164d-08 /
      data fpp(26,16,13,1),fpp(26,16,13,2),fpp(26,16,13,3)/
     x-2.8212838d-05,-2.3951927d-08,-2.2539123d-08 /
      data fpp(26,16,14,1),fpp(26,16,14,2),fpp(26,16,14,3)/
     x-2.9949184d-05,-3.0858456d-08,-2.3931343d-08 /
      data fpp(26,16,15,1),fpp(26,16,15,2),fpp(26,16,15,3)/
     x-3.2588570d-05,-3.2278740d-08,-2.5735505d-08 /
      data fpp(26,16,16,1),fpp(26,16,16,2),fpp(26,16,16,3)/
     x-3.7695090d-05,-2.3593349d-08,-1.7126638d-08 /
      data fpp(26,16,17,1),fpp(26,16,17,2),fpp(26,16,17,3)/
     x-3.7089516d-05,-2.0379832d-08,-1.3757945d-08 /
      data fpp(26,16,18,1),fpp(26,16,18,2),fpp(26,16,18,3)/
     x-3.8902000d-05,-8.2550979d-09, 1.5841704d-10 /
      data fpp(26,16,19,1),fpp(26,16,19,2),fpp(26,16,19,3)/
     x-4.1333341d-05,-7.4010630d-09, 7.1242767d-09 /
      data fpp(26,16,20,1),fpp(26,16,20,2),fpp(26,16,20,3)/
     x-4.2535647d-05,-1.2490951d-09, 1.9344476d-08 /
      data fpp(26,16,21,1),fpp(26,16,21,2),fpp(26,16,21,3)/
     x-4.2535647d-05,-1.2490951d-09, 1.9404433d-08 /
      data fpp(26,16,22,1),fpp(26,16,22,2),fpp(26,16,22,3)/
     x-4.1333341d-05,-7.4010630d-09, 6.8844476d-09 /
      data fpp(26,16,23,1),fpp(26,16,23,2),fpp(26,16,23,3)/
     x-3.8902000d-05,-8.2550979d-09, 1.0577762d-09 /
      data fpp(26,17, 1,1),fpp(26,17, 1,2),fpp(26,17, 1,3)/
     x 7.4113306d-07, 4.1495154d-09, 1.8941807d-08 /
      data fpp(26,17, 2,1),fpp(26,17, 2,2),fpp(26,17, 2,3)/
     x 7.2915323d-06, 6.1685341d-09, 1.8116386d-08 /
      data fpp(26,17, 3,1),fpp(26,17, 3,2),fpp(26,17, 3,3)/
     x 1.1010527d-05, 5.4218556d-09, 1.6592649d-08 /
      data fpp(26,17, 4,1),fpp(26,17, 4,2),fpp(26,17, 4,3)/
     x 1.1010527d-05, 5.4218556d-09, 1.6163861d-08 /
      data fpp(26,17, 5,1),fpp(26,17, 5,2),fpp(26,17, 5,3)/
     x 7.2915323d-06, 6.1685341d-09, 1.9831538d-08 /
      data fpp(26,17, 6,1),fpp(26,17, 6,2),fpp(26,17, 6,3)/
     x 7.4113306d-07, 4.1495154d-09, 1.2509988d-08 /
      data fpp(26,17, 7,1),fpp(26,17, 7,2),fpp(26,17, 7,3)/
     x-5.7159280d-06, 4.5159327d-09, 1.4128510d-08 /
      data fpp(26,17, 8,1),fpp(26,17, 8,2),fpp(26,17, 8,3)/
     x-1.3076375d-05, 5.2005471d-09, 2.9759703d-09 /
      data fpp(26,17, 9,1),fpp(26,17, 9,2),fpp(26,17, 9,3)/
     x-1.7315217d-05, 1.0068063d-08, 3.9676084d-09 /
      data fpp(26,17,10,1),fpp(26,17,10,2),fpp(26,17,10,3)/
     x-2.1265145d-05, 1.3300774d-08,-6.8464040d-09 /
      data fpp(26,17,11,1),fpp(26,17,11,2),fpp(26,17,11,3)/
     x-2.4288159d-05, 1.1099038d-08,-6.5819923d-09 /
      data fpp(26,17,12,1),fpp(26,17,12,2),fpp(26,17,12,3)/
     x-2.6697176d-05, 7.2660816d-09,-1.4825627d-08 /
      data fpp(26,17,13,1),fpp(26,17,13,2),fpp(26,17,13,3)/
     x-2.8410684d-05, 1.3332112d-09,-1.2115501d-08 /
      data fpp(26,17,14,1),fpp(26,17,14,2),fpp(26,17,14,3)/
     x-3.0823528d-05,-5.1534926d-09,-1.4712368d-08 /
      data fpp(26,17,15,1),fpp(26,17,15,2),fpp(26,17,15,3)/
     x-3.3326401d-05,-1.3578801d-08,-1.3035026d-08 /
      data fpp(26,17,16,1),fpp(26,17,16,2),fpp(26,17,16,3)/
     x-3.6029582d-05,-2.6455637d-08,-1.1147527d-08 /
      data fpp(26,17,17,1),fpp(26,17,17,2),fpp(26,17,17,3)/
     x-3.8068053d-05,-3.9128507d-08,-8.3748640d-09 /
      data fpp(26,17,18,1),fpp(26,17,18,2),fpp(26,17,18,3)/
     x-3.9737100d-05,-5.4200551d-08,-3.3530165d-09 /
      data fpp(26,17,19,1),fpp(26,17,19,2),fpp(26,17,19,3)/
     x-4.0815179d-05,-6.1892021d-08, 3.7869301d-09 /
      data fpp(26,17,20,1),fpp(26,17,20,2),fpp(26,17,20,3)/
     x-4.1710766d-05,-7.2894474d-08, 6.2052962d-09 /
      data fpp(26,17,21,1),fpp(26,17,21,2),fpp(26,17,21,3)/
     x-4.1710766d-05,-7.2894474d-08, 6.4906463d-09 /
      data fpp(26,17,22,1),fpp(26,17,22,2),fpp(26,17,22,3)/
     x-4.0815179d-05,-6.1892021d-08, 2.6455296d-09 /
      data fpp(26,17,23,1),fpp(26,17,23,2),fpp(26,17,23,3)/
     x-3.9737100d-05,-5.4200551d-08, 9.2723519d-10 /
      data fpp(26,18, 1,1),fpp(26,18, 1,2),fpp(26,18, 1,3)/
     x-1.1600168d-05,-2.7614147d-08, 4.1471654d-09 /
      data fpp(26,18, 2,1),fpp(26,18, 2,2),fpp(26,18, 2,3)/
     x-9.5641287d-06,-3.2333867d-08, 5.7056693d-09 /
      data fpp(26,18, 3,1),fpp(26,18, 3,2),fpp(26,18, 3,3)/
     x-8.3431045d-06,-3.0549102d-08, 9.0301576d-09 /
      data fpp(26,18, 4,1),fpp(26,18, 4,2),fpp(26,18, 4,3)/
     x-8.3431045d-06,-3.0549102d-08, 9.0566927d-09 /
      data fpp(26,18, 5,1),fpp(26,18, 5,2),fpp(26,18, 5,3)/
     x-9.5641287d-06,-3.2333867d-08, 5.5995290d-09 /
      data fpp(26,18, 6,1),fpp(26,18, 6,2),fpp(26,18, 6,3)/
     x-1.1600168d-05,-2.7614147d-08, 4.5451915d-09 /
      data fpp(26,18, 7,1),fpp(26,18, 7,2),fpp(26,18, 7,3)/
     x-1.3143577d-05,-1.8433124d-08, 6.2197049d-09 /
      data fpp(26,18, 8,1),fpp(26,18, 8,2),fpp(26,18, 8,3)/
     x-1.5934217d-05,-6.7715849d-09, 5.7598884d-10 /
      data fpp(26,18, 9,1),fpp(26,18, 9,2),fpp(26,18, 9,3)/
     x-1.7925536d-05, 5.2662678d-09, 3.4763397d-09 /
      data fpp(26,18,10,1),fpp(26,18,10,2),fpp(26,18,10,3)/
     x-2.0430528d-05, 1.4628350d-08,-2.4813478d-09 /
      data fpp(26,18,11,1),fpp(26,18,11,2),fpp(26,18,11,3)/
     x-2.2059137d-05, 2.1971703d-08, 4.4905129d-10 /
      data fpp(26,18,12,1),fpp(26,18,12,2),fpp(26,18,12,3)/
     x-2.4929726d-05, 2.2638262d-08,-5.3148574d-09 /
      data fpp(26,18,13,1),fpp(26,18,13,2),fpp(26,18,13,3)/
     x-2.7264569d-05, 1.8619083d-08,-3.1896216d-09 /
      data fpp(26,18,14,1),fpp(26,18,14,2),fpp(26,18,14,3)/
     x-2.8992519d-05, 9.4724265d-09,-5.9266560d-09 /
      data fpp(26,18,15,1),fpp(26,18,15,2),fpp(26,18,15,3)/
     x-3.0416223d-05,-3.4060570d-09,-3.1037544d-09 /
      data fpp(26,18,16,1),fpp(26,18,16,2),fpp(26,18,16,3)/
     x-3.1966558d-05,-2.0584104d-08,-5.6583265d-09 /
      data fpp(26,18,17,1),fpp(26,18,17,2),fpp(26,18,17,3)/
     x-3.2820703d-05,-3.9106141d-08,-4.2629395d-09 /
      data fpp(26,18,18,1),fpp(26,18,18,2),fpp(26,18,18,3)/
     x-3.3281367d-05,-5.6942700d-08,-1.2899155d-09 /
      data fpp(26,18,19,1),fpp(26,18,19,2),fpp(26,18,19,3)/
     x-3.4558362d-05,-7.5030851d-08,-2.5773984d-09 /
      data fpp(26,18,20,1),fpp(26,18,20,2),fpp(26,18,20,3)/
     x-3.4754278d-05,-8.5173007d-08,-4.0049087d-10 /
      data fpp(26,18,21,1),fpp(26,18,21,2),fpp(26,18,21,3)/
     x-3.4754278d-05,-8.5173007d-08,-5.0982820d-10 /
      data fpp(26,18,22,1),fpp(26,18,22,2),fpp(26,18,22,3)/
     x-3.4558362d-05,-7.5030851d-08,-2.1400491d-09 /
      data fpp(26,18,23,1),fpp(26,18,23,2),fpp(26,18,23,3)/
     x-3.3281367d-05,-5.6942700d-08,-2.9299755d-09 /
      data fpp(26,19, 1,1),fpp(26,19, 1,2),fpp(26,19, 1,3)/
     x-2.3276086d-05,-5.5692926d-08,-1.0425024d-22 /
      data fpp(26,19, 2,1),fpp(26,19, 2,2),fpp(26,19, 2,3)/
     x-2.3276086d-05,-6.8833067d-08, 1.0212529d-22 /
      data fpp(26,19, 3,1),fpp(26,19, 3,2),fpp(26,19, 3,3)/
     x-2.3276086d-05,-6.9225449d-08, 3.5884556d-22 /
      data fpp(26,19, 4,1),fpp(26,19, 4,2),fpp(26,19, 4,3)/
     x-2.3276086d-05,-6.9225449d-08,-1.0071680d-22 /
      data fpp(26,19, 5,1),fpp(26,19, 5,2),fpp(26,19, 5,3)/
     x-2.3276086d-05,-6.8833067d-08,-2.3701019d-22 /
      data fpp(26,19, 6,1),fpp(26,19, 6,2),fpp(26,19, 6,3)/
     x-2.3276086d-05,-5.5692926d-08, 1.4766441d-22 /
      data fpp(26,19, 7,1),fpp(26,19, 7,2),fpp(26,19, 7,3)/
     x-2.3276086d-05,-3.8783438d-08, 8.1048410d-22 /
      data fpp(26,19, 8,1),fpp(26,19, 8,2),fpp(26,19, 8,3)/
     x-2.3276086d-05,-2.0114208d-08, 2.7411389d-22 /
      data fpp(26,19, 9,1),fpp(26,19, 9,2),fpp(26,19, 9,3)/
     x-2.3276086d-05,-1.1331339d-09, 2.2086275d-22 /
      data fpp(26,19,10,1),fpp(26,19,10,2),fpp(26,19,10,3)/
     x-2.3276086d-05, 1.8185825d-08,-3.7920748d-22 /
      data fpp(26,19,11,1),fpp(26,19,11,2),fpp(26,19,11,3)/
     x-2.3276086d-05, 3.3014148d-08, 4.0173935d-22 /
      data fpp(26,19,12,1),fpp(26,19,12,2),fpp(26,19,12,3)/
     x-2.3276086d-05, 4.0180869d-08,-4.2191235d-22 /
      data fpp(26,19,13,1),fpp(26,19,13,2),fpp(26,19,13,3)/
     x-2.3276086d-05, 3.8190459d-08,-2.0733442d-22 /
      data fpp(26,19,14,1),fpp(26,19,14,2),fpp(26,19,14,3)/
     x-2.3276086d-05, 2.7263787d-08, 6.5084458d-23 /
      data fpp(26,19,15,1),fpp(26,19,15,2),fpp(26,19,15,3)/
     x-2.3276086d-05, 9.2030285d-09, 3.3090259d-22 /
      data fpp(26,19,16,1),fpp(26,19,16,2),fpp(26,19,16,3)/
     x-2.3276086d-05,-1.7207948d-08,-5.5448064d-25 /
      data fpp(26,19,17,1),fpp(26,19,17,2),fpp(26,19,17,3)/
     x-2.3276086d-05,-4.4446930d-08,-4.6372397d-22 /
      data fpp(26,19,18,1),fpp(26,19,18,2),fpp(26,19,18,3)/
     x-2.3276086d-05,-7.2028650d-08, 4.4860695d-22 /
      data fpp(26,19,19,1),fpp(26,19,19,2),fpp(26,19,19,3)/
     x-2.3276086d-05,-9.9984574d-08,-5.0426256d-23 /
      data fpp(26,19,20,1),fpp(26,19,20,2),fpp(26,19,20,3)/
     x-2.3276086d-05,-1.1441350d-07,-4.5045860d-22 /
      data fpp(26,19,21,1),fpp(26,19,21,2),fpp(26,19,21,3)/
     x-2.3276086d-05,-1.1441350d-07, 2.0542471d-22 /
      data fpp(26,19,22,1),fpp(26,19,22,2),fpp(26,19,22,3)/
     x-2.3276086d-05,-9.9984574d-08,-5.3494066d-22 /
      data fpp(26,19,23,1),fpp(26,19,23,2),fpp(26,19,23,3)/
     x-2.3276086d-05,-7.2028650d-08,-1.2698231d-21 /
      data fpp(27, 1, 1,1),fpp(27, 1, 1,2),fpp(27, 1, 1,3)/
     x 2.9169190d-05,-1.8546862d-07, 2.0015331d-22 /
      data fpp(27, 1, 2,1),fpp(27, 1, 2,2),fpp(27, 1, 2,3)/
     x 2.9169190d-05,-1.7201319d-07,-3.4812992d-22 /
      data fpp(27, 1, 3,1),fpp(27, 1, 3,2),fpp(27, 1, 3,3)/
     x 2.9169190d-05,-1.6286182d-07, 6.6276335d-22 /
      data fpp(27, 1, 4,1),fpp(27, 1, 4,2),fpp(27, 1, 4,3)/
     x 2.9169190d-05,-1.6286182d-07,-6.1461796d-22 /
      data fpp(27, 1, 5,1),fpp(27, 1, 5,2),fpp(27, 1, 5,3)/
     x 2.9169190d-05,-1.7201319d-07, 3.4720458d-23 /
      data fpp(27, 1, 6,1),fpp(27, 1, 6,2),fpp(27, 1, 6,3)/
     x 2.9169190d-05,-1.8546862d-07, 2.9784705d-22 /
      data fpp(27, 1, 7,1),fpp(27, 1, 7,2),fpp(27, 1, 7,3)/
     x 2.9169190d-05,-2.1617646d-07, 1.8027864d-21 /
      data fpp(27, 1, 8,1),fpp(27, 1, 8,2),fpp(27, 1, 8,3)/
     x 2.9169190d-05,-2.5977495d-07, 6.2848991d-22 /
      data fpp(27, 1, 9,1),fpp(27, 1, 9,2),fpp(27, 1, 9,3)/
     x 2.9169190d-05,-2.9995824d-07,-2.7464408d-22 /
      data fpp(27, 1,10,1),fpp(27, 1,10,2),fpp(27, 1,10,3)/
     x 2.9169190d-05,-3.4157919d-07,-1.1340343d-21 /
      data fpp(27, 1,11,1),fpp(27, 1,11,2),fpp(27, 1,11,3)/
     x 2.9169190d-05,-3.6916988d-07, 3.2531837d-22 /
      data fpp(27, 1,12,1),fpp(27, 1,12,2),fpp(27, 1,12,3)/
     x 2.9169190d-05,-3.8464369d-07,-1.0976285d-21 /
      data fpp(27, 1,13,1),fpp(27, 1,13,2),fpp(27, 1,13,3)/
     x 2.9169190d-05,-3.7635039d-07,-6.8526211d-22 /
      data fpp(27, 1,14,1),fpp(27, 1,14,2),fpp(27, 1,14,3)/
     x 2.9169190d-05,-3.4721033d-07, 3.9837132d-22 /
      data fpp(27, 1,15,1),fpp(27, 1,15,2),fpp(27, 1,15,3)/
     x 2.9169190d-05,-3.0024057d-07,-1.8450998d-22 /
      data fpp(27, 1,16,1),fpp(27, 1,16,2),fpp(27, 1,16,3)/
     x 2.9169190d-05,-2.4604007d-07, 3.9211922d-22 /
      data fpp(27, 1,17,1),fpp(27, 1,17,2),fpp(27, 1,17,3)/
     x 2.9169190d-05,-1.8952766d-07,-2.7525994d-22 /
      data fpp(27, 1,18,1),fpp(27, 1,18,2),fpp(27, 1,18,3)/
     x 2.9169190d-05,-1.4521522d-07, 5.4509917d-22 /
      data fpp(27, 1,19,1),fpp(27, 1,19,2),fpp(27, 1,19,3)/
     x 2.9169190d-05,-1.1450790d-07, 4.7389141d-22 /
      data fpp(27, 1,20,1),fpp(27, 1,20,2),fpp(27, 1,20,3)/
     x 2.9169190d-05,-9.8579171d-08,-2.9044880d-22 /
      data fpp(27, 1,21,1),fpp(27, 1,21,2),fpp(27, 1,21,3)/
     x 2.9169190d-05,-9.8579171d-08, 2.0659274d-22 /
      data fpp(27, 1,22,1),fpp(27, 1,22,2),fpp(27, 1,22,3)/
     x 2.9169190d-05,-1.1450790d-07,-1.1904736d-21 /
      data fpp(27, 1,23,1),fpp(27, 1,23,2),fpp(27, 1,23,3)/
     x 2.9169190d-05,-1.4521522d-07,-1.8678581d-21 /
      data fpp(27, 2, 1,1),fpp(27, 2, 1,2),fpp(27, 2, 1,3)/
     x 2.9960738d-05,-2.7062768d-08,-4.3097015d-09 /
      data fpp(27, 2, 2,1),fpp(27, 2, 2,2),fpp(27, 2, 2,3)/
     x 4.3638671d-05,-2.4973623d-08,-4.8805970d-09 /
      data fpp(27, 2, 3,1),fpp(27, 2, 3,2),fpp(27, 2, 3,3)/
     x 6.2731516d-05,-2.4276359d-08,-6.1679106d-09 /
      data fpp(27, 2, 4,1),fpp(27, 2, 4,2),fpp(27, 2, 4,3)/
     x 6.2731516d-05,-2.4276359d-08,-6.0559697d-09 /
      data fpp(27, 2, 5,1),fpp(27, 2, 5,2),fpp(27, 2, 5,3)/
     x 4.3638671d-05,-2.4973623d-08,-5.3283604d-09 /
      data fpp(27, 2, 6,1),fpp(27, 2, 6,2),fpp(27, 2, 6,3)/
     x 2.9960738d-05,-2.7062768d-08,-2.6305888d-09 /
      data fpp(27, 2, 7,1),fpp(27, 2, 7,2),fpp(27, 2, 7,3)/
     x 1.6570740d-05,-3.6647076d-08,-2.1492845d-09 /
      data fpp(27, 2, 8,1),fpp(27, 2, 8,2),fpp(27, 2, 8,3)/
     x 3.9032264d-06,-5.1450108d-08,-7.7227336d-10 /
      data fpp(27, 2, 9,1),fpp(27, 2, 9,2),fpp(27, 2, 9,3)/
     x-6.8625087d-06,-6.5083513d-08, 5.2383779d-09 /
      data fpp(27, 2,10,1),fpp(27, 2,10,2),fpp(27, 2,10,3)/
     x-1.7146573d-05,-8.0841613d-08, 3.8187618d-09 /
      data fpp(27, 2,11,1),fpp(27, 2,11,2),fpp(27, 2,11,3)/
     x-2.3609859d-05,-9.2660237d-08, 9.4865750d-09 /
      data fpp(27, 2,12,1),fpp(27, 2,12,2),fpp(27, 2,12,3)/
     x-2.6990651d-05,-1.0071263d-07, 6.2349383d-09 /
      data fpp(27, 2,13,1),fpp(27, 2,13,2),fpp(27, 2,13,3)/
     x-2.6611020d-05,-9.9299217d-08, 7.5736718d-09 /
      data fpp(27, 2,14,1),fpp(27, 2,14,2),fpp(27, 2,14,3)/
     x-2.0238865d-05,-8.9579332d-08, 5.4703746d-09 /
      data fpp(27, 2,15,1),fpp(27, 2,15,2),fpp(27, 2,15,3)/
     x-1.1938729d-05,-7.3518862d-08, 6.5448298d-09 /
      data fpp(27, 2,16,1),fpp(27, 2,16,2),fpp(27, 2,16,3)/
     x-2.4180416d-06,-5.4919858d-08,-1.6496939d-09 /
      data fpp(27, 2,17,1),fpp(27, 2,17,2),fpp(27, 2,17,3)/
     x 9.1673767d-06,-3.4944680d-08, 5.3945660d-11 /
      data fpp(27, 2,18,1),fpp(27, 2,18,2),fpp(27, 2,18,3)/
     x 2.1497493d-05,-1.9569558d-08,-4.5660888d-09 /
      data fpp(27, 2,19,1),fpp(27, 2,19,2),fpp(27, 2,19,3)/
     x 3.7365029d-05,-9.9842074d-09,-5.7895906d-09 /
      data fpp(27, 2,20,1),fpp(27, 2,20,2),fpp(27, 2,20,3)/
     x 5.2794786d-05,-6.8416572d-09,-8.2755489d-09 /
      data fpp(27, 2,21,1),fpp(27, 2,21,2),fpp(27, 2,21,3)/
     x 5.2794786d-05,-6.8416572d-09,-8.2785579d-09 /
      data fpp(27, 2,22,1),fpp(27, 2,22,2),fpp(27, 2,22,3)/
     x 3.7365029d-05,-9.9842074d-09,-5.7775549d-09 /
      data fpp(27, 2,23,1),fpp(27, 2,23,2),fpp(27, 2,23,3)/
     x 2.1497493d-05,-1.9569558d-08,-4.6112226d-09 /
      data fpp(27, 3, 1,1),fpp(27, 3, 1,2),fpp(27, 3, 1,3)/
     x 3.9347541d-05, 1.9771969d-07,-1.0604696d-08 /
      data fpp(27, 3, 2,1),fpp(27, 3, 2,2),fpp(27, 3, 2,3)/
     x 6.4725833d-05, 2.0590768d-07,-1.1790608d-08 /
      data fpp(27, 3, 3,1),fpp(27, 3, 3,2),fpp(27, 3, 3,3)/
     x 9.1208114d-05, 2.1196726d-07,-1.4232871d-08 /
      data fpp(27, 3, 4,1),fpp(27, 3, 4,2),fpp(27, 3, 4,3)/
     x 9.1208114d-05, 2.1196726d-07,-1.4406084d-08 /
      data fpp(27, 3, 5,1),fpp(27, 3, 5,2),fpp(27, 3, 5,3)/
     x 6.4725833d-05, 2.0590768d-07,-1.1097755d-08 /
      data fpp(27, 3, 6,1),fpp(27, 3, 6,2),fpp(27, 3, 6,3)/
     x 3.9347541d-05, 1.9771969d-07,-1.3202896d-08 /
      data fpp(27, 3, 7,1),fpp(27, 3, 7,2),fpp(27, 3, 7,3)/
     x 1.0321428d-05, 2.0076477d-07,-8.0906604d-09 /
      data fpp(27, 3, 8,1),fpp(27, 3, 8,2),fpp(27, 3, 8,3)/
     x-2.2859893d-05, 2.1957538d-07, 3.5655376d-09 /
      data fpp(27, 3, 9,1),fpp(27, 3, 9,2),fpp(27, 3, 9,3)/
     x-5.6095690d-05, 2.4229229d-07, 5.8285100d-09 /
      data fpp(27, 3,10,1),fpp(27, 3,10,2),fpp(27, 3,10,3)/
     x-8.4392896d-05, 2.6894565d-07, 1.5120422d-08 /
      data fpp(27, 3,11,1),fpp(27, 3,11,2),fpp(27, 3,11,3)/
     x-1.0404010d-04, 2.8981083d-07, 1.7689800d-08 /
      data fpp(27, 3,12,1),fpp(27, 3,12,2),fpp(27, 3,12,3)/
     x-1.1166581d-04, 2.9549420d-07, 2.2120377d-08 /
      data fpp(27, 3,13,1),fpp(27, 3,13,2),fpp(27, 3,13,3)/
     x-1.0707021d-04, 2.8154726d-07, 1.9828694d-08 /
      data fpp(27, 3,14,1),fpp(27, 3,14,2),fpp(27, 3,14,3)/
     x-8.9579603d-05, 2.4952766d-07, 1.8564849d-08 /
      data fpp(27, 3,15,1),fpp(27, 3,15,2),fpp(27, 3,15,3)/
     x-6.2932031d-05, 2.1031602d-07, 1.3911910d-08 /
      data fpp(27, 3,16,1),fpp(27, 3,16,2),fpp(27, 3,16,3)/
     x-3.0819455d-05, 1.7171950d-07, 3.7875094d-09 /
      data fpp(27, 3,17,1),fpp(27, 3,17,2),fpp(27, 3,17,3)/
     x 2.9229307d-06, 1.4930638d-07,-5.0619481d-09 /
      data fpp(27, 3,18,1),fpp(27, 3,18,2),fpp(27, 3,18,3)/
     x 3.2722023d-05, 1.3949345d-07,-1.3539717d-08 /
      data fpp(27, 3,19,1),fpp(27, 3,19,2),fpp(27, 3,19,3)/
     x 5.9496019d-05, 1.3644473d-07,-1.8779183d-08 /
      data fpp(27, 3,20,1),fpp(27, 3,20,2),fpp(27, 3,20,3)/
     x 8.4380413d-05, 1.3794580d-07,-1.9343550d-08 /
      data fpp(27, 3,21,1),fpp(27, 3,21,2),fpp(27, 3,21,3)/
     x 8.4380413d-05, 1.3794580d-07,-1.9579757d-08 /
      data fpp(27, 3,22,1),fpp(27, 3,22,2),fpp(27, 3,22,3)/
     x 5.9496019d-05, 1.3644473d-07,-1.7834355d-08 /
      data fpp(27, 3,23,1),fpp(27, 3,23,2),fpp(27, 3,23,3)/
     x 3.2722023d-05, 1.3949345d-07,-1.7082822d-08 /
      data fpp(27, 4, 1,1),fpp(27, 4, 1,2),fpp(27, 4, 1,3)/
     x 9.2286528d-06, 1.9018402d-07,-1.7844908d-08 /
      data fpp(27, 4, 2,1),fpp(27, 4, 2,2),fpp(27, 4, 2,3)/
     x 3.6518345d-05, 1.4334290d-07,-1.8810184d-08 /
      data fpp(27, 4, 3,1),fpp(27, 4, 3,2),fpp(27, 4, 3,3)/
     x 5.3194012d-05, 1.0640734d-07,-2.0914357d-08 /
      data fpp(27, 4, 4,1),fpp(27, 4, 4,2),fpp(27, 4, 4,3)/
     x 5.3194012d-05, 1.0640734d-07,-2.0851838d-08 /
      data fpp(27, 4, 5,1),fpp(27, 4, 5,2),fpp(27, 4, 5,3)/
     x 3.6518345d-05, 1.4334290d-07,-1.9060259d-08 /
      data fpp(27, 4, 6,1),fpp(27, 4, 6,2),fpp(27, 4, 6,3)/
     x 9.2286528d-06, 1.9018402d-07,-1.6907126d-08 /
      data fpp(27, 4, 7,1),fpp(27, 4, 7,2),fpp(27, 4, 7,3)/
     x-2.4379926d-05, 2.3558801d-07,-3.3112365d-09 /
      data fpp(27, 4, 8,1),fpp(27, 4, 8,2),fpp(27, 4, 8,3)/
     x-6.0437552d-05, 2.7114860d-07, 6.1520721d-09 /
      data fpp(27, 4, 9,1),fpp(27, 4, 9,2),fpp(27, 4, 9,3)/
     x-9.5649927d-05, 2.9591433d-07, 8.7029479d-09 /
      data fpp(27, 4,10,1),fpp(27, 4,10,2),fpp(27, 4,10,3)/
     x-1.2616958d-04, 3.0705903d-07, 1.9036136d-08 /
      data fpp(27, 4,11,1),fpp(27, 4,11,2),fpp(27, 4,11,3)/
     x-1.4755194d-04, 3.0141692d-07, 1.7152508d-08 /
      data fpp(27, 4,12,1),fpp(27, 4,12,2),fpp(27, 4,12,3)/
     x-1.5616569d-04, 2.9873581d-07, 2.6353833d-08 /
      data fpp(27, 4,13,1),fpp(27, 4,13,2),fpp(27, 4,13,3)/
     x-1.5087615d-04, 2.9911017d-07, 2.1432160d-08 /
      data fpp(27, 4,14,1),fpp(27, 4,14,2),fpp(27, 4,14,3)/
     x-1.3239954d-04, 3.0346868d-07, 2.5917526d-08 /
      data fpp(27, 4,15,1),fpp(27, 4,15,2),fpp(27, 4,15,3)/
     x-1.0349106d-04, 2.9425479d-07, 1.8897736d-08 /
      data fpp(27, 4,16,1),fpp(27, 4,16,2),fpp(27, 4,16,3)/
     x-6.7942750d-05, 2.7404184d-07, 1.8491531d-08 /
      data fpp(27, 4,17,1),fpp(27, 4,17,2),fpp(27, 4,17,3)/
     x-3.0350866d-05, 2.2971916d-07,-2.8638594d-09 /
      data fpp(27, 4,18,1),fpp(27, 4,18,2),fpp(27, 4,18,3)/
     x 6.2342867d-06, 1.8159574d-07,-1.9036093d-08 /
      data fpp(27, 4,19,1),fpp(27, 4,19,2),fpp(27, 4,19,3)/
     x 3.7240312d-05, 1.3620530d-07,-2.8991768d-08 /
      data fpp(27, 4,20,1),fpp(27, 4,20,2),fpp(27, 4,20,3)/
     x 5.6308838d-05, 9.7058456d-08,-2.6996836d-08 /
      data fpp(27, 4,21,1),fpp(27, 4,21,2),fpp(27, 4,21,3)/
     x 5.6308838d-05, 9.7058456d-08,-2.7513607d-08 /
      data fpp(27, 4,22,1),fpp(27, 4,22,2),fpp(27, 4,22,3)/
     x 3.7240312d-05, 1.3620530d-07,-2.6924684d-08 /
      data fpp(27, 4,23,1),fpp(27, 4,23,2),fpp(27, 4,23,3)/
     x 6.2342867d-06, 1.8159574d-07,-2.6787658d-08 /
      data fpp(27, 5, 1,1),fpp(27, 5, 1,2),fpp(27, 5, 1,3)/
     x-3.2232753d-05, 1.9544246d-08,-2.7584429d-08 /
      data fpp(27, 5, 2,1),fpp(27, 5, 2,2),fpp(27, 5, 2,3)/
     x-7.4662883d-06,-2.9279276d-08,-2.0331142d-08 /
      data fpp(27, 5, 3,1),fpp(27, 5, 3,2),fpp(27, 5, 3,3)/
     x 9.9280992d-06,-7.3596605d-08,-5.0910047d-09 /
      data fpp(27, 5, 4,1),fpp(27, 5, 4,2),fpp(27, 5, 4,3)/
     x 9.9280992d-06,-7.3596605d-08,-4.5614150d-09 /
      data fpp(27, 5, 5,1),fpp(27, 5, 5,2),fpp(27, 5, 5,3)/
     x-7.4662883d-06,-2.9279276d-08,-2.2449500d-08 /
      data fpp(27, 5, 6,1),fpp(27, 5, 6,2),fpp(27, 5, 6,3)/
     x-3.2232753d-05, 1.9544246d-08,-1.9640584d-08 /
      data fpp(27, 5, 7,1),fpp(27, 5, 7,2),fpp(27, 5, 7,3)/
     x-5.7878465d-05, 6.2883184d-08,-6.9881650d-09 /
      data fpp(27, 5, 8,1),fpp(27, 5, 8,2),fpp(27, 5, 8,3)/
     x-8.2469472d-05, 8.7830224d-08,-4.0675627d-10 /
      data fpp(27, 5, 9,1),fpp(27, 5, 9,2),fpp(27, 5, 9,3)/
     x-1.0331590d-04, 9.8050367d-08, 2.6151901d-09 /
      data fpp(27, 5,10,1),fpp(27, 5,10,2),fpp(27, 5,10,3)/
     x-1.1883917d-04, 9.8818241d-08, 7.9459959d-09 /
      data fpp(27, 5,11,1),fpp(27, 5,11,2),fpp(27, 5,11,3)/
     x-1.2834634d-04, 1.0652148d-07, 1.9600826d-08 /
      data fpp(27, 5,12,1),fpp(27, 5,12,2),fpp(27, 5,12,3)/
     x-1.3243281d-04, 1.1156254d-07, 2.7650698d-08 /
      data fpp(27, 5,13,1),fpp(27, 5,13,2),fpp(27, 5,13,3)/
     x-1.3126070d-04, 1.1801204d-07, 2.5796381d-08 /
      data fpp(27, 5,14,1),fpp(27, 5,14,2),fpp(27, 5,14,3)/
     x-1.2504314d-04, 1.2059760d-07, 1.9163779d-08 /
      data fpp(27, 5,15,1),fpp(27, 5,15,2),fpp(27, 5,15,3)/
     x-1.1108171d-04, 1.2466482d-07, 1.7548504d-08 /
      data fpp(27, 5,16,1),fpp(27, 5,16,2),fpp(27, 5,16,3)/
     x-9.1026287d-05, 1.1211314d-07, 1.2642205d-08 /
      data fpp(27, 5,17,1),fpp(27, 5,17,2),fpp(27, 5,17,3)/
     x-6.4639974d-05, 8.9816963d-08,-2.1173224d-09 /
      data fpp(27, 5,18,1),fpp(27, 5,18,2),fpp(27, 5,18,3)/
     x-3.5566893d-05, 4.6123568d-08,-2.2172915d-08 /
      data fpp(27, 5,19,1),fpp(27, 5,19,2),fpp(27, 5,19,3)/
     x-7.7216537d-06,-3.2659391d-09,-3.5191017d-08 /
      data fpp(27, 5,20,1),fpp(27, 5,20,2),fpp(27, 5,20,3)/
     x 1.2719262d-05,-4.0179625d-08,-1.1063016d-08 /
      data fpp(27, 5,21,1),fpp(27, 5,21,2),fpp(27, 5,21,3)/
     x 1.2719262d-05,-4.0179625d-08,-1.2215445d-08 /
      data fpp(27, 5,22,1),fpp(27, 5,22,2),fpp(27, 5,22,3)/
     x-7.7216537d-06,-3.2659391d-09,-3.0581302d-08 /
      data fpp(27, 5,23,1),fpp(27, 5,23,2),fpp(27, 5,23,3)/
     x-3.5566893d-05, 4.6123568d-08,-3.9459349d-08 /
      data fpp(27, 6, 1,1),fpp(27, 6, 1,2),fpp(27, 6, 1,3)/
     x-4.8362463d-05,-3.4361001d-08,-4.0121891d-08 /
      data fpp(27, 6, 2,1),fpp(27, 6, 2,2),fpp(27, 6, 2,3)/
     x-3.4280131d-05, 3.7742059d-09,-1.7256219d-08 /
      data fpp(27, 6, 3,1),fpp(27, 6, 3,2),fpp(27, 6, 3,3)/
     x-2.3276508d-05, 4.9979083d-08, 3.1146765d-08 /
      data fpp(27, 6, 4,1),fpp(27, 6, 4,2),fpp(27, 6, 4,3)/
     x-2.3276508d-05, 4.9979083d-08, 3.2187814d-08 /
      data fpp(27, 6, 5,1),fpp(27, 6, 5,2),fpp(27, 6, 5,3)/
     x-3.4280131d-05, 3.7742059d-09,-2.1420415d-08 /
      data fpp(27, 6, 6,1),fpp(27, 6, 6,2),fpp(27, 6, 6,3)/
     x-4.8362463d-05,-3.4361001d-08,-2.4506156d-08 /
      data fpp(27, 6, 7,1),fpp(27, 6, 7,2),fpp(27, 6, 7,3)/
     x-6.2711737d-05,-6.7120748d-08,-2.4554963d-08 /
      data fpp(27, 6, 8,1),fpp(27, 6, 8,2),fpp(27, 6, 8,3)/
     x-7.4112649d-05,-8.2469496d-08,-1.5273994d-08 /
      data fpp(27, 6, 9,1),fpp(27, 6, 9,2),fpp(27, 6, 9,3)/
     x-8.1570196d-05,-8.2115801d-08,-1.0349063d-08 /
      data fpp(27, 6,10,1),fpp(27, 6,10,2),fpp(27, 6,10,3)/
     x-8.6474407d-05,-6.0331992d-08, 2.6702466d-09 /
      data fpp(27, 6,11,1),fpp(27, 6,11,2),fpp(27, 6,11,3)/
     x-8.9680284d-05,-3.7502831d-08, 1.7668077d-08 /
      data fpp(27, 6,12,1),fpp(27, 6,12,2),fpp(27, 6,12,3)/
     x-9.2002653d-05,-1.8985973d-08, 2.8657445d-08 /
      data fpp(27, 6,13,1),fpp(27, 6,13,2),fpp(27, 6,13,3)/
     x-9.2465372d-05,-2.1158347d-08, 2.3702142d-08 /
      data fpp(27, 6,14,1),fpp(27, 6,14,2),fpp(27, 6,14,3)/
     x-9.2862350d-05,-3.5859079d-08, 1.4533988d-08 /
      data fpp(27, 6,15,1),fpp(27, 6,15,2),fpp(27, 6,15,3)/
     x-9.0214079d-05,-5.4914071d-08, 2.1619056d-09 /
      data fpp(27, 6,16,1),fpp(27, 6,16,2),fpp(27, 6,16,3)/
     x-8.2483875d-05,-5.6494388d-08, 8.1838927d-10 /
      data fpp(27, 6,17,1),fpp(27, 6,17,2),fpp(27, 6,17,3)/
     x-6.9496263d-05,-4.8987017d-08,-1.7435463d-08 /
      data fpp(27, 6,18,1),fpp(27, 6,18,2),fpp(27, 6,18,3)/
     x-5.1876503d-05,-2.4090018d-08,-2.7076538d-08 /
      data fpp(27, 6,19,1),fpp(27, 6,19,2),fpp(27, 6,19,3)/
     x-3.4299438d-05, 8.8584532d-09,-3.0258383d-08 /
      data fpp(27, 6,20,1),fpp(27, 6,20,2),fpp(27, 6,20,3)/
     x-2.1364342d-05, 4.5660044d-08, 2.2110072d-08 /
      data fpp(27, 6,21,1),fpp(27, 6,21,2),fpp(27, 6,21,3)/
     x-2.1364342d-05, 4.5660044d-08, 2.0798975d-08 /
      data fpp(27, 6,22,1),fpp(27, 6,22,2),fpp(27, 6,22,3)/
     x-3.4299438d-05, 8.8584532d-09,-2.5013993d-08 /
      data fpp(27, 6,23,1),fpp(27, 6,23,2),fpp(27, 6,23,3)/
     x-5.1876503d-05,-2.4090018d-08,-4.6743004d-08 /
      data fpp(27, 7, 1,1),fpp(27, 7, 1,2),fpp(27, 7, 1,3)/
     x-4.2242971d-05,-8.0100244d-08,-3.1173745d-08 /
      data fpp(27, 7, 2,1),fpp(27, 7, 2,2),fpp(27, 7, 2,3)/
     x-3.9915075d-05,-4.5817548d-08,-6.6525106d-09 /
      data fpp(27, 7, 3,1),fpp(27, 7, 3,2),fpp(27, 7, 3,3)/
     x-3.9544856d-05,-1.8319726d-08, 4.5783787d-08 /
      data fpp(27, 7, 4,1),fpp(27, 7, 4,2),fpp(27, 7, 4,3)/
     x-3.9544856d-05,-1.8319726d-08, 4.5974894d-08 /
      data fpp(27, 7, 5,1),fpp(27, 7, 5,2),fpp(27, 7, 5,3)/
     x-3.9915075d-05,-4.5817548d-08,-7.4169387d-09 /
      data fpp(27, 7, 6,1),fpp(27, 7, 6,2),fpp(27, 7, 6,3)/
     x-4.2242971d-05,-8.0100244d-08,-2.8307139d-08 /
      data fpp(27, 7, 7,1),fpp(27, 7, 7,2),fpp(27, 7, 7,3)/
     x-4.4655321d-05,-1.0040019d-07,-2.9354504d-08 /
      data fpp(27, 7, 8,1),fpp(27, 7, 8,2),fpp(27, 7, 8,3)/
     x-4.7471939d-05,-1.1195224d-07,-2.2274846d-08 /
      data fpp(27, 7, 9,1),fpp(27, 7, 9,2),fpp(27, 7, 9,3)/
     x-5.1314649d-05,-1.1158716d-07,-7.5461116d-09 /
      data fpp(27, 7,10,1),fpp(27, 7,10,2),fpp(27, 7,10,3)/
     x-5.5942229d-05,-1.1549027d-07,-1.5407075d-09 /
      data fpp(27, 7,11,1),fpp(27, 7,11,2),fpp(27, 7,11,3)/
     x-6.0490395d-05,-1.1251015d-07, 1.3708942d-08 /
      data fpp(27, 7,12,1),fpp(27, 7,12,2),fpp(27, 7,12,3)/
     x-6.3498135d-05,-1.1361865d-07, 1.2704941d-08 /
      data fpp(27, 7,13,1),fpp(27, 7,13,2),fpp(27, 7,13,3)/
     x-6.4410577d-05,-1.1137866d-07, 1.3471295d-08 /
      data fpp(27, 7,14,1),fpp(27, 7,14,2),fpp(27, 7,14,3)/
     x-6.3407609d-05,-1.0916128d-07, 5.4098798d-09 /
      data fpp(27, 7,15,1),fpp(27, 7,15,2),fpp(27, 7,15,3)/
     x-6.1371110d-05,-1.0300854d-07, 8.8918583d-10 /
      data fpp(27, 7,16,1),fpp(27, 7,16,2),fpp(27, 7,16,3)/
     x-5.7390116d-05,-9.6135584d-08,-8.9666231d-09 /
      data fpp(27, 7,17,1),fpp(27, 7,17,2),fpp(27, 7,17,3)/
     x-5.1373645d-05,-7.9868894d-08,-1.9022693d-08 /
      data fpp(27, 7,18,1),fpp(27, 7,18,2),fpp(27, 7,18,3)/
     x-4.4374463d-05,-5.1763497d-08,-2.8942604d-08 /
      data fpp(27, 7,19,1),fpp(27, 7,19,2),fpp(27, 7,19,3)/
     x-3.7701078d-05,-1.4167874d-08,-1.5206891d-08 /
      data fpp(27, 7,20,1),fpp(27, 7,20,2),fpp(27, 7,20,3)/
     x-3.3626039d-05, 1.9539449d-08, 3.5770168d-08 /
      data fpp(27, 7,21,1),fpp(27, 7,21,2),fpp(27, 7,21,3)/
     x-3.3626039d-05, 1.9539449d-08, 3.5292941d-08 /
      data fpp(27, 7,22,1),fpp(27, 7,22,2),fpp(27, 7,22,3)/
     x-3.7701078d-05,-1.4167874d-08,-1.3297983d-08 /
      data fpp(27, 7,23,1),fpp(27, 7,23,2),fpp(27, 7,23,3)/
     x-4.4374463d-05,-5.1763497d-08,-3.6101008d-08 /
      data fpp(27, 8, 1,1),fpp(27, 8, 1,2),fpp(27, 8, 1,3)/
     x-3.1687942d-05,-1.1923802d-07,-1.7138903d-08 /
      data fpp(27, 8, 2,1),fpp(27, 8, 2,2),fpp(27, 8, 2,3)/
     x-3.5343763d-05,-1.4450402d-07, 2.2778050d-09 /
      data fpp(27, 8, 3,1),fpp(27, 8, 3,2),fpp(27, 8, 3,3)/
     x-3.9433554d-05,-1.6870018d-07, 4.4027682d-08 /
      data fpp(27, 8, 4,1),fpp(27, 8, 4,2),fpp(27, 8, 4,3)/
     x-3.9433554d-05,-1.6870018d-07, 4.3778050d-08 /
      data fpp(27, 8, 5,1),fpp(27, 8, 5,2),fpp(27, 8, 5,3)/
     x-3.5343763d-05,-1.4450402d-07, 3.2763339d-09 /
      data fpp(27, 8, 6,1),fpp(27, 8, 6,2),fpp(27, 8, 6,3)/
     x-3.1687942d-05,-1.1923802d-07,-2.0883386d-08 /
      data fpp(27, 8, 7,1),fpp(27, 8, 7,2),fpp(27, 8, 7,3)/
     x-2.9136448d-05,-1.0727849d-07,-2.7742790d-08 /
      data fpp(27, 8, 8,1),fpp(27, 8, 8,2),fpp(27, 8, 8,3)/
     x-2.9441551d-05,-9.9721546d-08,-1.8145453d-08 /
      data fpp(27, 8, 9,1),fpp(27, 8, 9,2),fpp(27, 8, 9,3)/
     x-3.1898813d-05,-1.0753555d-07,-7.6753968d-09 /
      data fpp(27, 8,10,1),fpp(27, 8,10,2),fpp(27, 8,10,3)/
     x-3.6775635d-05,-1.1370692d-07, 8.4704028d-10 /
      data fpp(27, 8,11,1),fpp(27, 8,11,2),fpp(27, 8,11,3)/
     x-4.0774178d-05,-1.3045656d-07, 4.2872356d-09 /
      data fpp(27, 8,12,1),fpp(27, 8,12,2),fpp(27, 8,12,3)/
     x-4.4222640d-05,-1.3853943d-07, 4.0171363d-12 /
      data fpp(27, 8,13,1),fpp(27, 8,13,2),fpp(27, 8,13,3)/
     x-4.4881544d-05,-1.3332703d-07, 1.6966958d-09 /
      data fpp(27, 8,14,1),fpp(27, 8,14,2),fpp(27, 8,14,3)/
     x-4.4158613d-05,-1.1549579d-07,-7.9080037d-10 /
      data fpp(27, 8,15,1),fpp(27, 8,15,2),fpp(27, 8,15,3)/
     x-4.1237145d-05,-9.7051787d-08, 1.4665057d-09 /
      data fpp(27, 8,16,1),fpp(27, 8,16,2),fpp(27, 8,16,3)/
     x-3.7967785d-05,-8.0963275d-08,-1.1075222d-08 /
      data fpp(27, 8,17,1),fpp(27, 8,17,2),fpp(27, 8,17,3)/
     x-3.3623972d-05,-6.9537405d-08,-1.1165616d-08 /
      data fpp(27, 8,18,1),fpp(27, 8,18,2),fpp(27, 8,18,3)/
     x-3.0605533d-05,-6.8855996d-08,-2.2262312d-08 /
      data fpp(27, 8,19,1),fpp(27, 8,19,2),fpp(27, 8,19,3)/
     x-2.9021673d-05,-7.2186959d-08,-1.7851360d-09 /
      data fpp(27, 8,20,1),fpp(27, 8,20,2),fpp(27, 8,20,3)/
     x-2.9689979d-05,-8.1817841d-08, 2.9402856d-08 /
      data fpp(27, 8,21,1),fpp(27, 8,21,2),fpp(27, 8,21,3)/
     x-2.9689979d-05,-8.1817841d-08, 2.9684000d-08 /
      data fpp(27, 8,22,1),fpp(27, 8,22,2),fpp(27, 8,22,3)/
     x-2.9021673d-05,-7.2186959d-08,-2.9097144d-09 /
      data fpp(27, 8,23,1),fpp(27, 8,23,2),fpp(27, 8,23,3)/
     x-3.0605533d-05,-6.8855996d-08,-1.8045143d-08 /
      data fpp(27, 9, 1,1),fpp(27, 9, 1,2),fpp(27, 9, 1,3)/
     x-2.9518033d-05,-1.0894766d-07,-1.0353650d-08 /
      data fpp(27, 9, 2,1),fpp(27, 9, 2,2),fpp(27, 9, 2,3)/
     x-3.2361720d-05,-1.0816639d-07, 9.2072999d-09 /
      data fpp(27, 9, 3,1),fpp(27, 9, 3,2),fpp(27, 9, 3,3)/
     x-3.5479659d-05,-1.1087956d-07, 5.1524450d-08 /
      data fpp(27, 9, 4,1),fpp(27, 9, 4,2),fpp(27, 9, 4,3)/
     x-3.5479659d-05,-1.1087956d-07, 5.0822999d-08 /
      data fpp(27, 9, 5,1),fpp(27, 9, 5,2),fpp(27, 9, 5,3)/
     x-3.2361720d-05,-1.0816639d-07, 1.2013106d-08 /
      data fpp(27, 9, 6,1),fpp(27, 9, 6,2),fpp(27, 9, 6,3)/
     x-2.9518033d-05,-1.0894766d-07,-2.0875424d-08 /
      data fpp(27, 9, 7,1),fpp(27, 9, 7,2),fpp(27, 9, 7,3)/
     x-2.5745445d-05,-1.0048585d-07,-2.4511410d-08 /
      data fpp(27, 9, 8,1),fpp(27, 9, 8,2),fpp(27, 9, 8,3)/
     x-2.3757212d-05,-9.5161577d-08,-2.5078934d-08 /
      data fpp(27, 9, 9,1),fpp(27, 9, 9,2),fpp(27, 9, 9,3)/
     x-2.3495790d-05,-8.2270650d-08,-7.1728530d-09 /
      data fpp(27, 9,10,1),fpp(27, 9,10,2),fpp(27, 9,10,3)/
     x-2.5818967d-05,-8.9682066d-08,-6.2296537d-09 /
      data fpp(27, 9,11,1),fpp(27, 9,11,2),fpp(27, 9,11,3)/
     x-2.8376167d-05,-9.1663597d-08, 2.0914680d-09 /
      data fpp(27, 9,12,1),fpp(27, 9,12,2),fpp(27, 9,12,3)/
     x-3.0451665d-05,-9.4223618d-08,-2.1362183d-09 /
      data fpp(27, 9,13,1),fpp(27, 9,13,2),fpp(27, 9,13,3)/
     x-3.1660471d-05,-9.3313213d-08, 4.5340511d-10 /
      data fpp(27, 9,14,1),fpp(27, 9,14,2),fpp(27, 9,14,3)/
     x-3.2361384d-05,-8.8855549d-08,-5.6774022d-09 /
      data fpp(27, 9,15,1),fpp(27, 9,15,2),fpp(27, 9,15,3)/
     x-3.0928363d-05,-7.8784315d-08,-1.7437965d-09 /
      data fpp(27, 9,16,1),fpp(27, 9,16,2),fpp(27, 9,16,3)/
     x-2.9110856d-05,-7.2011316d-08,-1.1347412d-08 /
      data fpp(27, 9,17,1),fpp(27, 9,17,2),fpp(27, 9,17,3)/
     x-2.6344240d-05,-6.1981486d-08,-1.2866556d-08 /
      data fpp(27, 9,18,1),fpp(27, 9,18,2),fpp(27, 9,18,3)/
     x-2.4169466d-05,-5.6812521d-08,-1.5186365d-08 /
      data fpp(27, 9,19,1),fpp(27, 9,19,2),fpp(27, 9,19,3)/
     x-2.3567688d-05,-6.3084292d-08, 1.6120166d-09 /
      data fpp(27, 9,20,1),fpp(27, 9,20,2),fpp(27, 9,20,3)/
     x-2.5503519d-05,-7.6268087d-08, 2.6738299d-08 /
      data fpp(27, 9,21,1),fpp(27, 9,21,2),fpp(27, 9,21,3)/
     x-2.5503519d-05,-7.6268087d-08, 2.6979095d-08 /
      data fpp(27, 9,22,1),fpp(27, 9,22,2),fpp(27, 9,22,3)/
     x-2.3567688d-05,-6.3084292d-08, 6.4882988d-10 /
      data fpp(27, 9,23,1),fpp(27, 9,23,2),fpp(27, 9,23,3)/
     x-2.4169466d-05,-5.6812521d-08,-1.1574415d-08 /
      data fpp(27,10, 1,1),fpp(27,10, 1,2),fpp(27,10, 1,3)/
     x-3.2353101d-05,-5.6971345d-08,-7.1457332d-09 /
      data fpp(27,10, 2,1),fpp(27,10, 2,2),fpp(27,10, 2,3)/
     x-3.6786124d-05,-5.2830423d-08, 1.4791466d-08 /
      data fpp(27,10, 3,1),fpp(27,10, 3,2),fpp(27,10, 3,3)/
     x-3.9354405d-05,-4.1781584d-08, 6.1979868d-08 /
      data fpp(27,10, 4,1),fpp(27,10, 4,2),fpp(27,10, 4,3)/
     x-3.9354405d-05,-4.1781584d-08, 6.1664664d-08 /
      data fpp(27,10, 5,1),fpp(27,10, 5,2),fpp(27,10, 5,3)/
     x-3.6786124d-05,-5.2830423d-08, 1.6052279d-08 /
      data fpp(27,10, 6,1),fpp(27,10, 6,2),fpp(27,10, 6,3)/
     x-3.2353101d-05,-5.6971345d-08,-1.1873782d-08 /
      data fpp(27,10, 7,1),fpp(27,10, 7,2),fpp(27,10, 7,3)/
     x-2.7493214d-05,-6.0778098d-08,-2.8557151d-08 /
      data fpp(27,10, 8,1),fpp(27,10, 8,2),fpp(27,10, 8,3)/
     x-2.3146075d-05,-5.9632145d-08,-2.3897614d-08 /
      data fpp(27,10, 9,1),fpp(27,10, 9,2),fpp(27,10, 9,3)/
     x-2.1362863d-05,-6.7381851d-08,-2.5852391d-08 /
      data fpp(27,10,10,1),fpp(27,10,10,2),fpp(27,10,10,3)/
     x-2.0383428d-05,-5.5564821d-08,-4.6928202d-09 /
      data fpp(27,10,11,1),fpp(27,10,11,2),fpp(27,10,11,3)/
     x-2.1752804d-05,-4.2889049d-08,-3.3763277d-09 /
      data fpp(27,10,12,1),fpp(27,10,12,2),fpp(27,10,12,3)/
     x-2.3617405d-05,-3.6566095d-08, 1.9813115d-10 /
      data fpp(27,10,13,1),fpp(27,10,13,2),fpp(27,10,13,3)/
     x-2.5082974d-05,-3.9420113d-08, 2.5838031d-09 /
      data fpp(27,10,14,1),fpp(27,10,14,2),fpp(27,10,14,3)/
     x-2.6188860d-05,-4.5082012d-08,-4.5333436d-09 /
      data fpp(27,10,15,1),fpp(27,10,15,2),fpp(27,10,15,3)/
     x-2.5946501d-05,-4.9810951d-08,-8.4504287d-09 /
      data fpp(27,10,16,1),fpp(27,10,16,2),fpp(27,10,16,3)/
     x-2.4236377d-05,-4.4991462d-08,-9.6649417d-09 /
      data fpp(27,10,17,1),fpp(27,10,17,2),fpp(27,10,17,3)/
     x-2.3381092d-05,-4.8536651d-08,-1.8889804d-08 /
      data fpp(27,10,18,1),fpp(27,10,18,2),fpp(27,10,18,3)/
     x-2.2949281d-05,-4.5893920d-08,-1.6775840d-08 /
      data fpp(27,10,19,1),fpp(27,10,19,2),fpp(27,10,19,3)/
     x-2.4482739d-05,-4.1475875d-08,-4.0068340d-09 /
      data fpp(27,10,20,1),fpp(27,10,20,2),fpp(27,10,20,3)/
     x-2.6909990d-05,-3.9109812d-08, 3.2803176d-08 /
      data fpp(27,10,21,1),fpp(27,10,21,2),fpp(27,10,21,3)/
     x-2.6909990d-05,-3.9109812d-08, 3.2593888d-08 /
      data fpp(27,10,22,1),fpp(27,10,22,2),fpp(27,10,22,3)/
     x-2.4482739d-05,-4.1475875d-08,-3.1696824d-09 /
      data fpp(27,10,23,1),fpp(27,10,23,2),fpp(27,10,23,3)/
     x-2.2949281d-05,-4.5893920d-08,-1.9915159d-08 /
      data fpp(27,11, 1,1),fpp(27,11, 1,2),fpp(27,11, 1,3)/
     x-3.5968311d-05,-5.1669639d-09, 5.3367493d-09 /
      data fpp(27,11, 2,1),fpp(27,11, 2,2),fpp(27,11, 2,3)/
     x-4.1629162d-05, 1.3488082d-08, 2.4326501d-08 /
      data fpp(27,11, 3,1),fpp(27,11, 3,2),fpp(27,11, 3,3)/
     x-4.5877872d-05, 2.6005896d-08, 6.5357245d-08 /
      data fpp(27,11, 4,1),fpp(27,11, 4,2),fpp(27,11, 4,3)/
     x-4.5877872d-05, 2.6005896d-08, 6.4765013d-08 /
      data fpp(27,11, 5,1),fpp(27,11, 5,2),fpp(27,11, 5,3)/
     x-4.1629162d-05, 1.3488082d-08, 2.6695429d-08 /
      data fpp(27,11, 6,1),fpp(27,11, 6,2),fpp(27,11, 6,3)/
     x-3.5968311d-05,-5.1669639d-09,-3.5467299d-09 /
      data fpp(27,11, 7,1),fpp(27,11, 7,2),fpp(27,11, 7,3)/
     x-3.0075968d-05,-2.2401753d-08,-2.4508510d-08 /
      data fpp(27,11, 8,1),fpp(27,11, 8,2),fpp(27,11, 8,3)/
     x-2.4939327d-05,-3.2309841d-08,-3.0419232d-08 /
      data fpp(27,11, 9,1),fpp(27,11, 9,2),fpp(27,11, 9,3)/
     x-2.1220989d-05,-2.0201944d-08,-2.7814563d-08 /
      data fpp(27,11,10,1),fpp(27,11,10,2),fpp(27,11,10,3)/
     x-2.0008975d-05,-1.2058650d-08,-8.3225168d-09 /
      data fpp(27,11,11,1),fpp(27,11,11,2),fpp(27,11,11,3)/
     x-2.1198296d-05,-1.8780206d-08,-1.0895370d-08 /
      data fpp(27,11,12,1),fpp(27,11,12,2),fpp(27,11,12,3)/
     x-2.3009825d-05,-1.7512001d-08,-2.0960036d-09 /
      data fpp(27,11,13,1),fpp(27,11,13,2),fpp(27,11,13,3)/
     x-2.3739103d-05,-7.0063328d-09, 1.2793844d-09 /
      data fpp(27,11,14,1),fpp(27,11,14,2),fpp(27,11,14,3)/
     x-2.2925219d-05,-6.8164040d-09,-3.0215338d-09 /
      data fpp(27,11,15,1),fpp(27,11,15,2),fpp(27,11,15,3)/
     x-2.2197268d-05,-9.9718813d-09,-7.1932491d-09 /
      data fpp(27,11,16,1),fpp(27,11,16,2),fpp(27,11,16,3)/
     x-2.1495262d-05,-2.4022836d-08,-1.6205470d-08 /
      data fpp(27,11,17,1),fpp(27,11,17,2),fpp(27,11,17,3)/
     x-2.0779015d-05,-2.5871911d-08,-1.7984872d-08 /
      data fpp(27,11,18,1),fpp(27,11,18,2),fpp(27,11,18,3)/
     x-2.2190425d-05,-2.9611798d-08,-1.9855041d-08 /
      data fpp(27,11,19,1),fpp(27,11,19,2),fpp(27,11,19,3)/
     x-2.5159071d-05,-2.9012210d-08,-1.0594965d-08 /
      data fpp(27,11,20,1),fpp(27,11,20,2),fpp(27,11,20,3)/
     x-2.8363077d-05,-1.9292665d-08, 3.8234899d-08 /
      data fpp(27,11,21,1),fpp(27,11,21,2),fpp(27,11,21,3)/
     x-2.8363077d-05,-1.9292665d-08, 3.7592785d-08 /
      data fpp(27,11,22,1),fpp(27,11,22,2),fpp(27,11,22,3)/
     x-2.5159071d-05,-2.9012210d-08,-8.0265101d-09 /
      data fpp(27,11,23,1),fpp(27,11,23,2),fpp(27,11,23,3)/
     x-2.2190425d-05,-2.9611798d-08,-2.9486745d-08 /
      data fpp(27,12, 1,1),fpp(27,12, 1,2),fpp(27,12, 1,3)/
     x-3.9259861d-05, 4.1639200d-08, 1.6126188d-08 /
      data fpp(27,12, 2,1),fpp(27,12, 2,2),fpp(27,12, 2,3)/
     x-4.4445461d-05, 5.2878094d-08, 3.0247624d-08 /
      data fpp(27,12, 3,1),fpp(27,12, 3,2),fpp(27,12, 3,3)/
     x-4.8748050d-05, 5.7757999d-08, 6.0883315d-08 /
      data fpp(27,12, 4,1),fpp(27,12, 4,2),fpp(27,12, 4,3)/
     x-4.8748050d-05, 5.7757999d-08, 6.0226244d-08 /
      data fpp(27,12, 5,1),fpp(27,12, 5,2),fpp(27,12, 5,3)/
     x-4.4445461d-05, 5.2878094d-08, 3.2875907d-08 /
      data fpp(27,12, 6,1),fpp(27,12, 6,2),fpp(27,12, 6,3)/
     x-3.9259861d-05, 4.1639200d-08, 6.2701284d-09 /
      data fpp(27,12, 7,1),fpp(27,12, 7,2),fpp(27,12, 7,3)/
     x-3.3446272d-05, 3.0385111d-08,-1.5956421d-08 /
      data fpp(27,12, 8,1),fpp(27,12, 8,2),fpp(27,12, 8,3)/
     x-2.1044016d-05, 2.0871511d-08,-2.0444446d-08 /
      data fpp(27,12, 9,1),fpp(27,12, 9,2),fpp(27,12, 9,3)/
     x-2.3719903d-05, 4.1896264d-09,-2.8265795d-08 /
      data fpp(27,12,10,1),fpp(27,12,10,2),fpp(27,12,10,3)/
     x-2.1811150d-05,-4.2005785d-09,-2.2492374d-08 /
      data fpp(27,12,11,1),fpp(27,12,11,2),fpp(27,12,11,3)/
     x-2.1497647d-05, 1.0009874d-08,-1.3764711d-08 /
      data fpp(27,12,12,1),fpp(27,12,12,2),fpp(27,12,12,3)/
     x-2.2082928d-05, 1.0614099d-08,-4.4878303d-10 /
      data fpp(27,12,13,1),fpp(27,12,13,2),fpp(27,12,13,3)/
     x-2.2615136d-05,-4.5545555d-09,-8.4401570d-09 /
      data fpp(27,12,14,1),fpp(27,12,14,2),fpp(27,12,14,3)/
     x-2.1802840d-05,-5.6523724d-09,-1.7905889d-09 /
      data fpp(27,12,15,1),fpp(27,12,15,2),fpp(27,12,15,3)/
     x-2.1063531d-05,-1.2301524d-08,-1.4397487d-08 /
      data fpp(27,12,16,1),fpp(27,12,16,2),fpp(27,12,16,3)/
     x-1.9640891d-05,-8.9171952d-09,-1.2619462d-08 /
      data fpp(27,12,17,1),fpp(27,12,17,2),fpp(27,12,17,3)/
     x-1.9439592d-05,-1.5975704d-08,-1.9124665d-08 /
      data fpp(27,12,18,1),fpp(27,12,18,2),fpp(27,12,18,3)/
     x-2.0137942d-05,-1.5658889d-08,-1.8881878d-08 /
      data fpp(27,12,19,1),fpp(27,12,19,2),fpp(27,12,19,3)/
     x-2.2857225d-05,-1.0475285d-08,-7.3478242d-09 /
      data fpp(27,12,20,1),fpp(27,12,20,2),fpp(27,12,20,3)/
     x-2.6504944d-05,-3.7195294d-09, 3.6273174d-08 /
      data fpp(27,12,21,1),fpp(27,12,21,2),fpp(27,12,21,3)/
     x-2.6504944d-05,-3.7195294d-09, 3.5854389d-08 /
      data fpp(27,12,22,1),fpp(27,12,22,2),fpp(27,12,22,3)/
     x-2.2857225d-05,-1.0475285d-08,-5.6726826d-09 /
      data fpp(27,12,23,1),fpp(27,12,23,2),fpp(27,12,23,3)/
     x-2.0137942d-05,-1.5658889d-08,-2.5163659d-08 /
      data fpp(27,13, 1,1),fpp(27,13, 1,2),fpp(27,13, 1,3)/
     x-4.2585932d-05, 5.4610163d-08, 2.1209417d-08 /
      data fpp(27,13, 2,1),fpp(27,13, 2,2),fpp(27,13, 2,3)/
     x-4.7262635d-05, 5.6999543d-08, 3.1081167d-08 /
      data fpp(27,13, 3,1),fpp(27,13, 3,2),fpp(27,13, 3,3)/
     x-5.0203110d-05, 6.0962107d-08, 5.2465917d-08 /
      data fpp(27,13, 4,1),fpp(27,13, 4,2),fpp(27,13, 4,3)/
     x-5.0203110d-05, 6.0962107d-08, 5.2061665d-08 /
      data fpp(27,13, 5,1),fpp(27,13, 5,2),fpp(27,13, 5,3)/
     x-4.7262635d-05, 5.6999543d-08, 3.2698174d-08 /
      data fpp(27,13, 6,1),fpp(27,13, 6,2),fpp(27,13, 6,3)/
     x-4.2585932d-05, 5.4610163d-08, 1.5145637d-08 /
      data fpp(27,13, 7,1),fpp(27,13, 7,2),fpp(27,13, 7,3)/
     x-3.6801374d-05, 4.4861308d-08,-3.2807219d-09 /
      data fpp(27,13, 8,1),fpp(27,13, 8,2),fpp(27,13, 8,3)/
     x-3.0845035d-05, 3.2823798d-08,-1.4022749d-08 /
      data fpp(27,13, 9,1),fpp(27,13, 9,2),fpp(27,13, 9,3)/
     x-2.6602761d-05, 2.1443438d-08,-2.4628281d-08 /
      data fpp(27,13,10,1),fpp(27,13,10,2),fpp(27,13,10,3)/
     x-2.3834341d-05, 1.0860964d-08,-1.9464126d-08 /
      data fpp(27,13,11,1),fpp(27,13,11,2),fpp(27,13,11,3)/
     x-2.2980685d-05,-9.2592899d-09,-2.3515216d-08 /
      data fpp(27,13,12,1),fpp(27,13,12,2),fpp(27,13,12,3)/
     x-2.1576167d-05,-6.9443967d-09,-1.2475012d-08 /
      data fpp(27,13,13,1),fpp(27,13,13,2),fpp(27,13,13,3)/
     x-2.0691067d-05, 1.2245546d-09,-4.5847363d-09 /
      data fpp(27,13,14,1),fpp(27,13,14,2),fpp(27,13,14,3)/
     x-2.0099646d-05,-6.5741065d-09,-1.1186043d-08 /
      data fpp(27,13,15,1),fpp(27,13,15,2),fpp(27,13,15,3)/
     x-1.9031697d-05,-6.8220233d-09,-1.0671093d-08 /
      data fpp(27,13,16,1),fpp(27,13,16,2),fpp(27,13,16,3)/
     x-1.8345730d-05,-1.2308383d-08,-1.8129586d-08 /
      data fpp(27,13,17,1),fpp(27,13,17,2),fpp(27,13,17,3)/
     x-1.8118291d-05,-6.2252725d-09,-1.2810561d-08 /
      data fpp(27,13,18,1),fpp(27,13,18,2),fpp(27,13,18,3)/
     x-1.9635915d-05,-3.7526459d-09,-1.4628168d-08 /
      data fpp(27,13,19,1),fpp(27,13,19,2),fpp(27,13,19,3)/
     x-2.2488948d-05,-1.0866502d-09,-6.7676789d-10 /
      data fpp(27,13,20,1),fpp(27,13,20,2),fpp(27,13,20,3)/
     x-2.5404310d-05,-1.8292177d-09, 2.9335239d-08 /
      data fpp(27,13,21,1),fpp(27,13,21,2),fpp(27,13,21,3)/
     x-2.5404310d-05,-1.8292177d-09, 2.9332666d-08 /
      data fpp(27,13,22,1),fpp(27,13,22,2),fpp(27,13,22,3)/
     x-2.2488948d-05,-1.0866502d-09,-6.6647608d-10 /
      data fpp(27,13,23,1),fpp(27,13,23,2),fpp(27,13,23,3)/
     x-1.9635915d-05,-3.7526459d-09,-1.4666762d-08 /
      data fpp(27,14, 1,1),fpp(27,14, 1,2),fpp(27,14, 1,3)/
     x-4.3081333d-05, 5.1920149d-08, 2.6004155d-08 /
      data fpp(27,14, 2,1),fpp(27,14, 2,2),fpp(27,14, 2,3)/
     x-4.6560030d-05, 5.5123735d-08, 3.0991690d-08 /
      data fpp(27,14, 3,1),fpp(27,14, 3,2),fpp(27,14, 3,3)/
     x-4.9814776d-05, 5.2393573d-08, 4.2029085d-08 /
      data fpp(27,14, 4,1),fpp(27,14, 4,2),fpp(27,14, 4,3)/
     x-4.9814776d-05, 5.2393573d-08, 4.1416901d-08 /
      data fpp(27,14, 5,1),fpp(27,14, 5,2),fpp(27,14, 5,3)/
     x-4.6560030d-05, 5.5123735d-08, 3.3440424d-08 /
      data fpp(27,14, 6,1),fpp(27,14, 6,2),fpp(27,14, 6,3)/
     x-4.3081333d-05, 5.1920149d-08, 1.6821402d-08 /
      data fpp(27,14, 7,1),fpp(27,14, 7,2),fpp(27,14, 7,3)/
     x-3.8129416d-05, 4.8169657d-08, 7.2739667d-09 /
      data fpp(27,14, 8,1),fpp(27,14, 8,2),fpp(27,14, 8,3)/
     x-3.3215363d-05, 3.3833298d-08,-9.9172689d-09 /
      data fpp(27,14, 9,1),fpp(27,14, 9,2),fpp(27,14, 9,3)/
     x-2.9446661d-05, 1.8036621d-08,-1.5604891d-08 /
      data fpp(27,14,10,1),fpp(27,14,10,2),fpp(27,14,10,3)/
     x-2.0072604d-05, 2.7567217d-09,-2.3663167d-08 /
      data fpp(27,14,11,1),fpp(27,14,11,2),fpp(27,14,11,3)/
     x-2.3134942d-05,-2.9727143d-09,-1.5742441d-08 /
      data fpp(27,14,12,1),fpp(27,14,12,2),fpp(27,14,12,3)/
     x-2.2198567d-05,-1.8836512d-08,-2.1367071d-08 /
      data fpp(27,14,13,1),fpp(27,14,13,2),fpp(27,14,13,3)/
     x-1.9772103d-05,-2.4343663d-08,-1.2789277d-08 /
      data fpp(27,14,14,1),fpp(27,14,14,2),fpp(27,14,14,3)/
     x-1.7649883d-05,-1.6051202d-08,-1.1475822d-08 /
      data fpp(27,14,15,1),fpp(27,14,15,2),fpp(27,14,15,3)/
     x-1.7026980d-05,-1.4410383d-08,-1.3307434d-08 /
      data fpp(27,14,16,1),fpp(27,14,16,2),fpp(27,14,16,3)/
     x-1.7486179d-05,-7.8492711d-09,-1.3294442d-08 /
      data fpp(27,14,17,1),fpp(27,14,17,2),fpp(27,14,17,3)/
     x-1.8449588d-05,-7.1232060d-09,-1.1514796d-08 /
      data fpp(27,14,18,1),fpp(27,14,18,2),fpp(27,14,18,3)/
     x-2.0501166d-05,-5.3305271d-09,-6.6463724d-09 /
      data fpp(27,14,19,1),fpp(27,14,19,2),fpp(27,14,19,3)/
     x-2.3158209d-05,-3.1781145d-09, 2.1002858d-09 /
      data fpp(27,14,20,1),fpp(27,14,20,2),fpp(27,14,20,3)/
     x-2.5443778d-05,-9.6359969d-10, 2.2245229d-08 /
      data fpp(27,14,21,1),fpp(27,14,21,2),fpp(27,14,21,3)/
     x-2.5443778d-05,-9.6359969d-10, 2.2214170d-08 /
      data fpp(27,14,22,1),fpp(27,14,22,2),fpp(27,14,22,3)/
     x-2.3158209d-05,-3.1781145d-09, 2.2245229d-09 /
      data fpp(27,14,23,1),fpp(27,14,23,2),fpp(27,14,23,3)/
     x-2.0501166d-05,-5.3305271d-09,-7.1122615d-09 /
      data fpp(27,15, 1,1),fpp(27,15, 1,2),fpp(27,15, 1,3)/
     x-4.1080822d-05, 4.3709242d-08, 2.3540639d-08 /
      data fpp(27,15, 2,1),fpp(27,15, 2,2),fpp(27,15, 2,3)/
     x-4.3553954d-05, 4.6505519d-08, 2.6418722d-08 /
      data fpp(27,15, 3,1),fpp(27,15, 3,2),fpp(27,15, 3,3)/
     x-4.5817661d-05, 4.7463601d-08, 3.2784472d-08 /
      data fpp(27,15, 4,1),fpp(27,15, 4,2),fpp(27,15, 4,3)/
     x-4.5817661d-05, 4.7463601d-08, 3.2437223d-08 /
      data fpp(27,15, 5,1),fpp(27,15, 5,2),fpp(27,15, 5,3)/
     x-4.3553954d-05, 4.6505519d-08, 2.7807721d-08 /
      data fpp(27,15, 6,1),fpp(27,15, 6,2),fpp(27,15, 6,3)/
     x-4.1080822d-05, 4.3709242d-08, 1.8331895d-08 /
      data fpp(27,15, 7,1),fpp(27,15, 7,2),fpp(27,15, 7,3)/
     x-3.7898080d-05, 3.2460064d-08, 6.8646989d-09 /
      data fpp(27,15, 8,1),fpp(27,15, 8,2),fpp(27,15, 8,3)/
     x-3.3921995d-05, 2.3843011d-08,-3.7906906d-09 /
      data fpp(27,15, 9,1),fpp(27,15, 9,2),fpp(27,15, 9,3)/
     x-3.0469333d-05, 1.4410077d-08,-9.7019366d-09 /
      data fpp(27,15,10,1),fpp(27,15,10,2),fpp(27,15,10,3)/
     x-2.7054588d-05, 2.1121492d-09,-1.7401563d-08 /
      data fpp(27,15,11,1),fpp(27,15,11,2),fpp(27,15,11,3)/
     x-2.3747190d-05,-8.8498528d-09,-1.6691811d-08 /
      data fpp(27,15,12,1),fpp(27,15,12,2),fpp(27,15,12,3)/
     x-2.1623403d-05,-1.3709553d-08,-1.7831191d-08 /
      data fpp(27,15,13,1),fpp(27,15,13,2),fpp(27,15,13,3)/
     x-1.8882638d-05,-1.7849902d-08,-1.3983424d-08 /
      data fpp(27,15,14,1),fpp(27,15,14,2),fpp(27,15,14,3)/
     x-2.1852431d-05,-2.5221087d-08,-1.6235112d-08 /
      data fpp(27,15,15,1),fpp(27,15,15,2),fpp(27,15,15,3)/
     x-1.5847271d-05,-1.9536444d-08,-1.1076129d-08 /
      data fpp(27,15,16,1),fpp(27,15,16,2),fpp(27,15,16,3)/
     x-1.6002638d-05,-1.6294532d-08,-1.1460371d-08 /
      data fpp(27,15,17,1),fpp(27,15,17,2),fpp(27,15,17,3)/
     x-1.7868057d-05,-7.2819034d-09,-9.0823883d-09 /
      data fpp(27,15,18,1),fpp(27,15,18,2),fpp(27,15,18,3)/
     x-1.9397098d-05, 1.0747545d-09,-2.1007624d-10 /
      data fpp(27,15,19,1),fpp(27,15,19,2),fpp(27,15,19,3)/
     x-2.2088665d-05, 1.7991080d-09, 3.9226933d-09 /
      data fpp(27,15,20,1),fpp(27,15,20,2),fpp(27,15,20,3)/
     x-2.3545239d-05,-3.1638351d-10, 1.4519303d-08 /
      data fpp(27,15,21,1),fpp(27,15,21,2),fpp(27,15,21,3)/
     x-2.3545239d-05,-3.1638351d-10, 1.4480744d-08 /
      data fpp(27,15,22,1),fpp(27,15,22,2),fpp(27,15,22,3)/
     x-2.2088665d-05, 1.7991080d-09, 4.0769303d-09 /
      data fpp(27,15,23,1),fpp(27,15,23,2),fpp(27,15,23,3)/
     x-1.9397098d-05, 1.0747545d-09,-7.8846516d-10 /
      data fpp(27,16, 1,1),fpp(27,16, 1,2),fpp(27,16, 1,3)/
     x-3.7794077d-05, 2.5242884d-08, 1.5998246d-08 /
      data fpp(27,16, 2,1),fpp(27,16, 2,2),fpp(27,16, 2,3)/
     x-4.0083058d-05, 2.8854191d-08, 1.8503509d-08 /
      data fpp(27,16, 3,1),fpp(27,16, 3,2),fpp(27,16, 3,3)/
     x-4.0720695d-05, 2.7752025d-08, 2.3987719d-08 /
      data fpp(27,16, 4,1),fpp(27,16, 4,2),fpp(27,16, 4,3)/
     x-4.0720695d-05, 2.7752025d-08, 2.3785090d-08 /
      data fpp(27,16, 5,1),fpp(27,16, 5,2),fpp(27,16, 5,3)/
     x-4.0083058d-05, 2.8854191d-08, 1.9314025d-08 /
      data fpp(27,16, 6,1),fpp(27,16, 6,2),fpp(27,16, 6,3)/
     x-3.7794077d-05, 2.5242884d-08, 1.2958812d-08 /
      data fpp(27,16, 7,1),fpp(27,16, 7,2),fpp(27,16, 7,3)/
     x-3.5094875d-05, 2.5990086d-08, 6.8507288d-09 /
      data fpp(27,16, 8,1),fpp(27,16, 8,2),fpp(27,16, 8,3)/
     x-3.2517614d-05, 2.0794657d-08, 1.6382731d-09 /
      data fpp(27,16, 9,1),fpp(27,16, 9,2),fpp(27,16, 9,3)/
     x-2.9909390d-05, 1.4323072d-08,-7.4038213d-09 /
      data fpp(27,16,10,1),fpp(27,16,10,2),fpp(27,16,10,3)/
     x-2.7179777d-05, 6.7946817d-09,-8.0229879d-09 /
      data fpp(27,16,11,1),fpp(27,16,11,2),fpp(27,16,11,3)/
     x-2.4528205d-05,-3.6278745d-09,-1.4504227d-08 /
      data fpp(27,16,12,1),fpp(27,16,12,2),fpp(27,16,12,3)/
     x-2.1949990d-05,-1.0325274d-08,-1.1960104d-08 /
      data fpp(27,16,13,1),fpp(27,16,13,2),fpp(27,16,13,3)/
     x-1.9818439d-05,-1.8256727d-08,-1.5655356d-08 /
      data fpp(27,16,14,1),fpp(27,16,14,2),fpp(27,16,14,3)/
     x-1.7330486d-05,-1.5064451d-08,-9.4184701d-09 /
      data fpp(27,16,15,1),fpp(27,16,15,2),fpp(27,16,15,3)/
     x-1.5813644d-05,-1.5443840d-08,-1.2670763d-08 /
      data fpp(27,16,16,1),fpp(27,16,16,2),fpp(27,16,16,3)/
     x-1.4610778d-05,-1.0972600d-08,-5.8984777d-09 /
      data fpp(27,16,17,1),fpp(27,16,17,2),fpp(27,16,17,3)/
     x-1.6143605d-05,-1.1749181d-08,-5.7353262d-09 /
      data fpp(27,16,18,1),fpp(27,16,18,2),fpp(27,16,18,3)/
     x-1.7597273d-05,-1.0968491d-08,-1.1602173d-09 /
      data fpp(27,16,19,1),fpp(27,16,19,2),fpp(27,16,19,3)/
     x-1.8687182d-05,-1.0018318d-08, 4.3761956d-09 /
      data fpp(27,16,20,1),fpp(27,16,20,2),fpp(27,16,20,3)/
     x-2.0059560d-05,-9.7708663d-09, 7.6554348d-09 /
      data fpp(27,16,21,1),fpp(27,16,21,2),fpp(27,16,21,3)/
     x-2.0059560d-05,-9.7708663d-09, 7.8455978d-09 /
      data fpp(27,16,22,1),fpp(27,16,22,2),fpp(27,16,22,3)/
     x-1.8687182d-05,-1.0018318d-08, 3.6155435d-09 /
      data fpp(27,16,23,1),fpp(27,16,23,2),fpp(27,16,23,3)/
     x-1.7597273d-05,-1.0968491d-08, 1.6922283d-09 /
      data fpp(27,17, 1,1),fpp(27,17, 1,2),fpp(27,17, 1,3)/
     x-3.3620196d-05,-6.8077636d-10, 5.0492310d-09 /
      data fpp(27,17, 2,1),fpp(27,17, 2,2),fpp(27,17, 2,3)/
     x-3.4875383d-05,-5.9222822d-09, 8.4015381d-09 /
      data fpp(27,17, 3,1),fpp(27,17, 3,2),fpp(27,17, 3,3)/
     x-3.4366130d-05,-2.4716989d-09, 1.5344617d-08 /
      data fpp(27,17, 4,1),fpp(27,17, 4,2),fpp(27,17, 4,3)/
     x-3.4366130d-05,-2.4716989d-09, 1.5765381d-08 /
      data fpp(27,17, 5,1),fpp(27,17, 5,2),fpp(27,17, 5,3)/
     x-3.4875383d-05,-5.9222822d-09, 6.7184818d-09 /
      data fpp(27,17, 6,1),fpp(27,17, 6,2),fpp(27,17, 6,3)/
     x-3.3620196d-05,-6.8077636d-10, 1.1360692d-08 /
      data fpp(27,17, 7,1),fpp(27,17, 7,2),fpp(27,17, 7,3)/
     x-3.2540714d-05, 1.5795923d-09, 1.8387495d-09 /
      data fpp(27,17, 8,1),fpp(27,17, 8,2),fpp(27,17, 8,3)/
     x-3.0293589d-05, 6.9783616d-09, 5.2843097d-09 /
      data fpp(27,17, 9,1),fpp(27,17, 9,2),fpp(27,17, 9,3)/
     x-2.9154434d-05, 6.2976344d-09,-4.9759882d-09 /
      data fpp(27,17,10,1),fpp(27,17,10,2),fpp(27,17,10,3)/
     x-2.6893812d-05, 6.7091242d-09,-3.3803567d-09 /
      data fpp(27,17,11,1),fpp(27,17,11,2),fpp(27,17,11,3)/
     x-2.4684129d-05, 5.3613508d-09,-5.5025850d-09 /
      data fpp(27,17,12,1),fpp(27,17,12,2),fpp(27,17,12,3)/
     x-2.2682734d-05, 1.0106508d-09,-1.0609303d-08 /
      data fpp(27,17,13,1),fpp(27,17,13,2),fpp(27,17,13,3)/
     x-2.0595379d-05, 8.7681116d-10,-6.0602022d-09 /
      data fpp(27,17,14,1),fpp(27,17,14,2),fpp(27,17,14,3)/
     x-1.8727292d-05,-4.5211094d-09,-7.1498881d-09 /
      data fpp(27,17,15,1),fpp(27,17,15,2),fpp(27,17,15,3)/
     x-1.7483101d-05,-8.6881970d-09,-7.3402453d-09 /
      data fpp(27,17,16,1),fpp(27,17,16,2),fpp(27,17,16,3)/
     x-1.6195032d-05,-1.1815069d-08,-5.4891308d-09 /
      data fpp(27,17,17,1),fpp(27,17,17,2),fpp(27,17,17,3)/
     x-1.5689932d-05,-1.1721374d-08,-7.0323145d-10 /
      data fpp(27,17,18,1),fpp(27,17,18,2),fpp(27,17,18,3)/
     x-1.6047888d-05,-1.7200791d-08,-3.6979434d-09 /
      data fpp(27,17,19,1),fpp(27,17,19,2),fpp(27,17,19,3)/
     x-1.6327011d-05,-2.1725838d-08, 3.4950049d-09 /
      data fpp(27,17,20,1),fpp(27,17,20,2),fpp(27,17,20,3)/
     x-1.6891079d-05,-2.6600151d-08, 1.7179236d-09 /
      data fpp(27,17,21,1),fpp(27,17,21,2),fpp(27,17,21,3)/
     x-1.6891079d-05,-2.6600151d-08, 2.0987267d-09 /
      data fpp(27,17,22,1),fpp(27,17,22,2),fpp(27,17,22,3)/
     x-1.6327011d-05,-2.1725838d-08, 1.9717924d-09 /
      data fpp(27,17,23,1),fpp(27,17,23,2),fpp(27,17,23,3)/
     x-1.6047888d-05,-1.7200791d-08, 2.0141038d-09 /
      data fpp(27,18, 1,1),fpp(27,18, 1,2),fpp(27,18, 1,3)/
     x-2.8168779d-05,-1.6519778d-08, 3.0698919d-09 /
      data fpp(27,18, 2,1),fpp(27,18, 2,2),fpp(27,18, 2,3)/
     x-2.8764190d-05,-2.3165062d-08, 3.8602163d-09 /
      data fpp(27,18, 3,1),fpp(27,18, 3,2),fpp(27,18, 3,3)/
     x-2.8940614d-05,-2.9865229d-08, 5.4892430d-09 /
      data fpp(27,18, 4,1),fpp(27,18, 4,2),fpp(27,18, 4,3)/
     x-2.8940614d-05,-2.9865229d-08, 5.6021628d-09 /
      data fpp(27,18, 5,1),fpp(27,18, 5,2),fpp(27,18, 5,3)/
     x-2.8764190d-05,-2.3165062d-08, 3.4085371d-09 /
      data fpp(27,18, 6,1),fpp(27,18, 6,2),fpp(27,18, 6,3)/
     x-2.8168779d-05,-1.6519778d-08, 4.7636889d-09 /
      data fpp(27,18, 7,1),fpp(27,18, 7,2),fpp(27,18, 7,3)/
     x-2.7901289d-05,-8.3084549d-09, 1.5367075d-09 /
      data fpp(27,18, 8,1),fpp(27,18, 8,2),fpp(27,18, 8,3)/
     x-2.7018017d-05,-7.0810333d-10, 1.0894813d-09 /
      data fpp(27,18, 9,1),fpp(27,18, 9,2),fpp(27,18, 9,3)/
     x-2.6346381d-05, 8.4863902d-09, 1.0536741d-10 /
      data fpp(27,18,10,1),fpp(27,18,10,2),fpp(27,18,10,3)/
     x-2.5256490d-05, 1.4368822d-08,-1.5109509d-09 /
      data fpp(27,18,11,1),fpp(27,18,11,2),fpp(27,18,11,3)/
     x-2.4161996d-05, 1.8182471d-08,-6.1563709d-11 /
      data fpp(27,18,12,1),fpp(27,18,12,2),fpp(27,18,12,3)/
     x-2.3054244d-05, 1.8282671d-08,-4.2427942d-09 /
      data fpp(27,18,13,1),fpp(27,18,13,2),fpp(27,18,13,3)/
     x-2.1574019d-05, 1.4749483d-08,-9.6725934d-10 /
      data fpp(27,18,14,1),fpp(27,18,14,2),fpp(27,18,14,3)/
     x-2.0657508d-05, 9.1488884d-09,-3.8881684d-09 /
      data fpp(27,18,15,1),fpp(27,18,15,2),fpp(27,18,15,3)/
     x-1.9745235d-05, 2.1966277d-09,-1.4800671d-09 /
      data fpp(27,18,16,1),fpp(27,18,16,2),fpp(27,18,16,3)/
     x-1.8962311d-05,-7.7671230d-09,-2.1915633d-09 /
      data fpp(27,18,17,1),fpp(27,18,17,2),fpp(27,18,17,3)/
     x-1.8647833d-05,-1.9365322d-08,-1.7536798d-09 /
      data fpp(27,18,18,1),fpp(27,18,18,2),fpp(27,18,18,3)/
     x-1.8600383d-05,-2.8228345d-08,-2.7937175d-09 /
      data fpp(27,18,19,1),fpp(27,18,19,2),fpp(27,18,19,3)/
     x-1.7898139d-05,-3.5078332d-08, 9.2854963d-10 /
      data fpp(27,18,20,1),fpp(27,18,20,2),fpp(27,18,20,3)/
     x-1.8044043d-05,-3.9828528d-08,-9.2048106d-10 /
      data fpp(27,18,21,1),fpp(27,18,21,2),fpp(27,18,21,3)/
     x-1.8044043d-05,-3.9828528d-08,-7.0283163d-10 /
      data fpp(27,18,22,1),fpp(27,18,22,2),fpp(27,18,22,3)/
     x-1.7898139d-05,-3.5078332d-08, 5.7951894d-11 /
      data fpp(27,18,23,1),fpp(27,18,23,2),fpp(27,18,23,3)/
     x-1.8600383d-05,-2.8228345d-08, 4.7102405d-10 /
      data fpp(27,19, 1,1),fpp(27,19, 1,2),fpp(27,19, 1,3)/
     x-2.3308480d-05,-3.5240111d-08, 1.3410406d-22 /
      data fpp(27,19, 2,1),fpp(27,19, 2,2),fpp(27,19, 2,3)/
     x-2.3308480d-05,-4.5417469d-08,-3.7852730d-23 /
      data fpp(27,19, 3,1),fpp(27,19, 3,2),fpp(27,19, 3,3)/
     x-2.3308480d-05,-5.8067386d-08, 9.8856336d-23 /
      data fpp(27,19, 4,1),fpp(27,19, 4,2),fpp(27,19, 4,3)/
     x-2.3308480d-05,-5.8067386d-08,-9.5567490d-23 /
      data fpp(27,19, 5,1),fpp(27,19, 5,2),fpp(27,19, 5,3)/
     x-2.3308480d-05,-4.5417469d-08,-4.3188252d-23 /
      data fpp(27,19, 6,1),fpp(27,19, 6,2),fpp(27,19, 6,3)/
     x-2.3308480d-05,-3.5240111d-08,-8.1114732d-24 /
      data fpp(27,19, 7,1),fpp(27,19, 7,2),fpp(27,19, 7,3)/
     x-2.3308480d-05,-2.2345773d-08, 3.8332824d-22 /
      data fpp(27,19, 8,1),fpp(27,19, 8,2),fpp(27,19, 8,3)/
     x-2.3308480d-05,-1.0145948d-08, 2.0745691d-22 /
      data fpp(27,19, 9,1),fpp(27,19, 9,2),fpp(27,19, 9,3)/
     x-2.3308480d-05, 7.7568049d-09, 1.7389090d-23 /
      data fpp(27,19,10,1),fpp(27,19,10,2),fpp(27,19,10,3)/
     x-2.3308480d-05, 1.9815589d-08,-2.3862119d-22 /
      data fpp(27,19,11,1),fpp(27,19,11,2),fpp(27,19,11,3)/
     x-2.3308480d-05, 2.9908764d-08, 1.5367944d-22 /
      data fpp(27,19,12,1),fpp(27,19,12,2),fpp(27,19,12,3)/
     x-2.3308480d-05, 3.3858664d-08,-3.6850997d-22 /
      data fpp(27,19,13,1),fpp(27,19,13,2),fpp(27,19,13,3)/
     x-2.3308480d-05, 3.0125259d-08,-2.3161811d-22 /
      data fpp(27,19,14,1),fpp(27,19,14,2),fpp(27,19,14,3)/
     x-2.3308480d-05, 2.1925556d-08,-2.4425747d-22 /
      data fpp(27,19,15,1),fpp(27,19,15,2),fpp(27,19,15,3)/
     x-2.3308480d-05, 1.1901686d-08, 4.7699423d-23 /
      data fpp(27,19,16,1),fpp(27,19,16,2),fpp(27,19,16,3)/
     x-2.3308480d-05,-5.1164385d-09, 3.3164526d-22 /
      data fpp(27,19,17,1),fpp(27,19,17,2),fpp(27,19,17,3)/
     x-2.3308480d-05,-2.4817339d-08,-1.9458910d-22 /
      data fpp(27,19,18,1),fpp(27,19,18,2),fpp(27,19,18,3)/
     x-2.3308480d-05,-3.7885827d-08, 8.0340735d-23 /
      data fpp(27,19,19,1),fpp(27,19,19,2),fpp(27,19,19,3)/
     x-2.3308480d-05,-4.7960834d-08, 2.8292715d-22 /
      data fpp(27,19,20,1),fpp(27,19,20,2),fpp(27,19,20,3)/
     x-2.3308480d-05,-5.4085736d-08,-2.3464013d-22 /
      data fpp(27,19,21,1),fpp(27,19,21,2),fpp(27,19,21,3)/
     x-2.3308480d-05,-5.4085736d-08, 8.9347975d-24 /
      data fpp(27,19,22,1),fpp(27,19,22,2),fpp(27,19,22,3)/
     x-2.3308480d-05,-4.7960834d-08,-1.7718451d-22 /
      data fpp(27,19,23,1),fpp(27,19,23,2),fpp(27,19,23,3)/
     x-2.3308480d-05,-3.7885827d-08,-7.4670252d-22 /
      data fpp(28, 1, 1,1),fpp(28, 1, 1,2),fpp(28, 1, 1,3)/
     x-3.2752189d-05,-5.6696396d-08,-6.8478824d-23 /
      data fpp(28, 1, 2,1),fpp(28, 1, 2,2),fpp(28, 1, 2,3)/
     x-3.2752189d-05,-7.7615911d-08, 5.4045368d-22 /
      data fpp(28, 1, 3,1),fpp(28, 1, 3,2),fpp(28, 1, 3,3)/
     x-3.2752189d-05,-9.0943399d-08, 1.9158963d-22 /
      data fpp(28, 1, 4,1),fpp(28, 1, 4,2),fpp(28, 1, 4,3)/
     x-3.2752189d-05,-9.0943399d-08,-2.9388169d-22 /
      data fpp(28, 1, 5,1),fpp(28, 1, 5,2),fpp(28, 1, 5,3)/
     x-3.2752189d-05,-7.7615911d-08, 1.7177221d-22 /
      data fpp(28, 1, 6,1),fpp(28, 1, 6,2),fpp(28, 1, 6,3)/
     x-3.2752189d-05,-5.6696396d-08, 4.3624499d-22 /
      data fpp(28, 1, 7,1),fpp(28, 1, 7,2),fpp(28, 1, 7,3)/
     x-3.2752189d-05,-3.2959581d-08, 5.4180728d-22 /
      data fpp(28, 1, 8,1),fpp(28, 1, 8,2),fpp(28, 1, 8,3)/
     x-3.2752189d-05,-1.1405353d-08, 1.5383327d-22 /
      data fpp(28, 1, 9,1),fpp(28, 1, 9,2),fpp(28, 1, 9,3)/
     x-3.2752189d-05, 3.5476485d-09,-1.2655767d-22 /
      data fpp(28, 1,10,1),fpp(28, 1,10,2),fpp(28, 1,10,3)/
     x-3.2752189d-05, 1.8411633d-08,-4.7275452d-22 /
      data fpp(28, 1,11,1),fpp(28, 1,11,2),fpp(28, 1,11,3)/
     x-3.2752189d-05, 2.2745823d-08, 2.1138091d-22 /
      data fpp(28, 1,12,1),fpp(28, 1,12,2),fpp(28, 1,12,3)/
     x-3.2752189d-05, 2.7086152d-08,-4.8623269d-22 /
      data fpp(28, 1,13,1),fpp(28, 1,13,2),fpp(28, 1,13,3)/
     x-3.2752189d-05, 2.5382756d-08,-3.7917045d-22 /
      data fpp(28, 1,14,1),fpp(28, 1,14,2),fpp(28, 1,14,3)/
     x-3.2752189d-05, 1.3212344d-08,-1.2335319d-22 /
      data fpp(28, 1,15,1),fpp(28, 1,15,2),fpp(28, 1,15,3)/
     x-3.2752189d-05, 3.0763350d-10,-1.9095329d-22 /
      data fpp(28, 1,16,1),fpp(28, 1,16,2),fpp(28, 1,16,3)/
     x-3.2752189d-05,-1.2691877d-08, 4.1517905d-22 /
      data fpp(28, 1,17,1),fpp(28, 1,17,2),fpp(28, 1,17,3)/
     x-3.2752189d-05,-3.4234128d-08,-1.0171092d-22 /
      data fpp(28, 1,18,1),fpp(28, 1,18,2),fpp(28, 1,18,3)/
     x-3.2752189d-05,-5.8014016d-08, 6.7849312d-22 /
      data fpp(28, 1,19,1),fpp(28, 1,19,2),fpp(28, 1,19,3)/
     x-3.2752189d-05,-7.7442301d-08, 7.1866588d-22 /
      data fpp(28, 1,20,1),fpp(28, 1,20,2),fpp(28, 1,20,3)/
     x-3.2752189d-05,-9.4882031d-08,-4.7832229d-22 /
      data fpp(28, 1,21,1),fpp(28, 1,21,2),fpp(28, 1,21,3)/
     x-3.2752189d-05,-9.4882031d-08, 2.4737880d-22 /
      data fpp(28, 1,22,1),fpp(28, 1,22,2),fpp(28, 1,22,3)/
     x-3.2752189d-05,-7.7442301d-08,-4.1624951d-22 /
      data fpp(28, 1,23,1),fpp(28, 1,23,2),fpp(28, 1,23,3)/
     x-3.2752189d-05,-5.8014016d-08,-1.0460367d-21 /
      data fpp(28, 2, 1,1),fpp(28, 2, 1,2),fpp(28, 2, 1,3)/
     x-2.8270592d-05, 1.8392791d-08, 4.4704261d-09 /
      data fpp(28, 2, 2,1),fpp(28, 2, 2,2),fpp(28, 2, 2,3)/
     x-2.7830854d-05, 9.2318219d-09, 4.0591478d-09 /
      data fpp(28, 2, 3,1),fpp(28, 2, 3,2),fpp(28, 2, 3,3)/
     x-3.0518994d-05, 1.8867971d-09, 3.2929828d-09 /
      data fpp(28, 2, 4,1),fpp(28, 2, 4,2),fpp(28, 2, 4,3)/
     x-3.0518994d-05, 1.8867971d-09, 3.0914777d-09 /
      data fpp(28, 2, 5,1),fpp(28, 2, 5,2),fpp(28, 2, 5,3)/
     x-2.7830854d-05, 9.2318219d-09, 4.8651680d-09 /
      data fpp(28, 2, 6,1),fpp(28, 2, 6,2),fpp(28, 2, 6,3)/
     x-2.8270592d-05, 1.8392791d-08, 1.4478504d-09 /
      data fpp(28, 2, 7,1),fpp(28, 2, 7,2),fpp(28, 2, 7,3)/
     x-2.9791992d-05, 2.6919161d-08, 1.3434303d-09 /
      data fpp(28, 2, 8,1),fpp(28, 2, 8,2),fpp(28, 2, 8,3)/
     x-3.2075439d-05, 3.2810706d-08,-8.2157162d-10 /
      data fpp(28, 2, 9,1),fpp(28, 2, 9,2),fpp(28, 2, 9,3)/
     x-3.4714348d-05, 3.4904703d-08,-4.0571438d-09 /
      data fpp(28, 2,10,1),fpp(28, 2,10,2),fpp(28, 2,10,3)/
     x-3.6340491d-05, 3.7176733d-08,-9.4985318d-10 /
      data fpp(28, 2,11,1),fpp(28, 2,11,2),fpp(28, 2,11,3)/
     x-3.7822037d-05, 3.5508354d-08,-4.1434435d-09 /
      data fpp(28, 2,12,1),fpp(28, 2,12,2),fpp(28, 2,12,3)/
     x-3.7957631d-05, 3.5827697d-08,-6.4763730d-09 /
      data fpp(28, 2,13,1),fpp(28, 2,13,2),fpp(28, 2,13,3)/
     x-3.7080735d-05, 3.6234487d-08, 4.8935285d-11 /
      data fpp(28, 2,14,1),fpp(28, 2,14,2),fpp(28, 2,14,3)/
     x-3.6338095d-05, 3.3575311d-08,-5.7193682d-09 /
      data fpp(28, 2,15,1),fpp(28, 2,15,2),fpp(28, 2,15,3)/
     x-3.4235131d-05, 3.2384733d-08,-1.1714625d-09 /
      data fpp(28, 2,16,1),fpp(28, 2,16,2),fpp(28, 2,16,3)/
     x-3.1308909d-05, 3.1383754d-08,-1.5947816d-09 /
      data fpp(28, 2,17,1),fpp(28, 2,17,2),fpp(28, 2,17,3)/
     x-2.8628518d-05, 2.6468257d-08, 1.5505891d-09 /
      data fpp(28, 2,18,1),fpp(28, 2,18,2),fpp(28, 2,18,3)/
     x-2.6576948d-05, 1.9028033d-08, 1.3924252d-09 /
      data fpp(28, 2,19,1),fpp(28, 2,19,2),fpp(28, 2,19,3)/
     x-2.6441508d-05, 1.1884602d-08, 4.8797102d-09 /
      data fpp(28, 2,20,1),fpp(28, 2,20,2),fpp(28, 2,20,3)/
     x-2.8053844d-05, 3.7640626d-09, 3.0887339d-09 /
      data fpp(28, 2,21,1),fpp(28, 2,21,2),fpp(28, 2,21,3)/
     x-2.8053844d-05, 3.7640626d-09, 3.2939431d-09 /
      data fpp(28, 2,22,1),fpp(28, 2,22,2),fpp(28, 2,22,3)/
     x-2.6441508d-05, 1.1884602d-08, 4.0588734d-09 /
      data fpp(28, 2,23,1),fpp(28, 2,23,2),fpp(28, 2,23,3)/
     x-2.6576948d-05, 1.9028033d-08, 4.4705633d-09 /
      data fpp(28, 3, 1,1),fpp(28, 3, 1,2),fpp(28, 3, 1,3)/
     x-3.4427561d-05, 1.6912523d-07, 7.8569455d-09 /
      data fpp(28, 3, 2,1),fpp(28, 3, 2,2),fpp(28, 3, 2,3)/
     x-3.1195717d-05, 1.8468862d-07, 8.7861089d-09 /
      data fpp(28, 3, 3,1),fpp(28, 3, 3,2),fpp(28, 3, 3,3)/
     x-3.1963710d-05, 1.9139621d-07, 1.0998619d-08 /
      data fpp(28, 3, 4,1),fpp(28, 3, 4,2),fpp(28, 3, 4,3)/
     x-3.1963710d-05, 1.9139621d-07, 1.0611089d-08 /
      data fpp(28, 3, 5,1),fpp(28, 3, 5,2),fpp(28, 3, 5,3)/
     x-3.1195717d-05, 1.8468862d-07, 1.0336227d-08 /
      data fpp(28, 3, 6,1),fpp(28, 3, 6,2),fpp(28, 3, 6,3)/
     x-3.4427561d-05, 1.6912523d-07, 2.0440019d-09 /
      data fpp(28, 3, 7,1),fpp(28, 3, 7,2),fpp(28, 3, 7,3)/
     x-3.9288371d-05, 1.4728293d-07,-5.1223484d-10 /
      data fpp(28, 3, 8,1),fpp(28, 3, 8,2),fpp(28, 3, 8,3)/
     x-4.3763828d-05, 1.2016253d-07,-5.9950626d-09 /
      data fpp(28, 3, 9,1),fpp(28, 3, 9,2),fpp(28, 3, 9,3)/
     x-4.7094921d-05, 9.6833539d-08,-5.5075149d-09 /
      data fpp(28, 3,10,1),fpp(28, 3,10,2),fpp(28, 3,10,3)/
     x-4.9578247d-05, 7.2881434d-08,-7.9748778d-09 /
      data fpp(28, 3,11,1),fpp(28, 3,11,2),fpp(28, 3,11,3)/
     x-5.0893973d-05, 5.7220761d-08,-4.5929741d-09 /
      data fpp(28, 3,12,1),fpp(28, 3,12,2),fpp(28, 3,12,3)/
     x-5.1643289d-05, 4.5603062d-08,-9.6532260d-09 /
      data fpp(28, 3,13,1),fpp(28, 3,13,2),fpp(28, 3,13,3)/
     x-5.0721946d-05, 5.1679294d-08,-4.7941221d-09 /
      data fpp(28, 3,14,1),fpp(28, 3,14,2),fpp(28, 3,14,3)/
     x-4.9178103d-05, 6.8486411d-08,-7.1702857d-09 /
      data fpp(28, 3,15,1),fpp(28, 3,15,2),fpp(28, 3,15,3)/
     x-4.6173672d-05, 9.2153434d-08,-2.5247352d-09 /
      data fpp(28, 3,16,1),fpp(28, 3,16,2),fpp(28, 3,16,3)/
     x-4.2036142d-05, 1.1515686d-07,-6.7307736d-09 /
      data fpp(28, 3,17,1),fpp(28, 3,17,2),fpp(28, 3,17,3)/
     x-3.6602362d-05, 1.4436110d-07,-5.5217030d-10 /
      data fpp(28, 3,18,1),fpp(28, 3,18,2),fpp(28, 3,18,3)/
     x-3.0866926d-05, 1.6790189d-07, 2.9394548d-09 /
      data fpp(28, 3,19,1),fpp(28, 3,19,2),fpp(28, 3,19,3)/
     x-2.6605365d-05, 1.7990389d-07, 6.7943510d-09 /
      data fpp(28, 3,20,1),fpp(28, 3,20,2),fpp(28, 3,20,3)/
     x-2.5832907d-05, 1.8782578d-07, 1.1883141d-08 /
      data fpp(28, 3,21,1),fpp(28, 3,21,2),fpp(28, 3,21,3)/
     x-2.5832907d-05, 1.8782578d-07, 1.1953401d-08 /
      data fpp(28, 3,22,1),fpp(28, 3,22,2),fpp(28, 3,22,3)/
     x-2.6605365d-05, 1.7990389d-07, 6.5133141d-09 /
      data fpp(28, 3,23,1),fpp(28, 3,23,2),fpp(28, 3,23,3)/
     x-3.0866926d-05, 1.6790189d-07, 3.9933429d-09 /
      data fpp(28, 4, 1,1),fpp(28, 4, 1,2),fpp(28, 4, 1,3)/
     x-3.9773450d-05, 5.5106289d-08, 1.9898763d-09 /
      data fpp(28, 4, 2,1),fpp(28, 4, 2,2),fpp(28, 4, 2,3)/
     x-3.3959770d-05, 5.0013685d-08, 7.0202474d-09 /
      data fpp(28, 4, 3,1),fpp(28, 4, 3,2),fpp(28, 4, 3,3)/
     x-2.9500643d-05, 4.2528362d-08, 1.7929134d-08 /
      data fpp(28, 4, 4,1),fpp(28, 4, 4,2),fpp(28, 4, 4,3)/
     x-2.9500643d-05, 4.2528362d-08, 1.7702474d-08 /
      data fpp(28, 4, 5,1),fpp(28, 4, 5,2),fpp(28, 4, 5,3)/
     x-3.3959770d-05, 5.0013685d-08, 7.9268858d-09 /
      data fpp(28, 4, 6,1),fpp(28, 4, 6,2),fpp(28, 4, 6,3)/
     x-3.9773450d-05, 5.5106289d-08,-1.4100176d-09 /
      data fpp(28, 4, 7,1),fpp(28, 4, 7,2),fpp(28, 4, 7,3)/
     x-4.5777219d-05, 5.5949099d-08,-8.2868153d-09 /
      data fpp(28, 4, 8,1),fpp(28, 4, 8,2),fpp(28, 4, 8,3)/
     x-5.0431037d-05, 5.6539184d-08,-7.4427212d-09 /
      data fpp(28, 4, 9,1),fpp(28, 4, 9,2),fpp(28, 4, 9,3)/
     x-5.3324819d-05, 5.1761140d-08,-9.9423001d-09 /
      data fpp(28, 4,10,1),fpp(28, 4,10,2),fpp(28, 4,10,3)/
     x-5.4161108d-05, 4.9297532d-08,-6.7880785d-09 /
      data fpp(28, 4,11,1),fpp(28, 4,11,2),fpp(28, 4,11,3)/
     x-5.3985095d-05, 4.7608602d-08,-4.9053860d-09 /
      data fpp(28, 4,12,1),fpp(28, 4,12,2),fpp(28, 4,12,3)/
     x-5.3573321d-05, 5.1760056d-08, 2.4096225d-09 /
      data fpp(28, 4,13,1),fpp(28, 4,13,2),fpp(28, 4,13,3)/
     x-5.3980800d-05, 5.1048336d-08,-4.7331039d-09 /
      data fpp(28, 4,14,1),fpp(28, 4,14,2),fpp(28, 4,14,3)/
     x-5.3983319d-05, 5.2479044d-08,-1.4772067d-09 /
      data fpp(28, 4,15,1),fpp(28, 4,15,2),fpp(28, 4,15,3)/
     x-5.3029524d-05, 5.5001529d-08,-7.3580692d-09 /
      data fpp(28, 4,16,1),fpp(28, 4,16,2),fpp(28, 4,16,3)/
     x-4.9978885d-05, 5.9988800d-08,-5.0905164d-09 /
      data fpp(28, 4,17,1),fpp(28, 4,17,2),fpp(28, 4,17,3)/
     x-4.4344375d-05, 6.2087339d-08,-8.2798652d-09 /
      data fpp(28, 4,18,1),fpp(28, 4,18,2),fpp(28, 4,18,3)/
     x-3.7299715d-05, 6.5364424d-08,-3.7900228d-09 /
      data fpp(28, 4,19,1),fpp(28, 4,19,2),fpp(28, 4,19,3)/
     x-3.0480281d-05, 7.2499831d-08, 5.4399565d-09 /
      data fpp(28, 4,20,1),fpp(28, 4,20,2),fpp(28, 4,20,3)/
     x-2.5376698d-05, 7.2932814d-08, 1.8030197d-08 /
      data fpp(28, 4,21,1),fpp(28, 4,21,2),fpp(28, 4,21,3)/
     x-2.5376698d-05, 7.2932814d-08, 1.8189431d-08 /
      data fpp(28, 4,22,1),fpp(28, 4,22,2),fpp(28, 4,22,3)/
     x-3.0480281d-05, 7.2499831d-08, 4.8030197d-09 /
      data fpp(28, 4,23,1),fpp(28, 4,23,2),fpp(28, 4,23,3)/
     x-3.7299715d-05, 6.5364424d-08,-1.4015098d-09 /
      data fpp(28, 5, 1,1),fpp(28, 5, 1,2),fpp(28, 5, 1,3)/
     x-3.4125284d-05,-2.9550387d-08,-8.1915887d-09 /
      data fpp(28, 5, 2,1),fpp(28, 5, 2,2),fpp(28, 5, 2,3)/
     x-2.9357365d-05,-2.4743362d-08, 2.8831773d-09 /
      data fpp(28, 5, 3,1),fpp(28, 5, 3,2),fpp(28, 5, 3,3)/
     x-2.6065906d-05,-1.3509659d-08, 2.6658879d-08 /
      data fpp(28, 5, 4,1),fpp(28, 5, 4,2),fpp(28, 5, 4,3)/
     x-2.6065906d-05,-1.3509659d-08, 2.6581773d-08 /
      data fpp(28, 5, 5,1),fpp(28, 5, 5,2),fpp(28, 5, 5,3)/
     x-2.9357365d-05,-2.4743362d-08, 3.1916016d-09 /
      data fpp(28, 5, 6,1),fpp(28, 5, 6,2),fpp(28, 5, 6,3)/
     x-3.4125284d-05,-2.9550387d-08,-9.3481797d-09 /
      data fpp(28, 5, 7,1),fpp(28, 5, 7,2),fpp(28, 5, 7,3)/
     x-3.9341399d-05,-2.9079332d-08,-1.3798883d-08 /
      data fpp(28, 5, 8,1),fpp(28, 5, 8,2),fpp(28, 5, 8,3)/
     x-4.3240337d-05,-2.2319263d-08,-1.3456289d-08 /
      data fpp(28, 5, 9,1),fpp(28, 5, 9,2),fpp(28, 5, 9,3)/
     x-4.5677065d-05,-9.8780982d-09,-1.0375962d-08 /
      data fpp(28, 5,10,1),fpp(28, 5,10,2),fpp(28, 5,10,3)/
     x-4.7221815d-05, 5.9284369d-09,-5.0398647d-09 /
      data fpp(28, 5,11,1),fpp(28, 5,11,2),fpp(28, 5,11,3)/
     x-4.8505552d-05, 2.2344832d-08, 5.3542040d-10 /
      data fpp(28, 5,12,1),fpp(28, 5,12,2),fpp(28, 5,12,3)/
     x-4.9100668d-05, 2.9356715d-08, 8.8981831d-09 /
      data fpp(28, 5,13,1),fpp(28, 5,13,2),fpp(28, 5,13,3)/
     x-4.9423618d-05, 2.6127362d-08,-1.2815275d-10 /
      data fpp(28, 5,14,1),fpp(28, 5,14,2),fpp(28, 5,14,3)/
     x-4.8249784d-05, 1.5597414d-08, 3.6144279d-09 /
      data fpp(28, 5,15,1),fpp(28, 5,15,2),fpp(28, 5,15,3)/
     x-4.7145956d-05,-1.5955055d-10,-8.3295589d-09 /
      data fpp(28, 5,16,1),fpp(28, 5,16,2),fpp(28, 5,16,3)/
     x-4.4228165d-05,-1.3112063d-08,-6.2961922d-09 /
      data fpp(28, 5,17,1),fpp(28, 5,17,2),fpp(28, 5,17,3)/
     x-3.9975007d-05,-2.6710457d-08,-1.4485672d-08 /
      data fpp(28, 5,18,1),fpp(28, 5,18,2),fpp(28, 5,18,3)/
     x-3.4257408d-05,-3.3359582d-08,-7.7611181d-09 /
      data fpp(28, 5,19,1),fpp(28, 5,19,2),fpp(28, 5,19,3)/
     x-2.9172770d-05,-3.7903215d-08,-2.4698552d-09 /
      data fpp(28, 5,20,1),fpp(28, 5,20,2),fpp(28, 5,20,3)/
     x-2.6114808d-05,-3.5557037d-08, 2.3640539d-08 /
      data fpp(28, 5,21,1),fpp(28, 5,21,2),fpp(28, 5,21,3)/
     x-2.6114808d-05,-3.5557037d-08, 2.3313311d-08 /
      data fpp(28, 5,22,1),fpp(28, 5,22,2),fpp(28, 5,22,3)/
     x-2.9172770d-05,-3.7903215d-08,-1.1609461d-09 /
      data fpp(28, 5,23,1),fpp(28, 5,23,2),fpp(28, 5,23,3)/
     x-3.4257408d-05,-3.3359582d-08,-1.2669527d-08 /
      data fpp(28, 6, 1,1),fpp(28, 6, 1,2),fpp(28, 6, 1,3)/
     x-2.4261360d-05,-2.0904742d-08,-9.5722086d-09 /
      data fpp(28, 6, 2,1),fpp(28, 6, 2,2),fpp(28, 6, 2,3)/
     x-2.3478566d-05,-5.0402368d-09, 2.6444172d-09 /
      data fpp(28, 6, 3,1),fpp(28, 6, 3,2),fpp(28, 6, 3,3)/
     x-2.4742908d-05, 5.5102751d-09, 2.8994540d-08 /
      data fpp(28, 6, 4,1),fpp(28, 6, 4,2),fpp(28, 6, 4,3)/
     x-2.4742908d-05, 5.5102751d-09, 2.8694172d-08 /
      data fpp(28, 6, 5,1),fpp(28, 6, 5,2),fpp(28, 6, 5,3)/
     x-2.3478566d-05,-5.0402368d-09, 3.8458895d-09 /
      data fpp(28, 6, 6,1),fpp(28, 6, 6,2),fpp(28, 6, 6,3)/
     x-2.4261360d-05,-2.0904742d-08,-1.4077730d-08 /
      data fpp(28, 6, 7,1),fpp(28, 6, 7,2),fpp(28, 6, 7,3)/
     x-2.5932148d-05,-2.9631771d-08,-1.3534970d-08 /
      data fpp(28, 6, 8,1),fpp(28, 6, 8,2),fpp(28, 6, 8,3)/
     x-2.8608511d-05,-3.3262130d-08,-1.5782390d-08 /
      data fpp(28, 6, 9,1),fpp(28, 6, 9,2),fpp(28, 6, 9,3)/
     x-3.1861949d-05,-3.0248747d-08,-7.3354707d-09 /
      data fpp(28, 6,10,1),fpp(28, 6,10,2),fpp(28, 6,10,3)/
     x-3.5477854d-05,-2.5011280d-08,-2.8757273d-09 /
      data fpp(28, 6,11,1),fpp(28, 6,11,2),fpp(28, 6,11,3)/
     x-3.8685726d-05,-2.2987930d-08, 8.3838002d-10 /
      data fpp(28, 6,12,1),fpp(28, 6,12,2),fpp(28, 6,12,3)/
     x-4.0311110d-05,-1.9186915d-08, 5.5222073d-09 /
      data fpp(28, 6,13,1),fpp(28, 6,13,2),fpp(28, 6,13,3)/
     x-4.0049203d-05,-1.7557783d-08, 1.0727910d-09 /
      data fpp(28, 6,14,1),fpp(28, 6,14,2),fpp(28, 6,14,3)/
     x-3.7278989d-05,-1.8868698d-08, 2.1866289d-09 /
      data fpp(28, 6,15,1),fpp(28, 6,15,2),fpp(28, 6,15,3)/
     x-3.4209339d-05,-2.4363327d-08,-3.8193064d-09 /
      data fpp(28, 6,16,1),fpp(28, 6,16,2),fpp(28, 6,16,3)/
     x-3.1330793d-05,-3.1540550d-08,-1.0909403d-08 /
      data fpp(28, 6,17,1),fpp(28, 6,17,2),fpp(28, 6,17,3)/
     x-2.8099172d-05,-3.3245510d-08,-1.2543080d-08 /
      data fpp(28, 6,18,1),fpp(28, 6,18,2),fpp(28, 6,18,3)/
     x-2.5899109d-05,-3.3926098d-08,-1.0918275d-08 /
      data fpp(28, 6,19,1),fpp(28, 6,19,2),fpp(28, 6,19,3)/
     x-2.4918146d-05,-2.8886969d-08,-3.7838189d-09 /
      data fpp(28, 6,20,1),fpp(28, 6,20,2),fpp(28, 6,20,3)/
     x-2.5255671d-05,-2.0704667d-08, 2.6053551d-08 /
      data fpp(28, 6,21,1),fpp(28, 6,21,2),fpp(28, 6,21,3)/
     x-2.5255671d-05,-2.0704667d-08, 2.5731257d-08 /
      data fpp(28, 6,22,1),fpp(28, 6,22,2),fpp(28, 6,22,3)/
     x-2.4918146d-05,-2.8886969d-08,-2.4946449d-09 /
      data fpp(28, 6,23,1),fpp(28, 6,23,2),fpp(28, 6,23,3)/
     x-2.5899109d-05,-3.3926098d-08,-1.5752678d-08 /
      data fpp(28, 7, 1,1),fpp(28, 7, 1,2),fpp(28, 7, 1,3)/
     x-1.8203628d-05,-4.2830646d-08,-1.0656588d-08 /
      data fpp(28, 7, 2,1),fpp(28, 7, 2,2),fpp(28, 7, 2,3)/
     x-2.0178081d-05,-5.1095691d-08, 8.1317631d-10 /
      data fpp(28, 7, 3,1),fpp(28, 7, 3,2),fpp(28, 7, 3,3)/
     x-2.2351537d-05,-5.6531441d-08, 2.5403883d-08 /
      data fpp(28, 7, 4,1),fpp(28, 7, 4,2),fpp(28, 7, 4,3)/
     x-2.2351537d-05,-5.6531441d-08, 2.5381763d-08 /
      data fpp(28, 7, 5,1),fpp(28, 7, 5,2),fpp(28, 7, 5,3)/
     x-2.0178081d-05,-5.1095691d-08, 9.0165538d-10 /
      data fpp(28, 7, 6,1),fpp(28, 7, 6,2),fpp(28, 7, 6,3)/
     x-1.8203628d-05,-4.2830646d-08,-1.0988385d-08 /
      data fpp(28, 7, 7,1),fpp(28, 7, 7,2),fpp(28, 7, 7,3)/
     x-1.8037616d-05,-3.8393583d-08,-1.0948117d-08 /
      data fpp(28, 7, 8,1),fpp(28, 7, 8,2),fpp(28, 7, 8,3)/
     x-1.9741096d-05,-3.6632215d-08,-1.1219148d-08 /
      data fpp(28, 7, 9,1),fpp(28, 7, 9,2),fpp(28, 7, 9,3)/
     x-2.1993591d-05,-3.7126914d-08,-4.1752905d-09 /
      data fpp(28, 7,10,1),fpp(28, 7,10,2),fpp(28, 7,10,3)/
     x-2.4613621d-05,-4.3883317d-08,-2.0796899d-09 /
      data fpp(28, 7,11,1),fpp(28, 7,11,2),fpp(28, 7,11,3)/
     x-2.6672297d-05,-4.4393113d-08, 4.9405013d-10 /
      data fpp(28, 7,12,1),fpp(28, 7,12,2),fpp(28, 7,12,3)/
     x-2.7720685d-05,-4.8609053d-08, 1.0348938d-10 /
      data fpp(28, 7,13,1),fpp(28, 7,13,2),fpp(28, 7,13,3)/
     x-2.7625050d-05,-4.5896229d-08,-9.0800764d-10 /
      data fpp(28, 7,14,1),fpp(28, 7,14,2),fpp(28, 7,14,3)/
     x-2.6032022d-05,-4.2122621d-08,-2.4714588d-09 /
      data fpp(28, 7,15,1),fpp(28, 7,15,2),fpp(28, 7,15,3)/
     x-2.3729511d-05,-3.4387142d-08,-1.2061571d-09 /
      data fpp(28, 7,16,1),fpp(28, 7,16,2),fpp(28, 7,16,3)/
     x-2.1662370d-05,-2.8725738d-08,-1.0703913d-08 /
      data fpp(28, 7,17,1),fpp(28, 7,17,2),fpp(28, 7,17,3)/
     x-1.9836052d-05,-2.6307503d-08,-9.9781923d-09 /
      data fpp(28, 7,18,1),fpp(28, 7,18,2),fpp(28, 7,18,3)/
     x-1.8949840d-05,-2.2936027d-08,-9.3833181d-09 /
      data fpp(28, 7,19,1),fpp(28, 7,19,2),fpp(28, 7,19,3)/
     x-1.9801520d-05,-2.0548907d-08,-4.8853535d-10 /
      data fpp(28, 7,20,1),fpp(28, 7,20,2),fpp(28, 7,20,3)/
     x-2.1535230d-05,-1.9624295d-08, 2.3337460d-08 /
      data fpp(28, 7,21,1),fpp(28, 7,21,2),fpp(28, 7,21,3)/
     x-2.1535230d-05,-1.9624295d-08, 2.3231889d-08 /
      data fpp(28, 7,22,1),fpp(28, 7,22,2),fpp(28, 7,22,3)/
     x-1.9801520d-05,-2.0548907d-08,-6.6254050d-11 /
      data fpp(28, 7,23,1),fpp(28, 7,23,2),fpp(28, 7,23,3)/
     x-1.8949840d-05,-2.2936027d-08,-1.0966873d-08 /
      data fpp(28, 8, 1,1),fpp(28, 8, 1,2),fpp(28, 8, 1,3)/
     x-1.6377935d-05,-7.1772675d-08,-9.7319182d-09 /
      data fpp(28, 8, 2,1),fpp(28, 8, 2,2),fpp(28, 8, 2,3)/
     x-1.7921622d-05,-8.4577000d-08, 9.6383639d-10 /
      data fpp(28, 8, 3,1),fpp(28, 8, 3,2),fpp(28, 8, 3,3)/
     x-1.8925076d-05,-9.1384511d-08, 2.3876573d-08 /
      data fpp(28, 8, 4,1),fpp(28, 8, 4,2),fpp(28, 8, 4,3)/
     x-1.8925076d-05,-9.1384511d-08, 2.3888364d-08 /
      data fpp(28, 8, 5,1),fpp(28, 8, 5,2),fpp(28, 8, 5,3)/
     x-1.7921622d-05,-8.4577000d-08, 9.1667144d-10 /
      data fpp(28, 8, 6,1),fpp(28, 8, 6,2),fpp(28, 8, 6,3)/
     x-1.6377935d-05,-7.1772675d-08,-9.5550496d-09 /
      data fpp(28, 8, 7,1),fpp(28, 8, 7,2),fpp(28, 8, 7,3)/
     x-1.5525324d-05,-5.6793898d-08,-1.0696473d-08 /
      data fpp(28, 8, 8,1),fpp(28, 8, 8,2),fpp(28, 8, 8,3)/
     x-1.5621397d-05,-4.8209010d-08,-7.6590588d-09 /
      data fpp(28, 8, 9,1),fpp(28, 8, 9,2),fpp(28, 8, 9,3)/
     x-1.6285509d-05,-4.9243598d-08,-6.6672921d-09 /
      data fpp(28, 8,10,1),fpp(28, 8,10,2),fpp(28, 8,10,3)/
     x-1.6449135d-05,-4.5455451d-08, 4.3282270d-09 /
      data fpp(28, 8,11,1),fpp(28, 8,11,2),fpp(28, 8,11,3)/
     x-1.7281514d-05,-5.1439620d-08,-4.6456161d-09 /
      data fpp(28, 8,12,1),fpp(28, 8,12,2),fpp(28, 8,12,3)/
     x-1.7098114d-05,-5.0376872d-08, 2.2542373d-09 /
      data fpp(28, 8,13,1),fpp(28, 8,13,2),fpp(28, 8,13,3)/
     x-1.7495799d-05,-5.0857303d-08,-4.3713332d-09 /
      data fpp(28, 8,14,1),fpp(28, 8,14,2),fpp(28, 8,14,3)/
     x-1.7235561d-05,-4.6640819d-08,-2.7689044d-09 /
      data fpp(28, 8,15,1),fpp(28, 8,15,2),fpp(28, 8,15,3)/
     x-1.7127342d-05,-4.2088104d-08,-2.5530492d-09 /
      data fpp(28, 8,16,1),fpp(28, 8,16,2),fpp(28, 8,16,3)/
     x-1.6689976d-05,-3.9556496d-08,-1.1018899d-08 /
      data fpp(28, 8,17,1),fpp(28, 8,17,2),fpp(28, 8,17,3)/
     x-1.6248767d-05,-3.5524479d-08,-7.3713561d-09 /
      data fpp(28, 8,18,1),fpp(28, 8,18,2),fpp(28, 8,18,3)/
     x-1.5727961d-05,-3.6329793d-08,-7.4956769d-09 /
      data fpp(28, 8,19,1),fpp(28, 8,19,2),fpp(28, 8,19,3)/
     x-1.6255365d-05,-3.8917402d-08, 1.3540637d-09 /
      data fpp(28, 8,20,1),fpp(28, 8,20,2),fpp(28, 8,20,3)/
     x-1.6771405d-05,-4.4798154d-08, 2.0079422d-08 /
      data fpp(28, 8,21,1),fpp(28, 8,21,2),fpp(28, 8,21,3)/
     x-1.6771405d-05,-4.4798154d-08, 2.0084702d-08 /
      data fpp(28, 8,22,1),fpp(28, 8,22,2),fpp(28, 8,22,3)/
     x-1.6255365d-05,-3.8917402d-08, 1.3329422d-09 /
      data fpp(28, 8,23,1),fpp(28, 8,23,2),fpp(28, 8,23,3)/
     x-1.5727961d-05,-3.6329793d-08,-7.4164711d-09 /
      data fpp(28, 9, 1,1),fpp(28, 9, 1,2),fpp(28, 9, 1,3)/
     x-1.5383312d-05,-6.0078654d-08,-4.7955199d-09 /
      data fpp(28, 9, 2,1),fpp(28, 9, 2,2),fpp(28, 9, 2,3)/
     x-1.7516153d-05,-6.0596311d-08, 5.0910399d-09 /
      data fpp(28, 9, 3,1),fpp(28, 9, 3,2),fpp(28, 9, 3,3)/
     x-1.9320489d-05,-6.3930513d-08, 2.6431360d-08 /
      data fpp(28, 9, 4,1),fpp(28, 9, 4,2),fpp(28, 9, 4,3)/
     x-1.9320489d-05,-6.3930513d-08, 2.6160399d-08 /
      data fpp(28, 9, 5,1),fpp(28, 9, 5,2),fpp(28, 9, 5,3)/
     x-1.7516153d-05,-6.0596311d-08, 6.1748853d-09 /
      data fpp(28, 9, 6,1),fpp(28, 9, 6,2),fpp(28, 9, 6,3)/
     x-1.5383312d-05,-6.0078654d-08,-8.8599402d-09 /
      data fpp(28, 9, 7,1),fpp(28, 9, 7,2),fpp(28, 9, 7,3)/
     x-1.4179184d-05,-6.4430824d-08,-1.2735124d-08 /
      data fpp(28, 9, 8,1),fpp(28, 9, 8,2),fpp(28, 9, 8,3)/
     x-1.3324325d-05,-5.8531747d-08,-1.2199562d-08 /
      data fpp(28, 9, 9,1),fpp(28, 9, 9,2),fpp(28, 9, 9,3)/
     x-1.2841495d-05,-4.1898696d-08,-4.4666277d-09 /
      data fpp(28, 9,10,1),fpp(28, 9,10,2),fpp(28, 9,10,3)/
     x-1.2405069d-05,-3.8294877d-08, 6.6072845d-11 /
      data fpp(28, 9,11,1),fpp(28, 9,11,2),fpp(28, 9,11,3)/
     x-1.2324797d-05,-3.1848409d-08,-1.7976637d-09 /
      data fpp(28, 9,12,1),fpp(28, 9,12,2),fpp(28, 9,12,3)/
     x-1.2076167d-05,-3.1883458d-08, 1.1245818d-09 /
      data fpp(28, 9,13,1),fpp(28, 9,13,2),fpp(28, 9,13,3)/
     x-1.2346478d-05,-3.2674561d-08,-2.7006635d-09 /
      data fpp(28, 9,14,1),fpp(28, 9,14,2),fpp(28, 9,14,3)/
     x-1.2305840d-05,-3.5314105d-08,-2.3219279d-09 /
      data fpp(28, 9,15,1),fpp(28, 9,15,2),fpp(28, 9,15,3)/
     x-1.2964226d-05,-3.7260440d-08,-6.0116251d-09 /
      data fpp(28, 9,16,1),fpp(28, 9,16,2),fpp(28, 9,16,3)/
     x-1.3148378d-05,-3.5048276d-08,-9.6315718d-09 /
      data fpp(28, 9,17,1),fpp(28, 9,17,2),fpp(28, 9,17,3)/
     x-1.3285698d-05,-3.5594582d-08,-9.4620878d-09 /
      data fpp(28, 9,18,1),fpp(28, 9,18,2),fpp(28, 9,18,3)/
     x-1.3547139d-05,-3.5744800d-08,-6.5200772d-09 /
      data fpp(28, 9,19,1),fpp(28, 9,19,2),fpp(28, 9,19,3)/
     x-1.3963401d-05,-3.9781486d-08,-4.5760351d-10 /
      data fpp(28, 9,20,1),fpp(28, 9,20,2),fpp(28, 9,20,3)/
     x-1.3423685d-05,-4.1183090d-08, 2.0350491d-08 /
      data fpp(28, 9,21,1),fpp(28, 9,21,2),fpp(28, 9,21,3)/
     x-1.3423685d-05,-4.1183090d-08, 2.0177328d-08 /
      data fpp(28, 9,22,1),fpp(28, 9,22,2),fpp(28, 9,22,3)/
     x-1.3963401d-05,-3.9781486d-08, 2.3504912d-10 /
      data fpp(28, 9,23,1),fpp(28, 9,23,2),fpp(28, 9,23,3)/
     x-1.3547139d-05,-3.5744800d-08,-9.1175246d-09 /
      data fpp(28,10, 1,1),fpp(28,10, 1,2),fpp(28,10, 1,3)/
     x-1.5639994d-05,-2.9912710d-08,-2.9444048d-09 /
      data fpp(28,10, 2,1),fpp(28,10, 2,2),fpp(28,10, 2,3)/
     x-1.8031208d-05,-2.7037756d-08, 7.8888096d-09 /
      data fpp(28,10, 3,1),fpp(28,10, 3,2),fpp(28,10, 3,3)/
     x-2.0369455d-05,-2.4893435d-08, 3.1389166d-08 /
      data fpp(28,10, 4,1),fpp(28,10, 4,2),fpp(28,10, 4,3)/
     x-2.0369455d-05,-2.4893435d-08, 3.0888096d-08 /
      data fpp(28,10, 5,1),fpp(28,10, 5,2),fpp(28,10, 5,3)/
     x-1.8031208d-05,-2.7037756d-08, 9.8930886d-09 /
      data fpp(28,10, 6,1),fpp(28,10, 6,2),fpp(28,10, 6,3)/
     x-1.5639994d-05,-2.9912710d-08,-1.0460451d-08 /
      data fpp(28,10, 7,1),fpp(28,10, 7,2),fpp(28,10, 7,3)/
     x-1.2890764d-05,-2.1482805d-08,-1.0051286d-08 /
      data fpp(28,10, 8,1),fpp(28,10, 8,2),fpp(28,10, 8,3)/
     x-1.1699620d-05,-2.3664003d-08,-9.3344065d-09 /
      data fpp(28,10, 9,1),fpp(28,10, 9,2),fpp(28,10, 9,3)/
     x-1.1079856d-05,-3.5161619d-08,-1.2611088d-08 /
      data fpp(28,10,10,1),fpp(28,10,10,2),fpp(28,10,10,3)/
     x-1.1363109d-05,-2.9365039d-08,-2.2124063d-10 /
      data fpp(28,10,11,1),fpp(28,10,11,2),fpp(28,10,11,3)/
     x-1.1444871d-05,-2.5166745d-08,-4.5039493d-09 /
      data fpp(28,10,12,1),fpp(28,10,12,2),fpp(28,10,12,3)/
     x-1.1405675d-05,-2.0089296d-08, 2.3703771d-10 /
      data fpp(28,10,13,1),fpp(28,10,13,2),fpp(28,10,13,3)/
     x-1.1176627d-05,-1.6444453d-08,-2.4442016d-09 /
      data fpp(28,10,14,1),fpp(28,10,14,2),fpp(28,10,14,3)/
     x-1.0618896d-05,-1.6102762d-08,-2.4602315d-09 /
      data fpp(28,10,15,1),fpp(28,10,15,2),fpp(28,10,15,3)/
     x-1.0558510d-05,-1.8870136d-08,-5.7148725d-09 /
      data fpp(28,10,16,1),fpp(28,10,16,2),fpp(28,10,16,3)/
     x-1.1021342d-05,-2.4250401d-08,-1.0680279d-08 /
      data fpp(28,10,17,1),fpp(28,10,17,2),fpp(28,10,17,3)/
     x-1.0970916d-05,-2.6097192d-08,-1.1564013d-08 /
      data fpp(28,10,18,1),fpp(28,10,18,2),fpp(28,10,18,3)/
     x-1.0920787d-05,-3.0691006d-08,-9.0636679d-09 /
      data fpp(28,10,19,1),fpp(28,10,19,2),fpp(28,10,19,3)/
     x-1.0918288d-05,-2.9956653d-08,-1.8131485d-10 /
      data fpp(28,10,20,1),fpp(28,10,20,2),fpp(28,10,20,3)/
     x-1.0964003d-05,-3.0469487d-08, 2.1788927d-08 /
      data fpp(28,10,21,1),fpp(28,10,21,2),fpp(28,10,21,3)/
     x-1.0964003d-05,-3.0469487d-08, 2.1723875d-08 /
      data fpp(28,10,22,1),fpp(28,10,22,2),fpp(28,10,22,3)/
     x-1.0918288d-05,-2.9956653d-08, 7.8892733d-11 /
      data fpp(28,10,23,1),fpp(28,10,23,2),fpp(28,10,23,3)/
     x-1.0920787d-05,-3.0691006d-08,-1.0039446d-08 /
      data fpp(28,11, 1,1),fpp(28,11, 1,2),fpp(28,11, 1,3)/
     x-1.6998039d-05,-2.7050570d-10,-1.8921429d-09 /
      data fpp(28,11, 2,1),fpp(28,11, 2,2),fpp(28,11, 2,3)/
     x-1.9765018d-05, 6.7473366d-09, 9.7842859d-09 /
      data fpp(28,11, 3,1),fpp(28,11, 3,2),fpp(28,11, 3,3)/
     x-2.1367553d-05, 1.3504254d-08, 3.4754999d-08 /
      data fpp(28,11, 4,1),fpp(28,11, 4,2),fpp(28,11, 4,3)/
     x-2.1367553d-05, 1.3504254d-08, 3.4842859d-08 /
      data fpp(28,11, 5,1),fpp(28,11, 5,2),fpp(28,11, 5,3)/
     x-1.9765018d-05, 6.7473366d-09, 9.4328490d-09 /
      data fpp(28,11, 6,1),fpp(28,11, 6,2),fpp(28,11, 6,3)/
     x-1.6998039d-05,-2.7050570d-10,-5.7425454d-10 /
      data fpp(28,11, 7,1),fpp(28,11, 7,2),fpp(28,11, 7,3)/
     x-1.4286048d-05,-1.1637955d-08,-1.3135831d-08 /
      data fpp(28,11, 8,1),fpp(28,11, 8,2),fpp(28,11, 8,3)/
     x-1.1897175d-05,-8.8122413d-09,-1.2882422d-08 /
      data fpp(28,11, 9,1),fpp(28,11, 9,2),fpp(28,11, 9,3)/
     x-1.0665943d-05, 2.5451710d-09,-7.3344800d-09 /
      data fpp(28,11,10,1),fpp(28,11,10,2),fpp(28,11,10,3)/
     x-1.0749867d-05,-2.4496716d-10,-5.7796575d-09 /
      data fpp(28,11,11,1),fpp(28,11,11,2),fpp(28,11,11,3)/
     x-1.0770643d-05,-5.4846120d-09,-5.5468899d-09 /
      data fpp(28,11,12,1),fpp(28,11,12,2),fpp(28,11,12,3)/
     x-1.0747845d-05,-7.7593586d-09,-2.0327829d-09 /
      data fpp(28,11,13,1),fpp(28,11,13,2),fpp(28,11,13,3)/
     x-1.1014233d-05,-9.5476281d-09,-4.3219785d-09 /
      data fpp(28,11,14,1),fpp(28,11,14,2),fpp(28,11,14,3)/
     x-1.0816643d-05,-8.2748458d-09,-4.6793030d-09 /
      data fpp(28,11,15,1),fpp(28,11,15,2),fpp(28,11,15,3)/
     x-1.0323910d-05,-7.2590159d-09,-6.9608094d-09 /
      data fpp(28,11,16,1),fpp(28,11,16,2),fpp(28,11,16,3)/
     x-9.6750318d-06,-5.9501212d-09,-9.4774593d-09 /
      data fpp(28,11,17,1),fpp(28,11,17,2),fpp(28,11,17,3)/
     x-9.3026560d-06,-1.0016648d-08,-1.5129354d-08 /
      data fpp(28,11,18,1),fpp(28,11,18,2),fpp(28,11,18,3)/
     x-8.5056895d-06,-3.4911762d-09,-8.0051266d-09 /
      data fpp(28,11,19,1),fpp(28,11,19,2),fpp(28,11,19,3)/
     x-8.1326415d-06,-2.3919013d-09,-8.5014005d-10 /
      data fpp(28,11,20,1),fpp(28,11,20,2),fpp(28,11,20,3)/
     x-8.2439999d-06, 1.0610362d-09, 2.3405687d-08 /
      data fpp(28,11,21,1),fpp(28,11,21,2),fpp(28,11,21,3)/
     x-8.2439999d-06, 1.0610362d-09, 2.3208010d-08 /
      data fpp(28,11,22,1),fpp(28,11,22,2),fpp(28,11,22,3)/
     x-8.1326415d-06,-2.3919013d-09,-5.9431320d-11 /
      data fpp(28,11,23,1),fpp(28,11,23,2),fpp(28,11,23,3)/
     x-8.5056895d-06,-3.4911762d-09,-1.0970284d-08 /
      data fpp(28,12, 1,1),fpp(28,12, 1,2),fpp(28,12, 1,3)/
     x-1.8849436d-05, 2.4994733d-08, 1.9563057d-09 /
      data fpp(28,12, 2,1),fpp(28,12, 2,2),fpp(28,12, 2,3)/
     x-2.1600980d-05, 3.0048410d-08, 1.2087389d-08 /
      data fpp(28,12, 3,1),fpp(28,12, 3,2),fpp(28,12, 3,3)/
     x-2.2617907d-05, 3.6876418d-08, 3.3694140d-08 /
      data fpp(28,12, 4,1),fpp(28,12, 4,2),fpp(28,12, 4,3)/
     x-2.2617907d-05, 3.6876418d-08, 3.3873886d-08 /
      data fpp(28,12, 5,1),fpp(28,12, 5,2),fpp(28,12, 5,3)/
     x-2.1600980d-05, 3.0048410d-08, 1.1368402d-08 /
      data fpp(28,12, 6,1),fpp(28,12, 6,2),fpp(28,12, 6,3)/
     x-1.8849436d-05, 2.4994733d-08, 4.6525062d-09 /
      data fpp(28,12, 7,1),fpp(28,12, 7,2),fpp(28,12, 7,3)/
     x-1.5980569d-05, 2.0034627d-08,-5.9784266d-09 /
      data fpp(28,12, 8,1),fpp(28,12, 8,2),fpp(28,12, 8,3)/
     x-1.5666556d-05, 1.0912968d-08,-1.0738800d-08 /
      data fpp(28,12, 9,1),fpp(28,12, 9,2),fpp(28,12, 9,3)/
     x-1.2101225d-05, 9.8093467d-10,-1.1066374d-08 /
      data fpp(28,12,10,1),fpp(28,12,10,2),fpp(28,12,10,3)/
     x-1.1120501d-05, 3.4490750d-10,-1.0995703d-08 /
      data fpp(28,12,11,1),fpp(28,12,11,2),fpp(28,12,11,3)/
     x-1.0685012d-05, 5.1051928d-09,-4.9508145d-09 /
      data fpp(28,12,12,1),fpp(28,12,12,2),fpp(28,12,12,3)/
     x-1.0718639d-05, 3.1267304d-09,-5.2010394d-09 /
      data fpp(28,12,13,1),fpp(28,12,13,2),fpp(28,12,13,3)/
     x-1.0328265d-05, 6.3496525d-10,-4.2450280d-09 /
      data fpp(28,12,14,1),fpp(28,12,14,2),fpp(28,12,14,3)/
     x-1.0284861d-05,-4.7978545d-09,-7.8188486d-09 /
      data fpp(28,12,15,1),fpp(28,12,15,2),fpp(28,12,15,3)/
     x-9.6508818d-06,-6.0938004d-09,-6.4795776d-09 /
      data fpp(28,12,16,1),fpp(28,12,16,2),fpp(28,12,16,3)/
     x-9.4725684d-06,-5.9491146d-09,-1.4262841d-08 /
      data fpp(28,12,17,1),fpp(28,12,17,2),fpp(28,12,17,3)/
     x-8.6779061d-06, 1.6378486d-10,-8.4690578d-09 /
      data fpp(28,12,18,1),fpp(28,12,18,2),fpp(28,12,18,3)/
     x-8.4989352d-06,-3.3442892d-09,-1.1860928d-08 /
      data fpp(28,12,19,1),fpp(28,12,19,2),fpp(28,12,19,3)/
     x-8.1907216d-06, 3.5242582d-09, 1.9127681d-09 /
      data fpp(28,12,20,1),fpp(28,12,20,2),fpp(28,12,20,3)/
     x-8.1919145d-06, 8.2253417d-09, 2.2209855d-08 /
      data fpp(28,12,21,1),fpp(28,12,21,2),fpp(28,12,21,3)/
     x-8.1919145d-06, 8.2253417d-09, 2.2414051d-08 /
      data fpp(28,12,22,1),fpp(28,12,22,2),fpp(28,12,22,3)/
     x-8.1907216d-06, 3.5242582d-09, 1.0959855d-09 /
      data fpp(28,12,23,1),fpp(28,12,23,2),fpp(28,12,23,3)/
     x-8.4989352d-06,-3.3442892d-09,-8.7979928d-09 /
      data fpp(28,13, 1,1),fpp(28,13, 1,2),fpp(28,13, 1,3)/
     x-1.9870858d-05, 3.2291574d-08, 8.1290673d-09 /
      data fpp(28,13, 2,1),fpp(28,13, 2,2),fpp(28,13, 2,3)/
     x-2.2211715d-05, 3.5059024d-08, 1.4741865d-08 /
      data fpp(28,13, 3,1),fpp(28,13, 3,2),fpp(28,13, 3,3)/
     x-2.3469791d-05, 3.0990075d-08, 2.8903471d-08 /
      data fpp(28,13, 4,1),fpp(28,13, 4,2),fpp(28,13, 4,3)/
     x-2.3469791d-05, 3.0990075d-08, 2.8918655d-08 /
      data fpp(28,13, 5,1),fpp(28,13, 5,2),fpp(28,13, 5,3)/
     x-2.2211715d-05, 3.5059024d-08, 1.4681131d-08 /
      data fpp(28,13, 6,1),fpp(28,13, 6,2),fpp(28,13, 6,3)/
     x-1.9870858d-05, 3.2291574d-08, 8.3568217d-09 /
      data fpp(28,13, 7,1),fpp(28,13, 7,2),fpp(28,13, 7,3)/
     x-1.7571243d-05, 2.7499448d-08,-1.0841774d-10 /
      data fpp(28,13, 8,1),fpp(28,13, 8,2),fpp(28,13, 8,3)/
     x-1.5599491d-05, 1.9160369d-08,-7.9231507d-09 /
      data fpp(28,13, 9,1),fpp(28,13, 9,2),fpp(28,13, 9,3)/
     x-1.3583482d-05, 1.1531090d-08,-1.0198979d-08 /
      data fpp(28,13,10,1),fpp(28,13,10,2),fpp(28,13,10,3)/
     x-1.1994871d-05, 4.8653372d-09,-1.1280932d-08 /
      data fpp(28,13,11,1),fpp(28,13,11,2),fpp(28,13,11,3)/
     x-1.0590422d-05,-2.9361594d-09,-1.0677293d-08 /
      data fpp(28,13,12,1),fpp(28,13,12,2),fpp(28,13,12,3)/
     x-1.0302197d-05,-4.7475630d-09,-6.0098966d-09 /
      data fpp(28,13,13,1),fpp(28,13,13,2),fpp(28,13,13,3)/
     x-1.0136123d-05,-4.9922329d-09,-7.2831208d-09 /
      data fpp(28,13,14,1),fpp(28,13,14,2),fpp(28,13,14,3)/
     x-9.6026919d-06,-2.5337363d-09,-6.8576200d-09 /
      data fpp(28,13,15,1),fpp(28,13,15,2),fpp(28,13,15,3)/
     x-9.4789587d-06,-4.3657826d-09,-7.2863990d-09 /
      data fpp(28,13,16,1),fpp(28,13,16,2),fpp(28,13,16,3)/
     x-9.5339102d-06,-6.2534205d-09,-1.1996784d-08 /
      data fpp(28,13,17,1),fpp(28,13,17,2),fpp(28,13,17,3)/
     x-9.4410442d-06,-8.6384913d-09,-1.0726465d-08 /
      data fpp(28,13,18,1),fpp(28,13,18,2),fpp(28,13,18,3)/
     x-9.1802621d-06,-1.1316671d-09,-5.0973564d-09 /
      data fpp(28,13,19,1),fpp(28,13,19,2),fpp(28,13,19,3)/
     x-9.1204735d-06, 2.9486854d-10, 1.1158905d-09 /
      data fpp(28,13,20,1),fpp(28,13,20,2),fpp(28,13,20,3)/
     x-9.3328795d-06, 2.0375968d-09, 1.8633794d-08 /
      data fpp(28,13,21,1),fpp(28,13,21,2),fpp(28,13,21,3)/
     x-9.3328795d-06, 2.0375968d-09, 1.8540672d-08 /
      data fpp(28,13,22,1),fpp(28,13,22,2),fpp(28,13,22,3)/
     x-9.1204735d-06, 2.9486854d-10, 1.4883794d-09 /
      data fpp(28,13,23,1),fpp(28,13,23,2),fpp(28,13,23,3)/
     x-9.1802621d-06,-1.1316671d-09,-6.4941897d-09 /
      data fpp(28,14, 1,1),fpp(28,14, 1,2),fpp(28,14, 1,3)/
     x-2.0725453d-05, 2.5838971d-08, 7.0438660d-09 /
      data fpp(28,14, 2,1),fpp(28,14, 2,2),fpp(28,14, 2,3)/
     x-2.2682792d-05, 2.7715495d-08, 1.2912268d-08 /
      data fpp(28,14, 3,1),fpp(28,14, 3,2),fpp(28,14, 3,3)/
     x-2.2875758d-05, 3.1163281d-08, 2.5307062d-08 /
      data fpp(28,14, 4,1),fpp(28,14, 4,2),fpp(28,14, 4,3)/
     x-2.2875758d-05, 3.1163281d-08, 2.5622680d-08 /
      data fpp(28,14, 5,1),fpp(28,14, 5,2),fpp(28,14, 5,3)/
     x-2.2682792d-05, 2.7715495d-08, 1.1649796d-08 /
      data fpp(28,14, 6,1),fpp(28,14, 6,2),fpp(28,14, 6,3)/
     x-2.0725453d-05, 2.5838971d-08, 1.1778136d-08 /
      data fpp(28,14, 7,1),fpp(28,14, 7,2),fpp(28,14, 7,3)/
     x-1.8906952d-05, 1.9967579d-08, 1.2376599d-09 /
      data fpp(28,14, 8,1),fpp(28,14, 8,2),fpp(28,14, 8,3)/
     x-1.6659006d-05, 1.4445556d-08,-4.7287755d-09 /
      data fpp(28,14, 9,1),fpp(28,14, 9,2),fpp(28,14, 9,3)/
     x-1.4236668d-05, 6.8947042d-09,-6.3225578d-09 /
      data fpp(28,14,10,1),fpp(28,14,10,2),fpp(28,14,10,3)/
     x-1.4105723d-05,-1.8062561d-09,-1.1980993d-08 /
      data fpp(28,14,11,1),fpp(28,14,11,2),fpp(28,14,11,3)/
     x-1.1271315d-05,-5.3605554d-09,-1.1753469d-08 /
      data fpp(28,14,12,1),fpp(28,14,12,2),fpp(28,14,12,3)/
     x-9.5817725d-06,-8.1364783d-09,-7.0051322d-09 /
      data fpp(28,14,13,1),fpp(28,14,13,2),fpp(28,14,13,3)/
     x-9.5488532d-06,-1.0666034d-08,-8.2260024d-09 /
      data fpp(28,14,14,1),fpp(28,14,14,2),fpp(28,14,14,3)/
     x-9.6966305d-06,-1.5067200d-08,-8.0908580d-09 /
      data fpp(28,14,15,1),fpp(28,14,15,2),fpp(28,14,15,3)/
     x-9.5831851d-06,-1.2443069d-08,-7.4105655d-09 /
      data fpp(28,14,16,1),fpp(28,14,16,2),fpp(28,14,16,3)/
     x-9.6079936d-06,-1.1037203d-08,-1.0266880d-08 /
      data fpp(28,14,17,1),fpp(28,14,17,2),fpp(28,14,17,3)/
     x-9.4783072d-06,-7.6098195d-09,-5.5219147d-09 /
      data fpp(28,14,18,1),fpp(28,14,18,2),fpp(28,14,18,3)/
     x-9.6372968d-06,-1.0129043d-08,-3.6454612d-09 /
      data fpp(28,14,19,1),fpp(28,14,19,2),fpp(28,14,19,3)/
     x-9.9168656d-06,-1.0703732d-08, 2.1037596d-09 /
      data fpp(28,14,20,1),fpp(28,14,20,2),fpp(28,14,20,3)/
     x-1.0146218d-05,-1.0375729d-08, 1.3230423d-08 /
      data fpp(28,14,21,1),fpp(28,14,21,2),fpp(28,14,21,3)/
     x-1.0146218d-05,-1.0375729d-08, 1.3256852d-08 /
      data fpp(28,14,22,1),fpp(28,14,22,2),fpp(28,14,22,3)/
     x-9.9168656d-06,-1.0703732d-08, 1.9980423d-09 /
      data fpp(28,14,23,1),fpp(28,14,23,2),fpp(28,14,23,3)/
     x-9.6372968d-06,-1.0129043d-08,-3.2490211d-09 /
      data fpp(28,15, 1,1),fpp(28,15, 1,2),fpp(28,15, 1,3)/
     x-2.0602586d-05, 2.0352541d-08, 6.8990244d-09 /
      data fpp(28,15, 2,1),fpp(28,15, 2,2),fpp(28,15, 2,3)/
     x-2.1982172d-05, 2.2078997d-08, 1.1201951d-08 /
      data fpp(28,15, 3,1),fpp(28,15, 3,2),fpp(28,15, 3,3)/
     x-2.2023608d-05, 2.4356800d-08, 2.0293171d-08 /
      data fpp(28,15, 4,1),fpp(28,15, 4,2),fpp(28,15, 4,3)/
     x-2.2023608d-05, 2.4356800d-08, 2.0519512d-08 /
      data fpp(28,15, 5,1),fpp(28,15, 5,2),fpp(28,15, 5,3)/
     x-2.1982172d-05, 2.2078997d-08, 1.0296586d-08 /
      data fpp(28,15, 6,1),fpp(28,15, 6,2),fpp(28,15, 6,3)/
     x-2.0602586d-05, 2.0352541d-08, 1.0294143d-08 /
      data fpp(28,15, 7,1),fpp(28,15, 7,2),fpp(28,15, 7,3)/
     x-1.8720299d-05, 1.8630234d-08, 2.5268409d-09 /
      data fpp(28,15, 8,1),fpp(28,15, 8,2),fpp(28,15, 8,3)/
     x-1.6622081d-05, 1.3057406d-08,-2.4015069d-09 /
      data fpp(28,15, 9,1),fpp(28,15, 9,2),fpp(28,15, 9,3)/
     x-1.4534573d-05, 8.8900931d-09,-4.9208133d-09 /
      data fpp(28,15,10,1),fpp(28,15,10,2),fpp(28,15,10,3)/
     x-1.2702207d-05, 2.3596874d-09,-7.9152398d-09 /
      data fpp(28,15,11,1),fpp(28,15,11,2),fpp(28,15,11,3)/
     x-1.1387531d-05,-5.6216191d-09,-1.1418227d-08 /
      data fpp(28,15,12,1),fpp(28,15,12,2),fpp(28,15,12,3)/
     x-1.0017115d-05,-1.0706524d-08,-6.4118510d-09 /
      data fpp(28,15,13,1),fpp(28,15,13,2),fpp(28,15,13,3)/
     x-9.4917141d-06,-1.2343632d-08,-1.0934369d-08 /
      data fpp(28,15,14,1),fpp(28,15,14,2),fpp(28,15,14,3)/
     x-7.7465678d-06,-9.1974629d-09,-3.8506740d-09 /
      data fpp(28,15,15,1),fpp(28,15,15,2),fpp(28,15,15,3)/
     x-9.3157097d-06,-1.1861940d-08,-9.6629353d-09 /
      data fpp(28,15,16,1),fpp(28,15,16,2),fpp(28,15,16,3)/
     x-9.4117142d-06,-9.5977659d-09,-5.4975847d-09 /
      data fpp(28,15,17,1),fpp(28,15,17,2),fpp(28,15,17,3)/
     x-9.3255053d-06,-8.9222307d-09,-4.3467259d-09 /
      data fpp(28,15,18,1),fpp(28,15,18,2),fpp(28,15,18,3)/
     x-9.7541545d-06,-6.3521626d-09,-1.1155117d-09 /
      data fpp(28,15,19,1),fpp(28,15,19,2),fpp(28,15,19,3)/
     x-9.8805472d-06,-5.4799391d-09, 2.8087729d-09 /
      data fpp(28,15,20,1),fpp(28,15,20,2),fpp(28,15,20,3)/
     x-1.0343638d-05,-8.5346803d-09, 7.8804202d-09 /
      data fpp(28,15,21,1),fpp(28,15,21,2),fpp(28,15,21,3)/
     x-1.0343638d-05,-8.5346803d-09, 7.9543529d-09 /
      data fpp(28,15,22,1),fpp(28,15,22,2),fpp(28,15,22,3)/
     x-9.8805472d-06,-5.4799391d-09, 2.5130420d-09 /
      data fpp(28,15,23,1),fpp(28,15,23,2),fpp(28,15,23,3)/
     x-9.7541545d-06,-6.3521626d-09,-6.5210105d-12 /
      data fpp(28,16, 1,1),fpp(28,16, 1,2),fpp(28,16, 1,3)/
     x-1.9017540d-05, 1.2750865d-08, 7.6845941d-09 /
      data fpp(28,16, 2,1),fpp(28,16, 2,2),fpp(28,16, 2,3)/
     x-1.9613605d-05, 1.5968516d-08, 9.6308119d-09 /
      data fpp(28,16, 3,1),fpp(28,16, 3,2),fpp(28,16, 3,3)/
     x-2.0250619d-05, 1.5409517d-08, 1.3792158d-08 /
      data fpp(28,16, 4,1),fpp(28,16, 4,2),fpp(28,16, 4,3)/
     x-2.0250619d-05, 1.5409517d-08, 1.3808119d-08 /
      data fpp(28,16, 5,1),fpp(28,16, 5,2),fpp(28,16, 5,3)/
     x-1.9613605d-05, 1.5968516d-08, 9.5669699d-09 /
      data fpp(28,16, 6,1),fpp(28,16, 6,2),fpp(28,16, 6,3)/
     x-1.9017540d-05, 1.2750865d-08, 7.9240014d-09 /
      data fpp(28,16, 7,1),fpp(28,16, 7,2),fpp(28,16, 7,3)/
     x-1.8121533d-05, 7.5114836d-09, 7.3702453d-10 /
      data fpp(28,16, 8,1),fpp(28,16, 8,2),fpp(28,16, 8,3)/
     x-1.6478020d-05, 5.3248190d-09, 1.1279005d-09 /
      data fpp(28,16, 9,1),fpp(28,16, 9,2),fpp(28,16, 9,3)/
     x-1.4855559d-05,-4.5507650d-10,-5.2486265d-09 /
      data fpp(28,16,10,1),fpp(28,16,10,2),fpp(28,16,10,3)/
     x-1.3102258d-05,-1.6324935d-09,-4.1333944d-09 /
      data fpp(28,16,11,1),fpp(28,16,11,2),fpp(28,16,11,3)/
     x-1.1601467d-05,-2.1529681d-09,-8.2177960d-09 /
      data fpp(28,16,12,1),fpp(28,16,12,2),fpp(28,16,12,3)/
     x-1.0341403d-05,-3.0374266d-09,-4.9954217d-09 /
      data fpp(28,16,13,1),fpp(28,16,13,2),fpp(28,16,13,3)/
     x-9.5134059d-06,-5.9594389d-09,-7.8005173d-09 /
      data fpp(28,16,14,1),fpp(28,16,14,2),fpp(28,16,14,3)/
     x-9.3288737d-06,-8.1429481d-09,-5.8025091d-09 /
      data fpp(28,16,15,1),fpp(28,16,15,2),fpp(28,16,15,3)/
     x-9.1568524d-06,-6.1091707d-09,-4.9894462d-09 /
      data fpp(28,16,16,1),fpp(28,16,16,2),fpp(28,16,16,3)/
     x-9.4617977d-06,-4.5717328d-09,-4.2397063d-09 /
      data fpp(28,16,17,1),fpp(28,16,17,2),fpp(28,16,17,3)/
     x-9.3360626d-06,-4.7012578d-09,-2.0517288d-09 /
      data fpp(28,16,18,1),fpp(28,16,18,2),fpp(28,16,18,3)/
     x-9.5089091d-06,-6.4623069d-09, 4.4662148d-10 /
      data fpp(28,16,19,1),fpp(28,16,19,2),fpp(28,16,19,3)/
     x-9.9179328d-06,-9.3765112d-09, 2.6524288d-10 /
      data fpp(28,16,20,1),fpp(28,16,20,2),fpp(28,16,20,3)/
     x-9.8261145d-06,-9.4855496d-09, 4.4924070d-09 /
      data fpp(28,16,21,1),fpp(28,16,21,2),fpp(28,16,21,3)/
     x-9.8261145d-06,-9.4855496d-09, 4.3901575d-09 /
      data fpp(28,16,22,1),fpp(28,16,22,2),fpp(28,16,22,3)/
     x-9.9179328d-06,-9.3765112d-09, 6.7424070d-10 /
      data fpp(28,16,23,1),fpp(28,16,23,2),fpp(28,16,23,3)/
     x-9.5089091d-06,-6.4623069d-09,-1.0871204d-09 /
      data fpp(28,17, 1,1),fpp(28,17, 1,2),fpp(28,17, 1,3)/
     x-1.6860349d-05,-5.3560022d-09, 5.0768737d-09 /
      data fpp(28,17, 2,1),fpp(28,17, 2,2),fpp(28,17, 2,3)/
     x-1.7190000d-05,-7.9530621d-09, 5.8462527d-09 /
      data fpp(28,17, 3,1),fpp(28,17, 3,2),fpp(28,17, 3,3)/
     x-1.8146006d-05,-7.9948701d-09, 7.5381156d-09 /
      data fpp(28,17, 4,1),fpp(28,17, 4,2),fpp(28,17, 4,3)/
     x-1.8146006d-05,-7.9948701d-09, 7.4625269d-09 /
      data fpp(28,17, 5,1),fpp(28,17, 5,2),fpp(28,17, 5,3)/
     x-1.7190000d-05,-7.9530621d-09, 6.1486076d-09 /
      data fpp(28,17, 6,1),fpp(28,17, 6,2),fpp(28,17, 6,3)/
     x-1.6860349d-05,-5.3560022d-09, 3.9430426d-09 /
      data fpp(28,17, 7,1),fpp(28,17, 7,2),fpp(28,17, 7,3)/
     x-1.5921214d-05,-6.7616866d-10, 2.0792218d-09 /
      data fpp(28,17, 8,1),fpp(28,17, 8,2),fpp(28,17, 8,3)/
     x-1.5149267d-05, 1.6433180d-09,-2.5992977d-10 /
      data fpp(28,17, 9,1),fpp(28,17, 9,2),fpp(28,17, 9,3)/
     x-1.3667047d-05, 4.9302129d-09,-1.0395027d-09 /
      data fpp(28,17,10,1),fpp(28,17,10,2),fpp(28,17,10,3)/
     x-1.2759609d-05, 4.1702867d-09,-1.5820595d-09 /
      data fpp(28,17,11,1),fpp(28,17,11,2),fpp(28,17,11,3)/
     x-1.1975327d-05, 2.2334914d-09,-4.6322595d-09 /
      data fpp(28,17,12,1),fpp(28,17,12,2),fpp(28,17,12,3)/
     x-1.0971889d-05,-1.1437698d-09,-3.8889026d-09 /
      data fpp(28,17,13,1),fpp(28,17,13,2),fpp(28,17,13,3)/
     x-1.0407802d-05, 1.8138739d-10,-3.8121300d-09 /
      data fpp(28,17,14,1),fpp(28,17,14,2),fpp(28,17,14,3)/
     x-1.0067304d-05,-2.3074475d-10,-4.8625772d-09 /
      data fpp(28,17,15,1),fpp(28,17,15,2),fpp(28,17,15,3)/
     x-9.5411936d-06, 2.9862289d-10,-7.3756116d-10 /
      data fpp(28,17,16,1),fpp(28,17,16,2),fpp(28,17,16,3)/
     x-9.5902918d-06,-2.1153027d-09,-4.1871782d-09 /
      data fpp(28,17,17,1),fpp(28,17,17,2),fpp(28,17,17,3)/
     x-9.5722176d-06,-2.2727383d-09,-5.1372622d-10 /
      data fpp(28,17,18,1),fpp(28,17,18,2),fpp(28,17,18,3)/
     x-9.4713492d-06,-3.7986097d-09, 2.4208304d-10 /
      data fpp(28,17,19,1),fpp(28,17,19,2),fpp(28,17,19,3)/
     x-9.6767772d-06,-5.0140162d-09,-4.5460595d-10 /
      data fpp(28,17,20,1),fpp(28,17,20,2),fpp(28,17,20,3)/
     x-9.5249196d-06,-7.5231213d-09, 1.5763407d-09 /
      data fpp(28,17,21,1),fpp(28,17,21,2),fpp(28,17,21,3)/
     x-9.5249196d-06,-7.5231213d-09, 1.4982807d-09 /
      data fpp(28,17,22,1),fpp(28,17,22,2),fpp(28,17,22,3)/
     x-9.6767772d-06,-5.0140162d-09,-1.4236593d-10 /
      data fpp(28,17,23,1),fpp(28,17,23,2),fpp(28,17,23,3)/
     x-9.4713492d-06,-3.7986097d-09,-9.2881704d-10 /
      data fpp(28,18, 1,1),fpp(28,18, 1,2),fpp(28,18, 1,3)/
     x-1.4324718d-05,-9.3268565d-09, 3.6990737d-09 /
      data fpp(28,18, 2,1),fpp(28,18, 2,2),fpp(28,18, 2,3)/
     x-1.4579111d-05,-1.4156268d-08, 3.1018526d-09 /
      data fpp(28,18, 3,1),fpp(28,18, 3,2),fpp(28,18, 3,3)/
     x-1.5094440d-05,-1.9430037d-08, 1.8935157d-09 /
      data fpp(28,18, 4,1),fpp(28,18, 4,2),fpp(28,18, 4,3)/
     x-1.5094440d-05,-1.9430037d-08, 1.7685264d-09 /
      data fpp(28,18, 5,1),fpp(28,18, 5,2),fpp(28,18, 5,3)/
     x-1.4579111d-05,-1.4156268d-08, 3.6018098d-09 /
      data fpp(28,18, 6,1),fpp(28,18, 6,2),fpp(28,18, 6,3)/
     x-1.4324718d-05,-9.3268565d-09, 1.8242342d-09 /
      data fpp(28,18, 7,1),fpp(28,18, 7,2),fpp(28,18, 7,3)/
     x-1.3851265d-05,-4.8068090d-09, 1.1012533d-09 /
      data fpp(28,18, 8,1),fpp(28,18, 8,2),fpp(28,18, 8,3)/
     x-1.3393716d-05, 1.0190915d-10,-2.2924752d-10 /
      data fpp(28,18, 9,1),fpp(28,18, 9,2),fpp(28,18, 9,3)/
     x-1.2888941d-05, 4.7342249d-09,-1.8426324d-10 /
      data fpp(28,18,10,1),fpp(28,18,10,2),fpp(28,18,10,3)/
     x-1.2343513d-05, 8.9513467d-09, 9.6630048d-10 /
      data fpp(28,18,11,1),fpp(28,18,11,2),fpp(28,18,11,3)/
     x-1.2092881d-05, 1.1219002d-08,-3.6809387d-09 /
      data fpp(28,18,12,1),fpp(28,18,12,2),fpp(28,18,12,3)/
     x-1.1253296d-05, 1.3612506d-08, 1.7574542d-09 /
      data fpp(28,18,13,1),fpp(28,18,13,2),fpp(28,18,13,3)/
     x-1.1239355d-05, 1.1233889d-08,-3.3488782d-09 /
      data fpp(28,18,14,1),fpp(28,18,14,2),fpp(28,18,14,3)/
     x-1.0777448d-05, 9.0659271d-09,-3.6194154d-10 /
      data fpp(28,18,15,1),fpp(28,18,15,2),fpp(28,18,15,3)/
     x-1.0602839d-05, 4.9146792d-09,-1.2033557d-09 /
      data fpp(28,18,16,1),fpp(28,18,16,2),fpp(28,18,16,3)/
     x-1.0384199d-05, 1.0329436d-09,-8.2463570d-10 /
      data fpp(28,18,17,1),fpp(28,18,17,2),fpp(28,18,17,3)/
     x-1.0187963d-05,-4.2077891d-09,-1.4981015d-09 /
      data fpp(28,18,18,1),fpp(28,18,18,2),fpp(28,18,18,3)/
     x-9.9171004d-06,-8.3432544d-09, 8.1704173d-10 /
      data fpp(28,18,19,1),fpp(28,18,19,2),fpp(28,18,19,3)/
     x-1.0249084d-05,-1.2567424d-08,-1.7700654d-09 /
      data fpp(28,18,20,1),fpp(28,18,20,2),fpp(28,18,20,3)/
     x-1.0069549d-05,-1.4421965d-08, 2.6321989d-10 /
      data fpp(28,18,21,1),fpp(28,18,21,2),fpp(28,18,21,3)/
     x-1.0069549d-05,-1.4421965d-08, 9.5373039d-11 /
      data fpp(28,18,22,1),fpp(28,18,22,2),fpp(28,18,22,3)/
     x-1.0249084d-05,-1.2567424d-08,-1.0986780d-09 /
      data fpp(28,18,23,1),fpp(28,18,23,2),fpp(28,18,23,3)/
     x-9.9171004d-06,-8.3432544d-09,-1.7006610d-09 /
      data fpp(28,19, 1,1),fpp(28,19, 1,2),fpp(28,19, 1,3)/
     x-1.1889995d-05,-1.7336572d-08, 1.5735040d-22 /
      data fpp(28,19, 2,1),fpp(28,19, 2,2),fpp(28,19, 2,3)/
     x-1.1889995d-05,-2.5421866d-08, 1.4400159d-22 /
      data fpp(28,19, 3,1),fpp(28,19, 3,2),fpp(28,19, 3,3)/
     x-1.1889995d-05,-3.4284981d-08, 8.4363375d-23 /
      data fpp(28,19, 4,1),fpp(28,19, 4,2),fpp(28,19, 4,3)/
     x-1.1889995d-05,-3.4284981d-08,-4.8221475d-23 /
      data fpp(28,19, 5,1),fpp(28,19, 5,2),fpp(28,19, 5,3)/
     x-1.1889995d-05,-2.5421866d-08,-1.2718021d-22 /
      data fpp(28,19, 6,1),fpp(28,19, 6,2),fpp(28,19, 6,3)/
     x-1.1889995d-05,-1.7336572d-08, 1.4382327d-23 /
      data fpp(28,19, 7,1),fpp(28,19, 7,2),fpp(28,19, 7,3)/
     x-1.1889995d-05,-1.0096596d-08, 1.9208987d-22 /
      data fpp(28,19, 8,1),fpp(28,19, 8,2),fpp(28,19, 8,3)/
     x-1.1889995d-05,-2.0509546d-09, 1.7821520d-22 /
      data fpp(28,19, 9,1),fpp(28,19, 9,2),fpp(28,19, 9,3)/
     x-1.1889995d-05, 6.1328876d-09, 2.5342537d-23 /
      data fpp(28,19,10,1),fpp(28,19,10,2),fpp(28,19,10,3)/
     x-1.1889995d-05, 1.4024327d-08,-1.4135254d-22 /
      data fpp(28,19,11,1),fpp(28,19,11,2),fpp(28,19,11,3)/
     x-1.1889995d-05, 1.8890499d-08, 5.2075865d-23 /
      data fpp(28,19,12,1),fpp(28,19,12,2),fpp(28,19,12,3)/
     x-1.1889995d-05, 2.4693747d-08,-1.1991908d-22 /
      data fpp(28,19,13,1),fpp(28,19,13,2),fpp(28,19,13,3)/
     x-1.1889995d-05, 2.0883055d-08,-8.9380442d-23 /
      data fpp(28,19,14,1),fpp(28,19,14,2),fpp(28,19,14,3)/
     x-1.1889995d-05, 1.7967036d-08,-7.9255146d-23 /
      data fpp(28,19,15,1),fpp(28,19,15,2),fpp(28,19,15,3)/
     x-1.1889995d-05, 1.0042660d-08, 4.6912735d-23 /
      data fpp(28,19,16,1),fpp(28,19,16,2),fpp(28,19,16,3)/
     x-1.1889995d-05, 3.9835282d-09, 7.9204599d-23 /
      data fpp(28,19,17,1),fpp(28,19,17,2),fpp(28,19,17,3)/
     x-1.1889995d-05,-4.8961055d-09,-1.9153205d-22 /
      data fpp(28,19,18,1),fpp(28,19,18,2),fpp(28,19,18,3)/
     x-1.1889995d-05,-1.0828373d-08, 1.4868617d-22 /
      data fpp(28,19,19,1),fpp(28,19,19,2),fpp(28,19,19,3)/
     x-1.1889995d-05,-1.6716288d-08, 6.3637707d-23 /
      data fpp(28,19,20,1),fpp(28,19,20,2),fpp(28,19,20,3)/
     x-1.1889995d-05,-1.8789017d-08,-1.1215172d-22 /
      data fpp(28,19,21,1),fpp(28,19,21,2),fpp(28,19,21,3)/
     x-1.1889995d-05,-1.8789017d-08, 1.1213851d-22 /
      data fpp(28,19,22,1),fpp(28,19,22,2),fpp(28,19,22,3)/
     x-1.1889995d-05,-1.6716288d-08,-6.5154749d-23 /
      data fpp(28,19,23,1),fpp(28,19,23,2),fpp(28,19,23,3)/
     x-1.1889995d-05,-1.0828373d-08,-5.1838983d-22 /
      data fpp(29, 1, 1,1),fpp(29, 1, 1,2),fpp(29, 1, 1,3)/
     x-1.3960432d-05, 1.0015812d-08, 2.1282738d-22 /
      data fpp(29, 1, 2,1),fpp(29, 1, 2,2),fpp(29, 1, 2,3)/
     x-1.3960432d-05,-9.7378977d-10,-1.0525313d-22 /
      data fpp(29, 1, 3,1),fpp(29, 1, 3,2),fpp(29, 1, 3,3)/
     x-1.3960432d-05,-6.9676208d-09, 2.5647593d-22 /
      data fpp(29, 1, 4,1),fpp(29, 1, 4,2),fpp(29, 1, 4,3)/
     x-1.3960432d-05,-6.9676208d-09,-2.6042059d-22 /
      data fpp(29, 1, 5,1),fpp(29, 1, 5,2),fpp(29, 1, 5,3)/
     x-1.3960432d-05,-9.7378977d-10,-1.3644319d-22 /
      data fpp(29, 1, 6,1),fpp(29, 1, 6,2),fpp(29, 1, 6,3)/
     x-1.3960432d-05, 1.0015812d-08, 1.8522269d-22 /
      data fpp(29, 1, 7,1),fpp(29, 1, 7,2),fpp(29, 1, 7,3)/
     x-1.3960432d-05, 2.1220675d-08, 3.9576010d-22 /
      data fpp(29, 1, 8,1),fpp(29, 1, 8,2),fpp(29, 1, 8,3)/
     x-1.3960432d-05, 3.6798321d-08, 1.2515660d-23 /
      data fpp(29, 1, 9,1),fpp(29, 1, 9,2),fpp(29, 1, 9,3)/
     x-1.3960432d-05, 4.8295221d-08,-1.4382802d-22 /
      data fpp(29, 1,10,1),fpp(29, 1,10,2),fpp(29, 1,10,3)/
     x-1.3960432d-05, 5.9037731d-08,-3.4816436d-22 /
      data fpp(29, 1,11,1),fpp(29, 1,11,2),fpp(29, 1,11,3)/
     x-1.3960432d-05, 6.5626354d-08, 1.4273407d-22 /
      data fpp(29, 1,12,1),fpp(29, 1,12,2),fpp(29, 1,12,3)/
     x-1.3960432d-05, 6.3898445d-08,-1.9417311d-22 /
      data fpp(29, 1,13,1),fpp(29, 1,13,2),fpp(29, 1,13,3)/
     x-1.3960432d-05, 6.8741442d-08,-3.7806803d-23 /
      data fpp(29, 1,14,1),fpp(29, 1,14,2),fpp(29, 1,14,3)/
     x-1.3960432d-05, 6.5179868d-08, 2.7621702d-23 /
      data fpp(29, 1,15,1),fpp(29, 1,15,2),fpp(29, 1,15,3)/
     x-1.3960432d-05, 5.8681113d-08,-1.2981723d-22 /
      data fpp(29, 1,16,1),fpp(29, 1,16,2),fpp(29, 1,16,3)/
     x-1.3960432d-05, 5.0113043d-08, 1.3437956d-22 /
      data fpp(29, 1,17,1),fpp(29, 1,17,2),fpp(29, 1,17,3)/
     x-1.3960432d-05, 3.8423939d-08,-3.4271073d-22 /
      data fpp(29, 1,18,1),fpp(29, 1,18,2),fpp(29, 1,18,3)/
     x-1.3960432d-05, 2.2827462d-08, 1.7396184d-22 /
      data fpp(29, 1,19,1),fpp(29, 1,19,2),fpp(29, 1,19,3)/
     x-1.3960432d-05, 1.3669763d-08, 2.0733486d-22 /
      data fpp(29, 1,20,1),fpp(29, 1,20,2),fpp(29, 1,20,3)/
     x-1.3960432d-05, 1.0482234d-08,-6.0768229d-23 /
      data fpp(29, 1,21,1),fpp(29, 1,21,2),fpp(29, 1,21,3)/
     x-1.3960432d-05, 1.0482234d-08, 8.0413318d-23 /
      data fpp(29, 1,22,1),fpp(29, 1,22,2),fpp(29, 1,22,3)/
     x-1.3960432d-05, 1.3669763d-08,-2.2218658d-22 /
      data fpp(29, 1,23,1),fpp(29, 1,23,2),fpp(29, 1,23,3)/
     x-1.3960432d-05, 2.2827462d-08,-1.0426124d-21 /
      data fpp(29, 2, 1,1),fpp(29, 2, 1,2),fpp(29, 2, 1,3)/
     x-1.4678370d-05, 1.6968377d-08, 3.0716639d-10 /
      data fpp(29, 2, 2,1),fpp(29, 2, 2,2),fpp(29, 2, 2,3)/
     x-1.3315253d-05, 1.0947580d-08, 8.8566722d-10 /
      data fpp(29, 2, 3,1),fpp(29, 2, 3,2),fpp(29, 2, 3,3)/
     x-1.2055539d-05, 6.9352416d-09, 2.1501647d-09 /
      data fpp(29, 2, 4,1),fpp(29, 2, 4,2),fpp(29, 2, 4,3)/
     x-1.2055539d-05, 6.9352416d-09, 2.1066722d-09 /
      data fpp(29, 2, 5,1),fpp(29, 2, 5,2),fpp(29, 2, 5,3)/
     x-1.3315253d-05, 1.0947580d-08, 1.0596376d-09 /
      data fpp(29, 2, 6,1),fpp(29, 2, 6,2),fpp(29, 2, 6,3)/
     x-1.4678370d-05, 1.6968377d-08,-3.4522242d-10 /
      data fpp(29, 2, 7,1),fpp(29, 2, 7,2),fpp(29, 2, 7,3)/
     x-1.6202770d-05, 2.2558649d-08, 3.2125210d-10 /
      data fpp(29, 2, 8,1),fpp(29, 2, 8,2),fpp(29, 2, 8,3)/
     x-1.7801471d-05, 2.9403359d-08,-9.3978597d-10 /
      data fpp(29, 2, 9,1),fpp(29, 2, 9,2),fpp(29, 2, 9,3)/
     x-1.9280100d-05, 3.4409559d-08,-2.5621082d-09 /
      data fpp(29, 2,10,1),fpp(29, 2,10,2),fpp(29, 2,10,3)/
     x-2.0491463d-05, 3.8924539d-08,-8.1178120d-10 /
      data fpp(29, 2,11,1),fpp(29, 2,11,2),fpp(29, 2,11,3)/
     x-2.1301994d-05, 4.1747293d-08,-1.9076699d-10 /
      data fpp(29, 2,12,1),fpp(29, 2,12,2),fpp(29, 2,12,3)/
     x-2.1578826d-05, 4.1203109d-08,-4.4251508d-09 /
      data fpp(29, 2,13,1),fpp(29, 2,13,2),fpp(29, 2,13,3)/
     x-2.1266041d-05, 4.4517115d-08,-1.0862966d-10 /
      data fpp(29, 2,14,1),fpp(29, 2,14,2),fpp(29, 2,14,3)/
     x-2.0408755d-05, 4.4640263d-08,-1.1403305d-09 /
      data fpp(29, 2,15,1),fpp(29, 2,15,2),fpp(29, 2,15,3)/
     x-1.9120749d-05, 4.3637773d-08,-1.3300483d-09 /
      data fpp(29, 2,16,1),fpp(29, 2,16,2),fpp(29, 2,16,3)/
     x-1.7546322d-05, 4.1773915d-08, 4.6052353d-10 /
      data fpp(29, 2,17,1),fpp(29, 2,17,2),fpp(29, 2,17,3)/
     x-1.5853305d-05, 3.8152121d-08,-5.1204587d-10 /
      data fpp(29, 2,18,1),fpp(29, 2,18,2),fpp(29, 2,18,3)/
     x-1.4189700d-05, 3.2345075d-08, 1.5876600d-09 /
      data fpp(29, 2,19,1),fpp(29, 2,19,2),fpp(29, 2,19,3)/
     x-1.2598999d-05, 2.8660475d-08, 1.6140605d-10 /
      data fpp(29, 2,20,1),fpp(29, 2,20,2),fpp(29, 2,20,3)/
     x-1.1379409d-05, 2.7035532d-08, 3.7667158d-09 /
      data fpp(29, 2,21,1),fpp(29, 2,21,2),fpp(29, 2,21,3)/
     x-1.1379409d-05, 2.7035532d-08, 3.6191495d-09 /
      data fpp(29, 2,22,1),fpp(29, 2,22,2),fpp(29, 2,22,3)/
     x-1.2598999d-05, 2.8660475d-08, 7.5167158d-10 /
      data fpp(29, 2,23,1),fpp(29, 2,23,2),fpp(29, 2,23,3)/
     x-1.4189700d-05, 3.2345075d-08,-6.2583579d-10 /
      data fpp(29, 3, 1,1),fpp(29, 3, 1,2),fpp(29, 3, 1,3)/
     x-1.6837298d-05, 3.6110682d-08, 2.1574774d-09 /
      data fpp(29, 3, 2,1),fpp(29, 3, 2,2),fpp(29, 3, 2,3)/
     x-1.3742967d-05, 3.5183472d-08, 3.6850451d-09 /
      data fpp(29, 3, 3,1),fpp(29, 3, 3,2),fpp(29, 3, 3,3)/
     x-1.1353275d-05, 3.3226654d-08, 7.1023421d-09 /
      data fpp(29, 3, 4,1),fpp(29, 3, 4,2),fpp(29, 3, 4,3)/
     x-1.1353275d-05, 3.3226654d-08, 6.8504511d-09 /
      data fpp(29, 3, 5,1),fpp(29, 3, 5,2),fpp(29, 3, 5,3)/
     x-1.3742967d-05, 3.5183472d-08, 4.6926091d-09 /
      data fpp(29, 3, 6,1),fpp(29, 3, 6,2),fpp(29, 3, 6,3)/
     x-1.6837298d-05, 3.6110682d-08,-1.6208875d-09 /
      data fpp(29, 3, 7,1),fpp(29, 3, 7,2),fpp(29, 3, 7,3)/
     x-2.0567943d-05, 3.8544727d-08, 1.7909408d-09 /
      data fpp(29, 3, 8,1),fpp(29, 3, 8,2),fpp(29, 3, 8,3)/
     x-2.4684796d-05, 3.1588245d-08,-5.5428756d-09 /
      data fpp(29, 3, 9,1),fpp(29, 3, 9,2),fpp(29, 3, 9,3)/
     x-2.8524628d-05, 2.4066545d-08,-3.6194384d-09 /
      data fpp(29, 3,10,1),fpp(29, 3,10,2),fpp(29, 3,10,3)/
     x-3.1694116d-05, 1.9264114d-08,-3.9793708d-09 /
      data fpp(29, 3,11,1),fpp(29, 3,11,2),fpp(29, 3,11,3)/
     x-3.3784004d-05, 1.3384476d-08,-4.4630782d-09 /
      data fpp(29, 3,12,1),fpp(29, 3,12,2),fpp(29, 3,12,3)/
     x-3.4561032d-05, 1.7289118d-08,-2.1683163d-09 /
      data fpp(29, 3,13,1),fpp(29, 3,13,2),fpp(29, 3,13,3)/
     x-3.3842008d-05, 1.7190096d-08,-4.8636566d-09 /
      data fpp(29, 3,14,1),fpp(29, 3,14,2),fpp(29, 3,14,3)/
     x-3.1707984d-05, 2.6259078d-08,-2.3770573d-09 /
      data fpp(29, 3,15,1),fpp(29, 3,15,2),fpp(29, 3,15,3)/
     x-2.8373281d-05, 3.6767794d-08,-3.6281144d-09 /
      data fpp(29, 3,16,1),fpp(29, 3,16,2),fpp(29, 3,16,3)/
     x-2.4235978d-05, 4.6791298d-08,-1.1104853d-09 /
      data fpp(29, 3,17,1),fpp(29, 3,17,2),fpp(29, 3,17,3)/
     x-1.9713483d-05, 5.4967576d-08,-3.9299445d-09 /
      data fpp(29, 3,18,1),fpp(29, 3,18,2),fpp(29, 3,18,3)/
     x-1.5454319d-05, 6.3792236d-08, 4.8302633d-09 /
      data fpp(29, 3,19,1),fpp(29, 3,19,2),fpp(29, 3,19,3)/
     x-1.1874559d-05, 6.3688338d-08, 2.6088913d-09 /
      data fpp(29, 3,20,1),fpp(29, 3,20,2),fpp(29, 3,20,3)/
     x-9.2487835d-06, 6.1375639d-08, 8.7341715d-09 /
      data fpp(29, 3,21,1),fpp(29, 3,21,2),fpp(29, 3,21,3)/
     x-9.2487835d-06, 6.1375639d-08, 8.4930400d-09 /
      data fpp(29, 3,22,1),fpp(29, 3,22,2),fpp(29, 3,22,3)/
     x-1.1874559d-05, 6.3688338d-08, 3.5734171d-09 /
      data fpp(29, 3,23,1),fpp(29, 3,23,2),fpp(29, 3,23,3)/
     x-1.5454319d-05, 6.3792236d-08, 1.2132914d-09 /
      data fpp(29, 4, 1,1),fpp(29, 4, 1,2),fpp(29, 4, 1,3)/
     x-1.9934854d-05, 1.2588896d-08, 1.3739241d-09 /
      data fpp(29, 4, 2,1),fpp(29, 4, 2,2),fpp(29, 4, 2,3)/
     x-1.5879266d-05, 1.6318534d-08, 5.2521517d-09 /
      data fpp(29, 4, 3,1),fpp(29, 4, 3,2),fpp(29, 4, 3,3)/
     x-1.3191440d-05, 1.6158141d-08, 1.3617469d-08 /
      data fpp(29, 4, 4,1),fpp(29, 4, 4,2),fpp(29, 4, 4,3)/
     x-1.3191440d-05, 1.6158141d-08, 1.3521517d-08 /
      data fpp(29, 4, 5,1),fpp(29, 4, 5,2),fpp(29, 4, 5,3)/
     x-1.5879266d-05, 1.6318534d-08, 5.6359588d-09 /
      data fpp(29, 4, 6,1),fpp(29, 4, 6,2),fpp(29, 4, 6,3)/
     x-1.9934854d-05, 1.2588896d-08,-6.5352455d-11 /
      data fpp(29, 4, 7,1),fpp(29, 4, 7,2),fpp(29, 4, 7,3)/
     x-2.4711197d-05, 3.2624419d-09,-5.3745490d-09 /
      data fpp(29, 4, 8,1),fpp(29, 4, 8,2),fpp(29, 4, 8,3)/
     x-2.9438302d-05, 2.4366061d-10,-8.4364516d-09 /
      data fpp(29, 4, 9,1),fpp(29, 4, 9,2),fpp(29, 4, 9,3)/
     x-3.3650797d-05, 1.3242629d-09,-2.8796447d-09 /
      data fpp(29, 4,10,1),fpp(29, 4,10,2),fpp(29, 4,10,3)/
     x-3.6985983d-05,-1.9809937d-09,-1.0044970d-08 /
      data fpp(29, 4,11,1),fpp(29, 4,11,2),fpp(29, 4,11,3)/
     x-3.9107678d-05, 7.1480474d-10, 1.0595228d-09 /
      data fpp(29, 4,12,1),fpp(29, 4,12,2),fpp(29, 4,12,3)/
     x-3.9941028d-05,-2.3595799d-09,-6.1931215d-09 /
      data fpp(29, 4,13,1),fpp(29, 4,13,2),fpp(29, 4,13,3)/
     x-3.9400646d-05, 7.2250045d-10,-2.8703657d-10 /
      data fpp(29, 4,14,1),fpp(29, 4,14,2),fpp(29, 4,14,3)/
     x-3.7467182d-05, 3.2342507d-10,-4.6587322d-09 /
      data fpp(29, 4,15,1),fpp(29, 4,15,2),fpp(29, 4,15,3)/
     x-3.4190842d-05, 1.2910511d-09,-5.0780347d-09 /
      data fpp(29, 4,16,1),fpp(29, 4,16,2),fpp(29, 4,16,3)/
     x-2.9741710d-05, 5.0608915d-09,-5.0291288d-09 /
      data fpp(29, 4,17,1),fpp(29, 4,17,2),fpp(29, 4,17,3)/
     x-2.4471635d-05, 1.1977576d-08,-4.8054499d-09 /
      data fpp(29, 4,18,1),fpp(29, 4,18,2),fpp(29, 4,18,3)/
     x-1.9035429d-05, 1.8485979d-08, 2.5092831d-10 /
      data fpp(29, 4,19,1),fpp(29, 4,19,2),fpp(29, 4,19,3)/
     x-1.4319188d-05, 2.8586173d-08, 3.8017366d-09 /
      data fpp(29, 4,20,1),fpp(29, 4,20,2),fpp(29, 4,20,3)/
     x-1.1202046d-05, 3.3461912d-08, 1.4542125d-08 /
      data fpp(29, 4,21,1),fpp(29, 4,21,2),fpp(29, 4,21,3)/
     x-1.1202046d-05, 3.3461912d-08, 1.4472756d-08 /
      data fpp(29, 4,22,1),fpp(29, 4,22,2),fpp(29, 4,22,3)/
     x-1.4319188d-05, 2.8586173d-08, 4.0792125d-09 /
      data fpp(29, 4,23,1),fpp(29, 4,23,2),fpp(29, 4,23,3)/
     x-1.9035429d-05, 1.8485979d-08,-7.8960626d-10 /
      data fpp(29, 5, 1,1),fpp(29, 5, 1,2),fpp(29, 5, 1,3)/
     x-2.0266110d-05, 9.5337346d-09,-4.0291465d-09 /
      data fpp(29, 5, 2,1),fpp(29, 5, 2,2),fpp(29, 5, 2,3)/
     x-1.6704252d-05, 1.9542392d-08, 3.5582930d-09 /
      data fpp(29, 5, 3,1),fpp(29, 5, 3,2),fpp(29, 5, 3,3)/
     x-1.4264476d-05, 2.8140780d-08, 1.9795974d-08 /
      data fpp(29, 5, 4,1),fpp(29, 5, 4,2),fpp(29, 5, 4,3)/
     x-1.4264476d-05, 2.8140780d-08, 1.9832930d-08 /
      data fpp(29, 5, 5,1),fpp(29, 5, 5,2),fpp(29, 5, 5,3)/
     x-1.6704252d-05, 1.9542392d-08, 3.4104707d-09 /
      data fpp(29, 5, 6,1),fpp(29, 5, 6,2),fpp(29, 5, 6,3)/
     x-2.0266110d-05, 9.5337346d-09,-3.4748128d-09 /
      data fpp(29, 5, 7,1),fpp(29, 5, 7,2),fpp(29, 5, 7,3)/
     x-2.4155939d-05, 2.4055052d-09,-7.5112196d-09 /
      data fpp(29, 5, 8,1),fpp(29, 5, 8,2),fpp(29, 5, 8,3)/
     x-2.7769179d-05,-2.5628877d-09,-8.4803089d-09 /
      data fpp(29, 5, 9,1),fpp(29, 5, 9,2),fpp(29, 5, 9,3)/
     x-3.0775836d-05,-1.1363596d-08,-6.5675447d-09 /
      data fpp(29, 5,10,1),fpp(29, 5,10,2),fpp(29, 5,10,3)/
     x-3.3073567d-05,-1.1340139d-08,-7.2495124d-09 /
      data fpp(29, 5,11,1),fpp(29, 5,11,2),fpp(29, 5,11,3)/
     x-3.4631454d-05,-1.0243695d-08,-4.3440589d-10 /
      data fpp(29, 5,12,1),fpp(29, 5,12,2),fpp(29, 5,12,3)/
     x-3.5364513d-05,-7.8507979d-09,-3.0128641d-09 /
      data fpp(29, 5,13,1),fpp(29, 5,13,2),fpp(29, 5,13,3)/
     x-3.5244828d-05,-8.0800978d-09, 4.8586220d-10 /
      data fpp(29, 5,14,1),fpp(29, 5,14,2),fpp(29, 5,14,3)/
     x-3.4157726d-05,-9.5527781d-09,-4.9305847d-09 /
      data fpp(29, 5,15,1),fpp(29, 5,15,2),fpp(29, 5,15,3)/
     x-3.2134468d-05,-1.1931998d-08,-4.7635233d-09 /
      data fpp(29, 5,16,1),fpp(29, 5,16,2),fpp(29, 5,16,3)/
     x-2.9061051d-05,-1.3034864d-08,-6.0153220d-09 /
      data fpp(29, 5,17,1),fpp(29, 5,17,2),fpp(29, 5,17,3)/
     x-2.5059999d-05,-1.2877880d-08,-7.1751888d-09 /
      data fpp(29, 5,18,1),fpp(29, 5,18,2),fpp(29, 5,18,3)/
     x-2.0603476d-05,-1.1736152d-08,-1.2839230d-09 /
      data fpp(29, 5,19,1),fpp(29, 5,19,2),fpp(29, 5,19,3)/
     x-1.6587266d-05,-1.0033030d-08, 3.1088079d-10 /
      data fpp(29, 5,20,1),fpp(29, 5,20,2),fpp(29, 5,20,3)/
     x-1.3860030d-05,-3.2232871d-09, 1.8040400d-08 /
      data fpp(29, 5,21,1),fpp(29, 5,21,2),fpp(29, 5,21,3)/
     x-1.3860030d-05,-3.2232871d-09, 1.7723360d-08 /
      data fpp(29, 5,22,1),fpp(29, 5,22,2),fpp(29, 5,22,3)/
     x-1.6587266d-05,-1.0033030d-08, 1.5790400d-09 /
      data fpp(29, 5,23,1),fpp(29, 5,23,2),fpp(29, 5,23,3)/
     x-2.0603476d-05,-1.1736152d-08,-6.0395200d-09 /
      data fpp(29, 6, 1,1),fpp(29, 6, 1,2),fpp(29, 6, 1,3)/
     x-1.7792099d-05,-2.7238344d-09,-7.8839268d-09 /
      data fpp(29, 6, 2,1),fpp(29, 6, 2,2),fpp(29, 6, 2,3)/
     x-1.6405605d-05, 1.5118978d-09, 1.2678536d-09 /
      data fpp(29, 6, 3,1),fpp(29, 6, 3,2),fpp(29, 6, 3,3)/
     x-1.5751860d-05, 9.2787383d-09, 2.0812512d-08 /
      data fpp(29, 6, 4,1),fpp(29, 6, 4,2),fpp(29, 6, 4,3)/
     x-1.5751860d-05, 9.2787383d-09, 2.0928536d-08 /
      data fpp(29, 6, 5,1),fpp(29, 6, 5,2),fpp(29, 6, 5,3)/
     x-1.6405605d-05, 1.5118978d-09, 8.0375994d-10 /
      data fpp(29, 6, 6,1),fpp(29, 6, 6,2),fpp(29, 6, 6,3)/
     x-1.7792099d-05,-2.7238344d-09,-6.1435756d-09 /
      data fpp(29, 6, 7,1),fpp(29, 6, 7,2),fpp(29, 6, 7,3)/
     x-1.9559669d-05,-6.8844627d-09,-6.2294575d-09 /
      data fpp(29, 6, 8,1),fpp(29, 6, 8,2),fpp(29, 6, 8,3)/
     x-2.1453306d-05,-1.3992110d-08,-1.0938594d-08 /
      data fpp(29, 6, 9,1),fpp(29, 6, 9,2),fpp(29, 6, 9,3)/
     x-2.3182008d-05,-9.8698775d-09,-4.0161652d-09 /
      data fpp(29, 6,10,1),fpp(29, 6,10,2),fpp(29, 6,10,3)/
     x-2.4814176d-05,-1.2658451d-08,-2.9967448d-09 /
      data fpp(29, 6,11,1),fpp(29, 6,11,2),fpp(29, 6,11,3)/
     x-2.6176811d-05,-1.3740026d-08,-1.9968554d-09 /
      data fpp(29, 6,12,1),fpp(29, 6,12,2),fpp(29, 6,12,3)/
     x-2.6952906d-05,-1.4237228d-08,-1.0158336d-09 /
      data fpp(29, 6,13,1),fpp(29, 6,13,2),fpp(29, 6,13,3)/
     x-2.6937815d-05,-1.6402109d-08, 6.0189649d-11 /
      data fpp(29, 6,14,1),fpp(29, 6,14,2),fpp(29, 6,14,3)/
     x-2.6221694d-05,-1.6112313d-08,-5.2249250d-09 /
      data fpp(29, 6,15,1),fpp(29, 6,15,2),fpp(29, 6,15,3)/
     x-2.4948563d-05,-1.3563058d-08,-3.1604895d-09 /
      data fpp(29, 6,16,1),fpp(29, 6,16,2),fpp(29, 6,16,3)/
     x-2.3192955d-05,-1.2921434d-08,-6.1331169d-09 /
      data fpp(29, 6,17,1),fpp(29, 6,17,2),fpp(29, 6,17,3)/
     x-2.0907051d-05,-1.4466055d-08,-8.3070428d-09 /
      data fpp(29, 6,18,1),fpp(29, 6,18,2),fpp(29, 6,18,3)/
     x-1.8527060d-05,-1.3541371d-08,-2.6387117d-09 /
      data fpp(29, 6,19,1),fpp(29, 6,19,2),fpp(29, 6,19,3)/
     x-1.6627978d-05,-1.2454054d-08, 8.6188971d-10 /
      data fpp(29, 6,20,1),fpp(29, 6,20,2),fpp(29, 6,20,3)/
     x-1.5612974d-05,-1.4568764d-08, 1.7191153d-08 /
      data fpp(29, 6,21,1),fpp(29, 6,21,2),fpp(29, 6,21,3)/
     x-1.5612974d-05,-1.4568764d-08, 1.6995596d-08 /
      data fpp(29, 6,22,1),fpp(29, 6,22,2),fpp(29, 6,22,3)/
     x-1.6627978d-05,-1.2454054d-08, 1.6441153d-09 /
      data fpp(29, 6,23,1),fpp(29, 6,23,2),fpp(29, 6,23,3)/
     x-1.8527060d-05,-1.3541371d-08,-5.5720576d-09 /
      data fpp(29, 7, 1,1),fpp(29, 7, 1,2),fpp(29, 7, 1,3)/
     x-1.4542519d-05,-3.4638397d-08,-5.5608405d-09 /
      data fpp(29, 7, 2,1),fpp(29, 7, 2,2),fpp(29, 7, 2,3)/
     x-1.4972603d-05,-3.7589983d-08, 1.6216810d-09 /
      data fpp(29, 7, 3,1),fpp(29, 7, 3,2),fpp(29, 7, 3,3)/
     x-1.5648994d-05,-4.1255733d-08, 1.7074116d-08 /
      data fpp(29, 7, 4,1),fpp(29, 7, 4,2),fpp(29, 7, 4,3)/
     x-1.5648994d-05,-4.1255733d-08, 1.6966810d-08 /
      data fpp(29, 7, 5,1),fpp(29, 7, 5,2),fpp(29, 7, 5,3)/
     x-1.4972603d-05,-3.7589983d-08, 2.0509054d-09 /
      data fpp(29, 7, 6,1),fpp(29, 7, 6,2),fpp(29, 7, 6,3)/
     x-1.4542519d-05,-3.4638397d-08,-7.1704319d-09 /
      data fpp(29, 7, 7,1),fpp(29, 7, 7,2),fpp(29, 7, 7,3)/
     x-1.4594213d-05,-2.8867654d-08,-9.3691778d-09 /
      data fpp(29, 7, 8,1),fpp(29, 7, 8,2),fpp(29, 7, 8,3)/
     x-1.5163678d-05,-1.9468673d-08,-3.3528570d-09 /
      data fpp(29, 7, 9,1),fpp(29, 7, 9,2),fpp(29, 7, 9,3)/
     x-1.6110986d-05,-2.1156894d-08,-7.2193942d-09 /
      data fpp(29, 7,10,1),fpp(29, 7,10,2),fpp(29, 7,10,3)/
     x-1.7203289d-05,-1.6026056d-08, 2.2304339d-09 /
      data fpp(29, 7,11,1),fpp(29, 7,11,2),fpp(29, 7,11,3)/
     x-1.8220416d-05,-1.8796200d-08,-1.7023413d-09 /
      data fpp(29, 7,12,1),fpp(29, 7,12,2),fpp(29, 7,12,3)/
     x-1.8819125d-05,-1.9200289d-08,-1.4210686d-09 /
      data fpp(29, 7,13,1),fpp(29, 7,13,2),fpp(29, 7,13,3)/
     x-1.8889223d-05,-1.6311466d-08, 1.3866158d-09 /
      data fpp(29, 7,14,1),fpp(29, 7,14,2),fpp(29, 7,14,3)/
     x-1.8464304d-05,-1.5997972d-08,-4.1253945d-09 /
      data fpp(29, 7,15,1),fpp(29, 7,15,2),fpp(29, 7,15,3)/
     x-1.7710844d-05,-1.7815768d-08,-2.8850376d-09 /
      data fpp(29, 7,16,1),fpp(29, 7,16,2),fpp(29, 7,16,3)/
     x-1.6760405d-05,-1.9279400d-08,-8.3344551d-09 /
      data fpp(29, 7,17,1),fpp(29, 7,17,2),fpp(29, 7,17,3)/
     x-1.5682146d-05,-1.9257898d-08,-5.7771421d-09 /
      data fpp(29, 7,18,1),fpp(29, 7,18,2),fpp(29, 7,18,3)/
     x-1.4826179d-05,-1.8098366d-08,-4.5569766d-09 /
      data fpp(29, 7,19,1),fpp(29, 7,19,2),fpp(29, 7,19,3)/
     x-1.4492843d-05,-1.8150754d-08, 5.0483035d-12 /
      data fpp(29, 7,20,1),fpp(29, 7,20,2),fpp(29, 7,20,3)/
     x-1.4633042d-05,-1.6501658d-08, 1.6536783d-08 /
      data fpp(29, 7,21,1),fpp(29, 7,21,2),fpp(29, 7,21,3)/
     x-1.4633042d-05,-1.6501658d-08, 1.6387126d-08 /
      data fpp(29, 7,22,1),fpp(29, 7,22,2),fpp(29, 7,22,3)/
     x-1.4492843d-05,-1.8150754d-08, 6.0367833d-10 /
      data fpp(29, 7,23,1),fpp(29, 7,23,2),fpp(29, 7,23,3)/
     x-1.4826179d-05,-1.8098366d-08,-6.8018392d-09 /
      data fpp(29, 8, 1,1),fpp(29, 8, 1,2),fpp(29, 8, 1,3)/
     x-1.2000318d-05,-4.4722577d-08,-4.1707244d-09 /
      data fpp(29, 8, 2,1),fpp(29, 8, 2,2),fpp(29, 8, 2,3)/
     x-1.2969751d-05,-4.9151965d-08, 1.8414488d-09 /
      data fpp(29, 8, 3,1),fpp(29, 8, 3,2),fpp(29, 8, 3,3)/
     x-1.3866142d-05,-5.4255805d-08, 1.4804929d-08 /
      data fpp(29, 8, 4,1),fpp(29, 8, 4,2),fpp(29, 8, 4,3)/
     x-1.3866142d-05,-5.4255805d-08, 1.4664488d-08 /
      data fpp(29, 8, 5,1),fpp(29, 8, 5,2),fpp(29, 8, 5,3)/
     x-1.2969751d-05,-4.9151965d-08, 2.4032121d-09 /
      data fpp(29, 8, 6,1),fpp(29, 8, 6,2),fpp(29, 8, 6,3)/
     x-1.2000318d-05,-4.4722577d-08,-6.2773368d-09 /
      data fpp(29, 8, 7,1),fpp(29, 8, 7,2),fpp(29, 8, 7,3)/
     x-1.1362258d-05,-3.9644920d-08,-7.2938648d-09 /
      data fpp(29, 8, 8,1),fpp(29, 8, 8,2),fpp(29, 8, 8,3)/
     x-1.1272862d-05,-3.4133199d-08,-6.5472039d-09 /
      data fpp(29, 8, 9,1),fpp(29, 8, 9,2),fpp(29, 8, 9,3)/
     x-1.1559153d-05,-2.5502547d-08,-2.5173198d-09 /
      data fpp(29, 8,10,1),fpp(29, 8,10,2),fpp(29, 8,10,3)/
     x-1.2027825d-05,-2.5237324d-08,-1.3835171d-09 /
      data fpp(29, 8,11,1),fpp(29, 8,11,2),fpp(29, 8,11,3)/
     x-1.2499767d-05,-1.9075174d-08, 2.0513881d-09 /
      data fpp(29, 8,12,1),fpp(29, 8,12,2),fpp(29, 8,12,3)/
     x-1.2784906d-05,-1.6961617d-08,-8.2203532d-10 /
      data fpp(29, 8,13,1),fpp(29, 8,13,2),fpp(29, 8,13,3)/
     x-1.2935262d-05,-2.0352029d-08, 1.2367532d-09 /
      data fpp(29, 8,14,1),fpp(29, 8,14,2),fpp(29, 8,14,3)/
     x-1.2899145d-05,-2.1895800d-08,-4.1249774d-09 /
      data fpp(29, 8,15,1),fpp(29, 8,15,2),fpp(29, 8,15,3)/
     x-1.2653486d-05,-2.3173868d-08,-2.7368436d-09 /
      data fpp(29, 8,16,1),fpp(29, 8,16,2),fpp(29, 8,16,3)/
     x-1.2272311d-05,-2.3960966d-08,-8.9276481d-09 /
      data fpp(29, 8,17,1),fpp(29, 8,17,2),fpp(29, 8,17,3)/
     x-1.1780959d-05,-2.2502352d-08,-3.5525641d-09 /
      data fpp(29, 8,18,1),fpp(29, 8,18,2),fpp(29, 8,18,3)/
     x-1.1482621d-05,-2.8065166d-08,-6.8620954d-09 /
      data fpp(29, 8,19,1),fpp(29, 8,19,2),fpp(29, 8,19,3)/
     x-1.1556867d-05,-2.8942930d-08, 1.0009458d-09 /
      data fpp(29, 8,20,1),fpp(29, 8,20,2),fpp(29, 8,20,3)/
     x-1.1824399d-05,-2.7424603d-08, 1.4858312d-08 /
      data fpp(29, 8,21,1),fpp(29, 8,21,2),fpp(29, 8,21,3)/
     x-1.1824399d-05,-2.7424603d-08, 1.4924591d-08 /
      data fpp(29, 8,22,1),fpp(29, 8,22,2),fpp(29, 8,22,3)/
     x-1.1556867d-05,-2.8942930d-08, 7.3583121d-10 /
      data fpp(29, 8,23,1),fpp(29, 8,23,2),fpp(29, 8,23,3)/
     x-1.1482621d-05,-2.8065166d-08,-5.8679156d-09 /
      data fpp(29, 9, 1,1),fpp(29, 9, 1,2),fpp(29, 9, 1,3)/
     x-1.0948721d-05,-3.2471294d-08,-4.6425777d-09 /
      data fpp(29, 9, 2,1),fpp(29, 9, 2,2),fpp(29, 9, 2,3)/
     x-1.2173669d-05,-3.5802155d-08, 1.7851555d-09 /
      data fpp(29, 9, 3,1),fpp(29, 9, 3,2),fpp(29, 9, 3,3)/
     x-1.3238386d-05,-3.5721047d-08, 1.5501956d-08 /
      data fpp(29, 9, 4,1),fpp(29, 9, 4,2),fpp(29, 9, 4,3)/
     x-1.3238386d-05,-3.5721047d-08, 1.5601555d-08 /
      data fpp(29, 9, 5,1),fpp(29, 9, 5,2),fpp(29, 9, 5,3)/
     x-1.2173669d-05,-3.5802155d-08, 1.3867600d-09 /
      data fpp(29, 9, 6,1),fpp(29, 9, 6,2),fpp(29, 9, 6,3)/
     x-1.0948721d-05,-3.2471294d-08,-3.1485945d-09 /
      data fpp(29, 9, 7,1),fpp(29, 9, 7,2),fpp(29, 9, 7,3)/
     x-9.9378178d-06,-2.8552665d-08,-6.7923818d-09 /
      data fpp(29, 9, 8,1),fpp(29, 9, 8,2),fpp(29, 9, 8,3)/
     x-9.3454885d-06,-2.9998530d-08,-5.6818782d-09 /
      data fpp(29, 9, 9,1),fpp(29, 9, 9,2),fpp(29, 9, 9,3)/
     x-9.1382316d-06,-2.6832916d-08,-6.4801052d-09 /
      data fpp(29, 9,10,1),fpp(29, 9,10,2),fpp(29, 9,10,3)/
     x-9.1607587d-06,-2.1024648d-08, 1.6022992d-09 /
      data fpp(29, 9,11,1),fpp(29, 9,11,2),fpp(29, 9,11,3)/
     x-9.3246467d-06,-1.8903104d-08, 7.0908557d-11 /
      data fpp(29, 9,12,1),fpp(29, 9,12,2),fpp(29, 9,12,3)/
     x-9.4436666d-06,-2.0953244d-08,-1.8859334d-09 /
      data fpp(29, 9,13,1),fpp(29, 9,13,2),fpp(29, 9,13,3)/
     x-9.5536188d-06,-1.6280420d-08, 1.4728250d-09 /
      data fpp(29, 9,14,1),fpp(29, 9,14,2),fpp(29, 9,14,3)/
     x-9.6152554d-06,-1.6418828d-08,-4.0053667d-09 /
      data fpp(29, 9,15,1),fpp(29, 9,15,2),fpp(29, 9,15,3)/
     x-9.6147345d-06,-1.5488760d-08,-3.4513582d-09 /
      data fpp(29, 9,16,1),fpp(29, 9,16,2),fpp(29, 9,16,3)/
     x-9.4956342d-06,-1.6876738d-08,-6.1892006d-09 /
      data fpp(29, 9,17,1),fpp(29, 9,17,2),fpp(29, 9,17,3)/
     x-9.3129696d-06,-2.2732694d-08,-7.7918394d-09 /
      data fpp(29, 9,18,1),fpp(29, 9,18,2),fpp(29, 9,18,3)/
     x-9.2419786d-06,-1.9640969d-08,-4.6434416d-09 /
      data fpp(29, 9,19,1),fpp(29, 9,19,2),fpp(29, 9,19,3)/
     x-9.3787075d-06,-2.2077526d-08, 2.3656060d-09 /
      data fpp(29, 9,20,1),fpp(29, 9,20,2),fpp(29, 9,20,3)/
     x-9.6017408d-06,-2.9799930d-08, 1.3181018d-08 /
      data fpp(29, 9,21,1),fpp(29, 9,21,2),fpp(29, 9,21,3)/
     x-9.6017408d-06,-2.9799930d-08, 1.3274144d-08 /
      data fpp(29, 9,22,1),fpp(29, 9,22,2),fpp(29, 9,22,3)/
     x-9.3787075d-06,-2.2077526d-08, 1.9931018d-09 /
      data fpp(29, 9,23,1),fpp(29, 9,23,2),fpp(29, 9,23,3)/
     x-9.2419786d-06,-1.9640969d-08,-3.2465509d-09 /
      data fpp(29,10, 1,1),fpp(29,10, 1,2),fpp(29,10, 1,3)/
     x-1.1286924d-05,-1.1392247d-08,-2.1819804d-09 /
      data fpp(29,10, 2,1),fpp(29,10, 2,2),fpp(29,10, 2,3)/
     x-1.2889045d-05,-1.1639413d-08, 3.8639609d-09 /
      data fpp(29,10, 3,1),fpp(29,10, 3,2),fpp(29,10, 3,3)/
     x-1.4167776d-05,-1.2860007d-08, 1.6726137d-08 /
      data fpp(29,10, 4,1),fpp(29,10, 4,2),fpp(29,10, 4,3)/
     x-1.4167776d-05,-1.2860007d-08, 1.6889609d-08 /
      data fpp(29,10, 5,1),fpp(29,10, 5,2),fpp(29,10, 5,3)/
     x-1.2889045d-05,-1.1639413d-08, 3.2100727d-09 /
      data fpp(29,10, 6,1),fpp(29,10, 6,2),fpp(29,10, 6,3)/
     x-1.1286924d-05,-1.1392247d-08, 2.7010020d-10 /
      data fpp(29,10, 7,1),fpp(29,10, 7,2),fpp(29,10, 7,3)/
     x-9.7437286d-06,-1.4144420d-08,-1.0290474d-08 /
      data fpp(29,10, 8,1),fpp(29,10, 8,2),fpp(29,10, 8,3)/
     x-8.6554430d-06,-7.8726806d-09,-1.1082062d-09 /
      data fpp(29,10, 9,1),fpp(29,10, 9,2),fpp(29,10, 9,3)/
     x-8.1177145d-06,-1.1165787d-08,-9.2767019d-09 /
      data fpp(29,10,10,1),fpp(29,10,10,2),fpp(29,10,10,3)/
     x-7.9641371d-06,-1.0664085d-08, 2.2150137d-09 /
      data fpp(29,10,11,1),fpp(29,10,11,2),fpp(29,10,11,3)/
     x-8.0677122d-06,-1.3312410d-08,-5.5833528d-09 /
      data fpp(29,10,12,1),fpp(29,10,12,2),fpp(29,10,12,3)/
     x-8.1598962d-06,-7.2254080d-09, 2.1183975d-09 /
      data fpp(29,10,13,1),fpp(29,10,13,2),fpp(29,10,13,3)/
     x-8.2105190d-06,-1.0526292d-08,-2.8902373d-09 /
      data fpp(29,10,14,1),fpp(29,10,14,2),fpp(29,10,14,3)/
     x-8.1355544d-06,-8.4288897d-09,-2.5574482d-09 /
      data fpp(29,10,15,1),fpp(29,10,15,2),fpp(29,10,15,3)/
     x-8.0194600d-06,-1.0871094d-08,-4.8799699d-09 /
      data fpp(29,10,16,1),fpp(29,10,16,2),fpp(29,10,16,3)/
     x-7.8782551d-06,-1.0532084d-08,-7.9226723d-09 /
      data fpp(29,10,17,1),fpp(29,10,17,2),fpp(29,10,17,3)/
     x-7.7352437d-06,-6.5668722d-09,-5.4293408d-09 /
      data fpp(29,10,18,1),fpp(29,10,18,2),fpp(29,10,18,3)/
     x-7.7675712d-06,-1.3370958d-08,-6.3599644d-09 /
      data fpp(29,10,19,1),fpp(29,10,19,2),fpp(29,10,19,3)/
     x-8.0441096d-06,-1.4746964d-08, 8.6919859d-10 /
      data fpp(29,10,20,1),fpp(29,10,20,2),fpp(29,10,20,3)/
     x-8.4339996d-06,-9.3756772d-09, 1.4883170d-08 /
      data fpp(29,10,21,1),fpp(29,10,21,2),fpp(29,10,21,3)/
     x-8.4339996d-06,-9.3756772d-09, 1.4915890d-08 /
      data fpp(29,10,22,1),fpp(29,10,22,2),fpp(29,10,22,3)/
     x-8.0441096d-06,-1.4746964d-08, 7.3831701d-10 /
      data fpp(29,10,23,1),fpp(29,10,23,2),fpp(29,10,23,3)/
     x-7.7675712d-06,-1.3370958d-08,-5.8691585d-09 /
      data fpp(29,11, 1,1),fpp(29,11, 1,2),fpp(29,11, 1,3)/
     x-1.2439532d-05, 4.0283049d-11, 2.8895406d-10 /
      data fpp(29,11, 2,1),fpp(29,11, 2,2),fpp(29,11, 2,3)/
     x-1.4310766d-05, 4.3598074d-09, 5.9220919d-09 /
      data fpp(29,11, 3,1),fpp(29,11, 3,2),fpp(29,11, 3,3)/
     x-1.5651915d-05, 9.1610765d-09, 1.8022678d-08 /
      data fpp(29,11, 4,1),fpp(29,11, 4,2),fpp(29,11, 4,3)/
     x-1.5651915d-05, 9.1610765d-09, 1.7970919d-08 /
      data fpp(29,11, 5,1),fpp(29,11, 5,2),fpp(29,11, 5,3)/
     x-1.4310766d-05, 4.3598074d-09, 6.1291301d-09 /
      data fpp(29,11, 6,1),fpp(29,11, 6,2),fpp(29,11, 6,3)/
     x-1.2439532d-05, 4.0283049d-11,-4.8743924d-10 /
      data fpp(29,11, 7,1),fpp(29,11, 7,2),fpp(29,11, 7,3)/
     x-1.0579839d-05, 1.1303441d-09,-4.1793731d-09 /
      data fpp(29,11, 8,1),fpp(29,11, 8,2),fpp(29,11, 8,3)/
     x-9.0719731d-06,-4.5107477d-09,-6.7950682d-09 /
      data fpp(29,11, 9,1),fpp(29,11, 9,2),fpp(29,11, 9,3)/
     x-8.1152396d-06,-5.0393567d-10,-4.6403540d-09 /
      data fpp(29,11,10,1),fpp(29,11,10,2),fpp(29,11,10,3)/
     x-7.7915590d-06,-2.3190116d-09,-4.6435159d-09 /
      data fpp(29,11,11,1),fpp(29,11,11,2),fpp(29,11,11,3)/
     x-7.7191319d-06, 1.5274429d-10,-7.8558245d-10 /
      data fpp(29,11,12,1),fpp(29,11,12,2),fpp(29,11,12,3)/
     x-7.7987930d-06,-4.1451243d-09,-4.2141543d-09 /
      data fpp(29,11,13,1),fpp(29,11,13,2),fpp(29,11,13,3)/
     x-7.8039641d-06,-1.6144130d-09,-3.5780040d-10 /
      data fpp(29,11,14,1),fpp(29,11,14,2),fpp(29,11,14,3)/
     x-7.6082087d-06,-3.8656136d-09,-6.3546441d-09 /
      data fpp(29,11,15,1),fpp(29,11,15,2),fpp(29,11,15,3)/
     x-7.3070907d-06,-1.0268651d-09,-4.2236231d-09 /
      data fpp(29,11,16,1),fpp(29,11,16,2),fpp(29,11,16,3)/
     x-7.0046105d-06,-9.9492754d-10,-6.7508634d-09 /
      data fpp(29,11,17,1),fpp(29,11,17,2),fpp(29,11,17,3)/
     x-6.8103606d-06,-4.9998172d-09,-1.0772923d-08 /
      data fpp(29,11,18,1),fpp(29,11,18,2),fpp(29,11,18,3)/
     x-6.7868170d-06, 1.1248016d-09,-4.1574430d-09 /
      data fpp(29,11,19,1),fpp(29,11,19,2),fpp(29,11,19,3)/
     x-7.1103629d-06, 3.0653836d-09, 3.4026954d-09 /
      data fpp(29,11,20,1),fpp(29,11,20,2),fpp(29,11,20,3)/
     x-7.6609231d-06, 1.3026389d-09, 1.4546661d-08 /
      data fpp(29,11,21,1),fpp(29,11,21,2),fpp(29,11,21,3)/
     x-7.6609231d-06, 1.3026389d-09, 1.4658669d-08 /
      data fpp(29,11,22,1),fpp(29,11,22,2),fpp(29,11,22,3)/
     x-7.1103629d-06, 3.0653836d-09, 2.9546661d-09 /
      data fpp(29,11,23,1),fpp(29,11,23,2),fpp(29,11,23,3)/
     x-6.7868170d-06, 1.1248016d-09,-2.4773331d-09 /
      data fpp(29,12, 1,1),fpp(29,12, 1,2),fpp(29,12, 1,3)/
     x-1.3742394d-05, 1.7231115d-08, 4.1403176d-09 /
      data fpp(29,12, 2,1),fpp(29,12, 2,2),fpp(29,12, 2,3)/
     x-1.5550618d-05, 1.8200183d-08, 8.2193649d-09 /
      data fpp(29,12, 3,1),fpp(29,12, 3,2),fpp(29,12, 3,3)/
     x-1.6780322d-05, 1.8215701d-08, 1.6982223d-08 /
      data fpp(29,12, 4,1),fpp(29,12, 4,2),fpp(29,12, 4,3)/
     x-1.6780322d-05, 1.8215701d-08, 1.6943649d-08 /
      data fpp(29,12, 5,1),fpp(29,12, 5,2),fpp(29,12, 5,3)/
     x-1.5550618d-05, 1.8200183d-08, 8.3736605d-09 /
      data fpp(29,12, 6,1),fpp(29,12, 6,2),fpp(29,12, 6,3)/
     x-1.3742394d-05, 1.7231115d-08, 3.5617091d-09 /
      data fpp(29,12, 7,1),fpp(29,12, 7,2),fpp(29,12, 7,3)/
     x-1.1831451d-05, 9.6230433d-09,-4.6204967d-09 /
      data fpp(29,12, 8,1),fpp(29,12, 8,2),fpp(29,12, 8,3)/
     x-9.8897606d-06, 7.9156715d-09,-3.0797222d-09 /
      data fpp(29,12, 9,1),fpp(29,12, 9,2),fpp(29,12, 9,3)/
     x-8.8751961d-06, 1.1815297d-09,-7.0606146d-09 /
      data fpp(29,12,10,1),fpp(29,12,10,2),fpp(29,12,10,3)/
     x-8.1068460d-06, 1.9401316d-09,-4.6778195d-09 /
      data fpp(29,12,11,1),fpp(29,12,11,2),fpp(29,12,11,3)/
     x-7.7623059d-06, 7.0143292d-10,-4.2281076d-09 /
      data fpp(29,12,12,1),fpp(29,12,12,2),fpp(29,12,12,3)/
     x-7.6425171d-06,-1.9409488d-10,-2.4097501d-09 /
      data fpp(29,12,13,1),fpp(29,12,13,2),fpp(29,12,13,3)/
     x-7.4718054d-06,-1.0160562d-09,-4.1328918d-09 /
      data fpp(29,12,14,1),fpp(29,12,14,2),fpp(29,12,14,3)/
     x-7.2577136d-06,-1.0865580d-10,-5.0586825d-09 /
      data fpp(29,12,15,1),fpp(29,12,15,2),fpp(29,12,15,3)/
     x-6.9329413d-06,-3.0214458d-09,-5.6323780d-09 /
      data fpp(29,12,16,1),fpp(29,12,16,2),fpp(29,12,16,3)/
     x-6.6688356d-06,-3.4882062d-09,-8.4118055d-09 /
      data fpp(29,12,17,1),fpp(29,12,17,2),fpp(29,12,17,3)/
     x-6.4487837d-06, 2.5661412d-09,-8.7203999d-09 /
      data fpp(29,12,18,1),fpp(29,12,18,2),fpp(29,12,18,3)/
     x-6.4663177d-06, 2.8717516d-09,-4.7065950d-09 /
      data fpp(29,12,19,1),fpp(29,12,19,2),fpp(29,12,19,3)/
     x-6.7798890d-06, 8.4854300d-09, 3.5467799d-09 /
      data fpp(29,12,20,1),fpp(29,12,20,2),fpp(29,12,20,3)/
     x-7.3273978d-06, 1.0165122d-08, 1.4519475d-08 /
      data fpp(29,12,21,1),fpp(29,12,21,2),fpp(29,12,21,3)/
     x-7.3273978d-06, 1.0165122d-08, 1.4668184d-08 /
      data fpp(29,12,22,1),fpp(29,12,22,2),fpp(29,12,22,3)/
     x-6.7798890d-06, 8.4854300d-09, 2.9519475d-09 /
      data fpp(29,12,23,1),fpp(29,12,23,2),fpp(29,12,23,3)/
     x-6.4663177d-06, 2.8717516d-09,-2.4759738d-09 /
      data fpp(29,13, 1,1),fpp(29,13, 1,2),fpp(29,13, 1,3)/
     x-1.4730637d-05, 1.5035257d-08, 6.7718709d-09 /
      data fpp(29,13, 2,1),fpp(29,13, 2,2),fpp(29,13, 2,3)/
     x-1.6290505d-05, 1.8839459d-08, 9.4562583d-09 /
      data fpp(29,13, 3,1),fpp(29,13, 3,2),fpp(29,13, 3,3)/
     x-1.7317724d-05, 1.9976118d-08, 1.5403096d-08 /
      data fpp(29,13, 4,1),fpp(29,13, 4,2),fpp(29,13, 4,3)/
     x-1.7317724d-05, 1.9976118d-08, 1.5062583d-08 /
      data fpp(29,13, 5,1),fpp(29,13, 5,2),fpp(29,13, 5,3)/
     x-1.6290505d-05, 1.8839459d-08, 1.0818311d-08 /
      data fpp(29,13, 6,1),fpp(29,13, 6,2),fpp(29,13, 6,3)/
     x-1.4730637d-05, 1.5035257d-08, 1.6641722d-09 /
      data fpp(29,13, 7,1),fpp(29,13, 7,2),fpp(29,13, 7,3)/
     x-1.2913655d-05, 1.4377483d-08, 5.2499978d-10 /
      data fpp(29,13, 8,1),fpp(29,13, 8,2),fpp(29,13, 8,3)/
     x-1.1157001d-05, 8.8480618d-09,-3.7641714d-09 /
      data fpp(29,13, 9,1),fpp(29,13, 9,2),fpp(29,13, 9,3)/
     x-9.6633104d-06, 7.7778170d-09,-3.4683143d-09 /
      data fpp(29,13,10,1),fpp(29,13,10,2),fpp(29,13,10,3)/
     x-8.5861736d-06, 5.5848516d-10,-6.3625713d-09 /
      data fpp(29,13,11,1),fpp(29,13,11,2),fpp(29,13,11,3)/
     x-7.8576274d-06,-2.9584760d-09,-7.0814003d-09 /
      data fpp(29,13,12,1),fpp(29,13,12,2),fpp(29,13,12,3)/
     x-7.4150467d-06,-1.0784962d-09,-1.3118275d-09 /
      data fpp(29,13,13,1),fpp(29,13,13,2),fpp(29,13,13,3)/
     x-7.1644427d-06,-6.3213622d-09,-5.6712898d-09 /
      data fpp(29,13,14,1),fpp(29,13,14,2),fpp(29,13,14,3)/
     x-6.8895859d-06,-7.6997632d-09,-6.0030131d-09 /
      data fpp(29,13,15,1),fpp(29,13,15,2),fpp(29,13,15,3)/
     x-6.6524679d-06,-4.8873516d-09,-6.3166576d-09 /
      data fpp(29,13,16,1),fpp(29,13,16,2),fpp(29,13,16,3)/
     x-6.5186292d-06,-3.0522478d-09,-4.7303565d-09 /
      data fpp(29,13,17,1),fpp(29,13,17,2),fpp(29,13,17,3)/
     x-6.5175317d-06,-5.2647475d-09,-1.0761917d-08 /
      data fpp(29,13,18,1),fpp(29,13,18,2),fpp(29,13,18,3)/
     x-6.6430366d-06,-6.1180810d-10,-2.2197729d-10 /
      data fpp(29,13,19,1),fpp(29,13,19,2),fpp(29,13,19,3)/
     x-7.0291579d-06,-1.0071035d-09,-3.5017428d-10 /
      data fpp(29,13,20,1),fpp(29,13,20,2),fpp(29,13,20,3)/
     x-7.4641724d-06, 6.0368744d-09, 1.3622674d-08 /
      data fpp(29,13,21,1),fpp(29,13,21,2),fpp(29,13,21,3)/
     x-7.4641724d-06, 6.0368744d-09, 1.3307064d-08 /
      data fpp(29,13,22,1),fpp(29,13,22,2),fpp(29,13,22,3)/
     x-7.0291579d-06,-1.0071035d-09, 9.1226744d-10 /
      data fpp(29,13,23,1),fpp(29,13,23,2),fpp(29,13,23,3)/
     x-6.6430366d-06,-6.1180810d-10,-4.9561337d-09 /
      data fpp(29,14, 1,1),fpp(29,14, 1,2),fpp(29,14, 1,3)/
     x-1.5016853d-05, 1.2627859d-08, 6.4611085d-09 /
      data fpp(29,14, 2,1),fpp(29,14, 2,2),fpp(29,14, 2,3)/
     x-1.6308801d-05, 1.4441981d-08, 8.5777830d-09 /
      data fpp(29,14, 3,1),fpp(29,14, 3,2),fpp(29,14, 3,3)/
     x-1.7082191d-05, 1.5879826d-08, 1.3227759d-08 /
      data fpp(29,14, 4,1),fpp(29,14, 4,2),fpp(29,14, 4,3)/
     x-1.7082191d-05, 1.5879826d-08, 1.3027830d-08 /
      data fpp(29,14, 5,1),fpp(29,14, 5,2),fpp(29,14, 5,3)/
     x-1.6308801d-05, 1.4441981d-08, 9.3774996d-09 /
      data fpp(29,14, 6,1),fpp(29,14, 6,2),fpp(29,14, 6,3)/
     x-1.5016853d-05, 1.2627859d-08, 3.4621712d-09 /
      data fpp(29,14, 7,1),fpp(29,14, 7,2),fpp(29,14, 7,3)/
     x-1.3442777d-05, 1.0867025d-08, 7.7381540d-10 /
      data fpp(29,14, 8,1),fpp(29,14, 8,2),fpp(29,14, 8,3)/
     x-1.1748615d-05, 1.0692081d-08,-5.5743285d-10 /
      data fpp(29,14, 9,1),fpp(29,14, 9,2),fpp(29,14, 9,3)/
     x-1.0206666d-05, 3.7072022d-09,-4.5440840d-09 /
      data fpp(29,14,10,1),fpp(29,14,10,2),fpp(29,14,10,3)/
     x-8.7045042d-06, 1.8259277d-09,-5.2662311d-09 /
      data fpp(29,14,11,1),fpp(29,14,11,2),fpp(29,14,11,3)/
     x-7.9797977d-06,-8.6752901d-10,-4.3909915d-09 /
      data fpp(29,14,12,1),fpp(29,14,12,2),fpp(29,14,12,3)/
     x-7.2743427d-06,-7.4919203d-09,-7.1698030d-09 /
      data fpp(29,14,13,1),fpp(29,14,13,2),fpp(29,14,13,3)/
     x-6.8324841d-06,-3.6984951d-09,-2.9297965d-09 /
      data fpp(29,14,14,1),fpp(29,14,14,2),fpp(29,14,14,3)/
     x-6.5635953d-06,-5.0922914d-09,-5.1110111d-09 /
      data fpp(29,14,15,1),fpp(29,14,15,2),fpp(29,14,15,3)/
     x-6.4402792d-06,-7.4291478d-09,-6.6261591d-09 /
      data fpp(29,14,16,1),fpp(29,14,16,2),fpp(29,14,16,3)/
     x-6.4818471d-06,-8.3028026d-09,-4.3843523d-09 /
      data fpp(29,14,17,1),fpp(29,14,17,2),fpp(29,14,17,3)/
     x-6.6371835d-06,-5.5071513d-09,-5.8364315d-09 /
      data fpp(29,14,18,1),fpp(29,14,18,2),fpp(29,14,18,3)/
     x-6.9496467d-06,-6.4245192d-09,-2.2699216d-09 /
      data fpp(29,14,19,1),fpp(29,14,19,2),fpp(29,14,19,3)/
     x-7.3743284d-06,-4.4570159d-09, 2.9161181d-09 /
      data fpp(29,14,20,1),fpp(29,14,20,2),fpp(29,14,20,3)/
     x-7.7713511d-06,-1.0312619d-08, 8.6054494d-09 /
      data fpp(29,14,21,1),fpp(29,14,21,2),fpp(29,14,21,3)/
     x-7.7713511d-06,-1.0312619d-08, 8.7255927d-09 /
      data fpp(29,14,22,1),fpp(29,14,22,2),fpp(29,14,22,3)/
     x-7.3743284d-06,-4.4570159d-09, 2.4355449d-09 /
      data fpp(29,14,23,1),fpp(29,14,23,2),fpp(29,14,23,3)/
     x-6.9496467d-06,-6.4245192d-09,-4.6777247d-10 /
      data fpp(29,15, 1,1),fpp(29,15, 1,2),fpp(29,15, 1,3)/
     x-1.4508833d-05, 1.2453309d-08, 4.9159181d-09 /
      data fpp(29,15, 2,1),fpp(29,15, 2,2),fpp(29,15, 2,3)/
     x-1.5517358d-05, 1.3392618d-08, 6.6681639d-09 /
      data fpp(29,15, 3,1),fpp(29,15, 3,2),fpp(29,15, 3,3)/
     x-1.6087906d-05, 1.2504577d-08, 1.0411426d-08 /
      data fpp(29,15, 4,1),fpp(29,15, 4,2),fpp(29,15, 4,3)/
     x-1.6087906d-05, 1.2504577d-08, 1.0431639d-08 /
      data fpp(29,15, 5,1),fpp(29,15, 5,2),fpp(29,15, 5,3)/
     x-1.5517358d-05, 1.3392618d-08, 6.5873149d-09 /
      data fpp(29,15, 6,1),fpp(29,15, 6,2),fpp(29,15, 6,3)/
     x-1.4508833d-05, 1.2453309d-08, 5.2191017d-09 /
      data fpp(29,15, 7,1),fpp(29,15, 7,2),fpp(29,15, 7,3)/
     x-1.3220723d-05, 8.1544159d-09, 2.5362783d-09 /
      data fpp(29,15, 8,1),fpp(29,15, 8,2),fpp(29,15, 8,3)/
     x-1.1789680d-05, 2.3836136d-09,-3.3642149d-09 /
      data fpp(29,15, 9,1),fpp(29,15, 9,2),fpp(29,15, 9,3)/
     x-1.0392373d-05, 1.3933740d-09,-1.0794188d-09 /
      data fpp(29,15,10,1),fpp(29,15,10,2),fpp(29,15,10,3)/
     x-9.1365835d-06,-1.8621961d-09,-4.3181098d-09 /
      data fpp(29,15,11,1),fpp(29,15,11,2),fpp(29,15,11,3)/
     x-8.1026876d-06,-5.5714080d-09,-5.6481419d-09 /
      data fpp(29,15,12,1),fpp(29,15,12,2),fpp(29,15,12,3)/
     x-7.3081361d-06,-4.9538225d-09,-3.0893225d-09 /
      data fpp(29,15,13,1),fpp(29,15,13,2),fpp(29,15,13,3)/
     x-6.7505055d-06,-8.8846574d-09,-5.9945682d-09 /
      data fpp(29,15,14,1),fpp(29,15,14,2),fpp(29,15,14,3)/
     x-6.5612973d-06,-7.9310711d-09,-2.9324048d-09 /
      data fpp(29,15,15,1),fpp(29,15,15,2),fpp(29,15,15,3)/
     x-6.2898908d-06,-7.3960571d-09,-6.2758127d-09 /
      data fpp(29,15,16,1),fpp(29,15,16,2),fpp(29,15,16,3)/
     x-6.3505055d-06,-5.7365418d-09,-1.9643444d-09 /
      data fpp(29,15,17,1),fpp(29,15,17,2),fpp(29,15,17,3)/
     x-6.6299223d-06,-8.7066473d-09,-3.8668098d-09 /
      data fpp(29,15,18,1),fpp(29,15,18,2),fpp(29,15,18,3)/
     x-6.9862839d-06,-9.6901150d-09,-5.6841645d-10 /
      data fpp(29,15,19,1),fpp(29,15,19,2),fpp(29,15,19,3)/
     x-7.3891466d-06,-1.1164833d-08, 1.4047560d-10 /
      data fpp(29,15,20,1),fpp(29,15,20,2),fpp(29,15,20,3)/
     x-7.6802096d-06,-6.7863976d-09, 6.0065140d-09 /
      data fpp(29,15,21,1),fpp(29,15,21,2),fpp(29,15,21,3)/
     x-7.6802096d-06,-6.7863976d-09, 5.9102201d-09 /
      data fpp(29,15,22,1),fpp(29,15,22,2),fpp(29,15,22,3)/
     x-7.3891466d-06,-1.1164833d-08, 5.2565140d-10 /
      data fpp(29,15,23,1),fpp(29,15,23,2),fpp(29,15,23,3)/
     x-6.9862839d-06,-9.6901150d-09,-2.0128257d-09 /
      data fpp(29,16, 1,1),fpp(29,16, 1,2),fpp(29,16, 1,3)/
     x-1.3335763d-05, 3.5589070d-09, 1.6777103d-09 /
      data fpp(29,16, 2,1),fpp(29,16, 2,2),fpp(29,16, 2,3)/
     x-1.4062522d-05, 3.9875456d-09, 3.6445793d-09 /
      data fpp(29,16, 3,1),fpp(29,16, 3,2),fpp(29,16, 3,3)/
     x-1.4476828d-05, 6.1018660d-09, 7.7439724d-09 /
      data fpp(29,16, 4,1),fpp(29,16, 4,2),fpp(29,16, 4,3)/
     x-1.4476828d-05, 6.1018660d-09, 7.9457931d-09 /
      data fpp(29,16, 5,1),fpp(29,16, 5,2),fpp(29,16, 5,3)/
     x-1.4062522d-05, 3.9875456d-09, 2.8372968d-09 /
      data fpp(29,16, 6,1),fpp(29,16, 6,2),fpp(29,16, 6,3)/
     x-1.3335763d-05, 3.5589070d-09, 4.7050196d-09 /
      data fpp(29,16, 7,1),fpp(29,16, 7,2),fpp(29,16, 7,3)/
     x-1.2418995d-05, 4.5153112d-09, 2.3426247d-09 /
      data fpp(29,16, 8,1),fpp(29,16, 8,2),fpp(29,16, 8,3)/
     x-1.1370305d-05, 3.7734644d-09,-2.0755185d-09 /
      data fpp(29,16, 9,1),fpp(29,16, 9,2),fpp(29,16, 9,3)/
     x-1.0268376d-05, 2.7193018d-09,-4.0550879d-11 /
      data fpp(29,16,10,1),fpp(29,16,10,2),fpp(29,16,10,3)/
     x-9.2111911d-06,-3.7714331d-10,-3.7622780d-09 /
      data fpp(29,16,11,1),fpp(29,16,11,2),fpp(29,16,11,3)/
     x-8.2659282d-06,-8.4683910d-10,-2.9103370d-09 /
      data fpp(29,16,12,1),fpp(29,16,12,2),fpp(29,16,12,3)/
     x-7.4843996d-06,-2.6927899d-09,-2.5963739d-09 /
      data fpp(29,16,13,1),fpp(29,16,13,2),fpp(29,16,13,3)/
     x-6.9279376d-06,-2.7628753d-09,-4.7041673d-09 /
      data fpp(29,16,14,1),fpp(29,16,14,2),fpp(29,16,14,3)/
     x-6.5540194d-06,-5.1834242d-09,-2.5869567d-09 /
      data fpp(29,16,15,1),fpp(29,16,15,2),fpp(29,16,15,3)/
     x-6.3589458d-06,-4.9866239d-09,-2.9480058d-09 /
      data fpp(29,16,16,1),fpp(29,16,16,2),fpp(29,16,16,3)/
     x-6.3420311d-06,-4.7510300d-09,-3.6210202d-09 /
      data fpp(29,16,17,1),fpp(29,16,17,2),fpp(29,16,17,3)/
     x-6.5121442d-06,-1.6662595d-09,-5.6791332d-10 /
      data fpp(29,16,18,1),fpp(29,16,18,2),fpp(29,16,18,3)/
     x-6.7670909d-06,-2.8150207d-09,-1.0732650d-10 /
      data fpp(29,16,19,1),fpp(29,16,19,2),fpp(29,16,19,3)/
     x-7.0410873d-06,-4.8836531d-09, 9.9721933d-10 /
      data fpp(29,16,20,1),fpp(29,16,20,2),fpp(29,16,20,3)/
     x-7.2359824d-06,-1.0541790d-08, 2.1184492d-09 /
      data fpp(29,16,21,1),fpp(29,16,21,2),fpp(29,16,21,3)/
     x-7.2359824d-06,-1.0541790d-08, 2.1460428d-09 /
      data fpp(29,16,22,1),fpp(29,16,22,2),fpp(29,16,22,3)/
     x-7.0410873d-06,-4.8836531d-09, 8.8684492d-10 /
      data fpp(29,16,23,1),fpp(29,16,23,2),fpp(29,16,23,3)/
     x-6.7670909d-06,-2.8150207d-09, 3.0657754d-10 /
      data fpp(29,17, 1,1),fpp(29,17, 1,2),fpp(29,17, 1,3)/
     x-1.1738408d-05,-2.6889365d-09, 6.0224802d-10 /
      data fpp(29,17, 2,1),fpp(29,17, 2,2),fpp(29,17, 2,3)/
     x-1.2164615d-05,-5.3428007d-09, 1.7955040d-09 /
      data fpp(29,17, 3,1),fpp(29,17, 3,2),fpp(29,17, 3,3)/
     x-1.2449845d-05,-6.9120408d-09, 4.2157362d-09 /
      data fpp(29,17, 4,1),fpp(29,17, 4,2),fpp(29,17, 4,3)/
     x-1.2449845d-05,-6.9120408d-09, 4.4550396d-09 /
      data fpp(29,17, 5,1),fpp(29,17, 5,2),fpp(29,17, 5,3)/
     x-1.2164615d-05,-5.3428007d-09, 8.3829029d-10 /
      data fpp(29,17, 6,1),fpp(29,17, 6,2),fpp(29,17, 6,3)/
     x-1.1738408d-05,-2.6889365d-09, 4.1917993d-09 /
      data fpp(29,17, 7,1),fpp(29,17, 7,2),fpp(29,17, 7,3)/
     x-1.1174429d-05,-2.2156607d-09, 3.9451261d-10 /
      data fpp(29,17, 8,1),fpp(29,17, 8,2),fpp(29,17, 8,3)/
     x-1.0509344d-05, 5.2252882d-10, 2.3015027d-10 /
      data fpp(29,17, 9,1),fpp(29,17, 9,2),fpp(29,17, 9,3)/
     x-9.7773774d-06,-2.7058126d-10,-1.3151137d-09 /
      data fpp(29,17,10,1),fpp(29,17,10,2),fpp(29,17,10,3)/
     x-9.0677525d-06, 3.3707694d-09,-9.6969547d-10 /
      data fpp(29,17,11,1),fpp(29,17,11,2),fpp(29,17,11,3)/
     x-8.4145651d-06, 2.9587644d-09,-8.0610440d-10 /
      data fpp(29,17,12,1),fpp(29,17,12,2),fpp(29,17,12,3)/
     x-7.8297094d-06, 3.7249819d-09,-1.8058869d-09 /
      data fpp(29,17,13,1),fpp(29,17,13,2),fpp(29,17,13,3)/
     x-7.3734151d-06, 1.9361587d-09,-3.9703480d-09 /
      data fpp(29,17,14,1),fpp(29,17,14,2),fpp(29,17,14,3)/
     x-7.0034917d-06, 4.6647681d-09,-3.1272122d-10 /
      data fpp(29,17,15,1),fpp(29,17,15,2),fpp(29,17,15,3)/
     x-6.7521241d-06, 3.3425526d-09,-7.7876716d-10 /
      data fpp(29,17,16,1),fpp(29,17,16,2),fpp(29,17,16,3)/
     x-6.6438013d-06, 7.4066193d-10,-2.5722102d-09 /
      data fpp(29,17,17,1),fpp(29,17,17,2),fpp(29,17,17,3)/
     x-6.6211973d-06,-2.6283148d-09,-9.3239224d-10 /
      data fpp(29,17,18,1),fpp(29,17,18,2),fpp(29,17,18,3)/
     x-6.6667155d-06,-3.0498021d-09, 3.0177912d-10 /
      data fpp(29,17,19,1),fpp(29,17,19,2),fpp(29,17,19,3)/
     x-6.7658804d-06,-5.3005549d-09,-2.7472422d-10 /
      data fpp(29,17,20,1),fpp(29,17,20,2),fpp(29,17,20,3)/
     x-6.8092431d-06,-5.0464411d-09, 7.9711778d-10 /
      data fpp(29,17,21,1),fpp(29,17,21,2),fpp(29,17,21,3)/
     x-6.8092431d-06,-5.0464411d-09, 7.4600878d-10 /
      data fpp(29,17,22,1),fpp(29,17,22,2),fpp(29,17,22,3)/
     x-6.7658804d-06,-5.3005549d-09,-7.0288222d-11 /
      data fpp(29,17,23,1),fpp(29,17,23,2),fpp(29,17,23,3)/
     x-6.6667155d-06,-3.0498021d-09,-4.6485589d-10 /
      data fpp(29,18, 1,1),fpp(29,18, 1,2),fpp(29,18, 1,3)/
     x-9.9323511d-06,-4.8031610d-09, 7.6853910d-10 /
      data fpp(29,18, 2,1),fpp(29,18, 2,2),fpp(29,18, 2,3)/
     x-1.0119368d-05,-6.6163426d-09, 9.6292181d-10 /
      data fpp(29,18, 3,1),fpp(29,18, 3,2),fpp(29,18, 3,3)/
     x-1.0281625d-05,-8.4537026d-09, 1.3797737d-09 /
      data fpp(29,18, 4,1),fpp(29,18, 4,2),fpp(29,18, 4,3)/
     x-1.0281625d-05,-8.4537026d-09, 1.3792181d-09 /
      data fpp(29,18, 5,1),fpp(29,18, 5,2),fpp(29,18, 5,3)/
     x-1.0119368d-05,-6.6163426d-09, 9.6514422d-10 /
      data fpp(29,18, 6,1),fpp(29,18, 6,2),fpp(29,18, 6,3)/
     x-9.9323511d-06,-4.8031610d-09, 7.6020505d-10 /
      data fpp(29,18, 7,1),fpp(29,18, 7,2),fpp(29,18, 7,3)/
     x-9.6936516d-06,-1.6526684d-09, 1.9940356d-09 /
      data fpp(29,18, 8,1),fpp(29,18, 8,2),fpp(29,18, 8,3)/
     x-9.4071207d-06, 1.3642034d-10,-2.7363474d-09 /
      data fpp(29,18, 9,1),fpp(29,18, 9,2),fpp(29,18, 9,3)/
     x-9.0978552d-06, 4.3630232d-09, 2.9513539d-09 /
      data fpp(29,18,10,1),fpp(29,18,10,2),fpp(29,18,10,3)/
     x-8.7694596d-06, 4.8940659d-09,-3.0690683d-09 /
      data fpp(29,18,11,1),fpp(29,18,11,2),fpp(29,18,11,3)/
     x-8.4664798d-06, 7.0117816d-09, 3.3249191d-09 /
      data fpp(29,18,12,1),fpp(29,18,12,2),fpp(29,18,12,3)/
     x-8.1325698d-06, 5.7928623d-09,-4.2306083d-09 /
      data fpp(29,18,13,1),fpp(29,18,13,2),fpp(29,18,13,3)/
     x-7.8685608d-06, 7.0182404d-09, 1.5975141d-09 /
      data fpp(29,18,14,1),fpp(29,18,14,2),fpp(29,18,14,3)/
     x-7.6327003d-06, 4.5243520d-09,-2.1594480d-09 /
      data fpp(29,18,15,1),fpp(29,18,15,2),fpp(29,18,15,3)/
     x-7.4434094d-06, 3.6164135d-09, 1.0402781d-09 /
      data fpp(29,18,16,1),fpp(29,18,16,2),fpp(29,18,16,3)/
     x-7.3008924d-06, 1.7883823d-09,-2.0016643d-09 /
      data fpp(29,18,17,1),fpp(29,18,17,2),fpp(29,18,17,3)/
     x-7.2003133d-06, 1.7951850d-10, 9.6637919d-10 /
      data fpp(29,18,18,1),fpp(29,18,18,2),fpp(29,18,18,3)/
     x-7.1312153d-06,-2.9857708d-09,-1.8638524d-09 /
      data fpp(29,18,19,1),fpp(29,18,19,2),fpp(29,18,19,3)/
     x-7.1055255d-06,-3.9141272d-09, 4.8903059d-10 /
      data fpp(29,18,20,1),fpp(29,18,20,2),fpp(29,18,20,3)/
     x-7.0777617d-06,-5.2724454d-09,-9.2269923d-11 /
      data fpp(29,18,21,1),fpp(29,18,21,2),fpp(29,18,21,3)/
     x-7.0777617d-06,-5.2724454d-09, 3.2294473d-11 /
      data fpp(29,18,22,1),fpp(29,18,22,2),fpp(29,18,22,3)/
     x-7.1055255d-06,-3.9141272d-09,-9.2269923d-12 /
      data fpp(29,18,23,1),fpp(29,18,23,2),fpp(29,18,23,3)/
     x-7.1312153d-06,-2.9857708d-09, 4.6134962d-12 /
      data fpp(29,19, 1,1),fpp(29,19, 1,2),fpp(29,19, 1,3)/
     x-8.3315392d-06,-8.0984195d-09, 2.0656048d-22 /
      data fpp(29,19, 2,1),fpp(29,19, 2,2),fpp(29,19, 2,3)/
     x-8.3315392d-06,-1.0191829d-08,-4.6767737d-23 /
      data fpp(29,19, 3,1),fpp(29,19, 3,2),fpp(29,19, 3,3)/
     x-8.3315392d-06,-1.3273149d-08, 6.7211180d-23 /
      data fpp(29,19, 4,1),fpp(29,19, 4,2),fpp(29,19, 4,3)/
     x-8.3315392d-06,-1.3273149d-08,-8.3858320d-23 /
      data fpp(29,19, 5,1),fpp(29,19, 5,2),fpp(29,19, 5,3)/
     x-8.3315392d-06,-1.0191829d-08, 4.3799611d-23 /
      data fpp(29,19, 6,1),fpp(29,19, 6,2),fpp(29,19, 6,3)/
     x-8.3315392d-06,-8.0984195d-09, 1.6023203d-23 /
      data fpp(29,19, 7,1),fpp(29,19, 7,2),fpp(29,19, 7,3)/
     x-8.3315392d-06,-3.1736658d-09, 1.5434440d-22 /
      data fpp(29,19, 8,1),fpp(29,19, 8,2),fpp(29,19, 8,3)/
     x-8.3315392d-06,-1.0682102d-09, 4.5765006d-23 /
      data fpp(29,19, 9,1),fpp(29,19, 9,2),fpp(29,19, 9,3)/
     x-8.3315392d-06, 6.8184884d-09,-1.1982234d-23 /
      data fpp(29,19,10,1),fpp(29,19,10,2),fpp(29,19,10,3)/
     x-8.3315392d-06, 7.0529671d-09,-7.9037658d-23 /
      data fpp(29,19,11,1),fpp(29,19,11,2),fpp(29,19,11,3)/
     x-8.3315392d-06, 1.0994109d-08, 5.7371278d-24 /
      data fpp(29,19,12,1),fpp(29,19,12,2),fpp(29,19,12,3)/
     x-8.3315392d-06, 9.1035688d-09,-1.0575846d-22 /
      data fpp(29,19,13,1),fpp(29,19,13,2),fpp(29,19,13,3)/
     x-8.3315392d-06, 1.1990880d-08,-6.6691263d-23 /
      data fpp(29,19,14,1),fpp(29,19,14,2),fpp(29,19,14,3)/
     x-8.3315392d-06, 7.2378240d-09, 2.3615861d-23 /
      data fpp(29,19,15,1),fpp(29,19,15,2),fpp(29,19,15,3)/
     x-8.3315392d-06, 6.1917932d-09, 6.3861886d-23 /
      data fpp(29,19,16,1),fpp(29,19,16,2),fpp(29,19,16,3)/
     x-8.3315392d-06, 4.1058088d-09, 7.1312980d-23 /
      data fpp(29,19,17,1),fpp(29,19,17,2),fpp(29,19,17,3)/
     x-8.3315392d-06, 1.9102407d-09,-1.0381274d-22 /
      data fpp(29,19,18,1),fpp(29,19,18,2),fpp(29,19,18,3)/
     x-8.3315392d-06,-3.0071146d-09, 5.8651697d-23 /
      data fpp(29,19,19,1),fpp(29,19,19,2),fpp(29,19,19,3)/
     x-8.3315392d-06,-3.0429364d-09, 2.2791185d-24 /
      data fpp(29,19,20,1),fpp(29,19,20,2),fpp(29,19,20,3)/
     x-8.3315392d-06,-3.8637773d-09,-4.7919680d-23 /
      data fpp(29,19,21,1),fpp(29,19,21,2),fpp(29,19,21,3)/
     x-8.3315392d-06,-3.8637773d-09, 9.0214830d-24 /
      data fpp(29,19,22,1),fpp(29,19,22,2),fpp(29,19,22,3)/
     x-8.3315392d-06,-3.0429364d-09,-9.0658935d-23 /
      data fpp(29,19,23,1),fpp(29,19,23,2),fpp(29,19,23,3)/
     x-8.3315392d-06,-3.0071146d-09,-1.5540411d-22 /
      data fpp(30, 1, 1,1),fpp(30, 1, 1,2),fpp(30, 1, 1,3)/
     x-7.2547838d-06, 1.0608215d-09, 3.8193631d-23 /
      data fpp(30, 1, 2,1),fpp(30, 1, 2,2),fpp(30, 1, 2,3)/
     x-7.2547838d-06,-2.9279321d-10,-2.0891710d-23 /
      data fpp(30, 1, 3,1),fpp(30, 1, 3,2),fpp(30, 1, 3,3)/
     x-7.2547838d-06,-4.6179476d-10, 2.5158726d-23 /
      data fpp(30, 1, 4,1),fpp(30, 1, 4,2),fpp(30, 1, 4,3)/
     x-7.2547838d-06,-4.6179476d-10,-2.7641771d-23 /
      data fpp(30, 1, 5,1),fpp(30, 1, 5,2),fpp(30, 1, 5,3)/
     x-7.2547838d-06,-2.9279321d-10,-4.7302964d-23 /
      data fpp(30, 1, 6,1),fpp(30, 1, 6,2),fpp(30, 1, 6,3)/
     x-7.2547838d-06, 1.0608215d-09, 3.5988296d-23 /
      data fpp(30, 1, 7,1),fpp(30, 1, 7,2),fpp(30, 1, 7,3)/
     x-7.2547838d-06, 9.8272502d-09, 7.8055938d-23 /
      data fpp(30, 1, 8,1),fpp(30, 1, 8,2),fpp(30, 1, 8,3)/
     x-7.2547838d-06, 1.2083234d-08, 4.4525047d-23 /
      data fpp(30, 1, 9,1),fpp(30, 1, 9,2),fpp(30, 1, 9,3)/
     x-7.2547838d-06, 1.6966248d-08,-2.9068345d-24 /
      data fpp(30, 1,10,1),fpp(30, 1,10,2),fpp(30, 1,10,3)/
     x-7.2547838d-06, 2.3870760d-08,-5.7467659d-23 /
      data fpp(30, 1,11,1),fpp(30, 1,11,2),fpp(30, 1,11,3)/
     x-7.2547838d-06, 2.5865116d-08, 3.7136178d-23 /
      data fpp(30, 1,12,1),fpp(30, 1,12,2),fpp(30, 1,12,3)/
     x-7.2547838d-06, 2.6907644d-08,-2.3418523d-23 /
      data fpp(30, 1,13,1),fpp(30, 1,13,2),fpp(30, 1,13,3)/
     x-7.2547838d-06, 2.6017760d-08,-5.4816556d-23 /
      data fpp(30, 1,14,1),fpp(30, 1,14,2),fpp(30, 1,14,3)/
     x-7.2547838d-06, 2.4899960d-08,-8.9185532d-24 /
      data fpp(30, 1,15,1),fpp(30, 1,15,2),fpp(30, 1,15,3)/
     x-7.2547838d-06, 2.1937031d-08, 1.7573080d-23 /
      data fpp(30, 1,16,1),fpp(30, 1,16,2),fpp(30, 1,16,3)/
     x-7.2547838d-06, 1.8038852d-08, 3.1325507d-23 /
      data fpp(30, 1,17,1),fpp(30, 1,17,2),fpp(30, 1,17,3)/
     x-7.2547838d-06, 1.2231972d-08,-3.2374756d-23 /
      data fpp(30, 1,18,1),fpp(30, 1,18,2),fpp(30, 1,18,3)/
     x-7.2547838d-06, 6.2854951d-09, 5.7117626d-23 /
      data fpp(30, 1,19,1),fpp(30, 1,19,2),fpp(30, 1,19,3)/
     x-7.2547838d-06, 3.9563732d-09, 8.9009113d-24 /
      data fpp(30, 1,20,1),fpp(30, 1,20,2),fpp(30, 1,20,3)/
     x-7.2547838d-06, 1.9575683d-09,-4.8554813d-23 /
      data fpp(30, 1,21,1),fpp(30, 1,21,2),fpp(30, 1,21,3)/
     x-7.2547838d-06, 1.9575683d-09, 6.3200047d-23 /
      data fpp(30, 1,22,1),fpp(30, 1,22,2),fpp(30, 1,22,3)/
     x-7.2547838d-06, 3.9563732d-09,-7.3005994d-23 /
      data fpp(30, 1,23,1),fpp(30, 1,23,2),fpp(30, 1,23,3)/
     x-7.2547838d-06, 6.2854951d-09,-7.8284306d-23 /
      data fpp(30, 2, 1,1),fpp(30, 2, 1,2),fpp(30, 2, 1,3)/
     x-1.8100815d-05, 1.8783570d-09,-4.6433712d-10 /
      data fpp(30, 2, 2,1),fpp(30, 2, 2,2),fpp(30, 2, 2,3)/
     x-2.2682373d-05, 5.8558642d-10,-7.1325757d-11 /
      data fpp(30, 2, 3,1),fpp(30, 2, 3,2),fpp(30, 2, 3,3)/
     x-2.5412230d-05,-7.6410479d-11, 7.4964015d-10 /
      data fpp(30, 2, 4,1),fpp(30, 2, 4,2),fpp(30, 2, 4,3)/
     x-2.5412230d-05,-7.6410479d-11, 7.8674243d-10 /
      data fpp(30, 2, 5,1),fpp(30, 2, 5,2),fpp(30, 2, 5,3)/
     x-2.2682373d-05, 5.8558642d-10,-2.1973488d-10 /
      data fpp(30, 2, 6,1),fpp(30, 2, 6,2),fpp(30, 2, 6,3)/
     x-1.8100815d-05, 1.8783570d-09, 9.2197087d-11 /
      data fpp(30, 2, 7,1),fpp(30, 2, 7,2),fpp(30, 2, 7,3)/
     x-1.2328615d-05, 6.3454996d-09,-1.4905347d-10 /
      data fpp(30, 2, 8,1),fpp(30, 2, 8,2),fpp(30, 2, 8,3)/
     x-5.9042645d-06, 7.8335325d-09, 5.0401679d-10 /
      data fpp(30, 2, 9,1),fpp(30, 2, 9,2),fpp(30, 2, 9,3)/
     x 3.8505017d-07, 1.0067504d-08,-1.8670137d-09 /
      data fpp(30, 2,10,1),fpp(30, 2,10,2),fpp(30, 2,10,3)/
     x 5.4907315d-06, 1.3258480d-08, 9.6403803d-10 /
      data fpp(30, 2,11,1),fpp(30, 2,11,2),fpp(30, 2,11,3)/
     x 9.3459972d-06, 1.4269768d-08,-1.9891384d-09 /
      data fpp(30, 2,12,1),fpp(30, 2,12,2),fpp(30, 2,12,3)/
     x 1.0729413d-05, 1.5184711d-08, 9.9251569d-10 /
      data fpp(30, 2,13,1),fpp(30, 2,13,2),fpp(30, 2,13,3)/
     x 1.0003020d-05, 1.4964480d-08,-1.9809243d-09 /
      data fpp(30, 2,14,1),fpp(30, 2,14,2),fpp(30, 2,14,3)/
     x 7.6693773d-06, 1.5200079d-08, 9.3118164d-10 /
      data fpp(30, 2,15,1),fpp(30, 2,15,2),fpp(30, 2,15,3)/
     x 3.2003746d-06, 1.4125938d-08,-1.7438022d-09 /
      data fpp(30, 2,16,1),fpp(30, 2,16,2),fpp(30, 2,16,3)/
     x-2.5068392d-06, 1.2922295d-08, 4.4027258d-11 /
      data fpp(30, 2,17,1),fpp(30, 2,17,2),fpp(30, 2,17,3)/
     x-8.6483475d-06, 1.0536055d-08, 1.5676932d-09 /
      data fpp(30, 2,18,1),fpp(30, 2,18,2),fpp(30, 2,18,3)/
     x-1.4235150d-05, 7.4290098d-09,-3.1480003d-10 /
      data fpp(30, 2,19,1),fpp(30, 2,19,2),fpp(30, 2,19,3)/
     x-1.8855501d-05, 6.0872535d-09,-3.0849306d-10 /
      data fpp(30, 2,20,1),fpp(30, 2,20,2),fpp(30, 2,20,3)/
     x-2.1370296d-05, 5.0848634d-09, 1.5487723d-09 /
      data fpp(30, 2,21,1),fpp(30, 2,21,2),fpp(30, 2,21,3)/
     x-2.1370296d-05, 5.0848634d-09, 1.5079297d-09 /
      data fpp(30, 2,22,1),fpp(30, 2,22,2),fpp(30, 2,22,3)/
     x-1.8855501d-05, 6.0872535d-09,-1.4512277d-10 /
      data fpp(30, 2,23,1),fpp(30, 2,23,2),fpp(30, 2,23,3)/
     x-1.4235150d-05, 7.4290098d-09,-9.2743861d-10 /
      data fpp(30, 3, 1,1),fpp(30, 3, 1,2),fpp(30, 3, 1,3)/
     x-2.0291351d-05, 3.4257505d-09, 2.9609938d-10 /
      data fpp(30, 3, 2,1),fpp(30, 3, 2,2),fpp(30, 3, 2,3)/
     x-3.1153517d-05,-2.0495525d-09, 9.0780124d-10 /
      data fpp(30, 3, 3,1),fpp(30, 3, 3,2),fpp(30, 3, 3,3)/
     x-3.8003362d-05,-5.2325633d-09, 2.0726957d-09 /
      data fpp(30, 3, 4,1),fpp(30, 3, 4,2),fpp(30, 3, 4,3)/
     x-3.8003362d-05,-5.2325633d-09, 2.3280124d-09 /
      data fpp(30, 3, 5,1),fpp(30, 3, 5,2),fpp(30, 3, 5,3)/
     x-3.1153517d-05,-2.0495525d-09,-1.1346562d-10 /
      data fpp(30, 3, 6,1),fpp(30, 3, 6,2),fpp(30, 3, 6,3)/
     x-2.0291351d-05, 3.4257505d-09, 4.1258501d-09 /
      data fpp(30, 3, 7,1),fpp(30, 3, 7,2),fpp(30, 3, 7,3)/
     x-6.4560286d-06, 7.9075146d-10,-4.3899348d-09 /
      data fpp(30, 3, 8,1),fpp(30, 3, 8,2),fpp(30, 3, 8,3)/
     x 7.9473979d-06, 4.5826362d-09, 1.4338891d-09 /
      data fpp(30, 3, 9,1),fpp(30, 3, 9,2),fpp(30, 3, 9,3)/
     x 2.1297314d-05, 2.7637372d-09,-1.3456215d-09 /
      data fpp(30, 3,10,1),fpp(30, 3,10,2),fpp(30, 3,10,3)/
     x 3.2377058d-05, 1.0953213d-09,-2.0514029d-09 /
      data fpp(30, 3,11,1),fpp(30, 3,11,2),fpp(30, 3,11,3)/
     x 3.9722002d-05, 1.0558134d-09,-2.4487669d-09 /
      data fpp(30, 3,12,1),fpp(30, 3,12,2),fpp(30, 3,12,3)/
     x 4.3110516d-05, 2.3535107d-09,-1.5352959d-10 /
      data fpp(30, 3,13,1),fpp(30, 3,13,2),fpp(30, 3,13,3)/
     x 4.1086004d-05, 4.1243205d-09,-2.9371148d-09 /
      data fpp(30, 3,14,1),fpp(30, 3,14,2),fpp(30, 3,14,3)/
     x 3.4813992d-05, 4.2997230d-09,-9.8011342d-11 /
      data fpp(30, 3,15,1),fpp(30, 3,15,2),fpp(30, 3,15,3)/
     x 2.4386641d-05, 5.5592185d-09,-2.6708399d-09 /
      data fpp(30, 3,16,1),fpp(30, 3,16,2),fpp(30, 3,16,3)/
     x 1.1307989d-05, 8.2719659d-09,-1.2186292d-09 /
      data fpp(30, 3,17,1),fpp(30, 3,17,2),fpp(30, 3,17,3)/
     x-3.7632586d-06, 1.1623807d-08, 1.5453567d-09 /
      data fpp(30, 3,18,1),fpp(30, 3,18,2),fpp(30, 3,18,3)/
     x-1.7832840d-05, 1.1998466d-08, 1.0372026d-09 /
      data fpp(30, 3,19,1),fpp(30, 3,19,2),fpp(30, 3,19,3)/
     x-2.9732720d-05, 7.6946127d-09, 3.0583298d-10 /
      data fpp(30, 3,20,1),fpp(30, 3,20,2),fpp(30, 3,20,3)/
     x-3.7525608d-05, 7.7029779d-09, 3.7394655d-09 /
      data fpp(30, 3,21,1),fpp(30, 3,21,2),fpp(30, 3,21,3)/
     x-3.7525608d-05, 7.7029779d-09, 3.6286871d-09 /
      data fpp(30, 3,22,1),fpp(30, 3,22,2),fpp(30, 3,22,3)/
     x-2.9732720d-05, 7.6946127d-09, 7.4894655d-10 /
      data fpp(30, 3,23,1),fpp(30, 3,23,2),fpp(30, 3,23,3)/
     x-1.7832840d-05, 1.1998466d-08,-6.2447327d-10 /
      data fpp(30, 4, 1,1),fpp(30, 4, 1,2),fpp(30, 4, 1,3)/
     x-2.7825731d-06, 2.4186409d-09, 1.8492556d-09 /
      data fpp(30, 4, 2,1),fpp(30, 4, 2,2),fpp(30, 4, 2,3)/
     x-1.6135367d-05, 7.6126235d-09, 2.8014889d-09 /
      data fpp(30, 4, 3,1),fpp(30, 4, 3,2),fpp(30, 4, 3,3)/
     x-2.5189280d-05, 9.0066638d-09, 4.9447889d-09 /
      data fpp(30, 4, 4,1),fpp(30, 4, 4,2),fpp(30, 4, 4,3)/
     x-2.5189280d-05, 9.0066638d-09, 4.7648888d-09 /
      data fpp(30, 4, 5,1),fpp(30, 4, 5,2),fpp(30, 4, 5,3)/
     x-1.6135367d-05, 7.6126235d-09, 3.5210894d-09 /
      data fpp(30, 4, 6,1),fpp(30, 4, 6,2),fpp(30, 4, 6,3)/
     x-2.7825731d-06, 2.4186409d-09,-8.4924624d-10 /
      data fpp(30, 4, 7,1),fpp(30, 4, 7,2),fpp(30, 4, 7,3)/
     x 1.2355599d-05, 2.4914946d-09,-1.2410438d-10 /
      data fpp(30, 4, 8,1),fpp(30, 4, 8,2),fpp(30, 4, 8,3)/
     x 2.6779151d-05,-2.1640773d-09,-4.6543362d-09 /
      data fpp(30, 4, 9,1),fpp(30, 4, 9,2),fpp(30, 4, 9,3)/
     x 3.9310399d-05,-3.1224526d-09, 7.4144925d-10 /
      data fpp(30, 4,10,1),fpp(30, 4,10,2),fpp(30, 4,10,3)/
     x 4.8282992d-05,-5.6397650d-09,-4.3114608d-09 /
      data fpp(30, 4,11,1),fpp(30, 4,11,2),fpp(30, 4,11,3)/
     x 5.3948839d-05,-6.4930214d-09,-1.4956061d-09 /
      data fpp(30, 4,12,1),fpp(30, 4,12,2),fpp(30, 4,12,3)/
     x 5.5700514d-05,-6.5987540d-09,-1.7061147d-09 /
      data fpp(30, 4,13,1),fpp(30, 4,13,2),fpp(30, 4,13,3)/
     x 5.4995323d-05,-7.4617619d-09,-3.6799349d-09 /
      data fpp(30, 4,14,1),fpp(30, 4,14,2),fpp(30, 4,14,3)/
     x 5.0173591d-05,-2.3989710d-09,-1.5741455d-09 /
      data fpp(30, 4,15,1),fpp(30, 4,15,2),fpp(30, 4,15,3)/
     x 4.1785421d-05,-3.6281158d-10,-2.0234831d-09 /
      data fpp(30, 4,16,1),fpp(30, 4,16,2),fpp(30, 4,16,3)/
     x 2.9570855d-05, 1.9898408d-09,-2.3319221d-09 /
      data fpp(30, 4,17,1),fpp(30, 4,17,2),fpp(30, 4,17,3)/
     x 1.4305817d-05, 2.9687166d-09,-6.4882854d-10 /
      data fpp(30, 4,18,1),fpp(30, 4,18,2),fpp(30, 4,18,3)/
     x-2.2722857d-06, 4.5771273d-09,-1.0727638d-09 /
      data fpp(30, 4,19,1),fpp(30, 4,19,2),fpp(30, 4,19,3)/
     x-1.7455406d-05, 1.1134296d-08, 4.9398836d-09 /
      data fpp(30, 4,20,1),fpp(30, 4,20,2),fpp(30, 4,20,3)/
     x-2.7668977d-05, 1.2103225d-08, 5.3132295d-09 /
      data fpp(30, 4,21,1),fpp(30, 4,21,2),fpp(30, 4,21,3)/
     x-2.7668977d-05, 1.2103225d-08, 5.5903697d-09 /
      data fpp(30, 4,22,1),fpp(30, 4,22,2),fpp(30, 4,22,3)/
     x-1.7455406d-05, 1.1134296d-08, 3.8313230d-09 /
      data fpp(30, 4,23,1),fpp(30, 4,23,2),fpp(30, 4,23,3)/
     x-2.2722857d-06, 4.5771273d-09, 3.0843385d-09 /
      data fpp(30, 5, 1,1),fpp(30, 5, 1,2),fpp(30, 5, 1,3)/
     x 1.1618055d-05, 4.8996860d-09, 4.5559695d-10 /
      data fpp(30, 5, 2,1),fpp(30, 5, 2,2),fpp(30, 5, 2,3)/
     x-2.8742337d-09, 7.5990585d-09, 2.5888061d-09 /
      data fpp(30, 5, 3,1),fpp(30, 5, 3,2),fpp(30, 5, 3,3)/
     x-8.2727620d-06, 1.1205908d-08, 7.1891787d-09 /
      data fpp(30, 5, 4,1),fpp(30, 5, 4,2),fpp(30, 5, 4,3)/
     x-8.2727620d-06, 1.1205908d-08, 7.1380610d-09 /
      data fpp(30, 5, 5,1),fpp(30, 5, 5,2),fpp(30, 5, 5,3)/
     x-2.8742337d-09, 7.5990585d-09, 2.7932769d-09 /
      data fpp(30, 5, 6,1),fpp(30, 5, 6,2),fpp(30, 5, 6,3)/
     x 1.1618055d-05, 4.8996860d-09,-3.1116860d-10 /
      data fpp(30, 5, 7,1),fpp(30, 5, 7,2),fpp(30, 5, 7,3)/
     x 2.3462969d-05, 1.2432702d-09,-1.5486025d-09 /
      data fpp(30, 5, 8,1),fpp(30, 5, 8,2),fpp(30, 5, 8,3)/
     x 3.3264589d-05,-1.9263270d-09,-5.4944213d-09 /
      data fpp(30, 5, 9,1),fpp(30, 5, 9,2),fpp(30, 5, 9,3)/
     x 4.0227918d-05,-2.2739270d-09,-4.7371221d-10 /
      data fpp(30, 5,10,1),fpp(30, 5,10,2),fpp(30, 5,10,3)/
     x 4.4736783d-05,-2.5362614d-09,-4.6107299d-09 /
      data fpp(30, 5,11,1),fpp(30, 5,11,2),fpp(30, 5,11,3)/
     x 4.7585727d-05,-5.0837280d-09, 9.1663165d-10 /
      data fpp(30, 5,12,1),fpp(30, 5,12,2),fpp(30, 5,12,3)/
     x 4.8672256d-05,-5.9584949d-09,-5.0557967d-09 /
      data fpp(30, 5,13,1),fpp(30, 5,13,2),fpp(30, 5,13,3)/
     x 4.8927414d-05,-4.2772728d-09, 1.3065553d-09 /
      data fpp(30, 5,14,1),fpp(30, 5,14,2),fpp(30, 5,14,3)/
     x 4.6703863d-05,-6.7038389d-09,-6.1704245d-09 /
      data fpp(30, 5,15,1),fpp(30, 5,15,2),fpp(30, 5,15,3)/
     x 4.3007234d-05,-4.1079722d-09,-6.2485720d-10 /
      data fpp(30, 5,16,1),fpp(30, 5,16,2),fpp(30, 5,16,3)/
     x 3.5905526d-05,-4.2313293d-09,-3.3301467d-09 /
      data fpp(30, 5,17,1),fpp(30, 5,17,2),fpp(30, 5,17,3)/
     x 2.5684999d-05, 5.0132654d-10,-4.0545562d-09 /
      data fpp(30, 5,18,1),fpp(30, 5,18,2),fpp(30, 5,18,3)/
     x 1.2761738d-05, 5.6930252d-09, 1.5483713d-09 /
      data fpp(30, 5,19,1),fpp(30, 5,19,2),fpp(30, 5,19,3)/
     x 2.2363307d-07, 7.7682048d-09, 3.8610709d-09 /
      data fpp(30, 5,20,1),fpp(30, 5,20,2),fpp(30, 5,20,3)/
     x-8.5349852d-06, 9.8841228d-09, 7.0073451d-09 /
      data fpp(30, 5,21,1),fpp(30, 5,21,2),fpp(30, 5,21,3)/
     x-8.5349852d-06, 9.8841228d-09, 7.0474292d-09 /
      data fpp(30, 5,22,1),fpp(30, 5,22,2),fpp(30, 5,22,3)/
     x 2.2363307d-07, 7.7682048d-09, 3.7007345d-09 /
      data fpp(30, 5,23,1),fpp(30, 5,23,2),fpp(30, 5,23,3)/
     x 1.2761738d-05, 5.6930252d-09, 2.1496327d-09 /
      data fpp(30, 6, 1,1),fpp(30, 6, 1,2),fpp(30, 6, 1,3)/
     x 1.2466049d-05, 1.9826151d-09, 4.5406454d-10 /
      data fpp(30, 6, 2,1),fpp(30, 6, 2,2),fpp(30, 6, 2,3)/
     x 7.1078026d-06, 3.9911426d-09, 2.5918709d-09 /
      data fpp(30, 6, 3,1),fpp(30, 6, 3,2),fpp(30, 6, 3,3)/
     x 4.7859302d-06, 6.1697033d-09, 7.1784518d-09 /
      data fpp(30, 6, 4,1),fpp(30, 6, 4,2),fpp(30, 6, 4,3)/
     x 4.7859302d-06, 6.1697033d-09, 7.1687092d-09 /
      data fpp(30, 6, 5,1),fpp(30, 6, 5,2),fpp(30, 6, 5,3)/
     x 7.1078026d-06, 3.9911426d-09, 2.6308415d-09 /
      data fpp(30, 6, 6,1),fpp(30, 6, 6,2),fpp(30, 6, 6,3)/
     x 1.2466049d-05, 1.9826151d-09, 3.0792498d-10 /
      data fpp(30, 6, 7,1),fpp(30, 6, 7,2),fpp(30, 6, 7,3)/
     x 1.8269835d-05,-1.4645753d-09,-3.8625414d-09 /
      data fpp(30, 6, 8,1),fpp(30, 6, 8,2),fpp(30, 6, 8,3)/
     x 2.3611653d-05,-2.1306145d-09,-2.8577595d-09 /
      data fpp(30, 6, 9,1),fpp(30, 6, 9,2),fpp(30, 6, 9,3)/
     x 2.8106004d-05,-5.7818395d-09,-2.7064208d-09 /
      data fpp(30, 6,10,1),fpp(30, 6,10,2),fpp(30, 6,10,3)/
     x 3.1997088d-05,-8.2151894d-09,-4.3165573d-09 /
      data fpp(30, 6,11,1),fpp(30, 6,11,2),fpp(30, 6,11,3)/
     x 3.5033406d-05,-3.1720668d-09, 1.9726502d-09 /
      data fpp(30, 6,12,1),fpp(30, 6,12,2),fpp(30, 6,12,3)/
     x 3.6711453d-05,-5.5672666d-09,-3.5740434d-09 /
      data fpp(30, 6,13,1),fpp(30, 6,13,2),fpp(30, 6,13,3)/
     x 3.6583907d-05,-5.4291468d-09, 3.2352326d-10 /
      data fpp(30, 6,14,1),fpp(30, 6,14,2),fpp(30, 6,14,3)/
     x 3.4350847d-05,-6.7856735d-09,-3.7200497d-09 /
      data fpp(30, 6,15,1),fpp(30, 6,15,2),fpp(30, 6,15,3)/
     x 3.1599282d-05,-7.2052997d-09,-3.4433245d-09 /
      data fpp(30, 6,16,1),fpp(30, 6,16,2),fpp(30, 6,16,3)/
     x 2.7691477d-05,-3.0645238d-09,-5.0665223d-10 /
      data fpp(30, 6,17,1),fpp(30, 6,17,2),fpp(30, 6,17,3)/
     x 2.1718525d-05,-4.9740228d-09,-6.5300666d-09 /
      data fpp(30, 6,18,1),fpp(30, 6,18,2),fpp(30, 6,18,3)/
     x 1.5038530d-05,-3.3492279d-09, 2.6269185d-09 /
      data fpp(30, 6,19,1),fpp(30, 6,19,2),fpp(30, 6,19,3)/
     x 8.9139888d-06,-2.0711483d-10, 2.0223927d-09 /
      data fpp(30, 6,20,1),fpp(30, 6,20,2),fpp(30, 6,20,3)/
     x 4.9864868d-06, 2.3602838d-09, 7.2835108d-09 /
      data fpp(30, 6,21,1),fpp(30, 6,21,2),fpp(30, 6,21,3)/
     x 4.9864868d-06, 2.3602838d-09, 7.1382712d-09 /
      data fpp(30, 6,22,1),fpp(30, 6,22,2),fpp(30, 6,22,3)/
     x 8.9139888d-06,-2.0711483d-10, 2.6033511d-09 /
      data fpp(30, 6,23,1),fpp(30, 6,23,2),fpp(30, 6,23,3)/
     x 1.5038530d-05,-3.3492279d-09, 4.4832446d-10 /
      data fpp(30, 7, 1,1),fpp(30, 7, 1,2),fpp(30, 7, 1,3)/
     x 8.9812594d-06,-6.8301464d-09, 1.3879069d-09 /
      data fpp(30, 7, 2,1),fpp(30, 7, 2,2),fpp(30, 7, 2,3)/
     x 9.5863015d-06,-5.5636290d-09, 2.7241863d-09 /
      data fpp(30, 7, 3,1),fpp(30, 7, 3,2),fpp(30, 7, 3,3)/
     x 1.0914497d-05,-5.8847216d-09, 5.7153480d-09 /
      data fpp(30, 7, 4,1),fpp(30, 7, 4,2),fpp(30, 7, 4,3)/
     x 1.0914497d-05,-5.8847216d-09, 5.4918628d-09 /
      data fpp(30, 7, 5,1),fpp(30, 7, 5,2),fpp(30, 7, 5,3)/
     x 9.5863015d-06,-5.5636290d-09, 3.6181269d-09 /
      data fpp(30, 7, 6,1),fpp(30, 7, 6,2),fpp(30, 7, 6,3)/
     x 8.9812594d-06,-6.8301464d-09,-1.9643705d-09 /
      data fpp(30, 7, 7,1),fpp(30, 7, 7,2),fpp(30, 7, 7,3)/
     x 9.9971064d-06,-7.3849690d-09,-1.7606450d-09 /
      data fpp(30, 7, 8,1),fpp(30, 7, 8,2),fpp(30, 7, 8,3)/
     x 1.2816839d-05,-7.5512149d-09,-2.9930494d-09 /
      data fpp(30, 7, 9,1),fpp(30, 7, 9,2),fpp(30, 7, 9,3)/
     x 1.5960493d-05,-4.5987150d-09,-4.2671573d-09 /
      data fpp(30, 7,10,1),fpp(30, 7,10,2),fpp(30, 7,10,3)/
     x 1.9746645d-05,-6.0298097d-10, 2.0616786d-09 /
      data fpp(30, 7,11,1),fpp(30, 7,11,2),fpp(30, 7,11,3)/
     x 2.2745208d-05,-6.2280049d-09,-3.9795573d-09 /
      data fpp(30, 7,12,1),fpp(30, 7,12,2),fpp(30, 7,12,3)/
     x 2.4424563d-05,-1.7724389d-09, 1.8565505d-09 /
      data fpp(30, 7,13,1),fpp(30, 7,13,2),fpp(30, 7,13,3)/
     x 2.4579612d-05,-4.0061400d-09,-3.4466446d-09 /
      data fpp(30, 7,14,1),fpp(30, 7,14,2),fpp(30, 7,14,3)/
     x 2.2582152d-05,-2.1534673d-09,-6.9971928d-11 /
      data fpp(30, 7,15,1),fpp(30, 7,15,2),fpp(30, 7,15,3)/
     x 1.9805422d-05,-3.0708289d-09,-2.2734676d-09 /
      data fpp(30, 7,16,1),fpp(30, 7,16,2),fpp(30, 7,16,3)/
     x 1.6915202d-05,-7.5105755d-09,-2.8361575d-09 /
      data fpp(30, 7,17,1),fpp(30, 7,17,2),fpp(30, 7,17,3)/
     x 1.3631073d-05,-4.6052355d-09,-4.3819025d-09 /
      data fpp(30, 7,18,1),fpp(30, 7,18,2),fpp(30, 7,18,3)/
     x 1.0653089d-05,-4.2961135d-09, 2.3637673d-09 /
      data fpp(30, 7,19,1),fpp(30, 7,19,2),fpp(30, 7,19,3)/
     x 9.1814216d-06,-6.9397455d-09, 9.2683334d-10 /
      data fpp(30, 7,20,1),fpp(30, 7,20,2),fpp(30, 7,20,3)/
     x 9.2665208d-06,-7.3252581d-09, 5.9288994d-09 /
      data fpp(30, 7,21,1),fpp(30, 7,21,2),fpp(30, 7,21,3)/
     x 9.2665208d-06,-7.3252581d-09, 5.7498852d-09 /
      data fpp(30, 7,22,1),fpp(30, 7,22,2),fpp(30, 7,22,3)/
     x 9.1814216d-06,-6.9397455d-09, 1.6428899d-09 /
      data fpp(30, 7,23,1),fpp(30, 7,23,2),fpp(30, 7,23,3)/
     x 1.0653089d-05,-4.2961135d-09,-3.2144497d-10 /
      data fpp(30, 8, 1,1),fpp(30, 8, 1,2),fpp(30, 8, 1,3)/
     x 7.8601588d-06,-1.0662029d-08, 6.1761307d-10 /
      data fpp(30, 8, 2,1),fpp(30, 8, 2,2),fpp(30, 8, 2,3)/
     x 9.5598753d-06,-1.1736627d-08, 1.7647739d-09 /
      data fpp(30, 8, 3,1),fpp(30, 8, 3,2),fpp(30, 8, 3,3)/
     x 1.0818071d-05,-1.2630817d-08, 4.3232915d-09 /
      data fpp(30, 8, 4,1),fpp(30, 8, 4,2),fpp(30, 8, 4,3)/
     x 1.0818071d-05,-1.2630817d-08, 4.1477385d-09 /
      data fpp(30, 8, 5,1),fpp(30, 8, 5,2),fpp(30, 8, 5,3)/
     x 9.5598753d-06,-1.1736627d-08, 2.4669859d-09 /
      data fpp(30, 8, 6,1),fpp(30, 8, 6,2),fpp(30, 8, 6,3)/
     x 7.8601588d-06,-1.0662029d-08,-2.0156821d-09 /
      data fpp(30, 8, 7,1),fpp(30, 8, 7,2),fpp(30, 8, 7,3)/
     x 6.9411290d-06,-4.9955488d-09,-4.0425742d-10 /
      data fpp(30, 8, 8,1),fpp(30, 8, 8,2),fpp(30, 8, 8,3)/
     x 7.6014310d-06,-3.6645261d-09,-2.3672882d-09 /
      data fpp(30, 8, 9,1),fpp(30, 8, 9,2),fpp(30, 8, 9,3)/
     x 9.3195763d-06,-5.8233004d-09,-2.1265898d-09 /
      data fpp(30, 8,10,1),fpp(30, 8,10,2),fpp(30, 8,10,3)/
     x 1.1023913d-05,-7.3728867d-09,-1.1263525d-09 /
      data fpp(30, 8,11,1),fpp(30, 8,11,2),fpp(30, 8,11,3)/
     x 1.3359884d-05,-1.9159137d-09, 6.3199976d-10 /
      data fpp(30, 8,12,1),fpp(30, 8,12,2),fpp(30, 8,12,3)/
     x 1.4192453d-05,-5.3429778d-09,-1.4016466d-09 /
      data fpp(30, 8,13,1),fpp(30, 8,13,2),fpp(30, 8,13,3)/
     x 1.4792631d-05,-2.5462932d-09,-1.0254135d-09 /
      data fpp(30, 8,14,1),fpp(30, 8,14,2),fpp(30, 8,14,3)/
     x 1.4009572d-05,-2.6004574d-09,-4.9669941d-10 /
      data fpp(30, 8,15,1),fpp(30, 8,15,2),fpp(30, 8,15,3)/
     x 1.2851743d-05,-4.5113845d-09,-2.9877888d-09 /
      data fpp(30, 8,16,1),fpp(30, 8,16,2),fpp(30, 8,16,3)/
     x 1.1356156d-05,-2.8931742d-09, 4.4785480d-10 /
      data fpp(30, 8,17,1),fpp(30, 8,17,2),fpp(30, 8,17,3)/
     x 9.5654794d-06,-6.6050351d-09,-4.8036304d-09 /
      data fpp(30, 8,18,1),fpp(30, 8,18,2),fpp(30, 8,18,3)/
     x 7.7963107d-06,-9.4663180d-09, 7.6666667d-10 /
      data fpp(30, 8,19,1),fpp(30, 8,19,2),fpp(30, 8,19,3)/
     x 7.5034335d-06,-8.0339032d-09, 1.7369637d-09 /
      data fpp(30, 8,20,1),fpp(30, 8,20,2),fpp(30, 8,20,3)/
     x 7.9221996d-06,-9.0592513d-09, 4.2854785d-09 /
      data fpp(30, 8,21,1),fpp(30, 8,21,2),fpp(30, 8,21,3)/
     x 7.9221996d-06,-9.0592513d-09, 4.2750825d-09 /
      data fpp(30, 8,22,1),fpp(30, 8,22,2),fpp(30, 8,22,3)/
     x 7.5034335d-06,-8.0339032d-09, 1.7785479d-09 /
      data fpp(30, 8,23,1),fpp(30, 8,23,2),fpp(30, 8,23,3)/
     x 7.7963107d-06,-9.4663180d-09, 6.1072607d-10 /
      data fpp(30, 9, 1,1),fpp(30, 9, 1,2),fpp(30, 9, 1,3)/
     x 8.3243607d-06,-4.5217363d-09,-6.2754168d-10 /
      data fpp(30, 9, 2,1),fpp(30, 9, 2,2),fpp(30, 9, 2,3)/
     x 9.7018344d-06,-7.4898639d-09, 7.5508336d-10 /
      data fpp(30, 9, 3,1),fpp(30, 9, 3,2),fpp(30, 9, 3,3)/
     x 1.1209193d-05,-9.5920100d-09, 3.6072082d-09 /
      data fpp(30, 9, 4,1),fpp(30, 9, 4,2),fpp(30, 9, 4,3)/
     x 1.1209193d-05,-9.5920100d-09, 3.8008336d-09 /
      data fpp(30, 9, 5,1),fpp(30, 9, 5,2),fpp(30, 9, 5,3)/
     x 9.7018344d-06,-7.4898639d-09,-1.9418182d-11 /
      data fpp(30, 9, 6,1),fpp(30, 9, 6,2),fpp(30, 9, 6,3)/
     x 8.3243607d-06,-4.5217363d-09, 2.2768391d-09 /
      data fpp(30, 9, 7,1),fpp(30, 9, 7,2),fpp(30, 9, 7,3)/
     x 7.2939089d-06,-8.6328358d-09,-3.0879383d-09 /
      data fpp(30, 9, 8,1),fpp(30, 9, 8,2),fpp(30, 9, 8,3)/
     x 6.5627442d-06,-7.7906809d-09,-1.9250861d-09 /
      data fpp(30, 9, 9,1),fpp(30, 9, 9,2),fpp(30, 9, 9,3)/
     x 6.2491158d-06,-2.1080833d-09,-1.2117174d-09 /
      data fpp(30, 9,10,1),fpp(30, 9,10,2),fpp(30, 9,10,3)/
     x 6.8303793d-06, 9.4527841d-11, 7.7195572d-10 /
      data fpp(30, 9,11,1),fpp(30, 9,11,2),fpp(30, 9,11,3)/
     x 7.7073233d-06,-4.1083402d-09,-1.8761055d-09 /
      data fpp(30, 9,12,1),fpp(30, 9,12,2),fpp(30, 9,12,3)/
     x 8.1418333d-06,-8.5564989d-10, 7.3246612d-10 /
      data fpp(30, 9,13,1),fpp(30, 9,13,2),fpp(30, 9,13,3)/
     x 8.9918094d-06,-3.8086871d-09,-1.0537590d-09 /
      data fpp(30, 9,14,1),fpp(30, 9,14,2),fpp(30, 9,14,3)/
     x 9.1426277d-06,-5.4447031d-09,-2.5174301d-09 /
      data fpp(30, 9,15,1),fpp(30, 9,15,2),fpp(30, 9,15,3)/
     x 9.4273673d-06,-2.8836329d-09,-8.7652071d-10 /
      data fpp(30, 9,16,1),fpp(30, 9,16,2),fpp(30, 9,16,3)/
     x 9.0378171d-06,-4.9167278d-09, 2.3512919d-11 /
      data fpp(30, 9,17,1),fpp(30, 9,17,2),fpp(30, 9,17,3)/
     x 8.1964848d-06,-4.9746240d-09,-5.2175310d-09 /
      data fpp(30, 9,18,1),fpp(30, 9,18,2),fpp(30, 9,18,3)/
     x 7.5609893d-06,-5.8386143d-09, 2.8466109d-09 /
      data fpp(30, 9,19,1),fpp(30, 9,19,2),fpp(30, 9,19,3)/
     x 7.4643538d-06,-8.9246417d-09,-1.6891277d-10 /
      data fpp(30, 9,20,1),fpp(30, 9,20,2),fpp(30, 9,20,3)/
     x 6.9458704d-06,-1.0437737d-08, 3.8290401d-09 /
      data fpp(30, 9,21,1),fpp(30, 9,21,2),fpp(30, 9,21,3)/
     x 6.9458704d-06,-1.0437737d-08, 3.5973359d-09 /
      data fpp(30, 9,22,1),fpp(30, 9,22,2),fpp(30, 9,22,3)/
     x 7.4643538d-06,-8.9246417d-09, 7.5790401d-10 /
      data fpp(30, 9,23,1),fpp(30, 9,23,2),fpp(30, 9,23,3)/
     x 7.5609893d-06,-5.8386143d-09,-6.2895201d-10 /
      data fpp(30,10, 1,1),fpp(30,10, 1,2),fpp(30,10, 1,3)/
     x 9.3784620d-06,-7.2510256d-09,-6.2278195d-10 /
      data fpp(30,10, 2,1),fpp(30,10, 2,2),fpp(30,10, 2,3)/
     x 1.0914522d-05,-6.3039175d-09, 7.4556391d-10 /
      data fpp(30,10, 3,1),fpp(30,10, 3,2),fpp(30,10, 3,3)/
     x 1.2303888d-05,-3.0011428d-09, 3.6405263d-09 /
      data fpp(30,10, 4,1),fpp(30,10, 4,2),fpp(30,10, 4,3)/
     x 1.2303888d-05,-3.0011428d-09, 3.7056391d-09 /
      data fpp(30,10, 5,1),fpp(30,10, 5,2),fpp(30,10, 5,3)/
     x 1.0914522d-05,-6.3039175d-09, 4.8511293d-10 /
      data fpp(30,10, 6,1),fpp(30,10, 6,2),fpp(30,10, 6,3)/
     x 9.3784620d-06,-7.2510256d-09, 3.5390920d-10 /
      data fpp(30,10, 7,1),fpp(30,10, 7,2),fpp(30,10, 7,3)/
     x 6.7468643d-06,-2.4731081d-09,-1.9007497d-09 /
      data fpp(30,10, 8,1),fpp(30,10, 8,2),fpp(30,10, 8,3)/
     x 5.6477215d-06,-1.1727504d-09, 1.2490898d-09 /
      data fpp(30,10, 9,1),fpp(30,10, 9,2),fpp(30,10, 9,3)/
     x 5.2738573d-06,-3.7443663d-09,-3.0956094d-09 /
      data fpp(30,10,10,1),fpp(30,10,10,2),fpp(30,10,10,3)/
     x 5.6920686d-06,-5.0052246d-09,-8.6665215d-10 /
      data fpp(30,10,11,1),fpp(30,10,11,2),fpp(30,10,11,3)/
     x 6.3288561d-06, 3.4927447d-10, 5.6221801d-10 /
      data fpp(30,10,12,1),fpp(30,10,12,2),fpp(30,10,12,3)/
     x 7.0949481d-06,-3.2344227d-09,-1.3822199d-09 /
      data fpp(30,10,13,1),fpp(30,10,13,2),fpp(30,10,13,3)/
     x 7.4202595d-06,-2.1895836d-10,-1.0333385d-09 /
      data fpp(30,10,14,1),fpp(30,10,14,2),fpp(30,10,14,3)/
     x 7.3677772d-06, 3.7926995d-10,-4.8442629d-10 /
      data fpp(30,10,15,1),fpp(30,10,15,2),fpp(30,10,15,3)/
     x 7.5047300d-06,-1.9540839d-09,-3.0289564d-09 /
      data fpp(30,10,16,1),fpp(30,10,16,2),fpp(30,10,16,3)/
     x 7.7491275d-06,-1.4399145d-09, 6.0025189d-10 /
      data fpp(30,10,17,1),fpp(30,10,17,2),fpp(30,10,17,3)/
     x 7.6176218d-06,-3.4964689d-09,-5.3720512d-09 /
      data fpp(30,10,18,1),fpp(30,10,18,2),fpp(30,10,18,3)/
     x 7.1537856d-06,-3.1792247d-09, 2.8879528d-09 /
      data fpp(30,10,19,1),fpp(30,10,19,2),fpp(30,10,19,3)/
     x 7.1570548d-06,-4.2675299d-09,-1.7975988d-10 /
      data fpp(30,10,20,1),fpp(30,10,20,2),fpp(30,10,20,3)/
     x 7.4119998d-06,-3.1898015d-09, 3.8310868d-09 /
      data fpp(30,10,21,1),fpp(30,10,21,2),fpp(30,10,21,3)/
     x 7.4119998d-06,-3.1898015d-09, 3.5966196d-09 /
      data fpp(30,10,22,1),fpp(30,10,22,2),fpp(30,10,22,3)/
     x 7.1570548d-06,-4.2675299d-09, 7.5810868d-10 /
      data fpp(30,10,23,1),fpp(30,10,23,2),fpp(30,10,23,3)/
     x 7.1537856d-06,-3.1792247d-09,-6.2905434d-10 /
      data fpp(30,11, 1,1),fpp(30,11, 1,2),fpp(30,11, 1,3)/
     x 1.0104766d-05, 3.5258387d-09, 1.5368986d-09 /
      data fpp(30,11, 2,1),fpp(30,11, 2,2),fpp(30,11, 2,3)/
     x 1.2150383d-05, 2.7055338d-09, 1.9262027d-09 /
      data fpp(30,11, 3,1),fpp(30,11, 3,2),fpp(30,11, 3,3)/
     x 1.3060957d-05,-2.4034189d-09, 2.7582905d-09 /
      data fpp(30,11, 4,1),fpp(30,11, 4,2),fpp(30,11, 4,3)/
     x 1.3060957d-05,-2.4034189d-09, 2.7620272d-09 /
      data fpp(30,11, 5,1),fpp(30,11, 5,2),fpp(30,11, 5,3)/
     x 1.2150383d-05, 2.7055338d-09, 1.9112559d-09 /
      data fpp(30,11, 6,1),fpp(30,11, 6,2),fpp(30,11, 6,3)/
     x 1.0104766d-05, 3.5258387d-09, 1.5929492d-09 /
      data fpp(30,11, 7,1),fpp(30,11, 7,2),fpp(30,11, 7,3)/
     x 7.9749194d-06, 5.2526806d-10,-2.2830528d-09 /
      data fpp(30,11, 8,1),fpp(30,11, 8,2),fpp(30,11, 8,3)/
     x 5.6909865d-06, 4.8168264d-10, 1.5392621d-09 /
      data fpp(30,11, 9,1),fpp(30,11, 9,2),fpp(30,11, 9,3)/
     x 4.4626198d-06,-9.1445132d-10,-3.8739955d-09 /
      data fpp(30,11,10,1),fpp(30,11,10,2),fpp(30,11,10,3)/
     x 4.9607795d-06, 1.9263707d-09, 1.9567200d-09 /
      data fpp(30,11,11,1),fpp(30,11,11,2),fpp(30,11,11,3)/
     x 5.9745659d-06,-3.2887577d-09,-3.9528846d-09 /
      data fpp(30,11,12,1),fpp(30,11,12,2),fpp(30,11,12,3)/
     x 6.7793965d-06, 1.7933405d-09, 1.8548183d-09 /
      data fpp(30,11,13,1),fpp(30,11,13,2),fpp(30,11,13,3)/
     x 7.6819821d-06,-1.3154795d-09,-3.4663888d-09 /
      data fpp(30,11,14,1),fpp(30,11,14,2),fpp(30,11,14,3)/
     x 7.4941044d-06,-2.0723766d-09, 1.0736809d-11 /
      data fpp(30,11,15,1),fpp(30,11,15,2),fpp(30,11,15,3)/
     x 7.1935454d-06,-1.3000314d-09,-2.5765584d-09 /
      data fpp(30,11,16,1),fpp(30,11,16,2),fpp(30,11,16,3)/
     x 6.6373052d-06,-1.3236142d-09,-1.7045030d-09 /
      data fpp(30,11,17,1),fpp(30,11,17,2),fpp(30,11,17,3)/
     x 6.1951803d-06, 9.6049976d-10,-2.6054295d-09 /
      data fpp(30,11,18,1),fpp(30,11,18,2),fpp(30,11,18,3)/
     x 5.7334085d-06, 5.5551323d-10, 1.2622086d-10 /
      data fpp(30,11,19,1),fpp(30,11,19,2),fpp(30,11,19,3)/
     x 5.8051814d-06, 1.9947613d-09, 2.1005460d-09 /
      data fpp(30,11,20,1),fpp(30,11,20,2),fpp(30,11,20,3)/
     x 6.1104615d-06,-8.0305736d-10, 3.4715951d-09 /
      data fpp(30,11,21,1),fpp(30,11,21,2),fpp(30,11,21,3)/
     x 6.1104615d-06,-8.0305736d-10, 3.5349417d-09 /
      data fpp(30,11,22,1),fpp(30,11,22,2),fpp(30,11,22,3)/
     x 5.8051814d-06, 1.9947613d-09, 1.8471595d-09 /
      data fpp(30,11,23,1),fpp(30,11,23,2),fpp(30,11,23,3)/
     x 5.7334085d-06, 5.5551323d-10, 1.0764202d-09 /
      data fpp(30,12, 1,1),fpp(30,12, 1,2),fpp(30,12, 1,3)/
     x 1.0996197d-05,-8.5232921d-10,-6.2542016d-10 /
      data fpp(30,12, 2,1),fpp(30,12, 2,2),fpp(30,12, 2,3)/
     x 1.2935309d-05, 1.4817824d-09, 7.5084032d-10 /
      data fpp(30,12, 3,1),fpp(30,12, 3,2),fpp(30,12, 3,3)/
     x 1.3220161d-05, 6.6148184d-09, 3.6220589d-09 /
      data fpp(30,12, 4,1),fpp(30,12, 4,2),fpp(30,12, 4,3)/
     x 1.3220161d-05, 6.6148184d-09, 3.7584032d-09 /
      data fpp(30,12, 5,1),fpp(30,12, 5,2),fpp(30,12, 5,3)/
     x 1.2935309d-05, 1.4817824d-09, 2.0546320d-10 /
      data fpp(30,12, 6,1),fpp(30,12, 6,2),fpp(30,12, 6,3)/
     x 1.0996197d-05,-8.5232921d-10, 1.4197440d-09 /
      data fpp(30,12, 7,1),fpp(30,12, 7,2),fpp(30,12, 7,3)/
     x 8.8107254d-06, 3.7203584d-10, 1.1556062d-10 /
      data fpp(30,12, 8,1),fpp(30,12, 8,2),fpp(30,12, 8,3)/
     x 7.1948803d-06,-7.5398012d-10,-1.8819865d-09 /
      data fpp(30,12, 9,1),fpp(30,12, 9,2),fpp(30,12, 9,3)/
     x 5.9675981d-06, 1.4021716d-09, 1.4123854d-09 /
      data fpp(30,12,10,1),fpp(30,12,10,2),fpp(30,12,10,3)/
     x 5.6584230d-06,-2.7002583d-09,-3.7675552d-09 /
      data fpp(30,12,11,1),fpp(30,12,11,2),fpp(30,12,11,3)/
     x 5.8611529d-06, 8.0575630d-10, 1.6578354d-09 /
      data fpp(30,12,12,1),fpp(30,12,12,2),fpp(30,12,12,3)/
     x 6.6862586d-06,-3.9389394d-09,-2.8637865d-09 /
      data fpp(30,12,13,1),fpp(30,12,13,2),fpp(30,12,13,3)/
     x 6.9009027d-06,-5.1912380d-10,-2.2026895d-09 /
      data fpp(30,12,14,1),fpp(30,12,14,2),fpp(30,12,14,3)/
     x 7.0488568d-06, 1.9102367d-09,-3.2545542d-10 /
      data fpp(30,12,15,1),fpp(30,12,15,2),fpp(30,12,15,3)/
     x 6.5714706d-06, 1.1542094d-09,-2.4954888d-09 /
      data fpp(30,12,16,1),fpp(30,12,16,2),fpp(30,12,16,3)/
     x 6.2744178d-06, 7.3437119d-10,-1.6925894d-09 /
      data fpp(30,12,17,1),fpp(30,12,17,2),fpp(30,12,17,3)/
     x 5.4893918d-06,-3.4553009d-10,-2.7341537d-09 /
      data fpp(30,12,18,1),fpp(30,12,18,2),fpp(30,12,18,3)/
     x 5.5431588d-06, 9.5717183d-10, 6.2920403d-10 /
      data fpp(30,12,19,1),fpp(30,12,19,2),fpp(30,12,19,3)/
     x 5.6099445d-06, 2.2884845d-09, 2.1733756d-10 /
      data fpp(30,12,20,1),fpp(30,12,20,2),fpp(30,12,20,3)/
     x 6.0036989d-06, 6.4020309d-09, 4.5014457d-09 /
      data fpp(30,12,21,1),fpp(30,12,21,2),fpp(30,12,21,3)/
     x 6.0036989d-06, 6.4020309d-09, 4.3869940d-09 /
      data fpp(30,12,22,1),fpp(30,12,22,2),fpp(30,12,22,3)/
     x 5.6099445d-06, 2.2884845d-09, 6.7514457d-10 /
      data fpp(30,12,23,1),fpp(30,12,23,2),fpp(30,12,23,3)/
     x 5.5431588d-06, 9.5717183d-10,-1.0875723d-09 /
      data fpp(30,13, 1,1),fpp(30,13, 1,2),fpp(30,13, 1,3)/
     x 1.1505319d-05, 5.8834781d-09,-1.6587122d-10 /
      data fpp(30,13, 2,1),fpp(30,13, 2,2),fpp(30,13, 2,3)/
     x 1.3245253d-05, 3.3673368d-09, 8.3174244d-10 /
      data fpp(30,13, 3,1),fpp(30,13, 3,2),fpp(30,13, 3,3)/
     x 1.3803862d-05,-5.5854756d-11, 2.8389014d-09 /
      data fpp(30,13, 4,1),fpp(30,13, 4,2),fpp(30,13, 4,3)/
     x 1.3803862d-05,-5.5854756d-11, 3.0674244d-09 /
      data fpp(30,13, 5,1),fpp(30,13, 5,2),fpp(30,13, 5,3)/
     x 1.3245253d-05, 3.3673368d-09,-8.2349537d-11 /
      data fpp(30,13, 6,1),fpp(30,13, 6,2),fpp(30,13, 6,3)/
     x 1.1505319d-05, 5.8834781d-09, 3.2619737d-09 /
      data fpp(30,13, 7,1),fpp(30,13, 7,2),fpp(30,13, 7,3)/
     x 1.0026827d-05, 3.9865886d-09,-9.6554529d-10 /
      data fpp(30,13, 8,1),fpp(30,13, 8,2),fpp(30,13, 8,3)/
     x 8.8185007d-06, 2.5342378d-09, 6.0020745d-10 /
      data fpp(30,13, 9,1),fpp(30,13, 9,2),fpp(30,13, 9,3)/
     x 7.6966552d-06, 1.3057648d-09,-1.4352845d-09 /
      data fpp(30,13,10,1),fpp(30,13,10,2),fpp(30,13,10,3)/
     x 6.8280868d-06, 2.8746626d-09,-8.5906937d-10 /
      data fpp(30,13,11,1),fpp(30,13,11,2),fpp(30,13,11,3)/
     x 6.2838137d-06, 6.5732495d-11,-1.1284380d-09 /
      data fpp(30,13,12,1),fpp(30,13,12,2),fpp(30,13,12,3)/
     x 6.4075233d-06, 1.9624171d-09,-6.2717860d-10 /
      data fpp(30,13,13,1),fpp(30,13,13,2),fpp(30,13,13,3)/
     x 6.4172213d-06,-2.6080253d-09,-2.3628476d-09 /
      data fpp(30,13,14,1),fpp(30,13,14,2),fpp(30,13,14,3)/
     x 6.0397929d-06,-5.5685700d-09,-1.9214310d-09 /
      data fpp(30,13,15,1),fpp(30,13,15,2),fpp(30,13,15,3)/
     x 5.9662339d-06,-3.3168062d-09,-1.9514283d-09 /
      data fpp(30,13,16,1),fpp(30,13,16,2),fpp(30,13,16,3)/
     x 6.0943146d-06,-1.6138706d-09,-2.2728559d-09 /
      data fpp(30,13,17,1),fpp(30,13,17,2),fpp(30,13,17,3)/
     x 5.7937658d-06, 4.2162062d-10,-9.5714827d-10 /
      data fpp(30,13,18,1),fpp(30,13,18,2),fpp(30,13,18,3)/
     x 5.8415183d-06, 1.6157995d-09, 1.0144894d-10 /
      data fpp(30,13,19,1),fpp(30,13,19,2),fpp(30,13,19,3)/
     x 6.1845790d-06, 8.5130056d-10, 5.5135251d-10 /
      data fpp(30,13,20,1),fpp(30,13,20,2),fpp(30,13,20,3)/
     x 6.8820862d-06,-8.0506619d-10, 3.6931410d-09 /
      data fpp(30,13,21,1),fpp(30,13,21,2),fpp(30,13,21,3)/
     x 6.8820862d-06,-8.0506619d-10, 3.6449006d-09 /
      data fpp(30,13,22,1),fpp(30,13,22,2),fpp(30,13,22,3)/
     x 6.1845790d-06, 8.5130056d-10, 7.4431410d-10 /
      data fpp(30,13,23,1),fpp(30,13,23,2),fpp(30,13,23,3)/
     x 5.8415183d-06, 1.6157995d-09,-6.2215705d-10 /
      data fpp(30,14, 1,1),fpp(30,14, 1,2),fpp(30,14, 1,3)/
     x 1.2353427d-05, 1.3184167d-09,-1.6189627d-10 /
      data fpp(30,14, 2,1),fpp(30,14, 2,2),fpp(30,14, 2,3)/
     x 1.3584401d-05, 3.0488705d-09, 8.2379255d-10 /
      data fpp(30,14, 3,1),fpp(30,14, 3,2),fpp(30,14, 3,3)/
     x 1.3311096d-05, 5.6086006d-09, 2.8667261d-09 /
      data fpp(30,14, 4,1),fpp(30,14, 4,2),fpp(30,14, 4,3)/
     x 1.3311096d-05, 5.6086006d-09, 2.9879255d-09 /
      data fpp(30,14, 5,1),fpp(30,14, 5,2),fpp(30,14, 5,3)/
     x 1.3584401d-05, 3.0488705d-09, 3.3899510d-10 /
      data fpp(30,14, 6,1),fpp(30,14, 6,2),fpp(30,14, 6,3)/
     x 1.2353427d-05, 1.3184167d-09, 1.6560942d-09 /
      data fpp(30,14, 7,1),fpp(30,14, 7,2),fpp(30,14, 7,3)/
     x 1.1416388d-05, 1.6816099d-09,-9.6337172d-10 /
      data fpp(30,14, 8,1),fpp(30,14, 8,2),fpp(30,14, 8,3)/
     x 1.0149307d-05, 2.6170288d-09, 2.1973927d-09 /
      data fpp(30,14, 9,1),fpp(30,14, 9,2),fpp(30,14, 9,3)/
     x 8.7633332d-06,-6.2523083d-10,-1.8261991d-09 /
      data fpp(30,14,10,1),fpp(30,14,10,2),fpp(30,14,10,3)/
     x 7.8472521d-06,-2.7983922d-09,-8.9259624d-10 /
      data fpp(30,14,11,1),fpp(30,14,11,2),fpp(30,14,11,3)/
     x 7.1698988d-06,-1.0686863d-09,-6.0341593d-10 /
      data fpp(30,14,12,1),fpp(30,14,12,2),fpp(30,14,12,3)/
     x 5.9921713d-06,-3.9107291d-09,-2.6937400d-09 /
      data fpp(30,14,13,1),fpp(30,14,13,2),fpp(30,14,13,3)/
     x 5.9362421d-06,-1.0487749d-09,-6.2162396d-10 /
      data fpp(30,14,14,1),fpp(30,14,14,2),fpp(30,14,14,3)/
     x 5.8017977d-06, 2.3640432d-09,-8.1976413d-10 /
      data fpp(30,14,15,1),fpp(30,14,15,2),fpp(30,14,15,3)/
     x 5.6351396d-06, 1.1301543d-10,-2.0993195d-09 /
      data fpp(30,14,16,1),fpp(30,14,16,2),fpp(30,14,16,3)/
     x 5.8209236d-06,-2.7888886d-10,-2.7829578d-09 /
      data fpp(30,14,17,1),fpp(30,14,17,2),fpp(30,14,17,3)/
     x 5.6585918d-06,-1.3409524d-09, 1.2311509d-09 /
      data fpp(30,14,18,1),fpp(30,14,18,2),fpp(30,14,18,3)/
     x 6.1448233d-06,-1.4203697d-09,-2.1416457d-09 /
      data fpp(30,14,19,1),fpp(30,14,19,2),fpp(30,14,19,3)/
     x 6.8371642d-06, 3.0631325d-10, 1.3354318d-09 /
      data fpp(30,14,20,1),fpp(30,14,20,2),fpp(30,14,20,3)/
     x 7.3056756d-06, 2.8182339d-09, 2.7999185d-09 /
      data fpp(30,14,21,1),fpp(30,14,21,2),fpp(30,14,21,3)/
     x 7.3056756d-06, 2.8182339d-09, 2.9325285d-09 /
      data fpp(30,14,22,1),fpp(30,14,22,2),fpp(30,14,22,3)/
     x 6.8371642d-06, 3.0631325d-10, 8.0499185d-10 /
      data fpp(30,14,23,1),fpp(30,14,23,2),fpp(30,14,23,3)/
     x 6.1448233d-06,-1.4203697d-09,-1.5249593d-10 /
      data fpp(30,15, 1,1),fpp(30,15, 1,2),fpp(30,15, 1,3)/
     x 1.2624416d-05, 8.4285520d-10, 3.0271281d-10 /
      data fpp(30,15, 2,1),fpp(30,15, 2,2),fpp(30,15, 2,3)/
     x 1.3173679d-05, 2.4371811d-09, 8.9457438d-10 /
      data fpp(30,15, 3,1),fpp(30,15, 3,2),fpp(30,15, 3,3)/
     x 1.2708953d-05, 1.6214523d-09, 2.1189897d-09 /
      data fpp(30,15, 4,1),fpp(30,15, 4,2),fpp(30,15, 4,3)/
     x 1.2708953d-05, 1.6214523d-09, 2.1957438d-09 /
      data fpp(30,15, 5,1),fpp(30,15, 5,2),fpp(30,15, 5,3)/
     x 1.3173679d-05, 2.4371811d-09, 5.8755795d-10 /
      data fpp(30,15, 6,1),fpp(30,15, 6,2),fpp(30,15, 6,3)/
     x 1.2624416d-05, 8.4285520d-10, 1.4540244d-09 /
      data fpp(30,15, 7,1),fpp(30,15, 7,2),fpp(30,15, 7,3)/
     x 1.1695362d-05, 1.2869719d-09,-4.0365563d-10 /
      data fpp(30,15, 8,1),fpp(30,15, 8,2),fpp(30,15, 8,3)/
     x 1.0379840d-05,-1.0023530d-09, 1.6059809d-10 /
      data fpp(30,15, 9,1),fpp(30,15, 9,2),fpp(30,15, 9,3)/
     x 9.2911867d-06, 1.1951585d-09,-2.3873674d-10 /
      data fpp(30,15,10,1),fpp(30,15,10,2),fpp(30,15,10,3)/
     x 8.1982918d-06, 2.3189062d-09, 7.9434886d-10 /
      data fpp(30,15,11,1),fpp(30,15,11,2),fpp(30,15,11,3)/
     x 7.3363438d-06,-1.7909874d-09,-2.9386587d-09 /
      data fpp(30,15,12,1),fpp(30,15,12,2),fpp(30,15,12,3)/
     x 6.2940681d-06, 1.6804992d-09,-1.0397141d-09 /
      data fpp(30,15,13,1),fpp(30,15,13,2),fpp(30,15,13,3)/
     x 5.5652528d-06, 8.0312475d-10, 1.0975150d-09 /
      data fpp(30,15,14,1),fpp(30,15,14,2),fpp(30,15,14,3)/
     x 4.9456486d-06,-3.8876027d-09,-3.3503459d-09 /
      data fpp(30,15,15,1),fpp(30,15,15,2),fpp(30,15,15,3)/
     x 4.9449454d-06,-3.1352555d-09, 3.0386847d-10 /
      data fpp(30,15,16,1),fpp(30,15,16,2),fpp(30,15,16,3)/
     x 5.0052528d-06,-3.2705740d-09,-3.8651280d-09 /
      data fpp(30,15,17,1),fpp(30,15,17,2),fpp(30,15,17,3)/
     x 5.0549611d-06,-1.0578111d-09, 3.1566436d-09 /
      data fpp(30,15,18,1),fpp(30,15,18,2),fpp(30,15,18,3)/
     x 5.5481420d-06,-1.9343208d-09,-2.7614464d-09 /
      data fpp(30,15,19,1),fpp(30,15,19,2),fpp(30,15,19,3)/
     x 6.0645733d-06,-2.0765535d-09, 1.8891419d-09 /
      data fpp(30,15,20,1),fpp(30,15,20,2),fpp(30,15,20,3)/
     x 6.7951048d-06,-4.4678693d-09, 1.2048789d-09 /
      data fpp(30,15,21,1),fpp(30,15,21,2),fpp(30,15,21,3)/
     x 6.7951048d-06,-4.4678693d-09, 1.4407924d-09 /
      data fpp(30,15,22,1),fpp(30,15,22,2),fpp(30,15,22,3)/
     x 6.0645733d-06,-2.0765535d-09, 9.4548789d-10 /
      data fpp(30,15,23,1),fpp(30,15,23,2),fpp(30,15,23,3)/
     x 5.5481420d-06,-1.9343208d-09, 7.7725606d-10 /
      data fpp(30,16, 1,1),fpp(30,16, 1,2),fpp(30,16, 1,3)/
     x 1.1767882d-05, 1.3101625d-09,-9.3848845d-10 /
      data fpp(30,16, 2,1),fpp(30,16, 2,2),fpp(30,16, 2,3)/
     x 1.1771261d-05,-7.9759493d-10,-1.2302310d-10 /
      data fpp(30,16, 3,1),fpp(30,16, 3,2),fpp(30,16, 3,3)/
     x 1.1888414d-05,-9.4409901d-11, 1.4305808d-09 /
      data fpp(30,16, 4,1),fpp(30,16, 4,2),fpp(30,16, 4,3)/
     x 1.1888414d-05,-9.4409901d-11, 1.7697690d-09 /
      data fpp(30,16, 5,1),fpp(30,16, 5,2),fpp(30,16, 5,3)/
     x 1.1771261d-05,-7.9759493d-10,-1.4797758d-09 /
      data fpp(30,16, 6,1),fpp(30,16, 6,2),fpp(30,16, 6,3)/
     x 1.1767882d-05, 1.3101625d-09, 4.1493343d-09 /
      data fpp(30,16, 7,1),fpp(30,16, 7,2),fpp(30,16, 7,3)/
     x 1.1624497d-05,-8.2949763d-10,-3.1175615d-09 /
      data fpp(30,16, 8,1),fpp(30,16, 8,2),fpp(30,16, 8,3)/
     x 1.0680152d-05, 1.3923833d-09, 2.3209116d-09 /
      data fpp(30,16, 9,1),fpp(30,16, 9,2),fpp(30,16, 9,3)/
     x 9.9341878d-06, 1.8445967d-09,-1.6608478d-10 /
      data fpp(30,16,10,1),fpp(30,16,10,2),fpp(30,16,10,3)/
     x 8.7305955d-06,-4.7723259d-10,-1.6565724d-09 /
      data fpp(30,16,11,1),fpp(30,16,11,2),fpp(30,16,11,3)/
     x 7.6429641d-06, 2.2326358d-09, 7.9237458d-10 /
      data fpp(30,16,12,1),fpp(30,16,12,2),fpp(30,16,12,3)/
     x 6.4721998d-06,-2.8112678d-09,-1.5129259d-09 /
      data fpp(30,16,13,1),fpp(30,16,13,2),fpp(30,16,13,3)/
     x 5.5789688d-06,-2.1637242d-09,-7.4067114d-10 /
      data fpp(30,16,14,1),fpp(30,16,14,2),fpp(30,16,14,3)/
     x 4.9870097d-06, 1.1863677d-09,-1.5243896d-09 /
      data fpp(30,16,15,1),fpp(30,16,15,2),fpp(30,16,15,3)/
     x 4.4094729d-06, 4.2800663d-10, 8.3822943d-10 /
      data fpp(30,16,16,1),fpp(30,16,16,2),fpp(30,16,16,3)/
     x 4.2660156d-06, 1.3611848d-09,-1.8285281d-09 /
      data fpp(30,16,17,1),fpp(30,16,17,2),fpp(30,16,17,3)/
     x 4.4110721d-06,-4.2780321d-10, 4.7588316d-10 /
      data fpp(30,16,18,1),fpp(30,16,18,2),fpp(30,16,18,3)/
     x 4.7485455d-06,-2.8423470d-09,-7.5004502d-11 /
      data fpp(30,16,19,1),fpp(30,16,19,2),fpp(30,16,19,3)/
     x 5.2155436d-06,-4.0000990d-09,-1.7586516d-10 /
      data fpp(30,16,20,1),fpp(30,16,20,2),fpp(30,16,20,3)/
     x 5.2379912d-06,-2.9467567d-09, 7.7846512d-10 /
      data fpp(30,16,21,1),fpp(30,16,21,2),fpp(30,16,21,3)/
     x 5.2379912d-06,-2.9467567d-09, 7.5253721d-10 /
      data fpp(30,16,22,1),fpp(30,16,22,2),fpp(30,16,22,3)/
     x 5.2155436d-06,-4.0000990d-09,-7.2153488d-11 /
      data fpp(30,16,23,1),fpp(30,16,23,2),fpp(30,16,23,3)/
     x 4.7485455d-06,-2.8423470d-09,-4.6392326d-10 /
      data fpp(30,17, 1,1),fpp(30,17, 1,2),fpp(30,17, 1,3)/
     x 1.0789204d-05,-8.3505295d-11,-4.6892621d-10 /
      data fpp(30,17, 2,1),fpp(30,17, 2,2),fpp(30,17, 2,3)/
     x 1.0702308d-05, 7.5319864d-10,-6.2147575d-11 /
      data fpp(30,17, 3,1),fpp(30,17, 3,2),fpp(30,17, 3,3)/
     x 1.1114923d-05,-1.2438127d-09, 7.1751651d-10 /
      data fpp(30,17, 4,1),fpp(30,17, 4,2),fpp(30,17, 4,3)/
     x 1.1114923d-05,-1.2438127d-09, 8.7852425d-10 /
      data fpp(30,17, 5,1),fpp(30,17, 5,2),fpp(30,17, 5,3)/
     x 1.0702308d-05, 7.5319864d-10,-7.0617854d-10 /
      data fpp(30,17, 6,1),fpp(30,17, 6,2),fpp(30,17, 6,3)/
     x 1.0789204d-05,-8.3505295d-11, 1.9461899d-09 /
      data fpp(30,17, 7,1),fpp(30,17, 7,2),fpp(30,17, 7,3)/
     x 1.0372214d-05, 2.0310186d-09,-1.0785811d-09 /
      data fpp(30,17, 8,1),fpp(30,17, 8,2),fpp(30,17, 8,3)/
     x 9.8746718d-06, 1.4328199d-09, 2.3681346d-09 /
      data fpp(30,17, 9,1),fpp(30,17, 9,2),fpp(30,17, 9,3)/
     x 9.0286887d-06,-2.5735453d-09,-2.3939573d-09 /
      data fpp(30,17,10,1),fpp(30,17,10,2),fpp(30,17,10,3)/
     x 8.4338762d-06,-4.0997584d-10, 1.2076947d-09 /
      data fpp(30,17,11,1),fpp(30,17,11,2),fpp(30,17,11,3)/
     x 7.8972826d-06,-1.1395558d-09,-2.4368215d-09 /
      data fpp(30,17,12,1),fpp(30,17,12,2),fpp(30,17,12,3)/
     x 6.8698547d-06, 3.5645721d-09, 2.5395913d-09 /
      data fpp(30,17,13,1),fpp(30,17,13,2),fpp(30,17,13,3)/
     x 6.1317076d-06, 1.8517719d-09,-1.7215437d-09 /
      data fpp(30,17,14,1),fpp(30,17,14,2),fpp(30,17,14,3)/
     x 5.6317458d-06,-8.5786824d-10,-1.6534165d-09 /
      data fpp(30,17,15,1),fpp(30,17,15,2),fpp(30,17,15,3)/
     x 4.7860620d-06, 1.4232290d-09, 2.3352097d-09 /
      data fpp(30,17,16,1),fpp(30,17,16,2),fpp(30,17,16,3)/
     x 4.4469006d-06,-2.1741651d-09,-1.6874224d-09 /
      data fpp(30,17,17,1),fpp(30,17,17,2),fpp(30,17,17,3)/
     x 4.1805986d-06,-3.2309761d-09,-1.5855203d-09 /
      data fpp(30,17,18,1),fpp(30,17,18,2),fpp(30,17,18,3)/
     x 4.0683578d-06, 1.3037088d-09, 2.0295034d-09 /
      data fpp(30,17,19,1),fpp(30,17,19,2),fpp(30,17,19,3)/
     x 4.2679402d-06, 7.6949744d-11,-5.3249348d-10 /
      data fpp(30,17,20,1),fpp(30,17,20,2),fpp(30,17,20,3)/
     x 4.1996216d-06,-1.7451040d-09, 1.0047047d-10 /
      data fpp(30,17,21,1),fpp(30,17,21,2),fpp(30,17,21,3)/
     x 4.1996216d-06,-1.7451040d-09,-3.5164663d-11 /
      data fpp(30,17,22,1),fpp(30,17,22,2),fpp(30,17,22,3)/
     x 4.2679402d-06, 7.6949744d-11, 1.0047047d-11 /
      data fpp(30,17,23,1),fpp(30,17,23,2),fpp(30,17,23,3)/
     x 4.0683578d-06, 1.3037088d-09,-5.0235234d-12 /
      data fpp(30,18, 1,1),fpp(30,18, 1,2),fpp(30,18, 1,3)/
     x 9.0611756d-06,-9.7614134d-10,-2.1678881d-09 /
      data fpp(30,18, 2,1),fpp(30,18, 2,2),fpp(30,18, 2,3)/
     x 9.2446838d-06,-2.2151996d-09,-1.1642238d-09 /
      data fpp(30,18, 3,1),fpp(30,18, 3,2),fpp(30,18, 3,3)/
     x 9.7158123d-06,-9.3033922d-10, 8.2478315d-10 /
      data fpp(30,18, 4,1),fpp(30,18, 4,2),fpp(30,18, 4,3)/
     x 9.7158123d-06,-9.3033922d-10, 1.1077624d-09 /
      data fpp(30,18, 5,1),fpp(30,18, 5,2),fpp(30,18, 5,3)/
     x 9.2446838d-06,-2.2151996d-09,-2.2961408d-09 /
      data fpp(30,18, 6,1),fpp(30,18, 6,2),fpp(30,18, 6,3)/
     x 9.0611756d-06,-9.7614134d-10, 2.0768008d-09 /
      data fpp(30,18, 7,1),fpp(30,18, 7,2),fpp(30,18, 7,3)/
     x 8.8668258d-06,-1.2945767d-09,-1.1062426d-11 /
      data fpp(30,18, 8,1),fpp(30,18, 8,2),fpp(30,18, 8,3)/
     x 8.4835603d-06,-1.1236628d-09,-2.0325511d-09 /
      data fpp(30,18, 9,1),fpp(30,18, 9,2),fpp(30,18, 9,3)/
     x 8.2239276d-06, 2.4495844d-09, 2.1412668d-09 /
      data fpp(30,18,10,1),fpp(30,18,10,2),fpp(30,18,10,3)/
     x 7.6997298d-06, 2.1171360d-09,-5.3251624d-10 /
      data fpp(30,18,11,1),fpp(30,18,11,2),fpp(30,18,11,3)/
     x 7.6082399d-06, 2.3255874d-09,-1.1201873d-11 /
      data fpp(30,18,12,1),fpp(30,18,12,2),fpp(30,18,12,3)/
     x 6.5712849d-06, 5.5297940d-10, 5.7732373d-10 /
      data fpp(30,18,13,1),fpp(30,18,13,2),fpp(30,18,13,3)/
     x 6.5292804d-06, 7.5663660d-10,-2.2980931d-09 /
      data fpp(30,18,14,1),fpp(30,18,14,2),fpp(30,18,14,3)/
     x 5.9463502d-06, 2.2451052d-09, 2.6150485d-09 /
      data fpp(30,18,15,1),fpp(30,18,15,2),fpp(30,18,15,3)/
     x 5.7167047d-06,-1.2092257d-10,-2.1621010d-09 /
      data fpp(30,18,16,1),fpp(30,18,16,2),fpp(30,18,16,3)/
     x 5.3304462d-06, 1.3354758d-09, 3.3355586d-11 /
      data fpp(30,18,17,1),fpp(30,18,17,2),fpp(30,18,17,3)/
     x 5.1301567d-06, 1.3517074d-09, 2.0286787d-09 /
      data fpp(30,18,18,1),fpp(30,18,18,2),fpp(30,18,18,3)/
     x 4.8556077d-06,-2.3724882d-09,-2.1480703d-09 /
      data fpp(30,18,19,1),fpp(30,18,19,2),fpp(30,18,19,3)/
     x 5.0977628d-06,-2.3076999d-09, 5.6360261d-10 /
      data fpp(30,18,20,1),fpp(30,18,20,2),fpp(30,18,20,3)/
     x 4.9638809d-06,-2.0728274d-09,-1.0634012d-10 /
      data fpp(30,18,21,1),fpp(30,18,21,2),fpp(30,18,21,3)/
     x 4.9638809d-06,-2.0728274d-09, 3.7219040d-11 /
      data fpp(30,18,22,1),fpp(30,18,22,2),fpp(30,18,22,3)/
     x 5.0977628d-06,-2.3076999d-09,-1.0634012d-11 /
      data fpp(30,18,23,1),fpp(30,18,23,2),fpp(30,18,23,3)/
     x 4.8556077d-06,-2.3724882d-09, 5.3170058d-12 /
      data fpp(30,19, 1,1),fpp(30,19, 1,2),fpp(30,19, 1,3)/
     x 7.1807696d-06,-2.0119293d-09, 3.8847289d-24 /
      data fpp(30,19, 2,1),fpp(30,19, 2,2),fpp(30,19, 2,3)/
     x 7.1807696d-06,-3.8924002d-09, 1.2872491d-23 /
      data fpp(30,19, 3,1),fpp(30,19, 3,2),fpp(30,19, 3,3)/
     x 7.1807696d-06,-1.0348304d-09, 5.6602027d-24 /
      data fpp(30,19, 4,1),fpp(30,19, 4,2),fpp(30,19, 4,3)/
     x 7.1807696d-06,-1.0348304d-09,-7.7209227d-24 /
      data fpp(30,19, 5,1),fpp(30,19, 5,2),fpp(30,19, 5,3)/
     x 7.1807696d-06,-3.8924002d-09,-1.3000981d-23 /
      data fpp(30,19, 6,1),fpp(30,19, 6,2),fpp(30,19, 6,3)/
     x 7.1807696d-06,-2.0119293d-09, 1.7849601d-24 /
      data fpp(30,19, 7,1),fpp(30,19, 7,2),fpp(30,19, 7,3)/
     x 7.1807696d-06,-2.8527116d-09, 1.7622766d-23 /
      data fpp(30,19, 8,1),fpp(30,19, 8,2),fpp(30,19, 8,3)/
     x 7.1807696d-06,-2.9381686d-09, 4.5703073d-24 /
      data fpp(30,19, 9,1),fpp(30,19, 9,2),fpp(30,19, 9,3)/
     x 7.1807696d-06, 4.7752078d-09,-2.6772416d-24 /
      data fpp(30,19,10,1),fpp(30,19,10,2),fpp(30,19,10,3)/
     x 7.1807696d-06, 3.9414320d-09,-1.8597003d-23 /
      data fpp(30,19,11,1),fpp(30,19,11,2),fpp(30,19,11,3)/
     x 7.1807696d-06, 3.8372063d-09, 1.2102220d-23 /
      data fpp(30,19,12,1),fpp(30,19,12,2),fpp(30,19,12,3)/
     x 7.1807696d-06, 2.2351030d-10,-1.9885222d-24 /
      data fpp(30,19,13,1),fpp(30,19,13,2),fpp(30,19,13,3)/
     x 7.1807696d-06, 1.1216817d-09,-5.9521563d-24 /
      data fpp(30,19,14,1),fpp(30,19,14,2),fpp(30,19,14,3)/
     x 7.1807696d-06, 3.8774474d-09,-4.1421744d-25 /
      data fpp(30,19,15,1),fpp(30,19,15,2),fpp(30,19,15,3)/
     x 7.1807696d-06,-9.3953872d-10,-2.0883677d-25 /
      data fpp(30,19,16,1),fpp(30,19,16,2),fpp(30,19,16,3)/
     x 7.1807696d-06, 2.8322621d-09, 3.7863390d-24 /
      data fpp(30,19,17,1),fpp(30,19,17,2),fpp(30,19,17,3)/
     x 7.1807696d-06, 3.8241463d-09,-1.5165473d-23 /
      data fpp(30,19,18,1),fpp(30,19,18,2),fpp(30,19,18,3)/
     x 7.1807696d-06,-3.8137559d-09, 6.4607143d-24 /
      data fpp(30,19,19,1),fpp(30,19,19,2),fpp(30,19,19,3)/
     x 7.1807696d-06,-2.8461500d-09, 7.6939620d-24 /
      data fpp(30,19,20,1),fpp(30,19,20,2),fpp(30,19,20,3)/
     x 7.1807696d-06,-1.9635863d-09,-1.6393066d-23 /
      data fpp(30,19,21,1),fpp(30,19,21,2),fpp(30,19,21,3)/
     x 7.1807696d-06,-1.9635863d-09, 1.5822842d-23 /
      data fpp(30,19,22,1),fpp(30,19,22,2),fpp(30,19,22,3)/
     x 7.1807696d-06,-2.8461500d-09,-4.4766187d-24 /
      data fpp(30,19,23,1),fpp(30,19,23,2),fpp(30,19,23,3)/
     x 7.1807696d-06,-3.8137559d-09,-8.3827949d-23 /
 
      data fpppp( 1, 1, 1,1),fpppp( 1, 1, 1,2),fpppp( 1, 1, 1,3)/
     x 1.2651963d-02, 6.8012048d-16, 5.9018390d-06 /
      data fpppp( 1, 1, 2,1),fpppp( 1, 1, 2,2),fpppp( 1, 1, 2,3)/
     x 1.7205884d-02,-1.3748349d-16, 3.9133033d-06 /
      data fpppp( 1, 1, 3,1),fpppp( 1, 1, 3,2),fpppp( 1, 1, 3,3)/
     x 2.4003786d-02, 1.4708975d-17,-7.8499808d-09 /
      data fpppp( 1, 1, 4,1),fpppp( 1, 1, 4,2),fpppp( 1, 1, 4,3)/
     x 2.4003786d-02, 5.3360853d-17,-6.0284077d-07 /
      data fpppp( 1, 1, 5,1),fpppp( 1, 1, 5,2),fpppp( 1, 1, 5,3)/
     x 1.7205884d-02,-3.6161244d-17, 6.2932664d-06 /
      data fpppp( 1, 1, 6,1),fpppp( 1, 1, 6,2),fpppp( 1, 1, 6,3)/
     x 1.2651963d-02,-3.1946447d-16,-3.0230229d-06 /
      data fpppp( 1, 1, 7,1),fpppp( 1, 1, 7,2),fpppp( 1, 1, 7,3)/
     x 2.0360823d-02,-8.0021158d-17,-3.1613174d-08 /
      data fpppp( 1, 1, 8,1),fpppp( 1, 1, 8,2),fpppp( 1, 1, 8,3)/
     x 1.2523908d-01,-2.9662508d-16,-6.5933094d-07 /
      data fpppp( 1, 1, 9,1),fpppp( 1, 1, 9,2),fpppp( 1, 1, 9,3)/
     x-1.5256164d-02,-1.2779180d-16,-7.5503982d-07 /
      data fpppp( 1, 1,10,1),fpppp( 1, 1,10,2),fpppp( 1, 1,10,3)/
     x-2.0588709d-01, 3.2847818d-16, 7.5532033d-10 /
      data fpppp( 1, 1,11,1),fpppp( 1, 1,11,2),fpppp( 1, 1,11,3)/
     x-3.1314801d-01, 1.4054276d-16,-8.9277991d-07 /
      data fpppp( 1, 1,12,1),fpppp( 1, 1,12,2),fpppp( 1, 1,12,3)/
     x-3.5727056d-01,-6.1363716d-17,-4.8289128d-07 /
      data fpppp( 1, 1,13,1),fpppp( 1, 1,13,2),fpppp( 1, 1,13,3)/
     x-3.1217918d-01,-1.1169586d-16,-5.6780361d-07 /
      data fpppp( 1, 1,14,1),fpppp( 1, 1,14,2),fpppp( 1, 1,14,3)/
     x-2.0096514d-01,-1.2896297d-16,-5.0158910d-07 /
      data fpppp( 1, 1,15,1),fpppp( 1, 1,15,2),fpppp( 1, 1,15,3)/
     x-9.6168296d-03, 3.6479992d-16,-8.1850947d-07 /
      data fpppp( 1, 1,16,1),fpppp( 1, 1,16,2),fpppp( 1, 1,16,3)/
     x 1.1956423d-01,-2.6795613d-16,-1.8875373d-07 /
      data fpppp( 1, 1,17,1),fpppp( 1, 1,17,2),fpppp( 1, 1,17,3)/
     x 2.0553072d-02,-4.7308545d-16,-3.9660600d-07 /
      data fpppp( 1, 1,18,1),fpppp( 1, 1,18,2),fpppp( 1, 1,18,3)/
     x 1.8706436d-02,-8.9445766d-17,-3.1247825d-06 /
      data fpppp( 1, 1,19,1),fpppp( 1, 1,19,2),fpppp( 1, 1,19,3)/
     x 2.2387908d-02,-1.6097676d-16, 6.8532193d-06 /
      data fpppp( 1, 1,20,1),fpppp( 1, 1,20,2),fpppp( 1, 1,20,3)/
     x 2.2914206d-02,-1.3846812d-16,-8.0869520d-07 /
      data fpppp( 1, 1,21,1),fpppp( 1, 1,21,2),fpppp( 1, 1,21,3)/
     x 2.2914206d-02, 3.1985147d-16,-1.6532992d-07 /
      data fpppp( 1, 1,22,1),fpppp( 1, 1,22,2),fpppp( 1, 1,22,3)/
     x 2.2387908d-02, 2.3713152d-17, 4.2797582d-06 /
      data fpppp( 1, 1,23,1),fpppp( 1, 1,23,2),fpppp( 1, 1,23,3)/
     x 1.8706436d-02,-4.7315604d-16, 6.5256967d-06 /
      data fpppp( 1, 2, 1,1),fpppp( 1, 2, 1,2),fpppp( 1, 2, 1,3)/
     x 9.6923433d-03,-2.3057740d-04, 3.5965106d-06 /
      data fpppp( 1, 2, 2,1),fpppp( 1, 2, 2,2),fpppp( 1, 2, 2,3)/
     x 1.2063864d-02,-9.5482956d-05, 2.3447214d-06 /
      data fpppp( 1, 2, 3,1),fpppp( 1, 2, 3,2),fpppp( 1, 2, 3,3)/
     x 1.4811617d-02, 2.1419125d-04,-1.2874008d-07 /
      data fpppp( 1, 2, 4,1),fpppp( 1, 2, 4,2),fpppp( 1, 2, 4,3)/
     x 1.4811617d-02, 1.7886556d-04,-4.9439226d-07 /
      data fpppp( 1, 2, 5,1),fpppp( 1, 2, 5,2),fpppp( 1, 2, 5,3)/
     x 1.2063864d-02, 4.5819819d-05, 3.8073301d-06 /
      data fpppp( 1, 2, 6,1),fpppp( 1, 2, 6,2),fpppp( 1, 2, 6,3)/
     x 9.6923433d-03,-7.6046281d-04,-1.8882720d-06 /
      data fpppp( 1, 2, 7,1),fpppp( 1, 2, 7,2),fpppp( 1, 2, 7,3)/
     x 1.3130830d-02, 2.5042978d-04,-2.5210548d-07 /
      data fpppp( 1, 2, 8,1),fpppp( 1, 2, 8,2),fpppp( 1, 2, 8,3)/
     x 5.7029641d-02, 8.4589083d-05,-9.9213038d-08 /
      data fpppp( 1, 2, 9,1),fpppp( 1, 2, 9,2),fpppp( 1, 2, 9,3)/
     x-2.2908294d-03, 6.2837844d-04,-5.2148884d-07 /
      data fpppp( 1, 2,10,1),fpppp( 1, 2,10,2),fpppp( 1, 2,10,3)/
     x-8.4282539d-02,-1.0778257d-03, 8.6098188d-08 /
      data fpppp( 1, 2,11,1),fpppp( 1, 2,11,2),fpppp( 1, 2,11,3)/
     x-1.3020982d-01, 6.7579999d-04,-4.5328702d-07 /
      data fpppp( 1, 2,12,1),fpppp( 1, 2,12,2),fpppp( 1, 2,12,3)/
     x-1.5136340d-01,-6.7430209d-05,-1.5235892d-07 /
      data fpppp( 1, 2,13,1),fpppp( 1, 2,13,2),fpppp( 1, 2,13,3)/
     x-1.2978962d-01,-4.0490823d-04,-2.8628002d-07 /
      data fpppp( 1, 2,14,1),fpppp( 1, 2,14,2),fpppp( 1, 2,14,3)/
     x-8.2071197d-02, 5.1533852d-04,-1.8739136d-07 /
      data fpppp( 1, 2,15,1),fpppp( 1, 2,15,2),fpppp( 1, 2,15,3)/
     x 1.6936582d-04, 6.9187530d-04,-3.8795557d-07 /
      data fpppp( 1, 2,16,1),fpppp( 1, 2,16,2),fpppp( 1, 2,16,3)/
     x 5.4910457d-02,-1.4245220d-03,-1.2738495d-07 /
      data fpppp( 1, 2,17,1),fpppp( 1, 2,17,2),fpppp( 1, 2,17,3)/
     x 1.3131968d-02,-9.3379847d-04,-1.8202383d-07 /
      data fpppp( 1, 2,18,1),fpppp( 1, 2,18,2),fpppp( 1, 2,18,3)/
     x 1.1676660d-02, 3.7135930d-03,-2.1268193d-06 /
      data fpppp( 1, 2,19,1),fpppp( 1, 2,19,2),fpppp( 1, 2,19,3)/
     x 1.5506522d-02,-2.6866709d-03, 4.3951143d-06 /
      data fpppp( 1, 2,20,1),fpppp( 1, 2,20,2),fpppp( 1, 2,20,3)/
     x 1.5081039d-02, 3.9583458d-04,-7.6369708d-07 /
      data fpppp( 1, 2,21,1),fpppp( 1, 2,21,2),fpppp( 1, 2,21,3)/
     x 1.5081039d-02, 2.3741238d-05,-3.3983416d-07 /
      data fpppp( 1, 2,22,1),fpppp( 1, 2,22,2),fpppp( 1, 2,22,3)/
     x 1.5506522d-02,-1.1982975d-03, 2.6996626d-06 /
      data fpppp( 1, 2,23,1),fpppp( 1, 2,23,2),fpppp( 1, 2,23,3)/
     x 1.1676660d-02,-1.8678072d-03, 4.2311246d-06 /
      data fpppp( 1, 3, 1,1),fpppp( 1, 3, 1,2),fpppp( 1, 3, 1,3)/
     x 2.3910234d-02,-1.5174294d-04,-1.8115919d-05 /
      data fpppp( 1, 3, 2,1),fpppp( 1, 3, 2,2),fpppp( 1, 3, 2,3)/
     x 1.5823976d-02,-3.0818280d-04,-1.2422624d-05 /
      data fpppp( 1, 3, 3,1),fpppp( 1, 3, 3,2),fpppp( 1, 3, 3,3)/
     x 3.4535202d-03, 5.2546194d-05,-1.3528127d-06 /
      data fpppp( 1, 3, 4,1),fpppp( 1, 3, 4,2),fpppp( 1, 3, 4,3)/
     x 3.4535202d-03,-1.1653790d-03, 6.2487619d-07 /
      data fpppp( 1, 3, 5,1),fpppp( 1, 3, 5,2),fpppp( 1, 3, 5,3)/
     x 1.5823976d-02, 4.5635181d-03,-2.0333379d-05 /
      data fpppp( 1, 3, 6,1),fpppp( 1, 3, 6,2),fpppp( 1, 3, 6,3)/
     x 2.3910234d-02,-1.8420621d-02, 1.1549414d-05 /
      data fpppp( 1, 3, 7,1),fpppp( 1, 3, 7,2),fpppp( 1, 3, 7,3)/
     x 8.2099143d-03, 7.5343998d-02, 1.6884551d-06 /
      data fpppp( 1, 3, 8,1),fpppp( 1, 3, 8,2),fpppp( 1, 3, 8,3)/
     x-1.0215202d-01,-1.1795460d-01, 1.5996801d-06 /
      data fpppp( 1, 3, 9,1),fpppp( 1, 3, 9,2),fpppp( 1, 3, 9,3)/
     x 4.9232419d-02, 2.4045036d-03, 1.9517872d-06 /
      data fpppp( 1, 3,10,1),fpppp( 1, 3,10,2),fpppp( 1, 3,10,3)/
     x 2.5788257d-01, 2.7822218d-02, 1.0327068d-06 /
      data fpppp( 1, 3,11,1),fpppp( 1, 3,11,2),fpppp( 1, 3,11,3)/
     x 3.7640640d-01, 1.7793742d-02, 1.6307966d-06 /
      data fpppp( 1, 3,12,1),fpppp( 1, 3,12,2),fpppp( 1, 3,12,3)/
     x 4.4848697d-01, 1.9908676d-02, 1.1976377d-06 /
      data fpppp( 1, 3,13,1),fpppp( 1, 3,13,2),fpppp( 1, 3,13,3)/
     x 3.7538506d-01, 1.7514745d-02, 1.4462921d-06 /
      data fpppp( 1, 3,14,1),fpppp( 1, 3,14,2),fpppp( 1, 3,14,3)/
     x 2.5392380d-01, 3.0030799d-02, 1.3955303d-06 /
      data fpppp( 1, 3,15,1),fpppp( 1, 3,15,2),fpppp( 1, 3,15,3)/
     x 4.2715538d-02,-4.4654842d-03, 1.5968605d-06 /
      data fpppp( 1, 3,16,1),fpppp( 1, 3,16,2),fpppp( 1, 3,16,3)/
     x-9.8973626d-02,-1.1109826d-01, 2.3150828d-06 /
      data fpppp( 1, 3,17,1),fpppp( 1, 3,17,2),fpppp( 1, 3,17,3)/
     x 9.4302973d-03, 7.2801066d-02, 9.9193559d-07 /
      data fpppp( 1, 3,18,1),fpppp( 1, 3,18,2),fpppp( 1, 3,18,3)/
     x 2.4081735d-02,-1.8293481d-02, 1.2853573d-05 /
      data fpppp( 1, 3,19,1),fpppp( 1, 3,19,2),fpppp( 1, 3,19,3)/
     x-5.2441800d-03, 5.5320963d-03,-2.3525246d-05 /
      data fpppp( 1, 3,20,1),fpppp( 1, 3,20,2),fpppp( 1, 3,20,3)/
     x 1.0016696d-03,-1.7142042d-03, 2.0635663d-06 /
      data fpppp( 1, 3,21,1),fpppp( 1, 3,21,2),fpppp( 1, 3,21,3)/
     x 1.0016696d-03,-4.2272391d-04,-2.3011716d-07 /
      data fpppp( 1, 3,22,1),fpppp( 1, 3,22,2),fpppp( 1, 3,22,3)/
     x-5.2441800d-03, 3.6617519d-04,-1.4350512d-05 /
      data fpppp( 1, 3,23,1),fpppp( 1, 3,23,2),fpppp( 1, 3,23,3)/
     x 2.4081735d-02, 1.0787228d-03,-2.1551678d-05 /
      data fpppp( 1, 4, 1,1),fpppp( 1, 4, 1,2),fpppp( 1, 4, 1,3)/
     x-2.1993161d-02,-7.3810540d-03, 2.8096506d-05 /
      data fpppp( 1, 4, 2,1),fpppp( 1, 4, 2,2),fpppp( 1, 4, 2,3)/
     x-1.1573371d-02,-3.7667893d-03, 1.9005702d-05 /
      data fpppp( 1, 4, 3,1),fpppp( 1, 4, 3,2),fpppp( 1, 4, 3,3)/
     x-3.2383291d-04, 4.2518614d-03, 1.2842534d-06 /
      data fpppp( 1, 4, 4,1),fpppp( 1, 4, 4,2),fpppp( 1, 4, 4,3)/
     x-3.2383291d-04, 3.7727157d-03,-1.7937251d-06 /
      data fpppp( 1, 4, 5,1),fpppp( 1, 4, 5,2),fpppp( 1, 4, 5,3)/
     x-1.1573371d-02,-1.8502065d-03, 3.1317616d-05 /
      data fpppp( 1, 4, 6,1),fpppp( 1, 4, 6,2),fpppp( 1, 4, 6,3)/
     x-2.1993161d-02,-1.4568239d-02,-1.8073172d-05 /
      data fpppp( 1, 4, 7,1),fpppp( 1, 4, 7,2),fpppp( 1, 4, 7,3)/
     x-4.7927746d-03, 1.3602698d-02,-3.9346694d-06 /
      data fpppp( 1, 4, 8,1),fpppp( 1, 4, 8,2),fpppp( 1, 4, 8,3)/
     x 5.7069102d-02,-3.6915147d-03,-6.8714006d-07 /
      data fpppp( 1, 4, 9,1),fpppp( 1, 4, 9,2),fpppp( 1, 4, 9,3)/
     x-3.4197031d-02, 2.4445769d-03,-3.4139745d-06 /
      data fpppp( 1, 4,10,1),fpppp( 1, 4,10,2),fpppp( 1, 4,10,3)/
     x-1.7191428d-01,-8.6953081d-03,-1.0351146d-06 /
      data fpppp( 1, 4,11,1),fpppp( 1, 4,11,2),fpppp( 1, 4,11,3)/
     x-2.4985049d-01, 3.3658150d-02,-2.0411873d-06 /
      data fpppp( 1, 4,12,1),fpppp( 1, 4,12,2),fpppp( 1, 4,12,3)/
     x-3.3046386d-01,-5.3359982d-02,-1.0204906d-06 /
      data fpppp( 1, 4,13,1),fpppp( 1, 4,13,2),fpppp( 1, 4,13,3)/
     x-2.4918818d-01, 3.3553496d-02,-1.8998056d-06 /
      data fpppp( 1, 4,14,1),fpppp( 1, 4,14,2),fpppp( 1, 4,14,3)/
     x-1.6993490d-01,-9.0005489d-03,-1.4620817d-06 /
      data fpppp( 1, 4,15,1),fpppp( 1, 4,15,2),fpppp( 1, 4,15,3)/
     x-2.9398209d-02, 3.2628303d-03,-1.8582411d-06 /
      data fpppp( 1, 4,16,1),fpppp( 1, 4,16,2),fpppp( 1, 4,16,3)/
     x 5.9448375d-02,-4.8810748d-03,-3.5762958d-06 /
      data fpppp( 1, 4,17,1),fpppp( 1, 4,17,2),fpppp( 1, 4,17,3)/
     x-7.2893917d-03, 1.8354954d-02,-1.1919254d-06 /
      data fpppp( 1, 4,18,1),fpppp( 1, 4,18,2),fpppp( 1, 4,18,3)/
     x-3.1535167d-02,-3.5662353d-02,-2.1104537d-05 /
      data fpppp( 1, 4,19,1),fpppp( 1, 4,19,2),fpppp( 1, 4,19,3)/
     x 2.2547723d-02, 3.1083449d-02, 3.7672287d-05 /
      data fpppp( 1, 4,20,1),fpppp( 1, 4,20,2),fpppp( 1, 4,20,3)/
     x 8.7840085d-03,-7.6076767d-03,-4.8470987d-06 /
      data fpppp( 1, 4,21,1),fpppp( 1, 4,21,2),fpppp( 1, 4,21,3)/
     x 8.7840085d-03,-3.5822814d-03,-1.1151745d-06 /
      data fpppp( 1, 4,22,1),fpppp( 1, 4,22,2),fpppp( 1, 4,22,3)/
     x 2.2547723d-02, 1.4981868d-02, 2.2744590d-05 /
      data fpppp( 1, 4,23,1),fpppp( 1, 4,23,2),fpppp( 1, 4,23,3)/
     x-3.1535167d-02, 2.4718576d-02, 3.4874327d-05 /
      data fpppp( 1, 5, 1,1),fpppp( 1, 5, 1,2),fpppp( 1, 5, 1,3)/
     x 4.1891123d-03,-8.1380797d-03,-1.7230701d-05 /
      data fpppp( 1, 5, 2,1),fpppp( 1, 5, 2,2),fpppp( 1, 5, 2,3)/
     x-1.3564448d-03,-4.5010537d-03,-1.1032692d-05 /
      data fpppp( 1, 5, 3,1),fpppp( 1, 5, 3,2),fpppp( 1, 5, 3,3)/
     x 6.0570436d-03, 3.0753657d-03, 1.2573831d-06 /
      data fpppp( 1, 5, 4,1),fpppp( 1, 5, 4,2),fpppp( 1, 5, 4,3)/
     x 6.0570436d-03, 3.4554790d-03, 2.9922850d-06 /
      data fpppp( 1, 5, 5,1),fpppp( 1, 5, 5,2),fpppp( 1, 5, 5,3)/
     x-1.3564448d-03,-6.0215071d-03,-1.7972300d-05 /
      data fpppp( 1, 5, 6,1),fpppp( 1, 5, 6,2),fpppp( 1, 5, 6,3)/
     x 4.1891123d-03,-2.4363795d-03, 8.7928268d-06 /
      data fpppp( 1, 5, 7,1),fpppp( 1, 5, 7,2),fpppp( 1, 5, 7,3)/
     x 1.0704039d-03,-5.4690778d-03, 4.1327098d-06 /
      data fpppp( 1, 5, 8,1),fpppp( 1, 5, 8,2),fpppp( 1, 5, 8,3)/
     x 9.4160946d-04, 1.8588262d-02,-2.5654606d-06 /
      data fpppp( 1, 5, 9,1),fpppp( 1, 5, 9,2),fpppp( 1, 5, 9,3)/
     x 1.1188036d-02,-1.2642057d-02, 3.1008665d-06 /
      data fpppp( 1, 5,10,1),fpppp( 1, 5,10,2),fpppp( 1, 5,10,3)/
     x 4.7915575d-02, 5.2196572d-03,-3.2476946d-07 /
      data fpppp( 1, 5,11,1),fpppp( 1, 5,11,2),fpppp( 1, 5,11,3)/
     x 6.8440088d-02,-4.2858724d-03, 1.0742023d-06 /
      data fpppp( 1, 5,12,1),fpppp( 1, 5,12,2),fpppp( 1, 5,12,3)/
     x 1.1163426d-01, 3.6903348d-03,-4.2671274d-07 /
      data fpppp( 1, 5,13,1),fpppp( 1, 5,13,2),fpppp( 1, 5,13,3)/
     x 6.7188755d-02,-3.1411832d-03, 1.2433499d-06 /
      data fpppp( 1, 5,14,1),fpppp( 1, 5,14,2),fpppp( 1, 5,14,3)/
     x 4.8536843d-02, 1.9275388d-03,-1.1840454d-07 /
      data fpppp( 1, 5,15,1),fpppp( 1, 5,15,2),fpppp( 1, 5,15,3)/
     x 9.2817194d-03,-1.3297817d-03, 8.8172865d-07 /
      data fpppp( 1, 5,16,1),fpppp( 1, 5,16,2),fpppp( 1, 5,16,3)/
     x 8.7551424d-03, 2.1476145d-03, 1.8108821d-06 /
      data fpppp( 1, 5,17,1),fpppp( 1, 5,17,2),fpppp( 1, 5,17,3)/
     x 4.1878495d-03,-3.3012626d-03,-1.0338503d-07 /
      data fpppp( 1, 5,18,1),fpppp( 1, 5,18,2),fpppp( 1, 5,18,3)/
     x 1.6790616d-02, 8.3832352d-03, 1.3980876d-05 /
      data fpppp( 1, 5,19,1),fpppp( 1, 5,19,2),fpppp( 1, 5,19,3)/
     x-2.4252955d-02,-6.1219614d-03,-2.4985721d-05 /
      data fpppp( 1, 5,20,1),fpppp( 1, 5,20,2),fpppp( 1, 5,20,3)/
     x-5.5861872d-03, 7.1309610d-06, 5.6077635d-06 /
      data fpppp( 1, 5,21,1),fpppp( 1, 5,21,2),fpppp( 1, 5,21,3)/
     x-5.5861872d-03,-8.1717789d-04, 3.0803795d-06 /
      data fpppp( 1, 5,22,1),fpppp( 1, 5,22,2),fpppp( 1, 5,22,3)/
     x-2.4252955d-02,-2.8247260d-03,-1.4876185d-05 /
      data fpppp( 1, 5,23,1),fpppp( 1, 5,23,2),fpppp( 1, 5,23,3)/
     x 1.6790616d-02,-3.9813975d-03,-2.3929884d-05 /
      data fpppp( 1, 6, 1,1),fpppp( 1, 6, 1,2),fpppp( 1, 6, 1,3)/
     x-5.9973720d-03,-1.1282065d-02,-1.6464488d-06 /
      data fpppp( 1, 6, 2,1),fpppp( 1, 6, 2,2),fpppp( 1, 6, 2,3)/
     x 1.9522329d-02,-6.9341713d-03,-7.8978814d-07 /
      data fpppp( 1, 6, 3,1),fpppp( 1, 6, 3,2),fpppp( 1, 6, 3,3)/
     x-1.7186427d-02, 1.5187152d-03, 8.5226054d-07 /
      data fpppp( 1, 6, 4,1),fpppp( 1, 6, 4,2),fpppp( 1, 6, 4,3)/
     x-1.7186427d-02, 3.0307657d-03, 1.1911528d-06 /
      data fpppp( 1, 6, 5,1),fpppp( 1, 6, 5,2),fpppp( 1, 6, 5,3)/
     x 1.9522329d-02,-1.2982373d-02,-2.1453572d-06 /
      data fpppp( 1, 6, 6,1),fpppp( 1, 6, 6,2),fpppp( 1, 6, 6,3)/
     x-5.9973720d-03, 1.1398692d-02, 3.4369352d-06 /
      data fpppp( 1, 6, 7,1),fpppp( 1, 6, 7,2),fpppp( 1, 6, 7,3)/
     x 1.0645635d-03,-3.0193844d-03,-2.9277502d-06 /
      data fpppp( 1, 6, 8,1),fpppp( 1, 6, 8,2),fpppp( 1, 6, 8,3)/
     x-7.7815697d-04, 7.9543721d-04, 9.9687456d-07 /
      data fpppp( 1, 6, 9,1),fpppp( 1, 6, 9,2),fpppp( 1, 6, 9,3)/
     x-2.2490349d-03,-2.1504144d-04,-7.3783988d-07 /
      data fpppp( 1, 6,10,1),fpppp( 1, 6,10,2),fpppp( 1, 6,10,3)/
     x-1.2357686d-02,-1.1821076d-05,-6.1070555d-07 /
      data fpppp( 1, 6,11,1),fpppp( 1, 6,11,2),fpppp( 1, 6,11,3)/
     x-2.4159751d-02, 1.1775969d-04, 3.0859868d-07 /
      data fpppp( 1, 6,12,1),fpppp( 1, 6,12,2),fpppp( 1, 6,12,3)/
     x-3.4987794d-02,-5.2801719d-04, 5.2555672d-07 /
      data fpppp( 1, 6,13,1),fpppp( 1, 6,13,2),fpppp( 1, 6,13,3)/
     x-1.8249016d-02, 1.7882929d-03,-1.3810755d-06 /
      data fpppp( 1, 6,14,1),fpppp( 1, 6,14,2),fpppp( 1, 6,14,3)/
     x-1.6817797d-02,-6.5278937d-03, 1.2071704d-06 /
      data fpppp( 1, 6,15,1),fpppp( 1, 6,15,2),fpppp( 1, 6,15,3)/
     x-1.8346872d-04, 2.4061199d-02,-1.0371144d-06 /
      data fpppp( 1, 6,16,1),fpppp( 1, 6,16,2),fpppp( 1, 6,16,3)/
     x-3.3525352d-02,-3.8126677d-02,-9.8833987d-07 /
      data fpppp( 1, 6,17,1),fpppp( 1, 6,17,2),fpppp( 1, 6,17,3)/
     x-4.3978763d-03, 2.4992993d-02, 2.2762153d-06 /
      data fpppp( 1, 6,18,1),fpppp( 1, 6,18,2),fpppp( 1, 6,18,3)/
     x 3.3430455d-03,-1.0284410d-02,-7.1328607d-06 /
      data fpppp( 1, 6,19,1),fpppp( 1, 6,19,2),fpppp( 1, 6,19,3)/
     x 5.9489131d-03, 1.6183349d-02, 1.1988816d-05 /
      data fpppp( 1, 6,20,1),fpppp( 1, 6,20,2),fpppp( 1, 6,20,3)/
     x-2.9209223d-03,-8.1886616d-03,-3.9152547d-06 /
      data fpppp( 1, 6,21,1),fpppp( 1, 6,21,2),fpppp( 1, 6,21,3)/
     x-2.9209223d-03,-6.3923944d-03,-2.6552748d-06 /
      data fpppp( 1, 6,22,1),fpppp( 1, 6,22,2),fpppp( 1, 6,22,3)/
     x 5.9489131d-03, 8.9982796d-03, 6.9488964d-06 /
      data fpppp( 1, 6,23,1),fpppp( 1, 6,23,2),fpppp( 1, 6,23,3)/
     x 3.3430455d-03, 1.6659599d-02, 1.1766838d-05 /
      data fpppp( 1, 7, 1,1),fpppp( 1, 7, 1,2),fpppp( 1, 7, 1,3)/
     x 2.6461210d-02,-5.0817082d-02, 1.2054434d-05 /
      data fpppp( 1, 7, 2,1),fpppp( 1, 7, 2,2),fpppp( 1, 7, 2,3)/
     x-3.8237190d-02,-2.9954092d-02, 7.2447292d-06 /
      data fpppp( 1, 7, 3,1),fpppp( 1, 7, 3,2),fpppp( 1, 7, 3,3)/
     x 2.5374096d-02, 1.1055210d-02,-2.2023808d-06 /
      data fpppp( 1, 7, 4,1),fpppp( 1, 7, 4,2),fpppp( 1, 7, 4,3)/
     x 2.5374096d-02, 1.7525144d-02,-3.7063319d-06 /
      data fpppp( 1, 7, 5,1),fpppp( 1, 7, 5,2),fpppp( 1, 7, 5,3)/
     x-3.8237190d-02,-5.5833829d-02, 1.3260533d-05 /
      data fpppp( 1, 7, 6,1),fpppp( 1, 7, 6,2),fpppp( 1, 7, 6,3)/
     x 2.6461210d-02, 4.6231930d-02,-1.0504831d-05 /
      data fpppp( 1, 7, 7,1),fpppp( 1, 7, 7,2),fpppp( 1, 7, 7,3)/
     x-1.0144928d-03,-1.9183588d-02,-7.4845882d-07 /
      data fpppp( 1, 7, 8,1),fpppp( 1, 7, 8,2),fpppp( 1, 7, 8,3)/
     x-2.2811814d-02, 9.5097058d-03, 7.2974659d-06 /
      data fpppp( 1, 7, 9,1),fpppp( 1, 7, 9,2),fpppp( 1, 7, 9,3)/
     x 9.9878911d-03,-8.7428839d-03,-7.0044515d-06 /
      data fpppp( 1, 7,10,1),fpppp( 1, 7,10,2),fpppp( 1, 7,10,3)/
     x 3.3874249d-03, 4.5988906d-03, 5.7261462d-06 /
      data fpppp( 1, 7,11,1),fpppp( 1, 7,11,2),fpppp( 1, 7,11,3)/
     x 3.4236714d-02, 5.8056200d-04,-3.4855506d-06 /
      data fpppp( 1, 7,12,1),fpppp( 1, 7,12,2),fpppp( 1, 7,12,3)/
     x 3.4753221d-02,-2.5922710d-03,-1.3399746d-06 /
      data fpppp( 1, 7,13,1),fpppp( 1, 7,13,2),fpppp( 1, 7,13,3)/
     x 1.1406243d-02, 8.0632197d-04, 3.5462276d-06 /
      data fpppp( 1, 7,14,1),fpppp( 1, 7,14,2),fpppp( 1, 7,14,3)/
     x 2.0761790d-02, 3.7742460d-03,-3.0609185d-06 /
      data fpppp( 1, 7,15,1),fpppp( 1, 7,15,2),fpppp( 1, 7,15,3)/
     x 3.4978108d-03,-6.0769581d-03, 1.0994183d-06 /
      data fpppp( 1, 7,16,1),fpppp( 1, 7,16,2),fpppp( 1, 7,16,3)/
     x 2.3029582d-02, 5.7746059d-04, 2.5020006d-06 /
      data fpppp( 1, 7,17,1),fpppp( 1, 7,17,2),fpppp( 1, 7,17,3)/
     x 1.7406622d-02, 1.3584660d-02,-4.8410988d-06 /
      data fpppp( 1, 7,18,1),fpppp( 1, 7,18,2),fpppp( 1, 7,18,3)/
     x 3.2377475d-03,-2.6042199d-02, 7.1212137d-06 /
      data fpppp( 1, 7,19,1),fpppp( 1, 7,19,2),fpppp( 1, 7,19,3)/
     x 2.8961537d-02, 3.2257930d-02,-1.0162989d-05 /
      data fpppp( 1, 7,20,1),fpppp( 1, 7,20,2),fpppp( 1, 7,20,3)/
     x 2.2692910d-02,-1.2556285d-02, 4.0211114d-06 /
      data fpppp( 1, 7,21,1),fpppp( 1, 7,21,2),fpppp( 1, 7,21,3)/
     x 2.2692910d-02,-8.7961538d-03, 2.8864540d-06 /
      data fpppp( 1, 7,22,1),fpppp( 1, 7,22,2),fpppp( 1, 7,22,3)/
     x 2.8961537d-02, 1.7217405d-02,-5.6243591d-06 /
      data fpppp( 1, 7,23,1),fpppp( 1, 7,23,2),fpppp( 1, 7,23,3)/
     x 3.2377475d-03, 3.0359768d-02,-9.8986471d-06 /
      data fpppp( 1, 8, 1,1),fpppp( 1, 8, 1,2),fpppp( 1, 8, 1,3)/
     x-2.6637794d-02, 1.8018669d-02,-8.6693817d-06 /
      data fpppp( 1, 8, 2,1),fpppp( 1, 8, 2,2),fpppp( 1, 8, 2,3)/
     x 3.3605979d-02, 1.0422652d-02,-5.2573607d-06 /
      data fpppp( 1, 8, 3,1),fpppp( 1, 8, 3,2),fpppp( 1, 8, 3,3)/
     x-2.0095204d-02,-4.3003883d-03, 1.3042851d-06 /
      data fpppp( 1, 8, 4,1),fpppp( 1, 8, 4,2),fpppp( 1, 8, 4,3)/
     x-2.0095204d-02,-7.0201326d-03, 2.6164839d-06 /
      data fpppp( 1, 8, 5,1),fpppp( 1, 8, 5,2),fpppp( 1, 8, 5,3)/
     x 3.3605979d-02, 2.1301629d-02,-1.0506156d-05 /
      data fpppp( 1, 8, 6,1),fpppp( 1, 8, 6,2),fpppp( 1, 8, 6,3)/
     x-2.6637794d-02,-2.2777496d-02, 1.1013600d-05 /
      data fpppp( 1, 8, 7,1),fpppp( 1, 8, 7,2),fpppp( 1, 8, 7,3)/
     x-3.9493921d-04, 1.0407795d-02, 8.8529638d-06 /
      data fpppp( 1, 8, 8,1),fpppp( 1, 8, 8,2),fpppp( 1, 8, 8,3)/
     x 9.1935084d-02, 1.8940336d-02,-2.7467982d-05 /
      data fpppp( 1, 8, 9,1),fpppp( 1, 8, 9,2),fpppp( 1, 8, 9,3)/
     x-8.0522922d-03,-3.9449212d-02, 2.1005162d-05 /
      data fpppp( 1, 8,10,1),fpppp( 1, 8,10,2),fpppp( 1, 8,10,3)/
     x-7.3820474d-04, 3.8270187d-02,-1.3249819d-05 /
      data fpppp( 1, 8,11,1),fpppp( 1, 8,11,2),fpppp( 1, 8,11,3)/
     x-7.1746815d-02,-2.3237582d-02, 6.1321284d-06 /
      data fpppp( 1, 8,12,1),fpppp( 1, 8,12,2),fpppp( 1, 8,12,3)/
     x-7.3948679d-02, 1.1856314d-02, 1.0083983d-05 /
      data fpppp( 1, 8,13,1),fpppp( 1, 8,13,2),fpppp( 1, 8,13,3)/
     x 1.1715537d-02,-2.1967098d-02,-1.9993724d-05 /
      data fpppp( 1, 8,14,1),fpppp( 1, 8,14,2),fpppp( 1, 8,14,3)/
     x-6.5460174d-02, 3.7391956d-02, 2.0161179d-05 /
      data fpppp( 1, 8,15,1),fpppp( 1, 8,15,2),fpppp( 1, 8,15,3)/
     x 1.2988667d-02,-4.3336392d-02,-1.2971610d-05 /
      data fpppp( 1, 8,16,1),fpppp( 1, 8,16,2),fpppp( 1, 8,16,3)/
     x-6.1264308d-03, 4.4093981d-02, 4.0465892d-06 /
      data fpppp( 1, 8,17,1),fpppp( 1, 8,17,2),fpppp( 1, 8,17,3)/
     x-2.3474986d-03,-2.5207462d-02, 4.1902408d-07 /
      data fpppp( 1, 8,18,1),fpppp( 1, 8,18,2),fpppp( 1, 8,18,3)/
     x 4.7186301d-04, 6.3930049d-03,-3.5051025d-06 /
      data fpppp( 1, 8,19,1),fpppp( 1, 8,19,2),fpppp( 1, 8,19,3)/
     x-2.8580425d-02, 5.5082799d-03, 4.5609289d-06 /
      data fpppp( 1, 8,20,1),fpppp( 1, 8,20,2),fpppp( 1, 8,20,3)/
     x-3.0123238d-02,-5.7558677d-03,-1.4938840d-06 /
      data fpppp( 1, 8,21,1),fpppp( 1, 8,21,2),fpppp( 1, 8,21,3)/
     x-3.0123238d-02,-5.5483419d-03,-9.7687712d-07 /
      data fpppp( 1, 8,22,1),fpppp( 1, 8,22,2),fpppp( 1, 8,22,3)/
     x-2.8580425d-02, 4.6781767d-03, 2.4929015d-06 /
      data fpppp( 1, 8,23,1),fpppp( 1, 8,23,2),fpppp( 1, 8,23,3)/
     x 4.7186301d-04, 9.5058922d-03, 4.2500001d-06 /
      data fpppp( 1, 9, 1,1),fpppp( 1, 9, 1,2),fpppp( 1, 9, 1,3)/
     x 1.6399968d-02,-5.0055079d-03, 1.7758942d-06 /
      data fpppp( 1, 9, 2,1),fpppp( 1, 9, 2,2),fpppp( 1, 9, 2,3)/
     x-7.6388470d-03,-3.2251386d-03, 9.0749080d-07 /
      data fpppp( 1, 9, 3,1),fpppp( 1, 9, 3,2),fpppp( 1, 9, 3,3)/
     x 8.7553395d-03, 1.2649487d-03,-7.8954991d-07 /
      data fpppp( 1, 9, 4,1),fpppp( 1, 9, 4,2),fpppp( 1, 9, 4,3)/
     x 8.7553395d-03, 8.3681020d-05,-1.0762414d-06 /
      data fpppp( 1, 9, 5,1),fpppp( 1, 9, 5,2),fpppp( 1, 9, 5,3)/
     x-7.6388470d-03, 1.4999320d-03, 2.0542569d-06 /
      data fpppp( 1, 9, 6,1),fpppp( 1, 9, 6,2),fpppp( 1, 9, 6,3)/
     x 1.6399968d-02,-2.2724523d-02,-2.5244786d-06 /
      data fpppp( 1, 9, 7,1),fpppp( 1, 9, 7,2),fpppp( 1, 9, 7,3)/
     x 1.0437176d-02, 8.4457532d-02,-1.4415289d-05 /
      data fpppp( 1, 9, 8,1),fpppp( 1, 9, 8,2),fpppp( 1, 9, 8,3)/
     x-1.4500160d-01,-9.7973774d-02, 4.5262179d-05 /
      data fpppp( 1, 9, 9,1),fpppp( 1, 9, 9,2),fpppp( 1, 9, 9,3)/
     x 3.2921158d-02, 9.4540305d-03,-4.6701894d-05 /
      data fpppp( 1, 9,10,1),fpppp( 1, 9,10,2),fpppp( 1, 9,10,3)/
     x-5.8116822d-04, 5.8228545d-02, 4.1941246d-05 /
      data fpppp( 1, 9,11,1),fpppp( 1, 9,11,2),fpppp( 1, 9,11,3)/
     x 2.6771830d-01,-4.5852777d-02,-2.0214324d-05 /
      data fpppp( 1, 9,12,1),fpppp( 1, 9,12,2),fpppp( 1, 9,12,3)/
     x 2.7980031d-01, 2.3882790d-02,-3.9745588d-05 /
      data fpppp( 1, 9,13,1),fpppp( 1, 9,13,2),fpppp( 1, 9,13,3)/
     x-4.6395781d-02,-4.6932290d-02, 7.5846713d-05 /
      data fpppp( 1, 9,14,1),fpppp( 1, 9,14,2),fpppp( 1, 9,14,3)/
     x 2.4145906d-01, 7.7592617d-02,-7.5447745d-05 /
      data fpppp( 1, 9,15,1),fpppp( 1, 9,15,2),fpppp( 1, 9,15,3)/
     x-4.6276219d-02,-8.4447294d-02, 4.9784652d-05 /
      data fpppp( 1, 9,16,1),fpppp( 1, 9,16,2),fpppp( 1, 9,16,3)/
     x 1.6613755d-03, 7.8646292d-02,-2.1193245d-05 /
      data fpppp( 1, 9,17,1),fpppp( 1, 9,17,2),fpppp( 1, 9,17,3)/
     x-3.9179069d-02,-4.6647926d-02, 9.0158828d-06 /
      data fpppp( 1, 9,18,1),fpppp( 1, 9,18,2),fpppp( 1, 9,18,3)/
     x-3.4608465d-02, 1.1412635d-02,-1.2943174d-06 /
      data fpppp( 1, 9,19,1),fpppp( 1, 9,19,2),fpppp( 1, 9,19,3)/
     x-1.7162163d-02,-3.6489710d-03, 4.0756832d-07 /
      data fpppp( 1, 9,20,1),fpppp( 1, 9,20,2),fpppp( 1, 9,20,3)/
     x-3.3976530d-02, 1.8753416d-03,-8.6208268d-07 /
      data fpppp( 1, 9,21,1),fpppp( 1, 9,21,2),fpppp( 1, 9,21,3)/
     x-3.3976530d-02, 1.0380179d-03,-7.5317178d-07 /
      data fpppp( 1, 9,22,1),fpppp( 1, 9,22,2),fpppp( 1, 9,22,3)/
     x-1.7162163d-02,-2.9967628d-04,-2.8075264d-08 /
      data fpppp( 1, 9,23,1),fpppp( 1, 9,23,2),fpppp( 1, 9,23,3)/
     x-3.4608465d-02,-1.1472199d-03, 3.3934602d-07 /
      data fpppp( 1,10, 1,1),fpppp( 1,10, 1,2),fpppp( 1,10, 1,3)/
     x-1.2942642d-02,-1.4155272d-02, 1.7538287d-06 /
      data fpppp( 1,10, 2,1),fpppp( 1,10, 2,2),fpppp( 1,10, 2,3)/
     x-1.0877414d-02,-8.0717029d-03, 7.6004007d-07 /
      data fpppp( 1,10, 3,1),fpppp( 1,10, 3,2),fpppp( 1,10, 3,3)/
     x-1.0572589d-02, 3.7776183d-03,-1.2276794d-06 /
      data fpppp( 1,10, 4,1),fpppp( 1,10, 4,2),fpppp( 1,10, 4,3)/
     x-1.0572589d-02, 5.8546897d-03,-1.4758775d-06 /
      data fpppp( 1,10, 5,1),fpppp( 1,10, 5,2),fpppp( 1,10, 5,3)/
     x-1.0877414d-02,-1.6379988d-02, 1.7528323d-06 /
      data fpppp( 1,10, 6,1),fpppp( 1,10, 6,2),fpppp( 1,10, 6,3)/
     x-1.2942642d-02, 1.7000799d-02,-1.9691421d-06 /
      data fpppp( 1,10, 7,1),fpppp( 1,10, 7,2),fpppp( 1,10, 7,3)/
     x-1.6436845d-02,-3.7052682d-02, 1.1762311d-05 /
      data fpppp( 1,10, 8,1),fpppp( 1,10, 8,2),fpppp( 1,10, 8,3)/
     x 9.2333078d-02, 1.0812694d-01,-3.5411042d-05 /
      data fpppp( 1,10, 9,1),fpppp( 1,10, 9,2),fpppp( 1,10, 9,3)/
     x-9.5304734d-02,-1.9342108d-01, 5.6932521d-05 /
      data fpppp( 1,10,10,1),fpppp( 1,10,10,2),fpppp( 1,10,10,3)/
     x 2.5922233d-03, 3.0942139d-01,-7.4083129d-05 /
      data fpppp( 1,10,11,1),fpppp( 1,10,11,2),fpppp( 1,10,11,3)/
     x-4.6344693d-01,-1.7667920d-01, 3.9546358d-05 /
      data fpppp( 1,10,12,1),fpppp( 1,10,12,2),fpppp( 1,10,12,3)/
     x-4.8211701d-01,-2.7117437d-01, 5.5575689d-05 /
      data fpppp( 1,10,13,1),fpppp( 1,10,13,2),fpppp( 1,10,13,3)/
     x 3.6041096d-02, 5.3623015d-01,-9.7171760d-05 /
      data fpppp( 1,10,14,1),fpppp( 1,10,14,2),fpppp( 1,10,14,3)/
     x-2.6261237d-01,-5.3108141d-01, 8.3023333d-05 /
      data fpppp( 1,10,15,1),fpppp( 1,10,15,2),fpppp( 1,10,15,3)/
     x 3.6744502d-02, 3.1308731d-01,-5.1611259d-05 /
      data fpppp( 1,10,16,1),fpppp( 1,10,16,2),fpppp( 1,10,16,3)/
     x-4.4357157d-04,-8.3926138d-02, 2.0537937d-05 /
      data fpppp( 1,10,17,1),fpppp( 1,10,17,2),fpppp( 1,10,17,3)/
     x 3.5326868d-02, 2.2505451d-02,-8.4872803d-06 /
      data fpppp( 1,10,18,1),fpppp( 1,10,18,2),fpppp( 1,10,18,3)/
     x 3.3052762d-02,-6.1782769d-03, 1.8368062d-06 /
      data fpppp( 1,10,19,1),fpppp( 1,10,19,2),fpppp( 1,10,19,3)/
     x 2.6018585d-02, 1.9131820d-03,-3.0765300d-07 /
      data fpppp( 1,10,20,1),fpppp( 1,10,20,2),fpppp( 1,10,20,3)/
     x 1.5486013d-01,-4.1800749d-04, 1.6130399d-07 /
      data fpppp( 1,10,21,1),fpppp( 1,10,21,2),fpppp( 1,10,21,3)/
     x 1.5486013d-01, 1.7721020d-05, 4.9121749d-08 /
      data fpppp( 1,10,22,1),fpppp( 1,10,22,2),fpppp( 1,10,22,3)/
     x 2.6018585d-02, 1.7026797d-04, 1.4107596d-07 /
      data fpppp( 1,10,23,1),fpppp( 1,10,23,2),fpppp( 1,10,23,3)/
     x 3.3052762d-02, 3.5765081d-04, 1.5407266d-07 /
      data fpppp( 1,11, 1,1),fpppp( 1,11, 1,2),fpppp( 1,11, 1,3)/
     x 9.6285439d-03, 2.2732285d-03, 1.0114720d-05 /
      data fpppp( 1,11, 2,1),fpppp( 1,11, 2,2),fpppp( 1,11, 2,3)/
     x 1.4860296d-02, 9.3401169d-04, 4.8167519d-06 /
      data fpppp( 1,11, 3,1),fpppp( 1,11, 3,2),fpppp( 1,11, 3,3)/
     x 5.9536840d-02,-1.8609108d-03,-6.2455126d-06 /
      data fpppp( 1,11, 4,1),fpppp( 1,11, 4,2),fpppp( 1,11, 4,3)/
     x 5.9536840d-02,-1.9918594d-03,-6.7539293d-06 /
      data fpppp( 1,11, 5,1),fpppp( 1,11, 5,2),fpppp( 1,11, 5,3)/
     x 1.4860296d-02, 1.4578062d-03, 6.8504186d-06 /
      data fpppp( 1,11, 6,1),fpppp( 1,11, 6,2),fpppp( 1,11, 6,3)/
     x 9.6285439d-03, 3.0899911d-04, 2.4884693d-06 /
      data fpppp( 1,11, 7,1),fpppp( 1,11, 7,2),fpppp( 1,11, 7,3)/
     x 1.0359065d-02, 1.6326391d-03,-3.5112508d-06 /
      data fpppp( 1,11, 8,1),fpppp( 1,11, 8,2),fpppp( 1,11, 8,3)/
     x-2.4303677d-02,-5.9501096d-03, 1.3239183d-05 /
      data fpppp( 1,11, 9,1),fpppp( 1,11, 9,2),fpppp( 1,11, 9,3)/
     x 8.0952767d-02, 1.1869092d-02,-2.6548753d-05 /
      data fpppp( 1,11,10,1),fpppp( 1,11,10,2),fpppp( 1,11,10,3)/
     x-4.7203120d-03,-1.2084662d-02, 4.8366881d-05 /
      data fpppp( 1,11,11,1),fpppp( 1,11,11,2),fpppp( 1,11,11,3)/
     x 3.0934632d-01, 2.0921752d-02,-2.9408669d-05 /
      data fpppp( 1,11,12,1),fpppp( 1,11,12,2),fpppp( 1,11,12,3)/
     x 3.2814645d-01,-6.9249750d-02,-3.2205097d-05 /
      data fpppp( 1,11,13,1),fpppp( 1,11,13,2),fpppp( 1,11,13,3)/
     x-9.3802965d-03, 2.5574590d-01, 4.8929760d-05 /
      data fpppp( 1,11,14,1),fpppp( 1,11,14,2),fpppp( 1,11,14,3)/
     x 8.5048581d-02,-4.0339013d-01,-3.1049425d-05 /
      data fpppp( 1,11,15,1),fpppp( 1,11,15,2),fpppp( 1,11,15,3)/
     x-9.7289082d-03, 2.5605224d-01, 1.7390386d-05 /
      data fpppp( 1,11,16,1),fpppp( 1,11,16,2),fpppp( 1,11,16,3)/
     x 2.1189777d-04,-7.0373740d-02,-6.4147468d-06 /
      data fpppp( 1,11,17,1),fpppp( 1,11,17,2),fpppp( 1,11,17,3)/
     x-9.4233495d-03, 2.5209157d-02, 2.3610201d-06 /
      data fpppp( 1,11,18,1),fpppp( 1,11,18,2),fpppp( 1,11,18,3)/
     x-8.9991165d-03,-3.0802990d-02,-2.1468684d-08 /
      data fpppp( 1,11,19,1),fpppp( 1,11,19,2),fpppp( 1,11,19,3)/
     x-9.3060265d-03, 9.5164482d-02,-2.9891335d-06 /
      data fpppp( 1,11,20,1),fpppp( 1,11,20,2),fpppp( 1,11,20,3)/
     x-2.2351410d-01,-5.1093108d-02, 1.7103365d-06 /
      data fpppp( 1,11,21,1),fpppp( 1,11,21,2),fpppp( 1,11,21,3)/
     x-2.2351410d-01,-4.1873756d-02, 1.4653641d-06 /
      data fpppp( 1,11,22,1),fpppp( 1,11,22,2),fpppp( 1,11,22,3)/
     x-9.3060265d-03, 5.8287074d-02,-2.0092441d-06 /
      data fpppp( 1,11,23,1),fpppp( 1,11,23,2),fpppp( 1,11,23,3)/
     x-8.9991165d-03, 1.0748729d-01,-3.6960539d-06 /
      data fpppp( 1,12, 1,1),fpppp( 1,12, 1,2),fpppp( 1,12, 1,3)/
     x 1.8107267d-04, 1.2736952d-02,-5.9907616d-06 /
      data fpppp( 1,12, 2,1),fpppp( 1,12, 2,2),fpppp( 1,12, 2,3)/
     x 5.4220582d-03, 5.9698630d-03,-4.1108592d-06 /
      data fpppp( 1,12, 3,1),fpppp( 1,12, 3,2),fpppp( 1,12, 3,3)/
     x-1.6783385d-01,-8.1333419d-03,-5.4872914d-07 /
      data fpppp( 1,12, 4,1),fpppp( 1,12, 4,2),fpppp( 1,12, 4,3)/
     x-1.6783385d-01,-8.8293155d-03, 2.6717703d-07 /
      data fpppp( 1,12, 5,1),fpppp( 1,12, 5,2),fpppp( 1,12, 5,3)/
     x 5.4220582d-03, 8.7537575d-03,-7.3744839d-06 /
      data fpppp( 1,12, 6,1),fpppp( 1,12, 6,2),fpppp( 1,12, 6,3)/
     x 1.8107267d-04, 2.2973476d-03, 6.2478311d-06 /
      data fpppp( 1,12, 7,1),fpppp( 1,12, 7,2),fpppp( 1,12, 7,3)/
     x-2.4328832d-03, 1.1863549d-03, 8.3272503d-07 /
      data fpppp( 1,12, 8,1),fpppp( 1,12, 8,2),fpppp( 1,12, 8,3)/
     x 6.3765525d-03,-6.6414604d-05,-1.5574296d-06 /
      data fpppp( 1,12, 9,1),fpppp( 1,12, 9,2),fpppp( 1,12, 9,3)/
     x-2.5336538d-02,-8.0562394d-04, 1.7649312d-06 /
      data fpppp( 1,12,10,1),fpppp( 1,12,10,2),fpppp( 1,12,10,3)/
     x 4.7784119d-03, 1.9528142d-03,-4.6506587d-06 /
      data fpppp( 1,12,11,1),fpppp( 1,12,11,2),fpppp( 1,12,11,3)/
     x-8.2572131d-02, 1.1870700d-02, 3.3348924d-07 /
      data fpppp( 1,12,12,1),fpppp( 1,12,12,2),fpppp( 1,12,12,3)/
     x-1.2303783d-01,-6.3072713d-02, 1.6465757d-05 /
      data fpppp( 1,12,13,1),fpppp( 1,12,13,2),fpppp( 1,12,13,3)/
     x 2.5826830d-03, 2.4251083d-01,-1.7464925d-05 /
      data fpppp( 1,12,14,1),fpppp( 1,12,14,2),fpppp( 1,12,14,3)/
     x-1.7154519d-02,-3.8329478d-01, 8.4738533d-06 /
      data fpppp( 1,12,15,1),fpppp( 1,12,15,2),fpppp( 1,12,15,3)/
     x 2.7779612d-03, 2.4300626d-01,-4.2406624d-06 /
      data fpppp( 1,12,16,1),fpppp( 1,12,16,2),fpppp( 1,12,16,3)/
     x 1.5044791d-04,-6.5413532d-02, 1.6811182d-06 /
      data fpppp( 1,12,17,1),fpppp( 1,12,17,2),fpppp( 1,12,17,3)/
     x 2.8067328d-03, 1.8230633d-02,-6.5541098d-07 /
      data fpppp( 1,12,18,1),fpppp( 1,12,18,2),fpppp( 1,12,18,3)/
     x 2.8764733d-03,-8.4997561d-03, 4.5284525d-07 /
      data fpppp( 1,12,19,1),fpppp( 1,12,19,2),fpppp( 1,12,19,3)/
     x 5.8557889d-03, 5.6111596d-03, 2.9757090d-07 /
      data fpppp( 1,12,20,1),fpppp( 1,12,20,2),fpppp( 1,12,20,3)/
     x 1.4502354d-01,-1.0181788d-03,-4.9248261d-07 /
      data fpppp( 1,12,21,1),fpppp( 1,12,21,2),fpppp( 1,12,21,3)/
     x 1.4502354d-01,-2.0150446d-04,-4.8235205d-07 /
      data fpppp( 1,12,22,1),fpppp( 1,12,22,2),fpppp( 1,12,22,3)/
     x 5.8557889d-03, 2.3444621d-03, 2.5704863d-07 /
      data fpppp( 1,12,23,1),fpppp( 1,12,23,2),fpppp( 1,12,23,3)/
     x 2.8764733d-03, 3.7503596d-03, 6.0480376d-07 /
      data fpppp( 1,13, 1,1),fpppp( 1,13, 1,2),fpppp( 1,13, 1,3)/
     x-2.4534290d-03,-1.8866632d-01,-1.6914029d-05 /
      data fpppp( 1,13, 2,1),fpppp( 1,13, 2,2),fpppp( 1,13, 2,3)/
     x-8.2327095d-03,-1.0433215d-01,-7.8636037d-06 /
      data fpppp( 1,13, 3,1),fpppp( 1,13, 3,2),fpppp( 1,13, 3,3)/
     x 6.8740338d-02, 6.7022205d-02, 1.1103620d-05 /
      data fpppp( 1,13, 4,1),fpppp( 1,13, 4,2),fpppp( 1,13, 4,3)/
     x 6.8740338d-02, 8.3405252d-02, 1.1850074d-05 /
      data fpppp( 1,13, 5,1),fpppp( 1,13, 5,2),fpppp( 1,13, 5,3)/
     x-8.2327095d-03,-1.6986434d-01,-1.0849420d-05 /
      data fpppp( 1,13, 6,1),fpppp( 1,13, 6,2),fpppp( 1,13, 6,3)/
     x-2.4534290d-03, 5.7079378d-02,-5.7172163d-06 /
      data fpppp( 1,13, 7,1),fpppp( 1,13, 7,2),fpppp( 1,13, 7,3)/
     x 5.7879915d-04,-1.0797274d-02,-1.5020607d-06 /
      data fpppp( 1,13, 8,1),fpppp( 1,13, 8,2),fpppp( 1,13, 8,3)/
     x-1.7317709d-03, 4.1304829d-03, 6.9520327d-07 /
      data fpppp( 1,13, 9,1),fpppp( 1,13, 9,2),fpppp( 1,13, 9,3)/
     x 1.1484502d-02,-1.8398825d-03, 4.2808663d-07 /
      data fpppp( 1,13,10,1),fpppp( 1,13,10,2),fpppp( 1,13,10,3)/
     x-1.1191563d-03, 1.6779677d-03,-5.9778282d-06 /
      data fpppp( 1,13,11,1),fpppp( 1,13,11,2),fpppp( 1,13,11,3)/
     x 1.7986594d-02, 1.0015625d-02, 2.2729980d-05 /
      data fpppp( 1,13,12,1),fpppp( 1,13,12,2),fpppp( 1,13,12,3)/
     x 1.6594624d-01,-5.0240476d-02,-3.2601141d-05 /
      data fpppp( 1,13,13,1),fpppp( 1,13,13,2),fpppp( 1,13,13,3)/
     x 2.4822260d-04, 1.8981927d-01, 8.7055552d-06 /
      data fpppp( 1,13,14,1),fpppp( 1,13,14,2),fpppp( 1,13,14,3)/
     x-1.0326102d-01,-2.9931513d-01, 1.6747004d-05 /
      data fpppp( 1,13,15,1),fpppp( 1,13,15,2),fpppp( 1,13,15,3)/
     x-3.6821220d-04, 1.8975394d-01,-1.2811479d-05 /
      data fpppp( 1,13,16,1),fpppp( 1,13,16,2),fpppp( 1,13,16,3)/
     x 4.8434806d-04,-5.1074246d-02, 3.1531752d-06 /
      data fpppp( 1,13,17,1),fpppp( 1,13,17,2),fpppp( 1,13,17,3)/
     x 4.9161082d-05, 1.4213514d-02,-2.5395747d-07 /
      data fpppp( 1,13,18,1),fpppp( 1,13,18,2),fpppp( 1,13,18,3)/
     x 7.1885672d-04,-6.6030385d-03,-2.1746082d-06 /
      data fpppp( 1,13,19,1),fpppp( 1,13,19,2),fpppp( 1,13,19,3)/
     x 1.9878748d-03, 6.2289763d-03, 7.4586947d-06 /
      data fpppp( 1,13,20,1),fpppp( 1,13,20,2),fpppp( 1,13,20,3)/
     x-3.8438331d-02,-2.0639378d-03,-3.8615295d-06 /
      data fpppp( 1,13,21,1),fpppp( 1,13,21,2),fpppp( 1,13,21,3)/
     x-3.8438331d-02,-1.2711194d-03,-3.1534880d-06 /
      data fpppp( 1,13,22,1),fpppp( 1,13,22,2),fpppp( 1,13,22,3)/
     x 1.9878748d-03, 3.0577026d-03, 4.6265287d-06 /
      data fpppp( 1,13,23,1),fpppp( 1,13,23,2),fpppp( 1,13,23,3)/
     x 7.1885672d-04, 5.2892378d-03, 8.4460143d-06 /
      data fpppp( 1,14, 1,1),fpppp( 1,14, 1,2),fpppp( 1,14, 1,3)/
     x-3.8313820d-03,-2.4381725d-01, 1.1390224d-05 /
      data fpppp( 1,14, 2,1),fpppp( 1,14, 2,2),fpppp( 1,14, 2,3)/
     x-1.8470812d-02,-1.3448073d-01, 8.0596416d-06 /
      data fpppp( 1,14, 3,1),fpppp( 1,14, 3,2),fpppp( 1,14, 3,3)/
     x 2.2682541d-01, 8.7759737d-02, 1.8993535d-06 /
      data fpppp( 1,14, 4,1),fpppp( 1,14, 4,2),fpppp( 1,14, 4,3)/
     x 2.2682541d-01, 1.0885090d-01, 1.9017440d-07 /
      data fpppp( 1,14, 5,1),fpppp( 1,14, 5,2),fpppp( 1,14, 5,3)/
     x-1.8470812d-02,-2.1884538d-01, 1.4896358d-05 /
      data fpppp( 1,14, 6,1),fpppp( 1,14, 6,2),fpppp( 1,14, 6,3)/
     x-3.8313820d-03, 7.2550208d-02,-1.4247462d-05 /
      data fpppp( 1,14, 7,1),fpppp( 1,14, 7,2),fpppp( 1,14, 7,3)/
     x-1.5356330d-03,-1.5878009d-02,-4.9328830d-07 /
      data fpppp( 1,14, 8,1),fpppp( 1,14, 8,2),fpppp( 1,14, 8,3)/
     x-6.4862759d-05, 9.2542266d-03,-1.6407829d-06 /
      data fpppp( 1,14, 9,1),fpppp( 1,14, 9,2),fpppp( 1,14, 9,3)/
     x-6.9815446d-03,-2.8702546d-04,-5.0711405d-07 /
      data fpppp( 1,14,10,1),fpppp( 1,14,10,2),fpppp( 1,14,10,3)/
     x-4.3056887d-04,-3.7856214d-02, 5.5614364d-06 /
      data fpppp( 1,14,11,1),fpppp( 1,14,11,2),fpppp( 1,14,11,3)/
     x-1.5608579d-03, 1.6430166d-01,-2.5133633d-05 /
      data fpppp( 1,14,12,1),fpppp( 1,14,12,2),fpppp( 1,14,12,3)/
     x-1.9868450d-01,-2.5640627d-01, 3.8755033d-05 /
      data fpppp( 1,14,13,1),fpppp( 1,14,13,2),fpppp( 1,14,13,3)/
     x-3.4270320d-03, 1.6081543d-01,-8.6005773d-06 /
      data fpppp( 1,14,14,1),fpppp( 1,14,14,2),fpppp( 1,14,14,3)/
     x 1.3650669d-01,-4.3014720d-02,-2.3318770d-05 /
      data fpppp( 1,14,15,1),fpppp( 1,14,15,2),fpppp( 1,14,15,3)/
     x-8.2158234d-04, 1.1546821d-02, 1.7411903d-05 /
      data fpppp( 1,14,16,1),fpppp( 1,14,16,2),fpppp( 1,14,16,3)/
     x-1.2757444d-03,-3.0833685d-03,-4.5543706d-06 /
      data fpppp( 1,14,17,1),fpppp( 1,14,17,2),fpppp( 1,14,17,3)/
     x-1.4686951d-03, 9.3886192d-04, 6.4304466d-07 /
      data fpppp( 1,14,18,1),fpppp( 1,14,18,2),fpppp( 1,14,18,3)/
     x-2.3300548d-03,-1.6320240d-04, 1.4770040d-06 /
      data fpppp( 1,14,19,1),fpppp( 1,14,19,2),fpppp( 1,14,19,3)/
     x-5.4874384d-03, 9.4269266d-04,-7.0784594d-06 /
      data fpppp( 1,14,20,1),fpppp( 1,14,20,2),fpppp( 1,14,20,3)/
     x 5.2563911d-03,-7.2766223d-04, 4.1285426d-06 /
      data fpppp( 1,14,21,1),fpppp( 1,14,21,2),fpppp( 1,14,21,3)/
     x 5.2563911d-03,-6.3816568d-04, 3.4741725d-06 /
      data fpppp( 1,14,22,1),fpppp( 1,14,22,2),fpppp( 1,14,22,3)/
     x-5.4874384d-03, 5.8470645d-04,-4.4609788d-06 /
      data fpppp( 1,14,23,1),fpppp( 1,14,23,2),fpppp( 1,14,23,3)/
     x-2.3300548d-03, 1.1792459d-03,-8.3385482d-06 /
      data fpppp( 1,15, 1,1),fpppp( 1,15, 1,2),fpppp( 1,15, 1,3)/
     x 2.6114958d-04, 1.0391598d-02,-1.0775296d-05 /
      data fpppp( 1,15, 2,1),fpppp( 1,15, 2,2),fpppp( 1,15, 2,3)/
     x 7.1051212d-03, 4.5627001d-03,-6.6029938d-06 /
      data fpppp( 1,15, 3,1),fpppp( 1,15, 3,2),fpppp( 1,15, 3,3)/
     x-2.3855266d-01,-7.6373636d-03, 1.5602798d-06 /
      data fpppp( 1,15, 4,1),fpppp( 1,15, 4,2),fpppp( 1,15, 4,3)/
     x-2.3855266d-01,-8.1456195d-03, 2.9206838d-06 /
      data fpppp( 1,15, 5,1),fpppp( 1,15, 5,2),fpppp( 1,15, 5,3)/
     x 7.1051212d-03, 6.5957238d-03,-1.2044610d-05 /
      data fpppp( 1,15, 6,1),fpppp( 1,15, 6,2),fpppp( 1,15, 6,3)/
     x 2.6114958d-04, 2.7677594d-03, 9.6307640d-06 /
      data fpppp( 1,15, 7,1),fpppp( 1,15, 7,2),fpppp( 1,15, 7,3)/
     x 3.4237706d-04, 4.3564141d-04,-1.4448605d-06 /
      data fpppp( 1,15, 8,1),fpppp( 1,15, 8,2),fpppp( 1,15, 8,3)/
     x 5.2028049d-04, 5.5076681d-03,-4.9087231d-07 /
      data fpppp( 1,15, 9,1),fpppp( 1,15, 9,2),fpppp( 1,15, 9,3)/
     x-1.5047386d-03,-4.8732331d-03, 8.5380650d-07 /
      data fpppp( 1,15,10,1),fpppp( 1,15,10,2),fpppp( 1,15,10,3)/
     x 7.5448643d-04,-1.1628892d-02,-2.5121445d-06 /
      data fpppp( 1,15,11,1),fpppp( 1,15,11,2),fpppp( 1,15,11,3)/
     x 2.3094257d-03, 6.1960799d-02, 7.8622620d-06 /
      data fpppp( 1,15,12,1),fpppp( 1,15,12,2),fpppp( 1,15,12,3)/
     x 6.5448346d-02,-9.5361579d-02,-1.1217849d-05 /
      data fpppp( 1,15,13,1),fpppp( 1,15,13,2),fpppp( 1,15,13,3)/
     x 1.2224132d-02, 5.9100197d-02, 2.9310391d-06 /
      data fpppp( 1,15,14,1),fpppp( 1,15,14,2),fpppp( 1,15,14,3)/
     x-3.4640488d-02,-1.5825901d-02, 6.3001137d-06 /
      data fpppp( 1,15,15,1),fpppp( 1,15,15,2),fpppp( 1,15,15,3)/
     x 2.9230839d-03, 4.2797447d-03,-4.7006521d-06 /
      data fpppp( 1,15,16,1),fpppp( 1,15,16,2),fpppp( 1,15,16,3)/
     x 3.6563761d-03,-1.1151855d-03, 1.2041413d-06 /
      data fpppp( 1,15,17,1),fpppp( 1,15,17,2),fpppp( 1,15,17,3)/
     x 4.1796708d-03, 3.6204151d-04,-1.5135963d-07 /
      data fpppp( 1,15,18,1),fpppp( 1,15,18,2),fpppp( 1,15,18,3)/
     x 4.7630912d-03,-6.2547435d-07,-2.7948798d-07 /
      data fpppp( 1,15,19,1),fpppp( 1,15,19,2),fpppp( 1,15,19,3)/
     x 5.9576032d-03, 9.3932760d-05, 2.3565625d-06 /
      data fpppp( 1,15,20,1),fpppp( 1,15,20,2),fpppp( 1,15,20,3)/
     x 3.9383669d-03,-1.6834253d-04,-1.5298790d-06 /
      data fpppp( 1,15,21,1),fpppp( 1,15,21,2),fpppp( 1,15,21,3)/
     x 3.9383669d-03,-1.5804411d-04,-1.3186580d-06 /
      data fpppp( 1,15,22,1),fpppp( 1,15,22,2),fpppp( 1,15,22,3)/
     x 5.9576032d-03, 5.2739082d-05, 1.5116783d-06 /
      data fpppp( 1,15,23,1),fpppp( 1,15,23,2),fpppp( 1,15,23,3)/
     x 4.7630912d-03, 1.5385082d-04, 2.8888275d-06 /
      data fpppp( 1,16, 1,1),fpppp( 1,16, 1,2),fpppp( 1,16, 1,3)/
     x-2.0091568d-03, 1.3775204d-02, 1.1296552d-05 /
      data fpppp( 1,16, 2,1),fpppp( 1,16, 2,2),fpppp( 1,16, 2,3)/
     x 2.8202719d-03, 7.2647652d-03, 5.3791775d-06 /
      data fpppp( 1,16, 3,1),fpppp( 1,16, 3,2),fpppp( 1,16, 3,3)/
     x 5.8536175d-02,-6.0286830d-03,-6.9158021d-06 /
      data fpppp( 1,16, 4,1),fpppp( 1,16, 4,2),fpppp( 1,16, 4,3)/
     x 5.8536175d-02,-7.1792937d-03,-7.5897433d-06 /
      data fpppp( 1,16, 5,1),fpppp( 1,16, 5,2),fpppp( 1,16, 5,3)/
     x 2.8202719d-03, 1.1867208d-02, 8.0749424d-06 /
      data fpppp( 1,16, 6,1),fpppp( 1,16, 6,2),fpppp( 1,16, 6,3)/
     x-2.0091568d-03,-3.4839580d-03, 1.1874338d-06 /
      data fpppp( 1,16, 7,1),fpppp( 1,16, 7,2),fpppp( 1,16, 7,3)/
     x-3.4949186d-03, 1.4967698d-03, 1.4290383d-06 /
      data fpppp( 1,16, 8,1),fpppp( 1,16, 8,2),fpppp( 1,16, 8,3)/
     x-3.7491991d-03, 3.3673338d-05, 7.6069222d-07 /
      data fpppp( 1,16, 9,1),fpppp( 1,16, 9,2),fpppp( 1,16, 9,3)/
     x 4.4198668d-04,-5.0849670d-05,-9.1514038d-07 /
      data fpppp( 1,16,10,1),fpppp( 1,16,10,2),fpppp( 1,16,10,3)/
     x-3.7644833d-03, 8.9847978d-04, 1.3859507d-07 /
      data fpppp( 1,16,11,1),fpppp( 1,16,11,2),fpppp( 1,16,11,3)/
     x-5.3229637d-03,-2.8392683d-03, 1.0358385d-06 /
      data fpppp( 1,16,12,1),fpppp( 1,16,12,2),fpppp( 1,16,12,3)/
     x 1.9199956d-02, 5.6438734d-03,-1.7886274d-06 /
      data fpppp( 1,16,13,1),fpppp( 1,16,13,2),fpppp( 1,16,13,3)/
     x-4.7004979d-02,-3.7981278d-03, 3.0965248d-06 /
      data fpppp( 1,16,14,1),fpppp( 1,16,14,2),fpppp( 1,16,14,3)/
     x 1.3241000d-03, 7.8318134d-04,-3.7407116d-06 /
      data fpppp( 1,16,15,1),fpppp( 1,16,15,2),fpppp( 1,16,15,3)/
     x-1.1525254d-02,-2.1293689d-04, 1.8528680d-06 /
      data fpppp( 1,16,16,1),fpppp( 1,16,16,2),fpppp( 1,16,16,3)/
     x-1.4191965d-02, 7.0783454d-05,-3.9473926d-07 /
      data fpppp( 1,16,17,1),fpppp( 1,16,17,2),fpppp( 1,16,17,3)/
     x-1.6421097d-02,-1.5159554d-06, 1.8556911d-07 /
      data fpppp( 1,16,18,1),fpppp( 1,16,18,2),fpppp( 1,16,18,3)/
     x-1.8296594d-02, 1.6843635d-05, 2.0235142d-07 /
      data fpppp( 1,16,19,1),fpppp( 1,16,19,2),fpppp( 1,16,19,3)/
     x-1.9931903d-02, 8.7001153d-07,-4.9117956d-07 /
      data fpppp( 1,16,20,1),fpppp( 1,16,20,2),fpppp( 1,16,20,3)/
     x-2.0153110d-02,-2.6380925d-05, 3.6252649d-07 /
      data fpppp( 1,16,21,1),fpppp( 1,16,21,2),fpppp( 1,16,21,3)/
     x-2.0153110d-02,-2.6535507d-05, 3.1069451d-07 /
      data fpppp( 1,16,22,1),fpppp( 1,16,22,2),fpppp( 1,16,22,3)/
     x-1.9931903d-02, 1.4883380d-06,-2.8385163d-07 /
      data fpppp( 1,16,23,1),fpppp( 1,16,23,2),fpppp( 1,16,23,3)/
     x-1.8296594d-02, 1.4524910d-05,-5.7512835d-07 /
      data fpppp( 1,17, 1,1),fpppp( 1,17, 1,2),fpppp( 1,17, 1,3)/
     x 1.4416072d-02,-2.2077489d-06,-1.7208522d-06 /
      data fpppp( 1,17, 2,1),fpppp( 1,17, 2,2),fpppp( 1,17, 2,3)/
     x 1.3817911d-02,-5.9488249d-05,-1.0805189d-06 /
      data fpppp( 1,17, 3,1),fpppp( 1,17, 3,2),fpppp( 1,17, 3,3)/
     x 9.1476724d-03,-1.8164616d-04, 2.0239781d-07 /
      data fpppp( 1,17, 4,1),fpppp( 1,17, 4,2),fpppp( 1,17, 4,3)/
     x 9.1476724d-03,-1.8267170d-04, 3.5854320d-07 /
      data fpppp( 1,17, 5,1),fpppp( 1,17, 5,2),fpppp( 1,17, 5,3)/
     x 1.3817911d-02,-5.5386093d-05,-1.7051005d-06 /
      data fpppp( 1,17, 6,1),fpppp( 1,17, 6,2),fpppp( 1,17, 6,3)/
     x 1.4416072d-02,-1.7590837d-05, 6.2132870d-07 /
      data fpppp( 1,17, 7,1),fpppp( 1,17, 7,2),fpppp( 1,17, 7,3)/
     x 1.3953382d-02, 1.1865419d-04, 3.0937520d-07 /
      data fpppp( 1,17, 8,1),fpppp( 1,17, 8,2),fpppp( 1,17, 8,3)/
     x 1.3640055d-02,-2.2946578d-04, 2.9642947d-08 /
      data fpppp( 1,17, 9,1),fpppp( 1,17, 9,2),fpppp( 1,17, 9,3)/
     x 1.2369980d-02, 9.8954979d-04, 2.8572886d-07 /
      data fpppp( 1,17,10,1),fpppp( 1,17,10,2),fpppp( 1,17,10,3)/
     x 1.3513242d-02,-3.5501093d-03,-3.5291071d-07 /
      data fpppp( 1,17,11,1),fpppp( 1,17,11,2),fpppp( 1,17,11,3)/
     x 1.4075328d-02, 1.3352990d-02, 3.2870980d-07 /
      data fpppp( 1,17,12,1),fpppp( 1,17,12,2),fpppp( 1,17,12,3)/
     x 3.7280696d-03,-4.5343781d-02,-2.8980697d-06 /
      data fpppp( 1,17,13,1),fpppp( 1,17,13,2),fpppp( 1,17,13,3)/
     x 8.2169869d-02, 6.9798154d-02, 3.7110475d-06 /
      data fpppp( 1,17,14,1),fpppp( 1,17,14,2),fpppp( 1,17,14,3)/
     x 2.8711826d-02,-4.3997245d-02, 1.3864974d-06 /
      data fpppp( 1,17,15,1),fpppp( 1,17,15,2),fpppp( 1,17,15,3)/
     x 4.2870858d-02, 1.1689345d-02,-7.1894428d-07 /
      data fpppp( 1,17,16,1),fpppp( 1,17,16,2),fpppp( 1,17,16,3)/
     x 5.2919228d-02,-3.1439646d-03,-7.7411405d-08 /
      data fpppp( 1,17,17,1),fpppp( 1,17,17,2),fpppp( 1,17,17,3)/
     x 6.1425653d-02, 8.4120665d-04,-2.9004397d-07 /
      data fpppp( 1,17,18,1),fpppp( 1,17,18,2),fpppp( 1,17,18,3)/
     x 6.8626770d-02,-2.2072963d-04,-3.0594195d-07 /
      data fpppp( 1,17,19,1),fpppp( 1,17,19,2),fpppp( 1,17,19,3)/
     x 7.4586111d-02, 5.1757961d-05,-1.5690001d-07 /
      data fpppp( 1,17,20,1),fpppp( 1,17,20,2),fpppp( 1,17,20,3)/
     x 7.8298312d-02,-9.6559777d-06,-4.3813945d-07 /
      data fpppp( 1,17,21,1),fpppp( 1,17,21,2),fpppp( 1,17,21,3)/
     x 7.8298312d-02, 4.6389950d-06,-4.2483469d-07 /
      data fpppp( 1,17,22,1),fpppp( 1,17,22,2),fpppp( 1,17,22,3)/
     x 7.4586111d-02,-5.4219295d-06,-2.1011906d-07 /
      data fpppp( 1,17,23,1),fpppp( 1,17,23,2),fpppp( 1,17,23,3)/
     x 6.8626770d-02,-6.3050349d-06,-1.0637050d-07 /
      data fpppp( 1,18, 1,1),fpppp( 1,18, 1,2),fpppp( 1,18, 1,3)/
     x-5.0543419d-02,-1.8216667d-05, 8.1627530d-07 /
      data fpppp( 1,18, 2,1),fpppp( 1,18, 2,2),fpppp( 1,18, 2,3)/
     x-5.0030188d-02,-2.0797387d-05, 4.0255033d-07 /
      data fpppp( 1,18, 3,1),fpppp( 1,18, 3,2),fpppp( 1,18, 3,3)/
     x-4.6594309d-02,-2.6973826d-05,-4.5569659d-07 /
      data fpppp( 1,18, 4,1),fpppp( 1,18, 4,2),fpppp( 1,18, 4,3)/
     x-4.6594309d-02,-2.5842756d-05,-5.0523315d-07 /
      data fpppp( 1,18, 5,1),fpppp( 1,18, 5,2),fpppp( 1,18, 5,3)/
     x-5.0030188d-02,-2.5321670d-05, 6.0069655d-07 /
      data fpppp( 1,18, 6,1),fpppp( 1,18, 6,2),fpppp( 1,18, 6,3)/
     x-5.0543419d-02,-1.2506048d-06, 7.3226974d-08 /
      data fpppp( 1,18, 7,1),fpppp( 1,18, 7,2),fpppp( 1,18, 7,3)/
     x-5.0766461d-02,-2.1565948d-05, 1.1288141d-07 /
      data fpppp( 1,18, 8,1),fpppp( 1,18, 8,2),fpppp( 1,18, 8,3)/
     x-5.0859934d-02,-3.5654116d-05, 5.3158097d-08 /
      data fpppp( 1,18, 9,1),fpppp( 1,18, 9,2),fpppp( 1,18, 9,3)/
     x-5.0542467d-02,-6.3363635d-06,-1.2152404d-07 /
      data fpppp( 1,18,10,1),fpppp( 1,18,10,2),fpppp( 1,18,10,3)/
     x-5.0920869d-02, 2.4931778d-04,-9.8583997d-09 /
      data fpppp( 1,18,11,1),fpppp( 1,18,11,2),fpppp( 1,18,11,3)/
     x-5.1114757d-02,-9.0273108d-04,-1.9378402d-07 /
      data fpppp( 1,18,12,1),fpppp( 1,18,12,2),fpppp( 1,18,12,3)/
     x-4.7988306d-02, 2.9768279d-03, 5.0483768d-07 /
      data fpppp( 1,18,13,1),fpppp( 1,18,13,2),fpppp( 1,18,13,3)/
     x-8.1024305d-02, 4.8752905d-03,-1.9617349d-06 /
      data fpppp( 1,18,14,1),fpppp( 1,18,14,2),fpppp( 1,18,14,3)/
     x-6.9060625d-02,-2.0750329d-03,-2.5380896d-07 /
      data fpppp( 1,18,15,1),fpppp( 1,18,15,2),fpppp( 1,18,15,3)/
     x-8.2108962d-02,-4.2193627d-04, 3.6929273d-07 /
      data fpppp( 1,18,16,1),fpppp( 1,18,16,2),fpppp( 1,18,16,3)/
     x-9.2702864d-02,-8.1267153d-04, 2.1794120d-07 /
      data fpppp( 1,18,17,1),fpppp( 1,18,17,2),fpppp( 1,18,17,3)/
     x-1.0164531d-01,-5.6541720d-04, 2.8251787d-07 /
      data fpppp( 1,18,18,1),fpppp( 1,18,18,2),fpppp( 1,18,18,3)/
     x-1.0919490d-01,-4.8170074d-04, 2.8957568d-07 /
      data fpppp( 1,18,19,1),fpppp( 1,18,19,2),fpppp( 1,18,19,3)/
     x-1.1540472d-01,-9.4156711d-04, 2.5695135d-07 /
      data fpppp( 1,18,20,1),fpppp( 1,18,20,2),fpppp( 1,18,20,3)/
     x-1.1942446d-01,-1.1770479d-03, 3.4810505d-07 /
      data fpppp( 1,18,21,1),fpppp( 1,18,21,2),fpppp( 1,18,21,3)/
     x-1.1942446d-01,-1.1936607d-03, 3.4453720d-07 /
      data fpppp( 1,18,22,1),fpppp( 1,18,22,2),fpppp( 1,18,22,3)/
     x-1.1540472d-01,-8.7511610d-04, 2.7122275d-07 /
      data fpppp( 1,18,23,1),fpppp( 1,18,23,2),fpppp( 1,18,23,3)/
     x-1.0919490d-01,-7.3089203d-04, 2.3605792d-07 /
      data fpppp( 1,19, 1,1),fpppp( 1,19, 1,2),fpppp( 1,19, 1,3)/
     x-9.2250133d-02, 7.1190261d-17,-1.0907492d-06 /
      data fpppp( 1,19, 2,1),fpppp( 1,19, 2,2),fpppp( 1,19, 2,3)/
     x-9.2493791d-02, 9.8004736d-19,-3.8374205d-07 /
      data fpppp( 1,19, 3,1),fpppp( 1,19, 3,2),fpppp( 1,19, 3,3)/
     x-1.0052101d-01,-4.2194355d-17, 1.1080074d-06 /
      data fpppp( 1,19, 4,1),fpppp( 1,19, 4,2),fpppp( 1,19, 4,3)/
     x-1.0052101d-01, 1.7187612d-17, 1.1487228d-06 /
      data fpppp( 1,19, 5,1),fpppp( 1,19, 5,2),fpppp( 1,19, 5,3)/
     x-9.2493791d-02, 5.9847040d-18,-5.4660355d-07 /
      data fpppp( 1,19, 6,1),fpppp( 1,19, 6,2),fpppp( 1,19, 6,3)/
     x-9.2250133d-02, 4.7231376d-17,-4.8001858d-07 /
      data fpppp( 1,19, 7,1),fpppp( 1,19, 7,2),fpppp( 1,19, 7,3)/
     x-9.2009692d-02, 3.1411461d-17,-3.4737505d-07 /
      data fpppp( 1,19, 8,1),fpppp( 1,19, 8,2),fpppp( 1,19, 8,3)/
     x-9.1962996d-02, 6.7624216d-18,-1.3891659d-07 /
      data fpppp( 1,19, 9,1),fpppp( 1,19, 9,2),fpppp( 1,19, 9,3)/
     x-9.2071931d-02,-3.9126191d-17,-6.9313478d-08 /
      data fpppp( 1,19,10,1),fpppp( 1,19,10,2),fpppp( 1,19,10,3)/
     x-9.2008741d-02, 2.4679435d-17, 9.4748741d-08 /
      data fpppp( 1,19,11,1),fpppp( 1,19,11,2),fpppp( 1,19,11,3)/
     x-9.2136735d-02, 1.2715662d-18,-7.6903065d-07 /
      data fpppp( 1,19,12,1),fpppp( 1,19,12,2),fpppp( 1,19,12,3)/
     x-8.9349113d-02,-1.1740437d-17, 2.6185023d-06 /
      data fpppp( 1,19,13,1),fpppp( 1,19,13,2),fpppp( 1,19,13,3)/
     x-1.6068447d-01,-2.7351912d-17,-5.8381443d-06 /
      data fpppp( 1,19,14,1),fpppp( 1,19,14,2),fpppp( 1,19,14,3)/
     x-1.3107303d-01, 4.1993471d-17, 3.9460491d-08 /
      data fpppp( 1,19,15,1),fpppp( 1,19,15,2),fpppp( 1,19,15,3)/
     x-1.5583852d-01,-2.4976944d-17, 4.1180137d-07 /
      data fpppp( 1,19,16,1),fpppp( 1,19,16,2),fpppp( 1,19,16,3)/
     x-1.7754402d-01, 5.7651418d-17, 5.1957244d-07 /
      data fpppp( 1,19,17,1),fpppp( 1,19,17,2),fpppp( 1,19,17,3)/
     x-1.9588264d-01,-3.6808715d-18, 5.5560116d-07 /
      data fpppp( 1,19,18,1),fpppp( 1,19,18,2),fpppp( 1,19,18,3)/
     x-2.1137513d-01, 1.8748029d-17, 5.6971874d-07 /
      data fpppp( 1,19,19,1),fpppp( 1,19,19,2),fpppp( 1,19,19,3)/
     x-2.2410732d-01, 3.4953931d-17, 6.4806791d-07 /
      data fpppp( 1,19,20,1),fpppp( 1,19,20,2),fpppp( 1,19,20,3)/
     x-2.3252603d-01,-3.5101663d-17, 6.8094656d-07 /
      data fpppp( 1,19,21,1),fpppp( 1,19,21,2),fpppp( 1,19,21,3)/
     x-2.3252603d-01, 2.5150261d-17, 6.8393735d-07 /
      data fpppp( 1,19,22,1),fpppp( 1,19,22,2),fpppp( 1,19,22,3)/
     x-2.2410732d-01,-1.0308036d-17, 6.3610478d-07 /
      data fpppp( 1,19,23,1),fpppp( 1,19,23,2),fpppp( 1,19,23,3)/
     x-2.1137513d-01,-3.4915428d-18, 6.1458046d-07 /
      data fpppp( 2, 1, 1,1),fpppp( 2, 1, 1,2),fpppp( 2, 1, 1,3)/
     x 8.2004287d-03, 3.0620746d-16, 9.9936085d-06 /
      data fpppp( 2, 1, 2,1),fpppp( 2, 1, 2,2),fpppp( 2, 1, 2,3)/
     x 1.3753561d-02,-5.2467683d-17, 6.2453873d-06 /
      data fpppp( 2, 1, 3,1),fpppp( 2, 1, 3,2),fpppp( 2, 1, 3,3)/
     x 1.7941378d-02, 1.2997275d-18,-1.2007072d-06 /
      data fpppp( 2, 1, 4,1),fpppp( 2, 1, 4,2),fpppp( 2, 1, 4,3)/
     x 1.7941378d-02, 3.2558977d-17,-2.2258710d-06 /
      data fpppp( 2, 1, 5,1),fpppp( 2, 1, 5,2),fpppp( 2, 1, 5,3)/
     x 1.3753561d-02,-3.5644012d-17, 1.0346043d-05 /
      data fpppp( 2, 1, 6,1),fpppp( 2, 1, 6,2),fpppp( 2, 1, 6,3)/
     x 8.2004287d-03,-1.5437366d-16,-5.3838488d-06 /
      data fpppp( 2, 1, 7,1),fpppp( 2, 1, 7,2),fpppp( 2, 1, 7,3)/
     x 2.0333277d-03,-3.1982892d-17, 7.0234795d-07 /
      data fpppp( 2, 1, 8,1),fpppp( 2, 1, 8,2),fpppp( 2, 1, 8,3)/
     x 3.0914917d-02,-9.7376489d-17,-8.1888153d-07 /
      data fpppp( 2, 1, 9,1),fpppp( 2, 1, 9,2),fpppp( 2, 1, 9,3)/
     x-3.4511708d-02,-7.2329568d-17,-7.0689306d-07 /
      data fpppp( 2, 1,10,1),fpppp( 2, 1,10,2),fpppp( 2, 1,10,3)/
     x-1.1875499d-01, 1.5175657d-16,-1.5664968d-07 /
      data fpppp( 2, 1,11,1),fpppp( 2, 1,11,2),fpppp( 2, 1,11,3)/
     x-1.6629155d-01, 7.5206379d-17,-3.4523383d-07 /
      data fpppp( 2, 1,12,1),fpppp( 2, 1,12,2),fpppp( 2, 1,12,3)/
     x-1.8669927d-01,-4.4518574d-17,-1.3004574d-06 /
      data fpppp( 2, 1,13,1),fpppp( 2, 1,13,2),fpppp( 2, 1,13,3)/
     x-1.6584267d-01,-4.2917773d-17,-3.7318844d-08 /
      data fpppp( 2, 1,14,1),fpppp( 2, 1,14,2),fpppp( 2, 1,14,3)/
     x-1.1640499d-01,-7.4832947d-17,-7.1028737d-07 /
      data fpppp( 2, 1,15,1),fpppp( 2, 1,15,2),fpppp( 2, 1,15,3)/
     x-3.1952440d-02, 1.7914070d-16,-4.1802083d-07 /
      data fpppp( 2, 1,16,1),fpppp( 2, 1,16,2),fpppp( 2, 1,16,3)/
     x 2.8322159d-02,-9.9020608d-17,-8.5987220d-07 /
      data fpppp( 2, 1,17,1),fpppp( 2, 1,17,2),fpppp( 2, 1,17,3)/
     x 3.6720509d-03,-2.3059696d-16, 3.1263110d-07 /
      data fpppp( 2, 1,18,1),fpppp( 2, 1,18,2),fpppp( 2, 1,18,3)/
     x 1.1185831d-02,-5.9806909d-17,-4.9285766d-06 /
      data fpppp( 2, 1,19,1),fpppp( 2, 1,19,2),fpppp( 2, 1,19,3)/
     x 1.6103600d-02,-9.7225522d-17, 1.0580098d-05 /
      data fpppp( 2, 1,20,1),fpppp( 2, 1,20,2),fpppp( 2, 1,20,3)/
     x 1.7301364d-02,-6.7647874d-17,-2.4128829d-06 /
      data fpppp( 2, 1,21,1),fpppp( 2, 1,21,2),fpppp( 2, 1,21,3)/
     x 1.7301364d-02, 1.3899026d-16,-1.3888924d-06 /
      data fpppp( 2, 1,22,1),fpppp( 2, 1,22,2),fpppp( 2, 1,22,3)/
     x 1.6103600d-02, 1.6658514d-17, 6.4841361d-06 /
      data fpppp( 2, 1,23,1),fpppp( 2, 1,23,2),fpppp( 2, 1,23,3)/
     x 1.1185831d-02,-1.2297134d-16, 1.0431280d-05 /
      data fpppp( 2, 2, 1,1),fpppp( 2, 2, 1,2),fpppp( 2, 2, 1,3)/
     x 6.5985052d-03,-3.2966242d-04, 6.3067203d-06 /
      data fpppp( 2, 2, 2,1),fpppp( 2, 2, 2,2),fpppp( 2, 2, 2,3)/
     x 9.7111145d-03,-1.7359963d-04, 3.9042560d-06 /
      data fpppp( 2, 2, 3,1),fpppp( 2, 2, 3,2),fpppp( 2, 2, 3,3)/
     x 1.0831467d-02, 1.6349690d-04,-8.7322518d-07 /
      data fpppp( 2, 2, 4,1),fpppp( 2, 2, 4,2),fpppp( 2, 2, 4,3)/
     x 1.0831467d-02, 1.5881342d-04,-1.5218744d-06 /
      data fpppp( 2, 2, 5,1),fpppp( 2, 2, 5,2),fpppp( 2, 2, 5,3)/
     x 9.7111145d-03,-1.5486569d-04, 6.4988530d-06 /
      data fpppp( 2, 2, 6,1),fpppp( 2, 2, 6,2),fpppp( 2, 2, 6,3)/
     x 6.5985052d-03,-3.9991470d-04,-3.4230185d-06 /
      data fpppp( 2, 2, 7,1),fpppp( 2, 2, 7,2),fpppp( 2, 2, 7,3)/
     x 4.0150912d-03, 2.7792775d-04, 2.7053017d-07 /
      data fpppp( 2, 2, 8,1),fpppp( 2, 2, 8,2),fpppp( 2, 2, 8,3)/
     x 1.5755674d-02, 3.1512914d-05,-4.6894512d-07 /
      data fpppp( 2, 2, 9,1),fpppp( 2, 2, 9,2),fpppp( 2, 2, 9,3)/
     x-1.1772569d-02, 2.3969150d-04,-3.2790719d-07 /
      data fpppp( 2, 2,10,1),fpppp( 2, 2,10,2),fpppp( 2, 2,10,3)/
     x-4.8032382d-02,-4.1823321d-04,-7.8099167d-08 /
      data fpppp( 2, 2,11,1),fpppp( 2, 2,11,2),fpppp( 2, 2,11,3)/
     x-6.8387990d-02, 2.2648995d-04,-5.0504914d-08 /
      data fpppp( 2, 2,12,1),fpppp( 2, 2,12,2),fpppp( 2, 2,12,3)/
     x-7.8216614d-02, 1.4985257d-05,-7.3685647d-07 /
      data fpppp( 2, 2,13,1),fpppp( 2, 2,13,2),fpppp( 2, 2,13,3)/
     x-6.8196292d-02,-3.3857282d-04, 1.0215511d-07 /
      data fpppp( 2, 2,14,1),fpppp( 2, 2,14,2),fpppp( 2, 2,14,3)/
     x-4.6975583d-02, 3.9715528d-04,-3.4630372d-07 /
      data fpppp( 2, 2,15,1),fpppp( 2, 2,15,2),fpppp( 2, 2,15,3)/
     x-1.0651734d-02, 3.1190941d-04,-1.6570194d-07 /
      data fpppp( 2, 2,16,1),fpppp( 2, 2,16,2),fpppp( 2, 2,16,3)/
     x 1.5012749d-02,-8.5602846d-04,-5.2036279d-07 /
      data fpppp( 2, 2,17,1),fpppp( 2, 2,17,2),fpppp( 2, 2,17,3)/
     x 4.6756743d-03,-1.0137360d-04, 2.8375015d-07 /
      data fpppp( 2, 2,18,1),fpppp( 2, 2,18,2),fpppp( 2, 2,18,3)/
     x 7.4815740d-03, 1.5779685d-03,-3.5110690d-06 /
      data fpppp( 2, 2,19,1),fpppp( 2, 2,19,2),fpppp( 2, 2,19,3)/
     x 1.1245623d-02,-1.2619057d-03, 6.8854608d-06 /
      data fpppp( 2, 2,20,1),fpppp( 2, 2,20,2),fpppp( 2, 2,20,3)/
     x 1.1003572d-02, 1.7936621d-04,-1.7155981d-06 /
      data fpppp( 2, 2,21,1),fpppp( 2, 2,21,2),fpppp( 2, 2,21,3)/
     x 1.1003572d-02, 1.2635143d-05,-1.0315621d-06 /
      data fpppp( 2, 2,22,1),fpppp( 2, 2,22,2),fpppp( 2, 2,22,3)/
     x 1.1245623d-02,-5.9498141d-04, 4.1493170d-06 /
      data fpppp( 2, 2,23,1),fpppp( 2, 2,23,2),fpppp( 2, 2,23,3)/
     x 7.4815740d-03,-9.2299743d-04, 6.7494702d-06 /
      data fpppp( 2, 3, 1,1),fpppp( 2, 3, 1,2),fpppp( 2, 3, 1,3)/
     x 1.7135010d-02, 1.1953441d-03,-3.1771717d-05 /
      data fpppp( 2, 3, 2,1),fpppp( 2, 3, 2,2),fpppp( 2, 3, 2,3)/
     x 2.9895463d-03, 4.7679915d-04,-2.0487487d-05 /
      data fpppp( 2, 3, 3,1),fpppp( 2, 3, 3,2),fpppp( 2, 3, 3,3)/
     x 2.4224103d-03,-5.7968480d-04, 1.7085397d-06 /
      data fpppp( 2, 3, 4,1),fpppp( 2, 3, 4,2),fpppp( 2, 3, 4,3)/
     x 2.4224103d-03,-1.4253815d-03, 5.1813517d-06 /
      data fpppp( 2, 3, 5,1),fpppp( 2, 3, 5,2),fpppp( 2, 3, 5,3)/
     x 2.9895463d-03, 3.8595859d-03,-3.4378735d-05 /
      data fpppp( 2, 3, 6,1),fpppp( 2, 3, 6,2),fpppp( 2, 3, 6,3)/
     x 1.7135010d-02,-1.1490106d-02, 2.0320463d-05 /
      data fpppp( 2, 3, 7,1),fpppp( 2, 3, 7,2),fpppp( 2, 3, 7,3)/
     x 2.0284394d-02, 2.9654378d-02,-5.3427050d-07 /
      data fpppp( 2, 3, 8,1),fpppp( 2, 3, 8,2),fpppp( 2, 3, 8,3)/
     x-8.6374493d-03,-4.5367336d-02, 3.2266889d-06 /
      data fpppp( 2, 3, 9,1),fpppp( 2, 3, 9,2),fpppp( 2, 3, 9,3)/
     x 6.1400710d-02, 6.7879658d-04, 1.2671362d-06 /
      data fpppp( 2, 3,10,1),fpppp( 2, 3,10,2),fpppp( 2, 3,10,3)/
     x 1.5384946d-01, 1.2463894d-02, 1.7452021d-06 /
      data fpppp( 2, 3,11,1),fpppp( 2, 3,11,2),fpppp( 2, 3,11,3)/
     x 2.0629694d-01, 7.3743956d-03,-4.3962385d-07 /
      data fpppp( 2, 3,12,1),fpppp( 2, 3,12,2),fpppp( 2, 3,12,3)/
     x 2.3999849d-01, 9.5348003d-03, 4.3232768d-06 /
      data fpppp( 2, 3,13,1),fpppp( 2, 3,13,2),fpppp( 2, 3,13,3)/
     x 2.0585305d-01, 7.1952247d-03,-5.6331858d-07 /
      data fpppp( 2, 3,14,1),fpppp( 2, 3,14,2),fpppp( 2, 3,14,3)/
     x 1.5204697d-01, 1.3521993d-02, 2.0433367d-06 /
      data fpppp( 2, 3,15,1),fpppp( 2, 3,15,2),fpppp( 2, 3,15,3)/
     x 5.8434232d-02,-2.5385087d-03, 1.1477878d-06 /
      data fpppp( 2, 3,16,1),fpppp( 2, 3,16,2),fpppp( 2, 3,16,3)/
     x-8.0498188d-03,-4.1477155d-02, 3.4607719d-06 /
      data fpppp( 2, 3,17,1),fpppp( 2, 3,17,2),fpppp( 2, 3,17,3)/
     x 1.9375971d-02, 2.6998875d-02,-9.4206522d-07 /
      data fpppp( 2, 3,18,1),fpppp( 2, 3,18,2),fpppp( 2, 3,18,3)/
     x 1.7503648d-02,-1.0447778d-02, 2.1461058d-05 /
      data fpppp( 2, 3,19,1),fpppp( 2, 3,19,2),fpppp( 2, 3,19,3)/
     x-6.1515242d-03, 4.1431658d-03,-3.6915969d-05 /
      data fpppp( 2, 3,20,1),fpppp( 2, 3,20,2),fpppp( 2, 3,20,3)/
     x 9.6188844d-04,-1.6812842d-03, 6.2709435d-06 /
      data fpppp( 2, 3,21,1),fpppp( 2, 3,21,2),fpppp( 2, 3,21,3)/
     x 9.6188844d-04,-8.5965351d-04, 2.5432100d-06 /
      data fpppp( 2, 3,22,1),fpppp( 2, 3,22,2),fpppp( 2, 3,22,3)/
     x-6.1515242d-03, 8.5664286d-04,-2.2005035d-05 /
      data fpppp( 2, 3,23,1),fpppp( 2, 3,23,2),fpppp( 2, 3,23,3)/
     x 1.7503648d-02, 1.8766827d-03,-3.4454945d-05 /
      data fpppp( 2, 4, 1,1),fpppp( 2, 4, 1,2),fpppp( 2, 4, 1,3)/
     x-1.4812984d-02, 9.0844854d-03, 5.0520267d-05 /
      data fpppp( 2, 4, 2,1),fpppp( 2, 4, 2,2),fpppp( 2, 4, 2,3)/
     x 5.6449044d-03, 5.6107738d-03, 3.2297911d-05 /
      data fpppp( 2, 4, 3,1),fpppp( 2, 4, 3,2),fpppp( 2, 4, 3,3)/
     x-1.4396369d-03,-8.4268134d-04,-3.5996854d-06 /
      data fpppp( 2, 4, 4,1),fpppp( 2, 4, 4,2),fpppp( 2, 4, 4,3)/
     x-1.4396369d-03,-2.5755532d-03,-9.1127255d-06 /
      data fpppp( 2, 4, 5,1),fpppp( 2, 4, 5,2),fpppp( 2, 4, 5,3)/
     x 5.6449044d-03, 1.2542261d-02, 5.4350072d-05 /
      data fpppp( 2, 4, 6,1),fpppp( 2, 4, 6,2),fpppp( 2, 4, 6,3)/
     x-1.4812984d-02,-1.6908593d-02,-3.2175335d-05 /
      data fpppp( 2, 4, 7,1),fpppp( 2, 4, 7,2),fpppp( 2, 4, 7,3)/
     x-1.3452690d-02, 1.0038842d-02,-3.3631063d-08 /
      data fpppp( 2, 4, 8,1),fpppp( 2, 4, 8,2),fpppp( 2, 4, 8,3)/
     x-7.1199224d-04,-3.0504535d-03,-4.7876187d-06 /
      data fpppp( 2, 4, 9,1),fpppp( 2, 4, 9,2),fpppp( 2, 4, 9,3)/
     x-4.1945499d-02, 1.8439389d-03,-1.3940217d-06 /
      data fpppp( 2, 4,10,1),fpppp( 2, 4,10,2),fpppp( 2, 4,10,3)/
     x-1.0332602d-01,-4.5100720d-03,-2.5381243d-06 /
      data fpppp( 2, 4,11,1),fpppp( 2, 4,11,2),fpppp( 2, 4,11,3)/
     x-1.3775293d-01, 1.6073360d-02, 1.5647247d-06 /
      data fpppp( 2, 4,12,1),fpppp( 2, 4,12,2),fpppp( 2, 4,12,3)/
     x-1.7584998d-01,-2.5420389d-02,-6.3544532d-06 /
      data fpppp( 2, 4,13,1),fpppp( 2, 4,13,2),fpppp( 2, 4,13,3)/
     x-1.3750799d-01, 1.5977956d-02, 1.5885245d-06 /
      data fpppp( 2, 4,14,1),fpppp( 2, 4,14,2),fpppp( 2, 4,14,3)/
     x-1.0250650d-01,-4.6565450d-03,-2.6568215d-06 /
      data fpppp( 2, 4,15,1),fpppp( 2, 4,15,2),fpppp( 2, 4,15,3)/
     x-3.9728213d-02, 2.2289618d-03,-1.2528205d-06 /
      data fpppp( 2, 4,16,1),fpppp( 2, 4,16,2),fpppp( 2, 4,16,3)/
     x 3.0236697d-03,-3.4374971d-03,-5.3037820d-06 /
      data fpppp( 2, 4,17,1),fpppp( 2, 4,17,2),fpppp( 2, 4,17,3)/
     x-1.3862088d-02, 1.1838256d-02, 2.0213899d-06 /
      data fpppp( 2, 4,18,1),fpppp( 2, 4,18,2),fpppp( 2, 4,18,3)/
     x-2.0516436d-02,-2.5908905d-02,-3.6007983d-05 /
      data fpppp( 2, 4,19,1),fpppp( 2, 4,19,2),fpppp( 2, 4,19,3)/
     x 2.0338425d-02, 2.6886581d-02, 5.9656376d-05 /
      data fpppp( 2, 4,20,1),fpppp( 2, 4,20,2),fpppp( 2, 4,20,3)/
     x 4.0238230d-03,-7.5611536d-03,-1.1254914d-05 /
      data fpppp( 2, 4,21,1),fpppp( 2, 4,21,2),fpppp( 2, 4,21,3)/
     x 4.0238230d-03,-4.2919560d-03,-5.1430643d-06 /
      data fpppp( 2, 4,22,1),fpppp( 2, 4,22,2),fpppp( 2, 4,22,3)/
     x 2.0338425d-02, 1.3809791d-02, 3.5208979d-05 /
      data fpppp( 2, 4,23,1),fpppp( 2, 4,23,2),fpppp( 2, 4,23,3)/
     x-2.0516436d-02, 2.3129059d-02, 5.5669758d-05 /
      data fpppp( 2, 5, 1,1),fpppp( 2, 5, 1,2),fpppp( 2, 5, 1,3)/
     x 3.2685180d-03,-4.5195504d-03,-3.4222598d-05 /
      data fpppp( 2, 5, 2,1),fpppp( 2, 5, 2,2),fpppp( 2, 5, 2,3)/
     x-8.3170567d-03,-2.4812730d-03,-2.0903285d-05 /
      data fpppp( 2, 5, 3,1),fpppp( 2, 5, 3,2),fpppp( 2, 5, 3,3)/
     x 5.1660729d-03, 1.7689002d-03, 5.6795567d-06 /
      data fpppp( 2, 5, 4,1),fpppp( 2, 5, 4,2),fpppp( 2, 5, 4,3)/
     x 5.1660729d-03, 1.9746374d-03, 9.1070097d-06 /
      data fpppp( 2, 5, 5,1),fpppp( 2, 5, 5,2),fpppp( 2, 5, 5,3)/
     x-8.3170567d-03,-3.3042219d-03,-3.4613096d-05 /
      data fpppp( 2, 5, 6,1),fpppp( 2, 5, 6,2),fpppp( 2, 5, 6,3)/
     x 3.2685180d-03,-1.4334920d-03, 1.7189197d-05 /
      data fpppp( 2, 5, 7,1),fpppp( 2, 5, 7,2),fpppp( 2, 5, 7,3)/
     x 4.2027269d-03,-2.9966044d-03, 1.0835826d-06 /
      data fpppp( 2, 5, 8,1),fpppp( 2, 5, 8,2),fpppp( 2, 5, 8,3)/
     x 9.8760288d-03, 1.0241968d-02, 2.1319955d-06 /
      data fpppp( 2, 5, 9,1),fpppp( 2, 5, 9,2),fpppp( 2, 5, 9,3)/
     x 1.2965420d-02,-6.9938889d-03, 4.1732518d-07 /
      data fpppp( 2, 5,10,1),fpppp( 2, 5,10,2),fpppp( 2, 5,10,3)/
     x 2.9553372d-02, 2.8734090d-03, 1.0661074d-06 /
      data fpppp( 2, 5,11,1),fpppp( 2, 5,11,2),fpppp( 2, 5,11,3)/
     x 3.8611705d-02,-2.3709454d-03,-1.5623392d-06 /
      data fpppp( 2, 5,12,1),fpppp( 2, 5,12,2),fpppp( 2, 5,12,3)/
     x 5.9264834d-02, 2.0083679d-03, 3.4847409d-06 /
      data fpppp( 2, 5,13,1),fpppp( 2, 5,13,2),fpppp( 2, 5,13,3)/
     x 3.7985761d-02,-1.6548934d-03,-1.5764142d-06 /
      data fpppp( 2, 5,14,1),fpppp( 2, 5,14,2),fpppp( 2, 5,14,3)/
     x 3.0009918d-02, 7.2392393d-04, 1.1297243d-06 /
      data fpppp( 2, 5,15,1),fpppp( 2, 5,15,2),fpppp( 2, 5,15,3)/
     x 1.2040978d-02, 4.8341714d-04, 2.1602975d-07 /
      data fpppp( 2, 5,16,1),fpppp( 2, 5,16,2),fpppp( 2, 5,16,3)/
     x 9.2147096d-03,-7.3904515d-04, 2.9635984d-06 /
      data fpppp( 2, 5,17,1),fpppp( 2, 5,17,2),fpppp( 2, 5,17,3)/
     x 5.6476226d-03,-8.2606357d-04,-2.1994001d-06 /
      data fpppp( 2, 5,18,1),fpppp( 2, 5,18,2),fpppp( 2, 5,18,3)/
     x 1.1077930d-02, 4.6109011d-03, 2.3786175d-05 /
      data fpppp( 2, 5,19,1),fpppp( 2, 5,19,2),fpppp( 2, 5,19,3)/
     x-1.8399286d-02,-3.4435746d-03,-3.9765272d-05 /
      data fpppp( 2, 5,20,1),fpppp( 2, 5,20,2),fpppp( 2, 5,20,3)/
     x-2.7858133d-03, 5.3755977d-05, 1.0069034d-05 /
      data fpppp( 2, 5,21,1),fpppp( 2, 5,21,2),fpppp( 2, 5,21,3)/
     x-2.7858133d-03,-4.0604924d-04, 5.9484269d-06 /
      data fpppp( 2, 5,22,1),fpppp( 2, 5,22,2),fpppp( 2, 5,22,3)/
     x-1.8399286d-02,-1.6043537d-03,-2.3282843d-05 /
      data fpppp( 2, 5,23,1),fpppp( 2, 5,23,2),fpppp( 2, 5,23,3)/
     x 1.1077930d-02,-2.2861772d-03,-3.8022931d-05 /
      data fpppp( 2, 6, 1,1),fpppp( 2, 6, 1,2),fpppp( 2, 6, 1,3)/
     x-2.1275211d-03,-6.2373358d-03, 1.1081384d-05 /
      data fpppp( 2, 6, 2,1),fpppp( 2, 6, 2,2),fpppp( 2, 6, 2,3)/
     x 1.2783765d-02,-3.8368251d-03, 6.3894569d-06 /
      data fpppp( 2, 6, 3,1),fpppp( 2, 6, 3,2),fpppp( 2, 6, 3,3)/
     x-9.7596829d-03, 8.2590646d-04,-3.1908412d-06 /
      data fpppp( 2, 6, 4,1),fpppp( 2, 6, 4,2),fpppp( 2, 6, 4,3)/
     x-9.7596829d-03, 1.6680417d-03,-4.0200482d-06 /
      data fpppp( 2, 6, 5,1),fpppp( 2, 6, 5,2),fpppp( 2, 6, 5,3)/
     x 1.2783765d-02,-7.2053661d-03, 9.7062849d-06 /
      data fpppp( 2, 6, 6,1),fpppp( 2, 6, 6,2),fpppp( 2, 6, 6,3)/
     x-2.1275211d-03, 6.3946932d-03,-1.3567205d-06 /
      data fpppp( 2, 6, 7,1),fpppp( 2, 6, 7,2),fpppp( 2, 6, 7,3)/
     x-5.5302654d-04,-1.6912291d-03,-1.8142798d-06 /
      data fpppp( 2, 6, 8,1),fpppp( 2, 6, 8,2),fpppp( 2, 6, 8,3)/
     x-2.6950880d-03, 4.3823917d-04,-2.9529397d-07 /
      data fpppp( 2, 6, 9,1),fpppp( 2, 6, 9,2),fpppp( 2, 6, 9,3)/
     x-2.8691389d-03,-1.2977370d-04,-1.2417552d-07 /
      data fpppp( 2, 6,10,1),fpppp( 2, 6,10,2),fpppp( 2, 6,10,3)/
     x-7.4447305d-03,-9.0451447d-06,-3.3546859d-07 /
      data fpppp( 2, 6,11,1),fpppp( 2, 6,11,2),fpppp( 2, 6,11,3)/
     x-1.3356115d-02, 4.5886370d-05, 4.1738144d-07 /
      data fpppp( 2, 6,12,1),fpppp( 2, 6,12,2),fpppp( 2, 6,12,3)/
     x-1.8480155d-02,-2.4510136d-04,-9.4378480d-07 /
      data fpppp( 2, 6,13,1),fpppp( 2, 6,13,2),fpppp( 2, 6,13,3)/
     x-1.0110095d-02, 7.8435144d-04, 4.1500087d-07 /
      data fpppp( 2, 6,14,1),fpppp( 2, 6,14,2),fpppp( 2, 6,14,3)/
     x-9.9605256d-03,-2.8498257d-03,-3.2343590d-07 /
      data fpppp( 2, 6,15,1),fpppp( 2, 6,15,2),fpppp( 2, 6,15,3)/
     x-1.7382975d-03, 1.0359717d-02,-6.3685976d-08 /
      data fpppp( 2, 6,16,1),fpppp( 2, 6,16,2),fpppp( 2, 6,16,3)/
     x-1.4913694d-02,-1.6427094d-02,-8.7178167d-07 /
      data fpppp( 2, 6,17,1),fpppp( 2, 6,17,2),fpppp( 2, 6,17,3)/
     x-3.1210619d-03, 1.0800886d-02, 9.9047750d-07 /
      data fpppp( 2, 6,18,1),fpppp( 2, 6,18,2),fpppp( 2, 6,18,3)/
     x 1.4124296d-03,-4.6860227d-03,-7.0337750d-06 /
      data fpppp( 2, 6,19,1),fpppp( 2, 6,19,2),fpppp( 2, 6,19,3)/
     x 4.7654867d-03, 7.9006019d-03, 1.3222116d-05 /
      data fpppp( 2, 6,20,1),fpppp( 2, 6,20,2),fpppp( 2, 6,20,3)/
     x 1.4435510d-04,-3.9928299d-03,-4.1895067d-06 /
      data fpppp( 2, 6,21,1),fpppp( 2, 6,21,2),fpppp( 2, 6,21,3)/
     x 1.4435510d-04,-3.1319014d-03,-2.8422924d-06 /
      data fpppp( 2, 6,22,1),fpppp( 2, 6,22,2),fpppp( 2, 6,22,3)/
     x 4.7654867d-03, 4.4568881d-03, 7.8332584d-06 /
      data fpppp( 2, 6,23,1),fpppp( 2, 6,23,2),fpppp( 2, 6,23,3)/
     x 1.4124296d-03, 8.2279041d-03, 1.3174439d-05 /
      data fpppp( 2, 7, 1,1),fpppp( 2, 7, 1,2),fpppp( 2, 7, 1,3)/
     x 9.0984970d-03,-2.7810932d-02,-3.3685260d-06 /
      data fpppp( 2, 7, 2,1),fpppp( 2, 7, 2,2),fpppp( 2, 7, 2,3)/
     x-2.1675167d-02,-1.6421671d-02,-1.4993811d-06 /
      data fpppp( 2, 7, 3,1),fpppp( 2, 7, 3,2),fpppp( 2, 7, 3,3)/
     x 1.3586599d-02, 5.9411002d-03, 2.6331069d-06 /
      data fpppp( 2, 7, 4,1),fpppp( 2, 7, 4,2),fpppp( 2, 7, 4,3)/
     x 1.3586599d-02, 9.5159787d-03, 2.4105461d-06 /
      data fpppp( 2, 7, 5,1),fpppp( 2, 7, 5,2),fpppp( 2, 7, 5,3)/
     x-2.1675167d-02,-3.0721186d-02,-6.0913785d-07 /
      data fpppp( 2, 7, 6,1),fpppp( 2, 7, 6,2),fpppp( 2, 7, 6,3)/
     x 9.0984970d-03, 2.5812246d-02,-6.7069383d-06 /
      data fpppp( 2, 7, 7,1),fpppp( 2, 7, 7,2),fpppp( 2, 7, 7,3)/
     x 9.8324943d-04,-1.0725803d-02, 4.1420841d-06 /
      data fpppp( 2, 7, 8,1),fpppp( 2, 7, 8,2),fpppp( 2, 7, 8,3)/
     x-1.2142012d-02, 5.2677957d-03,-4.1370682d-07 /
      data fpppp( 2, 7, 9,1),fpppp( 2, 7, 9,2),fpppp( 2, 7, 9,3)/
     x 6.0547609d-03,-4.8486832d-03,-3.3786179d-07 /
      data fpppp( 2, 7,10,1),fpppp( 2, 7,10,2),fpppp( 2, 7,10,3)/
     x 2.0904370d-03, 2.5386152d-03, 2.3256899d-07 /
      data fpppp( 2, 7,11,1),fpppp( 2, 7,11,2),fpppp( 2, 7,11,3)/
     x 1.8989959d-02, 3.1634120d-04,-1.5507602d-07 /
      data fpppp( 2, 7,12,1),fpppp( 2, 7,12,2),fpppp( 2, 7,12,3)/
     x 1.9050569d-02,-1.4379153d-03, 2.7171396d-07 /
      data fpppp( 2, 7,13,1),fpppp( 2, 7,13,2),fpppp( 2, 7,13,3)/
     x 6.3827510d-03, 4.4311995d-04,-1.0604243d-07 /
      data fpppp( 2, 7,14,1),fpppp( 2, 7,14,2),fpppp( 2, 7,14,3)/
     x 1.1738899d-02, 2.0829098d-03, 8.6036099d-08 /
      data fpppp( 2, 7,15,1),fpppp( 2, 7,15,2),fpppp( 2, 7,15,3)/
     x 2.4433017d-03,-3.3636545d-03, 1.4007056d-10 /
      data fpppp( 2, 7,16,1),fpppp( 2, 7,16,2),fpppp( 2, 7,16,3)/
     x 1.0131830d-02, 3.1336018d-04, 2.1400778d-07 /
      data fpppp( 2, 7,17,1),fpppp( 2, 7,17,2),fpppp( 2, 7,17,3)/
     x 9.8862926d-03, 7.5107244d-03,-4.4373396d-07 /
      data fpppp( 2, 7,18,1),fpppp( 2, 7,18,2),fpppp( 2, 7,18,3)/
     x 2.0000600d-03,-1.4422865d-02, 1.9407816d-06 /
      data fpppp( 2, 7,19,1),fpppp( 2, 7,19,2),fpppp( 2, 7,19,3)/
     x 1.5745471d-02, 1.7923946d-02,-5.2410334d-06 /
      data fpppp( 2, 7,20,1),fpppp( 2, 7,20,2),fpppp( 2, 7,20,3)/
     x 1.1635126d-02,-6.9779901d-03, 2.4041868d-06 /
      data fpppp( 2, 7,21,1),fpppp( 2, 7,21,2),fpppp( 2, 7,21,3)/
     x 1.1635126d-02,-4.8909151d-03, 1.8939217d-06 /
      data fpppp( 2, 7,22,1),fpppp( 2, 7,22,2),fpppp( 2, 7,22,3)/
     x 1.5745471d-02, 9.5756458d-03,-3.1999730d-06 /
      data fpppp( 2, 7,23,1),fpppp( 2, 7,23,2),fpppp( 2, 7,23,3)/
     x 2.0000600d-03, 1.6883261d-02,-5.7131946d-06 /
      data fpppp( 2, 8, 1,1),fpppp( 2, 8, 1,2),fpppp( 2, 8, 1,3)/
     x-5.4666187d-03, 6.4748779d-03, 1.9105709d-06 /
      data fpppp( 2, 8, 2,1),fpppp( 2, 8, 2,2),fpppp( 2, 8, 2,3)/
     x 1.9017410d-02, 3.5371647d-03, 7.2482501d-07 /
      data fpppp( 2, 8, 3,1),fpppp( 2, 8, 3,2),fpppp( 2, 8, 3,3)/
     x-1.0590215d-02,-2.3825125d-03,-2.3905472d-06 /
      data fpppp( 2, 8, 4,1),fpppp( 2, 8, 4,2),fpppp( 2, 8, 4,3)/
     x-1.0590215d-02,-3.0395016d-03,-1.3851928d-06 /
      data fpppp( 2, 8, 5,1),fpppp( 2, 8, 5,2),fpppp( 2, 8, 5,3)/
     x 1.9017410d-02, 6.1651210d-03,-3.2965926d-06 /
      data fpppp( 2, 8, 6,1),fpppp( 2, 8, 6,2),fpppp( 2, 8, 6,3)/
     x-5.4666187d-03,-3.3799579d-03, 1.6990887d-05 /
      data fpppp( 2, 8, 7,1),fpppp( 2, 8, 7,2),fpppp( 2, 8, 7,3)/
     x-5.1208771d-03, 3.6428096d-05,-1.3499570d-05 /
      data fpppp( 2, 8, 8,1),fpppp( 2, 8, 8,2),fpppp( 2, 8, 8,3)/
     x 5.1415594d-02, 1.1954005d-02, 1.2850407d-06 /
      data fpppp( 2, 8, 9,1),fpppp( 2, 8, 9,2),fpppp( 2, 8, 9,3)/
     x-4.7347795d-03,-2.2221704d-02, 1.4281380d-06 /
      data fpppp( 2, 8,10,1),fpppp( 2, 8,10,2),fpppp( 2, 8,10,3)/
     x-4.2423551d-04, 2.1261058d-02,-6.6930807d-07 /
      data fpppp( 2, 8,11,1),fpppp( 2, 8,11,2),fpppp( 2, 8,11,3)/
     x-3.9652498d-02,-1.2877440d-02, 2.4709023d-07 /
      data fpppp( 2, 8,12,1),fpppp( 2, 8,12,2),fpppp( 2, 8,12,3)/
     x-4.0807342d-02, 6.5565502d-03,-1.0376062d-07 /
      data fpppp( 2, 8,13,1),fpppp( 2, 8,13,2),fpppp( 2, 8,13,3)/
     x 6.4941074d-03,-1.2146317d-02, 5.9759648d-08 /
      data fpppp( 2, 8,14,1),fpppp( 2, 8,14,2),fpppp( 2, 8,14,3)/
     x-3.6231246d-02, 2.0669760d-02, 7.7790899d-10 /
      data fpppp( 2, 8,15,1),fpppp( 2, 8,15,2),fpppp( 2, 8,15,3)/
     x 7.0734071d-03,-2.3959595d-02, 4.3229265d-08 /
      data fpppp( 2, 8,16,1),fpppp( 2, 8,16,2),fpppp( 2, 8,16,3)/
     x-2.6717166d-03, 2.4379079d-02, 8.6898515d-09 /
      data fpppp( 2, 8,17,1),fpppp( 2, 8,17,2),fpppp( 2, 8,17,3)/
     x-1.3707343d-03,-1.3930059d-02, 2.2743755d-07 /
      data fpppp( 2, 8,18,1),fpppp( 2, 8,18,2),fpppp( 2, 8,18,3)/
     x 1.6793282d-04, 3.5332826d-03,-3.7016735d-07 /
      data fpppp( 2, 8,19,1),fpppp( 2, 8,19,2),fpppp( 2, 8,19,3)/
     x-1.5824839d-02, 3.1406535d-03, 1.7686630d-06 /
      data fpppp( 2, 8,20,1),fpppp( 2, 8,20,2),fpppp( 2, 8,20,3)/
     x-1.7245216d-02,-3.2544106d-03,-1.1753252d-06 /
      data fpppp( 2, 8,21,1),fpppp( 2, 8,21,2),fpppp( 2, 8,21,3)/
     x-1.7245216d-02,-3.1313852d-03,-1.0085835d-06 /
      data fpppp( 2, 8,22,1),fpppp( 2, 8,22,2),fpppp( 2, 8,22,3)/
     x-1.5824839d-02, 2.6485521d-03, 1.1016963d-06 /
      data fpppp( 2, 8,23,1),fpppp( 2, 8,23,2),fpppp( 2, 8,23,3)/
     x 1.6793282d-04, 5.3786629d-03, 2.1309580d-06 /
      data fpppp( 2, 9, 1,1),fpppp( 2, 9, 1,2),fpppp( 2, 9, 1,3)/
     x 3.3053685d-03,-2.8097729d-03,-8.9784590d-07 /
      data fpppp( 2, 9, 2,1),fpppp( 2, 9, 2,2),fpppp( 2, 9, 2,3)/
     x-4.2972248d-03,-1.8601454d-03,-6.2183193d-07 /
      data fpppp( 2, 9, 3,1),fpppp( 2, 9, 3,2),fpppp( 2, 9, 3,3)/
     x 4.8782229d-03, 7.3578173d-04, 5.1750244d-07 /
      data fpppp( 2, 9, 4,1),fpppp( 2, 9, 4,2),fpppp( 2, 9, 4,3)/
     x 4.8782229d-03,-2.4598792d-04,-4.4128031d-07 /
      data fpppp( 2, 9, 5,1),fpppp( 2, 9, 5,2),fpppp( 2, 9, 5,3)/
     x-4.2972248d-03, 2.0669332d-03, 3.2132990d-06 /
      data fpppp( 2, 9, 6,1),fpppp( 2, 9, 6,2),fpppp( 2, 9, 6,3)/
     x 3.3053685d-03,-1.7536318d-02,-1.5279587d-05 /
      data fpppp( 2, 9, 7,1),fpppp( 2, 9, 7,2),fpppp( 2, 9, 7,3)/
     x 1.3578206d-02, 5.4740190d-02, 2.1341397d-05 /
      data fpppp( 2, 9, 8,1),fpppp( 2, 9, 8,2),fpppp( 2, 9, 8,3)/
     x-8.2903210d-02,-5.9163104d-02,-6.9342837d-06 /
      data fpppp( 2, 9, 9,1),fpppp( 2, 9, 9,2),fpppp( 2, 9, 9,3)/
     x 1.8906995d-02, 6.5432971d-03,-3.9141009d-06 /
      data fpppp( 2, 9,10,1),fpppp( 2, 9,10,2),fpppp( 2, 9,10,3)/
     x-3.5717033d-04, 3.1842931d-02, 2.4504540d-06 /
      data fpppp( 2, 9,11,1),fpppp( 2, 9,11,2),fpppp( 2, 9,11,3)/
     x 1.4805213d-01,-2.5264885d-02,-6.6067670d-07 /
      data fpppp( 2, 9,12,1),fpppp( 2, 9,12,2),fpppp( 2, 9,12,3)/
     x 1.5471517d-01, 1.3174761d-02, 2.2254516d-07 /
      data fpppp( 2, 9,13,1),fpppp( 2, 9,13,2),fpppp( 2, 9,13,3)/
     x-2.5626198d-02,-2.5944743d-02,-4.1790808d-08 /
      data fpppp( 2, 9,14,1),fpppp( 2, 9,14,2),fpppp( 2, 9,14,3)/
     x 1.3354357d-01, 4.2896718d-02, 4.3174237d-08 /
      data fpppp( 2, 9,15,1),fpppp( 2, 9,15,2),fpppp( 2, 9,15,3)/
     x-2.5538253d-02,-4.6690297d-02, 3.5169631d-08 /
      data fpppp( 2, 9,16,1),fpppp( 2, 9,16,2),fpppp( 2, 9,16,3)/
     x 7.3176817d-04, 4.3480604d-02, 3.0163796d-08 /
      data fpppp( 2, 9,17,1),fpppp( 2, 9,17,2),fpppp( 2, 9,17,3)/
     x-2.1651672d-02,-2.5782412d-02, 7.7353070d-08 /
      data fpppp( 2, 9,18,1),fpppp( 2, 9,18,2),fpppp( 2, 9,18,3)/
     x-1.9138460d-02, 6.3065979d-03,-1.5600034d-07 /
      data fpppp( 2, 9,19,1),fpppp( 2, 9,19,2),fpppp( 2, 9,19,3)/
     x-9.5288619d-03,-1.8974679d-03, 8.3708466d-07 /
      data fpppp( 2, 9,20,1),fpppp( 2, 9,20,2),fpppp( 2, 9,20,3)/
     x-1.6077916d-02, 9.4648799d-04,-6.3229196d-07 /
      data fpppp( 2, 9,21,1),fpppp( 2, 9,21,2),fpppp( 2, 9,21,3)/
     x-1.6077916d-02, 4.9405546d-04,-5.5260237d-07 /
      data fpppp( 2, 9,22,1),fpppp( 2, 9,22,2),fpppp( 2, 9,22,3)/
     x-9.5288619d-03,-8.7737820d-05, 5.1832629d-07 /
      data fpppp( 2, 9,23,1),fpppp( 2, 9,23,2),fpppp( 2, 9,23,3)/
     x-1.9138460d-02,-4.7989003d-04, 1.0393436d-06 /
      data fpppp( 2,10, 1,1),fpppp( 2,10, 1,2),fpppp( 2,10, 1,3)/
     x-5.4937327d-03,-7.7779454d-03, 1.2846533d-06 /
      data fpppp( 2,10, 2,1),fpppp( 2,10, 2,2),fpppp( 2,10, 2,3)/
     x-5.6658635d-03,-4.4675660d-03, 5.6675159d-07 /
      data fpppp( 2,10, 3,1),fpppp( 2,10, 3,2),fpppp( 2,10, 3,3)/
     x-5.2884058d-03, 1.9481399d-03,-1.1944987d-06 /
      data fpppp( 2,10, 4,1),fpppp( 2,10, 4,2),fpppp( 2,10, 4,3)/
     x-5.2884058d-03, 3.1345770d-03,-8.0444208d-07 /
      data fpppp( 2,10, 5,1),fpppp( 2,10, 5,2),fpppp( 2,10, 5,3)/
     x-5.6658635d-03,-9.2133146d-03,-9.9347478d-07 /
      data fpppp( 2,10, 6,1),fpppp( 2,10, 6,2),fpppp( 2,10, 6,3)/
     x-5.4937327d-03, 1.0018612d-02, 7.1355022d-06 /
      data fpppp( 2,10, 7,1),fpppp( 2,10, 7,2),fpppp( 2,10, 7,3)/
     x-1.3749589d-02,-2.3136383d-02,-1.5364630d-05 /
      data fpppp( 2,10, 8,1),fpppp( 2,10, 8,2),fpppp( 2,10, 8,3)/
     x 5.5313908d-02, 6.4822903d-02, 1.4127582d-05 /
      data fpppp( 2,10, 9,1),fpppp( 2,10, 9,2),fpppp( 2,10, 9,3)/
     x-5.4084417d-02,-1.1050601d-01,-1.7035180d-08 /
      data fpppp( 2,10,10,1),fpppp( 2,10,10,2),fpppp( 2,10,10,3)/
     x 1.9704254d-03, 1.7219552d-01,-4.7751126d-06 /
      data fpppp( 2,10,11,1),fpppp( 2,10,11,2),fpppp( 2,10,11,3)/
     x-2.5616993d-01,-9.7961044d-02, 1.5984969d-06 /
      data fpppp( 2,10,12,1),fpppp( 2,10,12,2),fpppp( 2,10,12,3)/
     x-2.6651983d-01,-1.4986402d-01,-3.9509654d-07 /
      data fpppp( 2,10,13,1),fpppp( 2,10,13,2),fpppp( 2,10,13,3)/
     x 1.9959865d-02, 2.9646174d-01, 1.2906940d-07 /
      data fpppp( 2,10,14,1),fpppp( 2,10,14,2),fpppp( 2,10,14,3)/
     x-1.4518025d-01,-2.9364102d-01,-6.7015562d-09 /
      data fpppp( 2,10,15,1),fpppp( 2,10,15,2),fpppp( 2,10,15,3)/
     x 2.0326818d-02, 1.7310367d-01, 1.7731988d-09 /
      data fpppp( 2,10,16,1),fpppp( 2,10,16,2),fpppp( 2,10,16,3)/
     x-1.8015536d-04,-4.6408285d-02, 7.2117708d-08 /
      data fpppp( 2,10,17,1),fpppp( 2,10,17,2),fpppp( 2,10,17,3)/
     x 1.9531438d-02, 1.2453044d-02,-3.0762179d-07 /
      data fpppp( 2,10,18,1),fpppp( 2,10,18,2),fpppp( 2,10,18,3)/
     x 1.8265380d-02,-3.4342652d-03, 1.1005138d-06 /
      data fpppp( 2,10,19,1),fpppp( 2,10,19,2),fpppp( 2,10,19,3)/
     x 1.4367471d-02, 1.2555668d-03,-4.1033701d-06 /
      data fpppp( 2,10,20,1),fpppp( 2,10,20,2),fpppp( 2,10,20,3)/
     x 7.5275346d-02,-3.5948942d-04, 2.1755817d-06 /
      data fpppp( 2,10,21,1),fpppp( 2,10,21,2),fpppp( 2,10,21,3)/
     x 7.5275346d-02,-1.0109425d-04, 1.7894711d-06 /
      data fpppp( 2,10,22,1),fpppp( 2,10,22,2),fpppp( 2,10,22,3)/
     x 1.4367471d-02, 2.2198613d-04,-2.5589281d-06 /
      data fpppp( 2,10,23,1),fpppp( 2,10,23,2),fpppp( 2,10,23,3)/
     x 1.8265380d-02, 4.4166235d-04,-4.6911439d-06 /
      data fpppp( 2,11, 1,1),fpppp( 2,11, 1,2),fpppp( 2,11, 1,3)/
     x 5.2030704d-03, 1.8194166d-03, 4.3520869d-06 /
      data fpppp( 2,11, 2,1),fpppp( 2,11, 2,2),fpppp( 2,11, 2,3)/
     x 9.1350916d-03, 7.3182955d-04, 1.8567573d-06 /
      data fpppp( 2,11, 3,1),fpppp( 2,11, 3,2),fpppp( 2,11, 3,3)/
     x 3.5179155d-02,-1.5438636d-03,-3.2971287d-06 /
      data fpppp( 2,11, 4,1),fpppp( 2,11, 4,2),fpppp( 2,11, 4,3)/
     x 3.5179155d-02,-1.6398518d-03,-3.6353144d-06 /
      data fpppp( 2,11, 5,1),fpppp( 2,11, 5,2),fpppp( 2,11, 5,3)/
     x 9.1350916d-03, 1.1157823d-03, 3.2094999d-06 /
      data fpppp( 2,11, 6,1),fpppp( 2,11, 6,2),fpppp( 2,11, 6,3)/
     x 5.2030704d-03, 3.7959356d-04,-7.2069810d-07 /
      data fpppp( 2,11, 7,1),fpppp( 2,11, 7,2),fpppp( 2,11, 7,3)/
     x 7.0048234d-03, 8.4556000d-04, 6.7642095d-06 /
      data fpppp( 2,11, 8,1),fpppp( 2,11, 8,2),fpppp( 2,11, 8,3)/
     x-1.5669695d-02,-3.3843251d-03,-1.0539514d-05 /
      data fpppp( 2,11, 9,1),fpppp( 2,11, 9,2),fpppp( 2,11, 9,3)/
     x 4.6009292d-02, 8.1569559d-03, 8.2186256d-06 /
      data fpppp( 2,11,10,1),fpppp( 2,11,10,2),fpppp( 2,11,10,3)/
     x-3.3469576d-03,-8.4046895d-03, 1.9168236d-08 /
      data fpppp( 2,11,11,1),fpppp( 2,11,11,2),fpppp( 2,11,11,3)/
     x 1.7121218d-01, 1.2249808d-02,-1.8725819d-06 /
      data fpppp( 2,11,12,1),fpppp( 2,11,12,2),fpppp( 2,11,12,3)/
     x 1.8150352d-01,-3.8430337d-02, 4.2175275d-07 /
      data fpppp( 2,11,13,1),fpppp( 2,11,13,2),fpppp( 2,11,13,3)/
     x-5.1498737d-03, 1.4144064d-01,-1.0018289d-07 /
      data fpppp( 2,11,14,1),fpppp( 2,11,14,2),fpppp( 2,11,14,3)/
     x 4.7056285d-02,-2.2304945d-01, 3.6664709d-08 /
      data fpppp( 2,11,15,1),fpppp( 2,11,15,2),fpppp( 2,11,15,3)/
     x-5.3473829d-03, 1.4153532d-01, 1.7502804d-08 /
      data fpppp( 2,11,16,1),fpppp( 2,11,16,2),fpppp( 2,11,16,3)/
     x 1.3347926d-04,-3.8796996d-02,-6.4608271d-08 /
      data fpppp( 2,11,17,1),fpppp( 2,11,17,2),fpppp( 2,11,17,3)/
     x-5.1775847d-03, 1.3478994d-02, 2.5294344d-07 /
      data fpppp( 2,11,18,1),fpppp( 2,11,18,2),fpppp( 2,11,18,3)/
     x-4.9497891d-03,-1.5312377d-02,-9.7059867d-07 /
      data fpppp( 2,11,19,1),fpppp( 2,11,19,2),fpppp( 2,11,19,3)/
     x-5.2097240d-03, 4.6248355d-02, 3.3747615d-06 /
      data fpppp( 2,11,20,1),fpppp( 2,11,20,2),fpppp( 2,11,20,3)/
     x-1.0640921d-01,-2.4762302d-02,-1.8761535d-06 /
      data fpppp( 2,11,21,1),fpppp( 2,11,21,2),fpppp( 2,11,21,3)/
     x-1.0640921d-01,-2.0267094d-02,-1.5535686d-06 /
      data fpppp( 2,11,22,1),fpppp( 2,11,22,2),fpppp( 2,11,22,3)/
     x-5.2097240d-03, 2.8267525d-02, 2.0844221d-06 /
      data fpppp( 2,11,23,1),fpppp( 2,11,23,2),fpppp( 2,11,23,3)/
     x-4.9497891d-03, 5.2115736d-02, 3.8681738d-06 /
      data fpppp( 2,12, 1,1),fpppp( 2,12, 1,2),fpppp( 2,12, 1,3)/
     x 5.8803750d-04, 1.0211507d-02, 9.2260176d-06 /
      data fpppp( 2,12, 2,1),fpppp( 2,12, 2,2),fpppp( 2,12, 2,3)/
     x 4.6510410d-03, 4.7575528d-03, 4.3825723d-06 /
      data fpppp( 2,12, 3,1),fpppp( 2,12, 3,2),fpppp( 2,12, 3,3)/
     x-8.7760847d-02,-6.6130424d-03,-5.7168169d-06 /
      data fpppp( 2,12, 4,1),fpppp( 2,12, 4,2),fpppp( 2,12, 4,3)/
     x-8.7760847d-02,-7.1668298d-03,-6.2058060d-06 /
      data fpppp( 2,12, 5,1),fpppp( 2,12, 5,2),fpppp( 2,12, 5,3)/
     x 4.6510410d-03, 6.9727023d-03, 6.3385287d-06 /
      data fpppp( 2,12, 6,1),fpppp( 2,12, 6,2),fpppp( 2,12, 6,3)/
     x 5.8803750d-04, 1.9046966d-03, 1.8911810d-06 /
      data fpppp( 2,12, 7,1),fpppp( 2,12, 7,2),fpppp( 2,12, 7,3)/
     x-1.5999657d-03, 1.0253059d-03,-9.8362438d-07 /
      data fpppp( 2,12, 8,1),fpppp( 2,12, 8,2),fpppp( 2,12, 8,3)/
     x 4.0264249d-03,-3.1822502d-04, 4.0459680d-06 /
      data fpppp( 2,12, 9,1),fpppp( 2,12, 9,2),fpppp( 2,12, 9,3)/
     x-1.4193341d-02, 6.3484917d-04,-6.2889536d-06 /
      data fpppp( 2,12,10,1),fpppp( 2,12,10,2),fpppp( 2,12,10,3)/
     x 2.5378310d-03, 7.2522066d-04, 6.0224897d-06 /
      data fpppp( 2,12,11,1),fpppp( 2,12,11,2),fpppp( 2,12,11,3)/
     x-4.5779219d-02, 6.1434033d-03,-1.8712429d-06 /
      data fpppp( 2,12,12,1),fpppp( 2,12,12,2),fpppp( 2,12,12,3)/
     x-6.7997956d-02,-3.4640233d-02, 1.3240958d-07 /
      data fpppp( 2,12,13,1),fpppp( 2,12,13,2),fpppp( 2,12,13,3)/
     x 1.4746445d-03, 1.3405318d-01,-1.1200049d-07 /
      data fpppp( 2,12,14,1),fpppp( 2,12,14,2),fpppp( 2,12,14,3)/
     x-9.4459664d-03,-2.1192371d-01, 2.9049303d-08 /
      data fpppp( 2,12,15,1),fpppp( 2,12,15,2),fpppp( 2,12,15,3)/
     x 1.5848523d-03, 1.3435595d-01,-1.2788097d-08 /
      data fpppp( 2,12,16,1),fpppp( 2,12,16,2),fpppp( 2,12,16,3)/
     x 1.5670344d-04,-3.6210718d-02, 7.2563518d-08 /
      data fpppp( 2,12,17,1),fpppp( 2,12,17,2),fpppp( 2,12,17,3)/
     x 1.6574962d-03, 1.0195799d-02,-1.2562087d-07 /
      data fpppp( 2,12,18,1),fpppp( 2,12,18,2),fpppp( 2,12,18,3)/
     x 1.7678387d-03,-5.1415630d-03, 5.9878828d-07 /
      data fpppp( 2,12,19,1),fpppp( 2,12,19,2),fpppp( 2,12,19,3)/
     x 3.6972888d-03, 4.5909171d-03,-2.2361565d-06 /
      data fpppp( 2,12,20,1),fpppp( 2,12,20,2),fpppp( 2,12,20,3)/
     x 6.7859189d-02,-1.3331124d-03, 1.1432880d-06 /
      data fpppp( 2,12,21,1),fpppp( 2,12,21,2),fpppp( 2,12,21,3)/
     x 6.7859189d-02,-7.3989905d-04, 9.3385668d-07 /
      data fpppp( 2,12,22,1),fpppp( 2,12,22,2),fpppp( 2,12,22,3)/
     x 3.6972888d-03, 2.2180638d-03,-1.3984314d-06 /
      data fpppp( 2,12,23,1),fpppp( 2,12,23,2),fpppp( 2,12,23,3)/
     x 1.7678387d-03, 3.7566367d-03,-2.5426809d-06 /
      data fpppp( 2,13, 1,1),fpppp( 2,13, 1,2),fpppp( 2,13, 1,3)/
     x-1.7672315d-03,-9.6204636d-02,-1.8707543d-05 /
      data fpppp( 2,13, 2,1),fpppp( 2,13, 2,2),fpppp( 2,13, 2,3)/
     x-6.6810939d-03,-5.3837683d-02,-9.1951452d-06 /
      data fpppp( 2,13, 3,1),fpppp( 2,13, 3,2),fpppp( 2,13, 3,3)/
     x 3.0611709d-02, 3.2028988d-02, 1.0585977d-05 /
      data fpppp( 2,13, 4,1),fpppp( 2,13, 4,2),fpppp( 2,13, 4,3)/
     x 3.0611709d-02, 4.0638390d-02, 1.1640505d-05 /
      data fpppp( 2,13, 5,1),fpppp( 2,13, 5,2),fpppp( 2,13, 5,3)/
     x-6.6810939d-03,-8.8275292d-02,-1.3413258d-05 /
      data fpppp( 2,13, 6,1),fpppp( 2,13, 6,2),fpppp( 2,13, 6,3)/
     x-1.7672315d-03, 3.2936399d-02,-2.8896212d-06 /
      data fpppp( 2,13, 7,1),fpppp( 2,13, 7,2),fpppp( 2,13, 7,3)/
     x 3.3817765d-04,-5.2911094d-03,-8.5444733d-07 /
      data fpppp( 2,13, 8,1),fpppp( 2,13, 8,2),fpppp( 2,13, 8,3)/
     x-1.1373297d-03, 2.4263076d-03,-9.4018115d-07 /
      data fpppp( 2,13, 9,1),fpppp( 2,13, 9,2),fpppp( 2,13, 9,3)/
     x 6.3332377d-03,-1.1898716d-03, 1.5070560d-06 /
      data fpppp( 2,13,10,1),fpppp( 2,13,10,2),fpppp( 2,13,10,3)/
     x-7.7924367d-05, 2.2739378d-03,-2.3194934d-06 /
      data fpppp( 2,13,11,1),fpppp( 2,13,11,2),fpppp( 2,13,11,3)/
     x 9.4315192d-03, 4.3074949d-03, 2.7743924d-06 /
      data fpppp( 2,13,12,1),fpppp( 2,13,12,2),fpppp( 2,13,12,3)/
     x 9.1674948d-02,-2.7491496d-02,-1.1632599d-06 /
      data fpppp( 2,13,13,1),fpppp( 2,13,13,2),fpppp( 2,13,13,3)/
     x 5.9779119d-05, 1.0492272d-01, 3.0110137d-07 /
      data fpppp( 2,13,14,1),fpppp( 2,13,14,2),fpppp( 2,13,14,3)/
     x-5.7133183d-02,-1.6547570d-01,-1.4137913d-07 /
      data fpppp( 2,13,15,1),fpppp( 2,13,15,2),fpppp( 2,13,15,3)/
     x-2.4467504d-04, 1.0490790d-01, 5.1921896d-08 /
      data fpppp( 2,13,16,1),fpppp( 2,13,16,2),fpppp( 2,13,16,3)/
     x 2.2743201d-04,-2.8239698d-02,-1.4821784d-07 /
      data fpppp( 2,13,17,1),fpppp( 2,13,17,2),fpppp( 2,13,17,3)/
     x-4.4852103d-06, 7.8621407d-03, 4.7739590d-07 /
      data fpppp( 2,13,18,1),fpppp( 2,13,18,2),fpppp( 2,13,18,3)/
     x 3.7016767d-04,-3.5700068d-03,-2.0526858d-06 /
      data fpppp( 2,13,19,1),fpppp( 2,13,19,2),fpppp( 2,13,19,3)/
     x 9.6836080d-04, 3.3932150d-03, 6.5948942d-06 /
      data fpppp( 2,13,20,1),fpppp( 2,13,20,2),fpppp( 2,13,20,3)/
     x-1.6432393d-02,-1.1523108d-03,-3.4027453d-06 /
      data fpppp( 2,13,21,1),fpppp( 2,13,21,2),fpppp( 2,13,21,3)/
     x-1.6432393d-02,-7.2108608d-04,-2.7707922d-06 /
      data fpppp( 2,13,22,1),fpppp( 2,13,22,2),fpppp( 2,13,22,3)/
     x 9.6836080d-04, 1.6683161d-03, 4.0670819d-06 /
      data fpppp( 2,13,23,1),fpppp( 2,13,23,2),fpppp( 2,13,23,3)/
     x 3.7016767d-04, 2.8983638d-03, 7.4266106d-06 /
      data fpppp( 2,14, 1,1),fpppp( 2,14, 1,2),fpppp( 2,14, 1,3)/
     x-3.3854604d-03,-1.2756198d-01,-1.1925551d-05 /
      data fpppp( 2,14, 2,1),fpppp( 2,14, 2,2),fpppp( 2,14, 2,3)/
     x-1.4239681d-02,-7.1016884d-02,-5.1390999d-06 /
      data fpppp( 2,14, 3,1),fpppp( 2,14, 3,2),fpppp( 2,14, 3,3)/
     x 1.1630860d-01, 4.3702352d-02, 9.1401676d-06 /
      data fpppp( 2,14, 4,1),fpppp( 2,14, 4,2),fpppp( 2,14, 4,3)/
     x 1.1630860d-01, 5.4987786d-02, 9.6006414d-06 /
      data fpppp( 2,14, 5,1),fpppp( 2,14, 5,2),fpppp( 2,14, 5,3)/
     x-1.4239681d-02,-1.1615862d-01,-6.9809953d-06 /
      data fpppp( 2,14, 6,1),fpppp( 2,14, 6,2),fpppp( 2,14, 6,3)/
     x-3.3854604d-03, 4.1719542d-02,-5.0184435d-06 /
      data fpppp( 2,14, 7,1),fpppp( 2,14, 7,2),fpppp( 2,14, 7,3)/
     x-1.1831058d-03,-7.9886285d-03,-2.0235793d-06 /
      data fpppp( 2,14, 8,1),fpppp( 2,14, 8,2),fpppp( 2,14, 8,3)/
     x-8.0518064d-05, 5.3347760d-03,-3.7252391d-07 /
      data fpppp( 2,14, 9,1),fpppp( 2,14, 9,2),fpppp( 2,14, 9,3)/
     x-3.9142607d-03,-2.8741880d-04,-2.9367527d-07 /
      data fpppp( 2,14,10,1),fpppp( 2,14,10,2),fpppp( 2,14,10,3)/
     x-2.8256877d-04,-2.0360521d-02,-3.6377662d-07 /
      data fpppp( 2,14,11,1),fpppp( 2,14,11,2),fpppp( 2,14,11,3)/
     x-6.9303578d-04, 9.1069160d-02, 1.0416005d-06 /
      data fpppp( 2,14,12,1),fpppp( 2,14,12,2),fpppp( 2,14,12,3)/
     x-1.0996447d-01,-1.4237659d-01,-1.3761804d-07 /
      data fpppp( 2,14,13,1),fpppp( 2,14,13,2),fpppp( 2,14,13,3)/
     x-1.7366438d-03, 8.9086210d-02,-2.7077952d-07 /
      data fpppp( 2,14,14,1),fpppp( 2,14,14,2),fpppp( 2,14,14,3)/
     x 7.5552149d-02,-2.3813070d-02, 1.3053352d-07 /
      data fpppp( 2,14,15,1),fpppp( 2,14,15,2),fpppp( 2,14,15,3)/
     x-3.4501223d-04, 6.3987336d-03,-8.4350198d-08 /
      data fpppp( 2,14,16,1),fpppp( 2,14,16,2),fpppp( 2,14,16,3)/
     x-5.7982305d-04,-1.7010576d-03, 1.1216438d-07 /
      data fpppp( 2,14,17,1),fpppp( 2,14,17,2),fpppp( 2,14,17,3)/
     x-6.9791932d-04, 5.4867911d-04,-5.0385815d-07 /
      data fpppp( 2,14,18,1),fpppp( 2,14,18,2),fpppp( 2,14,18,3)/
     x-1.2398001d-03,-3.4812244d-05, 1.7754001d-06 /
      data fpppp( 2,14,19,1),fpppp( 2,14,19,2),fpppp( 2,14,19,3)/
     x-3.1498317d-03, 6.6587993d-04,-6.2457457d-06 /
      data fpppp( 2,14,20,1),fpppp( 2,14,20,2),fpppp( 2,14,20,3)/
     x 9.5857173d-04,-5.6151946d-04, 3.4578293d-06 /
      data fpppp( 2,14,21,1),fpppp( 2,14,21,2),fpppp( 2,14,21,3)/
     x 9.5857173d-04,-5.0106952d-04, 2.8621260d-06 /
      data fpppp( 2,14,22,1),fpppp( 2,14,22,2),fpppp( 2,14,22,3)/
     x-3.1498317d-03, 4.2408020d-04,-3.8629329d-06 /
      data fpppp( 2,14,23,1),fpppp( 2,14,23,2),fpppp( 2,14,23,3)/
     x-1.2398001d-03, 8.7193672d-04,-7.1601479d-06 /
      data fpppp( 2,15, 1,1),fpppp( 2,15, 1,2),fpppp( 2,15, 1,3)/
     x 1.9687747d-05, 7.5062824d-03, 1.2089307d-05 /
      data fpppp( 2,15, 2,1),fpppp( 2,15, 2,2),fpppp( 2,15, 2,3)/
     x 4.9328922d-03, 3.1847425d-03, 6.0224659d-06 /
      data fpppp( 2,15, 3,1),fpppp( 2,15, 3,2),fpppp( 2,15, 3,3)/
     x-1.2727792d-01,-5.8805223d-03,-6.5931710d-06 /
      data fpppp( 2,15, 4,1),fpppp( 2,15, 4,2),fpppp( 2,15, 4,3)/
     x-1.2727792d-01,-6.2220836d-03,-7.2664610d-06 /
      data fpppp( 2,15, 5,1),fpppp( 2,15, 5,2),fpppp( 2,15, 5,3)/
     x 4.9328922d-03, 4.5509876d-03, 8.7156259d-06 /
      data fpppp( 2,15, 6,1),fpppp( 2,15, 6,2),fpppp( 2,15, 6,3)/
     x 1.9687747d-05, 2.3828632d-03, 1.9899572d-06 /
      data fpppp( 2,15, 7,1),fpppp( 2,15, 7,2),fpppp( 2,15, 7,3)/
     x-1.3043194d-05, 6.6475399d-04, 1.9780986d-07 /
      data fpppp( 2,15, 8,1),fpppp( 2,15, 8,2),fpppp( 2,15, 8,3)/
     x 1.7068496d-04, 3.1959346d-03,-4.4778650d-07 /
      data fpppp( 2,15, 9,1),fpppp( 2,15, 9,2),fpppp( 2,15, 9,3)/
     x-8.8796490d-04,-2.5882535d-03, 8.9289629d-10 /
      data fpppp( 2,15,10,1),fpppp( 2,15,10,2),fpppp( 2,15,10,3)/
     x 4.0809021d-04,-6.7998068d-03,-3.8488819d-07 /
      data fpppp( 2,15,11,1),fpppp( 2,15,11,2),fpppp( 2,15,11,3)/
     x 1.3542470d-03, 3.5655489d-02, 3.6787016d-07 /
      data fpppp( 2,15,12,1),fpppp( 2,15,12,2),fpppp( 2,15,12,3)/
     x 3.6012185d-02,-5.3753597d-02,-9.2117628d-08 /
      data fpppp( 2,15,13,1),fpppp( 2,15,13,2),fpppp( 2,15,13,3)/
     x 5.9599440d-03, 3.2820937d-02, 7.9863109d-07 /
      data fpppp( 2,15,14,1),fpppp( 2,15,14,2),fpppp( 2,15,14,3)/
     x-1.9599882d-02,-8.7849686d-03,-4.8816279d-07 /
      data fpppp( 2,15,15,1),fpppp( 2,15,15,2),fpppp( 2,15,15,3)/
     x 1.0290392d-03, 2.3828588d-03, 1.2933586d-07 /
      data fpppp( 2,15,16,1),fpppp( 2,15,16,2),fpppp( 2,15,16,3)/
     x 1.3127668d-03,-6.1325209d-04,-7.6779692d-08 /
      data fpppp( 2,15,17,1),fpppp( 2,15,17,2),fpppp( 2,15,17,3)/
     x 1.5022597d-03, 2.1386079d-04, 1.5801973d-07 /
      data fpppp( 2,15,18,1),fpppp( 2,15,18,2),fpppp( 2,15,18,3)/
     x 1.7619751d-03, 1.8298661d-05,-3.8394685d-07 /
      data fpppp( 2,15,19,1),fpppp( 2,15,19,2),fpppp( 2,15,19,3)/
     x 2.4485171d-03, 6.5999809d-05, 1.9409140d-06 /
      data fpppp( 2,15,20,1),fpppp( 2,15,20,2),fpppp( 2,15,20,3)/
     x 1.9287063d-03,-1.3002396d-04,-1.2067611d-06 /
      data fpppp( 2,15,21,1),fpppp( 2,15,21,2),fpppp( 2,15,21,3)/
     x 1.9287063d-03,-1.2341737d-04,-1.0266768d-06 /
      data fpppp( 2,15,22,1),fpppp( 2,15,22,2),fpppp( 2,15,22,3)/
     x 2.4485171d-03, 3.9573434d-05, 1.2205768d-06 /
      data fpppp( 2,15,23,1),fpppp( 2,15,23,2),fpppp( 2,15,23,3)/
     x 1.7619751d-03, 1.1739757d-04, 2.3173177d-06 /
      data fpppp( 2,16, 1,1),fpppp( 2,16, 1,2),fpppp( 2,16, 1,3)/
     x-6.7640963d-04, 7.2222985d-03, 3.7422218d-06 /
      data fpppp( 2,16, 2,1),fpppp( 2,16, 2,2),fpppp( 2,16, 2,3)/
     x 3.0488232d-03, 3.7273067d-03, 1.4950480d-06 /
      data fpppp( 2,16, 3,1),fpppp( 2,16, 3,2),fpppp( 2,16, 3,3)/
     x 3.5921237d-02,-3.4212892d-03,-3.2431493d-06 /
      data fpppp( 2,16, 4,1),fpppp( 2,16, 4,2),fpppp( 2,16, 4,3)/
     x 3.5921237d-02,-4.0174658d-03,-3.3782058d-06 /
      data fpppp( 2,16, 5,1),fpppp( 2,16, 5,2),fpppp( 2,16, 5,3)/
     x 3.0488232d-03, 6.1120132d-03, 2.0352742d-06 /
      data fpppp( 2,16, 6,1),fpppp( 2,16, 6,2),fpppp( 2,16, 6,3)/
     x-6.7640963d-04,-1.7203510d-03, 1.7163737d-06 /
      data fpppp( 2,16, 7,1),fpppp( 2,16, 7,2),fpppp( 2,16, 7,3)/
     x-1.8640348d-03, 9.4049805d-04, 9.1696168d-07 /
      data fpppp( 2,16, 8,1),fpppp( 2,16, 8,2),fpppp( 2,16, 8,3)/
     x-2.0929419d-03, 5.8970001d-05, 2.2794366d-07 /
      data fpppp( 2,16, 9,1),fpppp( 2,16, 9,2),fpppp( 2,16, 9,3)/
     x 2.1974515d-04, 1.1679507d-04,-2.0665318d-07 /
      data fpppp( 2,16,10,1),fpppp( 2,16,10,2),fpppp( 2,16,10,3)/
     x-2.1065792d-03,-1.9259169d-05, 3.3032309d-07 /
      data fpppp( 2,16,11,1),fpppp( 2,16,11,2),fpppp( 2,16,11,3)/
     x-2.2383144d-03,-8.9056067d-04,-1.7906590d-06 /
      data fpppp( 2,16,12,1),fpppp( 2,16,12,2),fpppp( 2,16,12,3)/
     x 9.2166546d-03, 3.7519419d-03, 4.8244866d-06 /
      data fpppp( 2,16,13,1),fpppp( 2,16,13,2),fpppp( 2,16,13,3)/
     x-2.3182363d-02,-3.0376021d-03,-5.4066393d-06 /
      data fpppp( 2,16,14,1),fpppp( 2,16,14,2),fpppp( 2,16,14,3)/
     x 2.3075126d-03, 6.5317908d-04, 2.4366973d-06 /
      data fpppp( 2,16,15,1),fpppp( 2,16,15,2),fpppp( 2,16,15,3)/
     x-4.2681439d-03,-1.7643564d-04,-5.8733742d-07 /
      data fpppp( 2,16,16,1),fpppp( 2,16,16,2),fpppp( 2,16,16,3)/
     x-5.3052333d-03, 5.8328970d-05, 2.5499153d-07 /
      data fpppp( 2,16,17,1),fpppp( 2,16,17,2),fpppp( 2,16,17,3)/
     x-6.1717007d-03,-2.2421886d-06, 3.7748434d-09 /
      data fpppp( 2,16,18,1),fpppp( 2,16,18,2),fpppp( 2,16,18,3)/
     x-6.8949334d-03, 1.3113251d-05, 2.2140763d-07 /
      data fpppp( 2,16,19,1),fpppp( 2,16,19,2),fpppp( 2,16,19,3)/
     x-7.5379791d-03,-6.8006197d-08,-4.1238749d-07 /
      data fpppp( 2,16,20,1),fpppp( 2,16,20,2),fpppp( 2,16,20,3)/
     x-7.6190937d-03,-2.0526738d-05, 3.1542303d-07 /
      data fpppp( 2,16,21,1),fpppp( 2,16,21,2),fpppp( 2,16,21,3)/
     x-7.6190937d-03,-2.0699231d-05, 2.6921544d-07 /
      data fpppp( 2,16,22,1),fpppp( 2,16,22,2),fpppp( 2,16,22,3)/
     x-7.5379791d-03, 6.2196512d-07,-2.2755711d-07 /
      data fpppp( 2,16,23,1),fpppp( 2,16,23,2),fpppp( 2,16,23,3)/
     x-6.8949334d-03, 1.0525859d-05,-4.7170632d-07 /
      data fpppp( 2,17, 1,1),fpppp( 2,17, 1,2),fpppp( 2,17, 1,3)/
     x 8.1157614d-03,-4.1694175d-06,-6.0128319d-07 /
      data fpppp( 2,17, 2,1),fpppp( 2,17, 2,2),fpppp( 2,17, 2,3)/
     x 7.8749757d-03,-5.1753671d-05,-4.4747041d-07 /
      data fpppp( 2,17, 3,1),fpppp( 2,17, 3,2),fpppp( 2,17, 3,3)/
     x 4.7489546d-03,-1.5360209d-04,-1.5841332d-07 /
      data fpppp( 2,17, 4,1),fpppp( 2,17, 4,2),fpppp( 2,17, 4,3)/
     x 4.7489546d-03,-1.5380830d-04,-8.7465319d-08 /
      data fpppp( 2,17, 5,1),fpppp( 2,17, 5,2),fpppp( 2,17, 5,3)/
     x 7.8749757d-03,-5.0928832d-05,-7.3126243d-07 /
      data fpppp( 2,17, 6,1),fpppp( 2,17, 6,2),fpppp( 2,17, 6,3)/
     x 8.1157614d-03,-7.2625633d-06, 4.6293689d-07 /
      data fpppp( 2,17, 7,1),fpppp( 2,17, 7,2),fpppp( 2,17, 7,3)/
     x 7.7088132d-03, 5.8169579d-05, 1.9996737d-07 /
      data fpppp( 2,17, 8,1),fpppp( 2,17, 8,2),fpppp( 2,17, 8,3)/
     x 7.4590045d-03,-5.3536080d-05, 1.1236715d-07 /
      data fpppp( 2,17, 9,1),fpppp( 2,17, 9,2),fpppp( 2,17, 9,3)/
     x 6.7286081d-03, 3.2549297d-04, 4.0794724d-08 /
      data fpppp( 2,17,10,1),fpppp( 2,17,10,2),fpppp( 2,17,10,3)/
     x 7.3510357d-03,-1.1262839d-03,-3.4657905d-07 /
      data fpppp( 2,17,11,1),fpppp( 2,17,11,2),fpppp( 2,17,11,3)/
     x 7.0518123d-03, 4.1168373d-03, 7.6215069d-07 /
      data fpppp( 2,17,12,1),fpppp( 2,17,12,2),fpppp( 2,17,12,3)/
     x 5.5451199d-03,-1.8217607d-02,-4.9855927d-06 /
      data fpppp( 2,17,13,1),fpppp( 2,17,13,2),fpppp( 2,17,13,3)/
     x 3.8991141d-02, 3.2277350d-02, 9.3985164d-06 /
      data fpppp( 2,17,14,1),fpppp( 2,17,14,2),fpppp( 2,17,14,3)/
     x 9.9243559d-03,-2.1592371d-02,-3.8918241d-06 /
      data fpppp( 2,17,15,1),fpppp( 2,17,15,2),fpppp( 2,17,15,3)/
     x 1.5822483d-02, 5.7171000d-03, 8.5965438d-07 /
      data fpppp( 2,17,16,1),fpppp( 2,17,16,2),fpppp( 2,17,16,3)/
     x 1.9768880d-02,-1.5403658d-03,-4.9811086d-07 /
      data fpppp( 2,17,17,1),fpppp( 2,17,17,2),fpppp( 2,17,17,3)/
     x 2.3129674d-02, 4.1257733d-04,-1.6070189d-07 /
      data fpppp( 2,17,18,1),fpppp( 2,17,18,2),fpppp( 2,17,18,3)/
     x 2.5984984d-02,-1.0780831d-04,-3.0306810d-07 /
      data fpppp( 2,17,19,1),fpppp( 2,17,19,2),fpppp( 2,17,19,3)/
     x 2.8351798d-02, 2.4963684d-05,-1.6044361d-07 /
      data fpppp( 2,17,20,1),fpppp( 2,17,20,2),fpppp( 2,17,20,3)/
     x 2.9831592d-02,-5.3389138d-06,-4.0534842d-07 /
      data fpppp( 2,17,21,1),fpppp( 2,17,21,2),fpppp( 2,17,21,3)/
     x 2.9831592d-02, 1.6348142d-06,-3.9315316d-07 /
      data fpppp( 2,17,22,1),fpppp( 2,17,22,2),fpppp( 2,17,22,3)/
     x 2.8351798d-02,-2.9312279d-06,-2.0922463d-07 /
      data fpppp( 2,17,23,1),fpppp( 2,17,23,2),fpppp( 2,17,23,3)/
     x 2.5984984d-02,-3.2023868d-06,-1.2013926d-07 /
      data fpppp( 2,18, 1,1),fpppp( 2,18, 1,2),fpppp( 2,18, 1,3)/
     x-2.7525464d-02,-1.5978996d-05, 3.1650909d-07 /
      data fpppp( 2,18, 2,1),fpppp( 2,18, 2,2),fpppp( 2,18, 2,3)/
     x-2.7137780d-02,-1.8230566d-05, 1.5215733d-07 /
      data fpppp( 2,18, 3,1),fpppp( 2,18, 3,2),fpppp( 2,18, 3,3)/
     x-2.5028767d-02,-2.3338658d-05,-1.9193036d-07 /
      data fpppp( 2,18, 4,1),fpppp( 2,18, 4,2),fpppp( 2,18, 4,3)/
     x-2.5028767d-02,-2.2842887d-05,-2.0609601d-07 /
      data fpppp( 2,18, 5,1),fpppp( 2,18, 5,2),fpppp( 2,18, 5,3)/
     x-2.7137780d-02,-2.0213651d-05, 2.0881990d-07 /
      data fpppp( 2,18, 6,1),fpppp( 2,18, 6,2),fpppp( 2,18, 6,3)/
     x-2.7525464d-02,-8.5424262d-06, 1.0402446d-07 /
      data fpppp( 2,18, 7,1),fpppp( 2,18, 7,2),fpppp( 2,18, 7,3)/
     x-2.7704514d-02,-5.0365699d-06, 7.4501538d-08 /
      data fpppp( 2,18, 8,1),fpppp( 2,18, 8,2),fpppp( 2,18, 8,3)/
     x-2.7793451d-02,-5.0774272d-05,-2.0887637d-09 /
      data fpppp( 2,18, 9,1),fpppp( 2,18, 9,2),fpppp( 2,18, 9,3)/
     x-2.7643857d-02, 1.1177121d-04,-7.4792396d-08 /
      data fpppp( 2,18,10,1),fpppp( 2,18,10,2),fpppp( 2,18,10,3)/
     x-2.7882596d-02,-2.7494699d-04,-5.9436485d-09 /
      data fpppp( 2,18,11,1),fpppp( 2,18,11,2),fpppp( 2,18,11,3)/
     x-2.7781119d-02, 5.6140938d-04,-4.1056992d-07 /
      data fpppp( 2,18,12,1),fpppp( 2,18,12,2),fpppp( 2,18,12,3)/
     x-2.7749990d-02,-1.2077332d-03, 1.0806059d-06 /
      data fpppp( 2,18,13,1),fpppp( 2,18,13,2),fpppp( 2,18,13,3)/
     x-3.9752185d-02, 4.1609816d-03,-3.7254870d-06 /
      data fpppp( 2,18,14,1),fpppp( 2,18,14,2),fpppp( 2,18,14,3)/
     x-3.1895495d-02,-1.3955071d-03, 1.6543994d-06 /
      data fpppp( 2,18,15,1),fpppp( 2,18,15,2),fpppp( 2,18,15,3)/
     x-3.7106418d-02,-1.1979543d-06,-1.8786046d-07 /
      data fpppp( 2,18,16,1),fpppp( 2,18,16,2),fpppp( 2,18,16,3)/
     x-4.1275253d-02,-3.6040194d-04, 3.5425312d-07 /
      data fpppp( 2,18,17,1),fpppp( 2,18,17,2),fpppp( 2,18,17,3)/
     x-4.4804807d-02,-2.0791507d-04, 2.2340824d-07 /
      data fpppp( 2,18,18,1),fpppp( 2,18,18,2),fpppp( 2,18,18,3)/
     x-4.7789177d-02,-1.9965562d-04, 2.6664150d-07 /
      data fpppp( 2,18,19,1),fpppp( 2,18,19,2),fpppp( 2,18,19,3)/
     x-5.0238044d-02,-3.6928793d-04, 2.4719945d-07 /
      data fpppp( 2,18,20,1),fpppp( 2,18,20,2),fpppp( 2,18,20,3)/
     x-5.1823031d-02,-4.6435850d-04, 3.3216384d-07 /
      data fpppp( 2,18,21,1),fpppp( 2,18,21,2),fpppp( 2,18,21,3)/
     x-5.1823031d-02,-4.7030467d-04, 3.2935883d-07 /
      data fpppp( 2,18,22,1),fpppp( 2,18,22,2),fpppp( 2,18,22,3)/
     x-5.0238044d-02,-3.4550324d-04, 2.5841947d-07 /
      data fpppp( 2,18,23,1),fpppp( 2,18,23,2),fpppp( 2,18,23,3)/
     x-4.7789177d-02,-2.8884822d-04, 2.2456643d-07 /
      data fpppp( 2,19, 1,1),fpppp( 2,19, 1,2),fpppp( 2,19, 1,3)/
     x-5.0471433d-02, 2.9395140d-17,-2.6892643d-07 /
      data fpppp( 2,19, 2,1),fpppp( 2,19, 2,2),fpppp( 2,19, 2,3)/
     x-5.0767990d-02,-2.4149807d-19, 2.5457595d-08 /
      data fpppp( 2,19, 3,1),fpppp( 2,19, 3,2),fpppp( 2,19, 3,3)/
     x-5.5204935d-02,-1.8790455d-17, 6.6548202d-07 /
      data fpppp( 2,19, 4,1),fpppp( 2,19, 4,2),fpppp( 2,19, 4,3)/
     x-5.5204935d-02, 7.9705041d-18, 6.4937936d-07 /
      data fpppp( 2,19, 5,1),fpppp( 2,19, 5,2),fpppp( 2,19, 5,3)/
     x-5.0767990d-02, 2.0736579d-18, 8.9868246d-08 /
      data fpppp( 2,19, 6,1),fpppp( 2,19, 6,2),fpppp( 2,19, 6,3)/
     x-5.0471433d-02, 2.2497198d-17,-5.1046637d-07 /
      data fpppp( 2,19, 7,1),fpppp( 2,19, 7,2),fpppp( 2,19, 7,3)/
     x-5.0264648d-02, 1.6159426d-17,-2.1997243d-07 /
      data fpppp( 2,19, 8,1),fpppp( 2,19, 8,2),fpppp( 2,19, 8,3)/
     x-5.0244648d-02, 3.3782585d-18,-1.1686485d-07 /
      data fpppp( 2,19, 9,1),fpppp( 2,19, 9,2),fpppp( 2,19, 9,3)/
     x-5.0335942d-02,-1.8150261d-17,-8.6655224d-08 /
      data fpppp( 2,19,10,1),fpppp( 2,19,10,2),fpppp( 2,19,10,3)/
     x-5.0347300d-02, 1.0532603d-17, 4.3966743d-08 /
      data fpppp( 2,19,11,1),fpppp( 2,19,11,2),fpppp( 2,19,11,3)/
     x-5.0007463d-02,-3.1572265d-19,-5.1885329d-07 /
      data fpppp( 2,19,12,1),fpppp( 2,19,12,2),fpppp( 2,19,12,3)/
     x-5.2581222d-02,-4.5729565d-18, 2.6107251d-06 /
      data fpppp( 2,19,13,1),fpppp( 2,19,13,2),fpppp( 2,19,13,3)/
     x-7.8233559d-02,-1.2080017d-17,-8.8697306d-06 /
      data fpppp( 2,19,14,1),fpppp( 2,19,14,2),fpppp( 2,19,14,3)/
     x-5.9590576d-02, 1.8875379d-17, 3.8078387d-06 /
      data fpppp( 2,19,15,1),fpppp( 2,19,15,2),fpppp( 2,19,15,3)/
     x-6.9172596d-02,-1.4192232d-17,-5.2265911d-07 /
      data fpppp( 2,19,16,1),fpppp( 2,19,16,2),fpppp( 2,19,16,3)/
     x-7.7714173d-02, 2.7448631d-17, 7.4791243d-07 /
      data fpppp( 2,19,17,1),fpppp( 2,19,17,2),fpppp( 2,19,17,3)/
     x-8.4957616d-02,-8.2545642d-19, 4.5077927d-07 /
      data fpppp( 2,19,18,1),fpppp( 2,19,18,2),fpppp( 2,19,18,3)/
     x-9.1090744d-02, 1.1837327d-17, 5.2372672d-07 /
      data fpppp( 2,19,19,1),fpppp( 2,19,19,2),fpppp( 2,19,19,3)/
     x-9.6119423d-02, 1.6510811d-17, 6.1035703d-07 /
      data fpppp( 2,19,20,1),fpppp( 2,19,20,2),fpppp( 2,19,20,3)/
     x-9.9447566d-02,-1.7872184d-17, 6.5302360d-07 /
      data fpppp( 2,19,21,1),fpppp( 2,19,21,2),fpppp( 2,19,21,3)/
     x-9.9447566d-02, 1.3388243d-17, 6.5619065d-07 /
      data fpppp( 2,19,22,1),fpppp( 2,19,22,2),fpppp( 2,19,22,3)/
     x-9.6119423d-02,-6.1919643d-18, 5.9768882d-07 /
      data fpppp( 2,19,23,1),fpppp( 2,19,23,2),fpppp( 2,19,23,3)/
     x-9.1090744d-02,-6.6171155d-18, 5.7123251d-07 /
      data fpppp( 3, 1, 1,1),fpppp( 3, 1, 1,2),fpppp( 3, 1, 1,3)/
     x 2.9221415d-03,-2.8442867d-16, 1.3729882d-05 /
      data fpppp( 3, 1, 2,1),fpppp( 3, 1, 2,2),fpppp( 3, 1, 2,3)/
     x 1.4099487d-02, 1.6398215d-16, 8.2764650d-06 /
      data fpppp( 3, 1, 3,1),fpppp( 3, 1, 3,2),fpppp( 3, 1, 3,3)/
     x 1.0555268d-02,-1.3325723d-16,-2.6279277d-06 /
      data fpppp( 3, 1, 4,1),fpppp( 3, 1, 4,2),fpppp( 3, 1, 4,3)/
     x 1.0555268d-02,-3.5979563d-17,-3.9955557d-06 /
      data fpppp( 3, 1, 5,1),fpppp( 3, 1, 5,2),fpppp( 3, 1, 5,3)/
     x 1.4099487d-02,-1.3618124d-16, 1.3746977d-05 /
      data fpppp( 3, 1, 6,1),fpppp( 3, 1, 6,2),fpppp( 3, 1, 6,3)/
     x 2.9221415d-03, 3.0069721d-16,-6.7845363d-06 /
      data fpppp( 3, 1, 7,1),fpppp( 3, 1, 7,2),fpppp( 3, 1, 7,3)/
     x 3.3188312d-02, 3.4375991d-16, 3.3726402d-06 /
      data fpppp( 3, 1, 8,1),fpppp( 3, 1, 8,2),fpppp( 3, 1, 8,3)/
     x-1.8694926d-01, 1.0752853d-16,-1.0987854d-05 /
      data fpppp( 3, 1, 9,1),fpppp( 3, 1, 9,2),fpppp( 3, 1, 9,3)/
     x-1.5627870d-01, 4.9220465d-17, 2.6278797d-07 /
      data fpppp( 3, 1,10,1),fpppp( 3, 1,10,2),fpppp( 3, 1,10,3)/
     x-2.6087970d-02,-1.6537356d-16, 3.4210158d-06 /
      data fpppp( 3, 1,11,1),fpppp( 3, 1,11,2),fpppp( 3, 1,11,3)/
     x 4.5117086d-02,-9.3073003d-17, 1.4616175d-06 /
      data fpppp( 3, 1,12,1),fpppp( 3, 1,12,2),fpppp( 3, 1,12,3)/
     x 7.4697520d-02, 5.8929598d-17, 2.1125967d-06 /
      data fpppp( 3, 1,13,1),fpppp( 3, 1,13,2),fpppp( 3, 1,13,3)/
     x 4.4370078d-02, 3.2392066d-16, 1.7477153d-06 /
      data fpppp( 3, 1,14,1),fpppp( 3, 1,14,2),fpppp( 3, 1,14,3)/
     x-3.3897262d-02, 4.5174491d-17, 3.0829041d-06 /
      data fpppp( 3, 1,15,1),fpppp( 3, 1,15,2),fpppp( 3, 1,15,3)/
     x-1.6002537d-01,-1.0998840d-16,-4.6345801d-08 /
      data fpppp( 3, 1,16,1),fpppp( 3, 1,16,2),fpppp( 3, 1,16,3)/
     x-1.7922946d-01, 2.2391705d-17,-1.0613127d-05 /
      data fpppp( 3, 1,17,1),fpppp( 3, 1,17,2),fpppp( 3, 1,17,3)/
     x 2.5978226d-02, 2.6922750d-16, 3.0312988d-06 /
      data fpppp( 3, 1,18,1),fpppp( 3, 1,18,2),fpppp( 3, 1,18,3)/
     x 3.2234765d-04, 1.4144304d-16,-6.1923059d-06 /
      data fpppp( 3, 1,19,1),fpppp( 3, 1,19,2),fpppp( 3, 1,19,3)/
     x 1.1881075d-02,-1.8672233d-16, 1.3373154d-05 /
      data fpppp( 3, 1,20,1),fpppp( 3, 1,20,2),fpppp( 3, 1,20,3)/
     x 1.0437498d-02,-2.4300308d-18,-3.9255961d-06 /
      data fpppp( 3, 1,21,1),fpppp( 3, 1,21,2),fpppp( 3, 1,21,3)/
     x 1.0437498d-02,-2.5580998d-16,-2.6136557d-06 /
      data fpppp( 3, 1,22,1),fpppp( 3, 1,22,2),fpppp( 3, 1,22,3)/
     x 1.1881075d-02, 1.5795727d-16, 8.1253927d-06 /
      data fpppp( 3, 1,23,1),fpppp( 3, 1,23,2),fpppp( 3, 1,23,3)/
     x 3.2234765d-04, 1.1145002d-16, 1.3486799d-05 /
      data fpppp( 3, 2, 1,1),fpppp( 3, 2, 1,2),fpppp( 3, 2, 1,3)/
     x 2.8705980d-03,-1.5709192d-03, 8.5029603d-06 /
      data fpppp( 3, 2, 2,1),fpppp( 3, 2, 2,2),fpppp( 3, 2, 2,3)/
     x 9.9910483d-03,-9.3422586d-04, 5.1233500d-06 /
      data fpppp( 3, 2, 3,1),fpppp( 3, 2, 3,2),fpppp( 3, 2, 3,3)/
     x 5.7869866d-03, 3.7159686d-04,-1.6337093d-06 /
      data fpppp( 3, 2, 4,1),fpppp( 3, 2, 4,2),fpppp( 3, 2, 4,3)/
     x 5.7869866d-03, 4.7400727d-04,-2.4823943d-06 /
      data fpppp( 3, 2, 5,1),fpppp( 3, 2, 5,2),fpppp( 3, 2, 5,3)/
     x 9.9910483d-03,-1.3438675d-03, 8.5180899d-06 /
      data fpppp( 3, 2, 6,1),fpppp( 3, 2, 6,2),fpppp( 3, 2, 6,3)/
     x 2.8705980d-03,-3.4763143d-05,-4.2273142d-06 /
      data fpppp( 3, 2, 7,1),fpppp( 3, 2, 7,2),fpppp( 3, 2, 7,3)/
     x 1.6014514d-02, 1.7073086d-03, 1.3627640d-06 /
      data fpppp( 3, 2, 8,1),fpppp( 3, 2, 8,2),fpppp( 3, 2, 8,3)/
     x-7.8629101d-02,-1.0827536d-03,-4.8506430d-06 /
      data fpppp( 3, 2, 9,1),fpppp( 3, 2, 9,2),fpppp( 3, 2, 9,3)/
     x-6.5656899d-02,-1.0673424d-03, 7.6063150d-08 /
      data fpppp( 3, 2,10,1),fpppp( 3, 2,10,2),fpppp( 3, 2,10,3)/
     x-9.4710884d-03, 2.1952634d-03, 1.4897230d-06 /
      data fpppp( 3, 2,11,1),fpppp( 3, 2,11,2),fpppp( 3, 2,11,3)/
     x 2.1000852d-02,-1.2439812d-03, 6.1054783d-07 /
      data fpppp( 3, 2,12,1),fpppp( 3, 2,12,2),fpppp( 3, 2,12,3)/
     x 3.4600912d-02,-1.5813015d-04, 9.1452097d-07 /
      data fpppp( 3, 2,13,1),fpppp( 3, 2,13,2),fpppp( 3, 2,13,3)/
     x 2.0679938d-02, 1.9794982d-03, 7.4902915d-07 /
      data fpppp( 3, 2,14,1),fpppp( 3, 2,14,2),fpppp( 3, 2,14,3)/
     x-1.3166387d-02,-3.1075351d-03, 1.3272382d-06 /
      data fpppp( 3, 2,15,1),fpppp( 3, 2,15,2),fpppp( 3, 2,15,3)/
     x-6.7270905d-02, 1.9228902d-03,-6.4054002d-08 /
      data fpppp( 3, 2,16,1),fpppp( 3, 2,16,2),fpppp( 3, 2,16,3)/
     x-7.5124870d-02,-4.8580141d-04,-4.6520104d-06 /
      data fpppp( 3, 2,17,1),fpppp( 3, 2,17,2),fpppp( 3, 2,17,3)/
     x 1.2754332d-02, 7.2823857d-04, 1.3455441d-06 /
      data fpppp( 3, 2,18,1),fpppp( 3, 2,18,2),fpppp( 3, 2,18,3)/
     x 1.7250311d-03,-1.7320127d-03,-4.1420711d-06 /
      data fpppp( 3, 2,19,1),fpppp( 3, 2,19,2),fpppp( 3, 2,19,3)/
     x 8.1248169d-03, 1.3219303d-03, 8.4214818d-06 /
      data fpppp( 3, 2,20,1),fpppp( 3, 2,20,2),fpppp( 3, 2,20,3)/
     x 6.0555532d-03,-2.2370067d-04,-2.4783249d-06 /
      data fpppp( 3, 2,21,1),fpppp( 3, 2,21,2),fpppp( 3, 2,21,3)/
     x 6.0555532d-03,-4.4496367d-05,-1.6405023d-06 /
      data fpppp( 3, 2,22,1),fpppp( 3, 2,22,2),fpppp( 3, 2,22,3)/
     x 8.1248169d-03, 6.0511306d-04, 5.0701915d-06 /
      data fpppp( 3, 2,23,1),fpppp( 3, 2,23,2),fpppp( 3, 2,23,3)/
     x 1.7250311d-03, 9.5605194d-04, 8.4252679d-06 /
      data fpppp( 3, 3, 1,1),fpppp( 3, 3, 1,2),fpppp( 3, 3, 1,3)/
     x 8.3920586d-03, 2.6622764d-03,-4.1662920d-05 /
      data fpppp( 3, 3, 2,1),fpppp( 3, 3, 2,2),fpppp( 3, 3, 2,3)/
     x-3.3249259d-02, 1.6704664d-03,-2.6217813d-05 /
      data fpppp( 3, 3, 3,1),fpppp( 3, 3, 3,2),fpppp( 3, 3, 3,3)/
     x 2.0135933d-03,-2.3320378d-03, 4.3604732d-06 /
      data fpppp( 3, 3, 4,1),fpppp( 3, 3, 4,2),fpppp( 3, 3, 4,3)/
     x 2.0135933d-03, 9.5305735d-04, 8.7676221d-06 /
      data fpppp( 3, 3, 5,1),fpppp( 3, 3, 5,2),fpppp( 3, 3, 5,3)/
     x-3.3249259d-02,-1.1469914d-02,-4.3846409d-05 /
      data fpppp( 3, 3, 6,1),fpppp( 3, 3, 6,2),fpppp( 3, 3, 6,3)/
     x 8.3920586d-03, 5.1938704d-02, 2.4444314d-05 /
      data fpppp( 3, 3, 7,1),fpppp( 3, 3, 7,2),fpppp( 3, 3, 7,3)/
     x-2.2781968d-02,-1.4615049d-01,-2.8045080d-06 /
      data fpppp( 3, 3, 8,1),fpppp( 3, 3, 8,2),fpppp( 3, 3, 8,3)/
     x 2.1764060d-01, 1.3412941d-01, 1.4555952d-05 /
      data fpppp( 3, 3, 9,1),fpppp( 3, 3, 9,2),fpppp( 3, 3, 9,3)/
     x 1.8559886d-01, 1.1057837d-02, 3.3318834d-07 /
      data fpppp( 3, 3,10,1),fpppp( 3, 3,10,2),fpppp( 3, 3,10,3)/
     x 4.3803225d-02,-2.2053762d-02,-2.5319491d-06 /
      data fpppp( 3, 3,11,1),fpppp( 3, 3,11,2),fpppp( 3, 3,11,3)/
     x-3.6010093d-02,-9.7621710d-03,-1.1170724d-06 /
      data fpppp( 3, 3,12,1),fpppp( 3, 3,12,2),fpppp( 3, 3,12,3)/
     x-7.8303851d-02,-1.6367721d-02,-1.5240647d-06 /
      data fpppp( 3, 3,13,1),fpppp( 3, 3,13,2),fpppp( 3, 3,13,3)/
     x-3.5159667d-02,-9.1150205d-03,-1.1872317d-06 /
      data fpppp( 3, 3,14,1),fpppp( 3, 3,14,2),fpppp( 3, 3,14,3)/
     x 4.8477142d-02,-2.5016218d-02,-2.5295936d-06 /
      data fpppp( 3, 3,15,1),fpppp( 3, 3,15,2),fpppp( 3, 3,15,3)/
     x 1.8971100d-01, 2.0827892d-02, 1.0583082d-06 /
      data fpppp( 3, 3,16,1),fpppp( 3, 3,16,2),fpppp( 3, 3,16,3)/
     x 2.0862596d-01, 1.1950844d-01, 1.3960319d-05 /
      data fpppp( 3, 3,17,1),fpppp( 3, 3,17,2),fpppp( 3, 3,17,3)/
     x-1.7248070d-02,-1.3489037d-01,-2.5567461d-06 /
      data fpppp( 3, 3,18,1),fpppp( 3, 3,18,2),fpppp( 3, 3,18,3)/
     x 9.1240152d-03, 4.7191855d-02, 2.3567523d-05 /
      data fpppp( 3, 3,19,1),fpppp( 3, 3,19,2),fpppp( 3, 3,19,3)/
     x-1.8183234d-02,-1.0381198d-02,-4.3100740d-05 /
      data fpppp( 3, 3,20,1),fpppp( 3, 3,20,2),fpppp( 3, 3,20,3)/
     x 1.1989007d-03, 8.0783427d-04, 8.6890792d-06 /
      data fpppp( 3, 3,21,1),fpppp( 3, 3,21,2),fpppp( 3, 3,21,3)/
     x 1.1989007d-03,-2.1729221d-03, 4.3772036d-06 /
      data fpppp( 3, 3,22,1),fpppp( 3, 3,22,2),fpppp( 3, 3,22,3)/
     x-1.8183234d-02, 1.5418277d-03,-2.5853238d-05 /
      data fpppp( 3, 3,23,1),fpppp( 3, 3,23,2),fpppp( 3, 3,23,3)/
     x 9.1240152d-03, 2.4805092d-03,-4.1110611d-05 /
      data fpppp( 3, 4, 1,1),fpppp( 3, 4, 1,2),fpppp( 3, 4, 1,3)/
     x-5.5919953d-03, 5.9326409d-02, 6.5457553d-05 /
      data fpppp( 3, 4, 2,1),fpppp( 3, 4, 2,2),fpppp( 3, 4, 2,3)/
     x 6.0471972d-02, 3.4654601d-02, 4.1099192d-05 /
      data fpppp( 3, 4, 3,1),fpppp( 3, 4, 3,2),fpppp( 3, 4, 3,3)/
     x-5.2419078d-03,-1.4470060d-02,-7.1452184d-06 /
      data fpppp( 3, 4, 4,1),fpppp( 3, 4, 4,2),fpppp( 3, 4, 4,3)/
     x-5.2419078d-03,-2.1021184d-02,-1.4061354d-05 /
      data fpppp( 3, 4, 5,1),fpppp( 3, 4, 5,2),fpppp( 3, 4, 5,3)/
     x 6.0471972d-02, 6.0859094d-02, 6.8763734d-05 /
      data fpppp( 3, 4, 6,1),fpppp( 3, 4, 6,2),fpppp( 3, 4, 6,3)/
     x-5.5919953d-03,-3.8940442d-02,-3.8284479d-05 /
      data fpppp( 3, 4, 7,1),fpppp( 3, 4, 7,2),fpppp( 3, 4, 7,3)/
     x 1.4100946d-02, 9.7070107d-03, 5.7910547d-07 /
      data fpppp( 3, 4, 8,1),fpppp( 3, 4, 8,2),fpppp( 3, 4, 8,3)/
     x-1.4391309d-01,-1.7751255d-03,-1.2480297d-05 /
      data fpppp( 3, 4, 9,1),fpppp( 3, 4, 9,2),fpppp( 3, 4, 9,3)/
     x-1.2536422d-01,-1.7439922d-03,-9.6316150d-07 /
      data fpppp( 3, 4,10,1),fpppp( 3, 4,10,2),fpppp( 3, 4,10,3)/
     x-3.1223474d-02, 4.3118892d-03, 7.6270644d-07 /
      data fpppp( 3, 4,11,1),fpppp( 3, 4,11,2),fpppp( 3, 4,11,3)/
     x 2.2110454d-02,-1.4403505d-02, 2.2323451d-07 /
      data fpppp( 3, 4,12,1),fpppp( 3, 4,12,2),fpppp( 3, 4,12,3)/
     x 6.3619928d-02, 2.2682495d-02, 3.7913444d-07 /
      data fpppp( 3, 4,13,1),fpppp( 3, 4,13,2),fpppp( 3, 4,13,3)/
     x 2.1523856d-02,-1.4500441d-02, 1.5801888d-07 /
      data fpppp( 3, 4,14,1),fpppp( 3, 4,14,2),fpppp( 3, 4,14,3)/
     x-3.3073617d-02, 4.5226470d-03, 9.6765538d-07 /
      data fpppp( 3, 4,15,1),fpppp( 3, 4,15,2),fpppp( 3, 4,15,3)/
     x-1.2810311d-01,-2.0684312d-03,-1.8095760d-06 /
      data fpppp( 3, 4,16,1),fpppp( 3, 4,16,2),fpppp( 3, 4,16,3)/
     x-1.3638506d-01,-1.0170404d-03,-1.1706597d-05 /
      data fpppp( 3, 4,17,1),fpppp( 3, 4,17,2),fpppp( 3, 4,17,3)/
     x 1.1474303d-02, 6.0897903d-03, 1.2988378d-06 /
      data fpppp( 3, 4,18,1),fpppp( 3, 4,18,2),fpppp( 3, 4,18,3)/
     x-4.4640530d-03,-2.3481396d-02,-3.8530640d-05 /
      data fpppp( 3, 4,19,1),fpppp( 3, 4,19,2),fpppp( 3, 4,19,3)/
     x 3.4439990d-02, 3.7259533d-02, 6.8373962d-05 /
      data fpppp( 3, 4,20,1),fpppp( 3, 4,20,2),fpppp( 3, 4,20,3)/
     x-1.9962759d-03,-1.2990772d-02,-1.4163982d-05 /
      data fpppp( 3, 4,21,1),fpppp( 3, 4,21,2),fpppp( 3, 4,21,3)/
     x-1.9962759d-03,-8.9943600d-03,-7.2610240d-06 /
      data fpppp( 3, 4,22,1),fpppp( 3, 4,22,2),fpppp( 3, 4,22,3)/
     x 3.4439990d-02, 2.1273887d-02, 4.0762132d-05 /
      data fpppp( 3, 4,23,1),fpppp( 3, 4,23,2),fpppp( 3, 4,23,3)/
     x-4.4640530d-03, 3.6464778d-02, 6.5013726d-05 /
      data fpppp( 3, 5, 1,1),fpppp( 3, 5, 1,2),fpppp( 3, 5, 1,3)/
     x 1.7408461d-03, 1.7172336d-03,-4.4410562d-05 /
      data fpppp( 3, 5, 2,1),fpppp( 3, 5, 2,2),fpppp( 3, 5, 2,3)/
     x-4.0948704d-02, 9.9424125d-04,-2.6827126d-05 /
      data fpppp( 3, 5, 3,1),fpppp( 3, 5, 3,2),fpppp( 3, 5, 3,3)/
     x 1.1828663d-02,-4.9710069d-04, 8.3808743d-06 /
      data fpppp( 3, 5, 4,1),fpppp( 3, 5, 4,2),fpppp( 3, 5, 4,3)/
     x 1.1828663d-02,-5.9847367d-04, 1.2704758d-05 /
      data fpppp( 3, 5, 5,1),fpppp( 3, 5, 5,2),fpppp( 3, 5, 5,3)/
     x-4.0948704d-02, 1.3997332d-03,-4.4122662d-05 /
      data fpppp( 3, 5, 6,1),fpppp( 3, 5, 6,2),fpppp( 3, 5, 6,3)/
     x 1.7408461d-03, 1.9663892d-04, 2.0447696d-05 /
      data fpppp( 3, 5, 7,1),fpppp( 3, 5, 7,2),fpppp( 3, 5, 7,3)/
     x-2.3980769d-03, 6.7179148d-04, 1.6448908d-06 /
      data fpppp( 3, 5, 8,1),fpppp( 3, 5, 8,2),fpppp( 3, 5, 8,3)/
     x 3.8069335d-02,-2.7500089d-03, 4.1808441d-06 /
      data fpppp( 3, 5, 9,1),fpppp( 3, 5, 9,2),fpppp( 3, 5, 9,3)/
     x 3.5960353d-02, 1.8392218d-03, 4.6409671d-07 /
      data fpppp( 3, 5,10,1),fpppp( 3, 5,10,2),fpppp( 3, 5,10,3)/
     x 1.0234595d-02,-7.9545167d-04,-1.2980198d-07 /
      data fpppp( 3, 5,11,1),fpppp( 3, 5,11,2),fpppp( 3, 5,11,3)/
     x-4.1136115d-03, 5.9467912d-04,-7.6443450d-08 /
      data fpppp( 3, 5,12,1),fpppp( 3, 5,12,2),fpppp( 3, 5,12,3)/
     x-2.3829347d-02,-4.9814761d-04,-1.3863627d-07 /
      data fpppp( 3, 5,13,1),fpppp( 3, 5,13,2),fpppp( 3, 5,13,3)/
     x-3.7678003d-03, 1.9109738d-04, 6.1586974d-08 /
      data fpppp( 3, 5,14,1),fpppp( 3, 5,14,2),fpppp( 3, 5,14,3)/
     x 1.0441128d-02, 6.1894489d-04,-6.0298771d-07 /
      data fpppp( 3, 5,15,1),fpppp( 3, 5,15,2),fpppp( 3, 5,15,3)/
     x 3.6764409d-02,-3.2881450d-03, 2.1698044d-06 /
      data fpppp( 3, 5,16,1),fpppp( 3, 5,16,2),fpppp( 3, 5,16,3)/
     x 1.8228192d-02, 5.0054193d-03, 2.0632351d-06 /
      data fpppp( 3, 5,17,1),fpppp( 3, 5,17,2),fpppp( 3, 5,17,3)/
     x-1.9162836d-03,-2.6304377d-03, 4.3620490d-07 /
      data fpppp( 3, 5,18,1),fpppp( 3, 5,18,2),fpppp( 3, 5,18,3)/
     x 1.8147746d-03,-9.7027438d-04, 2.4421590d-05 /
      data fpppp( 3, 5,19,1),fpppp( 3, 5,19,2),fpppp( 3, 5,19,3)/
     x-2.0640436d-02, 1.3671537d-03,-4.4543177d-05 /
      data fpppp( 3, 5,20,1),fpppp( 3, 5,20,2),fpppp( 3, 5,20,3)/
     x-2.6731828d-03,-9.0696197d-05, 1.1743166d-05 /
      data fpppp( 3, 5,21,1),fpppp( 3, 5,21,2),fpppp( 3, 5,21,3)/
     x-2.6731828d-03, 5.2551811d-05, 7.2226723d-06 /
      data fpppp( 3, 5,22,1),fpppp( 3, 5,22,2),fpppp( 3, 5,22,3)/
     x-2.0640436d-02, 7.9416167d-04,-2.6461204d-05 /
      data fpppp( 3, 5,23,1),fpppp( 3, 5,23,2),fpppp( 3, 5,23,3)/
     x 1.8147746d-03, 1.1784457d-03,-4.3385811d-05 /
      data fpppp( 3, 6, 1,1),fpppp( 3, 6, 1,2),fpppp( 3, 6, 1,3)/
     x 1.0104025d-02, 1.6580957d-03, 1.4350772d-05 /
      data fpppp( 3, 6, 2,1),fpppp( 3, 6, 2,2),fpppp( 3, 6, 2,3)/
     x 2.5546694d-02, 1.0116973d-03, 8.1651224d-06 /
      data fpppp( 3, 6, 3,1),fpppp( 3, 6, 3,2),fpppp( 3, 6, 3,3)/
     x-3.0569747d-02,-2.5473114d-04,-4.5218297d-06 /
      data fpppp( 3, 6, 4,1),fpppp( 3, 6, 4,2),fpppp( 3, 6, 4,3)/
     x-3.0569747d-02,-4.6247519d-04,-5.5158499d-06 /
      data fpppp( 3, 6, 5,1),fpppp( 3, 6, 5,2),fpppp( 3, 6, 5,3)/
     x 2.5546694d-02, 1.8426735d-03, 1.2141203d-05 /
      data fpppp( 3, 6, 6,1),fpppp( 3, 6, 6,2),fpppp( 3, 6, 6,3)/
     x 1.0104025d-02,-1.4580651d-03,-5.5953170d-07 /
      data fpppp( 3, 6, 7,1),fpppp( 3, 6, 7,2),fpppp( 3, 6, 7,3)/
     x 1.7171931d-03, 4.0026508d-04,-3.0894040d-06 /
      data fpppp( 3, 6, 8,1),fpppp( 3, 6, 8,2),fpppp( 3, 6, 8,3)/
     x-9.5213714d-03,-1.2125180d-04,-2.8618963d-07 /
      data fpppp( 3, 6, 9,1),fpppp( 3, 6, 9,2),fpppp( 3, 6, 9,3)/
     x-9.2586479d-03, 2.8033665d-06,-3.5249075d-07 /
      data fpppp( 3, 6,10,1),fpppp( 3, 6,10,2),fpppp( 3, 6,10,3)/
     x-2.2757973d-03, 1.6990976d-05, 5.4032982d-08 /
      data fpppp( 3, 6,11,1),fpppp( 3, 6,11,2),fpppp( 3, 6,11,3)/
     x 2.5043721d-03,-1.6592961d-04,-1.2841239d-08 /
      data fpppp( 3, 6,12,1),fpppp( 3, 6,12,2),fpppp( 3, 6,12,3)/
     x 7.6832471d-03, 5.4073106d-04, 8.0841280d-08 /
      data fpppp( 3, 6,13,1),fpppp( 3, 6,13,2),fpppp( 3, 6,13,3)/
     x 1.5660917d-03,-2.0291079d-03,-2.0106883d-07 /
      data fpppp( 3, 6,14,1),fpppp( 3, 6,14,2),fpppp( 3, 6,14,3)/
     x-1.5633583d-03, 7.2185248d-03, 7.8039305d-07 /
      data fpppp( 3, 6,15,1),fpppp( 3, 6,15,2),fpppp( 3, 6,15,3)/
     x-9.6249247d-03,-2.6515972d-02,-2.9596898d-06 /
      data fpppp( 3, 6,16,1),fpppp( 3, 6,16,2),fpppp( 3, 6,16,3)/
     x 2.8171040d-02, 4.1724141d-02, 3.1171524d-06 /
      data fpppp( 3, 6,17,1),fpppp( 3, 6,17,2),fpppp( 3, 6,17,3)/
     x 1.5293405d-03,-2.6856992d-02,-2.1249509d-06 /
      data fpppp( 3, 6,18,1),fpppp( 3, 6,18,2),fpppp( 3, 6,18,3)/
     x-9.4343815d-04, 8.7432298d-03,-6.1137220d-06 /
      data fpppp( 3, 6,19,1),fpppp( 3, 6,19,2),fpppp( 3, 6,19,3)/
     x 6.0858703d-03,-8.2290174d-03, 1.2965766d-05 /
      data fpppp( 3, 6,20,1),fpppp( 3, 6,20,2),fpppp( 3, 6,20,3)/
     x 1.0256570d-02, 3.9130975d-03,-3.9492374d-06 /
      data fpppp( 3, 6,21,1),fpppp( 3, 6,21,2),fpppp( 3, 6,21,3)/
     x 1.0256570d-02, 2.8384820d-03,-2.6688661d-06 /
      data fpppp( 3, 6,22,1),fpppp( 3, 6,22,2),fpppp( 3, 6,22,3)/
     x 6.0858703d-03,-3.9305552d-03, 7.8442809d-06 /
      data fpppp( 3, 6,23,1),fpppp( 3, 6,23,2),fpppp( 3, 6,23,3)/
     x-9.4343815d-04,-7.3760033d-03, 1.3091848d-05 /
      data fpppp( 3, 7, 1,1),fpppp( 3, 7, 1,2),fpppp( 3, 7, 1,3)/
     x-4.3333103d-02,-4.4035803d-02,-3.9065393d-06 /
      data fpppp( 3, 7, 2,1),fpppp( 3, 7, 2,2),fpppp( 3, 7, 2,3)/
     x-2.6470300d-02,-2.4698091d-02,-1.6990464d-06 /
      data fpppp( 3, 7, 3,1),fpppp( 3, 7, 3,2),fpppp( 3, 7, 3,3)/
     x 4.6993932d-02, 1.4363279d-02, 3.3111510d-06 /
      data fpppp( 3, 7, 4,1),fpppp( 3, 7, 4,2),fpppp( 3, 7, 4,3)/
     x 4.6993932d-02, 1.8522305d-02, 2.8214035d-06 /
      data fpppp( 3, 7, 5,1),fpppp( 3, 7, 5,2),fpppp( 3, 7, 5,3)/
     x-2.6470300d-02,-4.1334196d-02, 2.5994358d-07 /
      data fpppp( 3, 7, 6,1),fpppp( 3, 7, 6,2),fpppp( 3, 7, 6,3)/
     x-4.3333103d-02, 1.8349591d-02,-1.1252752d-05 /
      data fpppp( 3, 7, 7,1),fpppp( 3, 7, 7,2),fpppp( 3, 7, 7,3)/
     x-3.5407411d-03,-4.0508495d-03, 8.5612421d-06 /
      data fpppp( 3, 7, 8,1),fpppp( 3, 7, 8,2),fpppp( 3, 7, 8,3)/
     x 5.6667237d-03, 3.7800559d-04,-2.3902903d-06 /
      data fpppp( 3, 7, 9,1),fpppp( 3, 7, 9,2),fpppp( 3, 7, 9,3)/
     x 1.3655485d-03, 7.8408961d-04, 4.9940815d-07 /
      data fpppp( 3, 7,10,1),fpppp( 3, 7,10,2),fpppp( 3, 7,10,3)/
     x 7.4358907d-04,-5.6893719d-04,-1.1485268d-07 /
      data fpppp( 3, 7,11,1),fpppp( 3, 7,11,2),fpppp( 3, 7,11,3)/
     x-4.6240945d-03,-1.2965666d-04, 3.6037482d-08 /
      data fpppp( 3, 7,12,1),fpppp( 3, 7,12,2),fpppp( 3, 7,12,3)/
     x-5.6434882d-03, 3.6603727d-04,-3.9322415d-08 /
      data fpppp( 3, 7,13,1),fpppp( 3, 7,13,2),fpppp( 3, 7,13,3)/
     x-1.1712297d-03,-1.0709248d-04, 1.4339354d-07 /
      data fpppp( 3, 7,14,1),fpppp( 3, 7,14,2),fpppp( 3, 7,14,3)/
     x-1.8467960d-03,-5.8682747d-04,-4.8605165d-07 /
      data fpppp( 3, 7,15,1),fpppp( 3, 7,15,2),fpppp( 3, 7,15,3)/
     x 2.2540765d-03, 8.9603578d-04, 1.8303183d-06 /
      data fpppp( 3, 7,16,1),fpppp( 3, 7,16,2),fpppp( 3, 7,16,3)/
     x-2.2609132d-02,-1.0499795d-04,-2.4959511d-06 /
      data fpppp( 3, 7,17,1),fpppp( 3, 7,17,2),fpppp( 3, 7,17,3)/
     x-2.5971147d-03,-2.0156311d-03, 1.5104614d-06 /
      data fpppp( 3, 7,18,1),fpppp( 3, 7,18,2),fpppp( 3, 7,18,3)/
     x-8.0400550d-05, 3.7888476d-03, 1.2945938d-06 /
      data fpppp( 3, 7,19,1),fpppp( 3, 7,19,2),fpppp( 3, 7,19,3)/
     x-5.7266050d-03,-4.5623970d-03,-4.1872541d-06 /
      data fpppp( 3, 7,20,1),fpppp( 3, 7,20,2),fpppp( 3, 7,20,3)/
     x-8.1078601d-03, 1.7865886d-03, 1.7106730d-06 /
      data fpppp( 3, 7,21,1),fpppp( 3, 7,21,2),fpppp( 3, 7,21,3)/
     x-8.1078601d-03, 1.2495266d-03, 1.3198084d-06 /
      data fpppp( 3, 7,22,1),fpppp( 3, 7,22,2),fpppp( 3, 7,22,3)/
     x-5.7266050d-03,-2.4141493d-03,-2.6237958d-06 /
      data fpppp( 3, 7,23,1),fpppp( 3, 7,23,2),fpppp( 3, 7,23,3)/
     x-8.0400550d-05,-4.2670813d-03,-4.5683750d-06 /
      data fpppp( 3, 8, 1,1),fpppp( 3, 8, 1,2),fpppp( 3, 8, 1,3)/
     x 6.7958519d-02,-2.8111732d-02, 1.7518183d-06 /
      data fpppp( 3, 8, 2,1),fpppp( 3, 8, 2,2),fpppp( 3, 8, 2,3)/
     x 1.4725728d-02,-1.7652208d-02, 5.6551673d-07 /
      data fpppp( 3, 8, 3,1),fpppp( 3, 8, 3,2),fpppp( 3, 8, 3,3)/
     x-2.8573926d-02, 1.1203779d-03,-2.8185412d-06 /
      data fpppp( 3, 8, 4,1),fpppp( 3, 8, 4,2),fpppp( 3, 8, 4,3)/
     x-2.8573926d-02, 7.4915691d-03,-1.3450707d-06 /
      data fpppp( 3, 8, 5,1),fpppp( 3, 8, 5,2),fpppp( 3, 8, 5,3)/
     x 1.4725728d-02,-4.3136972d-02,-5.3283650d-06 /
      data fpppp( 3, 8, 6,1),fpppp( 3, 8, 6,2),fpppp( 3, 8, 6,3)/
     x 6.7958519d-02, 6.7456135d-02, 2.3853875d-05 /
      data fpppp( 3, 8, 7,1),fpppp( 3, 8, 7,2),fpppp( 3, 8, 7,3)/
     x 1.3041742d-02,-4.1544679d-02,-2.2387960d-05 /
      data fpppp( 3, 8, 8,1),fpppp( 3, 8, 8,2),fpppp( 3, 8, 8,3)/
     x-1.2689425d-02, 7.7435235d-03, 7.2993566d-06 /
      data fpppp( 3, 8, 9,1),fpppp( 3, 8, 9,2),fpppp( 3, 8, 9,3)/
     x-5.3483777d-05, 2.9768836d-03,-1.1279695d-06 /
      data fpppp( 3, 8,10,1),fpppp( 3, 8,10,2),fpppp( 3, 8,10,3)/
     x-1.2829643d-04,-4.9409200d-03, 2.0968248d-07 /
      data fpppp( 3, 8,11,1),fpppp( 3, 8,11,2),fpppp( 3, 8,11,3)/
     x 1.0590429d-02, 3.2472872d-03,-2.1220081d-08 /
      data fpppp( 3, 8,12,1),fpppp( 3, 8,12,2),fpppp( 3, 8,12,3)/
     x 1.1179973d-02,-1.7226025d-03, 4.0229200d-08 /
      data fpppp( 3, 8,13,1),fpppp( 3, 8,13,2),fpppp( 3, 8,13,3)/
     x-1.7943299d-03, 3.2367679d-03,-1.7677193d-08 /
      data fpppp( 3, 8,14,1),fpppp( 3, 8,14,2),fpppp( 3, 8,14,3)/
     x 9.4496571d-03,-5.5509177d-03, 1.5944024d-07 /
      data fpppp( 3, 8,15,1),fpppp( 3, 8,15,2),fpppp( 3, 8,15,3)/
     x-2.5754885d-03, 6.4256570d-03,-4.3971837d-07 /
      data fpppp( 3, 8,16,1),fpppp( 3, 8,16,2),fpppp( 3, 8,16,3)/
     x 6.1052960d-03,-6.5387148d-03, 7.3716509d-07 /
      data fpppp( 3, 8,17,1),fpppp( 3, 8,17,2),fpppp( 3, 8,17,3)/
     x 3.5170823d-04, 3.7552930d-03,-2.6745194d-07 /
      data fpppp( 3, 8,18,1),fpppp( 3, 8,18,2),fpppp( 3, 8,18,3)/
     x-2.6966881d-04,-9.5928891d-04,-2.7605700d-07 /
      data fpppp( 3, 8,19,1),fpppp( 3, 8,19,2),fpppp( 3, 8,19,3)/
     x 4.3657917d-03,-5.4307232d-04, 1.7689427d-06 /
      data fpppp( 3, 8,20,1),fpppp( 3, 8,20,2),fpppp( 3, 8,20,3)/
     x 1.4132247d-03, 6.5617762d-04,-1.1650207d-06 /
      data fpppp( 3, 8,21,1),fpppp( 3, 8,21,2),fpppp( 3, 8,21,3)/
     x 1.4132247d-03, 6.4936908d-04,-1.0029551d-06 /
      data fpppp( 3, 8,22,1),fpppp( 3, 8,22,2),fpppp( 3, 8,22,3)/
     x 4.3657917d-03,-5.1583813d-04, 1.1206802d-06 /
      data fpppp( 3, 8,23,1),fpppp( 3, 8,23,2),fpppp( 3, 8,23,3)/
     x-2.6966881d-04,-1.0614171d-03, 2.1549274d-06 /
      data fpppp( 3, 9, 1,1),fpppp( 3, 9, 1,2),fpppp( 3, 9, 1,3)/
     x-4.2774541d-02, 5.8715237d-04,-8.3840826d-07 /
      data fpppp( 3, 9, 2,1),fpppp( 3, 9, 2,2),fpppp( 3, 9, 2,3)/
     x-3.6946751d-03, 4.1201430d-04,-5.7270183d-07 /
      data fpppp( 3, 9, 3,1),fpppp( 3, 9, 3,2),fpppp( 3, 9, 3,3)/
     x 7.4869011d-03,-5.3500463d-04, 7.4225341d-07 /
      data fpppp( 3, 9, 4,1),fpppp( 3, 9, 4,2),fpppp( 3, 9, 4,3)/
     x 7.4869011d-03, 4.6551075d-04,-5.6251916d-07 /
      data fpppp( 3, 9, 5,1),fpppp( 3, 9, 5,2),fpppp( 3, 9, 5,3)/
     x-3.6946751d-03,-3.5900472d-03, 4.6463885d-06 /
      data fpppp( 3, 9, 6,1),fpppp( 3, 9, 6,2),fpppp( 3, 9, 6,3)/
     x-4.2774541d-02, 1.5594883d-02,-2.0409997d-05 /
      data fpppp( 3, 9, 7,1),fpppp( 3, 9, 7,2),fpppp( 3, 9, 7,3)/
     x-2.1077343d-02,-3.1683069d-02, 3.0470884d-05 /
      data fpppp( 3, 9, 8,1),fpppp( 3, 9, 8,2),fpppp( 3, 9, 8,3)/
     x 1.5095039d-02, 2.7287810d-02,-1.6448434d-05 /
      data fpppp( 3, 9, 9,1),fpppp( 3, 9, 9,2),fpppp( 3, 9, 9,3)/
     x-2.7356475d-03,-4.9441124d-03, 2.0241333d-06 /
      data fpppp( 3, 9,10,1),fpppp( 3, 9,10,2),fpppp( 3, 9,10,3)/
     x-6.3539678d-05,-7.6975141d-03, 1.5360644d-07 /
      data fpppp( 3, 9,11,1),fpppp( 3, 9,11,2),fpppp( 3, 9,11,3)/
     x-3.9583340d-02, 6.5129875d-03,-2.8753990d-09 /
      data fpppp( 3, 9,12,1),fpppp( 3, 9,12,2),fpppp( 3, 9,12,3)/
     x-4.1444707d-02,-3.4916633d-03, 2.5714889d-08 /
      data fpppp( 3, 9,13,1),fpppp( 3, 9,13,2),fpppp( 3, 9,13,3)/
     x 6.9660105d-03, 6.9219098d-03, 2.3036388d-08 /
      data fpppp( 3, 9,14,1),fpppp( 3, 9,14,2),fpppp( 3, 9,14,3)/
     x-3.5634344d-02,-1.1485453d-02,-5.8232064d-09 /
      data fpppp( 3, 9,15,1),fpppp( 3, 9,15,2),fpppp( 3, 9,15,3)/
     x 7.0569076d-03, 1.2487292d-02, 1.6152953d-07 /
      data fpppp( 3, 9,16,1),fpppp( 3, 9,16,2),fpppp( 3, 9,16,3)/
     x-1.6314155d-03,-1.1649978d-02,-1.3981286d-07 /
      data fpppp( 3, 9,17,1),fpppp( 3, 9,17,2),fpppp( 3, 9,17,3)/
     x 5.7731907d-03, 6.9350518d-03, 1.0662633d-07 /
      data fpppp( 3, 9,18,1),fpppp( 3, 9,18,2),fpppp( 3, 9,18,3)/
     x 5.0978151d-03,-1.7116601d-03, 1.9625798d-07 /
      data fpppp( 3, 9,19,1),fpppp( 3, 9,19,2),fpppp( 3, 9,19,3)/
     x 2.3635516d-03, 8.8990021d-04,-6.3673171d-07 /
      data fpppp( 3, 9,20,1),fpppp( 3, 9,20,2),fpppp( 3, 9,20,3)/
     x 2.0312549d-02,-5.2849027d-04, 1.7568658d-07 /
      data fpppp( 3, 9,21,1),fpppp( 3, 9,21,2),fpppp( 3, 9,21,3)/
     x 2.0312549d-02,-3.7357844d-04, 1.1814933d-07 /
      data fpppp( 3, 9,22,1),fpppp( 3, 9,22,2),fpppp( 3, 9,22,3)/
     x 2.3635516d-03, 2.7025289d-04,-4.0658268d-07 /
      data fpppp( 3, 9,23,1),fpppp( 3, 9,23,2),fpppp( 3, 9,23,3)/
     x 5.0978151d-03, 6.1201733d-04,-6.6680089d-07 /
      data fpppp( 3,10, 1,1),fpppp( 3,10, 1,2),fpppp( 3,10, 1,3)/
     x 1.2995717d-02, 2.2571536d-03, 1.0326164d-06 /
      data fpppp( 3,10, 2,1),fpppp( 3,10, 2,2),fpppp( 3,10, 2,3)/
     x 3.8648094d-03, 1.1984667d-03, 4.6944727d-07 /
      data fpppp( 3,10, 3,1),fpppp( 3,10, 3,2),fpppp( 3,10, 3,3)/
     x 1.4904729d-03,-9.5387658d-04,-1.0429408d-06 /
      data fpppp( 3,10, 4,1),fpppp( 3,10, 4,2),fpppp( 3,10, 4,3)/
     x 1.4904729d-03,-1.1573518d-03,-5.0814591d-07 /
      data fpppp( 3,10, 5,1),fpppp( 3,10, 5,2),fpppp( 3,10, 5,3)/
     x 3.8648094d-03, 2.0123676d-03,-1.6697325d-06 /
      data fpppp( 3,10, 6,1),fpppp( 3,10, 6,2),fpppp( 3,10, 6,3)/
     x 1.2995717d-02,-7.9497485d-04, 9.0545403d-06 /
      data fpppp( 3,10, 7,1),fpppp( 3,10, 7,2),fpppp( 3,10, 7,3)/
     x 1.5349670d-02,-1.5807888d-03,-2.0010984d-05 /
      data fpppp( 3,10, 8,1),fpppp( 3,10, 8,2),fpppp( 3,10, 8,3)/
     x-2.8899435d-03,-3.1092086d-03, 2.1024260d-05 /
      data fpppp( 3,10, 9,1),fpppp( 3,10, 9,2),fpppp( 3,10, 9,3)/
     x 9.7173253d-03, 1.9861155d-02,-6.8202057d-06 /
      data fpppp( 3,10,10,1),fpppp( 3,10,10,2),fpppp( 3,10,10,3)/
     x 1.3514750d-03,-4.3090553d-02,-7.7326221d-07 /
      data fpppp( 3,10,11,1),fpppp( 3,10,11,2),fpppp( 3,10,11,3)/
     x 6.8835561d-02, 2.5474047d-02, 2.4221968d-07 /
      data fpppp( 3,10,12,1),fpppp( 3,10,12,2),fpppp( 3,10,12,3)/
     x 7.1561650d-02, 4.0340836d-02,-4.8766810d-08 /
      data fpppp( 3,10,13,1),fpppp( 3,10,13,2),fpppp( 3,10,13,3)/
     x-5.2579459d-03,-7.9515736d-02, 2.9945860d-08 /
      data fpppp( 3,10,14,1),fpppp( 3,10,14,2),fpppp( 3,10,14,3)/
     x 3.8954022d-02, 7.8675164d-02, 2.0033766d-08 /
      data fpppp( 3,10,15,1),fpppp( 3,10,15,2),fpppp( 3,10,15,3)/
     x-5.4240872d-03,-4.6401676d-02,-1.1418700d-08 /
      data fpppp( 3,10,16,1),fpppp( 3,10,16,2),fpppp( 3,10,16,3)/
     x 4.7966351d-04, 1.2415508d-02, 2.2500960d-08 /
      data fpppp( 3,10,17,1),fpppp( 3,10,17,2),fpppp( 3,10,17,3)/
     x-5.2160244d-03,-3.3036728d-03, 5.6787066d-08 /
      data fpppp( 3,10,18,1),fpppp( 3,10,18,2),fpppp( 3,10,18,3)/
     x-4.9194509d-03, 8.3769898d-04,-3.8727128d-07 /
      data fpppp( 3,10,19,1),fpppp( 3,10,19,2),fpppp( 3,10,19,3)/
     x-3.9074438d-03, 2.7115423d-04, 1.4649291d-06 /
      data fpppp( 3,10,20,1),fpppp( 3,10,20,2),fpppp( 3,10,20,3)/
     x-8.1511247d-02,-2.7881002d-04,-8.6640901d-07 /
      data fpppp( 3,10,21,1),fpppp( 3,10,21,2),fpppp( 3,10,21,3)/
     x-8.1511247d-02,-2.9352021d-04,-7.2684454d-07 /
      data fpppp( 3,10,22,1),fpppp( 3,10,22,2),fpppp( 3,10,22,3)/
     x-3.9074438d-03, 3.2999501d-04, 9.0667122d-07 /
      data fpppp( 3,10,23,1),fpppp( 3,10,23,2),fpppp( 3,10,23,3)/
     x-4.9194509d-03, 6.1704606d-04, 1.7061958d-06 /
      data fpppp( 3,11, 1,1),fpppp( 3,11, 1,2),fpppp( 3,11, 1,3)/
     x-3.1879037d-03, 1.5255592d-03, 3.1316031d-06 /
      data fpppp( 3,11, 2,1),fpppp( 3,11, 2,2),fpppp( 3,11, 2,3)/
     x 8.3936240d-06, 6.1856230d-04, 1.3056919d-06 /
      data fpppp( 3,11, 3,1),fpppp( 3,11, 3,2),fpppp( 3,11, 3,3)/
     x-3.6996331d-03,-1.2820573d-03,-2.4277471d-06 /
      data fpppp( 3,11, 4,1),fpppp( 3,11, 4,2),fpppp( 3,11, 4,3)/
     x-3.6996331d-03,-1.3572114d-03,-2.7413955d-06 /
      data fpppp( 3,11, 5,1),fpppp( 3,11, 5,2),fpppp( 3,11, 5,3)/
     x 8.3936240d-06, 9.1917898d-04, 2.5602855d-06 /
      data fpppp( 3,11, 6,1),fpppp( 3,11, 6,2),fpppp( 3,11, 6,3)/
     x-3.1879037d-03, 3.9824669d-04,-1.5731230d-06 /
      data fpppp( 3,11, 7,1),fpppp( 3,11, 7,2),fpppp( 3,11, 7,3)/
     x-4.8697035d-03, 6.8526268d-05, 7.6621823d-06 /
      data fpppp( 3,11, 8,1),fpppp( 3,11, 8,2),fpppp( 3,11, 8,3)/
     x-2.2796026d-03,-9.0463129d-04,-1.2067648d-05 /
      data fpppp( 3,11, 9,1),fpppp( 3,11, 9,2),fpppp( 3,11, 9,3)/
     x-7.1627254d-03, 4.6242450d-03, 1.0347239d-05 /
      data fpppp( 3,11,10,1),fpppp( 3,11,10,2),fpppp( 3,11,10,3)/
     x-1.7904687d-03,-4.0507798d-03,-2.5055536d-06 /
      data fpppp( 3,11,11,1),fpppp( 3,11,11,2),fpppp( 3,11,11,3)/
     x-4.5224633d-02,-8.5254810d-04,-3.3020839d-07 /
      data fpppp( 3,11,12,1),fpppp( 3,11,12,2),fpppp( 3,11,12,3)/
     x-4.8422830d-02, 9.7535468d-03,-9.7114956d-09 /
      data fpppp( 3,11,13,1),fpppp( 3,11,13,2),fpppp( 3,11,13,3)/
     x 1.4975079d-03,-3.7778688d-02,-1.8793875d-09 /
      data fpppp( 3,11,14,1),fpppp( 3,11,14,2),fpppp( 3,11,14,3)/
     x-1.2512905d-02, 5.9741221d-02, 1.4390225d-08 /
      data fpppp( 3,11,15,1),fpppp( 3,11,15,2),fpppp( 3,11,15,3)/
     x 1.5164184d-03,-3.8116059d-02,-1.0763500d-08 /
      data fpppp( 3,11,16,1),fpppp( 3,11,16,2),fpppp( 3,11,16,3)/
     x-7.5529439d-05, 1.1003805d-02, 7.8942016d-08 /
      data fpppp( 3,11,17,1),fpppp( 3,11,17,2),fpppp( 3,11,17,3)/
     x 1.4378701d-03,-6.0077070d-03,-3.3723782d-07 /
      data fpppp( 3,11,18,1),fpppp( 3,11,18,2),fpppp( 3,11,18,3)/
     x 1.3326390d-03, 1.2995918d-02, 1.2749070d-06 /
      data fpppp( 3,11,19,1),fpppp( 3,11,19,2),fpppp( 3,11,19,3)/
     x 9.8127961d-04,-4.5761002d-02,-4.8506011d-06 /
      data fpppp( 3,11,20,1),fpppp( 3,11,20,2),fpppp( 3,11,20,3)/
     x 1.4734714d-01, 2.4952893d-02, 2.6055352d-06 /
      data fpppp( 3,11,21,1),fpppp( 3,11,21,2),fpppp( 3,11,21,3)/
     x 1.4734714d-01, 2.0597352d-02, 2.1495998d-06 /
      data fpppp( 3,11,22,1),fpppp( 3,11,22,2),fpppp( 3,11,22,3)/
     x 9.8127961d-04,-2.8338837d-02,-3.0268596d-06 /
      data fpppp( 3,11,23,1),fpppp( 3,11,23,2),fpppp( 3,11,23,3)/
     x 1.3326390d-03,-5.2337203d-02,-5.5641235d-06 /
      data fpppp( 3,12, 1,1),fpppp( 3,12, 1,2),fpppp( 3,12, 1,3)/
     x 6.9014578d-04, 6.4601026d-03, 5.5450901d-06 /
      data fpppp( 3,12, 2,1),fpppp( 3,12, 2,2),fpppp( 3,12, 2,3)/
     x 4.5152132d-03, 2.8917591d-03, 2.5631575d-06 /
      data fpppp( 3,12, 3,1),fpppp( 3,12, 3,2),fpppp( 3,12, 3,3)/
     x 4.3316081d-02,-4.5737057d-03,-3.6778794d-06 /
      data fpppp( 3,12, 4,1),fpppp( 3,12, 4,2),fpppp( 3,12, 4,3)/
     x 4.3316081d-02,-4.8904306d-03,-3.9383117d-06 /
      data fpppp( 3,12, 5,1),fpppp( 3,12, 5,2),fpppp( 3,12, 5,3)/
     x 4.5152132d-03, 4.1586585d-03, 3.6048865d-06 /
      data fpppp( 3,12, 6,1),fpppp( 3,12, 6,2),fpppp( 3,12, 6,3)/
     x 6.9014578d-04, 1.7092298d-03, 1.6386065d-06 /
      data fpppp( 3,12, 7,1),fpppp( 3,12, 7,2),fpppp( 3,12, 7,3)/
     x 1.5156556d-03, 8.4574067d-04,-1.2918607d-06 /
      data fpppp( 3,12, 8,1),fpppp( 3,12, 8,2),fpppp( 3,12, 8,3)/
     x 3.9161791d-04,-7.8492547d-04, 3.5859794d-06 /
      data fpppp( 3,12, 9,1),fpppp( 3,12, 9,2),fpppp( 3,12, 9,3)/
     x 2.2993394d-03, 2.5846688d-03,-4.8849461d-06 /
      data fpppp( 3,12,10,1),fpppp( 3,12,10,2),fpppp( 3,12,10,3)/
     x-4.3349061d-04,-3.0762279d-04, 4.6265789d-06 /
      data fpppp( 3,12,11,1),fpppp( 3,12,11,2),fpppp( 3,12,11,3)/
     x 1.1888788d-02,-3.5106505d-03,-1.5179581d-06 /
      data fpppp( 3,12,12,1),fpppp( 3,12,12,2),fpppp( 3,12,12,3)/
     x 1.8430012d-02, 1.0193722d-02, 1.8575835d-07 /
      data fpppp( 3,12,13,1),fpppp( 3,12,13,2),fpppp( 3,12,13,3)/
     x-2.1033830d-04,-3.6073108d-02,-9.6878537d-08 /
      data fpppp( 3,12,14,1),fpppp( 3,12,14,2),fpppp( 3,12,14,3)/
     x 2.7004751d-03, 5.6765412d-02, 1.0820686d-08 /
      data fpppp( 3,12,15,1),fpppp( 3,12,15,2),fpppp( 3,12,15,3)/
     x-1.9417126d-04,-3.5868103d-02, 1.3581517d-08 /
      data fpppp( 3,12,16,1),fpppp( 3,12,16,2),fpppp( 3,12,16,3)/
     x 3.1132627d-04, 8.9815356d-03,-5.6119647d-08 /
      data fpppp( 3,12,17,1),fpppp( 3,12,17,2),fpppp( 3,12,17,3)/
     x 2.2359562d-05,-2.0432540d-04, 3.0669787d-07 /
      data fpppp( 3,12,18,1),fpppp( 3,12,18,2),fpppp( 3,12,18,3)/
     x 2.6067619d-04,-8.2199377d-03,-1.1073610d-06 /
      data fpppp( 3,12,19,1),fpppp( 3,12,19,2),fpppp( 3,12,19,3)/
     x 8.8380204d-04, 3.3311452d-02, 3.7930379d-06 /
      data fpppp( 3,12,20,1),fpppp( 3,12,20,2),fpppp( 3,12,20,3)/
     x-1.0814612d-01,-1.8259745d-02,-2.0740179d-06 /
      data fpppp( 3,12,21,1),fpppp( 3,12,21,2),fpppp( 3,12,21,3)/
     x-1.0814612d-01,-1.5145919d-02,-1.7114376d-06 /
      data fpppp( 3,12,22,1),fpppp( 3,12,22,2),fpppp( 3,12,22,3)/
     x 8.8380204d-04, 2.0856145d-02, 2.3427167d-06 /
      data fpppp( 3,12,23,1),fpppp( 3,12,23,2),fpppp( 3,12,23,3)/
     x 2.6067619d-04, 3.8487462d-02, 4.3313435d-06 /
      data fpppp( 3,13, 1,1),fpppp( 3,13, 1,2),fpppp( 3,13, 1,3)/
     x 8.5435964d-04, 5.2194706d-02,-1.2482367d-05 /
      data fpppp( 3,13, 2,1),fpppp( 3,13, 2,2),fpppp( 3,13, 2,3)/
     x-5.4709119d-03, 2.6920906d-02,-6.0908058d-06 /
      data fpppp( 3,13, 3,1),fpppp( 3,13, 3,2),fpppp( 3,13, 3,3)/
     x-3.4255947d-02,-2.5150101d-02, 7.2180427d-06 /
      data fpppp( 3,13, 4,1),fpppp( 3,13, 4,2),fpppp( 3,13, 4,3)/
     x-3.4255947d-02,-2.8802589d-02, 7.8959107d-06 /
      data fpppp( 3,13, 5,1),fpppp( 3,13, 5,2),fpppp( 3,13, 5,3)/
     x-5.4709119d-03, 4.1530859d-02,-8.8022778d-06 /
      data fpppp( 3,13, 6,1),fpppp( 3,13, 6,2),fpppp( 3,13, 6,3)/
     x 8.5435964d-04,-2.5926173d-03,-2.3143462d-06 /
      data fpppp( 3,13, 7,1),fpppp( 3,13, 7,2),fpppp( 3,13, 7,3)/
     x-5.3060312d-04, 2.3481280d-03,-5.4148054d-07 /
      data fpppp( 3,13, 8,1),fpppp( 3,13, 8,2),fpppp( 3,13, 8,3)/
     x-2.1833230d-04, 2.1786299d-04,-7.8158232d-07 /
      data fpppp( 3,13, 9,1),fpppp( 3,13, 9,2),fpppp( 3,13, 9,3)/
     x-1.6068168d-03,-7.5935306d-04, 7.0577765d-07 /
      data fpppp( 3,13,10,1),fpppp( 3,13,10,2),fpppp( 3,13,10,3)/
     x 1.6052847d-03, 4.0639932d-03,-6.0877702d-07 /
      data fpppp( 3,13,11,1),fpppp( 3,13,11,2),fpppp( 3,13,11,3)/
     x-4.3646148d-03,-5.1461301d-03, 1.1105092d-06 /
      data fpppp( 3,13,12,1),fpppp( 3,13,12,2),fpppp( 3,13,12,3)/
     x-2.5062357d-02, 8.2988525d-03,-4.3838017d-07 /
      data fpppp( 3,13,13,1),fpppp( 3,13,13,2),fpppp( 3,13,13,3)/
     x-3.0434684d-04,-2.8201988d-02, 9.3318277d-08 /
      data fpppp( 3,13,14,1),fpppp( 3,13,14,2),fpppp( 3,13,14,3)/
     x 1.5078575d-02, 4.4361309d-02,-5.3193660d-08 /
      data fpppp( 3,13,15,1),fpppp( 3,13,15,2),fpppp( 3,13,15,3)/
     x-2.9426279d-04,-2.8010375d-02, 9.5954601d-09 /
      data fpppp( 3,13,16,1),fpppp( 3,13,16,2),fpppp( 3,13,16,3)/
     x-5.2551329d-04, 7.0693601d-03,-5.9694845d-08 /
      data fpppp( 3,13,17,1),fpppp( 3,13,17,2),fpppp( 3,13,17,3)/
     x-5.0651028d-04,-2.7334912d-04, 1.6945397d-07 /
      data fpppp( 3,13,18,1),fpppp( 3,13,18,2),fpppp( 3,13,18,3)/
     x-6.2431118d-04,-5.7025669d-03,-8.2406235d-07 /
      data fpppp( 3,13,19,1),fpppp( 3,13,19,2),fpppp( 3,13,19,3)/
     x-1.0906592d-03, 2.4267968d-02, 2.4580784d-06 /
      data fpppp( 3,13,20,1),fpppp( 3,13,20,2),fpppp( 3,13,20,3)/
     x 9.5874134d-03,-1.3492403d-02,-1.2132598d-06 /
      data fpppp( 3,13,21,1),fpppp( 3,13,21,2),fpppp( 3,13,21,3)/
     x 9.5874134d-03,-1.1233287d-02,-9.7613487d-07 /
      data fpppp( 3,13,22,1),fpppp( 3,13,22,2),fpppp( 3,13,22,3)/
     x-1.0906592d-03, 1.5231504d-02, 1.5095786d-06 /
      data fpppp( 3,13,23,1),fpppp( 3,13,23,2),fpppp( 3,13,23,3)/
     x-6.2431118d-04, 2.8184171d-02, 2.7328116d-06 /
      data fpppp( 3,14, 1,1),fpppp( 3,14, 1,2),fpppp( 3,14, 1,3)/
     x-4.0117627d-03, 5.8939851d-02,-7.6685716d-06 /
      data fpppp( 3,14, 2,1),fpppp( 3,14, 2,2),fpppp( 3,14, 2,3)/
     x-8.7283106d-03, 3.0567477d-02,-3.2250195d-06 /
      data fpppp( 3,14, 3,1),fpppp( 3,14, 3,2),fpppp( 3,14, 3,3)/
     x-6.1122765d-02,-2.7747897d-02, 6.1437161d-06 /
      data fpppp( 3,14, 4,1),fpppp( 3,14, 4,2),fpppp( 3,14, 4,3)/
     x-6.1122765d-02,-3.2092393d-02, 6.4117491d-06 /
      data fpppp( 3,14, 5,1),fpppp( 3,14, 5,2),fpppp( 3,14, 5,3)/
     x-8.7283106d-03, 4.7945463d-02,-4.2971514d-06 /
      data fpppp( 3,14, 6,1),fpppp( 3,14, 6,2),fpppp( 3,14, 6,3)/
     x-4.0117627d-03,-6.2275954d-03,-3.6480768d-06 /
      data fpppp( 3,14, 7,1),fpppp( 3,14, 7,2),fpppp( 3,14, 7,3)/
     x-5.9008009d-04, 4.6554094d-03,-1.5050599d-06 /
      data fpppp( 3,14, 8,1),fpppp( 3,14, 8,2),fpppp( 3,14, 8,3)/
     x-1.2164646d-04,-7.7965615d-04,-2.5858368d-07 /
      data fpppp( 3,14, 9,1),fpppp( 3,14, 9,2),fpppp( 3,14, 9,3)/
     x 8.3220507d-04,-1.9288282d-04,-2.7650739d-07 /
      data fpppp( 3,14,10,1),fpppp( 3,14,10,2),fpppp( 3,14,10,3)/
     x-2.3392481d-04, 6.5357598d-03,-2.1864584d-07 /
      data fpppp( 3,14,11,1),fpppp( 3,14,11,2),fpppp( 3,14,11,3)/
     x 7.2459433d-04,-2.2740951d-02, 9.4920418d-07 /
      data fpppp( 3,14,12,1),fpppp( 3,14,12,2),fpppp( 3,14,12,3)/
     x 2.9984527d-02, 3.5750186d-02,-3.4367453d-07 /
      data fpppp( 3,14,13,1),fpppp( 3,14,13,2),fpppp( 3,14,13,3)/
     x 1.1583156d-03,-2.3201053d-02, 9.4698564d-09 /
      data fpppp( 3,14,14,1),fpppp( 3,14,14,2),fpppp( 3,14,14,3)/
     x-1.9559057d-02, 6.2513891d-03,-5.6669059d-09 /
      data fpppp( 3,14,15,1),fpppp( 3,14,15,2),fpppp( 3,14,15,3)/
     x 1.3515328d-03,-1.6597322d-03,-2.6824345d-08 /
      data fpppp( 3,14,16,1),fpppp( 3,14,16,2),fpppp( 3,14,16,3)/
     x 1.8689974d-03, 4.6471436d-04, 6.2123836d-08 /
      data fpppp( 3,14,17,1),fpppp( 3,14,17,2),fpppp( 3,14,17,3)/
     x 2.1924554d-03,-5.2862882d-05,-2.8483200d-07 /
      data fpppp( 3,14,18,1),fpppp( 3,14,18,2),fpppp( 3,14,18,3)/
     x 2.3646859d-03, 1.7807419d-04, 1.0751785d-06 /
      data fpppp( 3,14,19,1),fpppp( 3,14,19,2),fpppp( 3,14,19,3)/
     x 2.3837840d-03, 3.1938091d-04,-3.5766659d-06 /
      data fpppp( 3,14,20,1),fpppp( 3,14,20,2),fpppp( 3,14,20,3)/
     x 1.9571109d-02,-3.7505585d-04, 1.9545872d-06 /
      data fpppp( 3,14,21,1),fpppp( 3,14,21,2),fpppp( 3,14,21,3)/
     x 1.9571109d-02,-3.5296516d-04, 1.6112441d-06 /
      data fpppp( 3,14,22,1),fpppp( 3,14,22,2),fpppp( 3,14,22,3)/
     x 2.3837840d-03, 2.3101815d-04,-2.2032933d-06 /
      data fpppp( 3,14,23,1),fpppp( 3,14,23,2),fpppp( 3,14,23,3)/
     x 2.3646859d-03, 5.0943454d-04,-4.0749689d-06 /
      data fpppp( 3,15, 1,1),fpppp( 3,15, 1,2),fpppp( 3,15, 1,3)/
     x-3.6196065d-04, 3.8584443d-03, 7.9677636d-06 /
      data fpppp( 3,15, 2,1),fpppp( 3,15, 2,2),fpppp( 3,15, 2,3)/
     x 9.8309504d-04, 1.4273861d-03, 3.9536220d-06 /
      data fpppp( 3,15, 3,1),fpppp( 3,15, 3,2),fpppp( 3,15, 3,3)/
     x 4.9173684d-02,-3.6983435d-03,-4.3984909d-06 /
      data fpppp( 3,15, 4,1),fpppp( 3,15, 4,2),fpppp( 3,15, 4,3)/
     x 4.9173684d-02,-3.8447847d-03,-4.8353243d-06 /
      data fpppp( 3,15, 5,1),fpppp( 3,15, 5,2),fpppp( 3,15, 5,3)/
     x 9.8309504d-04, 2.0131508d-03, 5.7009556d-06 /
      data fpppp( 3,15, 6,1),fpppp( 3,15, 6,2),fpppp( 3,15, 6,3)/
     x-3.6196065d-04, 1.6618267d-03, 1.4152625d-06 /
      data fpppp( 3,15, 7,1),fpppp( 3,15, 7,2),fpppp( 3,15, 7,3)/
     x-6.6096613d-04, 1.3683620d-03, 1.0025174d-07 /
      data fpppp( 3,15, 8,1),fpppp( 3,15, 8,2),fpppp( 3,15, 8,3)/
     x-3.9847224d-04,-4.7852300d-04,-3.5749780d-07 /
      data fpppp( 3,15, 9,1),fpppp( 3,15, 9,2),fpppp( 3,15, 9,3)/
     x 7.9891870d-05, 1.2300936d-03, 3.7397807d-09 /
      data fpppp( 3,15,10,1),fpppp( 3,15,10,2),fpppp( 3,15,10,3)/
     x-1.7740315d-04, 6.7850800d-05,-4.3113627d-07 /
      data fpppp( 3,15,11,1),fpppp( 3,15,11,2),fpppp( 3,15,11,3)/
     x 1.4319565d-03,-4.6503251d-03, 6.8801273d-07 /
      data fpppp( 3,15,12,1),fpppp( 3,15,12,2),fpppp( 3,15,12,3)/
     x-1.3729388d-02, 1.1106519d-02,-8.4979758d-08 /
      data fpppp( 3,15,13,1),fpppp( 3,15,13,2),fpppp( 3,15,13,3)/
     x-4.8865328d-03,-8.3901829d-03, 2.0609585d-07 /
      data fpppp( 3,15,14,1),fpppp( 3,15,14,2),fpppp( 3,15,14,3)/
     x 2.1574897d-03, 2.2581693d-03,-6.4294878d-08 /
      data fpppp( 3,15,15,1),fpppp( 3,15,15,2),fpppp( 3,15,15,3)/
     x-5.5580718d-03,-5.8931984d-04, 1.3233012d-08 /
      data fpppp( 3,15,16,1),fpppp( 3,15,16,2),fpppp( 3,15,16,3)/
     x-7.5302492d-03, 1.7675983d-04,-3.2248705d-08 /
      data fpppp( 3,15,17,1),fpppp( 3,15,17,2),fpppp( 3,15,17,3)/
     x-9.1709515d-03,-1.3208751d-05, 8.6135780d-08 /
      data fpppp( 3,15,18,1),fpppp( 3,15,18,2),fpppp( 3,15,18,3)/
     x-1.0478331d-02, 5.6961043d-05,-2.2137059d-07 /
      data fpppp( 3,15,19,1),fpppp( 3,15,19,2),fpppp( 3,15,19,3)/
     x-1.1354006d-02, 2.9271216d-05, 1.1133986d-06 /
      data fpppp( 3,15,20,1),fpppp( 3,15,20,2),fpppp( 3,15,20,3)/
     x-1.6243450d-02,-8.6304687d-05,-7.0850328d-07 /
      data fpppp( 3,15,21,1),fpppp( 3,15,21,2),fpppp( 3,15,21,3)/
     x-1.6243450d-02,-8.5058852d-05,-6.0478540d-07 /
      data fpppp( 3,15,22,1),fpppp( 3,15,22,2),fpppp( 3,15,22,3)/
     x-1.1354006d-02, 2.4287875d-05, 6.9852708d-07 /
      data fpppp( 3,15,23,1),fpppp( 3,15,23,2),fpppp( 3,15,23,3)/
     x-1.0478331d-02, 7.5648571d-05, 1.3343977d-06 /
      data fpppp( 3,16, 1,1),fpppp( 3,16, 1,2),fpppp( 3,16, 1,3)/
     x 1.6252218d-03,-2.6948522d-03, 2.1891121d-06 /
      data fpppp( 3,16, 2,1),fpppp( 3,16, 2,2),fpppp( 3,16, 2,3)/
     x 5.8187426d-03,-1.5641838d-03, 7.9240185d-07 /
      data fpppp( 3,16, 3,1),fpppp( 3,16, 3,2),fpppp( 3,16, 3,3)/
     x 3.8300833d-03, 7.5106102d-04,-2.1683485d-06 /
      data fpppp( 3,16, 4,1),fpppp( 3,16, 4,2),fpppp( 3,16, 4,3)/
     x 3.8300833d-03, 9.3938896d-04,-2.2246988d-06 /
      data fpppp( 3,16, 5,1),fpppp( 3,16, 5,2),fpppp( 3,16, 5,3)/
     x 5.8187426d-03,-2.3174956d-03, 1.0178030d-06 /
      data fpppp( 3,16, 6,1),fpppp( 3,16, 6,2),fpppp( 3,16, 6,3)/
     x 1.6252218d-03, 1.3006694d-04, 1.3438579d-06 /
      data fpppp( 3,16, 7,1),fpppp( 3,16, 7,2),fpppp( 3,16, 7,3)/
     x 7.1984149d-04, 3.4185178d-04, 6.6673467d-07 /
      data fpppp( 3,16, 8,1),fpppp( 3,16, 8,2),fpppp( 3,16, 8,3)/
     x 4.7975599d-04, 1.5968660d-04, 1.2241702d-07 /
      data fpppp( 3,16, 9,1),fpppp( 3,16, 9,2),fpppp( 3,16, 9,3)/
     x-1.4015940d-04, 1.3295861d-05,-4.5702005d-08 /
      data fpppp( 3,16,10,1),fpppp( 3,16,10,2),fpppp( 3,16,10,3)/
     x 4.8579235d-04, 1.0521100d-04,-2.8581015d-07 /
      data fpppp( 3,16,11,1),fpppp( 3,16,11,2),fpppp( 3,16,11,3)/
     x 1.7634685d-04,-1.3851319d-03, 2.1091937d-07 /
      data fpppp( 3,16,12,1),fpppp( 3,16,12,2),fpppp( 3,16,12,3)/
     x 4.0792692d-03, 4.6902765d-03, 5.9721673d-07 /
      data fpppp( 3,16,13,1),fpppp( 3,16,13,2),fpppp( 3,16,13,3)/
     x 1.7871823d-02,-3.8432907d-03,-1.0017604d-06 /
      data fpppp( 3,16,14,1),fpppp( 3,16,14,2),fpppp( 3,16,14,3)/
     x 1.0619327d-02, 9.6189216d-04, 3.2677172d-07 /
      data fpppp( 3,16,15,1),fpppp( 3,16,15,2),fpppp( 3,16,15,3)/
     x 2.0564052d-02,-2.5585299d-04,-1.0581807d-08 /
      data fpppp( 3,16,16,1),fpppp( 3,16,16,2),fpppp( 3,16,16,3)/
     x 2.7864562d-02, 7.5840526d-05, 9.3482102d-08 /
      data fpppp( 3,16,17,1),fpppp( 3,16,17,2),fpppp( 3,16,17,3)/
     x 3.4007186d-02,-1.0742311d-05, 4.6198521d-08 /
      data fpppp( 3,16,18,1),fpppp( 3,16,18,2),fpppp( 3,16,18,3)/
     x 3.9080253d-02, 1.0071584d-05, 1.4053413d-07 /
      data fpppp( 3,16,19,1),fpppp( 3,16,19,2),fpppp( 3,16,19,3)/
     x 4.3098536d-02,-1.6438571d-06,-2.0747950d-07 /
      data fpppp( 3,16,20,1),fpppp( 3,16,20,2),fpppp( 3,16,20,3)/
     x 4.6898729d-02,-1.3496863d-05, 2.0815939d-07 /
      data fpppp( 3,16,21,1),fpppp( 3,16,21,2),fpppp( 3,16,21,3)/
     x 4.6898729d-02,-1.3790410d-05, 1.8243256d-07 /
      data fpppp( 3,16,22,1),fpppp( 3,16,22,2),fpppp( 3,16,22,3)/
     x 4.3098536d-02,-4.6967266d-07,-1.0457220d-07 /
      data fpppp( 3,16,23,1),fpppp( 3,16,23,2),fpppp( 3,16,23,3)/
     x 3.9080253d-02, 5.6683923d-06,-2.4536825d-07 /
      data fpppp( 3,17, 1,1),fpppp( 3,17, 1,2),fpppp( 3,17, 1,3)/
     x-1.7135635d-03,-3.9095562d-05,-7.2640839d-08 /
      data fpppp( 3,17, 2,1),fpppp( 3,17, 2,2),fpppp( 3,17, 2,3)/
     x-2.6432272d-03,-6.2135107d-05,-1.2797148d-07 /
      data fpppp( 3,17, 3,1),fpppp( 3,17, 3,2),fpppp( 3,17, 3,3)/
     x-3.8204546d-03,-1.1381233d-04,-2.6015775d-07 /
      data fpppp( 3,17, 4,1),fpppp( 3,17, 4,2),fpppp( 3,17, 4,3)/
     x-3.8204546d-03,-1.0977548d-04,-2.3632167d-07 /
      data fpppp( 3,17, 5,1),fpppp( 3,17, 5,2),fpppp( 3,17, 5,3)/
     x-2.6432272d-03,-7.8282513d-05,-2.2331579d-07 /
      data fpppp( 3,17, 6,1),fpppp( 3,17, 6,2),fpppp( 3,17, 6,3)/
     x-1.7135635d-03, 2.1457212d-05, 2.8490032d-07 /
      data fpppp( 3,17, 7,1),fpppp( 3,17, 7,2),fpppp( 3,17, 7,3)/
     x-2.0566073d-03,-2.1213064d-05, 1.4258049d-07 /
      data fpppp( 3,17, 8,1),fpppp( 3,17, 8,2),fpppp( 3,17, 8,3)/
     x-2.2121780d-03, 1.3111619d-04, 1.0319177d-07 /
      data fpppp( 3,17, 9,1),fpppp( 3,17, 9,2),fpppp( 3,17, 9,3)/
     x-2.1309377d-03,-2.6646550d-04,-1.5279085d-07 /
      data fpppp( 3,17,10,1),fpppp( 3,17,10,2),fpppp( 3,17,10,3)/
     x-2.4035983d-03, 9.5511429d-04, 2.9333117d-07 /
      data fpppp( 3,17,11,1),fpppp( 3,17,11,2),fpppp( 3,17,11,3)/
     x-2.1370498d-03,-3.6428726d-03,-1.7629284d-06 /
      data fpppp( 3,17,12,1),fpppp( 3,17,12,2),fpppp( 3,17,12,3)/
     x-5.4700225d-03, 1.6032472d-02, 2.1935112d-06 /
      data fpppp( 3,17,13,1),fpppp( 3,17,13,2),fpppp( 3,17,13,3)/
     x-3.2928977d-02,-2.5370472d-02, 1.4253906d-06 /
      data fpppp( 3,17,14,1),fpppp( 3,17,14,2),fpppp( 3,17,14,3)/
     x-4.4848632d-02, 1.5763737d-02,-4.3556995d-07 /
      data fpppp( 3,17,15,1),fpppp( 3,17,15,2),fpppp( 3,17,15,3)/
     x-7.6810048d-02,-4.2532556d-03,-9.5958957d-08 /
      data fpppp( 3,17,16,1),fpppp( 3,17,16,2),fpppp( 3,17,16,3)/
     x-1.0400300d-01, 1.1352653d-03,-2.3144907d-07 /
      data fpppp( 3,17,17,1),fpppp( 3,17,17,2),fpppp( 3,17,17,3)/
     x-1.2687965d-01,-3.0255529d-04,-2.0339922d-07 /
      data fpppp( 3,17,18,1),fpppp( 3,17,18,2),fpppp( 3,17,18,3)/
     x-1.4571067d-01, 8.0682510d-05,-2.2755915d-07 /
      data fpppp( 3,17,19,1),fpppp( 3,17,19,2),fpppp( 3,17,19,3)/
     x-1.6056543d-01,-1.9452014d-05,-2.0443835d-07 /
      data fpppp( 3,17,20,1),fpppp( 3,17,20,2),fpppp( 3,17,20,3)/
     x-1.7042180d-01, 1.6492397d-06,-3.6307007d-07 /
      data fpppp( 3,17,21,1),fpppp( 3,17,21,2),fpppp( 3,17,21,3)/
     x-1.7042180d-01,-3.5714142d-06,-3.5845857d-07 /
      data fpppp( 3,17,22,1),fpppp( 3,17,22,2),fpppp( 3,17,22,3)/
     x-1.6056543d-01, 1.4306019d-06,-2.2288435d-07 /
      data fpppp( 3,17,23,1),fpppp( 3,17,23,2),fpppp( 3,17,23,3)/
     x-1.4571067d-01, 2.3727017d-06,-1.5838665d-07 /
      data fpppp( 3,18, 1,1),fpppp( 3,18, 1,2),fpppp( 3,18, 1,3)/
     x 8.6002304d-03,-1.3404574d-05, 1.7822572d-07 /
      data fpppp( 3,18, 2,1),fpppp( 3,18, 2,2),fpppp( 3,18, 2,3)/
     x 9.0462548d-03,-1.5505901d-05, 9.0265185d-08 /
      data fpppp( 3,18, 3,1),fpppp( 3,18, 3,2),fpppp( 3,18, 3,3)/
     x 9.1712243d-03,-2.0432107d-05,-9.4959459d-08 /
      data fpppp( 3,18, 4,1),fpppp( 3,18, 4,2),fpppp( 3,18, 4,3)/
     x 9.1712243d-03,-1.9691225d-05,-1.0066832d-07 /
      data fpppp( 3,18, 5,1),fpppp( 3,18, 5,2),fpppp( 3,18, 5,3)/
     x 9.0462548d-03,-1.8469430d-05, 1.1310062d-07 /
      data fpppp( 3,18, 6,1),fpppp( 3,18, 6,2),fpppp( 3,18, 6,3)/
     x 8.6002304d-03,-2.2913407d-06, 9.2592832d-08 /
      data fpppp( 3,18, 7,1),fpppp( 3,18, 7,2),fpppp( 3,18, 7,3)/
     x 8.4656227d-03,-3.5595466d-05, 5.2494910d-08 /
      data fpppp( 3,18, 8,1),fpppp( 3,18, 8,2),fpppp( 3,18, 8,3)/
     x 8.3781664d-03, 8.5293628d-05,-2.6882198d-08 /
      data fpppp( 3,18, 9,1),fpppp( 3,18, 9,2),fpppp( 3,18, 9,3)/
     x 8.2775862d-03,-2.7161048d-04,-3.1053753d-08 /
      data fpppp( 3,18,10,1),fpppp( 3,18,10,2),fpppp( 3,18,10,3)/
     x 8.3679142d-03, 7.4497575d-04,-2.2633980d-07 /
      data fpppp( 3,18,11,1),fpppp( 3,18,11,2),fpppp( 3,18,11,3)/
     x 7.8549983d-03,-1.3168668d-03, 3.6709425d-07 /
      data fpppp( 3,18,12,1),fpppp( 3,18,12,2),fpppp( 3,18,12,3)/
     x 9.2727174d-03, 1.8446406d-03,-1.6001569d-06 /
      data fpppp( 3,18,13,1),fpppp( 3,18,13,2),fpppp( 3,18,13,3)/
     x 2.5151427d-02,-2.1514599d-02,-4.4104011d-07 /
      data fpppp( 3,18,14,1),fpppp( 3,18,14,2),fpppp( 3,18,14,3)/
     x 5.3020656d-02, 7.6660555d-03, 2.6891631d-07 /
      data fpppp( 3,18,15,1),fpppp( 3,18,15,2),fpppp( 3,18,15,3)/
     x 8.6270650d-02, 3.7533454d-04, 1.9138294d-07 /
      data fpppp( 3,18,16,1),fpppp( 3,18,16,2),fpppp( 3,18,16,3)/
     x 1.1485800d-01, 2.3572595d-03, 2.3468476d-07 /
      data fpppp( 3,18,17,1),fpppp( 3,18,17,2),fpppp( 3,18,17,3)/
     x 1.3892205d-01, 1.7133503d-03, 2.1995071d-07 /
      data fpppp( 3,18,18,1),fpppp( 3,18,18,2),fpppp( 3,18,18,3)/
     x 1.5873754d-01, 1.6222517d-03, 2.0948242d-07 /
      data fpppp( 3,18,19,1),fpppp( 3,18,19,2),fpppp( 3,18,19,3)/
     x 1.7437631d-01, 2.4447322d-03, 2.4920080d-07 /
      data fpppp( 3,18,20,1),fpppp( 3,18,20,2),fpppp( 3,18,20,3)/
     x 1.8450542d-01, 2.8837001d-03, 3.1702940d-07 /
      data fpppp( 3,18,21,1),fpppp( 3,18,21,2),fpppp( 3,18,21,3)/
     x 1.8450542d-01, 2.9130180d-03, 3.1741224d-07 /
      data fpppp( 3,18,22,1),fpppp( 3,18,22,2),fpppp( 3,18,22,3)/
     x 1.7437631d-01, 2.3274609d-03, 2.4766947d-07 /
      data fpppp( 3,18,23,1),fpppp( 3,18,23,2),fpppp( 3,18,23,3)/
     x 1.5873754d-01, 2.0620190d-03, 2.1522493d-07 /
      data fpppp( 3,19, 1,1),fpppp( 3,19, 1,2),fpppp( 3,19, 1,3)/
     x 1.5013287d-02,-4.5922324d-17,-2.8879901d-07 /
      data fpppp( 3,19, 2,1),fpppp( 3,19, 2,2),fpppp( 3,19, 2,3)/
     x 1.4978179d-02,-1.2035109d-17,-1.6815291d-08 /
      data fpppp( 3,19, 3,1),fpppp( 3,19, 3,2),fpppp( 3,19, 3,3)/
     x 1.6265127d-02, 2.5680565d-17, 5.6823667d-07 /
      data fpppp( 3,19, 4,1),fpppp( 3,19, 4,2),fpppp( 3,19, 4,3)/
     x 1.6265127d-02,-1.3671086d-17, 5.6433468d-07 /
      data fpppp( 3,19, 5,1),fpppp( 3,19, 5,2),fpppp( 3,19, 5,3)/
     x 1.4978179d-02, 4.6720750d-18,-1.2073025d-09 /
      data fpppp( 3,19, 6,1),fpppp( 3,19, 6,2),fpppp( 3,19, 6,3)/
     x 1.5013287d-02,-2.4296713d-17,-3.4732897d-07 /
      data fpppp( 3,19, 7,1),fpppp( 3,19, 7,2),fpppp( 3,19, 7,3)/
     x 1.5188230d-02, 1.2167735d-18,-1.6161027d-07 /
      data fpppp( 3,19, 8,1),fpppp( 3,19, 8,2),fpppp( 3,19, 8,3)/
     x 1.5173574d-02,-1.9918074d-17,-1.2528510d-07 /
      data fpppp( 3,19, 9,1),fpppp( 3,19, 9,2),fpppp( 3,19, 9,3)/
     x 1.5143452d-02, 3.4709288d-17, 2.5304504d-08 /
      data fpppp( 3,19,10,1),fpppp( 3,19,10,2),fpppp( 3,19,10,3)/
     x 1.5236312d-02,-5.5791126d-17,-4.3206441d-07 /
      data fpppp( 3,19,11,1),fpppp( 3,19,11,2),fpppp( 3,19,11,3)/
     x 1.4331205d-02, 2.1874608d-17, 1.3245825d-06 /
      data fpppp( 3,19,12,1),fpppp( 3,19,12,2),fpppp( 3,19,12,3)/
     x 1.7074877d-02,-1.9075640d-17,-3.8538356d-06 /
      data fpppp( 3,19,13,1),fpppp( 3,19,13,2),fpppp( 3,19,13,3)/
     x 5.2122916d-02, 4.0688937d-17,-1.0807332d-06 /
      data fpppp( 3,19,14,1),fpppp( 3,19,14,2),fpppp( 3,19,14,3)/
     x 1.0707930d-01,-2.1521985d-17, 5.5430887d-07 /
      data fpppp( 3,19,15,1),fpppp( 3,19,15,2),fpppp( 3,19,15,3)/
     x 1.7493569d-01, 3.7270525d-17, 3.7223367d-07 /
      data fpppp( 3,19,16,1),fpppp( 3,19,16,2),fpppp( 3,19,16,3)/
     x 2.3351085d-01,-4.0722673d-17, 4.7480002d-07 /
      data fpppp( 3,19,17,1),fpppp( 3,19,17,2),fpppp( 3,19,17,3)/
     x 2.8281274d-01,-2.7837520d-17, 4.5102987d-07 /
      data fpppp( 3,19,18,1),fpppp( 3,19,18,2),fpppp( 3,19,18,3)/
     x 3.2340314d-01,-2.0842207d-18, 4.1648546d-07 /
      data fpppp( 3,19,19,1),fpppp( 3,19,19,2),fpppp( 3,19,19,3)/
     x 3.5543070d-01,-1.6942643d-17, 5.7409767d-07 /
      data fpppp( 3,19,20,1),fpppp( 3,19,20,2),fpppp( 3,19,20,3)/
     x 3.7593328d-01, 6.4188289d-18, 6.3960632d-07 /
      data fpppp( 3,19,21,1),fpppp( 3,19,21,2),fpppp( 3,19,21,3)/
     x 3.7593328d-01, 4.0987245d-18, 6.4563677d-07 /
      data fpppp( 3,19,22,1),fpppp( 3,19,22,2),fpppp( 3,19,22,3)/
     x 3.5543070d-01, 2.6463541d-18, 5.4997587d-07 /
      data fpppp( 3,19,23,1),fpppp( 3,19,23,2),fpppp( 3,19,23,3)/
     x 3.2340314d-01,-5.9543808d-18, 5.0694223d-07 /
      data fpppp( 4, 1, 1,1),fpppp( 4, 1, 1,2),fpppp( 4, 1, 1,3)/
     x 5.3749019d-04,-1.1653392d-16, 1.5882888d-05 /
      data fpppp( 4, 1, 2,1),fpppp( 4, 1, 2,2),fpppp( 4, 1, 2,3)/
     x 1.1515412d-03,-7.9587089d-17, 9.3523078d-06 /
      data fpppp( 4, 1, 3,1),fpppp( 4, 1, 3,2),fpppp( 4, 1, 3,3)/
     x 7.8021129d-03, 1.5620280d-16,-4.0724466d-06 /
      data fpppp( 4, 1, 4,1),fpppp( 4, 1, 4,2),fpppp( 4, 1, 4,3)/
     x 7.8021129d-03, 6.2560223d-17,-5.0688036d-06 /
      data fpppp( 4, 1, 5,1),fpppp( 4, 1, 5,2),fpppp( 4, 1, 5,3)/
     x 1.1515412d-03, 1.1697213d-16, 1.3337736d-05 /
      data fpppp( 4, 1, 6,1),fpppp( 4, 1, 6,2),fpppp( 4, 1, 6,3)/
     x 5.3749019d-04,-2.5916212d-16, 9.3753342d-07 /
      data fpppp( 4, 1, 7,1),fpppp( 4, 1, 7,2),fpppp( 4, 1, 7,3)/
     x-1.0884538d-01,-4.2746316d-16,-2.0998795d-05 /
      data fpppp( 4, 1, 8,1),fpppp( 4, 1, 8,2),fpppp( 4, 1, 8,3)/
     x 2.7576619d-02, 2.9263604d-16, 5.8111844d-06 /
      data fpppp( 4, 1, 9,1),fpppp( 4, 1, 9,2),fpppp( 4, 1, 9,3)/
     x 8.0744376d-02,-6.0536820d-17, 2.9691604d-06 /
      data fpppp( 4, 1,10,1),fpppp( 4, 1,10,2),fpppp( 4, 1,10,3)/
     x 4.7206824d-02, 8.9260975d-18, 2.3397767d-06 /
      data fpppp( 4, 1,11,1),fpppp( 4, 1,11,2),fpppp( 4, 1,11,3)/
     x 3.0593118d-02, 9.8948107d-17, 1.9361819d-06 /
      data fpppp( 4, 1,12,1),fpppp( 4, 1,12,2),fpppp( 4, 1,12,3)/
     x 1.8205059d-02,-1.4073283d-16, 1.9993029d-06 /
      data fpppp( 4, 1,13,1),fpppp( 4, 1,13,2),fpppp( 4, 1,13,3)/
     x 3.1016020d-02,-3.5245211d-16, 1.6536122d-06 /
      data fpppp( 4, 1,14,1),fpppp( 4, 1,14,2),fpppp( 4, 1,14,3)/
     x 5.5793965d-02,-6.5389011d-17, 2.7978396d-06 /
      data fpppp( 4, 1,15,1),fpppp( 4, 1,15,2),fpppp( 4, 1,15,3)/
     x 8.1982327d-02,-3.6972937d-17, 3.0157097d-06 /
      data fpppp( 4, 1,16,1),fpppp( 4, 1,16,2),fpppp( 4, 1,16,3)/
     x 2.0302330d-02, 3.1013524d-16, 4.5153339d-06 /
      data fpppp( 4, 1,17,1),fpppp( 4, 1,17,2),fpppp( 4, 1,17,3)/
     x-8.8870786d-02,-1.3162393d-16,-1.9944353d-05 /
      data fpppp( 4, 1,18,1),fpppp( 4, 1,18,2),fpppp( 4, 1,18,3)/
     x 1.1589363d-03,-2.5794583d-16, 1.2307742d-06 /
      data fpppp( 4, 1,19,1),fpppp( 4, 1,19,2),fpppp( 4, 1,19,3)/
     x 4.4231060d-04, 2.6014901d-16, 1.2664898d-05 /
      data fpppp( 4, 1,20,1),fpppp( 4, 1,20,2),fpppp( 4, 1,20,3)/
     x 7.9522177d-03, 8.2396232d-17,-4.8701381d-06 /
      data fpppp( 4, 1,21,1),fpppp( 4, 1,21,2),fpppp( 4, 1,21,3)/
     x 7.9522177d-03, 9.8176368d-17,-3.9389448d-06 /
      data fpppp( 4, 1,22,1),fpppp( 4, 1,22,2),fpppp( 4, 1,22,3)/
     x 4.4231060d-04,-2.1998086d-16, 8.9401244d-06 /
      data fpppp( 4, 1,23,1),fpppp( 4, 1,23,2),fpppp( 4, 1,23,3)/
     x 1.1589363d-03, 7.5104308d-16, 1.5198675d-05 /
      data fpppp( 4, 2, 1,1),fpppp( 4, 2, 1,2),fpppp( 4, 2, 1,3)/
     x 1.3619327d-03, 1.1854252d-03, 9.3597454d-06 /
      data fpppp( 4, 2, 2,1),fpppp( 4, 2, 2,2),fpppp( 4, 2, 2,3)/
     x 1.0565893d-03, 6.9393133d-04, 5.5485654d-06 /
      data fpppp( 4, 2, 3,1),fpppp( 4, 2, 3,2),fpppp( 4, 2, 3,3)/
     x 4.4676628d-03,-3.2608327d-04,-2.2366126d-06 /
      data fpppp( 4, 2, 4,1),fpppp( 4, 2, 4,2),fpppp( 4, 2, 4,3)/
     x 4.4676628d-03,-3.8415986d-04,-2.9044763d-06 /
      data fpppp( 4, 2, 5,1),fpppp( 4, 2, 5,2),fpppp( 4, 2, 5,3)/
     x 1.0565893d-03, 9.2623769d-04, 8.2200202d-06 /
      data fpppp( 4, 2, 6,1),fpppp( 4, 2, 6,2),fpppp( 4, 2, 6,3)/
     x 1.3619327d-03, 3.1427636d-04,-6.5821036d-07 /
      data fpppp( 4, 2, 7,1),fpppp( 4, 2, 7,2),fpppp( 4, 2, 7,3)/
     x-4.5889128d-02,-1.7699006d-03,-9.3182682d-06 /
      data fpppp( 4, 2, 8,1),fpppp( 4, 2, 8,2),fpppp( 4, 2, 8,3)/
     x 1.2873952d-02, 1.5171461d-03, 2.4061252d-06 /
      data fpppp( 4, 2, 9,1),fpppp( 4, 2, 9,2),fpppp( 4, 2, 9,3)/
     x 3.5867838d-02, 8.3983811d-04, 1.2419604d-06 /
      data fpppp( 4, 2,10,1),fpppp( 4, 2,10,2),fpppp( 4, 2,10,3)/
     x 2.1001227d-02,-2.0299045d-03, 9.9760767d-07 /
      data fpppp( 4, 2,11,1),fpppp( 4, 2,11,2),fpppp( 4, 2,11,3)/
     x 1.3905163d-02, 8.5961143d-04, 8.3135098d-07 /
      data fpppp( 4, 2,12,1),fpppp( 4, 2,12,2),fpppp( 4, 2,12,3)/
     x 8.5708363d-03, 5.6311250d-04, 8.6695402d-07 /
      data fpppp( 4, 2,13,1),fpppp( 4, 2,13,2),fpppp( 4, 2,13,3)/
     x 1.4066014d-02,-3.5835054d-03, 6.9136190d-07 /
      data fpppp( 4, 2,14,1),fpppp( 4, 2,14,2),fpppp( 4, 2,14,3)/
     x 2.5145269d-02, 5.2405495d-03, 1.2261960d-06 /
      data fpppp( 4, 2,15,1),fpppp( 4, 2,15,2),fpppp( 4, 2,15,3)/
     x 3.6403172d-02,-3.4344424d-03, 1.2653735d-06 /
      data fpppp( 4, 2,16,1),fpppp( 4, 2,16,2),fpppp( 4, 2,16,3)/
     x 1.0577203d-02, 5.7835816d-04, 1.8057050d-06 /
      data fpppp( 4, 2,17,1),fpppp( 4, 2,17,2),fpppp( 4, 2,17,3)/
     x-3.7039339d-02, 1.5676952d-03,-8.6638392d-06 /
      data fpppp( 4, 2,18,1),fpppp( 4, 2,18,2),fpppp( 4, 2,18,3)/
     x 1.4335865d-03,-9.3174539d-04,-7.1788398d-07 /
      data fpppp( 4, 2,19,1),fpppp( 4, 2,19,2),fpppp( 4, 2,19,3)/
     x 1.0136875d-03,-1.5098127d-04, 7.9860907d-06 /
      data fpppp( 4, 2,20,1),fpppp( 4, 2,20,2),fpppp( 4, 2,20,3)/
     x 4.1544647d-03, 2.6327207d-05,-2.8427545d-06 /
      data fpppp( 4, 2,21,1),fpppp( 4, 2,21,2),fpppp( 4, 2,21,3)/
     x 4.1544647d-03, 5.9461075d-05,-2.1897116d-06 /
      data fpppp( 4, 2,22,1),fpppp( 4, 2,22,2),fpppp( 4, 2,22,3)/
     x 1.0136875d-03,-2.8351674d-04, 5.3739194d-06 /
      data fpppp( 4, 2,23,1),fpppp( 4, 2,23,2),fpppp( 4, 2,23,3)/
     x 1.4335865d-03,-4.3473736d-04, 9.0777586d-06 /
      data fpppp( 4, 3, 1,1),fpppp( 4, 3, 1,2),fpppp( 4, 3, 1,3)/
     x 6.5361511d-03, 3.7097504d-03,-4.1972032d-05 /
      data fpppp( 4, 3, 2,1),fpppp( 4, 3, 2,2),fpppp( 4, 3, 2,3)/
     x 1.2427249d-02, 1.4337351d-03,-2.6314835d-05 /
      data fpppp( 4, 3, 3,1),fpppp( 4, 3, 3,2),fpppp( 4, 3, 3,3)/
     x-5.7324919d-04,-1.6396370d-04, 5.1274413d-06 /
      data fpppp( 4, 3, 4,1),fpppp( 4, 3, 4,2),fpppp( 4, 3, 4,3)/
     x-5.7324919d-04,-5.9030483d-03, 8.8179479d-06 /
      data fpppp( 4, 3, 5,1),fpppp( 4, 3, 5,2),fpppp( 4, 3, 5,3)/
     x 1.2427249d-02, 2.4390074d-02,-4.1076861d-05 /
      data fpppp( 4, 3, 6,1),fpppp( 4, 3, 6,2),fpppp( 4, 3, 6,3)/
     x 6.5361511d-03,-8.2376519d-02, 1.3385567d-05 /
      data fpppp( 4, 3, 7,1),fpppp( 4, 3, 7,2),fpppp( 4, 3, 7,3)/
     x 1.2714461d-01, 1.3344801d-01, 2.5842637d-05 /
      data fpppp( 4, 3, 8,1),fpppp( 4, 3, 8,2),fpppp( 4, 3, 8,3)/
     x-2.0753523d-02,-6.0557020d-02,-4.0208606d-06 /
      data fpppp( 4, 3, 9,1),fpppp( 4, 3, 9,2),fpppp( 4, 3, 9,3)/
     x-8.2307490d-02,-2.0929738d-02,-2.3491501d-06 /
      data fpppp( 4, 3,10,1),fpppp( 4, 3,10,2),fpppp( 4, 3,10,3)/
     x-4.5197081d-02, 1.0486243d-02,-1.7035201d-06 /
      data fpppp( 4, 3,11,1),fpppp( 4, 3,11,2),fpppp( 4, 3,11,3)/
     x-2.5625604d-02,-3.3884675d-03,-1.4295467d-06 /
      data fpppp( 4, 3,12,1),fpppp( 4, 3,12,2),fpppp( 4, 3,12,3)/
     x-1.2257635d-02, 1.2080019d-02,-1.4240027d-06 /
      data fpppp( 4, 3,13,1),fpppp( 4, 3,13,2),fpppp( 4, 3,13,3)/
     x-2.5989934d-02,-4.4577278d-03,-1.2852838d-06 /
      data fpppp( 4, 3,14,1),fpppp( 4, 3,14,2),fpppp( 4, 3,14,3)/
     x-4.9167218d-02, 1.3548486d-02,-1.8668836d-06 /
      data fpppp( 4, 3,15,1),fpppp( 4, 3,15,2),fpppp( 4, 3,15,3)/
     x-8.3465489d-02,-3.0843695d-02,-2.5535395d-06 /
      data fpppp( 4, 3,16,1),fpppp( 4, 3,16,2),fpppp( 4, 3,16,3)/
     x-1.4830158d-02,-3.9281675d-02,-2.6076308d-06 /
      data fpppp( 4, 3,17,1),fpppp( 4, 3,17,2),fpppp( 4, 3,17,3)/
     x 1.0912189d-01, 1.0952507d-01, 2.4627993d-05 /
      data fpppp( 4, 3,18,1),fpppp( 4, 3,18,2),fpppp( 4, 3,18,3)/
     x 7.0497941d-03,-6.9447268d-02, 1.2910024d-05 /
      data fpppp( 4, 3,19,1),fpppp( 4, 3,19,2),fpppp( 4, 3,19,3)/
     x 8.7203363d-03, 2.1068454d-02,-4.0304834d-05 /
      data fpppp( 4, 3,20,1),fpppp( 4, 3,20,2),fpppp( 4, 3,20,3)/
     x 4.6713582d-04,-5.2997422d-03, 8.7087077d-06 /
      data fpppp( 4, 3,21,1),fpppp( 4, 3,21,2),fpppp( 4, 3,21,3)/
     x 4.6713582d-04,-4.1900418d-04, 5.0969429d-06 /
      data fpppp( 4, 3,22,1),fpppp( 4, 3,22,2),fpppp( 4, 3,22,3)/
     x 8.7203363d-03, 1.5455025d-03,-2.5857775d-05 /
      data fpppp( 4, 3,23,1),fpppp( 4, 3,23,2),fpppp( 4, 3,23,3)/
     x 7.0497941d-03, 3.7638024d-03,-4.1266448d-05 /
      data fpppp( 4, 4, 1,1),fpppp( 4, 4, 1,2),fpppp( 4, 4, 1,3)/
     x-3.5138460d-03,-8.6490115d-03, 6.3526411d-05 /
      data fpppp( 4, 4, 2,1),fpppp( 4, 4, 2,2),fpppp( 4, 4, 2,3)/
     x-1.6331732d-02,-5.1334957d-03, 4.0030567d-05 /
      data fpppp( 4, 4, 3,1),fpppp( 4, 4, 3,2),fpppp( 4, 4, 3,3)/
     x 3.5845554d-04, 1.7674876d-03,-6.8572744d-06 /
      data fpppp( 4, 4, 4,1),fpppp( 4, 4, 4,2),fpppp( 4, 4, 4,3)/
     x 3.5845554d-04, 2.8739512d-03,-1.2912967d-05 /
      data fpppp( 4, 4, 5,1),fpppp( 4, 4, 5,2),fpppp( 4, 4, 5,3)/
     x-1.6331732d-02,-9.5593504d-03, 6.4253338d-05 /
      data fpppp( 4, 4, 6,1),fpppp( 4, 4, 6,2),fpppp( 4, 4, 6,3)/
     x-3.5138460d-03, 7.9479437d-03,-2.7308979d-05 /
      data fpppp( 4, 4, 7,1),fpppp( 4, 4, 7,2),fpppp( 4, 4, 7,3)/
     x-8.5092849d-02,-1.9369089d-03,-2.1177783d-05 /
      data fpppp( 4, 4, 8,1),fpppp( 4, 4, 8,2),fpppp( 4, 4, 8,3)/
     x 1.1855831d-02,-2.7197316d-03, 1.2889666d-07 /
      data fpppp( 4, 4, 9,1),fpppp( 4, 4, 9,2),fpppp( 4, 4, 9,3)/
     x 5.6062945d-02, 5.1236023d-03, 5.8342624d-07 /
      data fpppp( 4, 4,10,1),fpppp( 4, 4,10,2),fpppp( 4, 4,10,3)/
     x 2.8579099d-02,-3.0946874d-03, 3.5170793d-07 /
      data fpppp( 4, 4,11,1),fpppp( 4, 4,11,2),fpppp( 4, 4,11,3)/
     x 1.4793472d-02, 2.4189538d-04, 3.5578920d-07 /
      data fpppp( 4, 4,12,1),fpppp( 4, 4,12,2),fpppp( 4, 4,12,3)/
     x 6.0937633d-03, 2.1385910d-04, 3.4016821d-07 /
      data fpppp( 4, 4,13,1),fpppp( 4, 4,13,2),fpppp( 4, 4,13,3)/
     x 1.4824911d-02, 1.8116207d-04, 2.8845445d-07 /
      data fpppp( 4, 4,14,1),fpppp( 4, 4,14,2),fpppp( 4, 4,14,3)/
     x 2.9343563d-02,-3.2213193d-03, 3.6506267d-07 /
      data fpppp( 4, 4,15,1),fpppp( 4, 4,15,2),fpppp( 4, 4,15,3)/
     x 5.6679125d-02, 5.0565119d-03, 8.6756620d-07 /
      data fpppp( 4, 4,16,1),fpppp( 4, 4,16,2),fpppp( 4, 4,16,3)/
     x 1.4650298d-02,-2.0156602d-03,-1.0579926d-06 /
      data fpppp( 4, 4,17,1),fpppp( 4, 4,17,2),fpppp( 4, 4,17,3)/
     x-7.4871113d-02,-2.3474898d-03,-1.9119791d-05 /
      data fpppp( 4, 4,18,1),fpppp( 4, 4,18,2),fpppp( 4, 4,18,3)/
     x-6.0294494d-03, 4.5868999d-03,-2.7980050d-05 /
      data fpppp( 4, 4,19,1),fpppp( 4, 4,19,2),fpppp( 4, 4,19,3)/
     x-8.5464663d-03,-3.3618834d-03, 6.4046653d-05 /
      data fpppp( 4, 4,20,1),fpppp( 4, 4,20,2),fpppp( 4, 4,20,3)/
     x-3.6066776d-03, 7.4610402d-04,-1.3074105d-05 /
      data fpppp( 4, 4,21,1),fpppp( 4, 4,21,2),fpppp( 4, 4,21,3)/
     x-3.6066776d-03, 2.7778863d-04,-6.9973773d-06 /
      data fpppp( 4, 4,22,1),fpppp( 4, 4,22,2),fpppp( 4, 4,22,3)/
     x-8.5464663d-03,-1.4886219d-03, 3.9739744d-05 /
      data fpppp( 4, 4,23,1),fpppp( 4, 4,23,2),fpppp( 4, 4,23,3)/
     x-6.0294494d-03,-2.4378309d-03, 6.3170861d-05 /
      data fpppp( 4, 5, 1,1),fpppp( 4, 5, 1,2),fpppp( 4, 5, 1,3)/
     x 2.3379463d-03,-1.2098741d-03,-4.2585756d-05 /
      data fpppp( 4, 5, 2,1),fpppp( 4, 5, 2,2),fpppp( 4, 5, 2,3)/
     x 1.6268272d-02,-6.2531187d-04,-2.5777507d-05 /
      data fpppp( 4, 5, 3,1),fpppp( 4, 5, 3,2),fpppp( 4, 5, 3,3)/
     x-7.9462105d-03, 5.9527220d-04, 8.0547328d-06 /
      data fpppp( 4, 5, 4,1),fpppp( 4, 5, 4,2),fpppp( 4, 5, 4,3)/
     x-7.9462105d-03, 6.5135831d-04, 1.1879248d-05 /
      data fpppp( 4, 5, 5,1),fpppp( 4, 5, 5,2),fpppp( 4, 5, 5,3)/
     x 1.6268272d-02,-8.4965633d-04,-4.1075567d-05 /
      data fpppp( 4, 5, 6,1),fpppp( 4, 5, 6,2),fpppp( 4, 5, 6,3)/
     x 2.3379463d-03,-3.6858237d-04, 1.4781967d-05 /
      data fpppp( 4, 5, 7,1),fpppp( 4, 5, 7,2),fpppp( 4, 5, 7,3)/
     x 2.5067063d-02, 1.5445894d-04, 9.2158655d-06 /
      data fpppp( 4, 5, 8,1),fpppp( 4, 5, 8,2),fpppp( 4, 5, 8,3)/
     x-1.1434631d-03, 5.1790471d-04, 5.3773293d-07 /
      data fpppp( 4, 5, 9,1),fpppp( 4, 5, 9,2),fpppp( 4, 5, 9,3)/
     x-1.5306133d-02,-4.7496566d-04, 1.8487797d-07 /
      data fpppp( 4, 5,10,1),fpppp( 4, 5,10,2),fpppp( 4, 5,10,3)/
     x-5.7361709d-03, 1.6483130d-04,-5.3381995d-08 /
      data fpppp( 4, 5,11,1),fpppp( 4, 5,11,2),fpppp( 4, 5,11,3)/
     x-1.6996628d-03,-1.1713797d-04,-1.0916136d-07 /
      data fpppp( 4, 5,12,1),fpppp( 4, 5,12,2),fpppp( 4, 5,12,3)/
     x 6.1310042d-04,-1.1874331d-04,-1.1979474d-07 /
      data fpppp( 4, 5,13,1),fpppp( 4, 5,13,2),fpppp( 4, 5,13,3)/
     x-1.5943758d-03, 7.7813440d-04,-8.5004267d-08 /
      data fpppp( 4, 5,14,1),fpppp( 4, 5,14,2),fpppp( 4, 5,14,3)/
     x-5.4811320d-03,-3.3312595d-03,-1.8201408d-08 /
      data fpppp( 4, 5,15,1),fpppp( 4, 5,15,2),fpppp( 4, 5,15,3)/
     x-1.5386764d-02, 1.2486956d-02,-1.1727776d-07 /
      data fpppp( 4, 5,16,1),fpppp( 4, 5,16,2),fpppp( 4, 5,16,3)/
     x-2.6970294d-03,-1.9459050d-02, 1.6388053d-06 /
      data fpppp( 4, 5,17,1),fpppp( 4, 5,17,2),fpppp( 4, 5,17,3)/
     x 2.2102688d-02, 1.0543694d-02, 5.9025450d-06 /
      data fpppp( 4, 5,18,1),fpppp( 4, 5,18,2),fpppp( 4, 5,18,3)/
     x 4.9782580d-03,-2.2050535d-04, 1.9515669d-05 /
      data fpppp( 4, 5,19,1),fpppp( 4, 5,19,2),fpppp( 4, 5,19,3)/
     x 5.4502779d-03,-1.2853130d-03,-4.2192091d-05 /
      data fpppp( 4, 5,20,1),fpppp( 4, 5,20,2),fpppp( 4, 5,20,3)/
     x 6.8465497d-03, 4.3362179d-04, 1.1213142d-05 /
      data fpppp( 4, 5,21,1),fpppp( 4, 5,21,2),fpppp( 4, 5,21,3)/
     x 6.8465497d-03, 3.4499945d-04, 7.1009492d-06 /
      data fpppp( 4, 5,22,1),fpppp( 4, 5,22,2),fpppp( 4, 5,22,3)/
     x 5.4502779d-03,-9.3082367d-04,-2.5743318d-05 /
      data fpppp( 4, 5,23,1),fpppp( 4, 5,23,2),fpppp( 4, 5,23,3)/
     x 4.9782580d-03,-1.5498404d-03,-4.2167228d-05 /
      data fpppp( 4, 6, 1,1),fpppp( 4, 6, 1,2),fpppp( 4, 6, 1,3)/
     x-6.9303622d-03,-4.2393052d-04, 9.9808257d-06 /
      data fpppp( 4, 6, 2,1),fpppp( 4, 6, 2,2),fpppp( 4, 6, 2,3)/
     x-2.9945605d-02,-2.6889675d-04, 5.6464478d-06 /
      data fpppp( 4, 6, 3,1),fpppp( 4, 6, 3,2),fpppp( 4, 6, 3,3)/
     x 4.7449019d-02, 2.2032179d-05,-3.3642547d-06 /
      data fpppp( 4, 6, 4,1),fpppp( 4, 6, 4,2),fpppp( 4, 6, 4,3)/
     x 4.7449019d-02, 9.4283161d-05,-3.8494424d-06 /
      data fpppp( 4, 6, 5,1),fpppp( 4, 6, 5,2),fpppp( 4, 6, 5,3)/
     x-2.9945605d-02,-5.5790068d-04, 7.5871985d-06 /
      data fpppp( 4, 6, 6,1),fpppp( 4, 6, 6,2),fpppp( 4, 6, 6,3)/
     x-6.9303622d-03, 6.5983422d-04, 2.7030105d-06 /
      data fpppp( 4, 6, 7,1),fpppp( 4, 6, 7,2),fpppp( 4, 6, 7,3)/
     x-9.6199211d-03,-1.7992663d-04,-5.3365856d-06 /
      data fpppp( 4, 6, 8,1),fpppp( 4, 6, 8,2),fpppp( 4, 6, 8,3)/
     x 8.3507830d-04, 2.7282479d-05, 9.4789820d-07 /
      data fpppp( 4, 6, 9,1),fpppp( 4, 6, 9,2),fpppp( 4, 6, 9,3)/
     x 4.5447606d-03,-3.0202180d-05,-3.8589795d-07 /
      data fpppp( 4, 6,10,1),fpppp( 4, 6,10,2),fpppp( 4, 6,10,3)/
     x 1.9972133d-03,-3.8383567d-05, 6.1092802d-08 /
      data fpppp( 4, 6,11,1),fpppp( 4, 6,11,2),fpppp( 4, 6,11,3)/
     x 6.6588323d-04, 1.1205370d-04,-1.2349636d-09 /
      data fpppp( 4, 6,12,1),fpppp( 4, 6,12,2),fpppp( 4, 6,12,3)/
     x 5.1481053d-05,-4.3364462d-04, 3.0502725d-08 /
      data fpppp( 4, 6,13,1),fpppp( 4, 6,13,2),fpppp( 4, 6,13,3)/
     x 8.6184883d-04, 1.4907454d-03, 1.4365847d-08 /
      data fpppp( 4, 6,14,1),fpppp( 4, 6,14,2),fpppp( 4, 6,14,3)/
     x 1.4441749d-03,-5.0791131d-03,-1.6601964d-08 /
      data fpppp( 4, 6,15,1),fpppp( 4, 6,15,2),fpppp( 4, 6,15,3)/
     x 4.6497425d-03, 1.7718064d-02, 1.2841316d-08 /
      data fpppp( 4, 6,16,1),fpppp( 4, 6,16,2),fpppp( 4, 6,16,3)/
     x-1.4399991d-02,-2.7705405d-02,-4.8950964d-07 /
      data fpppp( 4, 6,17,1),fpppp( 4, 6,17,2),fpppp( 4, 6,17,3)/
     x-5.6278154d-03, 1.7615328d-02,-1.2226021d-06 /
      data fpppp( 4, 6,18,1),fpppp( 4, 6,18,2),fpppp( 4, 6,18,3)/
     x-1.8109242d-03,-5.2355456d-03,-5.2230561d-06 /
      data fpppp( 4, 6,19,1),fpppp( 4, 6,19,2),fpppp( 4, 6,19,3)/
     x-1.3570811d-03, 3.1054173d-03, 1.2155675d-05 /
      data fpppp( 4, 6,20,1),fpppp( 4, 6,20,2),fpppp( 4, 6,20,3)/
     x-4.2954959d-03,-1.1663100d-03,-3.7446998d-06 /
      data fpppp( 4, 6,21,1),fpppp( 4, 6,21,2),fpppp( 4, 6,21,3)/
     x-4.2954959d-03,-6.7575138d-04,-2.5675365d-06 /
      data fpppp( 4, 6,22,1),fpppp( 4, 6,22,2),fpppp( 4, 6,22,3)/
     x-1.3570811d-03, 1.1431827d-03, 7.4470217d-06 /
      data fpppp( 4, 6,23,1),fpppp( 4, 6,23,2),fpppp( 4, 6,23,3)/
     x-1.8109242d-03, 2.1228342d-03, 1.2434392d-05 /
      data fpppp( 4, 7, 1,1),fpppp( 4, 7, 1,2),fpppp( 4, 7, 1,3)/
     x 2.6976400d-02, 7.7047898d-02, 1.5291155d-06 /
      data fpppp( 4, 7, 2,1),fpppp( 4, 7, 2,2),fpppp( 4, 7, 2,3)/
     x 4.3484616d-02, 4.3356430d-02, 1.2182515d-06 /
      data fpppp( 4, 7, 3,1),fpppp( 4, 7, 3,2),fpppp( 4, 7, 3,3)/
     x-7.7780639d-02,-2.4591553d-02, 1.0144412d-06 /
      data fpppp( 4, 7, 4,1),fpppp( 4, 7, 4,2),fpppp( 4, 7, 4,3)/
     x-7.7780639d-02,-3.2025591d-02, 2.0536930d-07 /
      data fpppp( 4, 7, 5,1),fpppp( 4, 7, 5,2),fpppp( 4, 7, 5,3)/
     x 4.3484616d-02, 7.3092580d-02, 4.4545391d-06 /
      data fpppp( 4, 7, 6,1),fpppp( 4, 7, 6,2),fpppp( 4, 7, 6,3)/
     x 2.6976400d-02,-3.4462665d-02,-1.0606963d-05 /
      data fpppp( 4, 7, 7,1),fpppp( 4, 7, 7,2),fpppp( 4, 7, 7,3)/
     x 1.4761333d-02, 8.8640118d-03, 8.0909655d-06 /
      data fpppp( 4, 7, 8,1),fpppp( 4, 7, 8,2),fpppp( 4, 7, 8,3)/
     x-1.5108093d-03,-2.2442044d-03,-3.1414057d-06 /
      data fpppp( 4, 7, 9,1),fpppp( 4, 7, 9,2),fpppp( 4, 7, 9,3)/
     x-6.7737641d-04, 3.3185978d-04, 7.6354547d-07 /
      data fpppp( 4, 7,10,1),fpppp( 4, 7,10,2),fpppp( 4, 7,10,3)/
     x-4.2874846d-04,-1.1020139d-05,-1.9811575d-07 /
      data fpppp( 4, 7,11,1),fpppp( 4, 7,11,2),fpppp( 4, 7,11,3)/
     x 1.0473955d-03, 6.0565197d-05, 5.4495727d-08 /
      data fpppp( 4, 7,12,1),fpppp( 4, 7,12,2),fpppp( 4, 7,12,3)/
     x 1.1323772d-03,-1.0359913d-04,-7.5876898d-09 /
      data fpppp( 4, 7,13,1),fpppp( 4, 7,13,2),fpppp( 4, 7,13,3)/
     x 1.3150063d-04,-2.7684858d-06, 9.6324656d-09 /
      data fpppp( 4, 7,14,1),fpppp( 4, 7,14,2),fpppp( 4, 7,14,3)/
     x 5.3732431d-04, 1.6783929d-04, 1.5814440d-08 /
      data fpppp( 4, 7,15,1),fpppp( 4, 7,15,2),fpppp( 4, 7,15,3)/
     x-9.6364245d-04,-2.5662700d-04, 2.6002045d-09 /
      data fpppp( 4, 7,16,1),fpppp( 4, 7,16,2),fpppp( 4, 7,16,3)/
     x 1.4101145d-02, 1.6545925d-05, 1.2107725d-07 /
      data fpppp( 4, 7,17,1),fpppp( 4, 7,17,2),fpppp( 4, 7,17,3)/
     x 2.2902510d-03, 5.4148123d-04, 2.8371955d-07 /
      data fpppp( 4, 7,18,1),fpppp( 4, 7,18,2),fpppp( 4, 7,18,3)/
     x 7.8884466d-04,-1.0727647d-03, 1.3139256d-06 /
      data fpppp( 4, 7,19,1),fpppp( 4, 7,19,2),fpppp( 4, 7,19,3)/
     x 1.6973540d-03, 1.4845174d-03,-3.4756274d-06 /
      data fpppp( 4, 7,20,1),fpppp( 4, 7,20,2),fpppp( 4, 7,20,3)/
     x 2.5473589d-03,-6.0082641d-04, 1.2348035d-06 /
      data fpppp( 4, 7,21,1),fpppp( 4, 7,21,2),fpppp( 4, 7,21,3)/
     x 2.5473589d-03,-4.3324212d-04, 9.0310631d-07 /
      data fpppp( 4, 7,22,1),fpppp( 4, 7,22,2),fpppp( 4, 7,22,3)/
     x 1.6973540d-03, 8.1418019d-04,-2.1488387d-06 /
      data fpppp( 4, 7,23,1),fpppp( 4, 7,23,2),fpppp( 4, 7,23,3)/
     x 7.8884466d-04, 1.4409997d-03,-3.6615322d-06 /
      data fpppp( 4, 8, 1,1),fpppp( 4, 8, 1,2),fpppp( 4, 8, 1,3)/
     x-4.1505214d-02, 1.7951524d-02, 1.9140360d-06 /
      data fpppp( 4, 8, 2,1),fpppp( 4, 8, 2,2),fpppp( 4, 8, 2,3)/
     x-2.5605059d-02, 1.1222019d-02, 1.0133582d-06 /
      data fpppp( 4, 8, 3,1),fpppp( 4, 8, 3,2),fpppp( 4, 8, 3,3)/
     x 4.9652816d-02,-9.2428314d-04,-1.4962425d-06 /
      data fpppp( 4, 8, 4,1),fpppp( 4, 8, 4,2),fpppp( 4, 8, 4,3)/
     x 4.9652816d-02,-4.9038991d-03,-4.8198333d-07 /
      data fpppp( 4, 8, 5,1),fpppp( 4, 8, 5,2),fpppp( 4, 8, 5,3)/
     x-2.5605059d-02, 2.7140483d-02,-3.0436784d-06 /
      data fpppp( 4, 8, 6,1),fpppp( 4, 8, 6,2),fpppp( 4, 8, 6,3)/
     x-4.1505214d-02,-4.1742716d-02, 1.7127923d-05 /
      data fpppp( 4, 8, 7,1),fpppp( 4, 8, 7,2),fpppp( 4, 8, 7,3)/
     x-4.8905588d-02, 2.6108305d-02,-2.1163924d-05 /
      data fpppp( 4, 8, 8,1),fpppp( 4, 8, 8,2),fpppp( 4, 8, 8,3)/
     x 5.7549062d-03,-6.1824334d-03, 9.9523121d-06 /
      data fpppp( 4, 8, 9,1),fpppp( 4, 8, 9,2),fpppp( 4, 8, 9,3)/
     x-1.4542865d-04, 2.7669050d-04,-2.3289857d-06 /
      data fpppp( 4, 8,10,1),fpppp( 4, 8,10,2),fpppp( 4, 8,10,3)/
     x 2.3074819d-04, 1.0320726d-03, 6.1910977d-07 /
      data fpppp( 4, 8,11,1),fpppp( 4, 8,11,2),fpppp( 4, 8,11,3)/
     x-2.6867803d-03,-8.0403305d-04,-1.3220449d-07 /
      data fpppp( 4, 8,12,1),fpppp( 4, 8,12,2),fpppp( 4, 8,12,3)/
     x-2.7936387d-03, 4.2610448d-04, 6.1214636d-08 /
      data fpppp( 4, 8,13,1),fpppp( 4, 8,13,2),fpppp( 4, 8,13,3)/
     x 6.5176076d-04,-8.4820996d-04, 1.4894425d-08 /
      data fpppp( 4, 8,14,1),fpppp( 4, 8,14,2),fpppp( 4, 8,14,3)/
     x-2.4513551d-03, 1.4730878d-03, 3.0857064d-08 /
      data fpppp( 4, 8,15,1),fpppp( 4, 8,15,2),fpppp( 4, 8,15,3)/
     x 8.4333941d-04,-1.7186847d-03, 5.1436292d-08 /
      data fpppp( 4, 8,16,1),fpppp( 4, 8,16,2),fpppp( 4, 8,16,3)/
     x-3.7457356d-03, 1.7536105d-03, 4.5494084d-08 /
      data fpppp( 4, 8,17,1),fpppp( 4, 8,17,2),fpppp( 4, 8,17,3)/
     x-5.3572326d-04,-9.8717955d-04, 5.4911679d-08 /
      data fpppp( 4, 8,18,1),fpppp( 4, 8,18,2),fpppp( 4, 8,18,3)/
     x-2.3942042d-04, 2.6311142d-04,-2.4553098d-07 /
      data fpppp( 4, 8,19,1),fpppp( 4, 8,19,2),fpppp( 4, 8,19,3)/
     x-1.4662332d-03, 3.7954952d-04, 1.4035862d-06 /
      data fpppp( 4, 8,20,1),fpppp( 4, 8,20,2),fpppp( 4, 8,20,3)/
     x-1.5979710d-04,-3.6519307d-04,-9.5323398d-07 /
      data fpppp( 4, 8,21,1),fpppp( 4, 8,21,2),fpppp( 4, 8,21,3)/
     x-1.5979710d-04,-3.4316849d-04,-8.2274506d-07 /
      data fpppp( 4, 8,22,1),fpppp( 4, 8,22,2),fpppp( 4, 8,22,3)/
     x-1.4662332d-03, 2.9145117d-04, 8.8163049d-07 /
      data fpppp( 4, 8,23,1),fpppp( 4, 8,23,2),fpppp( 4, 8,23,3)/
     x-2.3942042d-04, 5.9348023d-04, 1.7118028d-06 /
      data fpppp( 4, 9, 1,1),fpppp( 4, 9, 1,2),fpppp( 4, 9, 1,3)/
     x 2.6594133d-02,-2.2008799d-04,-3.1911645d-06 /
      data fpppp( 4, 9, 2,1),fpppp( 4, 9, 2,2),fpppp( 4, 9, 2,3)/
     x 6.4946281d-03,-4.9090899d-04,-2.1552645d-06 /
      data fpppp( 4, 9, 3,1),fpppp( 4, 9, 3,2),fpppp( 4, 9, 3,3)/
     x-1.2604703d-02, 7.8987703d-04, 5.2447486d-07 /
      data fpppp( 4, 9, 4,1),fpppp( 4, 9, 4,2),fpppp( 4, 9, 4,3)/
     x-1.2604703d-02,-2.4670772d-03,-2.8044414d-07 /
      data fpppp( 4, 9, 5,1),fpppp( 4, 9, 5,2),fpppp( 4, 9, 5,3)/
     x 6.4946281d-03, 1.2536908d-02, 1.0644115d-06 /
      data fpppp( 4, 9, 6,1),fpppp( 4, 9, 6,2),fpppp( 4, 9, 6,3)/
     x 2.6594133d-02,-4.9074402d-02,-1.5264950d-05 /
      data fpppp( 4, 9, 7,1),fpppp( 4, 9, 7,2),fpppp( 4, 9, 7,3)/
     x 7.6555135d-02, 8.0364384d-02, 3.1077609d-05 /
      data fpppp( 4, 9, 8,1),fpppp( 4, 9, 8,2),fpppp( 4, 9, 8,3)/
     x-1.2556227d-02,-5.3002131d-02,-2.0939581d-05 /
      data fpppp( 4, 9, 9,1),fpppp( 4, 9, 9,2),fpppp( 4, 9, 9,3)/
     x 2.3213892d-03, 1.3586845d-02, 5.0199534d-06 /
      data fpppp( 4, 9,10,1),fpppp( 4, 9,10,2),fpppp( 4, 9,10,3)/
     x-1.3623693d-05,-1.1960461d-03,-1.0241692d-06 /
      data fpppp( 4, 9,11,1),fpppp( 4, 9,11,2),fpppp( 4, 9,11,3)/
     x 1.0673704d-02,-8.7407304d-04, 3.1386946d-07 /
      data fpppp( 4, 9,12,1),fpppp( 4, 9,12,2),fpppp( 4, 9,12,3)/
     x 1.1157025d-02, 6.9629652d-04,-5.7613975d-08 /
      data fpppp( 4, 9,13,1),fpppp( 4, 9,13,2),fpppp( 4, 9,13,3)/
     x-1.8209711d-03,-1.7883059d-03, 3.7175074d-08 /
      data fpppp( 4, 9,14,1),fpppp( 4, 9,14,2),fpppp( 4, 9,14,3)/
     x 9.6062556d-03, 3.0343269d-03, 2.1639465d-08 /
      data fpppp( 4, 9,15,1),fpppp( 4, 9,15,2),fpppp( 4, 9,15,3)/
     x-1.8481126d-03,-3.3071943d-03, 3.6060740d-08 /
      data fpppp( 4, 9,16,1),fpppp( 4, 9,16,2),fpppp( 4, 9,16,3)/
     x 1.0229180d-03, 3.0965668d-03, 3.6959807d-08 /
      data fpppp( 4, 9,17,1),fpppp( 4, 9,17,2),fpppp( 4, 9,17,3)/
     x-1.4430769d-03,-1.8293125d-03, 3.8854054d-08 /
      data fpppp( 4, 9,18,1),fpppp( 4, 9,18,2),fpppp( 4, 9,18,3)/
     x-1.3478520d-03, 4.6285376d-04, 1.0374367d-07 /
      data fpppp( 4, 9,19,1),fpppp( 4, 9,19,2),fpppp( 4, 9,19,3)/
     x-6.5092834d-04, 5.1740654d-05,-2.8815880d-07 /
      data fpppp( 4, 9,20,1),fpppp( 4, 9,20,2),fpppp( 4, 9,20,3)/
     x-8.0184664d-03,-9.2032303d-05,-1.0126528d-08 /
      data fpppp( 4, 9,21,1),fpppp( 4, 9,21,2),fpppp( 4, 9,21,3)/
     x-8.0184664d-03,-1.0836232d-04,-3.4888436d-08 /
      data fpppp( 4, 9,22,1),fpppp( 4, 9,22,2),fpppp( 4, 9,22,3)/
     x-6.5092834d-04, 1.1706073d-04,-1.8911117d-07 /
      data fpppp( 4, 9,23,1),fpppp( 4, 9,23,2),fpppp( 4, 9,23,3)/
     x-1.3478520d-03, 2.1790348d-04,-2.6768495d-07 /
      data fpppp( 4,10, 1,1),fpppp( 4,10, 1,2),fpppp( 4,10, 1,3)/
     x-7.1567254d-03,-5.0995118d-04, 1.5166540d-06 /
      data fpppp( 4,10, 2,1),fpppp( 4,10, 2,2),fpppp( 4,10, 2,3)/
     x-1.7214471d-03,-3.5213602d-04, 8.4481543d-07 /
      data fpppp( 4,10, 3,1),fpppp( 4,10, 3,2),fpppp( 4,10, 3,3)/
     x 3.0379181d-03,-1.0200968d-04,-8.2815161d-07 /
      data fpppp( 4,10, 4,1),fpppp( 4,10, 4,2),fpppp( 4,10, 4,3)/
     x 3.0379181d-03, 5.2076077d-05,-4.1985399d-07 /
      data fpppp( 4,10, 5,1),fpppp( 4,10, 5,2),fpppp( 4,10, 5,3)/
     x-1.7214471d-03,-9.6847906d-04,-7.8837507d-07 /
      data fpppp( 4,10, 6,1),fpppp( 4,10, 6,2),fpppp( 4,10, 6,3)/
     x-7.1567254d-03, 1.8013352d-03, 7.6411184d-06 /
      data fpppp( 4,10, 7,1),fpppp( 4,10, 7,2),fpppp( 4,10, 7,3)/
     x-4.7993081d-02,-6.7627281d-03,-1.9978801d-05 /
      data fpppp( 4,10, 8,1),fpppp( 4,10, 8,2),fpppp( 4,10, 8,3)/
     x 1.3052587d-02, 1.5156949d-02, 2.2221958d-05 /
      data fpppp( 4,10, 9,1),fpppp( 4,10, 9,2),fpppp( 4,10, 9,3)/
     x-5.5159197d-03,-1.5854015d-02,-8.9748380d-06 /
      data fpppp( 4,10,10,1),fpppp( 4,10,10,2),fpppp( 4,10,10,3)/
     x 7.2255847d-04, 1.4834093d-02, 9.7018344d-07 /
      data fpppp( 4,10,11,1),fpppp( 4,10,11,2),fpppp( 4,10,11,3)/
     x-1.8208639d-02,-7.6001477d-03,-3.2548900d-07 /
      data fpppp( 4,10,12,1),fpppp( 4,10,12,2),fpppp( 4,10,12,3)/
     x-1.9051948d-02,-1.0585103d-02, 8.6327388d-08 /
      data fpppp( 4,10,13,1),fpppp( 4,10,13,2),fpppp( 4,10,13,3)/
     x 1.5022769d-03, 2.1238524d-02,-8.3635683d-09 /
      data fpppp( 4,10,14,1),fpppp( 4,10,14,2),fpppp( 4,10,14,3)/
     x-1.0369271d-02,-2.1073945d-02, 2.2814336d-08 /
      data fpppp( 4,10,15,1),fpppp( 4,10,15,2),fpppp( 4,10,15,3)/
     x 1.4912787d-03, 1.2418944d-02, 1.2292556d-08 /
      data fpppp( 4,10,16,1),fpppp( 4,10,16,2),fpppp( 4,10,16,3)/
     x-2.4792696d-04,-3.3314865d-03, 5.9019478d-10 /
      data fpppp( 4,10,17,1),fpppp( 4,10,17,2),fpppp( 4,10,17,3)/
     x 1.3686294d-03, 9.0469257d-04,-8.8737262d-09 /
      data fpppp( 4,10,18,1),fpppp( 4,10,18,2),fpppp( 4,10,18,3)/
     x 1.2867911d-03,-2.3817096d-04,-5.3183899d-08 /
      data fpppp( 4,10,19,1),fpppp( 4,10,19,2),fpppp( 4,10,19,3)/
     x 1.0009442d-03, 4.3053251d-04, 1.7839563d-07 /
      data fpppp( 4,10,20,1),fpppp( 4,10,20,2),fpppp( 4,10,20,3)/
     x 3.1908507d-02,-2.7569528d-04,-1.5734606d-07 /
      data fpppp( 4,10,21,1),fpppp( 4,10,21,2),fpppp( 4,10,21,3)/
     x 3.1908507d-02,-2.2830874d-04,-1.3891604d-07 /
      data fpppp( 4,10,22,1),fpppp( 4,10,22,2),fpppp( 4,10,22,3)/
     x 1.0009442d-03, 2.4098635d-04, 1.0467557d-07 /
      data fpppp( 4,10,23,1),fpppp( 4,10,23,2),fpppp( 4,10,23,3)/
     x 1.2867911d-03, 4.7262714d-04, 2.2326633d-07 /
      data fpppp( 4,11, 1,1),fpppp( 4,11, 1,2),fpppp( 4,11, 1,3)/
     x 2.3003741d-03, 6.7186076d-04, 2.0220978d-06 /
      data fpppp( 4,11, 2,1),fpppp( 4,11, 2,2),fpppp( 4,11, 2,3)/
     x 2.7869232d-03, 1.9409291d-04, 7.7051393d-07 /
      data fpppp( 4,11, 3,1),fpppp( 4,11, 3,2),fpppp( 4,11, 3,3)/
     x 8.2454374d-03,-8.2690805d-04,-1.7862225d-06 /
      data fpppp( 4,11, 4,1),fpppp( 4,11, 4,2),fpppp( 4,11, 4,3)/
     x 8.2454374d-03,-8.3178580d-04,-2.0053733d-06 /
      data fpppp( 4,11, 5,1),fpppp( 4,11, 5,2),fpppp( 4,11, 5,3)/
     x 2.7869232d-03, 2.1360393d-04, 1.6471174d-06 /
      data fpppp( 4,11, 6,1),fpppp( 4,11, 6,2),fpppp( 4,11, 6,3)/
     x 2.3003741d-03, 5.9869443d-04,-1.2651651d-06 /
      data fpppp( 4,11, 7,1),fpppp( 4,11, 7,2),fpppp( 4,11, 7,3)/
     x 1.3076770d-02,-7.4366617d-04, 6.4880486d-06 /
      data fpppp( 4,11, 8,1),fpppp( 4,11, 8,2),fpppp( 4,11, 8,3)/
     x-5.5358962d-03, 1.8763799d-03,-1.0145512d-05 /
      data fpppp( 4,11, 9,1),fpppp( 4,11, 9,2),fpppp( 4,11, 9,3)/
     x 3.4651567d-03, 4.6354660d-04, 8.9543111d-06 /
      data fpppp( 4,11,10,1),fpppp( 4,11,10,2),fpppp( 4,11,10,3)/
     x-8.7495067d-04,-2.0556511d-03,-2.7298718d-06 /
      data fpppp( 4,11,11,1),fpppp( 4,11,11,2),fpppp( 4,11,11,3)/
     x 1.2397953d-02, 1.5515400d-03, 1.6236326d-07 /
      data fpppp( 4,11,12,1),fpppp( 4,11,12,2),fpppp( 4,11,12,3)/
     x 1.3142767d-02,-2.8382147d-03,-1.2757519d-07 /
      data fpppp( 4,11,13,1),fpppp( 4,11,13,2),fpppp( 4,11,13,3)/
     x-3.1446643d-04, 1.0201214d-02, 2.4560950d-08 /
      data fpppp( 4,11,14,1),fpppp( 4,11,14,2),fpppp( 4,11,14,3)/
     x 3.4370326d-03,-1.6043075d-02, 4.9580325d-10 /
      data fpppp( 4,11,15,1),fpppp( 4,11,15,2),fpppp( 4,11,15,3)/
     x-3.0774606d-04, 1.0203168d-02, 4.5968304d-09 /
      data fpppp( 4,11,16,1),fpppp( 4,11,16,2),fpppp( 4,11,16,3)/
     x 1.7252754d-04,-2.9795976d-03, 2.0556239d-09 /
      data fpppp( 4,11,17,1),fpppp( 4,11,17,2),fpppp( 4,11,17,3)/
     x-2.4059007d-04, 1.6534736d-03,-1.5691782d-08 /
      data fpppp( 4,11,18,1),fpppp( 4,11,18,2),fpppp( 4,11,18,3)/
     x-2.0078517d-04,-3.5576777d-03, 4.5666242d-08 /
      data fpppp( 4,11,19,1),fpppp( 4,11,19,2),fpppp( 4,11,19,3)/
     x-1.5917074d-04, 1.3055951d-02,-2.3574836d-07 /
      data fpppp( 4,11,20,1),fpppp( 4,11,20,2),fpppp( 4,11,20,3)/
     x-7.7176628d-02,-7.1772744d-03, 8.8135026d-08 /
      data fpppp( 4,11,21,1),fpppp( 4,11,21,2),fpppp( 4,11,21,3)/
     x-7.7176628d-02,-5.9404485d-03, 6.7602106d-08 /
      data fpppp( 4,11,22,1),fpppp( 4,11,22,2),fpppp( 4,11,22,3)/
     x-1.5917074d-04, 8.1086468d-03,-1.5361668d-07 /
      data fpppp( 4,11,23,1),fpppp( 4,11,23,2),fpppp( 4,11,23,3)/
     x-2.0078517d-04, 1.4994712d-02,-2.6232756d-07 /
      data fpppp( 4,12, 1,1),fpppp( 4,12, 1,2),fpppp( 4,12, 1,3)/
     x 1.8592520d-03, 6.9995587d-03, 3.3446903d-06 /
      data fpppp( 4,12, 2,1),fpppp( 4,12, 2,2),fpppp( 4,12, 2,3)/
     x 2.1562222d-03, 3.3131577d-03, 1.4886778d-06 /
      data fpppp( 4,12, 3,1),fpppp( 4,12, 3,2),fpppp( 4,12, 3,3)/
     x-4.1207183d-03,-4.3509991d-03,-2.4137698d-06 /
      data fpppp( 4,12, 4,1),fpppp( 4,12, 4,2),fpppp( 4,12, 4,3)/
     x-4.1207183d-03,-4.7627284d-03,-2.5445335d-06 /
      data fpppp( 4,12, 5,1),fpppp( 4,12, 5,2),fpppp( 4,12, 5,3)/
     x 2.1562222d-03, 4.9600751d-03, 2.0117327d-06 /
      data fpppp( 4,12, 6,1),fpppp( 4,12, 6,2),fpppp( 4,12, 6,3)/
     x 1.8592520d-03, 8.2361844d-04, 1.3832343d-06 /
      data fpppp( 4,12, 7,1),fpppp( 4,12, 7,2),fpppp( 4,12, 7,3)/
     x-3.3581863d-03, 7.3098226d-04,-1.1737104d-06 /
      data fpppp( 4,12, 8,1),fpppp( 4,12, 8,2),fpppp( 4,12, 8,3)/
     x 1.2531890d-03,-4.9951078d-04, 2.4077438d-06 /
      data fpppp( 4,12, 9,1),fpppp( 4,12, 9,2),fpppp( 4,12, 9,3)/
     x 6.8829954d-05, 2.7517757d-03,-2.7858224d-06 /
      data fpppp( 4,12,10,1),fpppp( 4,12,10,2),fpppp( 4,12,10,3)/
     x-8.4721985d-04,-2.0220916d-03, 2.8341547d-06 /
      data fpppp( 4,12,11,1),fpppp( 4,12,11,2),fpppp( 4,12,11,3)/
     x-3.5060393d-03, 5.7894704d-04,-9.3079149d-07 /
      data fpppp( 4,12,12,1),fpppp( 4,12,12,2),fpppp( 4,12,12,3)/
     x-5.0003625d-03,-2.3774845d-03, 1.1395227d-07 /
      data fpppp( 4,12,13,1),fpppp( 4,12,13,2),fpppp( 4,12,13,3)/
     x 1.2398390d-04, 9.6408291d-03,-5.6648306d-08 /
      data fpppp( 4,12,14,1),fpppp( 4,12,14,2),fpppp( 4,12,14,3)/
     x-6.8569396d-04,-1.5158617d-02, 5.0558743d-09 /
      data fpppp( 4,12,15,1),fpppp( 4,12,15,2),fpppp( 4,12,15,3)/
     x 7.7506488d-05, 9.4159834d-03,-4.7654973d-09 /
      data fpppp( 4,12,16,1),fpppp( 4,12,16,2),fpppp( 4,12,16,3)/
     x-5.3336466d-05,-1.7892473d-03, 6.3563656d-09 /
      data fpppp( 4,12,17,1),fpppp( 4,12,17,2),fpppp( 4,12,17,3)/
     x 8.7873158d-05,-2.3259320d-03, 2.1410251d-08 /
      data fpppp( 4,12,18,1),fpppp( 4,12,18,2),fpppp( 4,12,18,3)/
     x 1.4836172d-04, 1.1229675d-02,-7.0447707d-08 /
      data fpppp( 4,12,19,1),fpppp( 4,12,19,2),fpppp( 4,12,19,3)/
     x 3.6276825d-04,-4.2060734d-02,-8.1185008d-08 /
      data fpppp( 4,12,20,1),fpppp( 4,12,20,2),fpppp( 4,12,20,3)/
     x 6.1791921d-02, 2.2954570d-02, 6.2783941d-08 /
      data fpppp( 4,12,21,1),fpppp( 4,12,21,2),fpppp( 4,12,21,3)/
     x 6.1791921d-02, 1.8984749d-02, 5.9085073d-08 /
      data fpppp( 4,12,22,1),fpppp( 4,12,22,2),fpppp( 4,12,22,3)/
     x 3.6276825d-04,-2.6181452d-02,-6.6389537d-08 /
      data fpppp( 4,12,23,1),fpppp( 4,12,23,2),fpppp( 4,12,23,3)/
     x 1.4836172d-04,-4.8317632d-02,-1.2593072d-07 /
      data fpppp( 4,13, 1,1),fpppp( 4,13, 1,2),fpppp( 4,13, 1,3)/
     x-3.2979271d-03, 4.8122615d-03,-8.3025787d-06 /
      data fpppp( 4,13, 2,1),fpppp( 4,13, 2,2),fpppp( 4,13, 2,3)/
     x-3.0657122d-03, 1.7550616d-03,-4.0095255d-06 /
      data fpppp( 4,13, 3,1),fpppp( 4,13, 3,2),fpppp( 4,13, 3,3)/
     x-5.5370107d-03,-4.6786425d-03, 4.9541433d-06 /
      data fpppp( 4,13, 4,1),fpppp( 4,13, 4,2),fpppp( 4,13, 4,3)/
     x-5.5370107d-03,-4.8841601d-03, 5.3666725d-06 /
      data fpppp( 4,13, 5,1),fpppp( 4,13, 5,2),fpppp( 4,13, 5,3)/
     x-3.0657122d-03, 2.5771318d-03,-5.6596425d-06 /
      data fpppp( 4,13, 6,1),fpppp( 4,13, 6,2),fpppp( 4,13, 6,3)/
     x-3.2979271d-03, 1.7294983d-03,-2.1146398d-06 /
      data fpppp( 4,13, 7,1),fpppp( 4,13, 7,2),fpppp( 4,13, 7,3)/
     x 7.9917352d-04, 2.5216102d-03,-1.8990276d-07 /
      data fpppp( 4,13, 8,1),fpppp( 4,13, 8,2),fpppp( 4,13, 8,3)/
     x-4.3528170d-04,-2.2563895d-04,-6.1421277d-07 /
      data fpppp( 4,13, 9,1),fpppp( 4,13, 9,2),fpppp( 4,13, 9,3)/
     x 2.1389445d-04, 4.3938862d-04, 2.3347391d-07 /
      data fpppp( 4,13,10,1),fpppp( 4,13,10,2),fpppp( 4,13,10,3)/
     x 1.0415739d-03, 1.6747498d-03, 2.4718190d-07 /
      data fpppp( 4,13,11,1),fpppp( 4,13,11,2),fpppp( 4,13,11,3)/
     x 1.8295691d-04,-1.4905211d-03, 2.8731181d-07 /
      data fpppp( 4,13,12,1),fpppp( 4,13,12,2),fpppp( 4,13,12,3)/
     x 6.8313916d-03,-1.5555885d-03,-8.8519212d-08 /
      data fpppp( 4,13,13,1),fpppp( 4,13,13,2),fpppp( 4,13,13,3)/
     x-5.3584135d-05, 7.4718775d-03,-1.1975474d-08 /
      data fpppp( 4,13,14,1),fpppp( 4,13,14,2),fpppp( 4,13,14,3)/
     x-4.0033776d-03,-1.1793239d-02,-1.4242969d-08 /
      data fpppp( 4,13,15,1),fpppp( 4,13,15,2),fpppp( 4,13,15,3)/
     x 2.6208663d-04, 7.3241788d-03,-1.0912421d-08 /
      data fpppp( 4,13,16,1),fpppp( 4,13,16,2),fpppp( 4,13,16,3)/
     x 4.5764379d-04,-1.2823667d-03,-1.2071006d-09 /
      data fpppp( 4,13,17,1),fpppp( 4,13,17,2),fpppp( 4,13,17,3)/
     x 5.6079037d-04,-2.1644306d-03,-1.9707587d-08 /
      data fpppp( 4,13,18,1),fpppp( 4,13,18,2),fpppp( 4,13,18,3)/
     x 6.4147428d-04, 1.0244444d-02,-3.6835943d-08 /
      data fpppp( 4,13,19,1),fpppp( 4,13,19,2),fpppp( 4,13,19,3)/
     x 4.8859168d-04,-3.7844079d-02,-1.7235112d-07 /
      data fpppp( 4,13,20,1),fpppp( 4,13,20,2),fpppp( 4,13,20,3)/
     x 2.1558680d-02, 2.0548522d-02, 1.7224780d-07 /
      data fpppp( 4,13,21,1),fpppp( 4,13,21,2),fpppp( 4,13,21,3)/
     x 2.1558680d-02, 1.6972332d-02, 1.5818160d-07 /
      data fpppp( 4,13,22,1),fpppp( 4,13,22,2),fpppp( 4,13,22,3)/
     x 4.8859168d-04,-2.3539319d-02,-1.1608631d-07 /
      data fpppp( 4,13,23,1),fpppp( 4,13,23,2),fpppp( 4,13,23,3)/
     x 6.4147428d-04,-4.3398407d-02,-2.4782898d-07 /
      data fpppp( 4,14, 1,1),fpppp( 4,14, 1,2),fpppp( 4,14, 1,3)/
     x-8.8528119d-04,-4.2125173d-04,-5.1050892d-06 /
      data fpppp( 4,14, 2,1),fpppp( 4,14, 2,2),fpppp( 4,14, 2,3)/
     x-7.6977779d-03,-1.2699794d-03,-2.1217587d-06 /
      data fpppp( 4,14, 3,1),fpppp( 4,14, 3,2),fpppp( 4,14, 3,3)/
     x-4.3531457d-03,-3.3231260d-03, 4.1688413d-06 /
      data fpppp( 4,14, 4,1),fpppp( 4,14, 4,2),fpppp( 4,14, 4,3)/
     x-4.3531457d-03,-2.9128481d-03, 4.3477811d-06 /
      data fpppp( 4,14, 5,1),fpppp( 4,14, 5,2),fpppp( 4,14, 5,3)/
     x-7.6977779d-03,-2.9110906d-03,-2.8375177d-06 /
      data fpppp( 4,14, 6,1),fpppp( 4,14, 6,2),fpppp( 4,14, 6,3)/
     x-8.8528119d-04, 5.7329154d-03,-2.4209930d-06 /
      data fpppp( 4,14, 7,1),fpppp( 4,14, 7,2),fpppp( 4,14, 7,3)/
     x-8.3879917d-04, 6.5814729d-04,-1.2489330d-06 /
      data fpppp( 4,14, 8,1),fpppp( 4,14, 8,2),fpppp( 4,14, 8,3)/
     x-7.3619047d-05, 7.8834689d-04,-1.7119733d-07 /
      data fpppp( 4,14, 9,1),fpppp( 4,14, 9,2),fpppp( 4,14, 9,3)/
     x-2.9846592d-04,-4.3059947d-04,-2.8920011d-07 /
      data fpppp( 4,14,10,1),fpppp( 4,14,10,2),fpppp( 4,14,10,3)/
     x 1.6246562d-04, 5.2998216d-04, 7.9609944d-08 /
      data fpppp( 4,14,11,1),fpppp( 4,14,11,2),fpppp( 4,14,11,3)/
     x 2.1789657d-04, 5.4705920d-03, 6.3926212d-07 /
      data fpppp( 4,14,12,1),fpppp( 4,14,12,2),fpppp( 4,14,12,3)/
     x-9.3678237d-03,-1.0462857d-02,-3.6231909d-07 /
      data fpppp( 4,14,13,1),fpppp( 4,14,13,2),fpppp( 4,14,13,3)/
     x-1.6272426d-04, 6.4648489d-03, 1.5216703d-07 /
      data fpppp( 4,14,14,1),fpppp( 4,14,14,2),fpppp( 4,14,14,3)/
     x 4.8780777d-03,-1.7039818d-03,-4.5867626d-08 /
      data fpppp( 4,14,15,1),fpppp( 4,14,15,2),fpppp( 4,14,15,3)/
     x-1.2218344d-03, 4.6812593d-04, 2.7728618d-09 /
      data fpppp( 4,14,16,1),fpppp( 4,14,16,2),fpppp( 4,14,16,3)/
     x-1.8173291d-03,-1.1162741d-04,-1.2775065d-08 /
      data fpppp( 4,14,17,1),fpppp( 4,14,17,2),fpppp( 4,14,17,3)/
     x-2.3357662d-03, 8.5352281d-05, 3.3308201d-09 /
      data fpppp( 4,14,18,1),fpppp( 4,14,18,2),fpppp( 4,14,18,3)/
     x-2.8306375d-03, 9.5223659d-05, 2.2755683d-08 /
      data fpppp( 4,14,19,1),fpppp( 4,14,19,2),fpppp( 4,14,19,3)/
     x-3.2686318d-03, 2.1678390d-04, 2.3970194d-07 /
      data fpppp( 4,14,20,1),fpppp( 4,14,20,2),fpppp( 4,14,20,3)/
     x-4.2002602d-02,-2.5971516d-04,-1.4606918d-07 /
      data fpppp( 4,14,21,1),fpppp( 4,14,21,2),fpppp( 4,14,21,3)/
     x-4.2002602d-02,-2.4338953d-04,-1.2722554d-07 /
      data fpppp( 4,14,22,1),fpppp( 4,14,22,2),fpppp( 4,14,22,3)/
     x-3.2686318d-03, 1.5148141d-04, 1.6432736d-07 /
      data fpppp( 4,14,23,1),fpppp( 4,14,23,2),fpppp( 4,14,23,3)/
     x-2.8306375d-03, 3.4010801d-04, 3.0541036d-07 /
      data fpppp( 4,15, 1,1),fpppp( 4,15, 1,2),fpppp( 4,15, 1,3)/
     x-2.5295606d-04, 2.8794345d-03, 5.4309568d-06 /
      data fpppp( 4,15, 2,1),fpppp( 4,15, 2,2),fpppp( 4,15, 2,3)/
     x 3.2547863d-03, 9.9792517d-04, 2.7038278d-06 /
      data fpppp( 4,15, 3,1),fpppp( 4,15, 3,2),fpppp( 4,15, 3,3)/
     x-2.4937288d-03,-3.0048462d-03,-2.9645604d-06 /
      data fpppp( 4,15, 4,1),fpppp( 4,15, 4,2),fpppp( 4,15, 4,3)/
     x-2.4937288d-03,-3.0556564d-03,-3.2716148d-06 /
      data fpppp( 4,15, 5,1),fpppp( 4,15, 5,2),fpppp( 4,15, 5,3)/
     x 3.2547863d-03, 1.2011660d-03, 3.9320454d-06 /
      data fpppp( 4,15, 6,1),fpppp( 4,15, 6,2),fpppp( 4,15, 6,3)/
     x-2.5295606d-04, 2.1172813d-03, 8.2514077d-07 /
      data fpppp( 4,15, 7,1),fpppp( 4,15, 7,2),fpppp( 4,15, 7,3)/
     x-2.8512968d-04, 4.1123596d-04, 7.2666054d-08 /
      data fpppp( 4,15, 8,1),fpppp( 4,15, 8,2),fpppp( 4,15, 8,3)/
     x-1.9916360d-04, 6.1655409d-04,-2.7361216d-07 /
      data fpppp( 4,15, 9,1),fpppp( 4,15, 9,2),fpppp( 4,15, 9,3)/
     x-1.8104203d-04,-3.1834566d-04,-8.2447714d-08 /
      data fpppp( 4,15,10,1),fpppp( 4,15,10,2),fpppp( 4,15,10,3)/
     x 7.3943465d-05,-1.9949357d-04,-1.4995053d-07 /
      data fpppp( 4,15,11,1),fpppp( 4,15,11,2),fpppp( 4,15,11,3)/
     x-2.1054424d-03, 4.0456252d-03, 2.5568936d-07 /
      data fpppp( 4,15,12,1),fpppp( 4,15,12,2),fpppp( 4,15,12,3)/
     x 7.5979846d-03,-5.4158377d-03, 4.5576587d-07 /
      data fpppp( 4,15,13,1),fpppp( 4,15,13,2),fpppp( 4,15,13,3)/
     x 3.0500228d-04, 2.6602099d-03,-3.3738352d-07 /
      data fpppp( 4,15,14,1),fpppp( 4,15,14,2),fpppp( 4,15,14,3)/
     x 4.0618442d-04,-7.0641366d-04, 9.8866717d-08 /
      data fpppp( 4,15,15,1),fpppp( 4,15,15,2),fpppp( 4,15,15,3)/
     x 4.2805493d-03, 2.0202587d-04,-1.6741113d-08 /
      data fpppp( 4,15,16,1),fpppp( 4,15,16,2),fpppp( 4,15,16,3)/
     x 6.3746581d-03,-4.1503165d-05, 1.3282461d-08 /
      data fpppp( 4,15,17,1),fpppp( 4,15,17,2),fpppp( 4,15,17,3)/
     x 8.1411375d-03, 3.5832591d-05, 1.4525986d-08 /
      data fpppp( 4,15,18,1),fpppp( 4,15,18,2),fpppp( 4,15,18,3)/
     x 9.6185275d-03, 2.6539560d-05, 5.0551390d-08 /
      data fpppp( 4,15,19,1),fpppp( 4,15,19,2),fpppp( 4,15,19,3)/
     x 1.0870500d-02, 2.3327371d-05, 4.1048942d-08 /
      data fpppp( 4,15,20,1),fpppp( 4,15,20,2),fpppp( 4,15,20,3)/
     x 2.2153128d-02,-6.1487865d-05,-6.3331646d-08 /
      data fpppp( 4,15,21,1),fpppp( 4,15,21,2),fpppp( 4,15,21,3)/
     x 2.2153128d-02,-5.9761524d-05,-6.1470484d-08 /
      data fpppp( 4,15,22,1),fpppp( 4,15,22,2),fpppp( 4,15,22,3)/
     x 1.0870500d-02, 1.6422006d-05, 3.3604291d-08 /
      data fpppp( 4,15,23,1),fpppp( 4,15,23,2),fpppp( 4,15,23,3)/
     x 9.6185275d-03, 5.2434678d-05, 7.8468830d-08 /
      data fpppp( 4,16, 1,1),fpppp( 4,16, 1,2),fpppp( 4,16, 1,3)/
     x 5.3575853d-04,-8.3714440d-04, 1.1648462d-06 /
      data fpppp( 4,16, 2,1),fpppp( 4,16, 2,2),fpppp( 4,16, 2,3)/
     x-3.0612661d-04,-7.1656254d-04, 3.1963967d-07 /
      data fpppp( 4,16, 3,1),fpppp( 4,16, 3,2),fpppp( 4,16, 3,3)/
     x 4.9056847d-03,-5.5393632d-04,-1.4947118d-06 /
      data fpppp( 4,16, 4,1),fpppp( 4,16, 4,2),fpppp( 4,16, 4,3)/
     x 4.9056847d-03,-3.8635024d-04,-1.4891211d-06 /
      data fpppp( 4,16, 5,1),fpppp( 4,16, 5,2),fpppp( 4,16, 5,3)/
     x-3.0612661d-04,-1.3869068d-03, 2.9727683d-07 /
      data fpppp( 4,16, 6,1),fpppp( 4,16, 6,2),fpppp( 4,16, 6,3)/
     x 5.3575853d-04, 1.6766467d-03, 1.2487068d-06 /
      data fpppp( 4,16, 7,1),fpppp( 4,16, 7,2),fpppp( 4,16, 7,3)/
     x-3.1756164d-05,-1.0848351d-04, 4.3818056d-07 /
      data fpppp( 4,16, 8,1),fpppp( 4,16, 8,2),fpppp( 4,16, 8,3)/
     x-1.5508867d-04,-3.5665871d-06, 5.9241954d-08 /
      data fpppp( 4,16, 9,1),fpppp( 4,16, 9,2),fpppp( 4,16, 9,3)/
     x-1.8243362d-05, 8.5880050d-04, 5.2415203d-08 /
      data fpppp( 4,16,10,1),fpppp( 4,16,10,2),fpppp( 4,16,10,3)/
     x-1.9247214d-04,-3.4180507d-03,-6.8962079d-07 /
      data fpppp( 4,16,11,1),fpppp( 4,16,11,2),fpppp( 4,16,11,3)/
     x 4.9359662d-03, 6.6717729d-03, 1.8016081d-06 /
      data fpppp( 4,16,12,1),fpppp( 4,16,12,2),fpppp( 4,16,12,3)/
     x-1.8018821d-02,-4.2773206d-03,-2.1635219d-06 /
      data fpppp( 4,16,13,1),fpppp( 4,16,13,2),fpppp( 4,16,13,3)/
     x-1.3844842d-03, 8.3277070d-04, 1.4772496d-06 /
      data fpppp( 4,16,14,1),fpppp( 4,16,14,2),fpppp( 4,16,14,3)/
     x-6.7182640d-03,-2.6489848d-04,-3.7215180d-07 /
      data fpppp( 4,16,15,1),fpppp( 4,16,15,2),fpppp( 4,16,15,3)/
     x-1.6116554d-02, 7.0444764d-05, 1.1391930d-07 /
      data fpppp( 4,16,16,1),fpppp( 4,16,16,2),fpppp( 4,16,16,3)/
     x-2.3956364d-02,-1.1529056d-05,-1.7993069d-08 /
      data fpppp( 4,16,17,1),fpppp( 4,16,17,2),fpppp( 4,16,17,3)/
     x-3.0567142d-02, 7.9661782d-06, 1.7550677d-08 /
      data fpppp( 4,16,18,1),fpppp( 4,16,18,2),fpppp( 4,16,18,3)/
     x-3.5951902d-02, 4.6194089d-06, 3.0152807d-09 /
      data fpppp( 4,16,19,1),fpppp( 4,16,19,2),fpppp( 4,16,19,3)/
     x-4.0114017d-02,-9.8729196d-07, 3.4507494d-09 /
      data fpppp( 4,16,20,1),fpppp( 4,16,20,2),fpppp( 4,16,20,3)/
     x-4.5526770d-02,-1.0581897d-05,-2.2654601d-08 /
      data fpppp( 4,16,21,1),fpppp( 4,16,21,2),fpppp( 4,16,21,3)/
     x-4.5526770d-02,-1.0635499d-05,-2.2055647d-08 /
      data fpppp( 4,16,22,1),fpppp( 4,16,22,2),fpppp( 4,16,22,3)/
     x-4.0114017d-02,-7.7288341d-07, 1.0549332d-09 /
      data fpppp( 4,16,23,1),fpppp( 4,16,23,2),fpppp( 4,16,23,3)/
     x-3.5951902d-02, 3.8153768d-06, 1.1999592d-08 /
      data fpppp( 4,17, 1,1),fpppp( 4,17, 1,2),fpppp( 4,17, 1,3)/
     x 8.0865984d-04, 4.1353959d-05, 2.0477003d-07 /
      data fpppp( 4,17, 2,1),fpppp( 4,17, 2,2),fpppp( 4,17, 2,3)/
     x 2.8520072d-03,-9.1104908d-06, 6.0420752d-08 /
      data fpppp( 4,17, 3,1),fpppp( 4,17, 3,2),fpppp( 4,17, 3,3)/
     x 2.2075564d-03,-1.1513251d-04,-2.4257271d-07 /
      data fpppp( 4,17, 4,1),fpppp( 4,17, 4,2),fpppp( 4,17, 4,3)/
     x 2.2075564d-03,-1.1883566d-04,-2.5364395d-07 /
      data fpppp( 4,17, 5,1),fpppp( 4,17, 5,2),fpppp( 4,17, 5,3)/
     x 2.8520072d-03, 5.7021029d-06, 1.0470569d-07 /
      data fpppp( 4,17, 6,1),fpppp( 4,17, 6,2),fpppp( 4,17, 6,3)/
     x 8.0865984d-04,-1.4193267d-05, 3.8701509d-08 /
      data fpppp( 4,17, 7,1),fpppp( 4,17, 7,2),fpppp( 4,17, 7,3)/
     x 5.0095359d-04,-3.4452611d-05, 1.3747551d-07 /
      data fpppp( 4,17, 8,1),fpppp( 4,17, 8,2),fpppp( 4,17, 8,3)/
     x 3.3210165d-04, 2.8523945d-04, 5.7639662d-08 /
      data fpppp( 4,17, 9,1),fpppp( 4,17, 9,2),fpppp( 4,17, 9,3)/
     x 2.7312535d-04,-1.1107682d-03,-1.9549819d-07 /
      data fpppp( 4,17,10,1),fpppp( 4,17,10,2),fpppp( 4,17,10,3)/
     x 4.1526425d-04, 4.2350076d-03, 3.7993874d-07 /
      data fpppp( 4,17,11,1),fpppp( 4,17,11,2),fpppp( 4,17,11,3)/
     x-3.7472007d-03,-1.6570133d-02,-2.5326168d-06 /
      data fpppp( 4,17,12,1),fpppp( 4,17,12,2),fpppp( 4,17,12,3)/
     x 2.8427510d-02, 2.5348883d-02, 4.9775174d-06 /
      data fpppp( 4,17,13,1),fpppp( 4,17,13,2),fpppp( 4,17,13,3)/
     x-4.2542298d-03,-1.2573728d-02,-3.3635016d-06 /
      data fpppp( 4,17,14,1),fpppp( 4,17,14,2),fpppp( 4,17,14,3)/
     x 2.6327692d-02, 7.9052665d-04, 9.6965227d-07 /
      data fpppp( 4,17,15,1),fpppp( 4,17,15,2),fpppp( 4,17,15,3)/
     x 6.0101964d-02,-2.3022292d-04,-2.3265644d-07 /
      data fpppp( 4,17,16,1),fpppp( 4,17,16,2),fpppp( 4,17,16,3)/
     x 8.9400477d-02, 5.8783620d-05, 7.5219412d-08 /
      data fpppp( 4,17,17,1),fpppp( 4,17,17,2),fpppp( 4,17,17,3)/
     x 1.1410773d-01,-1.4926357d-05,-1.6206740d-08 /
      data fpppp( 4,17,18,1),fpppp( 4,17,18,2),fpppp( 4,17,18,3)/
     x 1.3428222d-01, 4.6800896d-06, 2.8100700d-09 /
      data fpppp( 4,17,19,1),fpppp( 4,17,19,2),fpppp( 4,17,19,3)/
     x 1.4990755d-01,-2.1927412d-06,-1.1024226d-08 /
      data fpppp( 4,17,20,1),fpppp( 4,17,20,2),fpppp( 4,17,20,3)/
     x 1.6057816d-01,-7.1142007d-07,-1.0103387d-08 /
      data fpppp( 4,17,21,1),fpppp( 4,17,21,2),fpppp( 4,17,21,3)/
     x 1.6057816d-01,-1.0704761d-06,-1.0780476d-08 /
      data fpppp( 4,17,22,1),fpppp( 4,17,22,2),fpppp( 4,17,22,3)/
     x 1.4990755d-01,-7.5651704d-07,-8.3158676d-09 /
      data fpppp( 4,17,23,1),fpppp( 4,17,23,2),fpppp( 4,17,23,3)/
     x 1.3428222d-01,-7.0575109d-07,-7.3462742d-09 /
      data fpppp( 4,18, 1,1),fpppp( 4,18, 1,2),fpppp( 4,18, 1,3)/
     x-1.1511627d-03,-1.2008778d-05, 9.2277931d-08 /
      data fpppp( 4,18, 2,1),fpppp( 4,18, 2,2),fpppp( 4,18, 2,3)/
     x-1.2904035d-03,-1.3333691d-05, 5.0838906d-08 /
      data fpppp( 4,18, 3,1),fpppp( 4,18, 3,2),fpppp( 4,18, 3,3)/
     x-8.4935658d-04,-1.4975394d-05,-3.8447934d-08 /
      data fpppp( 4,18, 4,1),fpppp( 4,18, 4,2),fpppp( 4,18, 4,3)/
     x-8.4935658d-04,-1.7070838d-05,-3.7592304d-08 /
      data fpppp( 4,18, 5,1),fpppp( 4,18, 5,2),fpppp( 4,18, 5,3)/
     x-1.2904035d-03,-4.9519171d-06, 4.7416387d-08 /
      data fpppp( 4,18, 6,1),fpppp( 4,18, 6,2),fpppp( 4,18, 6,3)/
     x-1.1511627d-03,-4.3440429d-05, 1.0511238d-07 /
      data fpppp( 4,18, 7,1),fpppp( 4,18, 7,2),fpppp( 4,18, 7,3)/
     x-1.2429020d-03, 9.8654597d-05, 2.6980604d-08 /
      data fpppp( 4,18, 8,1),fpppp( 4,18, 8,2),fpppp( 4,18, 8,3)/
     x-1.3181848d-03,-3.0779667d-04,-3.2078563d-08 /
      data fpppp( 4,18, 9,1),fpppp( 4,18, 9,2),fpppp( 4,18, 9,3)/
     x-1.3808832d-03, 1.1002202d-03,-4.2333767d-08 /
      data fpppp( 4,18,10,1),fpppp( 4,18,10,2),fpppp( 4,18,10,3)/
     x-1.6244055d-03,-3.6397578d-03,-2.2681083d-07 /
      data fpppp( 4,18,11,1),fpppp( 4,18,11,2),fpppp( 4,18,11,3)/
     x 4.3243694d-04, 8.5033152d-03, 3.4283711d-07 /
      data fpppp( 4,18,12,1),fpppp( 4,18,12,2),fpppp( 4,18,12,3)/
     x-1.2449948d-02,-2.0432257d-02,-2.0218630d-06 /
      data fpppp( 4,18,13,1),fpppp( 4,18,13,2),fpppp( 4,18,13,3)/
     x 7.3448168d-03, 4.0174271d-02, 2.4578803d-06 /
      data fpppp( 4,18,14,1),fpppp( 4,18,14,2),fpppp( 4,18,14,3)/
     x-2.9191764d-02,-1.2609511d-02,-6.8455633d-07 /
      data fpppp( 4,18,15,1),fpppp( 4,18,15,2),fpppp( 4,18,15,3)/
     x-6.4663114d-02, 9.0658739d-04, 1.8017901d-07 /
      data fpppp( 4,18,16,1),fpppp( 4,18,16,2),fpppp( 4,18,16,3)/
     x-9.5478501d-02,-2.8539505d-03,-5.0355661d-08 /
      data fpppp( 4,18,17,1),fpppp( 4,18,17,2),fpppp( 4,18,17,3)/
     x-1.2145334d-01,-1.8385557d-03, 7.4880779d-09 /
      data fpppp( 4,18,18,1),fpppp( 4,18,18,2),fpppp( 4,18,18,3)/
     x-1.4265922d-01,-1.9453587d-03,-1.4191657d-08 /
      data fpppp( 4,18,19,1),fpppp( 4,18,19,2),fpppp( 4,18,19,3)/
     x-1.5907619d-01,-2.5873409d-03,-1.1981256d-08 /
      data fpppp( 4,18,20,1),fpppp( 4,18,20,2),fpppp( 4,18,20,3)/
     x-1.6971071d-01,-2.9920335d-03,-1.8086115d-08 /
      data fpppp( 4,18,21,1),fpppp( 4,18,21,2),fpppp( 4,18,21,3)/
     x-1.6971071d-01,-3.0135426d-03,-1.7845957d-08 /
      data fpppp( 4,18,22,1),fpppp( 4,18,22,2),fpppp( 4,18,22,3)/
     x-1.5907619d-01,-2.5013044d-03,-1.2941889d-08 /
      data fpppp( 4,18,23,1),fpppp( 4,18,23,2),fpppp( 4,18,23,3)/
     x-1.4265922d-01,-2.2679956d-03,-1.0589282d-08 /
      data fpppp( 4,19, 1,1),fpppp( 4,19, 1,2),fpppp( 4,19, 1,3)/
     x-2.4730641d-03,-3.9115894d-18,-2.6238103d-07 /
      data fpppp( 4,19, 2,1),fpppp( 4,19, 2,2),fpppp( 4,19, 2,3)/
     x-3.3469443d-03, 1.3173510d-17,-3.0067818d-08 /
      data fpppp( 4,19, 3,1),fpppp( 4,19, 3,2),fpppp( 4,19, 3,3)/
     x-3.8037597d-03,-3.5833330d-18, 4.6510949d-07 /
      data fpppp( 4,19, 4,1),fpppp( 4,19, 4,2),fpppp( 4,19, 4,3)/
     x-3.8037597d-03, 8.1730102d-18, 4.6972376d-07 /
      data fpppp( 4,19, 5,1),fpppp( 4,19, 5,2),fpppp( 4,19, 5,3)/
     x-3.3469443d-03,-1.5512629d-17,-4.8524872d-08 /
      data fpppp( 4,19, 6,1),fpppp( 4,19, 6,2),fpppp( 4,19, 6,3)/
     x-2.4730641d-03, 6.1184397d-18,-1.9316708d-07 /
      data fpppp( 4,19, 7,1),fpppp( 4,19, 7,2),fpppp( 4,19, 7,3)/
     x-2.3363103d-03,-1.4808716d-17,-1.3786006d-07 /
      data fpppp( 4,19, 8,1),fpppp( 4,19, 8,2),fpppp( 4,19, 8,3)/
     x-2.3577636d-03, 2.6478186d-17,-9.6620808d-08 /
      data fpppp( 4,19, 9,1),fpppp( 4,19, 9,2),fpppp( 4,19, 9,3)/
     x-2.4790696d-03,-2.4023831d-17,-3.7630035d-09 /
      data fpppp( 4,19,10,1),fpppp( 4,19,10,2),fpppp( 4,19,10,3)/
     x-2.9076735d-03, 6.0504280d-17,-3.5461495d-07 /
      data fpppp( 4,19,11,1),fpppp( 4,19,11,2),fpppp( 4,19,11,3)/
     x 9.3698757d-04,-3.9156730d-17, 1.1583828d-06 /
      data fpppp( 4,19,12,1),fpppp( 4,19,12,2),fpppp( 4,19,12,3)/
     x-2.8377751d-02, 4.2267252d-17,-4.9811235d-06 /
      data fpppp( 4,19,13,1),fpppp( 4,19,13,2),fpppp( 4,19,13,3)/
     x 1.4809923d-02,-3.7781813d-17, 5.2329385d-06 /
      data fpppp( 4,19,14,1),fpppp( 4,19,14,2),fpppp( 4,19,14,3)/
     x-5.9406817d-02,-1.4418963d-18,-1.4827613d-06 /
      data fpppp( 4,19,15,1),fpppp( 4,19,15,2),fpppp( 4,19,15,3)/
     x-1.3200431d-01,-5.3639874d-17, 3.7603983d-07 /
      data fpppp( 4,19,16,1),fpppp( 4,19,16,2),fpppp( 4,19,16,3)/
     x-1.9514725d-01, 2.3995833d-17,-1.1342000d-07 /
      data fpppp( 4,19,17,1),fpppp( 4,19,17,2),fpppp( 4,19,17,3)/
     x-2.4837558d-01, 4.9686593d-17, 1.4767972d-08 /
      data fpppp( 4,19,18,1),fpppp( 4,19,18,2),fpppp( 4,19,18,3)/
     x-2.9183621d-01, 8.5321890d-18,-2.6394379d-08 /
      data fpppp( 4,19,19,1),fpppp( 4,19,19,2),fpppp( 4,19,19,3)/
     x-3.2548699d-01, 2.1400687d-18,-1.6800556d-08 /
      data fpppp( 4,19,20,1),fpppp( 4,19,20,2),fpppp( 4,19,20,3)/
     x-3.4674420d-01, 5.9944734d-18,-2.0202002d-08 /
      data fpppp( 4,19,21,1),fpppp( 4,19,21,2),fpppp( 4,19,21,3)/
     x-3.4674420d-01,-1.3844543d-17,-1.9671251d-08 /
      data fpppp( 4,19,22,1),fpppp( 4,19,22,2),fpppp( 4,19,22,3)/
     x-3.2548699d-01,-5.0431920d-18,-1.8923562d-08 /
      data fpppp( 4,19,23,1),fpppp( 4,19,23,2),fpppp( 4,19,23,3)/
     x-2.9183621d-01,-1.8550722d-17,-1.8433106d-08 /
      data fpppp( 5, 1, 1,1),fpppp( 5, 1, 1,2),fpppp( 5, 1, 1,3)/
     x-2.0982094d-03, 7.3716336d-16, 1.8441735d-05 /
      data fpppp( 5, 1, 2,1),fpppp( 5, 1, 2,2),fpppp( 5, 1, 2,3)/
     x 3.1163240d-03,-8.5144264d-17, 1.0477364d-05 /
      data fpppp( 5, 1, 3,1),fpppp( 5, 1, 3,2),fpppp( 5, 1, 3,3)/
     x 4.8710034d-03,-9.6476362d-17,-5.5231946d-06 /
      data fpppp( 5, 1, 4,1),fpppp( 5, 1, 4,2),fpppp( 5, 1, 4,3)/
     x 4.8710034d-03,-1.4618829d-16,-7.3886079d-06 /
      data fpppp( 5, 1, 5,1),fpppp( 5, 1, 5,2),fpppp( 5, 1, 5,3)/
     x 3.1163240d-03, 1.6840939d-16, 1.7939018d-05 /
      data fpppp( 5, 1, 6,1),fpppp( 5, 1, 6,2),fpppp( 5, 1, 6,3)/
     x-2.0982094d-03,-6.0552282d-17,-9.5394650d-06 /
      data fpppp( 5, 1, 7,1),fpppp( 5, 1, 7,2),fpppp( 5, 1, 7,3)/
     x-2.3419021d-02, 2.1141930d-16,-1.8558285d-05 /
      data fpppp( 5, 1, 8,1),fpppp( 5, 1, 8,2),fpppp( 5, 1, 8,3)/
     x 2.2119779d-02,-5.2575488d-16, 1.3529050d-05 /
      data fpppp( 5, 1, 9,1),fpppp( 5, 1, 9,2),fpppp( 5, 1, 9,3)/
     x 1.6835374d-02, 2.7752112d-17, 1.8850738d-06 /
      data fpppp( 5, 1,10,1),fpppp( 5, 1,10,2),fpppp( 5, 1,10,3)/
     x 2.8657949d-02,-1.1187700d-17, 2.4821382d-06 /
      data fpppp( 5, 1,11,1),fpppp( 5, 1,11,2),fpppp( 5, 1,11,3)/
     x 3.3229185d-02,-2.0508976d-16, 1.4526396d-06 /
      data fpppp( 5, 1,12,1),fpppp( 5, 1,12,2),fpppp( 5, 1,12,3)/
     x 4.3756574d-02, 1.9260473d-16, 2.6182473d-06 /
      data fpppp( 5, 1,13,1),fpppp( 5, 1,13,2),fpppp( 5, 1,13,3)/
     x 3.2018235d-02, 9.3587695d-17, 1.4509102d-06 /
      data fpppp( 5, 1,14,1),fpppp( 5, 1,14,2),fpppp( 5, 1,14,3)/
     x 2.4033477d-02, 4.8909686d-17, 2.5830943d-06 /
      data fpppp( 5, 1,15,1),fpppp( 5, 1,15,2),fpppp( 5, 1,15,3)/
     x 1.5723423d-02, 4.8068285d-18, 1.6506469d-06 /
      data fpppp( 5, 1,16,1),fpppp( 5, 1,16,2),fpppp( 5, 1,16,3)/
     x 2.1369297d-02,-4.7261926d-16, 1.4222602d-05 /
      data fpppp( 5, 1,17,1),fpppp( 5, 1,17,2),fpppp( 5, 1,17,3)/
     x-4.5882587d-02, 1.7302581d-17,-2.0653962d-05 /
      data fpppp( 5, 1,18,1),fpppp( 5, 1,18,2),fpppp( 5, 1,18,3)/
     x-2.0505411d-03, 1.3616666d-16,-7.2859497d-06 /
      data fpppp( 5, 1,19,1),fpppp( 5, 1,19,2),fpppp( 5, 1,19,3)/
     x 8.8281131d-04,-2.1835847d-16, 1.6782867d-05 /
      data fpppp( 5, 1,20,1),fpppp( 5, 1,20,2),fpppp( 5, 1,20,3)/
     x 4.6786047d-03,-4.9626271d-17,-7.1031518d-06 /
      data fpppp( 5, 1,21,1),fpppp( 5, 1,21,2),fpppp( 5, 1,21,3)/
     x 4.6786047d-03,-1.8360115d-17,-5.4315240d-06 /
      data fpppp( 5, 1,22,1),fpppp( 5, 1,22,2),fpppp( 5, 1,22,3)/
     x 8.8281131d-04, 1.1711788d-16, 1.0096356d-05 /
      data fpppp( 5, 1,23,1),fpppp( 5, 1,23,2),fpppp( 5, 1,23,3)/
     x-2.0505411d-03,-9.9451257d-16, 1.7788468d-05 /
      data fpppp( 5, 2, 1,1),fpppp( 5, 2, 1,2),fpppp( 5, 2, 1,3)/
     x-1.6731462d-04, 2.5035014d-03, 1.0332286d-05 /
      data fpppp( 5, 2, 2,1),fpppp( 5, 2, 2,2),fpppp( 5, 2, 2,3)/
     x 2.3762422d-03, 1.5009345d-03, 5.9619494d-06 /
      data fpppp( 5, 2, 3,1),fpppp( 5, 2, 3,2),fpppp( 5, 2, 3,3)/
     x 2.2401166d-03,-5.1448245d-04,-2.8217982d-06 /
      data fpppp( 5, 2, 4,1),fpppp( 5, 2, 4,2),fpppp( 5, 2, 4,3)/
     x 2.2401166d-03,-7.4712874d-04,-3.8390008d-06 /
      data fpppp( 5, 2, 5,1),fpppp( 5, 2, 5,2),fpppp( 5, 2, 5,3)/
     x 2.3762422d-03, 2.4315196d-03, 1.0030760d-05 /
      data fpppp( 5, 2, 6,1),fpppp( 5, 2, 6,2),fpppp( 5, 2, 6,3)/
     x-1.6731462d-04,-9.8619295d-04,-4.9257526d-06 /
      data fpppp( 5, 2, 7,1),fpppp( 5, 2, 7,2),fpppp( 5, 2, 7,3)/
     x-9.5513142d-03, 2.2909347d-04,-8.4416945d-06 /
      data fpppp( 5, 2, 8,1),fpppp( 5, 2, 8,2),fpppp( 5, 2, 8,3)/
     x 9.8061058d-03,-2.3251788d-03, 5.7701612d-06 /
      data fpppp( 5, 2, 9,1),fpppp( 5, 2, 9,2),fpppp( 5, 2, 9,3)/
     x 7.6527969d-03, 9.4218281d-04, 7.2401145d-07 /
      data fpppp( 5, 2,10,1),fpppp( 5, 2,10,2),fpppp( 5, 2,10,3)/
     x 1.3226431d-02,-4.2826867d-04, 1.0834661d-06 /
      data fpppp( 5, 2,11,1),fpppp( 5, 2,11,2),fpppp( 5, 2,11,3)/
     x 1.5604209d-02, 1.3914351d-03, 6.4135165d-07 /
      data fpppp( 5, 2,12,1),fpppp( 5, 2,12,2),fpppp( 5, 2,12,3)/
     x 1.9846683d-02,-9.6289531d-04, 1.0885994d-06 /
      data fpppp( 5, 2,13,1),fpppp( 5, 2,13,2),fpppp( 5, 2,13,3)/
     x 1.5125022d-02, 4.1241256d-03, 6.5093251d-07 /
      data fpppp( 5, 2,14,1),fpppp( 5, 2,14,2),fpppp( 5, 2,14,3)/
     x 1.1001357d-02,-4.6872962d-03, 1.0878858d-06 /
      data fpppp( 5, 2,15,1),fpppp( 5, 2,15,2),fpppp( 5, 2,15,3)/
     x 7.1461043d-03, 4.3298103d-03, 7.9911596d-07 /
      data fpppp( 5, 2,16,1),fpppp( 5, 2,16,2),fpppp( 5, 2,16,3)/
     x 8.4883360d-03,-3.7351211d-03, 5.7946830d-06 /
      data fpppp( 5, 2,17,1),fpppp( 5, 2,17,2),fpppp( 5, 2,17,3)/
     x-1.9162564d-02,-9.4879043d-04,-9.0448132d-06 /
      data fpppp( 5, 2,18,1),fpppp( 5, 2,18,2),fpppp( 5, 2,18,3)/
     x 1.1031904d-04, 1.4607685d-03,-4.1012819d-06 /
      data fpppp( 5, 2,19,1),fpppp( 5, 2,19,2),fpppp( 5, 2,19,3)/
     x 1.2437755d-03, 4.4066860d-04, 9.5244666d-06 /
      data fpppp( 5, 2,20,1),fpppp( 5, 2,20,2),fpppp( 5, 2,20,3)/
     x 2.3780404d-03,-1.4727774d-04,-3.7172206d-06 /
      data fpppp( 5, 2,21,1),fpppp( 5, 2,21,2),fpppp( 5, 2,21,3)/
     x 2.3780404d-03,-1.8267608d-04,-2.7771002d-06 /
      data fpppp( 5, 2,22,1),fpppp( 5, 2,22,2),fpppp( 5, 2,22,3)/
     x 1.2437755d-03, 5.8226195d-04, 5.7639851d-06 /
      data fpppp( 5, 2,23,1),fpppp( 5, 2,23,2),fpppp( 5, 2,23,3)/
     x 1.1031904d-04, 9.2979347d-04, 1.0000524d-05 /
      data fpppp( 5, 3, 1,1),fpppp( 5, 3, 1,2),fpppp( 5, 3, 1,3)/
     x 4.1893872d-03, 3.2860367d-03,-4.2206131d-05 /
      data fpppp( 5, 3, 2,1),fpppp( 5, 3, 2,2),fpppp( 5, 3, 2,3)/
     x-7.7470387d-04, 1.6467636d-03,-2.6177015d-05 /
      data fpppp( 5, 3, 3,1),fpppp( 5, 3, 3,2),fpppp( 5, 3, 3,3)/
     x 1.3112629d-03,-1.0161040d-03, 5.7188124d-06 /
      data fpppp( 5, 3, 4,1),fpppp( 5, 3, 4,2),fpppp( 5, 3, 4,3)/
     x 1.3112629d-03,-2.5033595d-03, 1.0010303d-05 /
      data fpppp( 5, 3, 5,1),fpppp( 5, 3, 5,2),fpppp( 5, 3, 5,3)/
     x-7.7470387d-04, 7.5957857d-03,-4.3342976d-05 /
      data fpppp( 5, 3, 6,1),fpppp( 5, 3, 6,2),fpppp( 5, 3, 6,3)/
     x 4.1893872d-03,-1.9022796d-02, 2.2166226d-05 /
      data fpppp( 5, 3, 7,1),fpppp( 5, 3, 7,2),fpppp( 5, 3, 7,3)/
     x 2.7250211d-02, 4.0555765d-02, 2.5295783d-05 /
      data fpppp( 5, 3, 8,1),fpppp( 5, 3, 8,2),fpppp( 5, 3, 8,3)/
     x-2.1472356d-02,-3.7948363d-02,-1.3082405d-05 /
      data fpppp( 5, 3, 9,1),fpppp( 5, 3, 9,2),fpppp( 5, 3, 9,3)/
     x-9.8056668d-03, 1.8501946d-02,-5.6840004d-07 /
      data fpppp( 5, 3,10,1),fpppp( 5, 3,10,2),fpppp( 5, 3,10,3)/
     x-2.2197174d-02,-1.0072298d-02,-2.1581709d-06 /
      data fpppp( 5, 3,11,1),fpppp( 5, 3,11,2),fpppp( 5, 3,11,3)/
     x-2.6404290d-02, 1.1177959d-02,-1.0716924d-06 /
      data fpppp( 5, 3,12,1),fpppp( 5, 3,12,2),fpppp( 5, 3,12,3)/
     x-3.3584500d-02,-1.5848541d-02,-1.7489319d-06 /
      data fpppp( 5, 3,13,1),fpppp( 5, 3,13,2),fpppp( 5, 3,13,3)/
     x-2.4994249d-02, 1.3192356d-02,-1.0729666d-06 /
      data fpppp( 5, 3,14,1),fpppp( 5, 3,14,2),fpppp( 5, 3,14,3)/
     x-2.0236137d-02,-1.2914834d-02,-2.1326051d-06 /
      data fpppp( 5, 3,15,1),fpppp( 5, 3,15,2),fpppp( 5, 3,15,3)/
     x-9.1843544d-03, 2.4918503d-02,-8.2135349d-07 /
      data fpppp( 5, 3,16,1),fpppp( 5, 3,16,2),fpppp( 5, 3,16,3)/
     x-2.0152795d-02,-5.6239887d-02,-1.2883755d-05 /
      data fpppp( 5, 3,17,1),fpppp( 5, 3,17,2),fpppp( 5, 3,17,3)/
     x 4.7373967d-02, 6.6547033d-02, 2.6798703d-05 /
      data fpppp( 5, 3,18,1),fpppp( 5, 3,18,2),fpppp( 5, 3,18,3)/
     x 3.4128723d-03,-3.4796068d-02, 1.9682986d-05 /
      data fpppp( 5, 3,19,1),fpppp( 5, 3,19,2),fpppp( 5, 3,19,3)/
     x 1.2665899d-03, 1.1665557d-02,-4.1906139d-05 /
      data fpppp( 5, 3,20,1),fpppp( 5, 3,20,2),fpppp( 5, 3,20,3)/
     x 7.0297273d-04,-3.2654885d-03, 9.7444256d-06 /
      data fpppp( 5, 3,21,1),fpppp( 5, 3,21,2),fpppp( 5, 3,21,3)/
     x 7.0297273d-04,-7.2928063d-04, 5.6767331d-06 /
      data fpppp( 5, 3,22,1),fpppp( 5, 3,22,2),fpppp( 5, 3,22,3)/
     x 1.2665899d-03, 1.5207252d-03,-2.5635369d-05 /
      data fpppp( 5, 3,23,1),fpppp( 5, 3,23,2),fpppp( 5, 3,23,3)/
     x 3.4128723d-03, 3.2470500d-03,-4.1332401d-05 /
      data fpppp( 5, 4, 1,1),fpppp( 5, 4, 1,2),fpppp( 5, 4, 1,3)/
     x 5.5764433d-05, 6.9437445d-03, 6.0756837d-05 /
      data fpppp( 5, 4, 2,1),fpppp( 5, 4, 2,2),fpppp( 5, 4, 2,3)/
     x 4.5123751d-03, 3.9616669d-03, 3.8366443d-05 /
      data fpppp( 5, 4, 3,1),fpppp( 5, 4, 3,2),fpppp( 5, 4, 3,3)/
     x-5.5747064d-03,-2.0923376d-03,-6.1778268d-06 /
      data fpppp( 5, 4, 4,1),fpppp( 5, 4, 4,2),fpppp( 5, 4, 4,3)/
     x-5.5747064d-03,-2.6806210d-03,-1.2189331d-05 /
      data fpppp( 5, 4, 5,1),fpppp( 5, 4, 5,2),fpppp( 5, 4, 5,3)/
     x 4.5123751d-03, 6.3148005d-03, 6.2412460d-05 /
      data fpppp( 5, 4, 6,1),fpppp( 5, 4, 6,2),fpppp( 5, 4, 6,3)/
     x 5.5764433d-05,-1.8805066d-03,-2.9415727d-05 /
      data fpppp( 5, 4, 7,1),fpppp( 5, 4, 7,2),fpppp( 5, 4, 7,3)/
     x-1.6216628d-02, 3.4282507d-04,-2.3639844d-05 /
      data fpppp( 5, 4, 8,1),fpppp( 5, 4, 8,2),fpppp( 5, 4, 8,3)/
     x 1.3625943d-02, 1.1308249d-03, 6.8928993d-06 /
      data fpppp( 5, 4, 9,1),fpppp( 5, 4, 9,2),fpppp( 5, 4, 9,3)/
     x 1.7014724d-03,-3.9289089d-03,-1.4010894d-06 /
      data fpppp( 5, 4,10,1),fpppp( 5, 4,10,2),fpppp( 5, 4,10,3)/
     x 1.2351526d-02,-3.8754516d-04, 1.0505692d-06 /
      data fpppp( 5, 4,11,1),fpppp( 5, 4,11,2),fpppp( 5, 4,11,3)/
     x 1.6929539d-02, 7.1096371d-03, 3.7140988d-07 /
      data fpppp( 5, 4,12,1),fpppp( 5, 4,12,2),fpppp( 5, 4,12,3)/
     x 1.6308837d-02,-9.8699824d-03,-8.8711177d-09 /
      data fpppp( 5, 4,13,1),fpppp( 5, 4,13,2),fpppp( 5, 4,13,3)/
     x 1.6177685d-02, 7.2658810d-03, 4.3685926d-07 /
      data fpppp( 5, 4,14,1),fpppp( 5, 4,14,2),fpppp( 5, 4,14,3)/
     x 1.2245178d-02,-5.5967408d-04, 6.8539233d-07 /
      data fpppp( 5, 4,15,1),fpppp( 5, 4,15,2),fpppp( 5, 4,15,3)/
     x 1.6211762d-03,-3.0772879d-03, 2.4946187d-07 /
      data fpppp( 5, 4,16,1),fpppp( 5, 4,16,2),fpppp( 5, 4,16,3)/
     x 6.3666693d-03,-2.5033284d-03, 4.3146244d-06 /
      data fpppp( 5, 4,17,1),fpppp( 5, 4,17,2),fpppp( 5, 4,17,3)/
     x-2.5447279d-02, 6.0902784d-03,-2.2178068d-05 /
      data fpppp( 5, 4,18,1),fpppp( 5, 4,18,2),fpppp( 5, 4,18,3)/
     x 2.7194996d-03,-4.5308322d-03,-2.8631347d-05 /
      data fpppp( 5, 4,19,1),fpppp( 5, 4,19,2),fpppp( 5, 4,19,3)/
     x 2.4729286d-03, 5.4612053d-03, 6.1265972d-05 /
      data fpppp( 5, 4,20,1),fpppp( 5, 4,20,2),fpppp( 5, 4,20,3)/
     x-3.1613332d-03,-2.2450360d-03,-1.2058931d-05 /
      data fpppp( 5, 4,21,1),fpppp( 5, 4,21,2),fpppp( 5, 4,21,3)/
     x-3.1613332d-03,-1.6000225d-03,-6.1673671d-06 /
      data fpppp( 5, 4,22,1),fpppp( 5, 4,22,2),fpppp( 5, 4,22,3)/
     x 2.4729286d-03, 2.8811515d-03, 3.7699718d-05 /
      data fpppp( 5, 4,23,1),fpppp( 5, 4,23,2),fpppp( 5, 4,23,3)/
     x 2.7194996d-03, 5.1443696d-03, 5.9742108d-05 /
      data fpppp( 5, 5, 1,1),fpppp( 5, 5, 1,2),fpppp( 5, 5, 1,3)/
     x-7.1662152d-04,-2.9517982d-04,-4.2080069d-05 /
      data fpppp( 5, 5, 2,1),fpppp( 5, 5, 2,2),fpppp( 5, 5, 2,3)/
     x-2.5218916d-03,-6.8608757d-05,-2.5449536d-05 /
      data fpppp( 5, 5, 3,1),fpppp( 5, 5, 3,2),fpppp( 5, 5, 3,3)/
     x 1.4090687d-02, 4.0191441d-04, 8.0648542d-06 /
      data fpppp( 5, 5, 4,1),fpppp( 5, 5, 4,2),fpppp( 5, 5, 4,3)/
     x 1.4090687d-02, 4.2814037d-04, 1.1779171d-05 /
      data fpppp( 5, 5, 5,1),fpppp( 5, 5, 5,2),fpppp( 5, 5, 5,3)/
     x-2.5218916d-03,-1.7351260d-04,-4.0306805d-05 /
      data fpppp( 5, 5, 6,1),fpppp( 5, 5, 6,2),fpppp( 5, 5, 6,3)/
     x-7.1662152d-04, 9.8209598d-05, 1.3634691d-05 /
      data fpppp( 5, 5, 7,1),fpppp( 5, 5, 7,2),fpppp( 5, 5, 7,3)/
     x 3.7694392d-03,-4.9409864d-04, 1.1240372d-05 /
      data fpppp( 5, 5, 8,1),fpppp( 5, 5, 8,2),fpppp( 5, 5, 8,3)/
     x-2.3619263d-03,-7.1443255d-05,-1.6149245d-06 /
      data fpppp( 5, 5, 9,1),fpppp( 5, 5, 9,2),fpppp( 5, 5, 9,3)/
     x 2.8676171d-03, 7.2045743d-05, 1.1879063d-06 /
      data fpppp( 5, 5,10,1),fpppp( 5, 5,10,2),fpppp( 5, 5,10,3)/
     x-2.0430240d-03,-4.8859539d-05,-4.7904769d-07 /
      data fpppp( 5, 5,11,1),fpppp( 5, 5,11,2),fpppp( 5, 5,11,3)/
     x-4.8712551d-03,-2.7588023d-05,-2.8316881d-07 /
      data fpppp( 5, 5,12,1),fpppp( 5, 5,12,2),fpppp( 5, 5,12,3)/
     x-1.5170359d-03, 1.4474999d-04, 3.5828488d-07 /
      data fpppp( 5, 5,13,1),fpppp( 5, 5,13,2),fpppp( 5, 5,13,3)/
     x-4.8701849d-03,-7.1509080d-04,-4.2836270d-07 /
      data fpppp( 5, 5,14,1),fpppp( 5, 5,14,2),fpppp( 5, 5,14,3)/
     x-2.5371873d-03, 2.6258873d-03, 2.0605638d-07 /
      data fpppp( 5, 5,15,1),fpppp( 5, 5,15,2),fpppp( 5, 5,15,3)/
     x 2.7845063d-03,-9.8238012d-03,-1.6627241d-06 /
      data fpppp( 5, 5,16,1),fpppp( 5, 5,16,2),fpppp( 5, 5,16,3)/
     x 8.2729965d-03, 1.5030271d-02, 3.1772374d-06 /
      data fpppp( 5, 5,17,1),fpppp( 5, 5,17,2),fpppp( 5, 5,17,3)/
     x 4.5141950d-03,-7.7937725d-03, 6.5342399d-06 /
      data fpppp( 5, 5,18,1),fpppp( 5, 5,18,2),fpppp( 5, 5,18,3)/
     x-4.5220658d-03,-1.1958600d-03, 1.7075617d-05 /
      data fpppp( 5, 5,19,1),fpppp( 5, 5,19,2),fpppp( 5, 5,19,3)/
     x-9.8519077d-04, 1.1397546d-03,-3.9192563d-05 /
      data fpppp( 5, 5,20,1),fpppp( 5, 5,20,2),fpppp( 5, 5,20,3)/
     x 4.7170447d-03, 3.7133993d-04, 1.0251970d-05 /
      data fpppp( 5, 5,21,1),fpppp( 5, 5,21,2),fpppp( 5, 5,21,3)/
     x 4.7170447d-03, 4.9922956d-04, 6.4857222d-06 /
      data fpppp( 5, 5,22,1),fpppp( 5, 5,22,2),fpppp( 5, 5,22,3)/
     x-9.8519077d-04, 6.2819610d-04,-2.4127570d-05 /
      data fpppp( 5, 5,23,1),fpppp( 5, 5,23,2),fpppp( 5, 5,23,3)/
     x-4.5220658d-03, 7.2248439d-04,-3.9418106d-05 /
      data fpppp( 5, 6, 1,1),fpppp( 5, 6, 1,2),fpppp( 5, 6, 1,3)/
     x 1.7998005d-03, 3.6894296d-06, 1.5573291d-05 /
      data fpppp( 5, 6, 2,1),fpppp( 5, 6, 2,2),fpppp( 5, 6, 2,3)/
     x 4.2119352d-03,-6.2363348d-06, 8.7262023d-06 /
      data fpppp( 5, 6, 3,1),fpppp( 5, 6, 3,2),fpppp( 5, 6, 3,3)/
     x-3.1528771d-02,-3.7356419d-05,-5.3700562d-06 /
      data fpppp( 5, 6, 4,1),fpppp( 5, 6, 4,2),fpppp( 5, 6, 4,3)/
     x-3.1528771d-02,-2.0117888d-05,-6.3781875d-06 /
      data fpppp( 5, 6, 5,1),fpppp( 5, 6, 5,2),fpppp( 5, 6, 5,3)/
     x 4.2119352d-03,-7.5190461d-05, 1.2758727d-05 /
      data fpppp( 5, 6, 6,1),fpppp( 5, 6, 6,2),fpppp( 5, 6, 6,3)/
     x 1.7998005d-03, 2.6226740d-04, 4.5132231d-07 /
      data fpppp( 5, 6, 7,1),fpppp( 5, 6, 7,2),fpppp( 5, 6, 7,3)/
     x 1.0483136d-03,-9.0995612d-05,-4.6626515d-06 /
      data fpppp( 5, 6, 8,1),fpppp( 5, 6, 8,2),fpppp( 5, 6, 8,3)/
     x 1.0614590d-03,-9.2691335d-06, 1.0608665d-06 /
      data fpppp( 5, 6, 9,1),fpppp( 5, 6, 9,2),fpppp( 5, 6, 9,3)/
     x-3.7158870d-04, 5.6064679d-06,-5.4855999d-07 /
      data fpppp( 5, 6,10,1),fpppp( 5, 6,10,2),fpppp( 5, 6,10,3)/
     x 8.8214806d-04,-4.4701394d-06, 1.4409083d-07 /
      data fpppp( 5, 6,11,1),fpppp( 5, 6,11,2),fpppp( 5, 6,11,3)/
     x 1.6706876d-03,-1.2783257d-04, 5.5572351d-08 /
      data fpppp( 5, 6,12,1),fpppp( 5, 6,12,2),fpppp( 5, 6,12,3)/
     x 8.5693521d-04, 2.3465039d-04,-1.1016567d-07 /
      data fpppp( 5, 6,13,1),fpppp( 5, 6,13,2),fpppp( 5, 6,13,3)/
     x 1.7008817d-03,-7.1593821d-04, 1.5199368d-07 /
      data fpppp( 5, 6,14,1),fpppp( 5, 6,14,2),fpppp( 5, 6,14,3)/
     x 1.5867967d-03, 1.8009826d-03,-3.0028905d-07 /
      data fpppp( 5, 6,15,1),fpppp( 5, 6,15,2),fpppp( 5, 6,15,3)/
     x-3.4684327d-04,-5.0648401d-03, 1.3840771d-06 /
      data fpppp( 5, 6,16,1),fpppp( 5, 6,16,2),fpppp( 5, 6,16,3)/
     x-1.3757593d-03, 7.4938437d-03,-2.4301933d-06 /
      data fpppp( 5, 6,17,1),fpppp( 5, 6,17,2),fpppp( 5, 6,17,3)/
     x-7.4850155d-04,-4.7956252d-03,-5.3225635d-07 /
      data fpppp( 5, 6,18,1),fpppp( 5, 6,18,2),fpppp( 5, 6,18,3)/
     x 2.7241225d-03, 1.3966023d-03,-4.4310411d-06 /
      data fpppp( 5, 6,19,1),fpppp( 5, 6,19,2),fpppp( 5, 6,19,3)/
     x 2.7305995d-04,-1.1383470d-03, 1.0964811d-05 /
      data fpppp( 5, 6,20,1),fpppp( 5, 6,20,2),fpppp( 5, 6,20,3)/
     x-3.9690910d-04, 6.1167381d-04,-3.3830774d-06 /
      data fpppp( 5, 6,21,1),fpppp( 5, 6,21,2),fpppp( 5, 6,21,3)/
     x-3.9690910d-04, 4.5257766d-04,-2.3344286d-06 /
      data fpppp( 5, 6,22,1),fpppp( 5, 6,22,2),fpppp( 5, 6,22,3)/
     x 2.7305995d-04,-5.0196239d-04, 6.7702160d-06 /
      data fpppp( 5, 6,23,1),fpppp( 5, 6,23,2),fpppp( 5, 6,23,3)/
     x 2.7241225d-03,-9.8984005d-04, 1.1298690d-05 /
      data fpppp( 5, 7, 1,1),fpppp( 5, 7, 1,2),fpppp( 5, 7, 1,3)/
     x-6.9800143d-03,-2.9878981d-02,-8.4730345d-06 /
      data fpppp( 5, 7, 2,1),fpppp( 5, 7, 2,2),fpppp( 5, 7, 2,3)/
     x-5.2942966d-03,-1.6553747d-02,-4.4626668d-06 /
      data fpppp( 5, 7, 3,1),fpppp( 5, 7, 3,2),fpppp( 5, 7, 3,3)/
     x 4.4881887d-02, 1.0441397d-02, 3.9482026d-06 /
      data fpppp( 5, 7, 4,1),fpppp( 5, 7, 4,2),fpppp( 5, 7, 4,3)/
     x 4.4881887d-02, 1.3169524d-02, 4.2680598d-06 /
      data fpppp( 5, 7, 5,1),fpppp( 5, 7, 5,2),fpppp( 5, 7, 5,3)/
     x-5.2942966d-03,-2.7466254d-02,-5.7420959d-06 /
      data fpppp( 5, 7, 6,1),fpppp( 5, 7, 6,2),fpppp( 5, 7, 6,3)/
     x-6.9800143d-03, 1.1042922d-02,-3.6751755d-06 /
      data fpppp( 5, 7, 7,1),fpppp( 5, 7, 7,2),fpppp( 5, 7, 7,3)/
     x-6.2954955d-03,-2.9712737d-03, 4.4877264d-06 /
      data fpppp( 5, 7, 8,1),fpppp( 5, 7, 8,2),fpppp( 5, 7, 8,3)/
     x 8.9353700d-05, 7.1126548d-04,-1.7579565d-06 /
      data fpppp( 5, 7, 9,1),fpppp( 5, 7, 9,2),fpppp( 5, 7, 9,3)/
     x 1.6529331d-04,-1.4366617d-04, 4.8286160d-07 /
      data fpppp( 5, 7,10,1),fpppp( 5, 7,10,2),fpppp( 5, 7,10,3)/
     x-7.5898353d-05, 2.7140795d-06,-1.3437228d-07 /
      data fpppp( 5, 7,11,1),fpppp( 5, 7,11,2),fpppp( 5, 7,11,3)/
     x-5.6674008d-04,-2.4452023d-05, 2.1217973d-08 /
      data fpppp( 5, 7,12,1),fpppp( 5, 7,12,2),fpppp( 5, 7,12,3)/
     x-3.6006561d-04, 1.8054496d-05, 3.2200156d-08 /
      data fpppp( 5, 7,13,1),fpppp( 5, 7,13,2),fpppp( 5, 7,13,3)/
     x-3.7155962d-04, 1.0833295d-05,-1.1600006d-08 /
      data fpppp( 5, 7,14,1),fpppp( 5, 7,14,2),fpppp( 5, 7,14,3)/
     x-6.8766496d-04,-7.8492427d-05, 7.6949502d-08 /
      data fpppp( 5, 7,15,1),fpppp( 5, 7,15,2),fpppp( 5, 7,15,3)/
     x 1.8142604d-04, 8.0456287d-05,-3.4127506d-07 /
      data fpppp( 5, 7,16,1),fpppp( 5, 7,16,2),fpppp( 5, 7,16,3)/
     x-2.2209799d-03,-1.9159244d-05, 6.4620901d-07 /
      data fpppp( 5, 7,17,1),fpppp( 5, 7,17,2),fpppp( 5, 7,17,3)/
     x 1.3833786d-04,-1.3838390d-04, 1.5414388d-07 /
      data fpppp( 5, 7,18,1),fpppp( 5, 7,18,2),fpppp( 5, 7,18,3)/
     x-6.8586917d-04, 2.4974489d-04, 1.0924014d-06 /
      data fpppp( 5, 7,19,1),fpppp( 5, 7,19,2),fpppp( 5, 7,19,3)/
     x-4.1751949d-04,-1.4731748d-04,-2.6408131d-06 /
      data fpppp( 5, 7,20,1),fpppp( 5, 7,20,2),fpppp( 5, 7,20,3)/
     x-9.2994349d-04, 2.3763325d-05, 7.3205510d-07 /
      data fpppp( 5, 7,21,1),fpppp( 5, 7,21,2),fpppp( 5, 7,21,3)/
     x-9.2994349d-04, 1.1256627d-06, 4.8013012d-07 /
      data fpppp( 5, 7,22,1),fpppp( 5, 7,22,2),fpppp( 5, 7,22,3)/
     x-4.1751949d-04,-5.6766830d-05,-1.6331131d-06 /
      data fpppp( 5, 7,23,1),fpppp( 5, 7,23,2),fpppp( 5, 7,23,3)/
     x-6.8586917d-04,-8.9820036d-05,-2.6864733d-06 /
      data fpppp( 5, 8, 1,1),fpppp( 5, 8, 1,2),fpppp( 5, 8, 1,3)/
     x 1.1119224d-02,-9.7151097d-03, 1.0404231d-05 /
      data fpppp( 5, 8, 2,1),fpppp( 5, 8, 2,2),fpppp( 5, 8, 2,3)/
     x-3.5173991d-05,-5.9038763d-03, 5.9470462d-06 /
      data fpppp( 5, 8, 3,1),fpppp( 5, 8, 3,2),fpppp( 5, 8, 3,3)/
     x-2.7772743d-02, 1.3099349d-03,-3.3672230d-06 /
      data fpppp( 5, 8, 4,1),fpppp( 5, 8, 4,2),fpppp( 5, 8, 4,3)/
     x-2.7772743d-02, 2.9778908d-03,-3.7816955d-06 /
      data fpppp( 5, 8, 5,1),fpppp( 5, 8, 5,2),fpppp( 5, 8, 5,3)/
     x-3.5173991d-05,-1.2575700d-02, 7.6049363d-06 /
      data fpppp( 5, 8, 6,1),fpppp( 5, 8, 6,2),fpppp( 5, 8, 6,3)/
     x 1.1119224d-02, 1.5304229d-02, 4.1871434d-06 /
      data fpppp( 5, 8, 7,1),fpppp( 5, 8, 7,2),fpppp( 5, 8, 7,3)/
     x 2.4878405d-02,-8.3094053d-03,-1.0599069d-05 /
      data fpppp( 5, 8, 8,1),fpppp( 5, 8, 8,2),fpppp( 5, 8, 8,3)/
     x-7.6796164d-04, 1.9429683d-03, 5.2591743d-06 /
      data fpppp( 5, 8, 9,1),fpppp( 5, 8, 9,2),fpppp( 5, 8, 9,3)/
     x-1.2952024d-05,-1.6021325d-04,-1.2339314d-06 /
      data fpppp( 5, 8,10,1),fpppp( 5, 8,10,2),fpppp( 5, 8,10,3)/
     x 1.0411224d-04,-2.5185812d-04, 3.6608327d-07 /
      data fpppp( 5, 8,11,1),fpppp( 5, 8,11,2),fpppp( 5, 8,11,3)/
     x 9.0150897d-04, 2.0976359d-04,-5.9539231d-08 /
      data fpppp( 5, 8,12,1),fpppp( 5, 8,12,2),fpppp( 5, 8,12,3)/
     x 8.6345594d-04,-1.0780210d-04, 3.7860009d-08 /
      data fpppp( 5, 8,13,1),fpppp( 5, 8,13,2),fpppp( 5, 8,13,3)/
     x 1.0465380d-05, 2.1389994d-04, 2.4201478d-08 /
      data fpppp( 5, 8,14,1),fpppp( 5, 8,14,2),fpppp( 5, 8,14,3)/
     x 9.0228043d-04,-3.8555853d-04, 1.6575569d-08 /
      data fpppp( 5, 8,15,1),fpppp( 5, 8,15,2),fpppp( 5, 8,15,3)/
     x-1.2360232d-04, 4.6335445d-04, 1.4908991d-07 /
      data fpppp( 5, 8,16,1),fpppp( 5, 8,16,2),fpppp( 5, 8,16,3)/
     x 6.1966348d-04,-4.6709311d-04,-9.2474350d-08 /
      data fpppp( 5, 8,17,1),fpppp( 5, 8,17,2),fpppp( 5, 8,17,3)/
     x-7.6101927d-05, 2.8501650d-04, 8.8260596d-08 /
      data fpppp( 5, 8,18,1),fpppp( 5, 8,18,2),fpppp( 5, 8,18,3)/
     x 8.5927274d-05,-5.7755949d-05,-1.7913198d-07 /
      data fpppp( 5, 8,19,1),fpppp( 5, 8,19,2),fpppp( 5, 8,19,3)/
     x 1.6176914d-04, 8.0479733d-05, 1.0915712d-06 /
      data fpppp( 5, 8,20,1),fpppp( 5, 8,20,2),fpppp( 5, 8,20,3)/
     x-1.3544138d-04,-6.5628066d-05,-7.7349471d-07 /
      data fpppp( 5, 8,21,1),fpppp( 5, 8,21,2),fpppp( 5, 8,21,3)/
     x-1.3544138d-04,-5.5829681d-05,-6.7186177d-07 /
      data fpppp( 5, 8,22,1),fpppp( 5, 8,22,2),fpppp( 5, 8,22,3)/
     x 1.6176914d-04, 4.1286191d-05, 6.8503941d-07 /
      data fpppp( 5, 8,23,1),fpppp( 5, 8,23,2),fpppp( 5, 8,23,3)/
     x 8.5927274d-05, 8.9219834d-05, 1.3453621d-06 /
      data fpppp( 5, 9, 1,1),fpppp( 5, 9, 1,2),fpppp( 5, 9, 1,3)/
     x-6.7668306d-03,-1.0470730d-04,-6.8259864d-06 /
      data fpppp( 5, 9, 2,1),fpppp( 5, 9, 2,2),fpppp( 5, 9, 2,3)/
     x 2.4470263d-03, 6.4735464d-05,-4.2806961d-06 /
      data fpppp( 5, 9, 3,1),fpppp( 5, 9, 3,2),fpppp( 5, 9, 3,3)/
     x 7.5010701d-03,-5.4505182d-04, 9.5449738d-07 /
      data fpppp( 5, 9, 4,1),fpppp( 5, 9, 4,2),fpppp( 5, 9, 4,3)/
     x 7.5010701d-03, 1.1574863d-03, 1.3377473d-06 /
      data fpppp( 5, 9, 5,1),fpppp( 5, 9, 5,2),fpppp( 5, 9, 5,3)/
     x 2.4470263d-03,-6.7454169d-03,-5.8136958d-06 /
      data fpppp( 5, 9, 6,1),fpppp( 5, 9, 6,2),fpppp( 5, 9, 6,3)/
     x-6.7668306d-03, 2.5433364d-02,-1.0772375d-06 /
      data fpppp( 5, 9, 7,1),fpppp( 5, 9, 7,2),fpppp( 5, 9, 7,3)/
     x-4.0348666d-02,-3.9637194d-02, 1.4395314d-05 /
      data fpppp( 5, 9, 8,1),fpppp( 5, 9, 8,2),fpppp( 5, 9, 8,3)/
     x 1.8768727d-03, 2.5150989d-02,-1.1918000d-05 /
      data fpppp( 5, 9, 9,1),fpppp( 5, 9, 9,2),fpppp( 5, 9, 9,3)/
     x 4.0015633d-04,-6.4980337d-03, 3.0789358d-06 /
      data fpppp( 5, 9,10,1),fpppp( 5, 9,10,2),fpppp( 5, 9,10,3)/
     x 1.2610331d-04, 1.1360963d-03,-6.8182926d-07 /
      data fpppp( 5, 9,11,1),fpppp( 5, 9,11,2),fpppp( 5, 9,11,3)/
     x-2.7782936d-03, 3.6482045d-05, 2.1370091d-07 /
      data fpppp( 5, 9,12,1),fpppp( 5, 9,12,2),fpppp( 5, 9,12,3)/
     x-2.9096411d-03,-1.1743003d-04,-3.1859580d-08 /
      data fpppp( 5, 9,13,1),fpppp( 5, 9,13,2),fpppp( 5, 9,13,3)/
     x 5.2594644d-04, 4.4856544d-04, 3.1269677d-08 /
      data fpppp( 5, 9,14,1),fpppp( 5, 9,14,2),fpppp( 5, 9,14,3)/
     x-2.5647824d-03,-7.8695396d-04, 2.8545274d-08 /
      data fpppp( 5, 9,15,1),fpppp( 5, 9,15,2),fpppp( 5, 9,15,3)/
     x 5.0474276d-04, 8.6663016d-04, 5.4116493d-09 /
      data fpppp( 5, 9,16,1),fpppp( 5, 9,16,2),fpppp( 5, 9,16,3)/
     x-1.4239230d-04,-8.1377080d-04, 7.5546500d-08 /
      data fpppp( 5, 9,17,1),fpppp( 5, 9,17,2),fpppp( 5, 9,17,3)/
     x 4.2763671d-04, 5.0577752d-04, 2.5205096d-08 /
      data fpppp( 5, 9,18,1),fpppp( 5, 9,18,2),fpppp( 5, 9,18,3)/
     x 3.0297670d-04,-1.0299081d-04, 7.9942966d-08 /
      data fpppp( 5, 9,19,1),fpppp( 5, 9,19,2),fpppp( 5, 9,19,3)/
     x 1.6715845d-04, 1.9850154d-04,-2.3488876d-07 /
      data fpppp( 5, 9,20,1),fpppp( 5, 9,20,2),fpppp( 5, 9,20,3)/
     x 2.1153052d-03,-1.6720210d-04,-3.2503878d-08 /
      data fpppp( 5, 9,21,1),fpppp( 5, 9,21,2),fpppp( 5, 9,21,3)/
     x 2.1153052d-03,-1.4478972d-04,-5.1931631d-08 /
      data fpppp( 5, 9,22,1),fpppp( 5, 9,22,2),fpppp( 5, 9,22,3)/
     x 1.6715845d-04, 1.0885204d-04,-1.5717775d-07 /
      data fpppp( 5, 9,23,1),fpppp( 5, 9,23,2),fpppp( 5, 9,23,3)/
     x 3.0297670d-04, 2.3319483d-04,-2.1147334d-07 /
      data fpppp( 5,10, 1,1),fpppp( 5,10, 1,2),fpppp( 5,10, 1,3)/
     x 2.1300519d-03, 1.5807773d-04, 2.3160266d-06 /
      data fpppp( 5,10, 2,1),fpppp( 5,10, 2,2),fpppp( 5,10, 2,3)/
     x 2.8069763d-06, 1.6324239d-05, 1.3170138d-06 /
      data fpppp( 5,10, 3,1),fpppp( 5,10, 3,2),fpppp( 5,10, 3,3)/
     x-1.4698408d-04,-2.2929859d-04,-7.1298114d-07 /
      data fpppp( 5,10, 4,1),fpppp( 5,10, 4,2),fpppp( 5,10, 4,3)/
     x-1.4698408d-04,-3.3103422d-04,-9.0678762d-07 /
      data fpppp( 5,10, 5,1),fpppp( 5,10, 5,2),fpppp( 5,10, 5,3)/
     x 2.8069763d-06, 4.2326673d-04, 2.0922398d-06 /
      data fpppp( 5,10, 6,1),fpppp( 5,10, 6,2),fpppp( 5,10, 6,3)/
     x 2.1300519d-03,-1.3679566d-03,-5.9107070d-07 /
      data fpppp( 5,10, 7,1),fpppp( 5,10, 7,2),fpppp( 5,10, 7,3)/
     x 2.6931933d-02, 3.2259455d-03,-7.2414685d-06 /
      data fpppp( 5,10, 8,1),fpppp( 5,10, 8,2),fpppp( 5,10, 8,3)/
     x-3.1842636d-03,-2.5683737d-03, 1.2619474d-05 /
      data fpppp( 5,10, 9,1),fpppp( 5,10, 9,2),fpppp( 5,10, 9,3)/
     x 1.5442105d-05, 1.5910052d-03,-6.0632833d-06 /
      data fpppp( 5,10,10,1),fpppp( 5,10,10,2),fpppp( 5,10,10,3)/
     x 3.4600710d-04,-2.9524367d-03, 7.8763054d-07 /
      data fpppp( 5,10,11,1),fpppp( 5,10,11,2),fpppp( 5,10,11,3)/
     x 5.0678407d-03, 1.8925163d-03,-2.9914016d-07 /
      data fpppp( 5,10,12,1),fpppp( 5,10,12,2),fpppp( 5,10,12,3)/
     x 5.2094651d-03, 2.9087052d-03, 7.2524465d-08 /
      data fpppp( 5,10,13,1),fpppp( 5,10,13,2),fpppp( 5,10,13,3)/
     x-3.1503091d-04,-5.7024558d-03,-7.3090808d-09 /
      data fpppp( 5,10,14,1),fpppp( 5,10,14,2),fpppp( 5,10,14,3)/
     x 2.8513629d-03, 5.6490645d-03, 1.8972752d-08 /
      data fpppp( 5,10,15,1),fpppp( 5,10,15,2),fpppp( 5,10,15,3)/
     x-3.3689454d-04,-3.3253960d-03, 2.1494723d-08 /
      data fpppp( 5,10,16,1),fpppp( 5,10,16,2),fpppp( 5,10,16,3)/
     x 6.3770342d-05, 8.7477504d-04,-9.4859692d-09 /
      data fpppp( 5,10,17,1),fpppp( 5,10,17,2),fpppp( 5,10,17,3)/
     x-3.5368501d-04,-2.0754892d-04,-6.8149244d-09 /
      data fpppp( 5,10,18,1),fpppp( 5,10,18,2),fpppp( 5,10,18,3)/
     x-3.2622589d-04, 7.6853652d-05,-3.7449779d-08 /
      data fpppp( 5,10,19,1),fpppp( 5,10,19,2),fpppp( 5,10,19,3)/
     x-2.6334798d-04, 2.5489198d-04, 9.1037433d-08 /
      data fpppp( 5,10,20,1),fpppp( 5,10,20,2),fpppp( 5,10,20,3)/
     x-8.1269303d-03,-2.1098268d-04,-1.0349404d-07 /
      data fpppp( 5,10,21,1),fpppp( 5,10,21,2),fpppp( 5,10,21,3)/
     x-8.1269303d-03,-1.9221148d-04,-9.3085717d-08 /
      data fpppp( 5,10,22,1),fpppp( 5,10,22,2),fpppp( 5,10,22,3)/
     x-2.6334798d-04, 1.7980720d-04, 4.9404162d-08 /
      data fpppp( 5,10,23,1),fpppp( 5,10,23,2),fpppp( 5,10,23,3)/
     x-3.2622589d-04, 3.5842158d-04, 1.1867499d-07 /
      data fpppp( 5,11, 1,1),fpppp( 5,11, 1,2),fpppp( 5,11, 1,3)/
     x 6.2178524d-05, 7.5802246d-04, 1.3155450d-06 /
      data fpppp( 5,11, 2,1),fpppp( 5,11, 2,2),fpppp( 5,11, 2,3)/
     x 1.2669385d-03, 2.7331667d-04, 4.4777095d-07 /
      data fpppp( 5,11, 3,1),fpppp( 5,11, 3,2),fpppp( 5,11, 3,3)/
     x-5.5672192d-04,-7.5073762d-04,-1.4018786d-06 /
      data fpppp( 5,11, 4,1),fpppp( 5,11, 4,2),fpppp( 5,11, 4,3)/
     x-5.5672192d-04,-7.7628935d-04,-1.4191446d-06 /
      data fpppp( 5,11, 5,1),fpppp( 5,11, 5,2),fpppp( 5,11, 5,3)/
     x 1.2669385d-03, 3.7552357d-04, 5.1683474d-07 /
      data fpppp( 5,11, 6,1),fpppp( 5,11, 6,2),fpppp( 5,11, 6,3)/
     x 6.2178524d-05, 3.7474659d-04, 1.0565558d-06 /
      data fpppp( 5,11, 7,1),fpppp( 5,11, 7,2),fpppp( 5,11, 7,3)/
     x-7.4142278d-03,-8.1166378d-04, 1.5054404d-06 /
      data fpppp( 5,11, 8,1),fpppp( 5,11, 8,2),fpppp( 5,11, 8,3)/
     x 3.0664194d-03, 2.8633493d-03,-4.5359705d-06 /
      data fpppp( 5,11, 9,1),fpppp( 5,11, 9,2),fpppp( 5,11, 9,3)/
     x-1.4403205d-03,-1.4495801d-03, 5.4196612d-06 /
      data fpppp( 5,11,10,1),fpppp( 5,11,10,2),fpppp( 5,11,10,3)/
     x-5.2626148d-04,-5.2665882d-04,-1.8435523d-06 /
      data fpppp( 5,11,11,1),fpppp( 5,11,11,2),fpppp( 5,11,11,3)/
     x-3.2193557d-03, 1.4850850d-04, 1.5795358d-07 /
      data fpppp( 5,11,12,1),fpppp( 5,11,12,2),fpppp( 5,11,12,3)/
     x-3.4568866d-03, 7.2847368d-04,-1.1023435d-07 /
      data fpppp( 5,11,13,1),fpppp( 5,11,13,2),fpppp( 5,11,13,3)/
     x 1.3696243d-04,-2.6941343d-03, 2.1337036d-08 /
      data fpppp( 5,11,14,1),fpppp( 5,11,14,2),fpppp( 5,11,14,3)/
     x-8.6992458d-04, 4.2905854d-03, 3.9822283d-10 /
      data fpppp( 5,11,15,1),fpppp( 5,11,15,2),fpppp( 5,11,15,3)/
     x 1.4003410d-04,-2.7402800d-03, 1.5810518d-09 /
      data fpppp( 5,11,16,1),fpppp( 5,11,16,2),fpppp( 5,11,16,3)/
     x 4.1451089d-05, 7.7973712d-04, 1.9164940d-09 /
      data fpppp( 5,11,17,1),fpppp( 5,11,17,2),fpppp( 5,11,17,3)/
     x 1.5713783d-04,-4.0472956d-04,-8.1534616d-09 /
      data fpppp( 5,11,18,1),fpppp( 5,11,18,2),fpppp( 5,11,18,3)/
     x 1.6476768d-04, 9.5261067d-04, 4.2092862d-09 /
      data fpppp( 5,11,19,1),fpppp( 5,11,19,2),fpppp( 5,11,19,3)/
     x 1.9126612d-04,-2.8391281d-03,-8.0025458d-08 /
      data fpppp( 5,11,20,1),fpppp( 5,11,20,2),fpppp( 5,11,20,3)/
     x 1.9655573d-02, 1.4668986d-03, 1.1344827d-08 /
      data fpppp( 5,11,21,1),fpppp( 5,11,21,2),fpppp( 5,11,21,3)/
     x 1.9655573d-02, 1.1915243d-03, 5.3223174d-09 /
      data fpppp( 5,11,22,1),fpppp( 5,11,22,2),fpppp( 5,11,22,3)/
     x 1.9126612d-04,-1.7376310d-03,-5.5935418d-08 /
      data fpppp( 5,11,23,1),fpppp( 5,11,23,2),fpppp( 5,11,23,3)/
     x 1.6476768d-04,-3.1780033d-03,-8.6128364d-08 /
      data fpppp( 5,12, 1,1),fpppp( 5,12, 1,2),fpppp( 5,12, 1,3)/
     x-3.4230624d-04, 1.2788320d-03, 1.8342004d-06 /
      data fpppp( 5,12, 2,1),fpppp( 5,12, 2,2),fpppp( 5,12, 2,3)/
     x 2.3687711d-03, 3.2147081d-04, 7.6118832d-07 /
      data fpppp( 5,12, 3,1),fpppp( 5,12, 3,2),fpppp( 5,12, 3,3)/
     x 1.3833253d-02,-1.7405108d-03,-1.4841753d-06 /
      data fpppp( 5,12, 4,1),fpppp( 5,12, 4,2),fpppp( 5,12, 4,3)/
     x 1.3833253d-02,-1.7221476d-03,-1.5785845d-06 /
      data fpppp( 5,12, 5,1),fpppp( 5,12, 5,2),fpppp( 5,12, 5,3)/
     x 2.3687711d-03, 2.4801780d-04, 1.1388251d-06 /
      data fpppp( 5,12, 6,1),fpppp( 5,12, 6,2),fpppp( 5,12, 6,3)/
     x-3.4230624d-04, 1.5542809d-03, 4.1806240d-07 /
      data fpppp( 5,12, 7,1),fpppp( 5,12, 7,2),fpppp( 5,12, 7,3)/
     x 2.0732158d-03, 1.9781556d-04, 7.2923205d-08 /
      data fpppp( 5,12, 8,1),fpppp( 5,12, 8,2),fpppp( 5,12, 8,3)/
     x-9.6864187d-04, 1.2264307d-04, 6.1620746d-07 /
      data fpppp( 5,12, 9,1),fpppp( 5,12, 9,2),fpppp( 5,12, 9,3)/
     x 1.4915283d-03, 2.0208453d-03,-8.2689439d-07 /
      data fpppp( 5,12,10,1),fpppp( 5,12,10,2),fpppp( 5,12,10,3)/
     x-6.5801443d-04,-1.7681528d-03, 1.3981107d-06 /
      data fpppp( 5,12,11,1),fpppp( 5,12,11,2),fpppp( 5,12,11,3)/
     x 6.1162262d-04,-5.5586881d-05,-4.7862883d-07 /
      data fpppp( 5,12,12,1),fpppp( 5,12,12,2),fpppp( 5,12,12,3)/
     x 1.3495065d-03, 7.6615524d-04, 6.0299721d-08 /
      data fpppp( 5,12,13,1),fpppp( 5,12,13,2),fpppp( 5,12,13,3)/
     x-2.4946503d-05,-2.5503151d-03,-3.5951578d-08 /
      data fpppp( 5,12,14,1),fpppp( 5,12,14,2),fpppp( 5,12,14,3)/
     x 2.0759430d-04, 4.0671421d-03, 1.4776149d-09 /
      data fpppp( 5,12,15,1),fpppp( 5,12,15,2),fpppp( 5,12,15,3)/
     x 2.2939283d-05,-2.5352690d-03,-5.4394497d-09 /
      data fpppp( 5,12,16,1),fpppp( 5,12,16,2),fpppp( 5,12,16,3)/
     x 8.7766281d-05, 4.7432115d-04, 3.2988109d-09 /
      data fpppp( 5,12,17,1),fpppp( 5,12,17,2),fpppp( 5,12,17,3)/
     x 1.1034901d-04, 6.1642154d-04, 5.7340184d-09 /
      data fpppp( 5,12,18,1),fpppp( 5,12,18,2),fpppp( 5,12,18,3)/
     x 1.8612529d-04,-2.7687008d-03,-2.0687174d-08 /
      data fpppp( 5,12,19,1),fpppp( 5,12,19,2),fpppp( 5,12,19,3)/
     x 2.3908872d-04, 1.1324875d-02,-1.7864162d-07 /
      data fpppp( 5,12,20,1),fpppp( 5,12,20,2),fpppp( 5,12,20,3)/
     x-1.4561433d-02,-6.3189541d-03, 1.1491860d-07 /
      data fpppp( 5,12,21,1),fpppp( 5,12,21,2),fpppp( 5,12,21,3)/
     x-1.4561433d-02,-5.2591109d-03, 1.0091784d-07 /
      data fpppp( 5,12,22,1),fpppp( 5,12,22,2),fpppp( 5,12,22,3)/
     x 2.3908872d-04, 7.0855020d-03,-1.2263860d-07 /
      data fpppp( 5,12,23,1),fpppp( 5,12,23,2),fpppp( 5,12,23,3)/
     x 1.8612529d-04, 1.3128946d-02,-2.3069848d-07 /
      data fpppp( 5,13, 1,1),fpppp( 5,13, 1,2),fpppp( 5,13, 1,3)/
     x 9.0178756d-04, 1.1827584d-02,-5.6085809d-06 /
      data fpppp( 5,13, 2,1),fpppp( 5,13, 2,2),fpppp( 5,13, 2,3)/
     x-3.8695568d-03, 5.5987756d-03,-2.7009959d-06 /
      data fpppp( 5,13, 3,1),fpppp( 5,13, 3,2),fpppp( 5,13, 3,3)/
     x-1.4365648d-02,-7.4143765d-03, 3.3671804d-06 /
      data fpppp( 5,13, 4,1),fpppp( 5,13, 4,2),fpppp( 5,13, 4,3)/
     x-1.4365648d-02,-7.9993926d-03, 3.6513161d-06 /
      data fpppp( 5,13, 5,1),fpppp( 5,13, 5,2),fpppp( 5,13, 5,3)/
     x-3.8695568d-03, 7.9388402d-03,-3.8375387d-06 /
      data fpppp( 5,13, 6,1),fpppp( 5,13, 6,2),fpppp( 5,13, 6,3)/
     x 9.0178756d-04, 3.0523419d-03,-1.3465452d-06 /
      data fpppp( 5,13, 7,1),fpppp( 5,13, 7,2),fpppp( 5,13, 7,3)/
     x-6.4614439d-04, 3.0334310d-05,-4.6257053d-07 /
      data fpppp( 5,13, 8,1),fpppp( 5,13, 8,2),fpppp( 5,13, 8,3)/
     x 1.8049962d-04, 2.7336335d-04,-2.4369046d-07 /
      data fpppp( 5,13, 9,1),fpppp( 5,13, 9,2),fpppp( 5,13, 9,3)/
     x-2.3669200d-04, 8.7941346d-04, 3.1798107d-08 /
      data fpppp( 5,13,10,1),fpppp( 5,13,10,2),fpppp( 5,13,10,3)/
     x 4.1649032d-04, 5.9867741d-04, 4.5597366d-07 /
      data fpppp( 5,13,11,1),fpppp( 5,13,11,2),fpppp( 5,13,11,3)/
     x-2.8325130d-04,-1.3644801d-03, 5.4144037d-08 /
      data fpppp( 5,13,12,1),fpppp( 5,13,12,2),fpppp( 5,13,12,3)/
     x-2.1172369d-03, 8.0901062d-04,-3.4997644d-08 /
      data fpppp( 5,13,13,1),fpppp( 5,13,13,2),fpppp( 5,13,13,3)/
     x-4.7324478d-05,-2.0364631d-03, 6.5942366d-10 /
      data fpppp( 5,13,14,1),fpppp( 5,13,14,2),fpppp( 5,13,14,3)/
     x 1.0316596d-03, 3.1947044d-03,-1.3196174d-08 /
      data fpppp( 5,13,15,1),fpppp( 5,13,15,2),fpppp( 5,13,15,3)/
     x-1.0032787d-04,-1.9672224d-03,-8.3034354d-09 /
      data fpppp( 5,13,16,1),fpppp( 5,13,16,2),fpppp( 5,13,16,3)/
     x-1.4448047d-04, 3.4297839d-04,-2.3035163d-09 /
      data fpppp( 5,13,17,1),fpppp( 5,13,17,2),fpppp( 5,13,17,3)/
     x-1.7330368d-04, 6.3886630d-04,-4.0553150d-09 /
      data fpppp( 5,13,18,1),fpppp( 5,13,18,2),fpppp( 5,13,18,3)/
     x-2.4844537d-04,-2.6108614d-03,-3.6578000d-08 /
      data fpppp( 5,13,19,1),fpppp( 5,13,19,2),fpppp( 5,13,19,3)/
     x-4.6702531d-04, 1.0755159d-02,-2.3457342d-09 /
      data fpppp( 5,13,20,1),fpppp( 5,13,20,2),fpppp( 5,13,20,3)/
     x-7.7044639d-03,-6.0440740d-03, 4.4728835d-08 /
      data fpppp( 5,13,21,1),fpppp( 5,13,21,2),fpppp( 5,13,21,3)/
     x-7.7044639d-03,-5.0374762d-03, 4.5310993d-08 /
      data fpppp( 5,13,22,1),fpppp( 5,13,22,2),fpppp( 5,13,22,3)/
     x-4.6702531d-04, 6.7287672d-03,-4.6743670d-09 /
      data fpppp( 5,13,23,1),fpppp( 5,13,23,2),fpppp( 5,13,23,3)/
     x-2.4844537d-04, 1.2488107d-02,-2.7845626d-08 /
      data fpppp( 5,14, 1,1),fpppp( 5,14, 1,2),fpppp( 5,14, 1,3)/
     x-2.6469152d-03, 1.3517885d-02,-3.2916337d-06 /
      data fpppp( 5,14, 2,1),fpppp( 5,14, 2,2),fpppp( 5,14, 2,3)/
     x-5.1325808d-03, 6.6063814d-03,-1.3264907d-06 /
      data fpppp( 5,14, 3,1),fpppp( 5,14, 3,2),fpppp( 5,14, 3,3)/
     x-1.4028964d-02,-7.7072938d-03, 2.8299543d-06 /
      data fpppp( 5,14, 4,1),fpppp( 5,14, 4,2),fpppp( 5,14, 4,3)/
     x-1.4028964d-02,-8.5765008d-03, 2.9254617d-06 /
      data fpppp( 5,14, 5,1),fpppp( 5,14, 5,2),fpppp( 5,14, 5,3)/
     x-5.1325808d-03, 1.0083209d-02,-1.7085205d-06 /
      data fpppp( 5,14, 6,1),fpppp( 5,14, 6,2),fpppp( 5,14, 6,3)/
     x-2.6469152d-03, 4.7978020d-04,-1.8590221d-06 /
      data fpppp( 5,14, 7,1),fpppp( 5,14, 7,2),fpppp( 5,14, 7,3)/
     x-3.0623578d-04, 1.3963051d-03,-8.5210883d-07 /
      data fpppp( 5,14, 8,1),fpppp( 5,14, 8,2),fpppp( 5,14, 8,3)/
     x-1.9417126d-04, 1.7320739d-04,-2.1219417d-07 /
      data fpppp( 5,14, 9,1),fpppp( 5,14, 9,2),fpppp( 5,14, 9,3)/
     x 9.5995279d-05,-8.7178232d-05,-2.5871617d-07 /
      data fpppp( 5,14,10,1),fpppp( 5,14,10,2),fpppp( 5,14,10,3)/
     x 3.0376418d-04, 2.1064085d-03, 3.9761577d-07 /
      data fpppp( 5,14,11,1),fpppp( 5,14,11,2),fpppp( 5,14,11,3)/
     x-9.4668014d-04,-2.8625461d-03, 1.0158657d-07 /
      data fpppp( 5,14,12,1),fpppp( 5,14,12,2),fpppp( 5,14,12,3)/
     x 2.9812071d-03, 2.5772587d-03, 1.7342551d-09 /
      data fpppp( 5,14,13,1),fpppp( 5,14,13,2),fpppp( 5,14,13,3)/
     x-2.3237910d-05,-1.6640861d-03, 6.2863971d-09 /
      data fpppp( 5,14,14,1),fpppp( 5,14,14,2),fpppp( 5,14,14,3)/
     x-1.3694449d-03, 4.6429264d-04,-3.4663742d-09 /
      data fpppp( 5,14,15,1),fpppp( 5,14,15,2),fpppp( 5,14,15,3)/
     x 2.5638751d-04,-1.1484718d-04,-5.7454948d-09 /
      data fpppp( 5,14,16,1),fpppp( 5,14,16,2),fpppp( 5,14,16,3)/
     x 3.9224665d-04, 4.3143295d-05,-4.3565450d-09 /
      data fpppp( 5,14,17,1),fpppp( 5,14,17,2),fpppp( 5,14,17,3)/
     x 4.8501817d-04, 2.6937343d-05, 3.4531248d-09 /
      data fpppp( 5,14,18,1),fpppp( 5,14,18,2),fpppp( 5,14,18,3)/
     x 5.3665360d-04, 7.9748811d-05, 2.9367439d-08 /
      data fpppp( 5,14,19,1),fpppp( 5,14,19,2),fpppp( 5,14,19,3)/
     x 6.2245065d-04, 1.2632936d-04, 1.1882560d-07 /
      data fpppp( 5,14,20,1),fpppp( 5,14,20,2),fpppp( 5,14,20,3)/
     x 1.1532094d-02,-1.7058464d-04,-7.5966399d-08 /
      data fpppp( 5,14,21,1),fpppp( 5,14,21,2),fpppp( 5,14,21,3)/
     x 1.1532094d-02,-1.6179633d-04,-6.7404955d-08 /
      data fpppp( 5,14,22,1),fpppp( 5,14,22,2),fpppp( 5,14,22,3)/
     x 6.2245065d-04, 9.1176119d-05, 8.4579824d-08 /
      data fpppp( 5,14,23,1),fpppp( 5,14,23,2),fpppp( 5,14,23,3)/
     x 5.3665360d-04, 2.1157348d-04, 1.5778911d-07 /
      data fpppp( 5,15, 1,1),fpppp( 5,15, 1,2),fpppp( 5,15, 1,3)/
     x 1.6655690d-04, 4.5401732d-03, 3.5442706d-06 /
      data fpppp( 5,15, 2,1),fpppp( 5,15, 2,2),fpppp( 5,15, 2,3)/
     x 3.0086888d-03, 2.1866022d-03, 1.7545294d-06 /
      data fpppp( 5,15, 3,1),fpppp( 5,15, 3,2),fpppp( 5,15, 3,3)/
     x 1.0180513d-02,-2.6605836d-03,-1.9677144d-06 /
      data fpppp( 5,15, 4,1),fpppp( 5,15, 4,2),fpppp( 5,15, 4,3)/
     x 1.0180513d-02,-3.0038993d-03,-2.1653175d-06 /
      data fpppp( 5,15, 5,1),fpppp( 5,15, 5,2),fpppp( 5,15, 5,3)/
     x 3.0086888d-03, 3.5598649d-03, 2.5449418d-06 /
      data fpppp( 5,15, 6,1),fpppp( 5,15, 6,2),fpppp( 5,15, 6,3)/
     x 1.6655690d-04,-6.0956184d-04, 5.8022405d-07 /
      data fpppp( 5,15, 7,1),fpppp( 5,15, 7,2),fpppp( 5,15, 7,3)/
     x-3.5921150d-04, 9.1425384d-04, 8.9225313d-09 /
      data fpppp( 5,15, 8,1),fpppp( 5,15, 8,2),fpppp( 5,15, 8,3)/
     x-1.6473826d-04, 1.6227775d-04,-2.1487019d-07 /
      data fpppp( 5,15, 9,1),fpppp( 5,15, 9,2),fpppp( 5,15, 9,3)/
     x-9.1539359d-05,-2.1535505d-04,-4.9580866d-08 /
      data fpppp( 5,15,10,1),fpppp( 5,15,10,2),fpppp( 5,15,10,3)/
     x 1.2075116d-04, 1.0511288d-03,-2.8474966d-07 /
      data fpppp( 5,15,11,1),fpppp( 5,15,11,2),fpppp( 5,15,11,3)/
     x 2.4650496d-03,-7.5272093d-07, 7.9436883d-07 /
      data fpppp( 5,15,12,1),fpppp( 5,15,12,2),fpppp( 5,15,12,3)/
     x-4.3806795d-03,-1.4186542d-04,-3.1446306d-07 /
      data fpppp( 5,15,13,1),fpppp( 5,15,13,2),fpppp( 5,15,13,3)/
     x-1.2339102d-04,-4.2449287d-04, 1.0419056d-07 /
      data fpppp( 5,15,14,1),fpppp( 5,15,14,2),fpppp( 5,15,14,3)/
     x-1.4018778d-04, 1.2032649d-04,-1.6836933d-08 /
      data fpppp( 5,15,15,1),fpppp( 5,15,15,2),fpppp( 5,15,15,3)/
     x-1.1846118d-03,-2.5912032d-05, 1.4244260d-08 /
      data fpppp( 5,15,16,1),fpppp( 5,15,16,2),fpppp( 5,15,16,3)/
     x-1.7498754d-03, 1.7725232d-05, 3.9929173d-09 /
      data fpppp( 5,15,17,1),fpppp( 5,15,17,2),fpppp( 5,15,17,3)/
     x-2.2293811d-03, 9.5171487d-06, 1.1911085d-08 /
      data fpppp( 5,15,18,1),fpppp( 5,15,18,2),fpppp( 5,15,18,3)/
     x-2.5920776d-03, 2.3853261d-05, 3.0691943d-08 /
      data fpppp( 5,15,19,1),fpppp( 5,15,19,2),fpppp( 5,15,19,3)/
     x-2.8247063d-03, 1.2290364d-05, 3.2840249d-08 /
      data fpppp( 5,15,20,1),fpppp( 5,15,20,2),fpppp( 5,15,20,3)/
     x-5.7655104d-03,-4.1400658d-05,-4.2874638d-08 /
      data fpppp( 5,15,21,1),fpppp( 5,15,21,2),fpppp( 5,15,21,3)/
     x-5.7655104d-03,-4.0760171d-05,-4.1095433d-08 /
      data fpppp( 5,15,22,1),fpppp( 5,15,22,2),fpppp( 5,15,22,3)/
     x-2.8247063d-03, 9.7284186d-06, 2.5723429d-08 /
      data fpppp( 5,15,23,1),fpppp( 5,15,23,2),fpppp( 5,15,23,3)/
     x-2.5920776d-03, 3.3460557d-05, 5.7380019d-08 /
      data fpppp( 5,16, 1,1),fpppp( 5,16, 1,2),fpppp( 5,16, 1,3)/
     x 4.1365887d-04, 5.6010791d-04, 8.3579391d-07 /
      data fpppp( 5,16, 2,1),fpppp( 5,16, 2,2),fpppp( 5,16, 2,3)/
     x 7.0245098d-04, 2.1467767d-04, 2.1956778d-07 /
      data fpppp( 5,16, 3,1),fpppp( 5,16, 3,2),fpppp( 5,16, 3,3)/
     x 1.9899620d-03,-4.9616874d-04,-1.1039173d-06 /
      data fpppp( 5,16, 4,1),fpppp( 5,16, 4,2),fpppp( 5,16, 4,3)/
     x 1.9899620d-03,-5.4755090d-04,-1.0986664d-06 /
      data fpppp( 5,16, 5,1),fpppp( 5,16, 5,2),fpppp( 5,16, 5,3)/
     x 7.0245098d-04, 4.2020630d-04, 1.9856397d-07 /
      data fpppp( 5,16, 6,1),fpppp( 5,16, 6,2),fpppp( 5,16, 6,3)/
     x 4.1365887d-04,-2.1062445d-04, 9.1455817d-07 /
      data fpppp( 5,16, 7,1),fpppp( 5,16, 7,2),fpppp( 5,16, 7,3)/
     x 1.5148116d-04, 2.4248129d-04, 3.1151889d-07 /
      data fpppp( 5,16, 8,1),fpppp( 5,16, 8,2),fpppp( 5,16, 8,3)/
     x 1.9952152d-05, 2.0495419d-04, 8.4761895d-08 /
      data fpppp( 5,16, 9,1),fpppp( 5,16, 9,2),fpppp( 5,16, 9,3)/
     x 9.2586892d-06,-5.5439470d-04,-2.2796836d-07 /
      data fpppp( 5,16,10,1),fpppp( 5,16,10,2),fpppp( 5,16,10,3)/
     x 3.6830686d-04, 1.6294048d-03, 3.6900790d-07 /
      data fpppp( 5,16,11,1),fpppp( 5,16,11,2),fpppp( 5,16,11,3)/
     x-3.9250586d-03,-1.0449144d-03,-5.1667400d-07 /
      data fpppp( 5,16,12,1),fpppp( 5,16,12,2),fpppp( 5,16,12,3)/
     x 1.2761291d-02, 5.2721141d-04, 5.3510142d-07 /
      data fpppp( 5,16,13,1),fpppp( 5,16,13,2),fpppp( 5,16,13,3)/
     x 3.0759184d-04,-4.9205960d-04,-6.1610316d-08 /
      data fpppp( 5,16,14,1),fpppp( 5,16,14,2),fpppp( 5,16,14,3)/
     x 1.7805623d-03, 1.0536625d-04, 4.1957380d-08 /
      data fpppp( 5,16,15,1),fpppp( 5,16,15,2),fpppp( 5,16,15,3)/
     x 4.3135261d-03,-2.4316592d-05, 4.0770388d-09 /
      data fpppp( 5,16,16,1),fpppp( 5,16,16,2),fpppp( 5,16,16,3)/
     x 6.4137349d-03, 6.5732791d-06, 1.0567262d-08 /
      data fpppp( 5,16,17,1),fpppp( 5,16,17,2),fpppp( 5,16,17,3)/
     x 8.1965053d-03, 4.8778028d-06, 7.1844042d-09 /
      data fpppp( 5,16,18,1),fpppp( 5,16,18,2),fpppp( 5,16,18,3)/
     x 9.6509593d-03, 3.5238149d-07, 2.9549229d-09 /
      data fpppp( 5,16,19,1),fpppp( 5,16,19,2),fpppp( 5,16,19,3)/
     x 1.0795875d-02, 7.8641677d-07,-1.1090113d-09 /
      data fpppp( 5,16,20,1),fpppp( 5,16,20,2),fpppp( 5,16,20,3)/
     x 1.2296547d-02,-7.8507156d-06,-1.5455536d-08 /
      data fpppp( 5,16,21,1),fpppp( 5,16,21,2),fpppp( 5,16,21,3)/
     x 1.2296547d-02,-7.6387838d-06,-1.5330641d-08 /
      data fpppp( 5,16,22,1),fpppp( 5,16,22,2),fpppp( 5,16,22,3)/
     x 1.0795875d-02,-6.1310522d-08,-1.6085893d-09 /
      data fpppp( 5,16,23,1),fpppp( 5,16,23,2),fpppp( 5,16,23,3)/
     x 9.6509593d-03, 3.5313588d-06, 4.8283402d-09 /
      data fpppp( 5,17, 1,1),fpppp( 5,17, 1,2),fpppp( 5,17, 1,3)/
     x 5.1293230d-05,-4.5155634d-05, 1.4762184d-07 /
      data fpppp( 5,17, 2,1),fpppp( 5,17, 2,2),fpppp( 5,17, 2,3)/
     x 2.6952091d-04,-5.2352210d-05, 4.6183270d-08 /
      data fpppp( 5,17, 3,1),fpppp( 5,17, 3,2),fpppp( 5,17, 3,3)/
     x 6.1981015d-04,-6.9505137d-05,-1.6657930d-07 /
      data fpppp( 5,17, 4,1),fpppp( 5,17, 4,2),fpppp( 5,17, 4,3)/
     x 6.1981015d-04,-6.6474673d-05,-1.7463945d-07 /
      data fpppp( 5,17, 5,1),fpppp( 5,17, 5,2),fpppp( 5,17, 5,3)/
     x 2.6952091d-04,-6.4474065d-05, 7.8423890d-08 /
      data fpppp( 5,17, 6,1),fpppp( 5,17, 6,2),fpppp( 5,17, 6,3)/
     x 5.1293230d-05, 3.0132416d-07, 2.6719517d-08 /
      data fpppp( 5,17, 7,1),fpppp( 5,17, 7,2),fpppp( 5,17, 7,3)/
     x-2.0570264d-04, 5.1829809d-05, 1.1291540d-07 /
      data fpppp( 5,17, 8,1),fpppp( 5,17, 8,2),fpppp( 5,17, 8,3)/
     x-3.8777758d-04,-1.7108466d-04,-6.2527635d-08 /
      data fpppp( 5,17, 9,1),fpppp( 5,17, 9,2),fpppp( 5,17, 9,3)/
     x-5.2065145d-04, 7.1157464d-04, 1.5226180d-07 /
      data fpppp( 5,17,10,1),fpppp( 5,17,10,2),fpppp( 5,17,10,3)/
     x-1.3814231d-03,-2.9034795d-03,-1.0484417d-06 /
      data fpppp( 5,17,11,1),fpppp( 5,17,11,2),fpppp( 5,17,11,3)/
     x 7.4040037d-03, 9.9191078d-03, 1.6638785d-06 /
      data fpppp( 5,17,12,1),fpppp( 5,17,12,2),fpppp( 5,17,12,3)/
     x-2.9697799d-02,-1.2883681d-02,-1.0020284d-06 /
      data fpppp( 5,17,13,1),fpppp( 5,17,13,2),fpppp( 5,17,13,3)/
     x 1.2186981d-03, 6.3131864d-03, 3.8228239d-07 /
      data fpppp( 5,17,14,1),fpppp( 5,17,14,2),fpppp( 5,17,14,3)/
     x-7.0683055d-03,-1.0917804d-03,-6.1233555d-08 /
      data fpppp( 5,17,15,1),fpppp( 5,17,15,2),fpppp( 5,17,15,3)/
     x-1.6119576d-02, 2.8129168d-04, 3.6739767d-08 /
      data fpppp( 5,17,16,1),fpppp( 5,17,16,2),fpppp( 5,17,16,3)/
     x-2.3956383d-02,-7.5840286d-05, 1.6102701d-09 /
      data fpppp( 5,17,17,1),fpppp( 5,17,17,2),fpppp( 5,17,17,3)/
     x-3.0571188d-02, 1.9278517d-05, 3.3301739d-09 /
      data fpppp( 5,17,18,1),fpppp( 5,17,18,2),fpppp( 5,17,18,3)/
     x-3.5965523d-02,-4.0335250d-06,-2.4193740d-09 /
      data fpppp( 5,17,19,1),fpppp( 5,17,19,2),fpppp( 5,17,19,3)/
     x-4.0145026d-02, 5.2780433d-07,-8.1121239d-09 /
      data fpppp( 5,17,20,1),fpppp( 5,17,20,2),fpppp( 5,17,20,3)/
     x-4.3002375d-02,-1.3922058d-06,-9.3637995d-09 /
      data fpppp( 5,17,21,1),fpppp( 5,17,21,2),fpppp( 5,17,21,3)/
     x-4.3002375d-02,-1.1331551d-06,-9.6062980d-09 /
      data fpppp( 5,17,22,1),fpppp( 5,17,22,2),fpppp( 5,17,22,3)/
     x-4.0145026d-02,-5.0839834d-07,-7.1421300d-09 /
      data fpppp( 5,17,23,1),fpppp( 5,17,23,2),fpppp( 5,17,23,3)/
     x-3.5965523d-02,-1.4776499d-07,-6.0568511d-09 /
      data fpppp( 5,18, 1,1),fpppp( 5,18, 1,2),fpppp( 5,18, 1,3)/
     x 1.4018292d-03,-3.8971021d-06, 7.8253905d-08 /
      data fpppp( 5,18, 2,1),fpppp( 5,18, 2,2),fpppp( 5,18, 2,3)/
     x 1.4957812d-03,-6.5857617d-06, 5.0308775d-08 /
      data fpppp( 5,18, 3,1),fpppp( 5,18, 3,2),fpppp( 5,18, 3,3)/
     x 1.5862931d-03,-1.7023822d-05,-9.7791824d-09 /
      data fpppp( 5,18, 4,1),fpppp( 5,18, 4,2),fpppp( 5,18, 4,3)/
     x 1.5862931d-03,-8.8396902d-06,-9.4194962d-09 /
      data fpppp( 5,18, 5,1),fpppp( 5,18, 5,2),fpppp( 5,18, 5,3)/
     x 1.4957812d-03,-3.9322289d-05, 4.8870030d-08 /
      data fpppp( 5,18, 6,1),fpppp( 5,18, 6,2),fpppp( 5,18, 6,3)/
     x 1.4018292d-03, 1.1886488d-04, 8.3649198d-08 /
      data fpppp( 5,18, 7,1),fpppp( 5,18, 7,2),fpppp( 5,18, 7,3)/
     x 1.3028697d-03,-4.1267081d-04, 8.5082180d-09 /
      data fpppp( 5,18, 8,1),fpppp( 5,18, 8,2),fpppp( 5,18, 8,3)/
     x 1.3274153d-03, 1.1944728d-03,-7.8116370d-09 /
      data fpppp( 5,18, 9,1),fpppp( 5,18, 9,2),fpppp( 5,18, 9,3)/
     x 1.3713715d-03,-4.3779415d-03,-1.7284643d-07 /
      data fpppp( 5,18,10,1),fpppp( 5,18,10,2),fpppp( 5,18,10,3)/
     x 2.1313549d-03, 1.4418160d-02, 2.3854939d-07 /
      data fpppp( 5,18,11,1),fpppp( 5,18,11,2),fpppp( 5,18,11,3)/
     x-5.1353035d-03,-3.4273741d-02,-1.3683550d-06 /
      data fpppp( 5,18,12,1),fpppp( 5,18,12,2),fpppp( 5,18,12,3)/
     x 2.4106925d-02, 4.6418071d-02, 1.7066010d-06 /
      data fpppp( 5,18,13,1),fpppp( 5,18,13,2),fpppp( 5,18,13,3)/
     x-1.8741810d-03,-3.4865468d-02,-5.6231945d-07 /
      data fpppp( 5,18,14,1),fpppp( 5,18,14,2),fpppp( 5,18,14,3)/
     x 7.8774494d-03, 9.7794338d-03, 1.2806897d-07 /
      data fpppp( 5,18,15,1),fpppp( 5,18,15,2),fpppp( 5,18,15,3)/
     x 1.7351910d-02,-1.9768853d-03,-3.9844396d-08 /
      data fpppp( 5,18,16,1),fpppp( 5,18,16,2),fpppp( 5,18,16,3)/
     x 2.5593449d-02, 1.2207014d-03, 6.6126778d-09 /
      data fpppp( 5,18,17,1),fpppp( 5,18,17,2),fpppp( 5,18,17,3)/
     x 3.2550612d-02, 3.6783794d-04,-8.7408931d-09 /
      data fpppp( 5,18,18,1),fpppp( 5,18,18,2),fpppp( 5,18,18,3)/
     x 3.8232584d-02, 5.5436301d-04,-9.5952744d-09 /
      data fpppp( 5,18,19,1),fpppp( 5,18,19,2),fpppp( 5,18,19,3)/
     x 4.2633935d-02, 6.8414670d-04,-1.2655310d-08 /
      data fpppp( 5,18,20,1),fpppp( 5,18,20,2),fpppp( 5,18,20,3)/
     x 4.5487329d-02, 8.0319333d-04,-1.6280150d-08 /
      data fpppp( 5,18,21,1),fpppp( 5,18,21,2),fpppp( 5,18,21,3)/
     x 4.5487329d-02, 8.0671684d-04,-1.6345108d-08 /
      data fpppp( 5,18,22,1),fpppp( 5,18,22,2),fpppp( 5,18,22,3)/
     x 4.2633935d-02, 6.7005266d-04,-1.2395479d-08 /
      data fpppp( 5,18,23,1),fpppp( 5,18,23,2),fpppp( 5,18,23,3)/
     x 3.8232584d-02, 6.0721564d-04,-1.0569641d-08 /
      data fpppp( 5,19, 1,1),fpppp( 5,19, 1,2),fpppp( 5,19, 1,3)/
     x 2.2629647d-03, 4.0449628d-17,-1.6791521d-07 /
      data fpppp( 5,19, 2,1),fpppp( 5,19, 2,2),fpppp( 5,19, 2,3)/
     x 2.2479871d-03,-6.5223599d-18, 3.7171333d-09 /
      data fpppp( 5,19, 3,1),fpppp( 5,19, 3,2),fpppp( 5,19, 3,3)/
     x 1.8851662d-03,-1.1220111d-17, 3.7003177d-07 /
      data fpppp( 5,19, 4,1),fpppp( 5,19, 4,2),fpppp( 5,19, 4,3)/
     x 1.8851662d-03,-1.1756079d-17, 3.7260245d-07 /
      data fpppp( 5,19, 5,1),fpppp( 5,19, 5,2),fpppp( 5,19, 5,3)/
     x 2.2479871d-03, 1.3950414d-17,-6.5656090d-09 /
      data fpppp( 5,19, 6,1),fpppp( 5,19, 6,2),fpppp( 5,19, 6,3)/
     x 2.2629647d-03, 5.7469760d-18,-1.2935493d-07 /
      data fpppp( 5,19, 7,1),fpppp( 5,19, 7,2),fpppp( 5,19, 7,3)/
     x 2.2783689d-03, 2.1113482d-17,-1.2281220d-07 /
      data fpppp( 5,19, 8,1),fpppp( 5,19, 8,2),fpppp( 5,19, 8,3)/
     x 2.4360589d-03,-2.3460379d-17,-1.0811504d-08 /
      data fpppp( 5,19, 9,1),fpppp( 5,19, 9,2),fpppp( 5,19, 9,3)/
     x 2.5714136d-03, 9.7655830d-18,-2.9642941d-07 /
      data fpppp( 5,19,10,1),fpppp( 5,19,10,2),fpppp( 5,19,10,3)/
     x 4.1405591d-03,-3.2045502d-17, 7.5284312d-07 /
      data fpppp( 5,19,11,1),fpppp( 5,19,11,2),fpppp( 5,19,11,3)/
     x-1.0855077d-02, 2.9349992d-17,-2.9112211d-06 /
      data fpppp( 5,19,12,1),fpppp( 5,19,12,2),fpppp( 5,19,12,3)/
     x 5.0407702d-02,-2.3537923d-17, 3.2021563d-06 /
      data fpppp( 5,19,13,1),fpppp( 5,19,13,2),fpppp( 5,19,13,3)/
     x-3.8230642d-03, 1.6558224d-17,-1.1102086d-06 /
      data fpppp( 5,19,14,1),fpppp( 5,19,14,2),fpppp( 5,19,14,3)/
     x 1.6024741d-02, 2.2027852d-17, 2.3380193d-07 /
      data fpppp( 5,19,15,1),fpppp( 5,19,15,2),fpppp( 5,19,15,3)/
     x 3.5422085d-02, 4.1659559d-17,-8.5215161d-08 /
      data fpppp( 5,19,16,1),fpppp( 5,19,16,2),fpppp( 5,19,16,3)/
     x 5.2309009d-02,-1.6726490d-17, 7.6266856d-09 /
      data fpppp( 5,19,17,1),fpppp( 5,19,17,2),fpppp( 5,19,17,3)/
     x 6.6561128d-02,-3.9757435d-17,-1.8464293d-08 /
      data fpppp( 5,19,18,1),fpppp( 5,19,18,2),fpppp( 5,19,18,3)/
     x 7.8197950d-02,-7.7756229d-18,-1.6256431d-08 /
      data fpppp( 5,19,19,1),fpppp( 5,19,19,2),fpppp( 5,19,19,3)/
     x 8.7207222d-02, 2.5526227d-18,-1.7901333d-08 /
      data fpppp( 5,19,20,1),fpppp( 5,19,20,2),fpppp( 5,19,20,3)/
     x 9.2894568d-02, 4.8358176d-18,-1.9479904d-08 /
      data fpppp( 5,19,21,1),fpppp( 5,19,21,2),fpppp( 5,19,21,3)/
     x 9.2894568d-02, 7.1561853d-18,-1.9523016d-08 /
      data fpppp( 5,19,22,1),fpppp( 5,19,22,2),fpppp( 5,19,22,3)/
     x 8.7207222d-02,-7.2227363d-18,-1.7728883d-08 /
      data fpppp( 5,19,23,1),fpppp( 5,19,23,2),fpppp( 5,19,23,3)/
     x 7.8197950d-02,-6.0930436d-20,-1.6903118d-08 /
      data fpppp( 6, 1, 1,1),fpppp( 6, 1, 1,2),fpppp( 6, 1, 1,3)/
     x 3.8436761d-03,-5.6972167d-16, 2.1520047d-05 /
      data fpppp( 6, 1, 2,1),fpppp( 6, 1, 2,2),fpppp( 6, 1, 2,3)/
     x-1.0370354d-02, 1.0639387d-16, 1.1806294d-05 /
      data fpppp( 6, 1, 3,1),fpppp( 6, 1, 3,2),fpppp( 6, 1, 3,3)/
     x-4.5433034d-03, 4.7360682d-17,-7.0850827d-06 /
      data fpppp( 6, 1, 4,1),fpppp( 6, 1, 4,2),fpppp( 6, 1, 4,3)/
     x-4.5433034d-03, 1.9044543d-16,-1.0451746d-05 /
      data fpppp( 6, 1, 5,1),fpppp( 6, 1, 5,2),fpppp( 6, 1, 5,3)/
     x-1.0370354d-02,-3.6697332d-16, 2.5272946d-05 /
      data fpppp( 6, 1, 6,1),fpppp( 6, 1, 6,2),fpppp( 6, 1, 6,3)/
     x 3.8436761d-03, 1.1945800d-16,-2.8979899d-05 /
      data fpppp( 6, 1, 7,1),fpppp( 6, 1, 7,2),fpppp( 6, 1, 7,3)/
     x 3.7133792d-02,-6.1898563d-17, 1.5915355d-06 /
      data fpppp( 6, 1, 8,1),fpppp( 6, 1, 8,2),fpppp( 6, 1, 8,3)/
     x 4.5421825d-02, 3.3368578d-16, 8.1972315d-06 /
      data fpppp( 6, 1, 9,1),fpppp( 6, 1, 9,2),fpppp( 6, 1, 9,3)/
     x 2.5795970d-02, 6.3080759d-17, 3.8443177d-06 /
      data fpppp( 6, 1,10,1),fpppp( 6, 1,10,2),fpppp( 6, 1,10,3)/
     x 4.8115383d-03, 1.5610069d-16, 1.5372652d-06 /
      data fpppp( 6, 1,11,1),fpppp( 6, 1,11,2),fpppp( 6, 1,11,3)/
     x-4.1757735d-03, 2.9214352d-16, 2.2662664d-06 /
      data fpppp( 6, 1,12,1),fpppp( 6, 1,12,2),fpppp( 6, 1,12,3)/
     x-1.5114338d-02,-1.2565055d-16, 1.7456506d-06 /
      data fpppp( 6, 1,13,1),fpppp( 6, 1,13,2),fpppp( 6, 1,13,3)/
     x 8.2434859d-04, 1.8510009d-16, 2.2185393d-06 /
      data fpppp( 6, 1,14,1),fpppp( 6, 1,14,2),fpppp( 6, 1,14,3)/
     x 7.4192608d-03, 1.1452029d-16, 1.7423197d-06 /
      data fpppp( 6, 1,15,1),fpppp( 6, 1,15,2),fpppp( 6, 1,15,3)/
     x 2.8488181d-02, 6.1223574d-17, 3.2776937d-06 /
      data fpppp( 6, 1,16,1),fpppp( 6, 1,16,2),fpppp( 6, 1,16,3)/
     x 4.9298060d-02, 3.1564665d-16, 9.3570916d-06 /
      data fpppp( 6, 1,17,1),fpppp( 6, 1,17,2),fpppp( 6, 1,17,3)/
     x 6.3022410d-02, 7.5561318d-17,-6.8153567d-07 /
      data fpppp( 6, 1,18,1),fpppp( 6, 1,18,2),fpppp( 6, 1,18,3)/
     x 2.7774975d-03,-5.3779784d-17,-2.7001105d-05 /
      data fpppp( 6, 1,19,1),fpppp( 6, 1,19,2),fpppp( 6, 1,19,3)/
     x-7.4748204d-03, 2.3688878d-16, 2.4577675d-05 /
      data fpppp( 6, 1,20,1),fpppp( 6, 1,20,2),fpppp( 6, 1,20,3)/
     x-4.1820235d-03, 7.8516905d-18,-1.0322947d-05 /
      data fpppp( 6, 1,21,1),fpppp( 6, 1,21,2),fpppp( 6, 1,21,3)/
     x-4.1820235d-03, 1.0107842d-16,-7.1014720d-06 /
      data fpppp( 6, 1,22,1),fpppp( 6, 1,22,2),fpppp( 6, 1,22,3)/
     x-7.4748204d-03,-6.3516312d-17, 1.1691776d-05 /
      data fpppp( 6, 1,23,1),fpppp( 6, 1,23,2),fpppp( 6, 1,23,3)/
     x 2.7774975d-03, 5.6756666d-16, 2.1321018d-05 /
      data fpppp( 6, 2, 1,1),fpppp( 6, 2, 1,2),fpppp( 6, 2, 1,3)/
     x 2.6686684d-03,-5.7313785d-03, 1.1427080d-05 /
      data fpppp( 6, 2, 2,1),fpppp( 6, 2, 2,2),fpppp( 6, 2, 2,3)/
     x-4.3243253d-03,-3.4758735d-03, 6.4088788d-06 /
      data fpppp( 6, 2, 3,1),fpppp( 6, 2, 3,2),fpppp( 6, 2, 3,3)/
     x-1.8045757d-03, 1.0963783d-03,-3.4123768d-06 /
      data fpppp( 6, 2, 4,1),fpppp( 6, 2, 4,2),fpppp( 6, 2, 4,3)/
     x-1.8045757d-03, 1.5530815d-03,-5.0434353d-06 /
      data fpppp( 6, 2, 5,1),fpppp( 6, 2, 5,2),fpppp( 6, 2, 5,3)/
     x-4.3243253d-03,-5.3026864d-03, 1.2933113d-05 /
      data fpppp( 6, 2, 6,1),fpppp( 6, 2, 6,2),fpppp( 6, 2, 6,3)/
     x 2.6686684d-03, 1.1191699d-03,-1.3038797d-05 /
      data fpppp( 6, 2, 7,1),fpppp( 6, 2, 7,2),fpppp( 6, 2, 7,3)/
     x 1.7750737d-02,-2.5508009d-03, 4.2363404d-08 /
      data fpppp( 6, 2, 8,1),fpppp( 6, 2, 8,2),fpppp( 6, 2, 8,3)/
     x 2.1359904d-02, 1.4278605d-02, 3.5004544d-06 /
      data fpppp( 6, 2, 9,1),fpppp( 6, 2, 9,2),fpppp( 6, 2, 9,3)/
     x 1.1104491d-02,-8.5651855d-03, 1.5658804d-06 /
      data fpppp( 6, 2,10,1),fpppp( 6, 2,10,2),fpppp( 6, 2,10,3)/
     x 1.2031337d-03, 3.5128079d-03, 7.0392900d-07 /
      data fpppp( 6, 2,11,1),fpppp( 6, 2,11,2),fpppp( 6, 2,11,3)/
     x-3.8315684d-03,-4.2048507d-03, 9.3849409d-07 /
      data fpppp( 6, 2,12,1),fpppp( 6, 2,12,2),fpppp( 6, 2,12,3)/
     x-8.6180056d-03,-2.2976392d-04, 7.7395197d-07 /
      data fpppp( 6, 2,13,1),fpppp( 6, 2,13,2),fpppp( 6, 2,13,3)/
     x-1.7815160d-03,-6.4785675d-03, 9.2812202d-07 /
      data fpppp( 6, 2,14,1),fpppp( 6, 2,14,2),fpppp( 6, 2,14,3)/
     x 2.4880320d-03, 5.6819495d-03, 7.5630483d-07 /
      data fpppp( 6, 2,15,1),fpppp( 6, 2,15,2),fpppp( 6, 2,15,3)/
     x 1.2410210d-02,-1.0302884d-02, 1.4788150d-06 /
      data fpppp( 6, 2,16,1),fpppp( 6, 2,16,2),fpppp( 6, 2,16,3)/
     x 2.2263697d-02, 1.7163555d-02, 3.7568429d-06 /
      data fpppp( 6, 2,17,1),fpppp( 6, 2,17,2),fpppp( 6, 2,17,3)/
     x 2.7965845d-02,-3.9957622d-03,-6.5591522d-07 /
      data fpppp( 6, 2,18,1),fpppp( 6, 2,18,2),fpppp( 6, 2,18,3)/
     x 2.0011981d-03,-7.9824237d-04,-1.2325569d-05 /
      data fpppp( 6, 2,19,1),fpppp( 6, 2,19,2),fpppp( 6, 2,19,3)/
     x-2.8940605d-03,-2.6356098d-03, 1.2618415d-05 /
      data fpppp( 6, 2,20,1),fpppp( 6, 2,20,2),fpppp( 6, 2,20,3)/
     x-1.4864521d-03, 7.9016427d-04,-4.9864094d-06 /
      data fpppp( 6, 2,21,1),fpppp( 6, 2,21,2),fpppp( 6, 2,21,3)/
     x-1.4864521d-03, 6.2706006d-04,-3.4123793d-06 /
      data fpppp( 6, 2,22,1),fpppp( 6, 2,22,2),fpppp( 6, 2,22,3)/
     x-2.8940605d-03,-1.9831930d-03, 6.3222943d-06 /
      data fpppp( 6, 2,23,1),fpppp( 6, 2,23,2),fpppp( 6, 2,23,3)/
     x 2.0011981d-03,-3.2448056d-03, 1.1284883d-05 /
      data fpppp( 6, 3, 1,1),fpppp( 6, 3, 1,2),fpppp( 6, 3, 1,3)/
     x-2.7177991d-03, 1.8812959d-03,-4.2668804d-05 /
      data fpppp( 6, 3, 2,1),fpppp( 6, 3, 2,2),fpppp( 6, 3, 2,3)/
     x 8.4301511d-03, 1.2758241d-03,-2.6091947d-05 /
      data fpppp( 6, 3, 3,1),fpppp( 6, 3, 3,2),fpppp( 6, 3, 3,3)/
     x 5.2191597d-03,-3.2846870d-04, 6.2447372d-06 /
      data fpppp( 6, 3, 4,1),fpppp( 6, 3, 4,2),fpppp( 6, 3, 4,3)/
     x 5.2191597d-03, 2.0852435d-04, 1.1818754d-05 /
      data fpppp( 6, 3, 5,1),fpppp( 6, 3, 5,2),fpppp( 6, 3, 5,3)/
     x 8.4301511d-03,-8.7214808d-04,-4.8388013d-05 /
      data fpppp( 6, 3, 6,1),fpppp( 6, 3, 6,2),fpppp( 6, 3, 6,3)/
     x-2.7177991d-03, 9.9361917d-03, 4.0941442d-05 /
      data fpppp( 6, 3, 7,1),fpppp( 6, 3, 7,2),fpppp( 6, 3, 7,3)/
     x-3.1877189d-02,-1.2205290d-02, 5.6371250d-06 /
      data fpppp( 6, 3, 8,1),fpppp( 6, 3, 8,2),fpppp( 6, 3, 8,3)/
     x-3.0373730d-02, 9.0432737d-03,-8.1890208d-06 /
      data fpppp( 6, 3, 9,1),fpppp( 6, 3, 9,2),fpppp( 6, 3, 9,3)/
     x-2.4976948d-02,-1.1449826d-02,-2.3161069d-06 /
      data fpppp( 6, 3,10,1),fpppp( 6, 3,10,2),fpppp( 6, 3,10,3)/
     x-1.1631921d-02, 1.1823269d-02,-1.4159388d-06 /
      data fpppp( 6, 3,11,1),fpppp( 6, 3,11,2),fpppp( 6, 3,11,3)/
     x-9.5366420d-03,-1.3066867d-02,-1.5780244d-06 /
      data fpppp( 6, 3,12,1),fpppp( 6, 3,12,2),fpppp( 6, 3,12,3)/
     x-3.6108322d-03, 1.6243820d-02,-1.2405341d-06 /
      data fpppp( 6, 3,13,1),fpppp( 6, 3,13,2),fpppp( 6, 3,13,3)/
     x-1.5923923d-02,-1.9983305d-02,-1.5555030d-06 /
      data fpppp( 6, 3,14,1),fpppp( 6, 3,14,2),fpppp( 6, 3,14,3)/
     x-1.3199490d-02, 1.8191213d-02,-1.4258408d-06 /
      data fpppp( 6, 3,15,1),fpppp( 6, 3,15,2),fpppp( 6, 3,15,3)/
     x-2.6048091d-02,-1.9377361d-02,-2.4361909d-06 /
      data fpppp( 6, 3,16,1),fpppp( 6, 3,16,2),fpppp( 6, 3,16,3)/
     x-2.7872817d-02, 3.3076239d-02,-8.1566128d-06 /
      data fpppp( 6, 3,17,1),fpppp( 6, 3,17,2),fpppp( 6, 3,17,3)/
     x-5.0421633d-02,-4.8631427d-02, 7.1607126d-06 /
      data fpppp( 6, 3,18,1),fpppp( 6, 3,18,2),fpppp( 6, 3,18,3)/
     x-2.0345958d-03, 3.2513409d-02, 3.8583509d-05 /
      data fpppp( 6, 3,19,1),fpppp( 6, 3,19,2),fpppp( 6, 3,19,3)/
     x 6.5064523d-03,-6.6467333d-03,-4.7093394d-05 /
      data fpppp( 6, 3,20,1),fpppp( 6, 3,20,2),fpppp( 6, 3,20,3)/
     x 4.6184639d-03, 1.3000362d-03, 1.1594174d-05 /
      data fpppp( 6, 3,21,1),fpppp( 6, 3,21,2),fpppp( 6, 3,21,3)/
     x 4.6184639d-03,-7.3486730d-04, 6.2271911d-06 /
      data fpppp( 6, 3,22,1),fpppp( 6, 3,22,2),fpppp( 6, 3,22,3)/
     x 6.5064523d-03, 1.4928808d-03,-2.5625464d-05 /
      data fpppp( 6, 3,23,1),fpppp( 6, 3,23,2),fpppp( 6, 3,23,3)/
     x-2.0345958d-03, 1.9898557d-03,-4.1921231d-05 /
      data fpppp( 6, 4, 1,1),fpppp( 6, 4, 1,2),fpppp( 6, 4, 1,3)/
     x 6.6358428d-03,-2.4614260d-03, 5.7245524d-05 /
      data fpppp( 6, 4, 2,1),fpppp( 6, 4, 2,2),fpppp( 6, 4, 2,3)/
     x-2.2949399d-03,-1.4479530d-03, 3.6269164d-05 /
      data fpppp( 6, 4, 3,1),fpppp( 6, 4, 3,2),fpppp( 6, 4, 3,3)/
     x-2.7546318d-03, 6.5204685d-04,-5.0435771d-06 /
      data fpppp( 6, 4, 4,1),fpppp( 6, 4, 4,2),fpppp( 6, 4, 4,3)/
     x-2.7546318d-03, 7.7757106d-04,-1.1407632d-05 /
      data fpppp( 6, 4, 5,1),fpppp( 6, 4, 5,2),fpppp( 6, 4, 5,3)/
     x-2.2949399d-03,-1.9500499d-03, 6.1725383d-05 /
      data fpppp( 6, 4, 6,1),fpppp( 6, 4, 6,2),fpppp( 6, 4, 6,3)/
     x 6.6358428d-03,-5.7856278d-04,-3.8215298d-05 /
      data fpppp( 6, 4, 7,1),fpppp( 6, 4, 7,2),fpppp( 6, 4, 7,3)/
     x 2.4351930d-02, 5.8043885d-03,-1.3771881d-05 /
      data fpppp( 6, 4, 8,1),fpppp( 6, 4, 8,2),fpppp( 6, 4, 8,3)/
     x 1.4743630d-02,-3.6628419d-03, 4.5959474d-06 /
      data fpppp( 6, 4, 9,1),fpppp( 6, 4, 9,2),fpppp( 6, 4, 9,3)/
     x 1.3806471d-02,-1.7356504d-03,-5.8566936d-07 /
      data fpppp( 6, 4,10,1),fpppp( 6, 4,10,2),fpppp( 6, 4,10,3)/
     x 7.8262992d-03, 4.3132773d-03, 9.6705423d-07 /
      data fpppp( 6, 4,11,1),fpppp( 6, 4,11,2),fpppp( 6, 4,11,3)/
     x 5.9307597d-03,-7.2935967d-03, 6.6068835d-08 /
      data fpppp( 6, 4,12,1),fpppp( 6, 4,12,2),fpppp( 6, 4,12,3)/
     x 6.6083970d-03, 8.1402735d-03, 3.9473607d-07 /
      data fpppp( 6, 4,13,1),fpppp( 6, 4,13,2),fpppp( 6, 4,13,3)/
     x 1.0311568d-02,-8.1219447d-03, 1.3709906d-07 /
      data fpppp( 6, 4,14,1),fpppp( 6, 4,14,2),fpppp( 6, 4,14,3)/
     x 8.7600139d-03, 6.1416470d-03, 5.7847132d-07 /
      data fpppp( 6, 4,15,1),fpppp( 6, 4,15,2),fpppp( 6, 4,15,3)/
     x 1.3824761d-02,-5.6058272d-03, 1.0552485d-06 /
      data fpppp( 6, 4,16,1),fpppp( 6, 4,16,2),fpppp( 6, 4,16,3)/
     x 2.8481989d-03, 1.0149210d-02, 2.0261561d-06 /
      data fpppp( 6, 4,17,1),fpppp( 6, 4,17,2),fpppp( 6, 4,17,3)/
     x 2.2849084d-02,-1.6824502d-02,-1.2291185d-05 /
      data fpppp( 6, 4,18,1),fpppp( 6, 4,18,2),fpppp( 6, 4,18,3)/
     x 5.3378412d-03, 1.3458904d-02,-3.7324812d-05 /
      data fpppp( 6, 4,19,1),fpppp( 6, 4,19,2),fpppp( 6, 4,19,3)/
     x-9.6217040d-04,-4.7391602d-03, 6.0328717d-05 /
      data fpppp( 6, 4,20,1),fpppp( 6, 4,20,2),fpppp( 6, 4,20,3)/
     x-1.2093264d-03, 1.1408545d-03,-1.1179403d-05 /
      data fpppp( 6, 4,21,1),fpppp( 6, 4,21,2),fpppp( 6, 4,21,3)/
     x-1.2093264d-03, 1.4676882d-04,-4.9599101d-06 /
      data fpppp( 6, 4,22,1),fpppp( 6, 4,22,2),fpppp( 6, 4,22,3)/
     x-9.6217040d-04,-7.6281756d-04, 3.5450746d-05 /
      data fpppp( 6, 4,23,1),fpppp( 6, 4,23,2),fpppp( 6, 4,23,3)/
     x 5.3378412d-03,-1.4523807d-03, 5.5967583d-05 /
      data fpppp( 6, 5, 1,1),fpppp( 6, 5, 1,2),fpppp( 6, 5, 1,3)/
     x-4.9227790d-03,-8.5805779d-04,-4.0163105d-05 /
      data fpppp( 6, 5, 2,1),fpppp( 6, 5, 2,2),fpppp( 6, 5, 2,3)/
     x 8.7659596d-04,-3.1835080d-04,-2.4381380d-05 /
      data fpppp( 6, 5, 3,1),fpppp( 6, 5, 3,2),fpppp( 6, 5, 3,3)/
     x 7.7413066d-03, 8.6371212d-04, 7.3621559d-06 /
      data fpppp( 6, 5, 4,1),fpppp( 6, 5, 4,2),fpppp( 6, 5, 4,3)/
     x 7.7413066d-03, 8.1900322d-04, 1.0992435d-05 /
      data fpppp( 6, 5, 5,1),fpppp( 6, 5, 5,2),fpppp( 6, 5, 5,3)/
     x 8.7659596d-04,-1.3951522d-04,-3.8902498d-05 /
      data fpppp( 6, 5, 6,1),fpppp( 6, 5, 6,2),fpppp( 6, 5, 6,3)/
     x-4.9227790d-03,-1.5286912d-03, 1.4291086d-05 /
      data fpppp( 6, 5, 7,1),fpppp( 6, 5, 7,2),fpppp( 6, 5, 7,3)/
     x-9.8557610d-03, 6.6329834d-04, 1.0239548d-05 /
      data fpppp( 6, 5, 8,1),fpppp( 6, 5, 8,2),fpppp( 6, 5, 8,3)/
     x-3.0222802d-03,-1.9874731d-04,-1.4342189d-06 /
      data fpppp( 6, 5, 9,1),fpppp( 6, 5, 9,2),fpppp( 6, 5, 9,3)/
     x-1.2164546d-03,-1.3175182d-06, 1.1291972d-06 /
      data fpppp( 6, 5,10,1),fpppp( 6, 5,10,2),fpppp( 6, 5,10,3)/
     x 2.6155249d-04, 8.2332074d-07,-7.0671928d-07 /
      data fpppp( 6, 5,11,1),fpppp( 6, 5,11,2),fpppp( 6, 5,11,3)/
     x 2.9077363d-03,-7.3675586d-05, 2.0902106d-07 /
      data fpppp( 6, 5,12,1),fpppp( 6, 5,12,2),fpppp( 6, 5,12,3)/
     x 5.6188496d-04, 1.8378947d-04,-2.2501675d-07 /
      data fpppp( 6, 5,13,1),fpppp( 6, 5,13,2),fpppp( 6, 5,13,3)/
     x 1.9118942d-03,-7.3639007d-04, 4.2221330d-08 /
      data fpppp( 6, 5,14,1),fpppp( 6, 5,14,2),fpppp( 6, 5,14,3)/
     x 7.5583090d-05, 2.6805397d-03, 2.3824109d-08 /
      data fpppp( 6, 5,15,1),fpppp( 6, 5,15,2),fpppp( 6, 5,15,3)/
     x-1.0778280d-03,-1.0137250d-02,-1.7342718d-06 /
      data fpppp( 6, 5,16,1),fpppp( 6, 5,16,2),fpppp( 6, 5,16,3)/
     x 1.5083302d-02, 1.6018731d-02, 3.2842745d-06 /
      data fpppp( 6, 5,17,1),fpppp( 6, 5,17,2),fpppp( 6, 5,17,3)/
     x-7.8660811d-04,-1.0746165d-02, 5.7265933d-06 /
      data fpppp( 6, 5,18,1),fpppp( 6, 5,18,2),fpppp( 6, 5,18,3)/
     x-2.8466423d-03, 3.2194222d-03, 1.6901914d-05 /
      data fpppp( 6, 5,19,1),fpppp( 6, 5,19,2),fpppp( 6, 5,19,3)/
     x 4.7542648d-04,-1.9820528d-03,-3.6491984d-05 /
      data fpppp( 6, 5,20,1),fpppp( 6, 5,20,2),fpppp( 6, 5,20,3)/
     x 2.3391277d-03, 1.0925312d-03, 9.0329761d-06 /
      data fpppp( 6, 5,21,1),fpppp( 6, 5,21,2),fpppp( 6, 5,21,3)/
     x 2.3391277d-03, 7.7751787d-04, 5.4899913d-06 /
      data fpppp( 6, 5,22,1),fpppp( 6, 5,22,2),fpppp( 6, 5,22,3)/
     x 4.7542648d-04,-7.2199947d-04,-2.2320045d-05 /
      data fpppp( 6, 5,23,1),fpppp( 6, 5,23,2),fpppp( 6, 5,23,3)/
     x-2.8466423d-03,-1.5057778d-03,-3.6242858d-05 /
      data fpppp( 6, 6, 1,1),fpppp( 6, 6, 1,2),fpppp( 6, 6, 1,3)/
     x 1.3793812d-03, 3.0978117d-04, 1.8568636d-05 /
      data fpppp( 6, 6, 2,1),fpppp( 6, 6, 2,2),fpppp( 6, 6, 2,3)/
     x 8.1422926d-04, 1.7882535d-04, 1.0437017d-05 /
      data fpppp( 6, 6, 3,1),fpppp( 6, 6, 3,2),fpppp( 6, 6, 3,3)/
     x-1.6614715d-02,-9.0747910d-05,-6.2095052d-06 /
      data fpppp( 6, 6, 4,1),fpppp( 6, 6, 4,2),fpppp( 6, 6, 4,3)/
     x-1.6614715d-02,-1.1007902d-04,-7.5716631d-06 /
      data fpppp( 6, 6, 5,1),fpppp( 6, 6, 5,2),fpppp( 6, 6, 5,3)/
     x 8.1422926d-04, 2.5614978d-04, 1.5885648d-05 /
      data fpppp( 6, 6, 6,1),fpppp( 6, 6, 6,2),fpppp( 6, 6, 6,3)/
     x 1.3793812d-03, 1.9814586d-05,-1.8637331d-06 /
      data fpppp( 6, 6, 7,1),fpppp( 6, 6, 7,2),fpppp( 6, 6, 7,3)/
     x 2.6994635d-03,-5.1651842d-05,-3.5213685d-06 /
      data fpppp( 6, 6, 8,1),fpppp( 6, 6, 8,2),fpppp( 6, 6, 8,3)/
     x 1.2096484d-03,-6.2806909d-06, 7.0712562d-07 /
      data fpppp( 6, 6, 9,1),fpppp( 6, 6, 9,2),fpppp( 6, 6, 9,3)/
     x 7.0276218d-04,-6.3163790d-05,-4.6645050d-07 /
      data fpppp( 6, 6,10,1),fpppp( 6, 6,10,2),fpppp( 6, 6,10,3)/
     x 3.9434855d-04,-1.1100735d-05, 1.8354992d-07 /
      data fpppp( 6, 6,11,1),fpppp( 6, 6,11,2),fpppp( 6, 6,11,3)/
     x-2.9123394d-04, 1.2047610d-04,-6.0410122d-08 /
      data fpppp( 6, 6,12,1),fpppp( 6, 6,12,2),fpppp( 6, 6,12,3)/
     x 1.8750426d-04,-2.0079021d-04, 3.1072123d-08 /
      data fpppp( 6, 6,13,1),fpppp( 6, 6,13,2),fpppp( 6, 6,13,3)/
     x-1.5970949d-04, 3.7034104d-04, 5.7747907d-08 /
      data fpppp( 6, 6,14,1),fpppp( 6, 6,14,2),fpppp( 6, 6,14,3)/
     x-3.8856640d-05,-7.6911848d-04,-2.9759807d-07 /
      data fpppp( 6, 6,15,1),fpppp( 6, 6,15,2),fpppp( 6, 6,15,3)/
     x 6.6410790d-04, 1.4943673d-03, 1.4343876d-06 /
      data fpppp( 6, 6,16,1),fpppp( 6, 6,16,2),fpppp( 6, 6,16,3)/
     x-1.1111581d-02,-2.0371529d-03,-2.4850598d-06 /
      data fpppp( 6, 6,17,1),fpppp( 6, 6,17,2),fpppp( 6, 6,17,3)/
     x 5.7472867d-04, 1.1860341d-03,-2.7339393d-07 /
      data fpppp( 6, 6,18,1),fpppp( 6, 6,18,2),fpppp( 6, 6,18,3)/
     x 7.6423454d-04,-2.7952670d-04,-4.3059726d-06 /
      data fpppp( 6, 6,19,1),fpppp( 6, 6,19,2),fpppp( 6, 6,19,3)/
     x-2.3160160d-04,-4.8663841d-04, 1.0048902d-05 /
      data fpppp( 6, 6,20,1),fpppp( 6, 6,20,2),fpppp( 6, 6,20,3)/
     x-3.7935559d-04, 4.1791463d-04,-2.9963099d-06 /
      data fpppp( 6, 6,21,1),fpppp( 6, 6,21,2),fpppp( 6, 6,21,3)/
     x-3.7935559d-04, 3.8804581d-04,-2.0259314d-06 /
      data fpppp( 6, 6,22,1),fpppp( 6, 6,22,2),fpppp( 6, 6,22,3)/
     x-2.3160160d-04,-3.6716313d-04, 6.1673883d-06 /
      data fpppp( 6, 6,23,1),fpppp( 6, 6,23,2),fpppp( 6, 6,23,3)/
     x 7.6423454d-04,-7.2755899d-04, 1.0249705d-05 /
      data fpppp( 6, 7, 1,1),fpppp( 6, 7, 1,2),fpppp( 6, 7, 1,3)/
     x 2.0196924d-03,-6.8114454d-03,-1.4730910d-05 /
      data fpppp( 6, 7, 2,1),fpppp( 6, 7, 2,2),fpppp( 6, 7, 2,3)/
     x-1.1089392d-02,-3.5459998d-03,-8.1472711d-06 /
      data fpppp( 6, 7, 3,1),fpppp( 6, 7, 3,2),fpppp( 6, 7, 3,3)/
     x 2.1240361d-02, 3.1808668d-03, 5.3151559d-06 /
      data fpppp( 6, 7, 4,1),fpppp( 6, 7, 4,2),fpppp( 6, 7, 4,3)/
     x 2.1240361d-02, 3.6542716d-03, 6.4445558d-06 /
      data fpppp( 6, 7, 5,1),fpppp( 6, 7, 5,2),fpppp( 6, 7, 5,3)/
     x-1.1089392d-02,-5.4396189d-03,-1.2664870d-05 /
      data fpppp( 6, 7, 6,1),fpppp( 6, 7, 6,2),fpppp( 6, 7, 6,3)/
     x 2.0196924d-03, 2.8962626d-04, 2.2100870d-06 /
      data fpppp( 6, 7, 7,1),fpppp( 6, 7, 7,2),fpppp( 6, 7, 7,3)/
     x 6.4520166d-04,-1.5785195d-04, 1.7257777d-06 /
      data fpppp( 6, 7, 8,1),fpppp( 6, 7, 8,2),fpppp( 6, 7, 8,3)/
     x-2.6140701d-04, 2.4634436d-05,-7.7193122d-07 /
      data fpppp( 6, 7, 9,1),fpppp( 6, 7, 9,2),fpppp( 6, 7, 9,3)/
     x-2.2350237d-05,-3.7828009d-05, 2.5214375d-07 /
      data fpppp( 6, 7,10,1),fpppp( 6, 7,10,2),fpppp( 6, 7,10,3)/
     x-2.7960180d-05, 1.1203448d-05,-8.2868536d-08 /
      data fpppp( 6, 7,11,1),fpppp( 6, 7,11,2),fpppp( 6, 7,11,3)/
     x 2.1291301d-04,-3.4827197d-06, 3.4473013d-08 /
      data fpppp( 6, 7,12,1),fpppp( 6, 7,12,2),fpppp( 6, 7,12,3)/
     x 1.3533872d-04,-3.5602744d-07, 6.1420559d-09 /
      data fpppp( 6, 7,13,1),fpppp( 6, 7,13,2),fpppp( 6, 7,13,3)/
     x 1.7929407d-04,-3.1290394d-05, 3.1825879d-10 /
      data fpppp( 6, 7,14,1),fpppp( 6, 7,14,2),fpppp( 6, 7,14,3)/
     x 3.6201406d-04, 5.4370380d-05, 1.0402952d-07 /
      data fpppp( 6, 7,15,1),fpppp( 6, 7,15,2),fpppp( 6, 7,15,3)/
     x-5.7804015d-05,-4.9432311d-05,-3.5893521d-07 /
      data fpppp( 6, 7,16,1),fpppp( 6, 7,16,2),fpppp( 6, 7,16,3)/
     x 3.7929536d-03, 5.9877379d-06, 6.7556954d-07 /
      data fpppp( 6, 7,17,1),fpppp( 6, 7,17,2),fpppp( 6, 7,17,3)/
     x-2.7290496d-05, 4.3501781d-05, 1.3145921d-07 /
      data fpppp( 6, 7,18,1),fpppp( 6, 7,18,2),fpppp( 6, 7,18,3)/
     x-1.7952121d-04,-8.7901219d-05, 1.0634246d-06 /
      data fpppp( 6, 7,19,1),fpppp( 6, 7,19,2),fpppp( 6, 7,19,3)/
     x-3.0045791d-05, 2.6365044d-04,-1.9748942d-06 /
      data fpppp( 6, 7,20,1),fpppp( 6, 7,20,2),fpppp( 6, 7,20,3)/
     x-9.9268947d-04,-1.4493215d-04, 2.8296963d-07 /
      data fpppp( 6, 7,21,1),fpppp( 6, 7,21,2),fpppp( 6, 7,21,3)/
     x-9.9268947d-04,-1.1919369d-04, 8.8729657d-08 /
      data fpppp( 6, 7,22,1),fpppp( 6, 7,22,2),fpppp( 6, 7,22,3)/
     x-3.0045791d-05, 1.6069660d-04,-1.1979344d-06 /
      data fpppp( 6, 7,23,1),fpppp( 6, 7,23,2),fpppp( 6, 7,23,3)/
     x-1.7952121d-04, 2.9817566d-04,-1.8501749d-06 /
      data fpppp( 6, 8, 1,1),fpppp( 6, 8, 1,2),fpppp( 6, 8, 1,3)/
     x-4.3196468d-03, 2.2000831d-02, 1.6469597d-05 /
      data fpppp( 6, 8, 2,1),fpppp( 6, 8, 2,2),fpppp( 6, 8, 2,3)/
     x 2.1258839d-02, 1.2953154d-02, 9.5897944d-06 /
      data fpppp( 6, 8, 3,1),fpppp( 6, 8, 3,2),fpppp( 6, 8, 3,3)/
     x-1.2605341d-02,-4.9280441d-03,-4.2913772d-06 /
      data fpppp( 6, 8, 4,1),fpppp( 6, 8, 4,2),fpppp( 6, 8, 4,3)/
     x-1.2605341d-02,-7.5647352d-03,-5.7985877d-06 /
      data fpppp( 6, 8, 5,1),fpppp( 6, 8, 5,2),fpppp( 6, 8, 5,3)/
     x 2.1258839d-02, 2.3499918d-02, 1.5618637d-05 /
      data fpppp( 6, 8, 6,1),fpppp( 6, 8, 6,2),fpppp( 6, 8, 6,3)/
     x-4.3196468d-03,-1.7549534d-02,-6.1385616d-06 /
      data fpppp( 6, 8, 7,1),fpppp( 6, 8, 7,2),fpppp( 6, 8, 7,3)/
     x-4.5346397d-03, 5.7206548d-03,-3.4313595d-06 /
      data fpppp( 6, 8, 8,1),fpppp( 6, 8, 8,2),fpppp( 6, 8, 8,3)/
     x 4.7638392d-04,-1.4866584d-03, 2.5060140d-06 /
      data fpppp( 6, 8, 9,1),fpppp( 6, 8, 9,2),fpppp( 6, 8, 9,3)/
     x 5.3482455d-05, 3.0329841d-04,-5.4056656d-07 /
      data fpppp( 6, 8,10,1),fpppp( 6, 8,10,2),fpppp( 6, 8,10,3)/
     x 1.0625701d-04, 8.0347716d-06, 1.9987772d-07 /
      data fpppp( 6, 8,11,1),fpppp( 6, 8,11,2),fpppp( 6, 8,11,3)/
     x-1.4844816d-04,-4.0056778d-05,-2.0453838d-08 /
      data fpppp( 6, 8,12,1),fpppp( 6, 8,12,2),fpppp( 6, 8,12,3)/
     x-1.2672508d-04, 4.2970950d-05, 3.6533791d-08 /
      data fpppp( 6, 8,13,1),fpppp( 6, 8,13,2),fpppp( 6, 8,13,3)/
     x 6.2886652d-05,-6.3822461d-05, 2.5014413d-08 /
      data fpppp( 6, 8,14,1),fpppp( 6, 8,14,2),fpppp( 6, 8,14,3)/
     x-2.1978574d-04, 1.0941001d-04, 1.0084433d-08 /
      data fpppp( 6, 8,15,1),fpppp( 6, 8,15,2),fpppp( 6, 8,15,3)/
     x 9.3561775d-05,-1.2055504d-04, 1.5638011d-07 /
      data fpppp( 6, 8,16,1),fpppp( 6, 8,16,2),fpppp( 6, 8,16,3)/
     x-9.9062397d-04, 1.3298599d-04,-9.7250358d-08 /
      data fpppp( 6, 8,17,1),fpppp( 6, 8,17,2),fpppp( 6, 8,17,3)/
     x-5.6240901d-06,-5.9960620d-05, 9.0418028d-08 /
      data fpppp( 6, 8,18,1),fpppp( 6, 8,18,2),fpppp( 6, 8,18,3)/
     x-2.4275946d-05, 3.5185072d-05,-1.6977775d-07 /
      data fpppp( 6, 8,19,1),fpppp( 6, 8,19,2),fpppp( 6, 8,19,3)/
     x-1.9612156d-04, 1.1731495d-04, 8.3682081d-07 /
      data fpppp( 6, 8,20,1),fpppp( 6, 8,20,2),fpppp( 6, 8,20,3)/
     x 1.6246852d-04,-1.2270096d-04,-6.0862180d-07 /
      data fpppp( 6, 8,21,1),fpppp( 6, 8,21,2),fpppp( 6, 8,21,3)/
     x 1.6246852d-04,-1.1348559d-04,-5.2882092d-07 /
      data fpppp( 6, 8,22,1),fpppp( 6, 8,22,2),fpppp( 6, 8,22,3)/
     x-1.9612156d-04, 8.0453439d-05, 5.1761731d-07 /
      data fpppp( 6, 8,23,1),fpppp( 6, 8,23,2),fpppp( 6, 8,23,3)/
     x-2.4275946d-05, 1.7341575d-04, 1.0272354d-06 /
      data fpppp( 6, 9, 1,1),fpppp( 6, 9, 1,2),fpppp( 6, 9, 1,3)/
     x 3.5326040d-03,-3.8107904d-04,-9.7540958d-06 /
      data fpppp( 6, 9, 2,1),fpppp( 6, 9, 2,2),fpppp( 6, 9, 2,3)/
     x-1.4089105d-02,-2.9934043d-04,-6.0442022d-06 /
      data fpppp( 6, 9, 3,1),fpppp( 6, 9, 3,2),fpppp( 6, 9, 3,3)/
     x 3.4531410d-03,-4.0432604d-06, 1.1825928d-06 /
      data fpppp( 6, 9, 4,1),fpppp( 6, 9, 4,2),fpppp( 6, 9, 4,3)/
     x 3.4531410d-03,-2.1429350d-04, 2.4478027d-06 /
      data fpppp( 6, 9, 5,1),fpppp( 6, 9, 5,2),fpppp( 6, 9, 5,3)/
     x-1.4089105d-02, 5.4166053d-04,-1.1105042d-05 /
      data fpppp( 6, 9, 6,1),fpppp( 6, 9, 6,2),fpppp( 6, 9, 6,3)/
     x 3.5326040d-03,-3.5348326d-03, 9.2240532d-06 /
      data fpppp( 6, 9, 7,1),fpppp( 6, 9, 7,2),fpppp( 6, 9, 7,3)/
     x 5.7610131d-03, 7.6586012d-03, 3.3715699d-06 /
      data fpppp( 6, 9, 8,1),fpppp( 6, 9, 8,2),fpppp( 6, 9, 8,3)/
     x-7.5836918d-05,-5.7828828d-03,-6.0350173d-06 /
      data fpppp( 6, 9, 9,1),fpppp( 6, 9, 9,2),fpppp( 6, 9, 9,3)/
     x 5.1115611d-04, 1.5585198d-03, 1.5941426d-06 /
      data fpppp( 6, 9,10,1),fpppp( 6, 9,10,2),fpppp( 6, 9,10,3)/
     x 1.0689592d-04,-1.9979795d-04,-3.6511032d-07 /
      data fpppp( 6, 9,11,1),fpppp( 6, 9,11,2),fpppp( 6, 9,11,3)/
     x 8.5409213d-04,-4.0489281d-06, 1.2503418d-07 /
      data fpppp( 6, 9,12,1),fpppp( 6, 9,12,2),fpppp( 6, 9,12,3)/
     x 8.5304630d-04, 3.9657763d-05,-1.2496583d-08 /
      data fpppp( 6, 9,13,1),fpppp( 6, 9,13,2),fpppp( 6, 9,13,3)/
     x-5.9806641d-05,-1.0109862d-04, 2.8889704d-08 /
      data fpppp( 6, 9,14,1),fpppp( 6, 9,14,2),fpppp( 6, 9,14,3)/
     x 7.5027196d-04, 2.0262586d-04, 3.0029651d-08 /
      data fpppp( 6, 9,15,1),fpppp( 6, 9,15,2),fpppp( 6, 9,15,3)/
     x-9.7083826d-05,-2.1553137d-04, 3.1215512d-09 /
      data fpppp( 6, 9,16,1),fpppp( 6, 9,16,2),fpppp( 6, 9,16,3)/
     x 2.7289492d-04, 2.1499958d-04, 7.3727895d-08 /
      data fpppp( 6, 9,17,1),fpppp( 6, 9,17,2),fpppp( 6, 9,17,3)/
     x-1.1836166d-04,-1.1512527d-04, 2.1857878d-08 /
      data fpppp( 6, 9,18,1),fpppp( 6, 9,18,2),fpppp( 6, 9,18,3)/
     x-1.1995253d-04, 5.3137099d-05, 7.2553549d-08 /
      data fpppp( 6, 9,19,1),fpppp( 6, 9,19,2),fpppp( 6, 9,19,3)/
     x-5.4222846d-05, 9.9470435d-05,-1.9512700d-07 /
      data fpppp( 6, 9,20,1),fpppp( 6, 9,20,2),fpppp( 6, 9,20,3)/
     x-5.9967345d-04,-1.1085596d-04,-5.1237626d-08 /
      data fpppp( 6, 9,21,1),fpppp( 6, 9,21,2),fpppp( 6, 9,21,3)/
     x-5.9967345d-04,-1.0399746d-04,-6.7131404d-08 /
      data fpppp( 6, 9,22,1),fpppp( 6, 9,22,2),fpppp( 6, 9,22,3)/
     x-5.4222846d-05, 7.2036450d-05,-1.3155189d-07 /
      data fpppp( 6, 9,23,1),fpppp( 6, 9,23,2),fpppp( 6, 9,23,3)/
     x-1.1995253d-04, 1.5601454d-04,-1.6585312d-07 /
      data fpppp( 6,10, 1,1),fpppp( 6,10, 1,2),fpppp( 6,10, 1,3)/
     x-9.7797950d-04,-6.4288657d-05, 3.0323762d-06 /
      data fpppp( 6,10, 2,1),fpppp( 6,10, 2,2),fpppp( 6,10, 2,3)/
     x 4.1006221d-03,-1.0620309d-04, 1.7553740d-06 /
      data fpppp( 6,10, 3,1),fpppp( 6,10, 3,2),fpppp( 6,10, 3,3)/
     x-5.9976053d-04,-1.2709841d-04,-6.3394291d-07 /
      data fpppp( 6,10, 4,1),fpppp( 6,10, 4,2),fpppp( 6,10, 4,3)/
     x-5.9976053d-04,-2.4771074d-04,-1.2413963d-06 /
      data fpppp( 6,10, 5,1),fpppp( 6,10, 5,2),fpppp( 6,10, 5,3)/
     x 4.1006221d-03, 3.7624623d-04, 4.1851875d-06 /
      data fpppp( 6,10, 6,1),fpppp( 6,10, 6,2),fpppp( 6,10, 6,3)/
     x-9.7797950d-04,-1.8734736d-03,-6.0794243d-06 /
      data fpppp( 6,10, 7,1),fpppp( 6,10, 7,2),fpppp( 6,10, 7,3)/
     x-1.8579773d-03, 4.2059716d-03, 1.2577959d-06 /
      data fpppp( 6,10, 8,1),fpppp( 6,10, 8,2),fpppp( 6,10, 8,3)/
     x-2.0458851d-03,-2.5063910d-03, 5.5156045d-06 /
      data fpppp( 6,10, 9,1),fpppp( 6,10, 9,2),fpppp( 6,10, 9,3)/
     x-7.8397679d-04,-3.7528488d-04,-3.3981965d-06 /
      data fpppp( 6,10,10,1),fpppp( 6,10,10,2),fpppp( 6,10,10,3)/
     x 1.8161721d-04, 9.9010586d-04, 3.9574511d-07 /
      data fpppp( 6,10,11,1),fpppp( 6,10,11,2),fpppp( 6,10,11,3)/
     x-1.2448194d-03,-4.6364589d-04,-1.8865631d-07 /
      data fpppp( 6,10,12,1),fpppp( 6,10,12,2),fpppp( 6,10,12,3)/
     x-1.3213999d-03,-7.4565645d-04, 4.3204781d-08 /
      data fpppp( 6,10,13,1),fpppp( 6,10,13,2),fpppp( 6,10,13,3)/
     x 1.3250563d-04, 1.5363803d-03,-1.9687442d-09 /
      data fpppp( 6,10,14,1),fpppp( 6,10,14,2),fpppp( 6,10,14,3)/
     x-7.1855325d-04,-1.5067000d-03, 1.6786791d-08 /
      data fpppp( 6,10,15,1),fpppp( 6,10,15,2),fpppp( 6,10,15,3)/
     x 1.2670903d-04, 8.8750759d-04, 2.0769897d-08 /
      data fpppp( 6,10,16,1),fpppp( 6,10,16,2),fpppp( 6,10,16,3)/
     x-3.5223759d-05,-2.2789648d-04,-6.6358848d-09 /
      data fpppp( 6,10,17,1),fpppp( 6,10,17,2),fpppp( 6,10,17,3)/
     x 1.1903270d-04, 7.1766971d-05,-6.5870913d-09 /
      data fpppp( 6,10,18,1),fpppp( 6,10,18,2),fpppp( 6,10,18,3)/
     x 1.0489053d-04, 1.4383700d-05,-3.6031574d-08 /
      data fpppp( 6,10,19,1),fpppp( 6,10,19,2),fpppp( 6,10,19,3)/
     x 9.4195451d-05, 1.8592629d-04, 5.6885239d-08 /
      data fpppp( 6,10,20,1),fpppp( 6,10,20,2),fpppp( 6,10,20,3)/
     x 2.2951845d-03,-1.6210830d-04,-7.8224783d-08 /
      data fpppp( 6,10,21,1),fpppp( 6,10,21,2),fpppp( 6,10,21,3)/
     x 2.2951845d-03,-1.4625583d-04,-7.0821232d-08 /
      data fpppp( 6,10,22,1),fpppp( 6,10,22,2),fpppp( 6,10,22,3)/
     x 9.4195451d-05, 1.2251640d-04, 2.7271032d-08 /
      data fpppp( 6,10,23,1),fpppp( 6,10,23,2),fpppp( 6,10,23,3)/
     x 1.0489053d-04, 2.5217077d-04, 7.5021702d-08 /
      data fpppp( 6,11, 1,1),fpppp( 6,11, 1,2),fpppp( 6,11, 1,3)/
     x 5.4628588d-04, 5.5945683d-04, 5.4709842d-07 /
      data fpppp( 6,11, 2,1),fpppp( 6,11, 2,2),fpppp( 6,11, 2,3)/
     x 1.1808299d-04, 1.8812557d-04, 7.1481551d-08 /
      data fpppp( 6,11, 3,1),fpppp( 6,11, 3,2),fpppp( 6,11, 3,3)/
     x 4.0102465d-03,-5.9348946d-04,-1.0235903d-06 /
      data fpppp( 6,11, 4,1),fpppp( 6,11, 4,2),fpppp( 6,11, 4,3)/
     x 4.0102465d-03,-6.1815541d-04,-8.9077782d-07 /
      data fpppp( 6,11, 5,1),fpppp( 6,11, 5,2),fpppp( 6,11, 5,3)/
     x 1.1808299d-04, 2.8678935d-04,-4.5976845d-07 /
      data fpppp( 6,11, 6,1),fpppp( 6,11, 6,2),fpppp( 6,11, 6,3)/
     x 5.4628588d-04, 1.8946764d-04, 2.5392859d-06 /
      data fpppp( 6,11, 7,1),fpppp( 6,11, 7,2),fpppp( 6,11, 7,3)/
     x 8.7957775d-05,-4.1435996d-04,-1.7459013d-06 /
      data fpppp( 6,11, 8,1),fpppp( 6,11, 8,2),fpppp( 6,11, 8,3)/
     x 2.5154015d-03, 2.6281992d-03,-4.8001162d-07 /
      data fpppp( 6,11, 9,1),fpppp( 6,11, 9,2),fpppp( 6,11, 9,3)/
     x-6.2053300d-04,-1.9140510d-03, 2.5781552d-06 /
      data fpppp( 6,11,10,1),fpppp( 6,11,10,2),fpppp( 6,11,10,3)/
     x-3.6970511d-04,-4.7990865d-05,-1.0033457d-06 /
      data fpppp( 6,11,11,1),fpppp( 6,11,11,2),fpppp( 6,11,11,3)/
     x 8.6842795d-04, 1.6435973d-04, 6.2021746d-08 /
      data fpppp( 6,11,12,1),fpppp( 6,11,12,2),fpppp( 6,11,12,3)/
     x 9.5362112d-04,-1.5513759d-04,-6.6569746d-08 /
      data fpppp( 6,11,13,1),fpppp( 6,11,13,2),fpppp( 6,11,13,3)/
     x-7.4267525d-06, 7.4682001d-04, 1.2063397d-08 /
      data fpppp( 6,11,14,1),fpppp( 6,11,14,2),fpppp( 6,11,14,3)/
     x 2.6595801d-04,-1.1461954d-03, 2.1978934d-09 /
      data fpppp( 6,11,15,1),fpppp( 6,11,15,2),fpppp( 6,11,15,3)/
     x 6.9968252d-06, 7.3376804d-04, 9.0189829d-10 /
      data fpppp( 6,11,16,1),fpppp( 6,11,16,2),fpppp( 6,11,16,3)/
     x 5.5701774d-05,-2.1728862d-04, 3.8878052d-10 /
      data fpppp( 6,11,17,1),fpppp( 6,11,17,2),fpppp( 6,11,17,3)/
     x 3.1642282d-05, 1.3217926d-04,-8.3050955d-09 /
      data fpppp( 6,11,18,1),fpppp( 6,11,18,2),fpppp( 6,11,18,3)/
     x 5.8899960d-05,-2.0456547d-04, 2.1019434d-09 /
      data fpppp( 6,11,19,1),fpppp( 6,11,19,2),fpppp( 6,11,19,3)/
     x 8.8032660d-05, 1.2026291d-03,-6.6095157d-08 /
      data fpppp( 6,11,20,1),fpppp( 6,11,20,2),fpppp( 6,11,20,3)/
     x-5.0990275d-03,-7.3478929d-04, 9.9723638d-09 /
      data fpppp( 6,11,21,1),fpppp( 6,11,21,2),fpppp( 6,11,21,3)/
     x-5.0990275d-03,-6.2507458d-04, 5.0501197d-09 /
      data fpppp( 6,11,22,1),fpppp( 6,11,22,2),fpppp( 6,11,22,3)/
     x 8.8032660d-05, 7.6377029d-04,-4.6406180d-08 /
      data fpppp( 6,11,23,1),fpppp( 6,11,23,2),fpppp( 6,11,23,3)/
     x 5.8899960d-05, 1.4411552d-03,-7.1731718d-08 /
      data fpppp( 6,12, 1,1),fpppp( 6,12, 1,2),fpppp( 6,12, 1,3)/
     x 6.9297378d-04, 3.1757971d-03, 1.3365027d-06 /
      data fpppp( 6,12, 2,1),fpppp( 6,12, 2,2),fpppp( 6,12, 2,3)/
     x 1.3624507d-03, 1.4330910d-03, 5.5053473d-07 /
      data fpppp( 6,12, 3,1),fpppp( 6,12, 3,2),fpppp( 6,12, 3,3)/
     x-8.1970077d-04,-2.2041694d-03,-1.0759082d-06 /
      data fpppp( 6,12, 4,1),fpppp( 6,12, 4,2),fpppp( 6,12, 4,3)/
     x-8.1970077d-04,-2.3741117d-03,-1.1770129d-06 /
      data fpppp( 6,12, 5,1),fpppp( 6,12, 5,2),fpppp( 6,12, 5,3)/
     x 1.3624507d-03, 2.1128601d-03, 9.5495348d-07 /
      data fpppp( 6,12, 6,1),fpppp( 6,12, 6,2),fpppp( 6,12, 6,3)/
     x 6.9297378d-04, 6.2666281d-04,-1.8006767d-07 /
      data fpppp( 6,12, 7,1),fpppp( 6,12, 7,2),fpppp( 6,12, 7,3)/
     x 2.5382076d-05, 2.0713026d-04, 7.2113481d-07 /
      data fpppp( 6,12, 8,1),fpppp( 6,12, 8,2),fpppp( 6,12, 8,3)/
     x-6.3580042d-04, 6.6283472d-04,-3.4811236d-07 /
      data fpppp( 6,12, 9,1),fpppp( 6,12, 9,2),fpppp( 6,12, 9,3)/
     x 8.2861765d-04, 1.0270833d-03, 2.5538743d-07 /
      data fpppp( 6,12,10,1),fpppp( 6,12,10,2),fpppp( 6,12,10,3)/
     x-4.0051960d-04,-1.3485547d-03, 5.5502534d-07 /
      data fpppp( 6,12,11,1),fpppp( 6,12,11,2),fpppp( 6,12,11,3)/
     x-3.7458983d-04, 1.7459028d-04,-2.0275316d-07 /
      data fpppp( 6,12,12,1),fpppp( 6,12,12,2),fpppp( 6,12,12,3)/
     x-4.1114344d-04,-1.5543812d-04, 1.6336431d-08 /
      data fpppp( 6,12,13,1),fpppp( 6,12,13,2),fpppp( 6,12,13,3)/
     x-6.6828808d-06, 7.2484826d-04,-1.6691266d-08 /
      data fpppp( 6,12,14,1),fpppp( 6,12,14,2),fpppp( 6,12,14,3)/
     x-5.2280014d-05,-1.0825171d-03,-1.6549036d-09 /
      data fpppp( 6,12,15,1),fpppp( 6,12,15,2),fpppp( 6,12,15,3)/
     x 1.3178156d-05, 6.7773805d-04,-4.9449145d-09 /
      data fpppp( 6,12,16,1),fpppp( 6,12,16,2),fpppp( 6,12,16,3)/
     x 1.9005997d-05,-1.3685346d-04,-4.5300255d-10 /
      data fpppp( 6,12,17,1),fpppp( 6,12,17,2),fpppp( 6,12,17,3)/
     x 5.5794573d-05,-1.2833500d-04, 5.0699584d-09 /
      data fpppp( 6,12,18,1),fpppp( 6,12,18,2),fpppp( 6,12,18,3)/
     x 8.3617061d-05, 8.1826822d-04,-1.7972374d-08 /
      data fpppp( 6,12,19,1),fpppp( 6,12,19,2),fpppp( 6,12,19,3)/
     x 7.1823577d-05,-2.4555417d-03,-1.0062240d-07 /
      data fpppp( 6,12,20,1),fpppp( 6,12,20,2),fpppp( 6,12,20,3)/
     x 3.8020935d-03, 1.2392179d-03, 6.6482646d-08 /
      data fpppp( 6,12,21,1),fpppp( 6,12,21,2),fpppp( 6,12,21,3)/
     x 3.8020935d-03, 1.0019696d-03, 5.8857692d-08 /
      data fpppp( 6,12,22,1),fpppp( 6,12,22,2),fpppp( 6,12,22,3)/
     x 7.1823577d-05,-1.5065485d-03,-7.0122580d-08 /
      data fpppp( 6,12,23,1),fpppp( 6,12,23,2),fpppp( 6,12,23,3)/
     x 8.3617061d-05,-2.7404565d-03,-1.3234669d-07 /
      data fpppp( 6,13, 1,1),fpppp( 6,13, 1,2),fpppp( 6,13, 1,3)/
     x-1.2390004d-03, 3.2521378d-03,-3.9981801d-06 /
      data fpppp( 6,13, 2,1),fpppp( 6,13, 2,2),fpppp( 6,13, 2,3)/
     x-1.8182492d-03, 1.2514639d-03,-1.9249783d-06 /
      data fpppp( 6,13, 3,1),fpppp( 6,13, 3,2),fpppp( 6,13, 3,3)/
     x-2.7131702d-03,-2.9702990d-03, 2.4020456d-06 /
      data fpppp( 6,13, 4,1),fpppp( 6,13, 4,2),fpppp( 6,13, 4,3)/
     x-2.7131702d-03,-3.0847413d-03, 2.6042605d-06 /
      data fpppp( 6,13, 5,1),fpppp( 6,13, 5,2),fpppp( 6,13, 5,3)/
     x-1.8182492d-03, 1.7092332d-03,-2.7338379d-06 /
      data fpppp( 6,13, 6,1),fpppp( 6,13, 6,2),fpppp( 6,13, 6,3)/
     x-1.2390004d-03, 1.5355027d-03,-9.6495666d-07 /
      data fpppp( 6,13, 7,1),fpppp( 6,13, 7,2),fpppp( 6,13, 7,3)/
     x-8.6647876d-05, 8.6585284d-04,-5.0827989d-07 /
      data fpppp( 6,13, 8,1),fpppp( 6,13, 8,2),fpppp( 6,13, 8,3)/
     x 1.4161602d-04, 6.4216154d-05,-7.0229860d-08 /
      data fpppp( 6,13, 9,1),fpppp( 6,13, 9,2),fpppp( 6,13, 9,3)/
     x 1.3168918d-04, 1.1648349d-03, 5.8420588d-08 /
      data fpppp( 6,13,10,1),fpppp( 6,13,10,2),fpppp( 6,13,10,3)/
     x 4.0555254d-05,-2.7099945d-04, 3.8651318d-07 /
      data fpppp( 6,13,11,1),fpppp( 6,13,11,2),fpppp( 6,13,11,3)/
     x-1.3195542d-04,-5.9807593d-04,-1.2249979d-08 /
      data fpppp( 6,13,12,1),fpppp( 6,13,12,2),fpppp( 6,13,12,3)/
     x 4.7943392d-04,-2.1243991d-05, 5.0787215d-09 /
      data fpppp( 6,13,13,1),fpppp( 6,13,13,2),fpppp( 6,13,13,3)/
     x-3.5134529d-05, 5.3965254d-04,-4.0762368d-09 /
      data fpppp( 6,13,14,1),fpppp( 6,13,14,2),fpppp( 6,13,14,3)/
     x-3.1296603d-04,-8.2949877d-04,-8.4013588d-09 /
      data fpppp( 6,13,15,1),fpppp( 6,13,15,2),fpppp( 6,13,15,3)/
     x-3.9294140d-06, 5.2631535d-04,-7.4920172d-09 /
      data fpppp( 6,13,16,1),fpppp( 6,13,16,2),fpppp( 6,13,16,3)/
     x 1.0905783d-05,-8.9244075d-05,-1.2345827d-09 /
      data fpppp( 6,13,17,1),fpppp( 6,13,17,2),fpppp( 6,13,17,3)/
     x 1.1365654d-05,-1.2545026d-04, 1.8628861d-10 /
      data fpppp( 6,13,18,1),fpppp( 6,13,18,2),fpppp( 6,13,18,3)/
     x-1.3597984d-05, 8.1036101d-04,-1.6158741d-08 /
      data fpppp( 6,13,19,1),fpppp( 6,13,19,2),fpppp( 6,13,19,3)/
     x-1.0460370d-04,-2.4767789d-03, 1.1088902d-08 /
      data fpppp( 6,13,20,1),fpppp( 6,13,20,2),fpppp( 6,13,20,3)/
     x 1.5986066d-03, 1.2425080d-03, 1.7506739d-08 /
      data fpppp( 6,13,21,1),fpppp( 6,13,21,2),fpppp( 6,13,21,3)/
     x 1.5986066d-03, 1.0040836d-03, 1.8657972d-08 /
      data fpppp( 6,13,22,1),fpppp( 6,13,22,2),fpppp( 6,13,22,3)/
     x-1.0460370d-04,-1.5230814d-03, 6.4839681d-09 /
      data fpppp( 6,13,23,1),fpppp( 6,13,23,2),fpppp( 6,13,23,3)/
     x-1.3597984d-05,-2.7660049d-03, 1.1097617d-09 /
      data fpppp( 6,14, 1,1),fpppp( 6,14, 1,2),fpppp( 6,14, 1,3)/
     x-4.5214946d-04, 1.3241245d-03,-2.2050202d-06 /
      data fpppp( 6,14, 2,1),fpppp( 6,14, 2,2),fpppp( 6,14, 2,3)/
     x-2.6625016d-03, 1.0232859d-04,-8.6933520d-07 /
      data fpppp( 6,14, 3,1),fpppp( 6,14, 3,2),fpppp( 6,14, 3,3)/
     x-5.4857052d-03,-2.5892104d-03, 1.9604994d-06 /
      data fpppp( 6,14, 4,1),fpppp( 6,14, 4,2),fpppp( 6,14, 4,3)/
     x-5.4857052d-03,-2.4607517d-03, 2.0171075d-06 /
      data fpppp( 6,14, 5,1),fpppp( 6,14, 5,2),fpppp( 6,14, 5,3)/
     x-2.6625016d-03,-4.1150618d-04,-1.0957677d-06 /
      data fpppp( 6,14, 6,1),fpppp( 6,14, 6,2),fpppp( 6,14, 6,3)/
     x-4.5214946d-04, 3.2510048d-03,-1.3558982d-06 /
      data fpppp( 6,14, 7,1),fpppp( 6,14, 7,2),fpppp( 6,14, 7,3)/
     x-3.4730894d-04, 2.0382769d-04,-6.4879936d-07 /
      data fpppp( 6,14, 8,1),fpppp( 6,14, 8,2),fpppp( 6,14, 8,3)/
     x-1.5104816d-04, 3.4340105d-04,-2.3071934d-07 /
      data fpppp( 6,14, 9,1),fpppp( 6,14, 9,2),fpppp( 6,14, 9,3)/
     x 4.9261668d-05, 2.8900694d-04,-1.5196114d-07 /
      data fpppp( 6,14,10,1),fpppp( 6,14,10,2),fpppp( 6,14,10,3)/
     x 2.6511307d-04, 9.8022818d-04, 4.2523849d-07 /
      data fpppp( 6,14,11,1),fpppp( 6,14,11,2),fpppp( 6,14,11,3)/
     x 3.3774476d-06,-5.9987931d-04,-2.2421700d-08 /
      data fpppp( 6,14,12,1),fpppp( 6,14,12,2),fpppp( 6,14,12,3)/
     x-8.7743649d-04,-6.9013527d-04, 4.6811273d-08 /
      data fpppp( 6,14,13,1),fpppp( 6,14,13,2),fpppp( 6,14,13,3)/
     x-4.6572800d-05, 4.4479628d-04,-3.9365308d-11 /
      data fpppp( 6,14,14,1),fpppp( 6,14,14,2),fpppp( 6,14,14,3)/
     x 3.1931953d-04,-1.0283417d-04, 6.0063379d-11 /
      data fpppp( 6,14,15,1),fpppp( 6,14,15,2),fpppp( 6,14,15,3)/
     x-1.2634030d-04, 3.6943559d-05,-4.7303364d-09 /
      data fpppp( 6,14,16,1),fpppp( 6,14,16,2),fpppp( 6,14,16,3)/
     x-1.7450300d-04,-2.4235173d-06,-9.9511171d-10 /
      data fpppp( 6,14,17,1),fpppp( 6,14,17,2),fpppp( 6,14,17,3)/
     x-2.2713543d-04, 2.7528543d-05, 4.2939880d-09 /
      data fpppp( 6,14,18,1),fpppp( 6,14,18,2),fpppp( 6,14,18,3)/
     x-2.7963603d-04, 5.2338050d-05, 2.4077381d-08 /
      data fpppp( 6,14,19,1),fpppp( 6,14,19,2),fpppp( 6,14,19,3)/
     x-3.0246453d-04, 7.8240639d-05, 6.7157521d-08 /
      data fpppp( 6,14,20,1),fpppp( 6,14,20,2),fpppp( 6,14,20,3)/
     x-3.0473784d-03,-1.1227120d-04,-4.3062570d-08 /
      data fpppp( 6,14,21,1),fpppp( 6,14,21,2),fpppp( 6,14,21,3)/
     x-3.0473784d-03,-1.0682145d-04,-3.8576043d-08 /
      data fpppp( 6,14,22,1),fpppp( 6,14,22,2),fpppp( 6,14,22,3)/
     x-3.0246453d-04, 5.6441630d-05, 4.9211411d-08 /
      data fpppp( 6,14,23,1),fpppp( 6,14,23,2),fpppp( 6,14,23,3)/
     x-2.7963603d-04, 1.3408433d-04, 9.1375296d-08 /
      data fpppp( 6,15, 1,1),fpppp( 6,15, 1,2),fpppp( 6,15, 1,3)/
     x-6.8192765d-04,-1.1396620d-03, 2.1811867d-06 /
      data fpppp( 6,15, 2,1),fpppp( 6,15, 2,2),fpppp( 6,15, 2,3)/
     x-1.7965429d-03,-1.0361643d-03, 1.0495974d-06 /
      data fpppp( 6,15, 3,1),fpppp( 6,15, 3,2),fpppp( 6,15, 3,3)/
     x 6.1407454d-04,-9.5676383d-04,-1.3131618d-06 /
      data fpppp( 6,15, 4,1),fpppp( 6,15, 4,2),fpppp( 6,15, 4,3)/
     x 6.1407454d-04,-7.0759818d-04,-1.4217932d-06 /
      data fpppp( 6,15, 5,1),fpppp( 6,15, 5,2),fpppp( 6,15, 5,3)/
     x-1.7965429d-03,-2.0328269d-03, 1.4841230d-06 /
      data fpppp( 6,15, 6,1),fpppp( 6,15, 6,2),fpppp( 6,15, 6,3)/
     x-6.8192765d-04, 2.5978228d-03, 5.5171563d-07 /
      data fpppp( 6,15, 7,1),fpppp( 6,15, 7,2),fpppp( 6,15, 7,3)/
     x-2.4736751d-04,-1.1876966d-05,-4.0642221d-08 /
      data fpppp( 6,15, 8,1),fpppp( 6,15, 8,2),fpppp( 6,15, 8,3)/
     x-1.0800722d-04, 3.5238074d-04,-1.5886098d-07 /
      data fpppp( 6,15, 9,1),fpppp( 6,15, 9,2),fpppp( 6,15, 9,3)/
     x-9.2723612d-05,-2.9839186d-04,-8.7663654d-08 /
      data fpppp( 6,15,10,1),fpppp( 6,15,10,2),fpppp( 6,15,10,3)/
     x-5.4780256d-05, 1.3515635d-03,-5.1428483d-08 /
      data fpppp( 6,15,11,1),fpppp( 6,15,11,2),fpppp( 6,15,11,3)/
     x-8.9616633d-04,-2.4159680d-04, 4.5294980d-07 /
      data fpppp( 6,15,12,1),fpppp( 6,15,12,2),fpppp( 6,15,12,3)/
     x 1.1065830d-03,-7.6775566d-04,-1.3573455d-07 /
      data fpppp( 6,15,13,1),fpppp( 6,15,13,2),fpppp( 6,15,13,3)/
     x 8.7731821d-06, 2.4496413d-04, 6.1543621d-08 /
      data fpppp( 6,15,14,1),fpppp( 6,15,14,2),fpppp( 6,15,14,3)/
     x 1.5001209d-05,-6.6647536d-05,-4.4278497d-09 /
      data fpppp( 6,15,15,1),fpppp( 6,15,15,2),fpppp( 6,15,15,3)/
     x 2.9675075d-04, 3.0640570d-05, 1.0819260d-08 /
      data fpppp( 6,15,16,1),fpppp( 6,15,16,2),fpppp( 6,15,16,3)/
     x 4.3479755d-04,-5.3157960d-06, 3.5003958d-09 /
      data fpppp( 6,15,17,1),fpppp( 6,15,17,2),fpppp( 6,15,17,3)/
     x 5.6276137d-04, 1.3952634d-05, 9.0503974d-09 /
      data fpppp( 6,15,18,1),fpppp( 6,15,18,2),fpppp( 6,15,18,3)/
     x 6.7552473d-04, 1.0150150d-05, 1.9313298d-08 /
      data fpppp( 6,15,19,1),fpppp( 6,15,19,2),fpppp( 6,15,19,3)/
     x 8.0881341d-04, 9.6463405d-06, 2.2492046d-08 /
      data fpppp( 6,15,20,1),fpppp( 6,15,20,2),fpppp( 6,15,20,3)/
     x 1.6963047d-03,-2.8352932d-05,-2.7124671d-08 /
      data fpppp( 6,15,21,1),fpppp( 6,15,21,2),fpppp( 6,15,21,3)/
     x 1.6963047d-03,-2.7535091d-05,-2.5874677d-08 /
      data fpppp( 6,15,22,1),fpppp( 6,15,22,2),fpppp( 6,15,22,3)/
     x 8.0881341d-04, 6.3749765d-06, 1.7492068d-08 /
      data fpppp( 6,15,23,1),fpppp( 6,15,23,2),fpppp( 6,15,23,3)/
     x 6.7552473d-04, 2.2417766d-05, 3.8063214d-08 /
      data fpppp( 6,16, 1,1),fpppp( 6,16, 1,2),fpppp( 6,16, 1,3)/
     x 6.2132208d-04, 7.5848288d-05, 8.0443672d-07 /
      data fpppp( 6,16, 2,1),fpppp( 6,16, 2,2),fpppp( 6,16, 2,3)/
     x 3.0313314d-03,-5.9319186d-05, 2.7257910d-07 /
      data fpppp( 6,16, 3,1),fpppp( 6,16, 3,2),fpppp( 6,16, 3,3)/
     x 3.0627879d-03,-3.5544008d-04,-8.5614892d-07 /
      data fpppp( 6,16, 4,1),fpppp( 6,16, 4,2),fpppp( 6,16, 4,3)/
     x 3.0627879d-03,-3.4410655d-04,-8.7534096d-07 /
      data fpppp( 6,16, 5,1),fpppp( 6,16, 5,2),fpppp( 6,16, 5,3)/
     x 3.0313314d-03,-1.0465330d-04, 3.4934727d-07 /
      data fpppp( 6,16, 6,1),fpppp( 6,16, 6,2),fpppp( 6,16, 6,3)/
     x 6.2132208d-04, 2.4585121d-04, 5.1655608d-07 /
      data fpppp( 6,16, 7,1),fpppp( 6,16, 7,2),fpppp( 6,16, 7,3)/
     x 9.5055479d-05, 7.6092747d-05, 2.4885495d-07 /
      data fpppp( 6,16, 8,1),fpppp( 6,16, 8,2),fpppp( 6,16, 8,3)/
     x-7.0072310d-05, 1.1721210d-04, 5.0935986d-08 /
      data fpppp( 6,16, 9,1),fpppp( 6,16, 9,2),fpppp( 6,16, 9,3)/
     x 1.5612407d-04,-3.1380521d-04,-2.2148183d-07 /
      data fpppp( 6,16,10,1),fpppp( 6,16,10,2),fpppp( 6,16,10,3)/
     x 2.3753786d-04,-3.5949668d-04, 4.4181306d-07 /
      data fpppp( 6,16,11,1),fpppp( 6,16,11,2),fpppp( 6,16,11,3)/
     x-3.7864458d-04, 3.1817812d-03,-5.7899038d-07 /
      data fpppp( 6,16,12,1),fpppp( 6,16,12,2),fpppp( 6,16,12,3)/
     x-3.5193111d-03,-2.7903832d-03, 5.2680083d-07 /
      data fpppp( 6,16,13,1),fpppp( 6,16,13,2),fpppp( 6,16,13,3)/
     x-1.1688003d-04, 6.1260384d-04,-7.1537839d-08 /
      data fpppp( 6,16,14,1),fpppp( 6,16,14,2),fpppp( 6,16,14,3)/
     x-4.9054069d-04,-1.8025286d-04, 4.3508318d-08 /
      data fpppp( 6,16,15,1),fpppp( 6,16,15,2),fpppp( 6,16,15,3)/
     x-1.1639380d-03, 4.6830766d-05, 3.1080855d-09 /
      data fpppp( 6,16,16,1),fpppp( 6,16,16,2),fpppp( 6,16,16,3)/
     x-1.7179470d-03,-6.3143900d-06, 1.0877389d-08 /
      data fpppp( 6,16,17,1),fpppp( 6,16,17,2),fpppp( 6,16,17,3)/
     x-2.1959483d-03, 1.5147681d-06, 4.4741920d-09 /
      data fpppp( 6,16,18,1),fpppp( 6,16,18,2),fpppp( 6,16,18,3)/
     x-2.5720433d-03, 2.7527661d-06, 1.9864891d-09 /
      data fpppp( 6,16,19,1),fpppp( 6,16,19,2),fpppp( 6,16,19,3)/
     x-2.8621410d-03,-1.4773363d-06,-2.6437205d-09 /
      data fpppp( 6,16,20,1),fpppp( 6,16,20,2),fpppp( 6,16,20,3)/
     x-3.2433771d-03,-5.5210965d-06,-1.1323742d-08 /
      data fpppp( 6,16,21,1),fpppp( 6,16,21,2),fpppp( 6,16,21,3)/
     x-3.2433771d-03,-5.6323155d-06,-1.1351251d-08 /
      data fpppp( 6,16,22,1),fpppp( 6,16,22,2),fpppp( 6,16,22,3)/
     x-2.8621410d-03,-1.0324601d-06,-2.5336826d-09 /
      data fpppp( 6,16,23,1),fpppp( 6,16,23,2),fpppp( 6,16,23,3)/
     x-2.5720433d-03, 1.0844806d-06, 1.5738469d-09 /
      data fpppp( 6,17, 1,1),fpppp( 6,17, 1,2),fpppp( 6,17, 1,3)/
     x 1.0035906d-04,-1.3886456d-05, 5.4995201d-08 /
      data fpppp( 6,17, 2,1),fpppp( 6,17, 2,2),fpppp( 6,17, 2,3)/
     x-3.8723992d-05,-3.0170603d-05, 4.6287240d-09 /
      data fpppp( 6,17, 3,1),fpppp( 6,17, 3,2),fpppp( 6,17, 3,3)/
     x 4.0472441d-04,-6.4532177d-05,-1.0354123d-07 /
      data fpppp( 6,17, 4,1),fpppp( 6,17, 4,2),fpppp( 6,17, 4,3)/
     x 4.0472441d-04,-6.5464973d-05,-1.0311810d-07 /
      data fpppp( 6,17, 5,1),fpppp( 6,17, 5,2),fpppp( 6,17, 5,3)/
     x-3.8723992d-05,-2.6439421d-05, 2.9362294d-09 /
      data fpppp( 6,17, 6,1),fpppp( 6,17, 6,2),fpppp( 6,17, 6,3)/
     x 1.0035906d-04,-2.7878386d-05, 6.1342056d-08 /
      data fpppp( 6,17, 7,1),fpppp( 6,17, 7,2),fpppp( 6,17, 7,3)/
     x-1.4089562d-04, 1.7563238d-04, 7.1166094d-08 /
      data fpppp( 6,17, 8,1),fpppp( 6,17, 8,2),fpppp( 6,17, 8,3)/
     x 7.0142016d-05,-6.4083048d-04,-7.1459623d-08 /
      data fpppp( 6,17, 9,1),fpppp( 6,17, 9,2),fpppp( 6,17, 9,3)/
     x-5.2185832d-04, 2.3888893d-03, 2.2633959d-08 /
      data fpppp( 6,17,10,1),fpppp( 6,17,10,2),fpppp( 6,17,10,3)/
     x 2.8046876d-03,-9.0580387d-03,-5.5769898d-07 /
      data fpppp( 6,17,11,1),fpppp( 6,17,11,2),fpppp( 6,17,11,3)/
     x-8.0637528d-03, 1.3972278d-02, 6.6978965d-07 /
      data fpppp( 6,17,12,1),fpppp( 6,17,12,2),fpppp( 6,17,12,3)/
     x 8.4560989d-03,-7.1595137d-03,-1.2070526d-07 /
      data fpppp( 6,17,13,1),fpppp( 6,17,13,2),fpppp( 6,17,13,3)/
     x-2.7118645d-04, 8.2383057d-04, 7.2135780d-08 /
      data fpppp( 6,17,14,1),fpppp( 6,17,14,2),fpppp( 6,17,14,3)/
     x 1.8913184d-03,-4.3224218d-04, 4.6788883d-09 /
      data fpppp( 6,17,15,1),fpppp( 6,17,15,2),fpppp( 6,17,15,3)/
     x 4.3118346d-03, 1.0755616d-04, 1.4203104d-08 /
      data fpppp( 6,17,16,1),fpppp( 6,17,16,2),fpppp( 6,17,16,3)/
     x 6.4153848d-03,-3.0185198d-05, 5.4469122d-09 /
      data fpppp( 6,17,17,1),fpppp( 6,17,17,2),fpppp( 6,17,17,3)/
     x 8.1981203d-03, 9.1632311d-06, 2.6106766d-09 /
      data fpppp( 6,17,18,1),fpppp( 6,17,18,2),fpppp( 6,17,18,3)/
     x 9.6477612d-03,-2.7870365d-06,-2.4674848d-09 /
      data fpppp( 6,17,19,1),fpppp( 6,17,19,2),fpppp( 6,17,19,3)/
     x 1.0773100d-02, 9.4768864d-08,-7.0820835d-09 /
      data fpppp( 6,17,20,1),fpppp( 6,17,20,2),fpppp( 6,17,20,3)/
     x 1.1542989d-02,-1.1316898d-06,-8.4324526d-09 /
      data fpppp( 6,17,21,1),fpppp( 6,17,21,2),fpppp( 6,17,21,3)/
     x 1.1542989d-02,-9.6772685d-07,-8.6215868d-09 /
      data fpppp( 6,17,22,1),fpppp( 6,17,22,2),fpppp( 6,17,22,3)/
     x 1.0773100d-02,-5.6108291d-07,-6.3255468d-09 /
      data fpppp( 6,17,23,1),fpppp( 6,17,23,2),fpppp( 6,17,23,3)/
     x 9.6477612d-03,-3.2759229d-07,-5.3044973d-09 /
      data fpppp( 6,18, 1,1),fpppp( 6,18, 1,2),fpppp( 6,18, 1,3)/
     x 6.6656250d-04,-2.4335672d-05, 8.1799914d-08 /
      data fpppp( 6,18, 2,1),fpppp( 6,18, 2,2),fpppp( 6,18, 2,3)/
     x 8.7560253d-04,-2.0857545d-05, 5.7931136d-08 /
      data fpppp( 6,18, 3,1),fpppp( 6,18, 3,2),fpppp( 6,18, 3,3)/
     x 9.0937791d-04, 2.7406741d-06, 7.8358632d-09 /
      data fpppp( 6,18, 4,1),fpppp( 6,18, 4,2),fpppp( 6,18, 4,3)/
     x 9.0937791d-04,-2.5513234d-05, 5.9946765d-09 /
      data fpppp( 6,18, 5,1),fpppp( 6,18, 5,2),fpppp( 6,18, 5,3)/
     x 8.7560253d-04, 9.2158085d-05, 6.5295883d-08 /
      data fpppp( 6,18, 6,1),fpppp( 6,18, 6,2),fpppp( 6,18, 6,3)/
     x 6.6656250d-04,-4.4814429d-04, 5.4182113d-08 /
      data fpppp( 6,18, 7,1),fpppp( 6,18, 7,2),fpppp( 6,18, 7,3)/
     x 6.9440958d-04, 1.4202125d-03, 5.6669371d-09 /
      data fpppp( 6,18, 8,1),fpppp( 6,18, 8,2),fpppp( 6,18, 8,3)/
     x 2.9934262d-04,-4.0851045d-03,-2.9308949d-08 /
      data fpppp( 6,18, 9,1),fpppp( 6,18, 9,2),fpppp( 6,18, 9,3)/
     x 7.6903670d-04, 1.2735403d-02,-4.0434443d-08 /
      data fpppp( 6,18,10,1),fpppp( 6,18,10,2),fpppp( 6,18,10,3)/
     x-3.4155452d-03,-3.4770498d-02,-4.9912392d-07 /
      data fpppp( 6,18,11,1),fpppp( 6,18,11,2),fpppp( 6,18,11,3)/
     x 1.6425445d-02, 5.1722656d-02, 8.9159934d-07 /
      data fpppp( 6,18,12,1),fpppp( 6,18,12,2),fpppp( 6,18,12,3)/
     x-6.5488429d-03,-3.8140847d-02,-4.1838327d-07 /
      data fpppp( 6,18,13,1),fpppp( 6,18,13,2),fpppp( 6,18,13,3)/
     x 5.4819958d-04, 1.6149865d-02, 4.5641057d-08 /
      data fpppp( 6,18,14,1),fpppp( 6,18,14,2),fpppp( 6,18,14,3)/
     x-2.0794301d-03,-4.4728639d-03,-3.1005742d-08 /
      data fpppp( 6,18,15,1),fpppp( 6,18,15,2),fpppp( 6,18,15,3)/
     x-4.6329246d-03, 1.0144471d-03, 1.8406430d-09 /
      data fpppp( 6,18,16,1),fpppp( 6,18,16,2),fpppp( 6,18,16,3)/
     x-6.8480461d-03,-4.6018849d-04,-5.2877492d-09 /
      data fpppp( 6,18,17,1),fpppp( 6,18,17,2),fpppp( 6,18,17,3)/
     x-8.7160476d-03,-6.4955481d-05,-6.1871974d-09 /
      data fpppp( 6,18,18,1),fpppp( 6,18,18,2),fpppp( 6,18,18,3)/
     x-1.0237374d-02,-1.5892205d-04,-9.7726422d-09 /
      data fpppp( 6,18,19,1),fpppp( 6,18,19,2),fpppp( 6,18,19,3)/
     x-1.1413876d-02,-1.8057150d-04,-1.1893278d-08 /
      data fpppp( 6,18,20,1),fpppp( 6,18,20,2),fpppp( 6,18,20,3)/
     x-1.2176053d-02,-2.1580855d-04,-1.4949027d-08 /
      data fpppp( 6,18,21,1),fpppp( 6,18,21,2),fpppp( 6,18,21,3)/
     x-1.2176053d-02,-2.1605565d-04,-1.4981999d-08 /
      data fpppp( 6,18,22,1),fpppp( 6,18,22,2),fpppp( 6,18,22,3)/
     x-1.1413876d-02,-1.7958311d-04,-1.1761388d-08 /
      data fpppp( 6,18,23,1),fpppp( 6,18,23,2),fpppp( 6,18,23,3)/
     x-1.0237374d-02,-1.6262849d-04,-1.0267229d-08 /
      data fpppp( 6,19, 1,1),fpppp( 6,19, 1,2),fpppp( 6,19, 1,3)/
     x 9.2214695d-04,-3.8690366d-17,-1.1318001d-07 /
      data fpppp( 6,19, 2,1),fpppp( 6,19, 2,2),fpppp( 6,19, 2,3)/
     x 6.5153423d-04, 9.7549518d-18, 1.9447038d-08 /
      data fpppp( 6,19, 3,1),fpppp( 6,19, 3,2),fpppp( 6,19, 3,3)/
     x 5.1039800d-04, 9.9773407d-18, 3.0242170d-07 /
      data fpppp( 6,19, 4,1),fpppp( 6,19, 4,2),fpppp( 6,19, 4,3)/
     x 5.1039800d-04, 1.3648138d-17, 3.0456748d-07 /
      data fpppp( 6,19, 5,1),fpppp( 6,19, 5,2),fpppp( 6,19, 5,3)/
     x 6.5153423d-04,-4.4108023d-18, 1.0863911d-08 /
      data fpppp( 6,19, 6,1),fpppp( 6,19, 6,2),fpppp( 6,19, 6,3)/
     x 9.2214695d-04,-2.4615160d-18,-8.0993282d-08 /
      data fpppp( 6,19, 7,1),fpppp( 6,19, 7,2),fpppp( 6,19, 7,3)/
     x 1.2236416d-03,-1.6781006d-17,-9.1886419d-08 /
      data fpppp( 6,19, 8,1),fpppp( 6,19, 8,2),fpppp( 6,19, 8,3)/
     x 5.0311857d-04, 1.4383629d-17,-3.4171499d-08 /
      data fpppp( 6,19, 9,1),fpppp( 6,19, 9,2),fpppp( 6,19, 9,3)/
     x 1.4973953d-03,-1.9013594d-18,-1.5735932d-08 /
      data fpppp( 6,19,10,1),fpppp( 6,19,10,2),fpppp( 6,19,10,3)/
     x-7.1250973d-03, 1.3694044d-17,-7.4285945d-07 /
      data fpppp( 6,19,11,1),fpppp( 6,19,11,2),fpppp( 6,19,11,3)/
     x 3.1721985d-02,-1.3241354d-17, 1.4068291d-06 /
      data fpppp( 6,19,12,1),fpppp( 6,19,12,2),fpppp( 6,19,12,3)/
     x-1.3845113d-02,-6.5055002d-18,-8.1601216d-07 /
      data fpppp( 6,19,13,1),fpppp( 6,19,13,2),fpppp( 6,19,13,3)/
     x 1.0893878d-03,-2.2758569d-18, 6.7765860d-08 /
      data fpppp( 6,19,14,1),fpppp( 6,19,14,2),fpppp( 6,19,14,3)/
     x-4.2351479d-03,-2.4975571d-17,-6.7588886d-08 /
      data fpppp( 6,19,15,1),fpppp( 6,19,15,2),fpppp( 6,19,15,3)/
     x-9.4575318d-03,-2.2596153d-17,-3.8196812d-09 /
      data fpppp( 6,19,16,1),fpppp( 6,19,16,2),fpppp( 6,19,16,3)/
     x-1.3998116d-02, 2.5300551d-17,-1.4506929d-08 /
      data fpppp( 6,19,17,1),fpppp( 6,19,17,2),fpppp( 6,19,17,3)/
     x-1.7827862d-02, 1.2919858d-17,-1.3003826d-08 /
      data fpppp( 6,19,18,1),fpppp( 6,19,18,2),fpppp( 6,19,18,3)/
     x-2.0949669d-02,-4.2994241d-18,-1.6263176d-08 /
      data fpppp( 6,19,19,1),fpppp( 6,19,19,2),fpppp( 6,19,19,3)/
     x-2.3365932d-02, 3.2321196d-19,-1.6597949d-08 /
      data fpppp( 6,19,20,1),fpppp( 6,19,20,2),fpppp( 6,19,20,3)/
     x-2.4893549d-02,-1.4010031d-17,-1.8777640d-08 /
      data fpppp( 6,19,21,1),fpppp( 6,19,21,2),fpppp( 6,19,21,3)/
     x-2.4893549d-02,-1.0427912d-18,-1.8745247d-08 /
      data fpppp( 6,19,22,1),fpppp( 6,19,22,2),fpppp( 6,19,22,3)/
     x-2.3365932d-02, 1.8759127d-17,-1.6727521d-08 /
      data fpppp( 6,19,23,1),fpppp( 6,19,23,2),fpppp( 6,19,23,3)/
     x-2.0949669d-02, 3.2356028d-17,-1.5777278d-08 /
      data fpppp( 7, 1, 1,1),fpppp( 7, 1, 1,2),fpppp( 7, 1, 1,3)/
     x-1.9706462d-02,-6.2677355d-17, 2.5429234d-05 /
      data fpppp( 7, 1, 2,1),fpppp( 7, 1, 2,2),fpppp( 7, 1, 2,3)/
     x 1.1173903d-02, 8.0992785d-17, 1.3662979d-05 /
      data fpppp( 7, 1, 3,1),fpppp( 7, 1, 3,2),fpppp( 7, 1, 3,3)/
     x-6.9899138d-03,-5.2907590d-17,-8.8228387d-06 /
      data fpppp( 7, 1, 4,1),fpppp( 7, 1, 4,2),fpppp( 7, 1, 4,3)/
     x-6.9899138d-03,-1.8055278d-16,-1.3596111d-05 /
      data fpppp( 7, 1, 5,1),fpppp( 7, 1, 5,2),fpppp( 7, 1, 5,3)/
     x 1.1173903d-02, 3.4989725d-16, 3.2756069d-05 /
      data fpppp( 7, 1, 6,1),fpppp( 7, 1, 6,2),fpppp( 7, 1, 6,3)/
     x-1.9706462d-02, 1.0795959d-16,-4.6169852d-05 /
      data fpppp( 7, 1, 7,1),fpppp( 7, 1, 7,2),fpppp( 7, 1, 7,3)/
     x-4.0832415d-02, 8.3092467d-18, 1.9585486d-05 /
      data fpppp( 7, 1, 8,1),fpppp( 7, 1, 8,2),fpppp( 7, 1, 8,3)/
     x-8.5014690d-02,-6.6691919d-17, 3.6179092d-06 /
      data fpppp( 7, 1, 9,1),fpppp( 7, 1, 9,2),fpppp( 7, 1, 9,3)/
     x 2.7224106d-02,-1.1210889d-16, 4.3436782d-06 /
      data fpppp( 7, 1,10,1),fpppp( 7, 1,10,2),fpppp( 7, 1,10,3)/
     x 9.0508750d-02,-2.5509550d-16, 1.9512816d-06 /
      data fpppp( 7, 1,11,1),fpppp( 7, 1,11,2),fpppp( 7, 1,11,3)/
     x 1.4095756d-01,-2.5778048d-16, 1.8943493d-06 /
      data fpppp( 7, 1,12,1),fpppp( 7, 1,12,2),fpppp( 7, 1,12,3)/
     x 1.6800552d-01, 2.3395886d-17, 1.7313697d-06 /
      data fpppp( 7, 1,13,1),fpppp( 7, 1,13,2),fpppp( 7, 1,13,3)/
     x 1.2113635d-01,-2.6436137d-16, 1.8710622d-06 /
      data fpppp( 7, 1,14,1),fpppp( 7, 1,14,2),fpppp( 7, 1,14,3)/
     x 8.4515325d-02,-2.1370660d-16, 2.1663178d-06 /
      data fpppp( 7, 1,15,1),fpppp( 7, 1,15,2),fpppp( 7, 1,15,3)/
     x 1.6930191d-02, 1.6639828d-17, 3.6214185d-06 /
      data fpppp( 7, 1,16,1),fpppp( 7, 1,16,2),fpppp( 7, 1,16,3)/
     x-8.4378005d-02,-1.4672775d-16, 6.2797668d-06 /
      data fpppp( 7, 1,17,1),fpppp( 7, 1,17,2),fpppp( 7, 1,17,3)/
     x-7.5118375d-02,-6.0454900d-17, 1.4354266d-05 /
      data fpppp( 7, 1,18,1),fpppp( 7, 1,18,2),fpppp( 7, 1,18,3)/
     x-1.5412922d-02, 1.6817890d-16,-4.2192678d-05 /
      data fpppp( 7, 1,19,1),fpppp( 7, 1,19,2),fpppp( 7, 1,19,3)/
     x 8.5193008d-03,-2.3029284d-16, 3.1544622d-05 /
      data fpppp( 7, 1,20,1),fpppp( 7, 1,20,2),fpppp( 7, 1,20,3)/
     x-8.7115389d-03,-1.2360956d-17,-1.3366897d-05 /
      data fpppp( 7, 1,21,1),fpppp( 7, 1,21,2),fpppp( 7, 1,21,3)/
     x-8.7115389d-03,-1.4700313d-16,-8.8718328d-06 /
      data fpppp( 7, 1,22,1),fpppp( 7, 1,22,2),fpppp( 7, 1,22,3)/
     x 8.5193008d-03, 1.3611874d-16, 1.3564367d-05 /
      data fpppp( 7, 1,23,1),fpppp( 7, 1,23,2),fpppp( 7, 1,23,3)/
     x-1.5412922d-02,-5.2986237d-17, 2.5233278d-05 /
      data fpppp( 7, 2, 1,1),fpppp( 7, 2, 1,2),fpppp( 7, 2, 1,3)/
     x-8.9172263d-03, 1.4980864d-02, 1.2880466d-05 /
      data fpppp( 7, 2, 2,1),fpppp( 7, 2, 2,2),fpppp( 7, 2, 2,3)/
     x 6.0436343d-03, 9.2475560d-03, 7.0877642d-06 /
      data fpppp( 7, 2, 3,1),fpppp( 7, 2, 3,2),fpppp( 7, 2, 3,3)/
     x-2.1093664d-03,-2.4310684d-03,-4.0636277d-06 /
      data fpppp( 7, 2, 4,1),fpppp( 7, 2, 4,2),fpppp( 7, 2, 4,3)/
     x-2.1093664d-03,-3.4933818d-03,-6.2713243d-06 /
      data fpppp( 7, 2, 5,1),fpppp( 7, 2, 5,2),fpppp( 7, 2, 5,3)/
     x 6.0436343d-03, 1.3496810d-02, 1.5918551d-05 /
      data fpppp( 7, 2, 6,1),fpppp( 7, 2, 6,2),fpppp( 7, 2, 6,3)/
     x-8.9172263d-03,-9.5383681d-04,-2.0234983d-05 /
      data fpppp( 7, 2, 7,1),fpppp( 7, 2, 7,2),fpppp( 7, 2, 7,3)/
     x-2.1474697d-02, 1.3217127d-02, 7.5678267d-06 /
      data fpppp( 7, 2, 8,1),fpppp( 7, 2, 8,2),fpppp( 7, 2, 8,3)/
     x-4.2382502d-02,-6.1150360d-02, 1.5982157d-06 /
      data fpppp( 7, 2, 9,1),fpppp( 7, 2, 9,2),fpppp( 7, 2, 9,3)/
     x 1.2747720d-02, 3.6796414d-02, 1.8033690d-06 /
      data fpppp( 7, 2,10,1),fpppp( 7, 2,10,2),fpppp( 7, 2,10,3)/
     x 4.3405731d-02,-1.2151664d-02, 8.4154086d-07 /
      data fpppp( 7, 2,11,1),fpppp( 7, 2,11,2),fpppp( 7, 2,11,3)/
     x 6.8201565d-02, 1.1155317d-02, 8.1227966d-07 /
      data fpppp( 7, 2,12,1),fpppp( 7, 2,12,2),fpppp( 7, 2,12,3)/
     x 8.1249846d-02, 6.7768542d-03, 7.4660333d-07 /
      data fpppp( 7, 2,13,1),fpppp( 7, 2,13,2),fpppp( 7, 2,13,3)/
     x 6.0029885d-02, 1.6962782d-02, 8.0540624d-07 /
      data fpppp( 7, 2,14,1),fpppp( 7, 2,14,2),fpppp( 7, 2,14,3)/
     x 4.0388224d-02,-1.4249555d-02, 9.2789909d-07 /
      data fpppp( 7, 2,15,1),fpppp( 7, 2,15,2),fpppp( 7, 2,15,3)/
     x 7.7389796d-03, 3.1642903d-02, 1.5328534d-06 /
      data fpppp( 7, 2,16,1),fpppp( 7, 2,16,2),fpppp( 7, 2,16,3)/
     x-4.0822389d-02,-5.7683549d-02, 2.6195303d-06 /
      data fpppp( 7, 2,17,1),fpppp( 7, 2,17,2),fpppp( 7, 2,17,3)/
     x-3.5082373d-02, 1.2358862d-02, 5.6268227d-06 /
      data fpppp( 7, 2,18,1),fpppp( 7, 2,18,2),fpppp( 7, 2,18,3)/
     x-6.5591652d-03, 2.9137586d-03,-1.8721765d-05 /
      data fpppp( 7, 2,19,1),fpppp( 7, 2,19,2),fpppp( 7, 2,19,3)/
     x 4.7140053d-03, 9.8225170d-03, 1.5394962d-05 /
      data fpppp( 7, 2,20,1),fpppp( 7, 2,20,2),fpppp( 7, 2,20,3)/
     x-2.8651756d-03,-2.8475220d-03,-6.1780944d-06 /
      data fpppp( 7, 2,21,1),fpppp( 7, 2,21,2),fpppp( 7, 2,21,3)/
     x-2.8651756d-03,-2.2389092d-03,-4.0807453d-06 /
      data fpppp( 7, 2,22,1),fpppp( 7, 2,22,2),fpppp( 7, 2,22,3)/
     x 4.7140053d-03, 7.3880658d-03, 7.0055662d-06 /
      data fpppp( 7, 2,23,1),fpppp( 7, 2,23,2),fpppp( 7, 2,23,3)/
     x-6.5591652d-03, 1.2042951d-02, 1.2738471d-05 /
      data fpppp( 7, 3, 1,1),fpppp( 7, 3, 1,2),fpppp( 7, 3, 1,3)/
     x 1.1427644d-02,-6.9686512d-03,-4.3924230d-05 /
      data fpppp( 7, 3, 2,1),fpppp( 7, 3, 2,2),fpppp( 7, 3, 2,3)/
     x-2.6702150d-03,-3.7143986d-03,-2.6527892d-05 /
      data fpppp( 7, 3, 3,1),fpppp( 7, 3, 3,2),fpppp( 7, 3, 3,3)/
     x 5.9956317d-03, 2.1703635d-03, 6.8852654d-06 /
      data fpppp( 7, 3, 4,1),fpppp( 7, 3, 4,2),fpppp( 7, 3, 4,3)/
     x 5.9956317d-03, 4.0754773d-03, 1.3648508d-05 /
      data fpppp( 7, 3, 5,1),fpppp( 7, 3, 5,2),fpppp( 7, 3, 5,3)/
     x-2.6702150d-03,-1.1334854d-02,-5.3580864d-05 /
      data fpppp( 7, 3, 6,1),fpppp( 7, 3, 6,2),fpppp( 7, 3, 6,3)/
     x 1.1427644d-02, 2.1608055d-02, 5.7524416d-05 /
      data fpppp( 7, 3, 7,1),fpppp( 7, 3, 7,2),fpppp( 7, 3, 7,3)/
     x 1.3912671d-02,-2.1545050d-02,-1.1660932d-05 /
      data fpppp( 7, 3, 8,1),fpppp( 7, 3, 8,2),fpppp( 7, 3, 8,3)/
     x 3.1371605d-02, 4.6170156d-03,-3.9616070d-06 /
      data fpppp( 7, 3, 9,1),fpppp( 7, 3, 9,2),fpppp( 7, 3, 9,3)/
     x-2.0410216d-02, 5.2336135d-03,-3.0883547d-06 /
      data fpppp( 7, 3,10,1),fpppp( 7, 3,10,2),fpppp( 7, 3,10,3)/
     x-5.6425181d-02,-8.8603432d-03,-1.5594084d-06 /
      data fpppp( 7, 3,11,1),fpppp( 7, 3,11,2),fpppp( 7, 3,11,3)/
     x-7.3745993d-02, 1.1307518d-02,-1.3290543d-06 /
      data fpppp( 7, 3,12,1),fpppp( 7, 3,12,2),fpppp( 7, 3,12,3)/
     x-8.7052543d-02,-2.4253605d-02,-1.2313146d-06 /
      data fpppp( 7, 3,13,1),fpppp( 7, 3,13,2),fpppp( 7, 3,13,3)/
     x-4.8349411d-02, 3.7177510d-02,-1.3141748d-06 /
      data fpppp( 7, 3,14,1),fpppp( 7, 3,14,2),fpppp( 7, 3,14,3)/
     x-5.1693385d-02,-2.9185343d-02,-1.6882721d-06 /
      data fpppp( 7, 3,15,1),fpppp( 7, 3,15,2),fpppp( 7, 3,15,3)/
     x-1.5771311d-02, 1.9050401d-02,-2.5713528d-06 /
      data fpppp( 7, 3,16,1),fpppp( 7, 3,16,2),fpppp( 7, 3,16,3)/
     x 2.6001187d-02,-2.9260378d-02,-5.5864071d-06 /
      data fpppp( 7, 3,17,1),fpppp( 7, 3,17,2),fpppp( 7, 3,17,3)/
     x 4.4494515d-02, 2.9020450d-02,-8.0972396d-06 /
      data fpppp( 7, 3,18,1),fpppp( 7, 3,18,2),fpppp( 7, 3,18,3)/
     x 9.6035986d-03,-9.2957603d-03, 5.4007947d-05 /
      data fpppp( 7, 3,19,1),fpppp( 7, 3,19,2),fpppp( 7, 3,19,3)/
     x-7.4984381d-05,-3.7256267d-03,-5.1992034d-05 /
      data fpppp( 7, 3,20,1),fpppp( 7, 3,20,2),fpppp( 7, 3,20,3)/
     x 6.5259746d-03, 2.6179498d-03, 1.3380150d-05 /
      data fpppp( 7, 3,21,1),fpppp( 7, 3,21,2),fpppp( 7, 3,21,3)/
     x 6.5259746d-03, 2.7418326d-03, 6.9003873d-06 /
      data fpppp( 7, 3,22,1),fpppp( 7, 3,22,2),fpppp( 7, 3,22,3)/
     x-7.4984381d-05,-4.2211579d-03,-2.6072983d-05 /
      data fpppp( 7, 3,23,1),fpppp( 7, 3,23,2),fpppp( 7, 3,23,3)/
     x 9.6035986d-03,-7.4375181d-03,-4.3188493d-05 /
      data fpppp( 7, 4, 1,1),fpppp( 7, 4, 1,2),fpppp( 7, 4, 1,3)/
     x-1.6722085d-03,-7.7698407d-03, 5.4166824d-05 /
      data fpppp( 7, 4, 2,1),fpppp( 7, 4, 2,2),fpppp( 7, 4, 2,3)/
     x 1.1584662d-03,-4.2033542d-03, 3.4497995d-05 /
      data fpppp( 7, 4, 3,1),fpppp( 7, 4, 3,2),fpppp( 7, 4, 3,3)/
     x 2.8150524d-03, 2.4983477d-03,-3.8297291d-06 /
      data fpppp( 7, 4, 4,1),fpppp( 7, 4, 4,2),fpppp( 7, 4, 4,3)/
     x 2.8150524d-03, 4.1446938d-03,-1.0514320d-05 /
      data fpppp( 7, 4, 5,1),fpppp( 7, 4, 5,2),fpppp( 7, 4, 5,3)/
     x 1.1584662d-03,-1.0788739d-02, 6.1236358d-05 /
      data fpppp( 7, 4, 6,1),fpppp( 7, 4, 6,2),fpppp( 7, 4, 6,3)/
     x-1.6722085d-03, 1.6925351d-02,-4.6102037d-05 /
      data fpppp( 7, 4, 7,1),fpppp( 7, 4, 7,2),fpppp( 7, 4, 7,3)/
     x-6.8037387d-03,-1.9055415d-02,-5.6508416d-06 /
      data fpppp( 7, 4, 8,1),fpppp( 7, 4, 8,2),fpppp( 7, 4, 8,3)/
     x-3.8010065d-03, 8.3012938d-03, 2.8690225d-06 /
      data fpppp( 7, 4, 9,1),fpppp( 7, 4, 9,2),fpppp( 7, 4, 9,3)/
     x 1.1817271d-02,-3.5580580d-03, 2.4987218d-07 /
      data fpppp( 7, 4,10,1),fpppp( 7, 4,10,2),fpppp( 7, 4,10,3)/
     x 2.8291532d-02, 4.8807594d-03, 5.5887207d-07 /
      data fpppp( 7, 4,11,1),fpppp( 7, 4,11,2),fpppp( 7, 4,11,3)/
     x 2.6476922d-02,-2.4849749d-03, 2.3703678d-07 /
      data fpppp( 7, 4,12,1),fpppp( 7, 4,12,2),fpppp( 7, 4,12,3)/
     x 3.0058555d-02,-2.4933637d-04, 2.6679782d-07 /
      data fpppp( 7, 4,13,1),fpppp( 7, 4,13,2),fpppp( 7, 4,13,3)/
     x 8.7262037d-03, 5.4521202d-05, 2.5498201d-07 /
      data fpppp( 7, 4,14,1),fpppp( 7, 4,14,2),fpppp( 7, 4,14,3)/
     x 2.4065782d-02, 2.5681692d-04, 5.1769019d-07 /
      data fpppp( 7, 4,15,1),fpppp( 7, 4,15,2),fpppp( 7, 4,15,3)/
     x 1.0835174d-02, 1.7702503d-03, 3.7918490d-07 /
      data fpppp( 7, 4,16,1),fpppp( 7, 4,16,2),fpppp( 7, 4,16,3)/
     x 1.1386903d-02,-5.1926565d-03, 2.1176086d-06 /
      data fpppp( 7, 4,17,1),fpppp( 7, 4,17,2),fpppp( 7, 4,17,3)/
     x-1.4321699d-02, 2.7158538d-03,-4.3331343d-06 /
      data fpppp( 7, 4,18,1),fpppp( 7, 4,18,2),fpppp( 7, 4,18,3)/
     x 1.8483909d-04, 4.1762587d-03,-4.5668136d-05 /
      data fpppp( 7, 4,19,1),fpppp( 7, 4,19,2),fpppp( 7, 4,19,3)/
     x-1.4210443d-03,-9.5468607d-03, 5.9951647d-05 /
      data fpppp( 7, 4,20,1),fpppp( 7, 4,20,2),fpppp( 7, 4,20,3)/
     x 3.5103708d-03, 4.2973598d-03,-1.0354653d-05 /
      data fpppp( 7, 4,21,1),fpppp( 7, 4,21,2),fpppp( 7, 4,21,3)/
     x 3.5103708d-03, 3.3392701d-03,-3.7836381d-06 /
      data fpppp( 7, 4,22,1),fpppp( 7, 4,22,2),fpppp( 7, 4,22,3)/
     x-1.4210443d-03,-5.7145021d-03, 3.3667586d-05 /
      data fpppp( 7, 4,23,1),fpppp( 7, 4,23,2),fpppp( 7, 4,23,3)/
     x 1.8483909d-04,-1.0195086d-02, 5.2897095d-05 /
      data fpppp( 7, 5, 1,1),fpppp( 7, 5, 1,2),fpppp( 7, 5, 1,3)/
     x 6.4419389d-04,-3.1172425d-03,-3.7349691d-05 /
      data fpppp( 7, 5, 2,1),fpppp( 7, 5, 2,2),fpppp( 7, 5, 2,3)/
     x 1.3730952d-03,-1.7224811d-03,-2.2892842d-05 /
      data fpppp( 7, 5, 3,1),fpppp( 7, 5, 3,2),fpppp( 7, 5, 3,3)/
     x-4.5432215d-04, 1.0042627d-03, 6.0937630d-06 /
      data fpppp( 7, 5, 4,1),fpppp( 7, 5, 4,2),fpppp( 7, 5, 4,3)/
     x-4.5432215d-04, 1.4628167d-03, 9.5803912d-06 /
      data fpppp( 7, 5, 5,1),fpppp( 7, 5, 5,2),fpppp( 7, 5, 5,3)/
     x 1.3730952d-03,-3.5566971d-03,-3.6839355d-05 /
      data fpppp( 7, 5, 6,1),fpppp( 7, 5, 6,2),fpppp( 7, 5, 6,3)/
     x 6.4419389d-04, 3.7610677d-03, 1.4949732d-05 /
      data fpppp( 7, 5, 7,1),fpppp( 7, 5, 7,2),fpppp( 7, 5, 7,3)/
     x 7.3372626d-03,-2.7196741d-03, 9.9277188d-06 /
      data fpppp( 7, 5, 8,1),fpppp( 7, 5, 8,2),fpppp( 7, 5, 8,3)/
     x 2.0992858d-03, 6.6263746d-04,-1.5600061d-06 /
      data fpppp( 7, 5, 9,1),fpppp( 7, 5, 9,2),fpppp( 7, 5, 9,3)/
     x-3.6410345d-03,-1.8501615d-04, 6.8225827d-07 /
      data fpppp( 7, 5,10,1),fpppp( 7, 5,10,2),fpppp( 7, 5,10,3)/
     x-9.8449686d-03, 1.3123226d-05,-2.6648614d-07 /
      data fpppp( 7, 5,11,1),fpppp( 7, 5,11,2),fpppp( 7, 5,11,3)/
     x-7.5356416d-03, 4.4702970d-05,-5.5340345d-08 /
      data fpppp( 7, 5,12,1),fpppp( 7, 5,12,2),fpppp( 7, 5,12,3)/
     x-8.1632496d-03,-2.6271523d-04,-1.2228060d-07 /
      data fpppp( 7, 5,13,1),fpppp( 7, 5,13,2),fpppp( 7, 5,13,3)/
     x-2.9202885d-03, 9.0426799d-04,-8.0130161d-08 /
      data fpppp( 7, 5,14,1),fpppp( 7, 5,14,2),fpppp( 7, 5,14,3)/
     x-7.5621248d-03,-3.4185063d-03,-1.6709706d-07 /
      data fpppp( 7, 5,15,1),fpppp( 7, 5,15,2),fpppp( 7, 5,15,3)/
     x-3.4891375d-03, 1.2687425d-02, 2.6538359d-07 /
      data fpppp( 7, 5,16,1),fpppp( 7, 5,16,2),fpppp( 7, 5,16,3)/
     x-1.9608800d-02,-2.0009631d-02, 3.8419542d-08 /
      data fpppp( 7, 5,17,1),fpppp( 7, 5,17,2),fpppp( 7, 5,17,3)/
     x 1.0092599d-03, 1.2169950d-02, 6.1959387d-06 /
      data fpppp( 7, 5,18,1),fpppp( 7, 5,18,2),fpppp( 7, 5,18,3)/
     x-2.4182659d-03,-3.0710690d-03, 1.7564781d-05 /
      data fpppp( 7, 5,19,1),fpppp( 7, 5,19,2),fpppp( 7, 5,19,3)/
     x 1.2044594d-03,-4.3650168d-04,-3.4299498d-05 /
      data fpppp( 7, 5,20,1),fpppp( 7, 5,20,2),fpppp( 7, 5,20,3)/
     x-3.6756868d-03, 8.9560853d-04, 7.7926853d-06 /
      data fpppp( 7, 5,21,1),fpppp( 7, 5,21,2),fpppp( 7, 5,21,3)/
     x-3.6756868d-03, 9.9115833d-04, 4.3983515d-06 /
      data fpppp( 7, 5,22,1),fpppp( 7, 5,22,2),fpppp( 7, 5,22,3)/
     x 1.2044594d-03,-8.1870089d-04,-2.0722163d-05 /
      data fpppp( 7, 5,23,1),fpppp( 7, 5,23,2),fpppp( 7, 5,23,3)/
     x-2.4182659d-03,-1.6378219d-03,-3.3350225d-05 /
      data fpppp( 7, 6, 1,1),fpppp( 7, 6, 1,2),fpppp( 7, 6, 1,3)/
     x-1.2536774d-03,-2.2931994d-03, 1.7742280d-05 /
      data fpppp( 7, 6, 2,1),fpppp( 7, 6, 2,2),fpppp( 7, 6, 2,3)/
     x-2.5074835d-03,-1.3823945d-03, 1.0082403d-05 /
      data fpppp( 7, 6, 3,1),fpppp( 7, 6, 3,2),fpppp( 7, 6, 3,3)/
     x-3.8673550d-03, 3.9645100d-04,-5.5369489d-06 /
      data fpppp( 7, 6, 4,1),fpppp( 7, 6, 4,2),fpppp( 7, 6, 4,3)/
     x-3.8673550d-03, 6.9898982d-04,-6.9276225d-06 /
      data fpppp( 7, 6, 5,1),fpppp( 7, 6, 5,2),fpppp( 7, 6, 5,3)/
     x-2.5074835d-03,-2.5925497d-03, 1.5645097d-05 /
      data fpppp( 7, 6, 6,1),fpppp( 7, 6, 6,2),fpppp( 7, 6, 6,3)/
     x-1.2536774d-03, 2.2448828d-03,-3.1178248d-06 /
      data fpppp( 7, 6, 7,1),fpppp( 7, 6, 7,2),fpppp( 7, 6, 7,3)/
     x-1.3397533d-03,-6.6129008d-04,-2.9224198d-06 /
      data fpppp( 7, 6, 8,1),fpppp( 7, 6, 8,2),fpppp( 7, 6, 8,3)/
     x-1.8606517d-04, 1.3515561d-04, 5.3823900d-07 /
      data fpppp( 7, 6, 9,1),fpppp( 7, 6, 9,2),fpppp( 7, 6, 9,3)/
     x 1.3084542d-03,-3.2313092d-05,-2.9878808d-07 /
      data fpppp( 7, 6,10,1),fpppp( 7, 6,10,2),fpppp( 7, 6,10,3)/
     x 2.8857331d-03,-4.3500059d-08, 5.2286508d-08 /
      data fpppp( 7, 6,11,1),fpppp( 7, 6,11,2),fpppp( 7, 6,11,3)/
     x 2.2305530d-03,-9.1443750d-05, 3.1131662d-10 /
      data fpppp( 7, 6,12,1),fpppp( 7, 6,12,2),fpppp( 7, 6,12,3)/
     x 2.4938510d-03, 9.9714660d-05, 3.3563656d-08 /
      data fpppp( 7, 6,13,1),fpppp( 7, 6,13,2),fpppp( 7, 6,13,3)/
     x 1.0825809d-03,-1.8967080d-04, 9.7155649d-09 /
      data fpppp( 7, 6,14,1),fpppp( 7, 6,14,2),fpppp( 7, 6,14,3)/
     x 2.5351337d-03, 3.0166659d-04, 3.6791239d-08 /
      data fpppp( 7, 6,15,1),fpppp( 7, 6,15,2),fpppp( 7, 6,15,3)/
     x 1.2555917d-03,-4.7668538d-04,-1.1062897d-07 /
      data fpppp( 7, 6,16,1),fpppp( 7, 6,16,2),fpppp( 7, 6,16,3)/
     x 1.3383291d-02, 5.2201729d-04,-5.0581064d-08 /
      data fpppp( 7, 6,17,1),fpppp( 7, 6,17,2),fpppp( 7, 6,17,3)/
     x 1.3054036d-04,-3.7905263d-04,-1.3642135d-06 /
      data fpppp( 7, 6,18,1),fpppp( 7, 6,18,2),fpppp( 7, 6,18,3)/
     x 6.7203898d-04, 1.7242139d-04,-4.2062813d-06 /
      data fpppp( 7, 6,19,1),fpppp( 7, 6,19,2),fpppp( 7, 6,19,3)/
     x-4.3295444d-04,-8.4422530d-04, 9.3530300d-06 /
      data fpppp( 7, 6,20,1),fpppp( 7, 6,20,2),fpppp( 7, 6,20,3)/
     x 1.4411239d-03, 5.8025466d-04,-2.6490603d-06 /
      data fpppp( 7, 6,21,1),fpppp( 7, 6,21,2),fpppp( 7, 6,21,3)/
     x 1.4411239d-03, 5.0044118d-04,-1.7395530d-06 /
      data fpppp( 7, 6,22,1),fpppp( 7, 6,22,2),fpppp( 7, 6,22,3)/
     x-4.3295444d-04,-5.2497137d-04, 5.7150009d-06 /
      data fpppp( 7, 6,23,1),fpppp( 7, 6,23,2),fpppp( 7, 6,23,3)/
     x 6.7203898d-04,-1.0247808d-03, 9.4363280d-06 /
      data fpppp( 7, 7, 1,1),fpppp( 7, 7, 1,2),fpppp( 7, 7, 1,3)/
     x 1.1259764d-04, 1.2088169d-04,-1.2773212d-05 /
      data fpppp( 7, 7, 2,1),fpppp( 7, 7, 2,2),fpppp( 7, 7, 2,3)/
     x-3.4175982d-03, 5.2807977d-05,-7.2308229d-06 /
      data fpppp( 7, 7, 3,1),fpppp( 7, 7, 3,2),fpppp( 7, 7, 3,3)/
     x 2.1178166d-03,-9.6831267d-05, 3.9934683d-06 /
      data fpppp( 7, 7, 4,1),fpppp( 7, 7, 4,2),fpppp( 7, 7, 4,3)/
     x 2.1178166d-03,-9.0239026d-05, 5.1349180d-06 /
      data fpppp( 7, 7, 5,1),fpppp( 7, 7, 5,2),fpppp( 7, 7, 5,3)/
     x-3.4175982d-03, 2.6439012d-05,-1.1796622d-05 /
      data fpppp( 7, 7, 6,1),fpppp( 7, 7, 6,2),fpppp( 7, 7, 6,3)/
     x 1.1259764d-04, 2.1976531d-04, 4.3485328d-06 /
      data fpppp( 7, 7, 7,1),fpppp( 7, 7, 7,2),fpppp( 7, 7, 7,3)/
     x-2.9262701d-04,-9.4995974d-05, 2.1012431d-07 /
      data fpppp( 7, 7, 8,1),fpppp( 7, 7, 8,2),fpppp( 7, 7, 8,3)/
     x 1.9008642d-04, 9.1454637d-07,-1.7829060d-07 /
      data fpppp( 7, 7, 9,1),fpppp( 7, 7, 9,2),fpppp( 7, 7, 9,3)/
     x-2.3391379d-04,-6.2154328d-06, 8.1372969d-08 /
      data fpppp( 7, 7,10,1),fpppp( 7, 7,10,2),fpppp( 7, 7,10,3)/
     x-6.2797969d-04,-2.6711002d-06,-5.3548436d-09 /
      data fpppp( 7, 7,11,1),fpppp( 7, 7,11,2),fpppp( 7, 7,11,3)/
     x-4.6058009d-04, 1.7494484d-06, 1.3515973d-08 /
      data fpppp( 7, 7,12,1),fpppp( 7, 7,12,2),fpppp( 7, 7,12,3)/
     x-5.6935661d-04,-4.9533466d-06, 5.6773388d-09 /
      data fpppp( 7, 7,13,1),fpppp( 7, 7,13,2),fpppp( 7, 7,13,3)/
     x-1.8801861d-04, 1.7853576d-05, 1.9881532d-08 /
      data fpppp( 7, 7,14,1),fpppp( 7, 7,14,2),fpppp( 7, 7,14,3)/
     x-6.9502696d-04,-3.4767313d-05, 1.1146209d-08 /
      data fpppp( 7, 7,15,1),fpppp( 7, 7,15,2),fpppp( 7, 7,15,3)/
     x-2.4898678d-04, 2.3660539d-05, 6.8422214d-08 /
      data fpppp( 7, 7,16,1),fpppp( 7, 7,16,2),fpppp( 7, 7,16,3)/
     x-3.6998751d-03,-8.1638155d-06, 3.6210856d-08 /
      data fpppp( 7, 7,17,1),fpppp( 7, 7,17,2),fpppp( 7, 7,17,3)/
     x-2.2012227d-05,-5.2237462d-07, 4.5928068d-07 /
      data fpppp( 7, 7,18,1),fpppp( 7, 7,18,2),fpppp( 7, 7,18,3)/
     x-2.2794368d-04, 1.5228695d-05, 1.0616159d-06 /
      data fpppp( 7, 7,19,1),fpppp( 7, 7,19,2),fpppp( 7, 7,19,3)/
     x-1.9726828d-04, 1.2414003d-04,-1.5145552d-06 /
      data fpppp( 7, 7,20,1),fpppp( 7, 7,20,2),fpppp( 7, 7,20,3)/
     x-1.8367374d-03,-9.5500635d-05,-6.0904337d-08 /
      data fpppp( 7, 7,21,1),fpppp( 7, 7,21,2),fpppp( 7, 7,21,3)/
     x-1.8367374d-03,-8.5465335d-05,-2.1539207d-07 /
      data fpppp( 7, 7,22,1),fpppp( 7, 7,22,2),fpppp( 7, 7,22,3)/
     x-1.9726828d-04, 8.3998833d-05,-8.9660426d-07 /
      data fpppp( 7, 7,23,1),fpppp( 7, 7,23,2),fpppp( 7, 7,23,3)/
     x-2.2794368d-04, 1.6575819d-04,-1.2557000d-06 /
      data fpppp( 7, 8, 1,1),fpppp( 7, 8, 1,2),fpppp( 7, 8, 1,3)/
     x 2.6870347d-04, 8.6017778d-03, 1.3479104d-05 /
      data fpppp( 7, 8, 2,1),fpppp( 7, 8, 2,2),fpppp( 7, 8, 2,3)/
     x 7.9982997d-03, 4.9917772d-03, 8.0534674d-06 /
      data fpppp( 7, 8, 3,1),fpppp( 7, 8, 3,2),fpppp( 7, 8, 3,3)/
     x-1.9795040d-03,-2.2230184d-03,-2.6494947d-06 /
      data fpppp( 7, 8, 4,1),fpppp( 7, 8, 4,2),fpppp( 7, 8, 4,3)/
     x-1.9795040d-03,-3.1346286d-03,-4.2654476d-06 /
      data fpppp( 7, 8, 5,1),fpppp( 7, 8, 5,2),fpppp( 7, 8, 5,3)/
     x 7.9982997d-03, 8.6382180d-03, 1.4517279d-05 /
      data fpppp( 7, 8, 6,1),fpppp( 7, 8, 6,2),fpppp( 7, 8, 6,3)/
     x 2.6870347d-04,-5.0723754d-03,-1.0760189d-05 /
      data fpppp( 7, 8, 7,1),fpppp( 7, 8, 7,2),fpppp( 7, 8, 7,3)/
     x 3.1102029d-03, 1.0361325d-03, 1.4980840d-06 /
      data fpppp( 7, 8, 8,1),fpppp( 7, 8, 8,2),fpppp( 7, 8, 8,3)/
     x-1.0409693d-05,-2.9623636d-04, 5.5548069d-07 /
      data fpppp( 7, 8, 9,1),fpppp( 7, 8, 9,2),fpppp( 7, 8, 9,3)/
     x 1.5359367d-04, 1.0527991d-04,-2.4414373d-08 /
      data fpppp( 7, 8,10,1),fpppp( 7, 8,10,2),fpppp( 7, 8,10,3)/
     x 2.6125943d-04,-3.7820495d-05, 6.0737898d-08 /
      data fpppp( 7, 8,11,1),fpppp( 7, 8,11,2),fpppp( 7, 8,11,3)/
     x 2.5425131d-04, 3.8361321d-05, 2.1155242d-08 /
      data fpppp( 7, 8,12,1),fpppp( 7, 8,12,2),fpppp( 7, 8,12,3)/
     x 2.6651049d-04,-1.7733350d-05, 2.7000146d-08 /
      data fpppp( 7, 8,13,1),fpppp( 7, 8,13,2),fpppp( 7, 8,13,3)/
     x 1.0937112d-04, 3.0898701d-05, 2.4855223d-08 /
      data fpppp( 7, 8,14,1),fpppp( 7, 8,14,2),fpppp( 7, 8,14,3)/
     x 2.9930137d-04,-2.7665041d-05, 3.5963100d-08 /
      data fpppp( 7, 8,15,1),fpppp( 7, 8,15,2),fpppp( 7, 8,15,3)/
     x 1.0448242d-04, 3.9691030d-05, 4.3326488d-08 /
      data fpppp( 7, 8,16,1),fpppp( 7, 8,16,2),fpppp( 7, 8,16,3)/
     x 1.0061864d-03,-2.8568592d-05, 7.4532956d-08 /
      data fpppp( 7, 8,17,1),fpppp( 7, 8,17,2),fpppp( 7, 8,17,3)/
     x-1.6209813d-05, 3.3671711d-05,-1.9568849d-09 /
      data fpppp( 7, 8,18,1),fpppp( 7, 8,18,2),fpppp( 7, 8,18,3)/
     x-1.1532268d-05, 1.1750511d-05,-1.7182731d-07 /
      data fpppp( 7, 8,19,1),fpppp( 7, 8,19,2),fpppp( 7, 8,19,3)/
     x-5.6298275d-05, 7.2475319d-05, 6.4737744d-07 /
      data fpppp( 7, 8,20,1),fpppp( 7, 8,20,2),fpppp( 7, 8,20,3)/
     x 3.5852973d-04,-8.6762390d-05,-4.7274456d-07 /
      data fpppp( 7, 8,21,1),fpppp( 7, 8,21,2),fpppp( 7, 8,21,3)/
     x 3.5852973d-04,-8.0352466d-05,-4.0904543d-07 /
      data fpppp( 7, 8,22,1),fpppp( 7, 8,22,2),fpppp( 7, 8,22,3)/
     x-5.6298275d-05, 4.6835622d-05, 3.9258092d-07 /
      data fpppp( 7, 8,23,1),fpppp( 7, 8,23,2),fpppp( 7, 8,23,3)/
     x-1.1532268d-05, 1.0789938d-04, 7.8365965d-07 /
      data fpppp( 7, 9, 1,1),fpppp( 7, 9, 1,2),fpppp( 7, 9, 1,3)/
     x-8.3430178d-04, 4.1679955d-04,-7.8739505d-06 /
      data fpppp( 7, 9, 2,1),fpppp( 7, 9, 2,2),fpppp( 7, 9, 2,3)/
     x-4.9582646d-03, 2.6217409d-04,-5.0281028d-06 /
      data fpppp( 7, 9, 3,1),fpppp( 7, 9, 3,2),fpppp( 7, 9, 3,3)/
     x 1.5424617d-03,-1.4834255d-04, 1.9608142d-07 /
      data fpppp( 7, 9, 4,1),fpppp( 7, 9, 4,2),fpppp( 7, 9, 4,3)/
     x 1.5424617d-03,-9.7839503d-06, 1.7256881d-06 /
      data fpppp( 7, 9, 5,1),fpppp( 7, 9, 5,2),fpppp( 7, 9, 5,3)/
     x-4.9582646d-03,-2.9206031d-04,-1.1146529d-05 /
      data fpppp( 7, 9, 6,1),fpppp( 7, 9, 6,2),fpppp( 7, 9, 6,3)/
     x-8.3430178d-04, 2.4951785d-03, 1.5070149d-05 /
      data fpppp( 7, 9, 7,1),fpppp( 7, 9, 7,2),fpppp( 7, 9, 7,3)/
     x-7.2450660d-03,-3.9152247d-03,-4.7288442d-06 /
      data fpppp( 7, 9, 8,1),fpppp( 7, 9, 8,2),fpppp( 7, 9, 8,3)/
     x 5.5920556d-04, 2.1313862d-03,-1.6140214d-06 /
      data fpppp( 7, 9, 9,1),fpppp( 7, 9, 9,2),fpppp( 7, 9, 9,3)/
     x 2.1535479d-04,-5.1620505d-04, 4.1846544d-07 /
      data fpppp( 7, 9,10,1),fpppp( 7, 9,10,2),fpppp( 7, 9,10,3)/
     x 6.3232968d-05, 1.3049068d-04,-7.9931155d-08 /
      data fpppp( 7, 9,11,1),fpppp( 7, 9,11,2),fpppp( 7, 9,11,3)/
     x-1.6867742d-04, 1.7092631d-05, 4.2979762d-08 /
      data fpppp( 7, 9,12,1),fpppp( 7, 9,12,2),fpppp( 7, 9,12,3)/
     x-1.9114126d-04, 7.8879624d-06, 1.0909669d-08 /
      data fpppp( 7, 9,13,1),fpppp( 7, 9,13,2),fpppp( 7, 9,13,3)/
     x 6.0949632d-05, 3.5294173d-05, 2.3150506d-08 /
      data fpppp( 7, 9,14,1),fpppp( 7, 9,14,2),fpppp( 7, 9,14,3)/
     x-2.0382512d-04,-4.1298970d-05, 2.5762084d-08 /
      data fpppp( 7, 9,15,1),fpppp( 7, 9,15,2),fpppp( 7, 9,15,3)/
     x 2.5460547d-05, 5.5428093d-05, 2.9656138d-08 /
      data fpppp( 7, 9,16,1),fpppp( 7, 9,16,2),fpppp( 7, 9,16,3)/
     x-2.5236254d-04,-4.5009077d-05, 2.6919412d-08 /
      data fpppp( 7, 9,17,1),fpppp( 7, 9,17,2),fpppp( 7, 9,17,3)/
     x 2.9878663d-05, 4.4717011d-05, 4.2874187d-08 /
      data fpppp( 7, 9,18,1),fpppp( 7, 9,18,2),fpppp( 7, 9,18,3)/
     x 5.9662352d-06, 1.5250126d-05, 6.8481920d-08 /
      data fpppp( 7, 9,19,1),fpppp( 7, 9,19,2),fpppp( 7, 9,19,3)/
     x 5.1653844d-06, 7.7992418d-05,-1.6487636d-07 /
      data fpppp( 7, 9,20,1),fpppp( 7, 9,20,2),fpppp( 7, 9,20,3)/
     x 5.4977572d-05,-9.4884583d-05,-6.6258966d-08 /
      data fpppp( 7, 9,21,1),fpppp( 7, 9,21,2),fpppp( 7, 9,21,3)/
     x 5.4977572d-05,-8.8076756d-05,-7.9520663d-08 /
      data fpppp( 7, 9,22,1),fpppp( 7, 9,22,2),fpppp( 7, 9,22,3)/
     x 5.1653844d-06, 5.0761109d-05,-1.1182958d-07 /
      data fpppp( 7, 9,23,1),fpppp( 7, 9,23,2),fpppp( 7, 9,23,3)/
     x 5.9662352d-06, 1.1736753d-04,-1.3044352d-07 /
      data fpppp( 7,10, 1,1),fpppp( 7,10, 1,2),fpppp( 7,10, 1,3)/
     x 1.1573902d-03,-1.4110374d-04, 2.4789922d-06 /
      data fpppp( 7,10, 2,1),fpppp( 7,10, 2,2),fpppp( 7,10, 2,3)/
     x 1.6580588d-03,-1.5455059d-04, 1.4622258d-06 /
      data fpppp( 7,10, 3,1),fpppp( 7,10, 3,2),fpppp( 7,10, 3,3)/
     x 2.1605380d-04,-1.0357228d-04,-2.6725309d-07 /
      data fpppp( 7,10, 4,1),fpppp( 7,10, 4,2),fpppp( 7,10, 4,3)/
     x 2.1605380d-04,-2.4320999d-04,-1.0535392d-06 /
      data fpppp( 7,10, 5,1),fpppp( 7,10, 5,2),fpppp( 7,10, 5,3)/
     x 1.6580588d-03, 4.0400028d-04, 4.6073701d-06 /
      data fpppp( 7,10, 6,1),fpppp( 7,10, 6,2),fpppp( 7,10, 6,3)/
     x 1.1573902d-03,-2.2356695d-03,-9.3152991d-06 /
      data fpppp( 7,10, 7,1),fpppp( 7,10, 7,2),fpppp( 7,10, 7,3)/
     x 6.8854457d-03, 5.3615985d-03, 6.9876879d-06 /
      data fpppp( 7,10, 8,1),fpppp( 7,10, 8,2),fpppp( 7,10, 8,3)/
     x-2.2826826d-03,-4.0534639d-03, 5.3215579d-07 /
      data fpppp( 7,10, 9,1),fpppp( 7,10, 9,2),fpppp( 7,10, 9,3)/
     x-2.7864863d-04, 9.4830922d-04,-1.4166860d-06 /
      data fpppp( 7,10,10,1),fpppp( 7,10,10,2),fpppp( 7,10,10,3)/
     x 5.7844604d-05,-3.8968496d-04, 4.5550208d-08 /
      data fpppp( 7,10,11,1),fpppp( 7,10,11,2),fpppp( 7,10,11,3)/
     x 4.1307943d-04, 2.4868537d-04,-7.7169646d-08 /
      data fpppp( 7,10,12,1),fpppp( 7,10,12,2),fpppp( 7,10,12,3)/
     x 4.1065678d-04, 2.0994640d-04, 1.4339124d-08 /
      data fpppp( 7,10,13,1),fpppp( 7,10,13,2),fpppp( 7,10,13,3)/
     x 6.5472390d-06,-3.9178682d-04, 5.9663276d-09 /
      data fpppp( 7,10,14,1),fpppp( 7,10,14,2),fpppp( 7,10,14,3)/
     x 2.3929000d-04, 4.1099521d-04, 1.4556316d-08 /
      data fpppp( 7,10,15,1),fpppp( 7,10,15,2),fpppp( 7,10,15,3)/
     x 9.0592078d-06,-2.3255191d-04, 1.4394379d-08 /
      data fpppp( 7,10,16,1),fpppp( 7,10,16,2),fpppp( 7,10,16,3)/
     x 8.7271280d-05, 6.4021371d-05, 5.7199720d-09 /
      data fpppp( 7,10,17,1),fpppp( 7,10,17,2),fpppp( 7,10,17,3)/
     x-1.2312691d-05,-4.0433895d-06,-1.1847583d-08 /
      data fpppp( 7,10,18,1),fpppp( 7,10,18,2),fpppp( 7,10,18,3)/
     x-9.9587394d-06, 3.6898746d-05,-3.4840055d-08 /
      data fpppp( 7,10,19,1),fpppp( 7,10,19,2),fpppp( 7,10,19,3)/
     x-1.3482386d-06, 1.1997850d-04, 3.4674485d-08 /
      data fpppp( 7,10,20,1),fpppp( 7,10,20,2),fpppp( 7,10,20,3)/
     x-5.0912604d-04,-1.2137386d-04,-6.0105794d-08 /
      data fpppp( 7,10,21,1),fpppp( 7,10,21,2),fpppp( 7,10,21,3)/
     x-5.0912604d-04,-1.1208378d-04,-5.4706490d-08 /
      data fpppp( 7,10,22,1),fpppp( 7,10,22,2),fpppp( 7,10,22,3)/
     x-1.3482386d-06, 8.2818214d-05, 1.3077269d-08 /
      data fpppp( 7,10,23,1),fpppp( 7,10,23,2),fpppp( 7,10,23,3)/
     x-9.9587394d-06, 1.7624983d-04, 4.6149504d-08 /
      data fpppp( 7,11, 1,1),fpppp( 7,11, 1,2),fpppp( 7,11, 1,3)/
     x-7.9502325d-05, 3.6592588d-04, 3.1232267d-07 /
      data fpppp( 7,11, 2,1),fpppp( 7,11, 2,2),fpppp( 7,11, 2,3)/
     x 3.9097098d-04, 1.0012972d-04,-2.0222168d-08 /
      data fpppp( 7,11, 3,1),fpppp( 7,11, 3,2),fpppp( 7,11, 3,3)/
     x 1.3635297d-03,-4.5327485d-04,-8.4180250d-07 /
      data fpppp( 7,11, 4,1),fpppp( 7,11, 4,2),fpppp( 7,11, 4,3)/
     x 1.3635297d-03,-4.8155244d-04,-6.5108007d-07 /
      data fpppp( 7,11, 5,1),fpppp( 7,11, 5,2),fpppp( 7,11, 5,3)/
     x 3.9097098d-04, 2.1324007d-04,-7.8311188d-07 /
      data fpppp( 7,11, 6,1),fpppp( 7,11, 6,2),fpppp( 7,11, 6,3)/
     x-7.9502325d-05,-5.8237909d-05, 3.1731591d-06 /
      data fpppp( 7,11, 7,1),fpppp( 7,11, 7,2),fpppp( 7,11, 7,3)/
     x-2.4914032d-03, 3.3086566d-04,-3.4309946d-06 /
      data fpppp( 7,11, 8,1),fpppp( 7,11, 8,2),fpppp( 7,11, 8,3)/
     x 2.0415908d-03, 1.6588264d-03, 1.8043142d-06 /
      data fpppp( 7,11, 9,1),fpppp( 7,11, 9,2),fpppp( 7,11, 9,3)/
     x-7.2202831d-04,-1.6242683d-03, 8.0318167d-07 /
      data fpppp( 7,11,10,1),fpppp( 7,11,10,2),fpppp( 7,11,10,3)/
     x-2.5672011d-04, 9.1859399d-05,-4.3795853d-07 /
      data fpppp( 7,11,11,1),fpppp( 7,11,11,2),fpppp( 7,11,11,3)/
     x-2.8232312d-04, 1.4756533d-05,-1.6048988d-08 /
      data fpppp( 7,11,12,1),fpppp( 7,11,12,2),fpppp( 7,11,12,3)/
     x-2.6109011d-04, 9.8023768d-05,-3.0466068d-08 /
      data fpppp( 7,11,13,1),fpppp( 7,11,13,2),fpppp( 7,11,13,3)/
     x 8.9196684d-06,-1.8083800d-04, 4.6916050d-09 /
      data fpppp( 7,11,14,1),fpppp( 7,11,14,2),fpppp( 7,11,14,3)/
     x-5.7347386d-05, 3.1941790d-04, 4.0228657d-09 /
      data fpppp( 7,11,15,1),fpppp( 7,11,15,2),fpppp( 7,11,15,3)/
     x 2.1707421d-05,-1.9558769d-04, 1.4980638d-09 /
      data fpppp( 7,11,16,1),fpppp( 7,11,16,2),fpppp( 7,11,16,3)/
     x 1.3530596d-05, 5.6577472d-05,-2.7763883d-09 /
      data fpppp( 7,11,17,1),fpppp( 7,11,17,2),fpppp( 7,11,17,3)/
     x 5.1291868d-05,-1.7032419d-05,-6.2672192d-09 /
      data fpppp( 7,11,18,1),fpppp( 7,11,18,2),fpppp( 7,11,18,3)/
     x 6.6989711d-05, 1.1147086d-04, 3.8885096d-10 /
      data fpppp( 7,11,19,1),fpppp( 7,11,19,2),fpppp( 7,11,19,3)/
     x 8.6028470d-05,-3.4022065d-05,-5.2960408d-08 /
      data fpppp( 7,11,20,1),fpppp( 7,11,20,2),fpppp( 7,11,20,3)/
     x 1.4902208d-03,-4.6626606d-05, 7.2069227d-09 /
      data fpppp( 7,11,21,1),fpppp( 7,11,21,2),fpppp( 7,11,21,3)/
     x 1.4902208d-03,-5.3253701d-05, 3.3417005d-09 /
      data fpppp( 7,11,22,1),fpppp( 7,11,22,2),fpppp( 7,11,22,3)/
     x 8.6028470d-05,-7.5136843d-06,-3.7499519d-08 /
      data fpppp( 7,11,23,1),fpppp( 7,11,23,2),fpppp( 7,11,23,3)/
     x 6.6989711d-05, 1.2064432d-05,-5.7589481d-08 /
      data fpppp( 7,12, 1,1),fpppp( 7,12, 1,2),fpppp( 7,12, 1,3)/
     x 2.9120817d-04, 1.6414458d-03, 8.3982856d-07 /
      data fpppp( 7,12, 2,1),fpppp( 7,12, 2,2),fpppp( 7,12, 2,3)/
     x 1.1435063d-03, 6.6543282d-04, 3.2348000d-07 /
      data fpppp( 7,12, 3,1),fpppp( 7,12, 3,2),fpppp( 7,12, 3,3)/
     x 3.3575474d-03,-1.3865479d-03,-7.3219678d-07 /
      data fpppp( 7,12, 4,1),fpppp( 7,12, 4,2),fpppp( 7,12, 4,3)/
     x 3.3575474d-03,-1.4556302d-03,-8.2106949d-07 /
      data fpppp( 7,12, 5,1),fpppp( 7,12, 5,2),fpppp( 7,12, 5,3)/
     x 1.1435063d-03, 9.4176216d-04, 6.7897086d-07 /
      data fpppp( 7,12, 6,1),fpppp( 7,12, 6,2),fpppp( 7,12, 6,3)/
     x 2.9120817d-04, 6.0521077d-04,-4.9326214d-07 /
      data fpppp( 7,12, 7,1),fpppp( 7,12, 7,2),fpppp( 7,12, 7,3)/
     x 6.8738558d-04, 1.4827153d-04, 9.5997657d-07 /
      data fpppp( 7,12, 8,1),fpppp( 7,12, 8,2),fpppp( 7,12, 8,3)/
     x-2.9813480d-04, 9.9424260d-04,-6.4123247d-07 /
      data fpppp( 7,12, 9,1),fpppp( 7,12, 9,2),fpppp( 7,12, 9,3)/
     x 4.7063799d-04, 2.0251514d-04, 6.3811265d-07 /
      data fpppp( 7,12,10,1),fpppp( 7,12,10,2),fpppp( 7,12,10,3)/
     x-2.2341950d-04,-8.6182761d-04, 1.5429033d-07 /
      data fpppp( 7,12,11,1),fpppp( 7,12,11,2),fpppp( 7,12,11,3)/
     x-3.9437487d-05, 5.5528443d-05,-6.4973419d-08 /
      data fpppp( 7,12,12,1),fpppp( 7,12,12,2),fpppp( 7,12,12,3)/
     x 6.0513921d-05, 6.8185521d-05,-4.1651967d-09 /
      data fpppp( 7,12,13,1),fpppp( 7,12,13,2),fpppp( 7,12,13,3)/
     x-1.8961172d-05,-1.5893375d-04,-5.9523514d-09 /
      data fpppp( 7,12,14,1),fpppp( 7,12,14,2),fpppp( 7,12,14,3)/
     x 9.2455008d-06, 3.0136123d-04,-2.7190197d-09 /
      data fpppp( 7,12,15,1),fpppp( 7,12,15,2),fpppp( 7,12,15,3)/
     x 5.2320117d-06,-1.7756770d-04,-4.7220693d-09 /
      data fpppp( 7,12,16,1),fpppp( 7,12,16,2),fpppp( 7,12,16,3)/
     x 2.1708011d-05, 3.1395685d-05,-2.0414395d-09 /
      data fpppp( 7,12,17,1),fpppp( 7,12,17,2),fpppp( 7,12,17,3)/
     x 3.4344282d-05, 6.1990953d-05, 3.7999769d-09 /
      data fpppp( 7,12,18,1),fpppp( 7,12,18,2),fpppp( 7,12,18,3)/
     x 5.3800064d-05,-1.4376502d-04,-1.2582395d-08 /
      data fpppp( 7,12,19,1),fpppp( 7,12,19,2),fpppp( 7,12,19,3)/
     x 4.0630488d-05, 1.0261918d-03,-5.4088182d-08 /
      data fpppp( 7,12,20,1),fpppp( 7,12,20,2),fpppp( 7,12,20,3)/
     x-1.1411582d-03,-6.4332228d-04, 3.5926467d-08 /
      data fpppp( 7,12,21,1),fpppp( 7,12,21,2),fpppp( 7,12,21,3)/
     x-1.1411582d-03,-5.5080345d-04, 3.1962261d-08 /
      data fpppp( 7,12,22,1),fpppp( 7,12,22,2),fpppp( 7,12,22,3)/
     x 4.0630488d-05, 6.5611647d-04,-3.8231355d-08 /
      data fpppp( 7,12,23,1),fpppp( 7,12,23,2),fpppp( 7,12,23,3)/
     x 5.3800064d-05, 1.2440175d-03,-7.2045498d-08 /
      data fpppp( 7,13, 1,1),fpppp( 7,13, 1,2),fpppp( 7,13, 1,3)/
     x-1.9479377d-04, 4.4882227d-03,-2.7816247d-06 /
      data fpppp( 7,13, 2,1),fpppp( 7,13, 2,2),fpppp( 7,13, 2,3)/
     x-1.7584082d-03, 2.0140527d-03,-1.3373322d-06 /
      data fpppp( 7,13, 3,1),fpppp( 7,13, 3,2),fpppp( 7,13, 3,3)/
     x-5.4094555d-03,-3.1627208d-03, 1.6767550d-06 /
      data fpppp( 7,13, 4,1),fpppp( 7,13, 4,2),fpppp( 7,13, 4,3)/
     x-5.4094555d-03,-3.3815047d-03, 1.8181991d-06 /
      data fpppp( 7,13, 5,1),fpppp( 7,13, 5,2),fpppp( 7,13, 5,3)/
     x-1.7584082d-03, 2.8891882d-03,-1.9031088d-06 /
      data fpppp( 7,13, 6,1),fpppp( 7,13, 6,2),fpppp( 7,13, 6,3)/
     x-1.9479377d-04, 1.2064645d-03,-6.5996244d-07 /
      data fpppp( 7,13, 7,1),fpppp( 7,13, 7,2),fpppp( 7,13, 7,3)/
     x-2.4318282d-04, 4.3602425d-04,-5.3852674d-07 /
      data fpppp( 7,13, 8,1),fpppp( 7,13, 8,2),fpppp( 7,13, 8,3)/
     x 1.2253343d-04, 3.4267524d-04, 2.7207700d-08 /
      data fpppp( 7,13, 9,1),fpppp( 7,13, 9,2),fpppp( 7,13, 9,3)/
     x 2.0386864d-04, 9.4306437d-04, 1.2557474d-07 /
      data fpppp( 7,13,10,1),fpppp( 7,13,10,2),fpppp( 7,13,10,3)/
     x-1.8005989d-04,-5.7125190d-04, 2.5897722d-07 /
      data fpppp( 7,13,11,1),fpppp( 7,13,11,2),fpppp( 7,13,11,3)/
     x-1.2186319d-04,-3.3114425d-04,-1.0504337d-08 /
      data fpppp( 7,13,12,1),fpppp( 7,13,12,2),fpppp( 7,13,12,3)/
     x-1.9359314d-04, 8.4649893d-05, 1.7814863d-08 /
      data fpppp( 7,13,13,1),fpppp( 7,13,13,2),fpppp( 7,13,13,3)/
     x-3.4555702d-05,-1.3295721d-04,-4.5072290d-09 /
      data fpppp( 7,13,14,1),fpppp( 7,13,14,2),fpppp( 7,13,14,3)/
     x 4.9165456d-05, 2.3984669d-04,-5.4146767d-09 /
      data fpppp( 7,13,15,1),fpppp( 7,13,15,2),fpppp( 7,13,15,3)/
     x-3.0018966d-05,-1.3625290d-04,-6.3931984d-09 /
      data fpppp( 7,13,16,1),fpppp( 7,13,16,2),fpppp( 7,13,16,3)/
     x-3.3324574d-05, 2.7097645d-05,-8.1631732d-10 /
      data fpppp( 7,13,17,1),fpppp( 7,13,17,2),fpppp( 7,13,17,3)/
     x-3.7044123d-05, 6.4349769d-05, 2.4845775d-09 /
      data fpppp( 7,13,18,1),fpppp( 7,13,18,2),fpppp( 7,13,18,3)/
     x-6.0894297d-05,-1.2814244d-04,-4.1298695d-09 /
      data fpppp( 7,13,19,1),fpppp( 7,13,19,2),fpppp( 7,13,19,3)/
     x-1.3283920d-04, 9.0438112d-04, 1.4458270d-08 /
      data fpppp( 7,13,20,1),fpppp( 7,13,20,2),fpppp( 7,13,20,3)/
     x-7.0997765d-04,-5.7729463d-04, 4.2172767d-09 /
      data fpppp( 7,13,21,1),fpppp( 7,13,21,2),fpppp( 7,13,21,3)/
     x-7.0997765d-04,-4.9546050d-04, 5.3264825d-09 /
      data fpppp( 7,13,22,1),fpppp( 7,13,22,2),fpppp( 7,13,22,3)/
     x-1.3283920d-04, 5.7704462d-04, 1.0021447d-08 /
      data fpppp( 7,13,23,1),fpppp( 7,13,23,2),fpppp( 7,13,23,3)/
     x-6.0894297d-05, 1.0993694d-03, 1.2508218d-08 /
      data fpppp( 7,14, 1,1),fpppp( 7,14, 1,2),fpppp( 7,14, 1,3)/
     x-1.1340522d-03, 4.0983863d-03,-1.5552969d-06 /
      data fpppp( 7,14, 2,1),fpppp( 7,14, 2,2),fpppp( 7,14, 2,3)/
     x-2.7864456d-03, 1.8109660d-03,-6.1143671d-07 /
      data fpppp( 7,14, 3,1),fpppp( 7,14, 3,2),fpppp( 7,14, 3,3)/
     x-4.9226771d-03,-2.9672808d-03, 1.3903668d-06 /
      data fpppp( 7,14, 4,1),fpppp( 7,14, 4,2),fpppp( 7,14, 4,3)/
     x-4.9226771d-03,-3.1831751d-03, 1.4266862d-06 /
      data fpppp( 7,14, 5,1),fpppp( 7,14, 5,2),fpppp( 7,14, 5,3)/
     x-2.7864456d-03, 2.6745436d-03,-7.5671463d-07 /
      data fpppp( 7,14, 6,1),fpppp( 7,14, 6,2),fpppp( 7,14, 6,3)/
     x-1.1340522d-03, 8.5997054d-04,-1.0105047d-06 /
      data fpppp( 7,14, 7,1),fpppp( 7,14, 7,2),fpppp( 7,14, 7,3)/
     x-2.2258325d-04, 7.3637587d-04,-4.7166406d-07 /
      data fpppp( 7,14, 8,1),fpppp( 7,14, 8,2),fpppp( 7,14, 8,3)/
     x-8.2846285d-05, 9.1451408d-05,-2.5028396d-07 /
      data fpppp( 7,14, 9,1),fpppp( 7,14, 9,2),fpppp( 7,14, 9,3)/
     x 3.6187749d-05, 6.6570667d-04, 2.4853440d-09 /
      data fpppp( 7,14,10,1),fpppp( 7,14,10,2),fpppp( 7,14,10,3)/
     x 5.0749011d-04, 4.1899101d-04, 2.9633856d-07 /
      data fpppp( 7,14,11,1),fpppp( 7,14,11,2),fpppp( 7,14,11,3)/
     x-4.6510864d-05,-8.7734166d-04,-7.4172987d-09 /
      data fpppp( 7,14,12,1),fpppp( 7,14,12,2),fpppp( 7,14,12,3)/
     x 1.8626970d-04, 2.2259022d-04, 4.1240230d-08 /
      data fpppp( 7,14,13,1),fpppp( 7,14,13,2),fpppp( 7,14,13,3)/
     x-1.8158511d-05,-1.2692544d-04, 4.9313951d-09 /
      data fpppp( 7,14,14,1),fpppp( 7,14,14,2),fpppp( 7,14,14,3)/
     x-1.2059671d-04, 4.5041957d-05,-9.1726789d-10 /
      data fpppp( 7,14,15,1),fpppp( 7,14,15,2),fpppp( 7,14,15,3)/
     x-3.6522447d-06,-6.2923677d-06,-2.4752868d-09 /
      data fpppp( 7,14,16,1),fpppp( 7,14,16,2),fpppp( 7,14,16,3)/
     x-1.8053170d-06, 1.0414071d-05, 4.0230178d-10 /
      data fpppp( 7,14,17,1),fpppp( 7,14,17,2),fpppp( 7,14,17,3)/
     x-8.4072811d-06, 1.3660606d-05, 4.8094906d-09 /
      data fpppp( 7,14,18,1),fpppp( 7,14,18,2),fpppp( 7,14,18,3)/
     x-1.7176644d-05, 3.6187202d-05, 1.7775170d-08 /
      data fpppp( 7,14,19,1),fpppp( 7,14,19,2),fpppp( 7,14,19,3)/
     x 3.9111816d-06, 4.5643106d-05, 3.8134139d-08 /
      data fpppp( 7,14,20,1),fpppp( 7,14,20,2),fpppp( 7,14,20,3)/
     x 8.5449815d-04,-7.2158859d-05,-2.3225015d-08 /
      data fpppp( 7,14,21,1),fpppp( 7,14,21,2),fpppp( 7,14,21,3)/
     x 8.5449815d-04,-6.9100466d-05,-2.0899386d-08 /
      data fpppp( 7,14,22,1),fpppp( 7,14,22,2),fpppp( 7,14,22,3)/
     x 3.9111816d-06, 3.3409532d-05, 2.8831625d-08 /
      data fpppp( 7,14,23,1),fpppp( 7,14,23,2),fpppp( 7,14,23,3)/
     x-1.7176644d-05, 8.2063103d-05, 5.2659597d-08 /
      data fpppp( 7,15, 1,1),fpppp( 7,15, 1,2),fpppp( 7,15, 1,3)/
     x-6.7177142d-05, 1.7895251d-03, 1.4864962d-06 /
      data fpppp( 7,15, 2,1),fpppp( 7,15, 2,2),fpppp( 7,15, 2,3)/
     x 1.0629748d-03, 7.7455482d-04, 7.0825101d-07 /
      data fpppp( 7,15, 3,1),fpppp( 7,15, 3,2),fpppp( 7,15, 3,3)/
     x 2.4004195d-03,-1.3350104d-03,-9.1755373d-07 /
      data fpppp( 7,15, 4,1),fpppp( 7,15, 4,2),fpppp( 7,15, 4,3)/
     x 2.4004195d-03,-1.4494098d-03,-9.9081498d-07 /
      data fpppp( 7,15, 5,1),fpppp( 7,15, 5,2),fpppp( 7,15, 5,3)/
     x 1.0629748d-03, 1.2321523d-03, 1.0012960d-06 /
      data fpppp( 7,15, 6,1),fpppp( 7,15, 6,2),fpppp( 7,15, 6,3)/
     x-6.7177142d-05, 7.3534675d-05, 3.8757746d-07 /
      data fpppp( 7,15, 7,1),fpppp( 7,15, 7,2),fpppp( 7,15, 7,3)/
     x-1.7958058d-04, 4.6628912d-04,-6.4290628d-08 /
      data fpppp( 7,15, 8,1),fpppp( 7,15, 8,2),fpppp( 7,15, 8,3)/
     x-1.4268925d-04, 3.8395031d-05,-1.0201370d-07 /
      data fpppp( 7,15, 9,1),fpppp( 7,15, 9,2),fpppp( 7,15, 9,3)/
     x 2.6078165d-04, 1.6550436d-04,-1.8011522d-07 /
      data fpppp( 7,15,10,1),fpppp( 7,15,10,2),fpppp( 7,15,10,3)/
     x-1.3431079d-03, 1.0388941d-03, 2.2076676d-07 /
      data fpppp( 7,15,11,1),fpppp( 7,15,11,2),fpppp( 7,15,11,3)/
     x-2.9632333d-04,-7.2774906d-04, 1.3693972d-07 /
      data fpppp( 7,15,12,1),fpppp( 7,15,12,2),fpppp( 7,15,12,3)/
     x-3.3908148d-04,-1.2463284d-04, 1.2181219d-08 /
      data fpppp( 7,15,13,1),fpppp( 7,15,13,2),fpppp( 7,15,13,3)/
     x-2.4132928d-05,-3.6391098d-05, 2.2587454d-08 /
      data fpppp( 7,15,14,1),fpppp( 7,15,14,2),fpppp( 7,15,14,3)/
     x-2.0924074d-05, 1.8294348d-05, 7.0635262d-09 /
      data fpppp( 7,15,15,1),fpppp( 7,15,15,2),fpppp( 7,15,15,3)/
     x-1.0582299d-04,-6.5455855d-06, 6.0094283d-09 /
      data fpppp( 7,15,16,1),fpppp( 7,15,16,2),fpppp( 7,15,16,3)/
     x-1.4405033d-04, 8.6886095d-06, 4.5670010d-09 /
      data fpppp( 7,15,17,1),fpppp( 7,15,17,2),fpppp( 7,15,17,3)/
     x-1.7745588d-04, 3.9650249d-06, 6.3628139d-09 /
      data fpppp( 7,15,18,1),fpppp( 7,15,18,2),fpppp( 7,15,18,3)/
     x-1.9402097d-04, 9.6246452d-06, 1.2967884d-08 /
      data fpppp( 7,15,19,1),fpppp( 7,15,19,2),fpppp( 7,15,19,3)/
     x-1.8668287d-04, 4.7175366d-06, 1.5445048d-08 /
      data fpppp( 7,15,20,1),fpppp( 7,15,20,2),fpppp( 7,15,20,3)/
     x-3.6400627d-04,-1.9239172d-05,-1.7215400d-08 /
      data fpppp( 7,15,21,1),fpppp( 7,15,21,2),fpppp( 7,15,21,3)/
     x-3.6400627d-04,-1.8941418d-05,-1.6374323d-08 /
      data fpppp( 7,15,22,1),fpppp( 7,15,22,2),fpppp( 7,15,22,3)/
     x-1.8668287d-04, 3.5265197d-06, 1.2080737d-08 /
      data fpppp( 7,15,23,1),fpppp( 7,15,23,2),fpppp( 7,15,23,3)/
     x-1.9402097d-04, 1.4090958d-05, 2.5584052d-08 /
      data fpppp( 7,16, 1,1),fpppp( 7,16, 1,2),fpppp( 7,16, 1,3)/
     x 3.5554150d-04, 1.5772767d-04, 5.7558565d-07 /
      data fpppp( 7,16, 2,1),fpppp( 7,16, 2,2),fpppp( 7,16, 2,3)/
     x 6.3488749d-04, 1.6241609d-05, 1.8923536d-07 /
      data fpppp( 7,16, 3,1),fpppp( 7,16, 3,2),fpppp( 7,16, 3,3)/
     x 1.7772268d-03,-2.8386984d-04,-6.3071626d-07 /
      data fpppp( 7,16, 4,1),fpppp( 7,16, 4,2),fpppp( 7,16, 4,3)/
     x 1.7772268d-03,-2.8924753d-04,-6.4461450d-07 /
      data fpppp( 7,16, 5,1),fpppp( 7,16, 5,2),fpppp( 7,16, 5,3)/
     x 6.3488749d-04, 3.7752392d-05, 2.4482834d-07 /
      data fpppp( 7,16, 6,1),fpppp( 7,16, 6,2),fpppp( 7,16, 6,3)/
     x 3.5554150d-04, 7.7062237d-05, 3.6711196d-07 /
      data fpppp( 7,16, 7,1),fpppp( 7,16, 7,2),fpppp( 7,16, 7,3)/
     x-1.0199828d-05, 3.2031726d-05, 1.9478035d-07 /
      data fpppp( 7,16, 8,1),fpppp( 7,16, 8,2),fpppp( 7,16, 8,3)/
     x 1.9337282d-04, 2.4681878d-04,-5.1353483d-08 /
      data fpppp( 7,16, 9,1),fpppp( 7,16, 9,2),fpppp( 7,16, 9,3)/
     x-8.1877604d-04,-9.8655394d-04, 9.7310662d-08 /
      data fpppp( 7,16,10,1),fpppp( 7,16,10,2),fpppp( 7,16,10,3)/
     x 3.9977460d-03, 2.1562385d-03,-1.0421387d-07 /
      data fpppp( 7,16,11,1),fpppp( 7,16,11,2),fpppp( 7,16,11,3)/
     x 5.3787416d-04,-6.1506717d-04,-5.0203623d-08 /
      data fpppp( 7,16,12,1),fpppp( 7,16,12,2),fpppp( 7,16,12,3)/
     x 9.3113810d-04,-5.3990793d-04, 2.4641126d-07 /
      data fpppp( 7,16,13,1),fpppp( 7,16,13,2),fpppp( 7,16,13,3)/
     x 1.2940784d-05, 4.5418842d-05,-1.2124666d-08 /
      data fpppp( 7,16,14,1),fpppp( 7,16,14,2),fpppp( 7,16,14,3)/
     x 1.2199205d-04,-2.3223832d-05, 2.4740609d-08 /
      data fpppp( 7,16,15,1),fpppp( 7,16,15,2),fpppp( 7,16,15,3)/
     x 3.1017876d-04, 7.0949356d-06, 8.0912449d-09 /
      data fpppp( 7,16,16,1),fpppp( 7,16,16,2),fpppp( 7,16,16,3)/
     x 4.5936561d-04,-1.2523472d-06, 8.2775638d-09 /
      data fpppp( 7,16,17,1),fpppp( 7,16,17,2),fpppp( 7,16,17,3)/
     x 5.8758474d-04, 3.1082295d-06, 4.0141041d-09 /
      data fpppp( 7,16,18,1),fpppp( 7,16,18,2),fpppp( 7,16,18,3)/
     x 6.9387974d-04,-8.0723550d-07, 6.6602333d-10 /
      data fpppp( 7,16,19,1),fpppp( 7,16,19,2),fpppp( 7,16,19,3)/
     x 7.8352728d-04,-7.4701801d-07,-3.2400980d-09 /
      data fpppp( 7,16,20,1),fpppp( 7,16,20,2),fpppp( 7,16,20,3)/
     x 9.0267462d-04,-3.9413236d-06,-8.5230501d-09 /
      data fpppp( 7,16,21,1),fpppp( 7,16,21,2),fpppp( 7,16,21,3)/
     x 9.0267462d-04,-3.8677052d-06,-8.5914399d-09 /
      data fpppp( 7,16,22,1),fpppp( 7,16,22,2),fpppp( 7,16,22,3)/
     x 7.8352728d-04,-1.0414914d-06,-2.9665391d-09 /
      data fpppp( 7,16,23,1),fpppp( 7,16,23,2),fpppp( 7,16,23,3)/
     x 6.9387974d-04, 2.9703988d-07,-3.5982261d-10 /
      data fpppp( 7,17, 1,1),fpppp( 7,17, 1,2),fpppp( 7,17, 1,3)/
     x-3.8753365d-05,-4.6207032d-06, 4.6277627d-08 /
      data fpppp( 7,17, 2,1),fpppp( 7,17, 2,2),fpppp( 7,17, 2,3)/
     x 1.8282707d-04,-1.8621057d-05, 8.6646858d-09 /
      data fpppp( 7,17, 3,1),fpppp( 7,17, 3,2),fpppp( 7,17, 3,3)/
     x 2.9150060d-04,-4.9621282d-05,-7.1846208d-08 /
      data fpppp( 7,17, 4,1),fpppp( 7,17, 4,2),fpppp( 7,17, 4,3)/
     x 2.9150060d-04,-4.7872216d-05,-7.2000673d-08 /
      data fpppp( 7,17, 5,1),fpppp( 7,17, 5,2),fpppp( 7,17, 5,3)/
     x 1.8282707d-04,-2.5617322d-05, 9.2825436d-09 /
      data fpppp( 7,17, 6,1),fpppp( 7,17, 6,2),fpppp( 7,17, 6,3)/
     x-3.8753365d-05, 2.1615292d-05, 4.3960660d-08 /
      data fpppp( 7,17, 7,1),fpppp( 7,17, 7,2),fpppp( 7,17, 7,3)/
     x 2.1873424d-04,-1.4612255d-04, 4.7493441d-08 /
      data fpppp( 7,17, 8,1),fpppp( 7,17, 8,2),fpppp( 7,17, 8,3)/
     x-9.9507702d-04, 4.4505637d-04,-5.9415157d-08 /
      data fpppp( 7,17, 9,1),fpppp( 7,17, 9,2),fpppp( 7,17, 9,3)/
     x 2.7614212d-03,-1.8799677d-03,-2.8240489d-08 /
      data fpppp( 7,17,10,1),fpppp( 7,17,10,2),fpppp( 7,17,10,3)/
     x-1.2992667d-02, 4.0459283d-03,-8.5937624d-07 /
      data fpppp( 7,17,11,1),fpppp( 7,17,11,2),fpppp( 7,17,11,3)/
     x 2.9439976d-03,-2.6145604d-03, 1.2223277d-06 /
      data fpppp( 7,17,12,1),fpppp( 7,17,12,2),fpppp( 7,17,12,3)/
     x-2.0275084d-03, 1.3600253d-04,-3.5769309d-07 /
      data fpppp( 7,17,13,1),fpppp( 7,17,13,2),fpppp( 7,17,13,3)/
     x 1.1282897d-04, 9.8366886d-05, 1.0276550d-07 /
      data fpppp( 7,17,14,1),fpppp( 7,17,14,2),fpppp( 7,17,14,3)/
     x-5.0662741d-04,-3.0191376d-06,-1.4616322d-08 /
      data fpppp( 7,17,15,1),fpppp( 7,17,15,2),fpppp( 7,17,15,3)/
     x-1.1589426d-03,-1.7189582d-06, 1.5212743d-08 /
      data fpppp( 7,17,16,1),fpppp( 7,17,16,2),fpppp( 7,17,16,3)/
     x-1.7212716d-03,-2.4401758d-06, 3.9645004d-09 /
      data fpppp( 7,17,17,1),fpppp( 7,17,17,2),fpppp( 7,17,17,3)/
     x-2.1926887d-03, 1.5562083d-06, 2.5865925d-09 /
      data fpppp( 7,17,18,1),fpppp( 7,17,18,2),fpppp( 7,17,18,3)/
     x-2.5773860d-03,-1.3476739d-06,-2.4970252d-09 /
      data fpppp( 7,17,19,1),fpppp( 7,17,19,2),fpppp( 7,17,19,3)/
     x-2.8737917d-03, 5.2284928d-07,-6.2302876d-09 /
      data fpppp( 7,17,20,1),fpppp( 7,17,20,2),fpppp( 7,17,20,3)/
     x-3.0793331d-03,-1.2706066d-06,-7.6848271d-09 /
      data fpppp( 7,17,21,1),fpppp( 7,17,21,2),fpppp( 7,17,21,3)/
     x-3.0793331d-03,-1.1420874d-06,-7.8298181d-09 /
      data fpppp( 7,17,22,1),fpppp( 7,17,22,2),fpppp( 7,17,22,3)/
     x-2.8737917d-03, 8.7728349d-09,-5.6503235d-09 /
      data fpppp( 7,17,23,1),fpppp( 7,17,23,2),fpppp( 7,17,23,3)/
     x-2.5773860d-03, 5.8011273d-07,-4.6718903d-09 /
      data fpppp( 7,18, 1,1),fpppp( 7,18, 1,2),fpppp( 7,18, 1,3)/
     x 8.6392761d-04, 6.3064596d-05, 6.6573316d-08 /
      data fpppp( 7,18, 2,1),fpppp( 7,18, 2,2),fpppp( 7,18, 2,3)/
     x 9.4853669d-04, 4.2466335d-05, 5.2486956d-08 /
      data fpppp( 7,18, 3,1),fpppp( 7,18, 3,2),fpppp( 7,18, 3,3)/
     x 1.0010214d-03,-4.9965244d-05, 2.2827384d-08 /
      data fpppp( 7,18, 4,1),fpppp( 7,18, 4,2),fpppp( 7,18, 4,3)/
     x 1.0010214d-03, 3.4546538d-05, 2.1907786d-08 /
      data fpppp( 7,18, 5,1),fpppp( 7,18, 5,2),fpppp( 7,18, 5,3)/
     x 9.4853669d-04,-2.9558079d-04, 5.6165346d-08 /
      data fpppp( 7,18, 6,1),fpppp( 7,18, 6,2),fpppp( 7,18, 6,3)/
     x 8.6392761d-04, 1.3307413d-03, 5.2779356d-08 /
      data fpppp( 7,18, 7,1),fpppp( 7,18, 7,2),fpppp( 7,18, 7,3)/
     x 3.9739220d-04,-4.1280245d-03,-2.7813807d-08 /
      data fpppp( 7,18, 8,1),fpppp( 7,18, 8,2),fpppp( 7,18, 8,3)/
     x 1.6021247d-03, 1.0849098d-02, 5.3998939d-08 /
      data fpppp( 7,18, 9,1),fpppp( 7,18, 9,2),fpppp( 7,18, 9,3)/
     x-2.3414430d-03,-2.6275634d-02,-4.6358833d-07 /
      data fpppp( 7,18,10,1),fpppp( 7,18,10,2),fpppp( 7,18,10,3)/
     x 1.4875980d-02, 3.8686141d-02, 1.2066525d-06 /
      data fpppp( 7,18,11,1),fpppp( 7,18,11,2),fpppp( 7,18,11,3)/
     x-4.0042750d-03,-2.9724958d-02,-8.6888223d-07 /
      data fpppp( 7,18,12,1),fpppp( 7,18,12,2),fpppp( 7,18,12,3)/
     x 1.7125067d-03, 1.3322497d-02, 7.9407429d-08 /
      data fpppp( 7,18,13,1),fpppp( 7,18,13,2),fpppp( 7,18,13,3)/
     x-1.2195487d-04,-5.1954495d-03,-6.5987735d-08 /
      data fpppp( 7,18,14,1),fpppp( 7,18,14,2),fpppp( 7,18,14,3)/
     x 5.7811658d-04, 1.4162652d-03, 2.3599132d-09 /
      data fpppp( 7,18,15,1),fpppp( 7,18,15,2),fpppp( 7,18,15,3)/
     x 1.2537540d-03,-3.3682090d-04,-7.1527626d-09 /
      data fpppp( 7,18,16,1),fpppp( 7,18,16,2),fpppp( 7,18,16,3)/
     x 1.8438825d-03, 1.3788059d-04,-3.4086204d-09 /
      data fpppp( 7,18,17,1),fpppp( 7,18,17,2),fpppp( 7,18,17,3)/
     x 2.3428627d-03, 1.1789877d-05,-6.7777092d-09 /
      data fpppp( 7,18,18,1),fpppp( 7,18,18,2),fpppp( 7,18,18,3)/
     x 2.7521015d-03, 4.4673611d-05,-8.9759270d-09 /
      data fpppp( 7,18,19,1),fpppp( 7,18,19,2),fpppp( 7,18,19,3)/
     x 3.0680008d-03, 4.6939711d-05,-1.1349498d-08 /
      data fpppp( 7,18,20,1),fpppp( 7,18,20,2),fpppp( 7,18,20,3)/
     x 3.2745833d-03, 5.7890799d-05,-1.3716652d-08 /
      data fpppp( 7,18,21,1),fpppp( 7,18,21,2),fpppp( 7,18,21,3)/
     x 3.2745833d-03, 5.7755779d-05,-1.3776884d-08 /
      data fpppp( 7,18,22,1),fpppp( 7,18,22,2),fpppp( 7,18,22,3)/
     x 3.0680008d-03, 4.7479789d-05,-1.1108568d-08 /
      data fpppp( 7,18,23,1),fpppp( 7,18,23,2),fpppp( 7,18,23,3)/
     x 2.7521015d-03, 4.2648321d-05,-9.8794155d-09 /
      data fpppp( 7,19, 1,1),fpppp( 7,19, 1,2),fpppp( 7,19, 1,3)/
     x 1.3960441d-03, 3.3447238d-18,-7.0160626d-08 /
      data fpppp( 7,19, 2,1),fpppp( 7,19, 2,2),fpppp( 7,19, 2,3)/
     x 1.3663120d-03,-5.2913957d-18, 3.2196957d-08 /
      data fpppp( 7,19, 3,1),fpppp( 7,19, 3,2),fpppp( 7,19, 3,3)/
     x 1.0833287d-03,-2.5058370d-18, 2.5012853d-07 /
      data fpppp( 7,19, 4,1),fpppp( 7,19, 4,2),fpppp( 7,19, 4,3)/
     x 1.0833287d-03,-5.9557189d-18, 2.5258921d-07 /
      data fpppp( 7,19, 5,1),fpppp( 7,19, 5,2),fpppp( 7,19, 5,3)/
     x 1.3663120d-03,-1.0003875d-17, 2.2354262d-08 /
      data fpppp( 7,19, 6,1),fpppp( 7,19, 6,2),fpppp( 7,19, 6,3)/
     x 1.3960441d-03,-1.3180255d-18,-3.3250518d-08 /
      data fpppp( 7,19, 7,1),fpppp( 7,19, 7,2),fpppp( 7,19, 7,3)/
     x 5.9041477d-04, 4.8096546d-18,-1.2368667d-07 /
      data fpppp( 7,19, 8,1),fpppp( 7,19, 8,2),fpppp( 7,19, 8,3)/
     x 3.1177116d-03,-2.6479383d-18, 1.3270567d-07 /
      data fpppp( 7,19, 9,1),fpppp( 7,19, 9,2),fpppp( 7,19, 9,3)/
     x-4.9634326d-03,-2.7707029d-18,-8.1042283d-07 /
      data fpppp( 7,19,10,1),fpppp( 7,19,10,2),fpppp( 7,19,10,3)/
     x 2.9927753d-02, 1.8609961d-18, 2.4666266d-06 /
      data fpppp( 7,19,11,1),fpppp( 7,19,11,2),fpppp( 7,19,11,3)/
     x-8.2798630d-03, 5.2792078d-18,-1.9990232d-06 /
      data fpppp( 7,19,12,1),fpppp( 7,19,12,2),fpppp( 7,19,12,3)/
     x 3.5386185d-03, 7.3619466d-18, 2.1902084d-07 /
      data fpppp( 7,19,13,1),fpppp( 7,19,13,2),fpppp( 7,19,13,3)/
     x-2.6111814d-04,-1.0616575d-17,-1.5370000d-07 /
      data fpppp( 7,19,14,1),fpppp( 7,19,14,2),fpppp( 7,19,14,3)/
     x 1.1733282d-03, 2.1035324d-17, 3.2409580d-09 /
      data fpppp( 7,19,15,1),fpppp( 7,19,15,2),fpppp( 7,19,15,3)/
     x 2.5573598d-03, 1.5484982d-17,-2.1093410d-08 /
      data fpppp( 7,19,16,1),fpppp( 7,19,16,2),fpppp( 7,19,16,3)/
     x 3.7673819d-03,-2.7562185d-17,-9.9074392d-09 /
      data fpppp( 7,19,17,1),fpppp( 7,19,17,2),fpppp( 7,19,17,3)/
     x 4.7881785d-03,-4.5551178d-19,-1.3874357d-08 /
      data fpppp( 7,19,18,1),fpppp( 7,19,18,2),fpppp( 7,19,18,3)/
     x 5.6242309d-03, 8.3266364d-18,-1.4507442d-08 /
      data fpppp( 7,19,19,1),fpppp( 7,19,19,2),fpppp( 7,19,19,3)/
     x 6.2671900d-03, 2.2222649d-18,-1.5860417d-08 /
      data fpppp( 7,19,20,1),fpppp( 7,19,20,2),fpppp( 7,19,20,3)/
     x 6.6753785d-03, 1.0620197d-17,-1.7785605d-08 /
      data fpppp( 7,19,21,1),fpppp( 7,19,21,2),fpppp( 7,19,21,3)/
     x 6.6753785d-03,-1.2499408d-18,-1.7807182d-08 /
      data fpppp( 7,19,22,1),fpppp( 7,19,22,2),fpppp( 7,19,22,3)/
     x 6.2671900d-03,-2.5119362d-17,-1.5774109d-08 /
      data fpppp( 7,19,23,1),fpppp( 7,19,23,2),fpppp( 7,19,23,3)/
     x 5.6242309d-03,-1.6860241d-17,-1.4831096d-08 /
      data fpppp( 8, 1, 1,1),fpppp( 8, 1, 1,2),fpppp( 8, 1, 1,3)/
     x 6.8138968d-02, 3.5868578d-16, 2.8406141d-05 /
      data fpppp( 8, 1, 2,1),fpppp( 8, 1, 2,2),fpppp( 8, 1, 2,3)/
     x-6.9268640d-02,-2.2214514d-16, 1.5125207d-05 /
      data fpppp( 8, 1, 3,1),fpppp( 8, 1, 3,2),fpppp( 8, 1, 3,3)/
     x-5.0075294d-02, 9.8792806d-17,-1.0003953d-05 /
      data fpppp( 8, 1, 4,1),fpppp( 8, 1, 4,2),fpppp( 8, 1, 4,3)/
     x-5.0075294d-02, 1.6916406d-16,-1.5831429d-05 /
      data fpppp( 8, 1, 5,1),fpppp( 8, 1, 5,2),fpppp( 8, 1, 5,3)/
     x-6.9268640d-02,-2.0353744d-16, 3.8435111d-05 /
      data fpppp( 8, 1, 6,1),fpppp( 8, 1, 6,2),fpppp( 8, 1, 6,3)/
     x 6.8138968d-02,-1.3304196d-16,-5.9005999d-05 /
      data fpppp( 8, 1, 7,1),fpppp( 8, 1, 7,2),fpppp( 8, 1, 7,3)/
     x 2.3346965d-01, 6.3869891d-17, 3.0569974d-05 /
      data fpppp( 8, 1, 8,1),fpppp( 8, 1, 8,2),fpppp( 8, 1, 8,3)/
     x 3.9478291d-01,-3.0808672d-17, 1.0598150d-05 /
      data fpppp( 8, 1, 9,1),fpppp( 8, 1, 9,2),fpppp( 8, 1, 9,3)/
     x 2.8571835d-01, 1.3345197d-16,-1.6464919d-06 /
      data fpppp( 8, 1,10,1),fpppp( 8, 1,10,2),fpppp( 8, 1,10,3)/
     x 2.3932880d-01, 2.1997977d-16, 3.3138403d-06 /
      data fpppp( 8, 1,11,1),fpppp( 8, 1,11,2),fpppp( 8, 1,11,3)/
     x 1.8840504d-01, 1.1588448d-16,-1.7024905d-07 /
      data fpppp( 8, 1,12,1),fpppp( 8, 1,12,2),fpppp( 8, 1,12,3)/
     x 1.3586172d-01, 2.1324474d-17,-2.1781470d-06 /
      data fpppp( 8, 1,13,1),fpppp( 8, 1,13,2),fpppp( 8, 1,13,3)/
     x 1.9853650d-01, 1.7166918d-16, 3.4398893d-06 /
      data fpppp( 8, 1,14,1),fpppp( 8, 1,14,2),fpppp( 8, 1,14,3)/
     x 2.4505118d-01, 1.8360623d-16, 3.6920674d-07 /
      data fpppp( 8, 1,15,1),fpppp( 8, 1,15,2),fpppp( 8, 1,15,3)/
     x 2.9642843d-01,-7.1411972d-17, 4.8129096d-07 /
      data fpppp( 8, 1,16,1),fpppp( 8, 1,16,2),fpppp( 8, 1,16,3)/
     x 3.8139797d-01, 6.1337004d-17, 9.2030594d-06 /
      data fpppp( 8, 1,17,1),fpppp( 8, 1,17,2),fpppp( 8, 1,17,3)/
     x 2.4188746d-01, 4.9602009d-17, 2.9942023d-05 /
      data fpppp( 8, 1,18,1),fpppp( 8, 1,18,2),fpppp( 8, 1,18,3)/
     x 5.2076100d-02,-1.5124294d-16,-5.7841374d-05 /
      data fpppp( 8, 1,19,1),fpppp( 8, 1,19,2),fpppp( 8, 1,19,3)/
     x-6.2361477d-02, 1.4065053d-16, 3.8015452d-05 /
      data fpppp( 8, 1,20,1),fpppp( 8, 1,20,2),fpppp( 8, 1,20,3)/
     x-4.3565095d-02, 5.7841897d-17,-1.5756571d-05 /
      data fpppp( 8, 1,21,1),fpppp( 8, 1,21,2),fpppp( 8, 1,21,3)/
     x-4.3565095d-02, 1.2213401d-16,-1.0015253d-05 /
      data fpppp( 8, 1,22,1),fpppp( 8, 1,22,2),fpppp( 8, 1,22,3)/
     x-6.2361477d-02,-7.6958963d-17, 1.5050179d-05 /
      data fpppp( 8, 1,23,1),fpppp( 8, 1,23,2),fpppp( 8, 1,23,3)/
     x 5.2076100d-02,-1.5395341d-16, 2.8278399d-05 /
      data fpppp( 8, 2, 1,1),fpppp( 8, 2, 1,2),fpppp( 8, 2, 1,3)/
     x 3.3945640d-02,-5.4268288d-02, 1.4023542d-05 /
      data fpppp( 8, 2, 2,1),fpppp( 8, 2, 2,2),fpppp( 8, 2, 2,3)/
     x-3.2474251d-02,-3.3573432d-02, 7.6495926d-06 /
      data fpppp( 8, 2, 3,1),fpppp( 8, 2, 3,2),fpppp( 8, 2, 3,3)/
     x-2.1531654d-02, 8.9584318d-03,-4.4943620d-06 /
      data fpppp( 8, 2, 4,1),fpppp( 8, 2, 4,2),fpppp( 8, 2, 4,3)/
     x-2.1531654d-02, 1.2133378d-02,-7.1447519d-06 /
      data fpppp( 8, 2, 5,1),fpppp( 8, 2, 5,2),fpppp( 8, 2, 5,3)/
     x-3.2474251d-02,-4.6273216d-02, 1.8251152d-05 /
      data fpppp( 8, 2, 6,1),fpppp( 8, 2, 6,2),fpppp( 8, 2, 6,3)/
     x 3.3945640d-02,-6.6440996d-03,-2.5732305d-05 /
      data fpppp( 8, 2, 7,1),fpppp( 8, 2, 7,2),fpppp( 8, 2, 7,3)/
     x 1.1428368d-01,-1.5461536d-02, 1.2112753d-05 /
      data fpppp( 8, 2, 8,1),fpppp( 8, 2, 8,2),fpppp( 8, 2, 8,3)/
     x 1.9241895d-01, 9.9932426d-02, 5.2115618d-06 /
      data fpppp( 8, 2, 9,1),fpppp( 8, 2, 9,2),fpppp( 8, 2, 9,3)/
     x 1.3897414d-01,-5.2731806d-02,-1.1702005d-06 /
      data fpppp( 8, 2,10,1),fpppp( 8, 2,10,2),fpppp( 8, 2,10,3)/
     x 1.1539246d-01, 2.0259999d-02, 1.5406359d-06 /
      data fpppp( 8, 2,11,1),fpppp( 8, 2,11,2),fpppp( 8, 2,11,3)/
     x 9.1508500d-02,-3.6164834d-03,-2.3724314d-07 /
      data fpppp( 8, 2,12,1),fpppp( 8, 2,12,2),fpppp( 8, 2,12,3)/
     x 6.5848063d-02,-1.5035543d-02,-1.0008374d-06 /
      data fpppp( 8, 2,13,1),fpppp( 8, 2,13,2),fpppp( 8, 2,13,3)/
     x 9.4074277d-02,-2.6622135d-02, 1.3300282d-06 /
      data fpppp( 8, 2,14,1),fpppp( 8, 2,14,2),fpppp( 8, 2,14,3)/
     x 1.1859079d-01, 3.2106462d-02, 2.3389048d-07 /
      data fpppp( 8, 2,15,1),fpppp( 8, 2,15,2),fpppp( 8, 2,15,3)/
     x 1.4417871d-01,-4.3813920d-02,-1.2866459d-07 /
      data fpppp( 8, 2,16,1),fpppp( 8, 2,16,2),fpppp( 8, 2,16,3)/
     x 1.8557204d-01, 9.0410016d-02, 4.4188679d-06 /
      data fpppp( 8, 2,17,1),fpppp( 8, 2,17,2),fpppp( 8, 2,17,3)/
     x 1.1673950d-01,-9.9912000d-03, 1.2161350d-05 /
      data fpppp( 8, 2,18,1),fpppp( 8, 2,18,2),fpppp( 8, 2,18,3)/
     x 2.4939446d-02,-2.0443316d-02,-2.5411923d-05 /
      data fpppp( 8, 2,19,1),fpppp( 8, 2,19,2),fpppp( 8, 2,19,3)/
     x-2.9118773d-02,-3.4084452d-02, 1.8076680d-05 /
      data fpppp( 8, 2,20,1),fpppp( 8, 2,20,2),fpppp( 8, 2,20,3)/
     x-1.8414297d-02, 1.0273621d-02,-7.1308826d-06 /
      data fpppp( 8, 2,21,1),fpppp( 8, 2,21,2),fpppp( 8, 2,21,3)/
     x-1.8414297d-02, 8.6434829d-03,-4.5081548d-06 /
      data fpppp( 8, 2,22,1),fpppp( 8, 2,22,2),fpppp( 8, 2,22,3)/
     x-2.9118773d-02,-2.7563900d-02, 7.5857691d-06 /
      data fpppp( 8, 2,23,1),fpppp( 8, 2,23,2),fpppp( 8, 2,23,3)/
     x 2.4939446d-02,-4.4895383d-02, 1.3928994d-05 /
      data fpppp( 8, 3, 1,1),fpppp( 8, 3, 1,2),fpppp( 8, 3, 1,3)/
     x-4.8992390d-02, 8.8557699d-04,-4.5501669d-05 /
      data fpppp( 8, 3, 2,1),fpppp( 8, 3, 2,2),fpppp( 8, 3, 2,3)/
     x 3.7405447d-02, 1.7302342d-03,-2.7274488d-05 /
      data fpppp( 8, 3, 3,1),fpppp( 8, 3, 3,2),fpppp( 8, 3, 3,3)/
     x 2.9210147d-02, 4.4440909d-03, 7.3006858d-06 /
      data fpppp( 8, 3, 4,1),fpppp( 8, 3, 4,2),fpppp( 8, 3, 4,3)/
     x 2.9210147d-02, 2.8623063d-03, 1.5146058d-05 /
      data fpppp( 8, 3, 5,1),fpppp( 8, 3, 5,2),fpppp( 8, 3, 5,3)/
     x 3.7405447d-02, 8.0573724d-03,-5.8655976d-05 /
      data fpppp( 8, 3, 6,1),fpppp( 8, 3, 6,2),fpppp( 8, 3, 6,3)/
     x-4.8992390d-02,-2.2841191d-02, 7.2178909d-05 /
      data fpppp( 8, 3, 7,1),fpppp( 8, 3, 7,2),fpppp( 8, 3, 7,3)/
     x-1.1008019d-01, 1.5590793d-02,-2.5278083d-05 /
      data fpppp( 8, 3, 8,1),fpppp( 8, 3, 8,2),fpppp( 8, 3, 8,3)/
     x-1.8712045d-01,-5.4185678d-03,-5.0687365d-06 /
      data fpppp( 8, 3, 9,1),fpppp( 8, 3, 9,2),fpppp( 8, 3, 9,3)/
     x-1.3794576d-01,-1.3270034d-03,-8.8880965d-07 /
      data fpppp( 8, 3,10,1),fpppp( 8, 3,10,2),fpppp( 8, 3,10,3)/
     x-9.6326370d-02, 3.8292380d-03,-1.9094693d-06 /
      data fpppp( 8, 3,11,1),fpppp( 8, 3,11,2),fpppp( 8, 3,11,3)/
     x-9.4216057d-02,-9.8589649d-03,-8.2373239d-07 /
      data fpppp( 8, 3,12,1),fpppp( 8, 3,12,2),fpppp( 8, 3,12,3)/
     x-6.8432639d-02, 3.2071310d-02, 2.3151580d-06 /
      data fpppp( 8, 3,13,1),fpppp( 8, 3,13,2),fpppp( 8, 3,13,3)/
     x-1.2468269d-01,-5.0456615d-02,-4.7015744d-06 /
      data fpppp( 8, 3,14,1),fpppp( 8, 3,14,2),fpppp( 8, 3,14,3)/
     x-1.0680559d-01, 3.4048161d-02, 1.1245792d-06 /
      data fpppp( 8, 3,15,1),fpppp( 8, 3,15,2),fpppp( 8, 3,15,3)/
     x-1.4313541d-01,-1.4815171d-02,-2.6504915d-06 /
      data fpppp( 8, 3,16,1),fpppp( 8, 3,16,2),fpppp( 8, 3,16,3)/
     x-1.7956426d-01, 1.6448989d-02,-2.8829232d-06 /
      data fpppp( 8, 3,17,1),fpppp( 8, 3,17,2),fpppp( 8, 3,17,3)/
     x-1.2887183d-01,-1.3573105d-02,-2.6616276d-05 /
      data fpppp( 8, 3,18,1),fpppp( 8, 3,18,2),fpppp( 8, 3,18,3)/
     x-4.1617239d-02,-7.7615615d-03, 7.1739546d-05 /
      data fpppp( 8, 3,19,1),fpppp( 8, 3,19,2),fpppp( 8, 3,19,3)/
     x 3.2323427d-02, 5.9487456d-03,-5.8089288d-05 /
      data fpppp( 8, 3,20,1),fpppp( 8, 3,20,2),fpppp( 8, 3,20,3)/
     x 2.6361517d-02, 3.3337361d-03, 1.5132082d-05 /
      data fpppp( 8, 3,21,1),fpppp( 8, 3,21,2),fpppp( 8, 3,21,3)/
     x 2.6361517d-02, 4.0424693d-03, 7.3473282d-06 /
      data fpppp( 8, 3,22,1),fpppp( 8, 3,22,2),fpppp( 8, 3,22,3)/
     x 3.2323427d-02, 3.1138131d-03,-2.6950274d-05 /
      data fpppp( 8, 3,23,1),fpppp( 8, 3,23,2),fpppp( 8, 3,23,3)/
     x-4.1617239d-02, 2.8694357d-03,-4.5031757d-05 /
      data fpppp( 8, 4, 1,1),fpppp( 8, 4, 1,2),fpppp( 8, 4, 1,3)/
     x 3.8676036d-02,-1.3740693d-02, 5.2972261d-05 /
      data fpppp( 8, 4, 2,1),fpppp( 8, 4, 2,2),fpppp( 8, 4, 2,3)/
     x-8.5134377d-03,-7.5368652d-03, 3.3871065d-05 /
      data fpppp( 8, 4, 3,1),fpppp( 8, 4, 3,2),fpppp( 8, 4, 3,3)/
     x 2.2583841d-03, 4.9441850d-03,-2.9033659d-06 /
      data fpppp( 8, 4, 4,1),fpppp( 8, 4, 4,2),fpppp( 8, 4, 4,3)/
     x 2.2583841d-03, 6.3667030d-03,-1.0177597d-05 /
      data fpppp( 8, 4, 5,1),fpppp( 8, 4, 5,2),fpppp( 8, 4, 5,3)/
     x-8.5134377d-03,-1.3226937d-02, 6.2967988d-05 /
      data fpppp( 8, 4, 6,1),fpppp( 8, 4, 6,2),fpppp( 8, 4, 6,3)/
     x 3.8676036d-02, 7.5970764d-03,-5.6141199d-05 /
      data fpppp( 8, 4, 7,1),fpppp( 8, 4, 7,2),fpppp( 8, 4, 7,3)/
     x 3.3678589d-02,-1.3120587d-03, 3.5987333d-06 /
      data fpppp( 8, 4, 8,1),fpppp( 8, 4, 8,2),fpppp( 8, 4, 8,3)/
     x 5.3454201d-02,-6.8237267d-03, 1.7789521d-06 /
      data fpppp( 8, 4, 9,1),fpppp( 8, 4, 9,2),fpppp( 8, 4, 9,3)/
     x 4.0749218d-02, 2.3048787d-02, 7.4732982d-08 /
      data fpppp( 8, 4,10,1),fpppp( 8, 4,10,2),fpppp( 8, 4,10,3)/
     x-8.0649204d-04,-3.7640140d-02, 5.0957808d-07 /
      data fpppp( 8, 4,11,1),fpppp( 8, 4,11,2),fpppp( 8, 4,11,3)/
     x 3.0957437d-02, 2.6063090d-02, 4.0801144d-07 /
      data fpppp( 8, 4,12,1),fpppp( 8, 4,12,2),fpppp( 8, 4,12,3)/
     x 2.2221308d-02,-1.2025480d-02,-1.8542466d-06 /
      data fpppp( 8, 4,13,1),fpppp( 8, 4,13,2),fpppp( 8, 4,13,3)/
     x 5.6591931d-02, 1.7218474d-02, 2.9929181d-06 /
      data fpppp( 8, 4,14,1),fpppp( 8, 4,14,2),fpppp( 8, 4,14,3)/
     x 1.4074040d-02,-2.2934418d-02,-1.5757495d-06 /
      data fpppp( 8, 4,15,1),fpppp( 8, 4,15,2),fpppp( 8, 4,15,3)/
     x 4.2275882d-02, 1.3334624d-02, 1.5192313d-06 /
      data fpppp( 8, 4,16,1),fpppp( 8, 4,16,2),fpppp( 8, 4,16,3)/
     x 4.7885735d-02,-2.3746743d-03,-1.3731158d-06 /
      data fpppp( 8, 4,17,1),fpppp( 8, 4,17,2),fpppp( 8, 4,17,3)/
     x 4.7138657d-02,-4.9531512d-03, 8.0954337d-06 /
      data fpppp( 8, 4,18,1),fpppp( 8, 4,18,2),fpppp( 8, 4,18,3)/
     x 2.9796181d-02, 7.6611017d-03,-5.7636048d-05 /
      data fpppp( 8, 4,19,1),fpppp( 8, 4,19,2),fpppp( 8, 4,19,3)/
     x-4.9326063d-03,-1.0083721d-02, 6.2539934d-05 /
      data fpppp( 8, 4,20,1),fpppp( 8, 4,20,2),fpppp( 8, 4,20,3)/
     x 2.4497777d-03, 5.1791627d-03,-1.0335421d-05 /
      data fpppp( 8, 4,21,1),fpppp( 8, 4,21,2),fpppp( 8, 4,21,3)/
     x 2.4497777d-03, 3.9987433d-03,-3.0165374d-06 /
      data fpppp( 8, 4,22,1),fpppp( 8, 4,22,2),fpppp( 8, 4,22,3)/
     x-4.9326063d-03,-5.3620435d-03, 3.3264400d-05 /
      data fpppp( 8, 4,23,1),fpppp( 8, 4,23,2),fpppp( 8, 4,23,3)/
     x 2.9796181d-02,-1.0045189d-02, 5.2147206d-05 /
      data fpppp( 8, 5, 1,1),fpppp( 8, 5, 1,2),fpppp( 8, 5, 1,3)/
     x-2.6136963d-02, 4.5410269d-03,-3.5683887d-05 /
      data fpppp( 8, 5, 2,1),fpppp( 8, 5, 2,2),fpppp( 8, 5, 2,3)/
     x-3.0196634d-03, 3.1097770d-03,-2.2105960d-05 /
      data fpppp( 8, 5, 3,1),fpppp( 8, 5, 3,2),fpppp( 8, 5, 3,3)/
     x-9.2232991d-03, 8.1243038d-04, 4.9315190d-06 /
      data fpppp( 8, 5, 4,1),fpppp( 8, 5, 4,2),fpppp( 8, 5, 4,3)/
     x-9.2232991d-03,-5.3440022d-04, 8.5331584d-06 /
      data fpppp( 8, 5, 5,1),fpppp( 8, 5, 5,2),fpppp( 8, 5, 5,3)/
     x-3.0196634d-03, 8.4970994d-03,-3.6512518d-05 /
      data fpppp( 8, 5, 6,1),fpppp( 8, 5, 6,2),fpppp( 8, 5, 6,3)/
     x-2.6136963d-02,-1.5661432d-02, 1.8340704d-05 /
      data fpppp( 8, 5, 7,1),fpppp( 8, 5, 7,2),fpppp( 8, 5, 7,3)/
     x-9.7460493d-03, 9.6344117d-03, 7.4291404d-06 /
      data fpppp( 8, 5, 8,1),fpppp( 8, 5, 8,2),fpppp( 8, 5, 8,3)/
     x-1.3187923d-02,-2.6224054d-03,-1.2501727d-06 /
      data fpppp( 8, 5, 9,1),fpppp( 8, 5, 9,2),fpppp( 8, 5, 9,3)/
     x-9.3881271d-03, 6.8357967d-04, 7.0005088d-07 /
      data fpppp( 8, 5,10,1),fpppp( 8, 5,10,2),fpppp( 8, 5,10,3)/
     x 1.4930392d-02,-1.9150356d-04,-2.8715469d-07 /
      data fpppp( 8, 5,11,1),fpppp( 8, 5,11,2),fpppp( 8, 5,11,3)/
     x-7.5588458d-03, 1.5815519d-05,-9.9480005d-08 /
      data fpppp( 8, 5,12,1),fpppp( 8, 5,12,2),fpppp( 8, 5,12,3)/
     x-4.5117442d-03, 4.6251565d-05, 4.4012664d-07 /
      data fpppp( 8, 5,13,1),fpppp( 8, 5,13,2),fpppp( 8, 5,13,3)/
     x-1.4308943d-02,-2.6195407d-04,-8.2800403d-07 /
      data fpppp( 8, 5,14,1),fpppp( 8, 5,14,2),fpppp( 8, 5,14,3)/
     x 5.6880176d-03, 9.0379404d-04, 3.9126508d-07 /
      data fpppp( 8, 5,15,1),fpppp( 8, 5,15,2),fpppp( 8, 5,15,3)/
     x-9.7634305d-03,-3.4196125d-03,-9.7193306d-08 /
      data fpppp( 8, 5,16,1),fpppp( 8, 5,16,2),fpppp( 8, 5,16,3)/
     x-7.0147473d-03, 5.3301352d-03, 9.6661762d-07 /
      data fpppp( 8, 5,17,1),fpppp( 8, 5,17,2),fpppp( 8, 5,17,3)/
     x-1.1850011d-02,-3.4334380d-03, 3.0648945d-06 /
      data fpppp( 8, 5,18,1),fpppp( 8, 5,18,2),fpppp( 8, 5,18,3)/
     x-1.1342766d-02, 4.7932321d-04, 2.0752158d-05 /
      data fpppp( 8, 5,19,1),fpppp( 8, 5,19,2),fpppp( 8, 5,19,3)/
     x-5.8538990d-04,-1.2072159d-03,-3.4221336d-05 /
      data fpppp( 8, 5,20,1),fpppp( 8, 5,20,2),fpppp( 8, 5,20,3)/
     x-7.2943986d-03, 1.0688668d-03, 7.1915568d-06 /
      data fpppp( 8, 5,21,1),fpppp( 8, 5,21,2),fpppp( 8, 5,21,3)/
     x-7.2943986d-03, 9.3839004d-04, 3.6646813d-06 /
      data fpppp( 8, 5,22,1),fpppp( 8, 5,22,2),fpppp( 8, 5,22,3)/
     x-5.8538990d-04,-6.8530875d-04,-2.0113834d-05 /
      data fpppp( 8, 5,23,1),fpppp( 8, 5,23,2),fpppp( 8, 5,23,3)/
     x-1.1342766d-02,-1.4778287d-03,-3.2150974d-05 /
      data fpppp( 8, 6, 1,1),fpppp( 8, 6, 1,2),fpppp( 8, 6, 1,3)/
     x 1.1541349d-02, 5.5952247d-03, 1.6324498d-05 /
      data fpppp( 8, 6, 2,1),fpppp( 8, 6, 2,2),fpppp( 8, 6, 2,3)/
     x 7.1733648d-03, 3.3864361d-03, 9.4336226d-06 /
      data fpppp( 8, 6, 3,1),fpppp( 8, 6, 3,2),fpppp( 8, 6, 3,3)/
     x 5.7892971d-03,-9.5039846d-04,-4.5267142d-06 /
      data fpppp( 8, 6, 4,1),fpppp( 8, 6, 4,2),fpppp( 8, 6, 4,3)/
     x 5.7892971d-03,-1.6438949d-03,-5.9369089d-06 /
      data fpppp( 8, 6, 5,1),fpppp( 8, 6, 5,2),fpppp( 8, 6, 5,3)/
     x 7.1733648d-03, 6.1604221d-03, 1.5074402d-05 /
      data fpppp( 8, 6, 6,1),fpppp( 8, 6, 6,2),fpppp( 8, 6, 6,3)/
     x 1.1541349d-02,-4.8072226d-03,-4.8284228d-06 /
      data fpppp( 8, 6, 7,1),fpppp( 8, 6, 7,2),fpppp( 8, 6, 7,3)/
     x 3.0838242d-03, 1.2111466d-03,-1.9103116d-06 /
      data fpppp( 8, 6, 8,1),fpppp( 8, 6, 8,2),fpppp( 8, 6, 8,3)/
     x 3.8786476d-03,-3.6060243d-04, 3.1337115d-07 /
      data fpppp( 8, 6, 9,1),fpppp( 8, 6, 9,2),fpppp( 8, 6, 9,3)/
     x 2.8099276d-03, 6.8724513d-05,-2.7208928d-07 /
      data fpppp( 8, 6,10,1),fpppp( 8, 6,10,2),fpppp( 8, 6,10,3)/
     x-3.7130960d-03,-3.4898004d-05, 4.8379425d-08 /
      data fpppp( 8, 6,11,1),fpppp( 8, 6,11,2),fpppp( 8, 6,11,3)/
     x 2.3134385d-03, 2.4481500d-05, 1.6826397d-08 /
      data fpppp( 8, 6,12,1),fpppp( 8, 6,12,2),fpppp( 8, 6,12,3)/
     x 1.4621976d-03,-4.6226093d-05,-1.1842996d-07 /
      data fpppp( 8, 6,13,1),fpppp( 8, 6,13,2),fpppp( 8, 6,13,3)/
     x 4.0930816d-03, 7.0190223d-05, 2.1962024d-07 /
      data fpppp( 8, 6,14,1),fpppp( 8, 6,14,2),fpppp( 8, 6,14,3)/
     x-1.3540656d-03,-1.3398247d-04,-1.2154963d-07 /
      data fpppp( 8, 6,15,1),fpppp( 8, 6,15,2),fpppp( 8, 6,15,3)/
     x 2.8906214d-03, 1.3546457d-04,-8.1052104d-09 /
      data fpppp( 8, 6,16,1),fpppp( 8, 6,16,2),fpppp( 8, 6,16,3)/
     x 9.9053336d-05,-1.5404316d-04,-3.0212758d-07 /
      data fpppp( 8, 6,17,1),fpppp( 8, 6,17,2),fpppp( 8, 6,17,3)/
     x 3.4932826d-03, 2.5993627d-05,-5.4587317d-07 /
      data fpppp( 8, 6,18,1),fpppp( 8, 6,18,2),fpppp( 8, 6,18,3)/
     x 3.3805192d-03,-4.7007295d-06,-5.0398837d-06 /
      data fpppp( 8, 6,19,1),fpppp( 8, 6,19,2),fpppp( 8, 6,19,3)/
     x 1.6487659d-04,-5.5011005d-04, 9.3937541d-06 /
      data fpppp( 8, 6,20,1),fpppp( 8, 6,20,2),fpppp( 8, 6,20,3)/
     x 1.9957967d-03, 4.3060724d-04,-2.5338096d-06 /
      data fpppp( 8, 6,21,1),fpppp( 8, 6,21,2),fpppp( 8, 6,21,3)/
     x 1.9957967d-03, 3.8299281d-04,-1.5844504d-06 /
      data fpppp( 8, 6,22,1),fpppp( 8, 6,22,2),fpppp( 8, 6,22,3)/
     x 1.6487659d-04,-3.5965232d-04, 5.5963172d-06 /
      data fpppp( 8, 6,23,1),fpppp( 8, 6,23,2),fpppp( 8, 6,23,3)/
     x 3.3805192d-03,-7.1891722d-04, 9.2005046d-06 /
      data fpppp( 8, 7, 1,1),fpppp( 8, 7, 1,2),fpppp( 8, 7, 1,3)/
     x 2.7084008d-03, 3.0449027d-04,-8.1295849d-06 /
      data fpppp( 8, 7, 2,1),fpppp( 8, 7, 2,2),fpppp( 8, 7, 2,3)/
     x-3.0037681d-03, 1.8032458d-04,-4.7684828d-06 /
      data fpppp( 8, 7, 3,1),fpppp( 8, 7, 3,2),fpppp( 8, 7, 3,3)/
     x-8.9613962d-03,-6.7940296d-05, 1.9478662d-06 /
      data fpppp( 8, 7, 4,1),fpppp( 8, 7, 4,2),fpppp( 8, 7, 4,3)/
     x-8.9613962d-03,-9.9098093d-05, 2.7983884d-06 /
      data fpppp( 8, 7, 5,1),fpppp( 8, 7, 5,2),fpppp( 8, 7, 5,3)/
     x-3.0037681d-03, 3.0495577d-04,-8.1705718d-06 /
      data fpppp( 8, 7, 6,1),fpppp( 8, 7, 6,2),fpppp( 8, 7, 6,3)/
     x 2.7084008d-03,-1.6287668d-04, 4.6282489d-06 /
      data fpppp( 8, 7, 7,1),fpppp( 8, 7, 7,2),fpppp( 8, 7, 7,3)/
     x-9.1463184d-04, 1.7099567d-05,-5.8445715d-07 /
      data fpppp( 8, 7, 8,1),fpppp( 8, 7, 8,2),fpppp( 8, 7, 8,3)/
     x-9.2881981d-04,-2.0358337d-05, 1.5263973d-07 /
      data fpppp( 8, 7, 9,1),fpppp( 8, 7, 9,2),fpppp( 8, 7, 9,3)/
     x-6.4050186d-04, 8.8888142d-07, 2.2503086d-08 /
      data fpppp( 8, 7,10,1),fpppp( 8, 7,10,2),fpppp( 8, 7,10,3)/
     x 1.0922695d-03, 1.1501051d-06, 1.9217954d-08 /
      data fpppp( 8, 7,11,1),fpppp( 8, 7,11,2),fpppp( 8, 7,11,3)/
     x-5.3258337d-04, 1.2091749d-06, 5.8937091d-09 /
      data fpppp( 8, 7,12,1),fpppp( 8, 7,12,2),fpppp( 8, 7,12,3)/
     x-2.8907794d-04, 3.2032660d-06, 4.9335054d-08 /
      data fpppp( 8, 7,13,1),fpppp( 8, 7,13,2),fpppp( 8, 7,13,3)/
     x-1.0021999d-03,-5.7835695d-06,-3.7843665d-08 /
      data fpppp( 8, 7,14,1),fpppp( 8, 7,14,2),fpppp( 8, 7,14,3)/
     x 4.9494126d-04, 1.1103651d-05, 6.2858576d-08 /
      data fpppp( 8, 7,15,1),fpppp( 8, 7,15,2),fpppp( 8, 7,15,3)/
     x-7.0242439d-04,-8.3693061d-06, 4.6200325d-08 /
      data fpppp( 8, 7,16,1),fpppp( 8, 7,16,2),fpppp( 8, 7,16,3)/
     x 7.3839480d-05, 3.3005858d-06, 1.1622286d-07 /
      data fpppp( 8, 7,17,1),fpppp( 8, 7,17,2),fpppp( 8, 7,17,3)/
     x-9.1577220d-04, 1.1614931d-05, 2.6701145d-07 /
      data fpppp( 8, 7,18,1),fpppp( 8, 7,18,2),fpppp( 8, 7,18,3)/
     x-9.8827070d-04,-3.3554787d-06, 1.3257943d-06 /
      data fpppp( 8, 7,19,1),fpppp( 8, 7,19,2),fpppp( 8, 7,19,3)/
     x-4.0618410d-04, 1.3252989d-04,-1.4078017d-06 /
      data fpppp( 8, 7,20,1),fpppp( 8, 7,20,2),fpppp( 8, 7,20,3)/
     x-1.8500908d-03,-1.0128521d-04,-2.3829210d-07 /
      data fpppp( 8, 7,21,1),fpppp( 8, 7,21,2),fpppp( 8, 7,21,3)/
     x-1.8500908d-03,-8.9655506d-05,-3.9395826d-07 /
      data fpppp( 8, 7,22,1),fpppp( 8, 7,22,2),fpppp( 8, 7,22,3)/
     x-4.0618410d-04, 8.6011077d-05,-7.8513704d-07 /
      data fpppp( 8, 7,23,1),fpppp( 8, 7,23,2),fpppp( 8, 7,23,3)/
     x-9.8827070d-04, 1.7109007d-04,-1.0091981d-06 /
      data fpppp( 8, 8, 1,1),fpppp( 8, 8, 1,2),fpppp( 8, 8, 1,3)/
     x-2.1821923d-02,-7.2401036d-03, 6.1310115d-06 /
      data fpppp( 8, 8, 2,1),fpppp( 8, 8, 2,2),fpppp( 8, 8, 2,3)/
     x-2.7306867d-03,-4.0178397d-03, 3.9524386d-06 /
      data fpppp( 8, 8, 3,1),fpppp( 8, 8, 3,2),fpppp( 8, 8, 3,3)/
     x 9.8360684d-03, 2.5141873d-03,-7.0880297d-08 /
      data fpppp( 8, 8, 4,1),fpppp( 8, 8, 4,2),fpppp( 8, 8, 4,3)/
     x 9.8360684d-03, 3.1666294d-03,-1.1997206d-06 /
      data fpppp( 8, 8, 5,1),fpppp( 8, 8, 5,2),fpppp( 8, 8, 5,3)/
     x-2.7306867d-03,-6.6276080d-03, 8.4677998d-06 /
      data fpppp( 8, 8, 6,1),fpppp( 8, 8, 6,2),fpppp( 8, 8, 6,3)/
     x-2.1821923d-02, 2.5465273d-03,-1.0801593d-05 /
      data fpppp( 8, 8, 7,1),fpppp( 8, 8, 7,2),fpppp( 8, 8, 7,3)/
     x 1.0113064d-03,-6.0193250d-04, 4.0119860d-06 /
      data fpppp( 8, 8, 8,1),fpppp( 8, 8, 8,2),fpppp( 8, 8, 8,3)/
     x 3.4994395d-04, 1.4790345d-04,-5.2481321d-07 /
      data fpppp( 8, 8, 9,1),fpppp( 8, 8, 9,2),fpppp( 8, 8, 9,3)/
     x 2.6286511d-04,-3.3268729d-05, 2.5420378d-07 /
      data fpppp( 8, 8,10,1),fpppp( 8, 8,10,2),fpppp( 8, 8,10,3)/
     x-2.0104186d-04, 2.1150337d-05,-1.1155462d-08 /
      data fpppp( 8, 8,11,1),fpppp( 8, 8,11,2),fpppp( 8, 8,11,3)/
     x 2.2258923d-04, 1.5049666d-05, 4.3448807d-08 /
      data fpppp( 8, 8,12,1),fpppp( 8, 8,12,2),fpppp( 8, 8,12,3)/
     x 1.3743988d-04, 7.1066369d-06, 1.1953801d-08 /
      data fpppp( 8, 8,13,1),fpppp( 8, 8,13,2),fpppp( 8, 8,13,3)/
     x 3.3305408d-04,-3.8726218d-07, 4.3168149d-08 /
      data fpppp( 8, 8,14,1),fpppp( 8, 8,14,2),fpppp( 8, 8,14,3)/
     x-9.5622390d-05, 1.4965648d-05, 2.2636367d-08 /
      data fpppp( 8, 8,15,1),fpppp( 8, 8,15,2),fpppp( 8, 8,15,3)/
     x 2.2571468d-04,-4.8561493d-06, 4.9326009d-08 /
      data fpppp( 8, 8,16,1),fpppp( 8, 8,16,2),fpppp( 8, 8,16,3)/
     x-5.9305202d-06, 1.7761154d-05, 5.2866718d-08 /
      data fpppp( 8, 8,17,1),fpppp( 8, 8,17,2),fpppp( 8, 8,17,3)/
     x 2.2393698d-04, 5.2297570d-06, 4.3843057d-08 /
      data fpppp( 8, 8,18,1),fpppp( 8, 8,18,2),fpppp( 8, 8,18,3)/
     x 2.0216192d-04, 1.8716184d-05,-2.4782669d-07 /
      data fpppp( 8, 8,19,1),fpppp( 8, 8,19,2),fpppp( 8, 8,19,3)/
     x 2.6943556d-07, 5.9614589d-05, 5.6244991d-07 /
      data fpppp( 8, 8,20,1),fpppp( 8, 8,20,2),fpppp( 8, 8,20,3)/
     x 4.0739463d-04,-8.0076045d-05,-3.8319790d-07 /
      data fpppp( 8, 8,21,1),fpppp( 8, 8,21,2),fpppp( 8, 8,21,3)/
     x 4.0739463d-04,-7.5040252d-05,-3.2378751d-07 /
      data fpppp( 8, 8,22,1),fpppp( 8, 8,22,2),fpppp( 8, 8,22,3)/
     x 2.6943556d-07, 3.9471418d-05, 3.2480834d-07 /
      data fpppp( 8, 8,23,1),fpppp( 8, 8,23,2),fpppp( 8, 8,23,3)/
     x 2.0216192d-04, 9.4253075d-05, 6.4332918d-07 /
      data fpppp( 8, 9, 1,1),fpppp( 8, 9, 1,2),fpppp( 8, 9, 1,3)/
     x 3.4135941d-02,-1.2893145d-02,-2.8459511d-06 /
      data fpppp( 8, 9, 2,1),fpppp( 8, 9, 2,2),fpppp( 8, 9, 2,3)/
     x 2.4807126d-03,-8.1752044d-03,-2.1376015d-06 /
      data fpppp( 8, 9, 3,1),fpppp( 8, 9, 3,2),fpppp( 8, 9, 3,3)/
     x-5.7500642d-03, 1.2263316d-04,-1.3271753d-06 /
      data fpppp( 8, 9, 4,1),fpppp( 8, 9, 4,2),fpppp( 8, 9, 4,3)/
     x-5.7500642d-03, 3.2936944d-03,-8.9110173d-08 /
      data fpppp( 8, 9, 5,1),fpppp( 8, 9, 5,2),fpppp( 8, 9, 5,3)/
     x 2.4807126d-03,-2.0859449d-02,-7.0898621d-06 /
      data fpppp( 8, 9, 6,1),fpppp( 8, 9, 6,2),fpppp( 8, 9, 6,3)/
     x 3.4135941d-02, 3.4672774d-02, 1.5725026d-05 /
      data fpppp( 8, 9, 7,1),fpppp( 8, 9, 7,2),fpppp( 8, 9, 7,3)/
     x-3.2851247d-03,-2.2302694d-02,-8.8233875d-06 /
      data fpppp( 8, 9, 8,1),fpppp( 8, 9, 8,2),fpppp( 8, 9, 8,3)/
     x 1.5933939d-04, 5.7222493d-03, 9.4075167d-07 /
      data fpppp( 8, 9, 9,1),fpppp( 8, 9, 9,2),fpppp( 8, 9, 9,3)/
     x 1.0304296d-04,-1.5111534d-03,-2.6513179d-07 /
      data fpppp( 8, 9,10,1),fpppp( 8, 9,10,2),fpppp( 8, 9,10,3)/
     x 1.4877013d-04, 4.4913910d-04, 9.0919746d-08 /
      data fpppp( 8, 9,11,1),fpppp( 8, 9,11,2),fpppp( 8, 9,11,3)/
     x 6.2422984d-05,-9.8883202d-05,-3.8187374d-09 /
      data fpppp( 8, 9,12,1),fpppp( 8, 9,12,2),fpppp( 8, 9,12,3)/
     x 8.0457331d-05, 5.1732963d-05, 2.7013094d-08 /
      data fpppp( 8, 9,13,1),fpppp( 8, 9,13,2),fpppp( 8, 9,13,3)/
     x-4.5512514d-05,-7.6867604d-06, 1.5607461d-08 /
      data fpppp( 8, 9,14,1),fpppp( 8, 9,14,2),fpppp( 8, 9,14,3)/
     x 1.0979162d-04, 2.3262212d-05, 2.9687033d-08 /
      data fpppp( 8, 9,15,1),fpppp( 8, 9,15,2),fpppp( 8, 9,15,3)/
     x-4.1807285d-05,-7.7410923d-06, 2.6414932d-08 /
      data fpppp( 8, 9,16,1),fpppp( 8, 9,16,2),fpppp( 8, 9,16,3)/
     x 1.0098675d-05, 1.8584899d-05, 3.0262021d-08 /
      data fpppp( 8, 9,17,1),fpppp( 8, 9,17,2),fpppp( 8, 9,17,3)/
     x-7.3535958d-05, 4.4246221d-06, 2.7410042d-08 /
      data fpppp( 8, 9,18,1),fpppp( 8, 9,18,2),fpppp( 8, 9,18,3)/
     x-7.9373395d-05, 2.0444629d-05, 8.4465854d-08 /
      data fpppp( 8, 9,19,1),fpppp( 8, 9,19,2),fpppp( 8, 9,19,3)/
     x-2.6954793d-05, 5.4863564d-05,-1.5656523d-07 /
      data fpppp( 8, 9,20,1),fpppp( 8, 9,20,2),fpppp( 8, 9,20,3)/
     x-1.5003545d-04,-7.6602630d-05,-7.2000586d-08 /
      data fpppp( 8, 9,21,1),fpppp( 8, 9,21,2),fpppp( 8, 9,21,3)/
     x-1.5003545d-04,-7.2056594d-05,-8.5315203d-08 /
      data fpppp( 8, 9,22,1),fpppp( 8, 9,22,2),fpppp( 8, 9,22,3)/
     x-2.6954793d-05, 3.6679420d-05,-1.0330677d-07 /
      data fpppp( 8, 9,23,1),fpppp( 8, 9,23,2),fpppp( 8, 9,23,3)/
     x-7.9373395d-05, 8.8635169d-05,-1.1525339d-07 /
      data fpppp( 8,10, 1,1),fpppp( 8,10, 1,2),fpppp( 8,10, 1,3)/
     x-2.0790979d-02,-1.8513622d-04, 8.4859569d-07 /
      data fpppp( 8,10, 2,1),fpppp( 8,10, 2,2),fpppp( 8,10, 2,3)/
     x-4.0360421d-04,-1.7301486d-04, 5.2184178d-07 /
      data fpppp( 8,10, 3,1),fpppp( 8,10, 3,2),fpppp( 8,10, 3,3)/
     x 1.9799399d-03,-9.8691430d-05, 2.1004131d-07 /
      data fpppp( 8,10, 4,1),fpppp( 8,10, 4,2),fpppp( 8,10, 4,3)/
     x 1.9799399d-03,-1.8330231d-04,-4.6963502d-07 /
      data fpppp( 8,10, 5,1),fpppp( 8,10, 5,2),fpppp( 8,10, 5,3)/
     x-4.0360421d-04, 1.6542865d-04, 3.2405471d-06 /
      data fpppp( 8,10, 6,1),fpppp( 8,10, 6,2),fpppp( 8,10, 6,3)/
     x-2.0790979d-02,-1.4542994d-03,-9.3465494d-06 /
      data fpppp( 8,10, 7,1),fpppp( 8,10, 7,2),fpppp( 8,10, 7,3)/
     x 3.7326181d-03, 4.2833623d-03, 9.0905347d-06 /
      data fpppp( 8,10, 8,1),fpppp( 8,10, 8,2),fpppp( 8,10, 8,3)/
     x-1.5317725d-03,-3.4178148d-03,-2.0157994d-06 /
      data fpppp( 8,10, 9,1),fpppp( 8,10, 9,2),fpppp( 8,10, 9,3)/
     x-2.6542385d-04, 6.8376468d-04,-2.8318374d-07 /
      data fpppp( 8,10,10,1),fpppp( 8,10,10,2),fpppp( 8,10,10,3)/
     x-2.0840201d-05,-9.0171590d-05,-1.4692909d-07 /
      data fpppp( 8,10,11,1),fpppp( 8,10,11,2),fpppp( 8,10,11,3)/
     x-6.8266365d-05, 5.0809973d-05,-9.4444373d-09 /
      data fpppp( 8,10,12,1),fpppp( 8,10,12,2),fpppp( 8,10,12,3)/
     x-7.9338417d-05,-4.5745779d-05,-1.6382847d-09 /
      data fpppp( 8,10,13,1),fpppp( 8,10,13,2),fpppp( 8,10,13,3)/
     x 4.1562711d-05, 1.2652793d-04, 1.1681017d-08 /
      data fpppp( 8,10,14,1),fpppp( 8,10,14,2),fpppp( 8,10,14,3)/
     x-4.6656507d-05,-1.0070801d-04, 1.1651570d-08 /
      data fpppp( 8,10,15,1),fpppp( 8,10,15,2),fpppp( 8,10,15,3)/
     x 3.6443715d-05, 7.0647759d-05, 1.4510970d-08 /
      data fpppp( 8,10,16,1),fpppp( 8,10,16,2),fpppp( 8,10,16,3)/
     x 1.7373857d-05,-1.4552641d-05, 5.2222947d-09 /
      data fpppp( 8,10,17,1),fpppp( 8,10,17,2),fpppp( 8,10,17,3)/
     x 4.1076270d-05, 2.0313434d-05,-7.4083122d-09 /
      data fpppp( 8,10,18,1),fpppp( 8,10,18,2),fpppp( 8,10,18,3)/
     x 3.7031455d-05, 2.1157564d-05,-3.8433472d-08 /
      data fpppp( 8,10,19,1),fpppp( 8,10,19,2),fpppp( 8,10,19,3)/
     x 2.7107137d-05, 8.4507860d-05, 2.4163085d-08 /
      data fpppp( 8,10,20,1),fpppp( 8,10,20,2),fpppp( 8,10,20,3)/
     x 2.2733199d-04,-9.2525175d-05,-4.8371277d-08 /
      data fpppp( 8,10,21,1),fpppp( 8,10,21,2),fpppp( 8,10,21,3)/
     x 2.2733199d-04,-8.5596423d-05,-4.3793147d-08 /
      data fpppp( 8,10,22,1),fpppp( 8,10,22,2),fpppp( 8,10,22,3)/
     x 2.7107137d-05, 5.6792851d-05, 5.8505678d-09 /
      data fpppp( 8,10,23,1),fpppp( 8,10,23,2),fpppp( 8,10,23,3)/
     x 3.7031455d-05, 1.2508885d-04, 3.0238469d-08 /
      data fpppp( 8,11, 1,1),fpppp( 8,11, 1,2),fpppp( 8,11, 1,3)/
     x 5.7235738d-03, 2.3646325d-04, 4.6577070d-07 /
      data fpppp( 8,11, 2,1),fpppp( 8,11, 2,2),fpppp( 8,11, 2,3)/
     x 7.6167118d-04, 4.2208304d-05, 1.0259964d-07 /
      data fpppp( 8,11, 3,1),fpppp( 8,11, 3,2),fpppp( 8,11, 3,3)/
     x 9.1953291d-04,-3.5684583d-04,-7.6149335d-07 /
      data fpppp( 8,11, 4,1),fpppp( 8,11, 4,2),fpppp( 8,11, 4,3)/
     x 9.1953291d-04,-3.8695715d-04,-6.1122208d-07 /
      data fpppp( 8,11, 5,1),fpppp( 8,11, 5,2),fpppp( 8,11, 5,3)/
     x 7.6167118d-04, 1.6265360d-04,-4.9848545d-07 /
      data fpppp( 8,11, 6,1),fpppp( 8,11, 6,2),fpppp( 8,11, 6,3)/
     x 5.7235738d-03,-2.1520661d-04, 2.7198398d-06 /
      data fpppp( 8,11, 7,1),fpppp( 8,11, 7,2),fpppp( 8,11, 7,3)/
     x-1.2808639d-03, 1.0336565d-03,-3.4371463d-06 /
      data fpppp( 8,11, 8,1),fpppp( 8,11, 8,2),fpppp( 8,11, 8,3)/
     x 1.1294626d-03, 5.4734881d-04, 2.4680775d-06 /
      data fpppp( 8,11, 9,1),fpppp( 8,11, 9,2),fpppp( 8,11, 9,3)/
     x-4.6739136d-04,-1.0914502d-03,-4.4184574d-08 /
      data fpppp( 8,11,10,1),fpppp( 8,11,10,2),fpppp( 8,11,10,3)/
     x-1.6943408d-04, 5.5596723d-05,-1.4270965d-07 /
      data fpppp( 8,11,11,1),fpppp( 8,11,11,2),fpppp( 8,11,11,3)/
     x 1.2131389d-05, 1.3814630d-05,-5.0447052d-08 /
      data fpppp( 8,11,12,1),fpppp( 8,11,12,2),fpppp( 8,11,12,3)/
     x 4.8645453d-05, 2.3197099d-05,-9.9795159d-09 /
      data fpppp( 8,11,13,1),fpppp( 8,11,13,2),fpppp( 8,11,13,3)/
     x-1.3760481d-05, 6.6713186d-05, 1.1102537d-09 /
      data fpppp( 8,11,14,1),fpppp( 8,11,14,2),fpppp( 8,11,14,3)/
     x 2.2067495d-05,-7.1955639d-05, 5.0591212d-09 /
      data fpppp( 8,11,15,1),fpppp( 8,11,15,2),fpppp( 8,11,15,3)/
     x 6.0641040d-06, 5.8719040d-05, 1.1696684d-09 /
      data fpppp( 8,11,16,1),fpppp( 8,11,16,2),fpppp( 8,11,16,3)/
     x 1.8891515d-05,-1.5487149d-05,-2.6975555d-09 /
      data fpppp( 8,11,17,1),fpppp( 8,11,17,2),fpppp( 8,11,17,3)/
     x 2.2140373d-05, 2.3677629d-05,-6.1398490d-09 /
      data fpppp( 8,11,18,1),fpppp( 8,11,18,2),fpppp( 8,11,18,3)/
     x 3.4254071d-05, 1.5439059d-05, 2.6661143d-10 /
      data fpppp( 8,11,19,1),fpppp( 8,11,19,2),fpppp( 8,11,19,3)/
     x 5.3931028d-05, 1.9470382d-04,-4.1998370d-08 /
      data fpppp( 8,11,20,1),fpppp( 8,11,20,2),fpppp( 8,11,20,3)/
     x-3.2490658d-04,-1.5764008d-04, 4.1321582d-09 /
      data fpppp( 8,11,21,1),fpppp( 8,11,21,2),fpppp( 8,11,21,3)/
     x-3.2490658d-04,-1.4132559d-04, 1.1040303d-09 /
      data fpppp( 8,11,22,1),fpppp( 8,11,22,2),fpppp( 8,11,22,3)/
     x 5.3931028d-05, 1.2944586d-04,-2.9885859d-08 /
      data fpppp( 8,11,23,1),fpppp( 8,11,23,2),fpppp( 8,11,23,3)/
     x 3.4254071d-05, 2.6015641d-04,-4.5155308d-08 /
      data fpppp( 8,12, 1,1),fpppp( 8,12, 1,2),fpppp( 8,12, 1,3)/
     x-1.2430107d-03, 1.3197788d-03, 4.4009907d-07 /
      data fpppp( 8,12, 2,1),fpppp( 8,12, 2,2),fpppp( 8,12, 2,3)/
     x 6.4291852d-04, 5.3975966d-04, 1.3310450d-07 /
      data fpppp( 8,12, 3,1),fpppp( 8,12, 3,2),fpppp( 8,12, 3,3)/
     x 1.3643241d-03,-1.0953257d-03,-4.8906490d-07 /
      data fpppp( 8,12, 4,1),fpppp( 8,12, 4,2),fpppp( 8,12, 4,3)/
     x 1.3643241d-03,-1.1589981d-03,-5.5149808d-07 /
      data fpppp( 8,12, 5,1),fpppp( 8,12, 5,2),fpppp( 8,12, 5,3)/
     x 6.4291852d-04, 7.9444932d-04, 3.8283723d-07 /
      data fpppp( 8,12, 6,1),fpppp( 8,12, 6,2),fpppp( 8,12, 6,3)/
     x-1.2430107d-03, 3.6469256d-04,-4.9639865d-07 /
      data fpppp( 8,12, 7,1),fpppp( 8,12, 7,2),fpppp( 8,12, 7,3)/
     x 3.6472761d-04, 3.2543177d-04, 8.2768298d-07 /
      data fpppp( 8,12, 8,1),fpppp( 8,12, 8,2),fpppp( 8,12, 8,3)/
     x 6.2618283d-05, 9.6700389d-04,-5.0289209d-07 /
      data fpppp( 8,12, 9,1),fpppp( 8,12, 9,2),fpppp( 8,12, 9,3)/
     x 1.9017600d-04,-2.9442799d-04, 6.2337524d-07 /
      data fpppp( 8,12,10,1),fpppp( 8,12,10,2),fpppp( 8,12,10,3)/
     x-2.1027936d-04,-5.1260739d-04, 4.6563179d-09 /
      data fpppp( 8,12,11,1),fpppp( 8,12,11,2),fpppp( 8,12,11,3)/
     x-9.3559557d-05, 2.0070017d-05,-5.6950396d-09 /
      data fpppp( 8,12,12,1),fpppp( 8,12,12,2),fpppp( 8,12,12,3)/
     x-6.2825522d-05, 3.2722233d-06,-1.0221527d-08 /
      data fpppp( 8,12,13,1),fpppp( 8,12,13,2),fpppp( 8,12,13,3)/
     x-1.7295487d-05, 7.0207912d-05,-6.8284558d-10 /
      data fpppp( 8,12,14,1),fpppp( 8,12,14,2),fpppp( 8,12,14,3)/
     x-1.5196081d-05,-6.7188714d-05,-2.6269235d-09 /
      data fpppp( 8,12,15,1),fpppp( 8,12,15,2),fpppp( 8,12,15,3)/
     x-3.0582396d-06, 5.3455038d-05,-4.4333549d-09 /
      data fpppp( 8,12,16,1),fpppp( 8,12,16,2),fpppp( 8,12,16,3)/
     x 5.6640470d-06,-9.3575092d-06,-3.1583584d-09 /
      data fpppp( 8,12,17,1),fpppp( 8,12,17,2),fpppp( 8,12,17,3)/
     x 2.0969590d-05, 3.1618250d-06, 2.7965622d-09 /
      data fpppp( 8,12,18,1),fpppp( 8,12,18,2),fpppp( 8,12,18,3)/
     x 3.3844152d-05, 1.0345756d-04,-7.1421045d-09 /
      data fpppp( 8,12,19,1),fpppp( 8,12,19,2),fpppp( 8,12,19,3)/
     x 1.3034567d-05,-5.5478850d-05,-2.8401936d-08 /
      data fpppp( 8,12,20,1),fpppp( 8,12,20,2),fpppp( 8,12,20,3)/
     x 2.2033050d-04,-3.0781002d-05, 1.8281103d-08 /
      data fpppp( 8,12,21,1),fpppp( 8,12,21,2),fpppp( 8,12,21,3)/
     x 2.2033050d-04,-3.8872556d-05, 1.6237816d-08 /
      data fpppp( 8,12,22,1),fpppp( 8,12,22,2),fpppp( 8,12,22,3)/
     x 1.3034567d-05,-2.3112634d-05,-2.0228787d-08 /
      data fpppp( 8,12,23,1),fpppp( 8,12,23,2),fpppp( 8,12,23,3)/
     x 3.3844152d-05,-1.7915752d-05,-3.7791412d-08 /
      data fpppp( 8,13, 1,1),fpppp( 8,13, 1,2),fpppp( 8,13, 1,3)/
     x 6.9142133d-05, 2.5114814d-03,-1.9557300d-06 /
      data fpppp( 8,13, 2,1),fpppp( 8,13, 2,2),fpppp( 8,13, 2,3)/
     x-1.1533337d-03, 1.0549049d-03,-9.3850170d-07 /
      data fpppp( 8,13, 3,1),fpppp( 8,13, 3,2),fpppp( 8,13, 3,3)/
     x-2.8289572d-03,-2.0040464d-03, 1.1855321d-06 /
      data fpppp( 8,13, 4,1),fpppp( 8,13, 4,2),fpppp( 8,13, 4,3)/
     x-2.8289572d-03,-2.1130436d-03, 1.2830789d-06 /
      data fpppp( 8,13, 5,1),fpppp( 8,13, 5,2),fpppp( 8,13, 5,3)/
     x-1.1533337d-03, 1.4908938d-03,-1.3286889d-06 /
      data fpppp( 8,13, 6,1),fpppp( 8,13, 6,2),fpppp( 8,13, 6,3)/
     x 6.9142133d-05, 8.7652300d-04,-4.9252804d-07 /
      data fpppp( 8,13, 7,1),fpppp( 8,13, 7,2),fpppp( 8,13, 7,3)/
     x-1.3550997d-04, 4.0603509d-04,-4.9242900d-07 /
      data fpppp( 8,13, 8,1),fpppp( 8,13, 8,2),fpppp( 8,13, 8,3)/
     x 1.1710832d-04, 5.3205948d-04, 7.5786992d-08 /
      data fpppp( 8,13, 9,1),fpppp( 8,13, 9,2),fpppp( 8,13, 9,3)/
     x 7.7891357d-05, 5.5181640d-04, 1.4506236d-07 /
      data fpppp( 8,13,10,1),fpppp( 8,13,10,2),fpppp( 8,13,10,3)/
     x 8.4411798d-05,-5.9460445d-04, 1.8131323d-07 /
      data fpppp( 8,13,11,1),fpppp( 8,13,11,2),fpppp( 8,13,11,3)/
     x-6.2661336d-05,-1.6900980d-04,-7.2269462d-09 /
      data fpppp( 8,13,12,1),fpppp( 8,13,12,2),fpppp( 8,13,12,3)/
     x 4.6856746d-06, 3.9067921d-06, 2.2413398d-08 /
      data fpppp( 8,13,13,1),fpppp( 8,13,13,2),fpppp( 8,13,13,3)/
     x-2.5041879d-05, 4.9989502d-05,-3.9158172d-09 /
      data fpppp( 8,13,14,1),fpppp( 8,13,14,2),fpppp( 8,13,14,3)/
     x-3.9955389d-05,-4.8803247d-05,-3.3514192d-09 /
      data fpppp( 8,13,15,1),fpppp( 8,13,15,2),fpppp( 8,13,15,3)/
     x-1.7277190d-05, 4.3344094d-05,-5.3393345d-09 /
      data fpppp( 8,13,16,1),fpppp( 8,13,16,2),fpppp( 8,13,16,3)/
     x-1.6731511d-05,-4.4225809d-06,-5.7667592d-10 /
      data fpppp( 8,13,17,1),fpppp( 8,13,17,2),fpppp( 8,13,17,3)/
     x-2.1104452d-05, 4.1076592d-06, 3.4473464d-09 /
      data fpppp( 8,13,18,1),fpppp( 8,13,18,2),fpppp( 8,13,18,3)/
     x-3.4183584d-05, 9.7258946d-05, 1.9544866d-09 /
      data fpppp( 8,13,19,1),fpppp( 8,13,19,2),fpppp( 8,13,19,3)/
     x-6.9237474d-05,-9.9402796d-05, 1.4901648d-08 /
      data fpppp( 8,13,20,1),fpppp( 8,13,20,2),fpppp( 8,13,20,3)/
     x 1.4790076d-05,-1.7507791d-06,-2.1713876d-09 /
      data fpppp( 8,13,21,1),fpppp( 8,13,21,2),fpppp( 8,13,21,3)/
     x 1.4790076d-05,-1.3249166d-05,-1.1786070d-09 /
      data fpppp( 8,13,22,1),fpppp( 8,13,22,2),fpppp( 8,13,22,3)/
     x-6.9237474d-05,-5.3409249d-05, 1.0930525d-08 /
      data fpppp( 8,13,23,1),fpppp( 8,13,23,2),fpppp( 8,13,23,3)/
     x-3.4183584d-05,-7.5216857d-05, 1.6846195d-08 /
      data fpppp( 8,14, 1,1),fpppp( 8,14, 1,2),fpppp( 8,14, 1,3)/
     x-7.3270394d-04, 2.1010796d-03,-1.0951667d-06 /
      data fpppp( 8,14, 2,1),fpppp( 8,14, 2,2),fpppp( 8,14, 2,3)/
     x-1.7966479d-03, 8.1980860d-04,-4.2741283d-07 /
      data fpppp( 8,14, 3,1),fpppp( 8,14, 3,2),fpppp( 8,14, 3,3)/
     x-3.4578021d-03,-1.8840209d-03, 9.9078425d-07 /
      data fpppp( 8,14, 4,1),fpppp( 8,14, 4,2),fpppp( 8,14, 4,3)/
     x-3.4578021d-03,-1.9570853d-03, 1.0130162d-06 /
      data fpppp( 8,14, 5,1),fpppp( 8,14, 5,2),fpppp( 8,14, 5,3)/
     x-1.7966479d-03, 1.1120663d-03,-5.1634079d-07 /
      data fpppp( 8,14, 6,1),fpppp( 8,14, 6,2),fpppp( 8,14, 6,3)/
     x-7.3270394d-04, 1.0051133d-03,-7.6168680d-07 /
      data fpppp( 8,14, 7,1),fpppp( 8,14, 7,2),fpppp( 8,14, 7,3)/
     x-1.4645350d-04, 4.0233318d-04,-3.6423752d-07 /
      data fpppp( 8,14, 8,1),fpppp( 8,14, 8,2),fpppp( 8,14, 8,3)/
     x-7.7677595d-05, 2.1933551d-04,-2.4573620d-07 /
      data fpppp( 8,14, 9,1),fpppp( 8,14, 9,2),fpppp( 8,14, 9,3)/
     x 4.6162128d-04, 7.2633325d-04, 1.6936713d-07 /
      data fpppp( 8,14,10,1),fpppp( 8,14,10,2),fpppp( 8,14,10,3)/
     x-6.3070648d-04,-8.8601846d-05, 7.2883865d-08 /
      data fpppp( 8,14,11,1),fpppp( 8,14,11,2),fpppp( 8,14,11,3)/
     x-4.5156674d-05,-4.5768234d-04, 8.3278596d-08 /
      data fpppp( 8,14,12,1),fpppp( 8,14,12,2),fpppp( 8,14,12,3)/
     x-8.3917084d-05,-3.7702803d-05, 1.7831741d-08 /
      data fpppp( 8,14,13,1),fpppp( 8,14,13,2),fpppp( 8,14,13,3)/
     x-2.0573233d-05, 2.6942479d-05, 1.2055119d-08 /
      data fpppp( 8,14,14,1),fpppp( 8,14,14,2),fpppp( 8,14,14,3)/
     x 4.9997937d-06, 1.1955550d-06,-2.1472245d-09 /
      data fpppp( 8,14,15,1),fpppp( 8,14,15,2),fpppp( 8,14,15,3)/
     x-3.0568814d-05, 8.8720559d-06,-8.7901193d-10 /
      data fpppp( 8,14,16,1),fpppp( 8,14,16,2),fpppp( 8,14,16,3)/
     x-3.9281734d-05, 1.2534393d-06, 1.0837065d-09 /
      data fpppp( 8,14,17,1),fpppp( 8,14,17,2),fpppp( 8,14,17,3)/
     x-4.8915582d-05, 1.2438068d-05, 4.9291794d-09 /
      data fpppp( 8,14,18,1),fpppp( 8,14,18,2),fpppp( 8,14,18,3)/
     x-6.0883838d-05, 2.1190790d-05, 1.2685005d-08 /
      data fpppp( 8,14,19,1),fpppp( 8,14,19,2),fpppp( 8,14,19,3)/
     x-5.2168456d-05, 2.7867308d-05, 2.1636831d-08 /
      data fpppp( 8,14,20,1),fpppp( 8,14,20,2),fpppp( 8,14,20,3)/
     x-2.0714962d-04,-4.6892487d-05,-1.1482342d-08 /
      data fpppp( 8,14,21,1),fpppp( 8,14,21,2),fpppp( 8,14,21,3)/
     x-2.0714962d-04,-4.4919492d-05,-1.0323761d-08 /
      data fpppp( 8,14,22,1),fpppp( 8,14,22,2),fpppp( 8,14,22,3)/
     x-5.2168456d-05, 1.9975329d-05, 1.7002507d-08 /
      data fpppp( 8,14,23,1),fpppp( 8,14,23,2),fpppp( 8,14,23,3)/
     x-6.0883838d-05, 5.0785711d-05, 3.0063720d-08 /
      data fpppp( 8,15, 1,1),fpppp( 8,15, 1,2),fpppp( 8,15, 1,3)/
     x-1.4328135d-04, 5.6595855d-04, 1.0071796d-06 /
      data fpppp( 8,15, 2,1),fpppp( 8,15, 2,2),fpppp( 8,15, 2,3)/
     x 1.2238655d-04, 1.2675118d-04, 4.7315693d-07 /
      data fpppp( 8,15, 3,1),fpppp( 8,15, 3,2),fpppp( 8,15, 3,3)/
     x 1.2242587d-03,-8.1321597d-04,-6.4326788d-07 /
      data fpppp( 8,15, 4,1),fpppp( 8,15, 4,2),fpppp( 8,15, 4,3)/
     x 1.2242587d-03,-8.1530108d-04,-6.9210958d-07 /
      data fpppp( 8,15, 5,1),fpppp( 8,15, 5,2),fpppp( 8,15, 5,3)/
     x 1.2238655d-04, 1.3509161d-04, 6.6852376d-07 /
      data fpppp( 8,15, 6,1),fpppp( 8,15, 6,2),fpppp( 8,15, 6,3)/
     x-1.4328135d-04, 5.3468192d-04, 2.7455401d-07 /
      data fpppp( 8,15, 7,1),fpppp( 8,15, 7,2),fpppp( 8,15, 7,3)/
     x-2.3743931d-04, 2.2647321d-04,-8.6207703d-08 /
      data fpppp( 8,15, 8,1),fpppp( 8,15, 8,2),fpppp( 8,15, 8,3)/
     x 1.1474975d-04, 2.7984862d-05,-2.8373834d-08 /
      data fpppp( 8,15, 9,1),fpppp( 8,15, 9,2),fpppp( 8,15, 9,3)/
     x-1.2751938d-03, 4.3563880d-04,-3.8145753d-07 /
      data fpppp( 8,15,10,1),fpppp( 8,15,10,2),fpppp( 8,15,10,3)/
     x 2.3242161d-03, 6.6545712d-04, 6.0998958d-07 /
      data fpppp( 8,15,11,1),fpppp( 8,15,11,2),fpppp( 8,15,11,3)/
     x-9.7980130d-05,-7.3705863d-04,-1.6811386d-07 /
      data fpppp( 8,15,12,1),fpppp( 8,15,12,2),fpppp( 8,15,12,3)/
     x 6.5895001d-05,-6.1303076d-05, 1.0644704d-07 /
      data fpppp( 8,15,13,1),fpppp( 8,15,13,2),fpppp( 8,15,13,3)/
     x-7.9219457d-06,-3.7876837d-06,-3.4678422d-09 /
      data fpppp( 8,15,14,1),fpppp( 8,15,14,2),fpppp( 8,15,14,3)/
     x-1.0375216d-05,-9.8798023d-07, 1.3445646d-08 /
      data fpppp( 8,15,15,1),fpppp( 8,15,15,2),fpppp( 8,15,15,3)/
     x 1.0696047d-05, 7.3622099d-06, 3.3972490d-09 /
      data fpppp( 8,15,16,1),fpppp( 8,15,16,2),fpppp( 8,15,16,3)/
     x 1.9751780d-05, 5.3773042d-07, 5.0490537d-09 /
      data fpppp( 8,15,17,1),fpppp( 8,15,17,2),fpppp( 8,15,17,3)/
     x 2.8097983d-05, 4.0613400d-06, 4.6652532d-09 /
      data fpppp( 8,15,18,1),fpppp( 8,15,18,2),fpppp( 8,15,18,3)/
     x 4.1623699d-05, 5.4786028d-06, 8.9810201d-09 /
      data fpppp( 8,15,19,1),fpppp( 8,15,19,2),fpppp( 8,15,19,3)/
     x 6.5869047d-05, 1.9001038d-06, 1.0659603d-08 /
      data fpppp( 8,15,20,1),fpppp( 8,15,20,2),fpppp( 8,15,20,3)/
     x 1.5237599d-04,-1.2884074d-05,-1.0929069d-08 /
      data fpppp( 8,15,21,1),fpppp( 8,15,21,2),fpppp( 8,15,21,3)/
     x 1.5237599d-04,-1.2726442d-05,-1.0371159d-08 /
      data fpppp( 8,15,22,1),fpppp( 8,15,22,2),fpppp( 8,15,22,3)/
     x 6.5869047d-05, 1.2695752d-06, 8.4279643d-09 /
      data fpppp( 8,15,23,1),fpppp( 8,15,23,2),fpppp( 8,15,23,3)/
     x 4.1623699d-05, 7.8430852d-06, 1.7349664d-08 /
      data fpppp( 8,16, 1,1),fpppp( 8,16, 1,2),fpppp( 8,16, 1,3)/
     x 2.8084447d-04, 7.3965930d-05, 4.1790018d-07 /
      data fpppp( 8,16, 2,1),fpppp( 8,16, 2,2),fpppp( 8,16, 2,3)/
     x 8.2467825d-04,-1.6397051d-05, 1.3252101d-07 /
      data fpppp( 8,16, 3,1),fpppp( 8,16, 3,2),fpppp( 8,16, 3,3)/
     x 1.3980749d-03,-2.0800627d-04,-4.7266843d-07 /
      data fpppp( 8,16, 4,1),fpppp( 8,16, 4,2),fpppp( 8,16, 4,3)/
     x 1.3980749d-03,-2.1155131d-04,-4.8375878d-07 /
      data fpppp( 8,16, 5,1),fpppp( 8,16, 5,2),fpppp( 8,16, 5,3)/
     x 8.2467825d-04,-2.2168886d-06, 1.7688241d-07 /
      data fpppp( 8,16, 6,1),fpppp( 8,16, 6,2),fpppp( 8,16, 6,3)/
     x 2.8084447d-04, 2.0790321d-05, 2.5154496d-07 /
      data fpppp( 8,16, 7,1),fpppp( 8,16, 7,2),fpppp( 8,16, 7,3)/
     x 3.8955576d-04, 2.4567906d-04, 1.8769494d-07 /
      data fpppp( 8,16, 8,1),fpppp( 8,16, 8,2),fpppp( 8,16, 8,3)/
     x-6.2685014d-04,-7.5737252d-04,-2.2414909d-07 /
      data fpppp( 8,16, 9,1),fpppp( 8,16, 9,2),fpppp( 8,16, 9,3)/
     x 4.3565096d-03, 1.8276635d-03, 8.0395891d-07 /
      data fpppp( 8,16,10,1),fpppp( 8,16,10,2),fpppp( 8,16,10,3)/
     x-5.4521067d-03,-1.1835421d-03,-1.2933651d-06 /
      data fpppp( 8,16,11,1),fpppp( 8,16,11,2),fpppp( 8,16,11,3)/
     x 1.3832972d-04, 7.0358393d-04, 8.2281281d-07 /
      data fpppp( 8,16,12,1),fpppp( 8,16,12,2),fpppp( 8,16,12,3)/
     x-2.3997482d-04,-6.1068617d-04,-7.5840858d-08 /
      data fpppp( 8,16,13,1),fpppp( 8,16,13,2),fpppp( 8,16,13,3)/
     x-1.3581120d-05, 1.0462876d-04, 6.0704148d-08 /
      data fpppp( 8,16,14,1),fpppp( 8,16,14,2),fpppp( 8,16,14,3)/
     x-3.7878767d-05,-3.6982605d-05, 2.3940162d-09 /
      data fpppp( 8,16,15,1),fpppp( 8,16,15,2),fpppp( 8,16,15,3)/
     x-8.6278349d-05, 1.0804675d-05, 1.3244614d-08 /
      data fpppp( 8,16,16,1),fpppp( 8,16,16,2),fpppp( 8,16,16,3)/
     x-1.2830153d-04,-1.0061669d-06, 5.5523088d-09 /
      data fpppp( 8,16,17,1),fpppp( 8,16,17,2),fpppp( 8,16,17,3)/
     x-1.6085381d-04,-2.4308740d-07, 4.0462880d-09 /
      data fpppp( 8,16,18,1),fpppp( 8,16,18,2),fpppp( 8,16,18,3)/
     x-1.8490741d-04, 1.1877270d-06,-2.2723663d-10 /
      data fpppp( 8,16,19,1),fpppp( 8,16,19,2),fpppp( 8,16,19,3)/
     x-1.9998391d-04,-1.2853947d-06,-3.1991183d-09 /
      data fpppp( 8,16,20,1),fpppp( 8,16,20,2),fpppp( 8,16,20,3)/
     x-2.2220840d-04,-3.2219483d-06,-6.7277277d-09 /
      data fpppp( 8,16,21,1),fpppp( 8,16,21,2),fpppp( 8,16,21,3)/
     x-2.2220840d-04,-3.2964449d-06,-6.7906326d-09 /
      data fpppp( 8,16,22,1),fpppp( 8,16,22,2),fpppp( 8,16,22,3)/
     x-1.9998391d-04,-9.8740799d-07,-2.9474985d-09 /
      data fpppp( 8,16,23,1),fpppp( 8,16,23,2),fpppp( 8,16,23,3)/
     x-1.8490741d-04, 7.0276800d-08,-1.1708106d-09 /
      data fpppp( 8,17, 1,1),fpppp( 8,17, 1,2),fpppp( 8,17, 1,3)/
     x 8.4441786d-05, 1.6035107d-05, 3.8185041d-08 /
      data fpppp( 8,17, 2,1),fpppp( 8,17, 2,2),fpppp( 8,17, 2,3)/
     x 3.6143430d-04,-2.4768452d-06, 1.0248199d-08 /
      data fpppp( 8,17, 3,1),fpppp( 8,17, 3,2),fpppp( 8,17, 3,3)/
     x 3.0818123d-04,-4.0921827d-05,-5.0900556d-08 /
      data fpppp( 8,17, 4,1),fpppp( 8,17, 4,2),fpppp( 8,17, 4,3)/
     x 3.0818123d-04,-4.3062929d-05,-4.8653394d-08 /
      data fpppp( 8,17, 5,1),fpppp( 8,17, 5,2),fpppp( 8,17, 5,3)/
     x 3.6143430d-04, 6.0875616d-06, 1.2595504d-09 /
      data fpppp( 8,17, 6,1),fpppp( 8,17, 6,2),fpppp( 8,17, 6,3)/
     x 8.4441786d-05,-1.6081418d-05, 7.1892474d-08 /
      data fpppp( 8,17, 7,1),fpppp( 8,17, 7,2),fpppp( 8,17, 7,3)/
     x-1.3529599d-03,-1.6752646d-04,-1.0551022d-07 /
      data fpppp( 8,17, 8,1),fpppp( 8,17, 8,2),fpppp( 8,17, 8,3)/
     x 2.8071052d-03, 1.2532408d-03, 4.4109651d-07 /
      data fpppp( 8,17, 9,1),fpppp( 8,17, 9,2),fpppp( 8,17, 9,3)/
     x-1.2740754d-02,-4.9827774d-03,-1.9666252d-06 /
      data fpppp( 8,17,10,1),fpppp( 8,17,10,2),fpppp( 8,17,10,3)/
     x 6.8413139d-03, 7.9327259d-03, 2.0011330d-06 /
      data fpppp( 8,17,11,1),fpppp( 8,17,11,2),fpppp( 8,17,11,3)/
     x-1.1272499d-04,-4.4758785d-03,-3.8317812d-07 /
      data fpppp( 8,17,12,1),fpppp( 8,17,12,2),fpppp( 8,17,12,3)/
     x 6.7871686d-04, 8.1167205d-04, 2.5417327d-08 /
      data fpppp( 8,17,13,1),fpppp( 8,17,13,2),fpppp( 8,17,13,3)/
     x-5.6901848d-08,-3.4292969d-04,-1.5951757d-08 /
      data fpppp( 8,17,14,1),fpppp( 8,17,14,2),fpppp( 8,17,14,3)/
     x 1.3846657d-04, 6.5076562d-05, 1.0169385d-08 /
      data fpppp( 8,17,15,1),fpppp( 8,17,15,2),fpppp( 8,17,15,3)/
     x 3.0858627d-04,-2.3280103d-05, 5.0629190d-09 /
      data fpppp( 8,17,16,1),fpppp( 8,17,16,2),fpppp( 8,17,16,3)/
     x 4.6449794d-04, 8.7871598d-06, 5.9161132d-09 /
      data fpppp( 8,17,17,1),fpppp( 8,17,17,2),fpppp( 8,17,17,3)/
     x 5.9145136d-04,-4.1533235d-06, 1.3733603d-09 /
      data fpppp( 8,17,18,1),fpppp( 8,17,18,2),fpppp( 8,17,18,3)/
     x 6.9684520d-04, 1.5975101d-06,-1.9815380d-09 /
      data fpppp( 8,17,19,1),fpppp( 8,17,19,2),fpppp( 8,17,19,3)/
     x 7.7777875d-04,-1.5000186d-06,-5.9290375d-09 /
      data fpppp( 8,17,20,1),fpppp( 8,17,20,2),fpppp( 8,17,20,3)/
     x 8.3443634d-04,-7.5025140d-07,-6.9069249d-09 /
      data fpppp( 8,17,21,1),fpppp( 8,17,21,2),fpppp( 8,17,21,3)/
     x 8.3443634d-04,-9.1389476d-07,-7.0726441d-09 /
      data fpppp( 8,17,22,1),fpppp( 8,17,22,2),fpppp( 8,17,22,3)/
     x 7.7777875d-04,-8.4544517d-07,-5.2661606d-09 /
      data fpppp( 8,17,23,1),fpppp( 8,17,23,2),fpppp( 8,17,23,3)/
     x 6.9684520d-04,-8.5714026d-07,-4.4673267d-09 /
      data fpppp( 8,18, 1,1),fpppp( 8,18, 1,2),fpppp( 8,18, 1,3)/
     x 5.8744494d-04,-2.6098810d-04, 5.5713941d-08 /
      data fpppp( 8,18, 2,1),fpppp( 8,18, 2,2),fpppp( 8,18, 2,3)/
     x 5.0461684d-04,-1.7737702d-04, 4.7737609d-08 /
      data fpppp( 8,18, 3,1),fpppp( 8,18, 3,2),fpppp( 8,18, 3,3)/
     x 7.4393424d-04, 1.3126259d-04, 3.2510684d-08 /
      data fpppp( 8,18, 4,1),fpppp( 8,18, 4,2),fpppp( 8,18, 4,3)/
     x 7.4393424d-04,-9.5315168d-05, 2.9246560d-08 /
      data fpppp( 8,18, 5,1),fpppp( 8,18, 5,2),fpppp( 8,18, 5,3)/
     x 5.0461684d-04, 7.2893401d-04, 6.0794106d-08 /
      data fpppp( 8,18, 6,1),fpppp( 8,18, 6,2),fpppp( 8,18, 6,3)/
     x 5.8744494d-04,-3.6596544d-03, 6.7520796d-09 /
      data fpppp( 8,18, 7,1),fpppp( 8,18, 7,2),fpppp( 8,18, 7,3)/
     x 1.9870841d-03, 1.0459250d-02, 1.0604351d-07 /
      data fpppp( 8,18, 8,1),fpppp( 8,18, 8,2),fpppp( 8,18, 8,3)/
     x-2.7393667d-03,-2.2150714d-02,-4.7381416d-07 /
      data fpppp( 8,18, 9,1),fpppp( 8,18, 9,2),fpppp( 8,18, 9,3)/
     x 1.2904115d-02, 2.6363073d-02, 1.4545529d-06 /
      data fpppp( 8,18,10,1),fpppp( 8,18,10,2),fpppp( 8,18,10,3)/
     x-1.6277283d-03,-1.4609200d-02,-8.6019435d-07 /
      data fpppp( 8,18,11,1),fpppp( 8,18,11,2),fpppp( 8,18,11,3)/
     x 6.7042243d-04, 4.9057655d-03,-2.3368082d-07 /
      data fpppp( 8,18,12,1),fpppp( 8,18,12,2),fpppp( 8,18,12,3)/
     x-4.8477891d-04,-2.7923712d-03,-2.0958890d-08 /
      data fpppp( 8,18,13,1),fpppp( 8,18,13,2),fpppp( 8,18,13,3)/
     x 4.6827755d-05, 1.1646551d-03,-2.5354887d-08 /
      data fpppp( 8,18,14,1),fpppp( 8,18,14,2),fpppp( 8,18,14,3)/
     x-1.4088627d-04,-3.2785872d-04,-5.7500417d-09 /
      data fpppp( 8,18,15,1),fpppp( 8,18,15,2),fpppp( 8,18,15,3)/
     x-3.2559167d-04, 7.2761307d-05,-4.5645748d-09 /
      data fpppp( 8,18,16,1),fpppp( 8,18,16,2),fpppp( 8,18,16,3)/
     x-4.8708272d-04,-3.4171195d-05,-4.4251376d-09 /
      data fpppp( 8,18,17,1),fpppp( 8,18,17,2),fpppp( 8,18,17,3)/
     x-6.1980818d-04,-4.7795500d-06,-6.2379413d-09 /
      data fpppp( 8,18,18,1),fpppp( 8,18,18,2),fpppp( 8,18,18,3)/
     x-7.2824993d-04,-1.1832984d-05,-8.6053876d-09 /
      data fpppp( 8,18,19,1),fpppp( 8,18,19,2),fpppp( 8,18,19,3)/
     x-8.1095954d-04,-1.2769470d-05,-1.0511414d-08 /
      data fpppp( 8,18,20,1),fpppp( 8,18,20,2),fpppp( 8,18,20,3)/
     x-8.6496394d-04,-1.5765563d-05,-1.2659067d-08 /
      data fpppp( 8,18,21,1),fpppp( 8,18,21,2),fpppp( 8,18,21,3)/
     x-8.6496394d-04,-1.5743648d-05,-1.2701968d-08 /
      data fpppp( 8,18,22,1),fpppp( 8,18,22,2),fpppp( 8,18,22,3)/
     x-8.1095954d-04,-1.2857133d-05,-1.0339809d-08 /
      data fpppp( 8,18,23,1),fpppp( 8,18,23,2),fpppp( 8,18,23,3)/
     x-7.2824993d-04,-1.1504249d-05,-9.2489080d-09 /
      data fpppp( 8,19, 1,1),fpppp( 8,19, 1,2),fpppp( 8,19, 1,3)/
     x 8.9061785d-04, 4.3989857d-17,-4.0255457d-08 /
      data fpppp( 8,19, 2,1),fpppp( 8,19, 2,2),fpppp( 8,19, 2,3)/
     x 4.7453468d-04,-7.6809784d-19, 3.9580669d-08 /
      data fpppp( 8,19, 3,1),fpppp( 8,19, 3,2),fpppp( 8,19, 3,3)/
     x 7.4378819d-04, 1.5558048d-18, 2.1259525d-07 /
      data fpppp( 8,19, 4,1),fpppp( 8,19, 4,2),fpppp( 8,19, 4,3)/
     x 7.4378819d-04,-1.5262119d-18, 2.0920521d-07 /
      data fpppp( 8,19, 5,1),fpppp( 8,19, 5,2),fpppp( 8,19, 5,3)/
     x 4.7453468d-04, 2.1871017d-17, 5.3140828d-08 /
      data fpppp( 8,19, 6,1),fpppp( 8,19, 6,2),fpppp( 8,19, 6,3)/
     x 8.9061785d-04,-5.8220780d-18,-9.1106054d-08 /
      data fpppp( 8,19, 7,1),fpppp( 8,19, 7,2),fpppp( 8,19, 7,3)/
     x 3.8749681d-03, 3.2422182d-18, 1.7338042d-07 /
      data fpppp( 8,19, 8,1),fpppp( 8,19, 8,2),fpppp( 8,19, 8,3)/
     x-5.7200023d-03,-3.7030247d-18,-9.3725161d-07 /
      data fpppp( 8,19, 9,1),fpppp( 8,19, 9,2),fpppp( 8,19, 9,3)/
     x 2.6336945d-02, 5.2499717d-19, 3.1066561d-06 /
      data fpppp( 8,19,10,1),fpppp( 8,19,10,2),fpppp( 8,19,10,3)/
     x-4.1646382d-03,-1.6499354d-17,-1.9627144d-06 /
      data fpppp( 8,19,11,1),fpppp( 8,19,11,2),fpppp( 8,19,11,3)/
     x 1.1580835d-03,-2.6091170d-18,-4.7146587d-07 /
      data fpppp( 8,19,12,1),fpppp( 8,19,12,2),fpppp( 8,19,12,3)/
     x-1.0533640d-03, 5.2595727d-18,-2.5153849d-08 /
      data fpppp( 8,19,13,1),fpppp( 8,19,13,2),fpppp( 8,19,13,3)/
     x 8.4180858d-05, 1.7586065d-17,-5.3973096d-08 /
      data fpppp( 8,19,14,1),fpppp( 8,19,14,2),fpppp( 8,19,14,3)/
     x-2.9003963d-04,-2.0369023d-17,-1.4899527d-08 /
      data fpppp( 8,19,15,1),fpppp( 8,19,15,2),fpppp( 8,19,15,3)/
     x-6.6575745d-04,-5.5337564d-18,-1.3778983d-08 /
      data fpppp( 8,19,16,1),fpppp( 8,19,16,2),fpppp( 8,19,16,3)/
     x-9.9741192d-04, 1.4219601d-17,-1.1707801d-08 /
      data fpppp( 8,19,17,1),fpppp( 8,19,17,2),fpppp( 8,19,17,3)/
     x-1.2700492d-03, 2.6133310d-18,-1.2438279d-08 /
      data fpppp( 8,19,18,1),fpppp( 8,19,18,2),fpppp( 8,19,18,3)/
     x-1.4942457d-03,-3.1583431d-18,-1.3837938d-08 /
      data fpppp( 8,19,19,1),fpppp( 8,19,19,2),fpppp( 8,19,19,3)/
     x-1.6664118d-03,-7.3078579d-18,-1.4564517d-08 /
      data fpppp( 8,19,20,1),fpppp( 8,19,20,2),fpppp( 8,19,20,3)/
     x-1.7769228d-03,-3.6816441d-18,-1.6818939d-08 /
      data fpppp( 8,19,21,1),fpppp( 8,19,21,2),fpppp( 8,19,21,3)/
     x-1.7769228d-03, 4.0461501d-18,-1.6803488d-08 /
      data fpppp( 8,19,22,1),fpppp( 8,19,22,2),fpppp( 8,19,22,3)/
     x-1.6664118d-03, 3.6330373d-17,-1.4626318d-08 /
      data fpppp( 8,19,23,1),fpppp( 8,19,23,2),fpppp( 8,19,23,3)/
     x-1.4942457d-03,-1.1675340d-18,-1.3606185d-08 /
      data fpppp( 9, 1, 1,1),fpppp( 9, 1, 1,2),fpppp( 9, 1, 1,3)/
     x 5.2525674d-02,-4.4092254d-16, 3.7959207d-05 /
      data fpppp( 9, 1, 2,1),fpppp( 9, 1, 2,2),fpppp( 9, 1, 2,3)/
     x 2.2364235d-01, 2.7066788d-16, 2.1226574d-05 /
      data fpppp( 9, 1, 3,1),fpppp( 9, 1, 3,2),fpppp( 9, 1, 3,3)/
     x 7.4694060d-02,-1.3765033d-16,-1.0588317d-05 /
      data fpppp( 9, 1, 4,1),fpppp( 9, 1, 4,2),fpppp( 9, 1, 4,3)/
     x 7.4694060d-02,-1.2494855d-16,-1.7659630d-05 /
      data fpppp( 9, 1, 5,1),fpppp( 9, 1, 5,2),fpppp( 9, 1, 5,3)/
     x 2.2364235d-01, 4.3599057d-17, 4.9511827d-05 /
      data fpppp( 9, 1, 6,1),fpppp( 9, 1, 6,2),fpppp( 9, 1, 6,3)/
     x 5.2525674d-02, 2.3400549d-17,-6.8110492d-05 /
      data fpppp( 9, 1, 7,1),fpppp( 9, 1, 7,2),fpppp( 9, 1, 7,3)/
     x-2.2610877d-02,-5.3803359d-17, 4.2972854d-05 /
      data fpppp( 9, 1, 8,1),fpppp( 9, 1, 8,2),fpppp( 9, 1, 8,3)/
     x-1.8103391d-01, 3.2962896d-17,-4.0680828d-06 /
      data fpppp( 9, 1, 9,1),fpppp( 9, 1, 9,2),fpppp( 9, 1, 9,3)/
     x-1.5997227d-01,-1.4724762d-16, 2.9702838d-06 /
      data fpppp( 9, 1,10,1),fpppp( 9, 1,10,2),fpppp( 9, 1,10,3)/
     x-1.6247356d-01,-1.0925361d-16, 1.7133829d-06 /
      data fpppp( 9, 1,11,1),fpppp( 9, 1,11,2),fpppp( 9, 1,11,3)/
     x-1.5444295d-01,-2.5531843d-17,-3.0338075d-06 /
      data fpppp( 9, 1,12,1),fpppp( 9, 1,12,2),fpppp( 9, 1,12,3)/
     x-9.4375294d-02,-6.2529420d-17, 2.2869897d-06 /
      data fpppp( 9, 1,13,1),fpppp( 9, 1,13,2),fpppp( 9, 1,13,3)/
     x-1.2869881d-01,-3.9640150d-17, 1.5654721d-06 /
      data fpppp( 9, 1,14,1),fpppp( 9, 1,14,2),fpppp( 9, 1,14,3)/
     x-1.6451836d-01,-1.4432217d-16,-1.6184117d-06 /
      data fpppp( 9, 1,15,1),fpppp( 9, 1,15,2),fpppp( 9, 1,15,3)/
     x-1.6441357d-01, 2.2106107d-17, 3.9874927d-06 /
      data fpppp( 9, 1,16,1),fpppp( 9, 1,16,2),fpppp( 9, 1,16,3)/
     x-1.6720518d-01, 4.2318780d-17,-4.4934896d-06 /
      data fpppp( 9, 1,17,1),fpppp( 9, 1,17,2),fpppp( 9, 1,17,3)/
     x-1.2403738d-02,-1.4762104d-16, 4.2386885d-05 /
      data fpppp( 9, 1,18,1),fpppp( 9, 1,18,2),fpppp( 9, 1,18,3)/
     x 7.6093395d-02, 7.8175714d-17,-6.6004838d-05 /
      data fpppp( 9, 1,19,1),fpppp( 9, 1,19,2),fpppp( 9, 1,19,3)/
     x 2.0051919d-01,-7.2904056d-17, 4.7853308d-05 /
      data fpppp( 9, 1,20,1),fpppp( 9, 1,20,2),fpppp( 9, 1,20,3)/
     x 5.0366264d-02,-5.7863148d-17,-1.7380178d-05 /
      data fpppp( 9, 1,21,1),fpppp( 9, 1,21,2),fpppp( 9, 1,21,3)/
     x 5.0366264d-02,-9.5559977d-17,-1.0530474d-05 /
      data fpppp( 9, 1,22,1),fpppp( 9, 1,22,2),fpppp( 9, 1,22,3)/
     x 2.0051919d-01,-6.2126031d-17, 2.0454490d-05 /
      data fpppp( 9, 1,23,1),fpppp( 9, 1,23,2),fpppp( 9, 1,23,3)/
     x 7.6093395d-02, 2.2695912d-16, 3.6740728d-05 /
      data fpppp( 9, 2, 1,1),fpppp( 9, 2, 1,2),fpppp( 9, 2, 1,3)/
     x 2.9492295d-02, 8.5243877d-02, 1.8746737d-05 /
      data fpppp( 9, 2, 2,1),fpppp( 9, 2, 2,2),fpppp( 9, 2, 2,3)/
     x 1.0813460d-01, 4.9175991d-02, 1.0681062d-05 /
      data fpppp( 9, 2, 3,1),fpppp( 9, 2, 3,2),fpppp( 9, 2, 3,3)/
     x 3.6780643d-02,-2.5532721d-02,-4.7497944d-06 /
      data fpppp( 9, 2, 4,1),fpppp( 9, 2, 4,2),fpppp( 9, 2, 4,3)/
     x 3.6780643d-02,-3.0047050d-02,-7.9920774d-06 /
      data fpppp( 9, 2, 5,1),fpppp( 9, 2, 5,2),fpppp( 9, 2, 5,3)/
     x 1.0813460d-01, 6.7233305d-02, 2.3650194d-05 /
      data fpppp( 9, 2, 6,1),fpppp( 9, 2, 6,2),fpppp( 9, 2, 6,3)/
     x 2.9492295d-02, 1.7528947d-02,-2.9887508d-05 /
      data fpppp( 9, 2, 7,1),fpppp( 9, 2, 7,2),fpppp( 9, 2, 7,3)/
     x-1.2901257d-02, 3.6153160d-03, 1.7655230d-05 /
      data fpppp( 9, 2, 8,1),fpppp( 9, 2, 8,2),fpppp( 9, 2, 8,3)/
     x-9.0593402d-02,-6.4664854d-02,-1.7534152d-06 /
      data fpppp( 9, 2, 9,1),fpppp( 9, 2, 9,2),fpppp( 9, 2, 9,3)/
     x-8.0380572d-02, 2.8746145d-02, 9.3423721d-07 /
      data fpppp( 9, 2,10,1),fpppp( 9, 2,10,2),fpppp( 9, 2,10,3)/
     x-8.0510385d-02,-1.1813363d-02, 9.6979527d-07 /
      data fpppp( 9, 2,11,1),fpppp( 9, 2,11,2),fpppp( 9, 2,11,3)/
     x-7.7969315d-02,-1.4804592d-02,-1.7250745d-06 /
      data fpppp( 9, 2,12,1),fpppp( 9, 2,12,2),fpppp( 9, 2,12,3)/
     x-4.8408133d-02, 1.8585183d-02, 1.0915575d-06 /
      data fpppp( 9, 2,13,1),fpppp( 9, 2,13,2),fpppp( 9, 2,13,3)/
     x-6.3868699d-02, 2.2276304d-02, 5.5927821d-07 /
      data fpppp( 9, 2,14,1),fpppp( 9, 2,14,2),fpppp( 9, 2,14,3)/
     x-8.2152751d-02,-3.4383143d-02,-7.2686298d-07 /
      data fpppp( 9, 2,15,1),fpppp( 9, 2,15,2),fpppp( 9, 2,15,3)/
     x-8.2443930d-02, 2.6135230d-02, 1.4992578d-06 /
      data fpppp( 9, 2,16,1),fpppp( 9, 2,16,2),fpppp( 9, 2,16,3)/
     x-8.3778171d-02,-5.8365071d-02,-2.0461669d-06 /
      data fpppp( 9, 2,17,1),fpppp( 9, 2,17,2),fpppp( 9, 2,17,3)/
     x-7.6599108d-03,-2.9822898d-03, 1.7548971d-05 /
      data fpppp( 9, 2,18,1),fpppp( 9, 2,18,2),fpppp( 9, 2,18,3)/
     x 4.1782636d-02, 3.8575769d-02,-2.8826343d-05 /
      data fpppp( 9, 2,19,1),fpppp( 9, 2,19,2),fpppp( 9, 2,19,3)/
     x 9.6766728d-02, 4.8112453d-02, 2.2728242d-05 /
      data fpppp( 9, 2,20,1),fpppp( 9, 2,20,2),fpppp( 9, 2,20,3)/
     x 2.5235474d-02,-2.7291479d-02,-7.8704758d-06 /
      data fpppp( 9, 2,21,1),fpppp( 9, 2,21,2),fpppp( 9, 2,21,3)/
     x 2.5235474d-02,-2.5168448d-02,-4.7454448d-06 /
      data fpppp( 9, 2,22,1),fpppp( 9, 2,22,2),fpppp( 9, 2,22,3)/
     x 9.6766728d-02, 3.9620329d-02, 1.0228118d-05 /
      data fpppp( 9, 2,23,1),fpppp( 9, 2,23,2),fpppp( 9, 2,23,3)/
     x 4.1782636d-02, 7.0421234d-02, 1.8049122d-05 /
      data fpppp( 9, 3, 1,1),fpppp( 9, 3, 1,2),fpppp( 9, 3, 1,3)/
     x 3.3327113d-02,-5.7521819d-02,-5.0700875d-05 /
      data fpppp( 9, 3, 2,1),fpppp( 9, 3, 2,2),fpppp( 9, 3, 2,3)/
     x-1.0972496d-01,-3.5186813d-02,-3.0562779d-05 /
      data fpppp( 9, 3, 3,1),fpppp( 9, 3, 3,2),fpppp( 9, 3, 3,3)/
     x-3.8178230d-02, 5.6481337d-03, 7.4036471d-06 /
      data fpppp( 9, 3, 4,1),fpppp( 9, 3, 4,2),fpppp( 9, 3, 4,3)/
     x-3.8178230d-02, 1.7943252d-02, 1.6480262d-05 /
      data fpppp( 9, 3, 5,1),fpppp( 9, 3, 5,2),fpppp( 9, 3, 5,3)/
     x-1.0972496d-01,-8.4367288d-02,-6.6869239d-05 /
      data fpppp( 9, 3, 6,1),fpppp( 9, 3, 6,2),fpppp( 9, 3, 6,3)/
     x 3.3327113d-02, 1.2690496d-01, 8.5448349d-05 /
      data fpppp( 9, 3, 7,1),fpppp( 9, 3, 7,2),fpppp( 9, 3, 7,3)/
     x-4.4994721d-03,-8.1227281d-02,-3.9342004d-05 /
      data fpppp( 9, 3, 8,1),fpppp( 9, 3, 8,2),fpppp( 9, 3, 8,3)/
     x 6.9737953d-02, 2.0238038d-02, 3.3190790d-06 /
      data fpppp( 9, 3, 9,1),fpppp( 9, 3, 9,2),fpppp( 9, 3, 9,3)/
     x 6.0264012d-02,-4.9275714d-03,-1.0315037d-06 /
      data fpppp( 9, 3,10,1),fpppp( 9, 3,10,2),fpppp( 9, 3,10,3)/
     x 3.8967494d-02,-2.7110600d-04,-5.0132153d-06 /
      data fpppp( 9, 3,11,1),fpppp( 9, 3,11,2),fpppp( 9, 3,11,3)/
     x 6.1920449d-02, 4.8531023d-03, 3.5293017d-06 /
      data fpppp( 9, 3,12,1),fpppp( 9, 3,12,2),fpppp( 9, 3,12,3)/
     x 2.9416925d-02,-1.9373379d-02,-2.4505124d-06 /
      data fpppp( 9, 3,13,1),fpppp( 9, 3,13,2),fpppp( 9, 3,13,3)/
     x 6.5943833d-02, 3.0817568d-02, 6.0251060d-07 /
      data fpppp( 9, 3,14,1),fpppp( 9, 3,14,2),fpppp( 9, 3,14,3)/
     x 5.2477079d-02,-2.0066029d-02,-2.0695857d-06 /
      data fpppp( 9, 3,15,1),fpppp( 9, 3,15,2),fpppp( 9, 3,15,3)/
     x 6.3392988d-02, 3.4829708d-03,-2.7109425d-06 /
      data fpppp( 9, 3,16,1),fpppp( 9, 3,16,2),fpppp( 9, 3,16,3)/
     x 6.3573971d-02, 1.1915994d-02, 5.2247603d-06 /
      data fpppp( 9, 3,17,1),fpppp( 9, 3,17,2),fpppp( 9, 3,17,3)/
     x-2.1154689d-03,-7.0229010d-02,-4.0837242d-05 /
      data fpppp( 9, 3,18,1),fpppp( 9, 3,18,2),fpppp( 9, 3,18,3)/
     x 1.7839872d-02, 1.1820075d-01, 8.4725585d-05 /
      data fpppp( 9, 3,19,1),fpppp( 9, 3,19,2),fpppp( 9, 3,19,3)/
     x-9.7521873d-02,-8.0929745d-02,-6.5838417d-05 /
      data fpppp( 9, 3,20,1),fpppp( 9, 3,20,2),fpppp( 9, 3,20,3)/
     x-2.7871234d-02, 1.7358719d-02, 1.6405232d-05 /
      data fpppp( 9, 3,21,1),fpppp( 9, 3,21,2),fpppp( 9, 3,21,3)/
     x-2.7871234d-02, 5.7290458d-03, 7.4363532d-06 /
      data fpppp( 9, 3,22,1),fpppp( 9, 3,22,2),fpppp( 9, 3,22,3)/
     x-9.7521873d-02,-3.4411053d-02,-2.9962904d-05 /
      data fpppp( 9, 3,23,1),fpppp( 9, 3,23,2),fpppp( 9, 3,23,3)/
     x 1.7839872d-02,-5.6244345d-02,-4.9807591d-05 /
      data fpppp( 9, 4, 1,1),fpppp( 9, 4, 1,2),fpppp( 9, 4, 1,3)/
     x-5.6876756d-02,-1.2416700d-02, 5.5674510d-05 /
      data fpppp( 9, 4, 2,1),fpppp( 9, 4, 2,2),fpppp( 9, 4, 2,3)/
     x 3.0646820d-02,-6.7769562d-03, 3.5637530d-05 /
      data fpppp( 9, 4, 3,1),fpppp( 9, 4, 3,2),fpppp( 9, 4, 3,3)/
     x 1.6521994d-02, 4.6181117d-03,-2.5451268d-06 /
      data fpppp( 9, 4, 4,1),fpppp( 9, 4, 4,2),fpppp( 9, 4, 4,3)/
     x 1.6521994d-02, 5.8257809d-03,-1.0864151d-05 /
      data fpppp( 9, 4, 5,1),fpppp( 9, 4, 5,2),fpppp( 9, 4, 5,3)/
     x 3.0646820d-02,-1.1607633d-02, 6.8913625d-05 /
      data fpppp( 9, 4, 6,1),fpppp( 9, 4, 6,2),fpppp( 9, 4, 6,3)/
     x-5.6876756d-02, 5.6983370d-03,-6.9110847d-05 /
      data fpppp( 9, 4, 7,1),fpppp( 9, 4, 7,2),fpppp( 9, 4, 7,3)/
     x 8.4797318d-03,-2.4854049d-03, 1.4539395d-05 /
      data fpppp( 9, 4, 8,1),fpppp( 9, 4, 8,2),fpppp( 9, 4, 8,3)/
     x-1.4548665d-02, 5.9582396d-03,-1.2608202d-06 /
      data fpppp( 9, 4, 9,1),fpppp( 9, 4, 9,2),fpppp( 9, 4, 9,3)/
     x-1.2776512d-02,-2.7594941d-02,-3.2433147d-06 /
      data fpppp( 9, 4,10,1),fpppp( 9, 4,10,2),fpppp( 9, 4,10,3)/
     x 2.7143909d-02, 4.6943778d-02, 7.3417543d-06 /
      data fpppp( 9, 4,11,1),fpppp( 9, 4,11,2),fpppp( 9, 4,11,3)/
     x-2.0146229d-02,-3.6727853d-02,-5.0260736d-06 /
      data fpppp( 9, 4,12,1),fpppp( 9, 4,12,2),fpppp( 9, 4,12,3)/
     x-4.2606595d-03, 2.0319942d-02, 2.2206496d-06 /
      data fpppp( 9, 4,13,1),fpppp( 9, 4,13,2),fpppp( 9, 4,13,3)/
     x-3.1682114d-02,-2.2217090d-02,-3.0272490d-06 /
      data fpppp( 9, 4,14,1),fpppp( 9, 4,14,2),fpppp( 9, 4,14,3)/
     x 4.1821457d-03, 2.3390466d-02, 4.4076416d-06 /
      data fpppp( 9, 4,15,1),fpppp( 9, 4,15,2),fpppp( 9, 4,15,3)/
     x-1.4305557d-02,-1.2979322d-02,-8.9426357d-07 /
      data fpppp( 9, 4,16,1),fpppp( 9, 4,16,2),fpppp( 9, 4,16,3)/
     x-1.2811864d-02, 4.2964371d-03,-4.3869280d-06 /
      data fpppp( 9, 4,17,1),fpppp( 9, 4,17,2),fpppp( 9, 4,17,3)/
     x 6.2682017d-04,-6.1474094d-03, 1.8195589d-05 /
      data fpppp( 9, 4,18,1),fpppp( 9, 4,18,2),fpppp( 9, 4,18,3)/
     x-4.2390876d-02, 9.8600921d-03,-6.9029502d-05 /
      data fpppp( 9, 4,19,1),fpppp( 9, 4,19,2),fpppp( 9, 4,19,3)/
     x 2.5066028d-02,-1.4689925d-02, 6.7640500d-05 /
      data fpppp( 9, 4,20,1),fpppp( 9, 4,20,2),fpppp( 9, 4,20,3)/
     x 1.6937772d-02, 6.7955129d-03,-1.1000079d-05 /
      data fpppp( 9, 4,21,1),fpppp( 9, 4,21,2),fpppp( 9, 4,21,3)/
     x 1.6937772d-02, 5.1542207d-03,-2.7705404d-06 /
      data fpppp( 9, 4,22,1),fpppp( 9, 4,22,2),fpppp( 9, 4,22,3)/
     x 2.5066028d-02,-8.1247565d-03, 3.4722347d-05 /
      data fpppp( 9, 4,23,1),fpppp( 9, 4,23,2),fpppp( 9, 4,23,3)/
     x-4.2390876d-02,-1.4759290d-02, 5.4413571d-05 /
      data fpppp( 9, 5, 1,1),fpppp( 9, 5, 1,2),fpppp( 9, 5, 1,3)/
     x 2.5344545d-02,-7.8802019d-03,-3.6331850d-05 /
      data fpppp( 9, 5, 2,1),fpppp( 9, 5, 2,2),fpppp( 9, 5, 2,3)/
     x-8.7071949d-03,-4.7675534d-03,-2.2728531d-05 /
      data fpppp( 9, 5, 3,1),fpppp( 9, 5, 3,2),fpppp( 9, 5, 3,3)/
     x 4.6919715d-04, 9.9185847d-04, 4.0596613d-06 /
      data fpppp( 9, 5, 4,1),fpppp( 9, 5, 4,2),fpppp( 9, 5, 4,3)/
     x 4.6919715d-04, 2.5853195d-03, 8.1927716d-06 /
      data fpppp( 9, 5, 5,1),fpppp( 9, 5, 5,2),fpppp( 9, 5, 5,3)/
     x-8.7071949d-03,-1.1141398d-02,-3.9260972d-05 /
      data fpppp( 9, 5, 6,1),fpppp( 9, 5, 6,2),fpppp( 9, 5, 6,3)/
     x 2.5344545d-02, 1.6021714d-02, 2.5664804d-05 /
      data fpppp( 9, 5, 7,1),fpppp( 9, 5, 7,2),fpppp( 9, 5, 7,3)/
     x-4.0228833d-03,-1.0347688d-02, 2.4769071d-06 /
      data fpppp( 9, 5, 8,1),fpppp( 9, 5, 8,2),fpppp( 9, 5, 8,3)/
     x 4.2625302d-03, 2.7423913d-03,-4.1978319d-07 /
      data fpppp( 9, 5, 9,1),fpppp( 9, 5, 9,2),fpppp( 9, 5, 9,3)/
     x 4.2242489d-03,-7.4681694d-04, 3.1033381d-06 /
      data fpppp( 9, 5,10,1),fpppp( 9, 5,10,2),fpppp( 9, 5,10,3)/
     x-2.1432527d-02, 1.8474124d-04,-4.7710795d-06 /
      data fpppp( 9, 5,11,1),fpppp( 9, 5,11,2),fpppp( 9, 5,11,3)/
     x 9.3730326d-03,-5.9051486d-05, 3.0983676d-06 /
      data fpppp( 9, 5,12,1),fpppp( 9, 5,12,2),fpppp( 9, 5,12,3)/
     x 1.9262854d-03,-1.7795470d-05,-1.4065476d-06 /
      data fpppp( 9, 5,13,1),fpppp( 9, 5,13,2),fpppp( 9, 5,13,3)/
     x 1.2109930d-02, 5.5452494d-05, 2.0308369d-06 /
      data fpppp( 9, 5,14,1),fpppp( 9, 5,14,2),fpppp( 9, 5,14,3)/
     x-6.7612146d-03,-2.5638232d-04,-3.0444458d-06 /
      data fpppp( 9, 5,15,1),fpppp( 9, 5,15,2),fpppp( 9, 5,15,3)/
     x 4.6250374d-03, 8.9677068d-04, 1.6276657d-06 /
      data fpppp( 9, 5,16,1),fpppp( 9, 5,16,2),fpppp( 9, 5,16,3)/
     x 2.9509736d-03,-1.4429792d-03, 1.4939011d-06 /
      data fpppp( 9, 5,17,1),fpppp( 9, 5,17,2),fpppp( 9, 5,17,3)/
     x 5.2858598d-05, 7.6073475d-04,-3.2138809d-08 /
      data fpppp( 9, 5,18,1),fpppp( 9, 5,18,2),fpppp( 9, 5,18,3)/
     x 8.6224740d-03,-3.7988507d-04, 2.5083623d-05 /
      data fpppp( 9, 5,19,1),fpppp( 9, 5,19,2),fpppp( 9, 5,19,3)/
     x-6.5963818d-03,-8.8652254d-04,-3.6327308d-05 /
      data fpppp( 9, 5,20,1),fpppp( 9, 5,20,2),fpppp( 9, 5,20,3)/
     x-1.1503741d-02, 8.6053694d-04, 7.3771885d-06 /
      data fpppp( 9, 5,21,1),fpppp( 9, 5,21,2),fpppp( 9, 5,21,3)/
     x-1.1503741d-02, 7.9778700d-04, 3.4939750d-06 /
      data fpppp( 9, 5,22,1),fpppp( 9, 5,22,2),fpppp( 9, 5,22,3)/
     x-6.5963818d-03,-6.3552282d-04,-2.0794455d-05 /
      data fpppp( 9, 5,23,1),fpppp( 9, 5,23,2),fpppp( 9, 5,23,3)/
     x 8.6224740d-03,-1.3211340d-03,-3.3164579d-05 /
      data fpppp( 9, 6, 1,1),fpppp( 9, 6, 1,2),fpppp( 9, 6, 1,3)/
     x-1.1668847d-02, 9.2045745d-03, 1.4245937d-05 /
      data fpppp( 9, 6, 2,1),fpppp( 9, 6, 2,2),fpppp( 9, 6, 2,3)/
     x 1.4415013d-03, 4.9496023d-03, 8.4379622d-06 /
      data fpppp( 9, 6, 3,1),fpppp( 9, 6, 3,2),fpppp( 9, 6, 3,3)/
     x-1.4457931d-02,-3.7593403d-03,-3.1861974d-06 /
      data fpppp( 9, 6, 4,1),fpppp( 9, 6, 4,2),fpppp( 9, 6, 4,3)/
     x-1.4457931d-02,-4.4748366d-03,-4.6238230d-06 /
      data fpppp( 9, 6, 5,1),fpppp( 9, 6, 5,2),fpppp( 9, 6, 5,3)/
     x 1.4415013d-03, 7.8115875d-03, 1.4188464d-05 /
      data fpppp( 9, 6, 6,1),fpppp( 9, 6, 6,2),fpppp( 9, 6, 6,3)/
     x-1.1668847d-02,-1.5278699d-03,-7.3184462d-06 /
      data fpppp( 9, 6, 7,1),fpppp( 9, 6, 7,2),fpppp( 9, 6, 7,3)/
     x 1.5501795d-03, 3.2788766d-04,-9.6515168d-08 /
      data fpppp( 9, 6, 8,1),fpppp( 9, 6, 8,2),fpppp( 9, 6, 8,3)/
     x-8.3174799d-04,-1.2640358d-04,-7.4004086d-08 /
      data fpppp( 9, 6, 9,1),fpppp( 9, 6, 9,2),fpppp( 9, 6, 9,3)/
     x-8.7861943d-04, 1.6061975d-05,-8.7487788d-07 /
      data fpppp( 9, 6,10,1),fpppp( 9, 6,10,2),fpppp( 9, 6,10,3)/
     x 5.9648898d-03,-1.5694544d-05, 1.2405219d-06 /
      data fpppp( 9, 6,11,1),fpppp( 9, 6,11,2),fpppp( 9, 6,11,3)/
     x-2.3019795d-03,-1.1008939d-05,-8.3583005d-07 /
      data fpppp( 9, 6,12,1),fpppp( 9, 6,12,2),fpppp( 9, 6,12,3)/
     x-2.9760626d-04, 6.6265290d-06, 3.7807490d-07 /
      data fpppp( 9, 6,13,1),fpppp( 9, 6,13,2),fpppp( 9, 6,13,3)/
     x-3.0322057d-03,-2.4310671d-05,-5.4380161d-07 /
      data fpppp( 9, 6,14,1),fpppp( 9, 6,14,2),fpppp( 9, 6,14,3)/
     x 2.0469158d-03, 2.4108773d-05, 8.0145906d-07 /
      data fpppp( 9, 6,15,1),fpppp( 9, 6,15,2),fpppp( 9, 6,15,3)/
     x-1.0183350d-03,-5.0934276d-05,-4.6856620d-07 /
      data fpppp( 9, 6,16,1),fpppp( 9, 6,16,2),fpppp( 9, 6,16,3)/
     x 2.2181649d-05, 3.1355363d-05,-4.4628575d-07 /
      data fpppp( 9, 6,17,1),fpppp( 9, 6,17,2),fpppp( 9, 6,17,3)/
     x 2.9427880d-04,-8.1960510d-05, 2.6533035d-07 /
      data fpppp( 9, 6,18,1),fpppp( 9, 6,18,2),fpppp( 9, 6,18,3)/
     x-1.9981741d-03, 1.9736038d-05,-6.2321547d-06 /
      data fpppp( 9, 6,19,1),fpppp( 9, 6,19,2),fpppp( 9, 6,19,3)/
     x 1.9168180d-03,-3.6251391d-04, 1.0091232d-05 /
      data fpppp( 9, 6,20,1),fpppp( 9, 6,20,2),fpppp( 9, 6,20,3)/
     x 3.0661251d-03, 2.9867948d-04,-2.6469435d-06 /
      data fpppp( 9, 6,21,1),fpppp( 9, 6,21,2),fpppp( 9, 6,21,3)/
     x 3.0661251d-03, 2.6588801d-04,-1.5899244d-06 /
      data fpppp( 9, 6,22,1),fpppp( 9, 6,22,2),fpppp( 9, 6,22,3)/
     x 1.9168180d-03,-2.3134805d-04, 5.8631560d-06 /
      data fpppp( 9, 6,23,1),fpppp( 9, 6,23,2),fpppp( 9, 6,23,3)/
     x-1.9981741d-03,-4.7213594d-04, 9.6231319d-06 /
      data fpppp( 9, 7, 1,1),fpppp( 9, 7, 1,2),fpppp( 9, 7, 1,3)/
     x 1.3170242d-03, 2.6821612d-04,-3.5101540d-06 /
      data fpppp( 9, 7, 2,1),fpppp( 9, 7, 2,2),fpppp( 9, 7, 2,3)/
     x-2.1283425d-05, 1.4337586d-04,-2.2451044d-06 /
      data fpppp( 9, 7, 3,1),fpppp( 9, 7, 3,2),fpppp( 9, 7, 3,3)/
     x-4.2659208d-03,-1.1319516d-04, 2.0005147d-07 /
      data fpppp( 9, 7, 4,1),fpppp( 9, 7, 4,2),fpppp( 9, 7, 4,3)/
     x-4.2659208d-03,-1.3234686d-04, 6.6496435d-07 /
      data fpppp( 9, 7, 5,1),fpppp( 9, 7, 5,2),fpppp( 9, 7, 5,3)/
     x-2.1283425d-05, 2.1998266d-04,-4.1047560d-06 /
      data fpppp( 9, 7, 6,1),fpppp( 9, 7, 6,2),fpppp( 9, 7, 6,3)/
     x 1.3170242d-03,-1.9059384d-05, 3.4635392d-06 /
      data fpppp( 9, 7, 7,1),fpppp( 9, 7, 7,2),fpppp( 9, 7, 7,3)/
     x-5.6471911d-04,-7.2439005d-06,-4.9072924d-07 /
      data fpppp( 9, 7, 8,1),fpppp( 9, 7, 8,2),fpppp( 9, 7, 8,3)/
     x 3.0876103d-04,-6.5139880d-06, 1.8261242d-07 /
      data fpppp( 9, 7, 9,1),fpppp( 9, 7, 9,2),fpppp( 9, 7, 9,3)/
     x 3.3023461d-04,-5.6733012d-07, 2.2428471d-07 /
      data fpppp( 9, 7,10,1),fpppp( 9, 7,10,2),fpppp( 9, 7,10,3)/
     x-1.5001256d-03, 4.4124184d-06,-3.0226623d-07 /
      data fpppp( 9, 7,11,1),fpppp( 9, 7,11,2),fpppp( 9, 7,11,3)/
     x 7.1799639d-04, 3.6741353d-06, 2.3979298d-07 /
      data fpppp( 9, 7,12,1),fpppp( 9, 7,12,2),fpppp( 9, 7,12,3)/
     x 1.6186840d-04, 2.3574108d-06,-8.4735697d-08 /
      data fpppp( 9, 7,13,1),fpppp( 9, 7,13,2),fpppp( 9, 7,13,3)/
     x 8.9174112d-04, 4.5519056d-06, 1.6878405d-07 /
      data fpppp( 9, 7,14,1),fpppp( 9, 7,14,2),fpppp( 9, 7,14,3)/
     x-4.8341749d-04,-6.1492356d-06,-1.8034480d-07 /
      data fpppp( 9, 7,15,1),fpppp( 9, 7,15,2),fpppp( 9, 7,15,3)/
     x 3.3673772d-04, 1.0953260d-05, 1.7632204d-07 /
      data fpppp( 9, 7,16,1),fpppp( 9, 7,16,2),fpppp( 9, 7,16,3)/
     x 1.3787426d-05,-2.2828815d-06, 1.6722460d-07 /
      data fpppp( 9, 7,17,1),fpppp( 9, 7,17,2),fpppp( 9, 7,17,3)/
     x-9.8773329d-05, 1.0303490d-05, 6.6003482d-08 /
      data fpppp( 9, 7,18,1),fpppp( 9, 7,18,2),fpppp( 9, 7,18,3)/
     x 3.9971698d-04, 8.0742132d-06, 1.6935088d-06 /
      data fpppp( 9, 7,19,1),fpppp( 9, 7,19,2),fpppp( 9, 7,19,3)/
     x-9.1159293d-04, 1.0317559d-04,-1.6019393d-06 /
      data fpppp( 9, 7,20,1),fpppp( 9, 7,20,2),fpppp( 9, 7,20,3)/
     x-1.9440210d-03,-9.0980261d-05,-2.6517524d-07 /
      data fpppp( 9, 7,21,1),fpppp( 9, 7,21,2),fpppp( 9, 7,21,3)/
     x-1.9440210d-03,-8.2165035d-05,-4.5121660d-07 /
      data fpppp( 9, 7,22,1),fpppp( 9, 7,22,2),fpppp( 9, 7,22,3)/
     x-9.1159293d-04, 6.7914685d-05,-8.5777385d-07 /
      data fpppp( 9, 7,23,1),fpppp( 9, 7,23,2),fpppp( 9, 7,23,3)/
     x 3.9971698d-04, 1.4030261d-04,-1.0971116d-06 /
      data fpppp( 9, 8, 1,1),fpppp( 9, 8, 1,2),fpppp( 9, 8, 1,3)/
     x 6.2100154d-03,-1.2545758d-02,-1.1421405d-06 /
      data fpppp( 9, 8, 2,1),fpppp( 9, 8, 2,2),fpppp( 9, 8, 2,3)/
     x-8.9241360d-04,-6.7804288d-03,-3.0406555d-07 /
      data fpppp( 9, 8, 3,1),fpppp( 9, 8, 3,2),fpppp( 9, 8, 3,3)/
     x 2.1750884d-02, 4.9915061d-03, 1.6487353d-06 /
      data fpppp( 9, 8, 4,1),fpppp( 9, 8, 4,2),fpppp( 9, 8, 4,3)/
     x 2.1750884d-02, 6.0106058d-03, 1.3741148d-06 /
      data fpppp( 9, 8, 5,1),fpppp( 9, 8, 5,2),fpppp( 9, 8, 5,3)/
     x-8.9241360d-04,-1.0856827d-02, 7.9441650d-07 /
      data fpppp( 9, 8, 6,1),fpppp( 9, 8, 6,2),fpppp( 9, 8, 6,3)/
     x 6.2100154d-03, 2.7407370d-03,-5.2614482d-06 /
      data fpppp( 9, 8, 7,1),fpppp( 9, 8, 7,2),fpppp( 9, 8, 7,3)/
     x 9.6874252d-04,-7.5564455d-04, 2.4161248d-06 /
      data fpppp( 9, 8, 8,1),fpppp( 9, 8, 8,2),fpppp( 9, 8, 8,3)/
     x-7.2164849d-06, 2.0071997d-04,-3.1511866d-07 /
      data fpppp( 9, 8, 9,1),fpppp( 9, 8, 9,2),fpppp( 9, 8, 9,3)/
     x-5.8528642d-06,-4.8952647d-05, 1.3853868d-07 /
      data fpppp( 9, 8,10,1),fpppp( 9, 8,10,2),fpppp( 9, 8,10,3)/
     x 4.8237870d-04, 3.4112338d-05, 9.6417484d-08 /
      data fpppp( 9, 8,11,1),fpppp( 9, 8,11,2),fpppp( 9, 8,11,3)/
     x-1.2806682d-04,-3.3850960d-06,-2.4159484d-08 /
      data fpppp( 9, 8,12,1),fpppp( 9, 8,12,2),fpppp( 9, 8,12,3)/
     x 2.9094665d-05, 1.7314050d-05, 5.2223830d-08 /
      data fpppp( 9, 8,13,1),fpppp( 9, 8,13,2),fpppp( 9, 8,13,3)/
     x-1.8518128d-04, 1.1846469d-05,-1.1660742d-08 /
      data fpppp( 9, 8,14,1),fpppp( 9, 8,14,2),fpppp( 9, 8,14,3)/
     x 1.7091882d-04,-5.3892823d-06, 8.8588829d-08 /
      data fpppp( 9, 8,15,1),fpppp( 9, 8,15,2),fpppp( 9, 8,15,3)/
     x-6.5296764d-05, 1.4904362d-05, 1.3649496d-08 /
      data fpppp( 9, 8,16,1),fpppp( 9, 8,16,2),fpppp( 9, 8,16,3)/
     x 2.7682555d-06, 2.4325231d-06, 3.7512867d-08 /
      data fpppp( 9, 8,17,1),fpppp( 9, 8,17,2),fpppp( 9, 8,17,3)/
     x 5.6095008d-06, 1.5004274d-05, 9.1742171d-08 /
      data fpppp( 9, 8,18,1),fpppp( 9, 8,18,2),fpppp( 9, 8,18,3)/
     x-1.6461891d-04, 1.4896155d-05,-3.5379176d-07 /
      data fpppp( 9, 8,19,1),fpppp( 9, 8,19,2),fpppp( 9, 8,19,3)/
     x 1.5584102d-04, 4.1425710d-05, 5.6736350d-07 /
      data fpppp( 9, 8,20,1),fpppp( 9, 8,20,2),fpppp( 9, 8,20,3)/
     x 4.4874236d-04,-6.7082370d-05,-3.3623940d-07 /
      data fpppp( 9, 8,21,1),fpppp( 9, 8,21,2),fpppp( 9, 8,21,3)/
     x 4.4874236d-04,-6.3419395d-05,-2.7249716d-07 /
      data fpppp( 9, 8,22,1),fpppp( 9, 8,22,2),fpppp( 9, 8,22,3)/
     x 1.5584102d-04, 2.6773813d-05, 3.1239452d-07 /
      data fpppp( 9, 8,23,1),fpppp( 9, 8,23,2),fpppp( 9, 8,23,3)/
     x-1.6461891d-04, 6.9840770d-05, 6.0234190d-07 /
      data fpppp( 9, 9, 1,1),fpppp( 9, 9, 1,2),fpppp( 9, 9, 1,3)/
     x-1.2653203d-02, 4.9161211d-03, 4.0241018d-06 /
      data fpppp( 9, 9, 2,1),fpppp( 9, 9, 2,2),fpppp( 9, 9, 2,3)/
     x 8.5921020d-04, 3.1212616d-03, 2.0457749d-06 /
      data fpppp( 9, 9, 3,1),fpppp( 9, 9, 3,2),fpppp( 9, 9, 3,3)/
     x-1.4341531d-02,-1.1820344d-04,-2.3030517d-06 /
      data fpppp( 9, 9, 4,1),fpppp( 9, 9, 4,2),fpppp( 9, 9, 4,3)/
     x-1.4341531d-02,-1.1798628d-03,-2.1113310d-06 /
      data fpppp( 9, 9, 5,1),fpppp( 9, 9, 5,2),fpppp( 9, 9, 5,3)/
     x 8.5921020d-04, 7.3678991d-03, 1.2788920d-06 /
      data fpppp( 9, 9, 6,1),fpppp( 9, 9, 6,2),fpppp( 9, 9, 6,3)/
     x-1.2653203d-02,-1.1008769d-02, 6.8999127d-06 /
      data fpppp( 9, 9, 7,1),fpppp( 9, 9, 7,2),fpppp( 9, 9, 7,3)/
     x-2.5660461d-03, 6.2363399d-03,-5.6340890d-06 /
      data fpppp( 9, 9, 8,1),fpppp( 9, 9, 8,2),fpppp( 9, 9, 8,3)/
     x 1.5607011d-04,-1.5928448d-03, 8.7135969d-07 /
      data fpppp( 9, 9, 9,1),fpppp( 9, 9, 9,2),fpppp( 9, 9, 9,3)/
     x 9.7755001d-05, 4.4232459d-04,-2.2907014d-07 /
      data fpppp( 9, 9,10,1),fpppp( 9, 9,10,2),fpppp( 9, 9,10,3)/
     x-6.1568859d-05,-9.9410034d-05, 5.7181644d-08 /
      data fpppp( 9, 9,11,1),fpppp( 9, 9,11,2),fpppp( 9, 9,11,3)/
     x 8.3737044d-05, 6.1186018d-05, 1.7734285d-08 /
      data fpppp( 9, 9,12,1),fpppp( 9, 9,12,2),fpppp( 9, 9,12,3)/
     x 2.0853173d-05,-3.0401966d-06, 1.6177715d-08 /
      data fpppp( 9, 9,13,1),fpppp( 9, 9,13,2),fpppp( 9, 9,13,3)/
     x 9.2552625d-05, 2.3588562d-05, 3.0780239d-08 /
      data fpppp( 9, 9,14,1),fpppp( 9, 9,14,2),fpppp( 9, 9,14,3)/
     x-2.6784461d-05,-1.6722665d-06, 1.1406864d-08 /
      data fpppp( 9, 9,15,1),fpppp( 9, 9,15,2),fpppp( 9, 9,15,3)/
     x 3.8737813d-05, 1.3490130d-05, 3.4409144d-08 /
      data fpppp( 9, 9,16,1),fpppp( 9, 9,16,2),fpppp( 9, 9,16,3)/
     x 7.3674252d-06, 2.7764478d-06, 3.1869885d-08 /
      data fpppp( 9, 9,17,1),fpppp( 9, 9,17,2),fpppp( 9, 9,17,3)/
     x-3.6509488d-06, 1.2402772d-05, 1.1474850d-08 /
      data fpppp( 9, 9,18,1),fpppp( 9, 9,18,2),fpppp( 9, 9,18,3)/
     x 2.9250829d-05, 1.7991303d-05, 1.0896425d-07 /
      data fpppp( 9, 9,19,1),fpppp( 9, 9,19,2),fpppp( 9, 9,19,3)/
     x-5.7430562d-05, 3.5255270d-05,-1.6818565d-07 /
      data fpppp( 9, 9,20,1),fpppp( 9, 9,20,2),fpppp( 9, 9,20,3)/
     x-1.1271662d-04,-6.1732623d-05,-6.8529334d-08 /
      data fpppp( 9, 9,21,1),fpppp( 9, 9,21,2),fpppp( 9, 9,21,3)/
     x-1.1271662d-04,-5.8764665d-05,-8.3892760d-08 /
      data fpppp( 9, 9,22,1),fpppp( 9, 9,22,2),fpppp( 9, 9,22,3)/
     x-5.7430562d-05, 2.3383438d-05,-1.0673195d-07 /
      data fpppp( 9, 9,23,1),fpppp( 9, 9,23,2),fpppp( 9, 9,23,3)/
     x 2.9250829d-05, 6.2510675d-05,-1.2148715d-07 /
      data fpppp( 9,10, 1,1),fpppp( 9,10, 1,2),fpppp( 9,10, 1,3)/
     x 9.4944535d-03,-5.9375136d-04,-2.4150027d-06 /
      data fpppp( 9,10, 2,1),fpppp( 9,10, 2,2),fpppp( 9,10, 2,3)/
     x 8.3469803d-07,-4.1459003d-04,-1.4832120d-06 /
      data fpppp( 9,10, 3,1),fpppp( 9,10, 3,2),fpppp( 9,10, 3,3)/
     x 4.0250353d-03,-9.5061877d-05, 5.3519944d-07 /
      data fpppp( 9,10, 4,1),fpppp( 9,10, 4,2),fpppp( 9,10, 4,3)/
     x 4.0250353d-03, 1.7618856d-05, 4.9719427d-07 /
      data fpppp( 9,10, 5,1),fpppp( 9,10, 5,2),fpppp( 9,10, 5,3)/
     x 8.3469803d-07,-8.6531296d-04,-1.3311914d-06 /
      data fpppp( 9,10, 6,1),fpppp( 9,10, 6,2),fpppp( 9,10, 6,3)/
     x 9.4944535d-03, 1.0964596d-03,-2.9850803d-06 /
      data fpppp( 9,10, 7,1),fpppp( 9,10, 7,2),fpppp( 9,10, 7,3)/
     x 1.8939545d-03, 1.2277797d-03, 5.7052682d-06 /
      data fpppp( 9,10, 8,1),fpppp( 9,10, 8,2),fpppp( 9,10, 8,3)/
     x-1.0865102d-03,-1.8137797d-03,-1.9468310d-06 /
      data fpppp( 9,10, 9,1),fpppp( 9,10, 9,2),fpppp( 9,10, 9,3)/
     x-2.0758375d-04, 3.5861510d-04,-1.3811469d-08 /
      data fpppp( 9,10,10,1),fpppp( 9,10,10,2),fpppp( 9,10,10,3)/
     x-5.3305514d-07,-9.4658200d-05,-1.4245973d-07 /
      data fpppp( 9,10,11,1),fpppp( 9,10,11,2),fpppp( 9,10,11,3)/
     x 6.0383880d-06, 6.7009763d-05,-3.6163282d-10 /
      data fpppp( 9,10,12,1),fpppp( 9,10,12,2),fpppp( 9,10,12,3)/
     x 3.1967250d-05, 2.7526141d-05, 7.1689399d-10 /
      data fpppp( 9,10,13,1),fpppp( 9,10,13,2),fpppp( 9,10,13,3)/
     x-1.1813056d-05,-1.2417616d-05, 8.3574272d-09 /
      data fpppp( 9,10,14,1),fpppp( 9,10,14,2),fpppp( 9,10,14,3)/
     x 3.3377837d-05, 3.7318336d-05, 1.5501562d-08 /
      data fpppp( 9,10,15,1),fpppp( 9,10,15,2),fpppp( 9,10,15,3)/
     x 2.8446930d-06,-9.8724581d-06, 1.1304902d-08 /
      data fpppp( 9,10,16,1),fpppp( 9,10,16,2),fpppp( 9,10,16,3)/
     x 1.1202397d-05, 1.1241017d-05, 5.1258504d-09 /
      data fpppp( 9,10,17,1),fpppp( 9,10,17,2),fpppp( 9,10,17,3)/
     x 9.3244613d-06, 5.2156892d-06,-2.9455745d-09 /
      data fpppp( 9,10,18,1),fpppp( 9,10,18,2),fpppp( 9,10,18,3)/
     x 2.0424677d-06, 2.8515024d-05,-4.3967493d-08 /
      data fpppp( 9,10,19,1),fpppp( 9,10,19,2),fpppp( 9,10,19,3)/
     x 2.5836602d-05, 4.7387910d-05, 2.2772106d-08 /
      data fpppp( 9,10,20,1),fpppp( 9,10,20,2),fpppp( 9,10,20,3)/
     x 2.1270882d-05,-6.7360889d-05,-4.1592979d-08 /
      data fpppp( 9,10,21,1),fpppp( 9,10,21,2),fpppp( 9,10,21,3)/
     x 2.1270882d-05,-6.3923121d-05,-3.6999151d-08 /
      data fpppp( 9,10,22,1),fpppp( 9,10,22,2),fpppp( 9,10,22,3)/
     x 2.5836602d-05, 3.3636835d-05, 4.3967948d-09 /
      data fpppp( 9,10,23,1),fpppp( 9,10,23,2),fpppp( 9,10,23,3)/
     x 2.0424677d-06, 8.0081553d-05, 2.4939924d-08 /
      data fpppp( 9,11, 1,1),fpppp( 9,11, 1,2),fpppp( 9,11, 1,3)/
     x-2.6883718d-03, 7.7048957d-05, 1.1199697d-06 /
      data fpppp( 9,11, 2,1),fpppp( 9,11, 2,2),fpppp( 9,11, 2,3)/
     x 4.7864157d-04,-3.7918631d-05, 5.3483193d-07 /
      data fpppp( 9,11, 3,1),fpppp( 9,11, 3,2),fpppp( 9,11, 3,3)/
     x-8.7330878d-05,-2.7754691d-04,-6.9476133d-07 /
      data fpppp( 9,11, 4,1),fpppp( 9,11, 4,2),fpppp( 9,11, 4,3)/
     x-8.7330878d-05,-2.8932587d-04,-7.3723961d-07 /
      data fpppp( 9,11, 5,1),fpppp( 9,11, 5,2),fpppp( 9,11, 5,3)/
     x 4.7864157d-04, 9.1971993d-06, 7.0474507d-07 /
      data fpppp( 9,11, 6,1),fpppp( 9,11, 6,2),fpppp( 9,11, 6,3)/
     x-2.6883718d-03,-9.9635406d-05, 4.8279537d-07 /
      data fpppp( 9,11, 7,1),fpppp( 9,11, 7,2),fpppp( 9,11, 7,3)/
     x-3.4621048d-05, 1.3606556d-03,-1.6256038d-06 /
      data fpppp( 9,11, 8,1),fpppp( 9,11, 8,2),fpppp( 9,11, 8,3)/
     x 5.2065581d-04,-2.8251129d-04, 1.8953372d-06 /
      data fpppp( 9,11, 9,1),fpppp( 9,11, 9,2),fpppp( 9,11, 9,3)/
     x-3.2997672d-04,-6.2412001d-04,-2.3635476d-07 /
      data fpppp( 9,11,10,1),fpppp( 9,11,10,2),fpppp( 9,11,10,3)/
     x-1.4489122d-04, 1.1990723d-06,-4.7352298d-08 /
      data fpppp( 9,11,11,1),fpppp( 9,11,11,2),fpppp( 9,11,11,3)/
     x-6.1563438d-05, 8.3924315d-06,-4.6298693d-08 /
      data fpppp( 9,11,12,1),fpppp( 9,11,12,2),fpppp( 9,11,12,3)/
     x-4.2514374d-05, 2.9712540d-05,-3.5519632d-09 /
      data fpppp( 9,11,13,1),fpppp( 9,11,13,2),fpppp( 9,11,13,3)/
     x-7.6700489d-06, 1.0789559d-06, 2.1076795d-09 /
      data fpppp( 9,11,14,1),fpppp( 9,11,14,2),fpppp( 9,11,14,3)/
     x-1.1246714d-05, 3.3105147d-05, 3.6630489d-09 /
      data fpppp( 9,11,15,1),fpppp( 9,11,15,2),fpppp( 9,11,15,3)/
     x 5.9518938d-06,-7.1841466d-06, 1.8689737d-09 /
      data fpppp( 9,11,16,1),fpppp( 9,11,16,2),fpppp( 9,11,16,3)/
     x 1.2427339d-05, 6.6533468d-06,-2.5603564d-09 /
      data fpppp( 9,11,17,1),fpppp( 9,11,17,2),fpppp( 9,11,17,3)/
     x 2.2795356d-05, 7.4886941d-06,-6.1219995d-09 /
      data fpppp( 9,11,18,1),fpppp( 9,11,18,2),fpppp( 9,11,18,3)/
     x 3.2232329d-05, 3.5623511d-05, 1.7705776d-09 /
      data fpppp( 9,11,19,1),fpppp( 9,11,19,2),fpppp( 9,11,19,3)/
     x 3.5864119d-05, 6.2637556d-05,-3.4652758d-08 /
      data fpppp( 9,11,20,1),fpppp( 9,11,20,2),fpppp( 9,11,20,3)/
     x 1.2779513d-04,-7.5786814d-05, 1.8363418d-09 /
      data fpppp( 9,11,21,1),fpppp( 9,11,21,2),fpppp( 9,11,21,3)/
     x 1.2779513d-04,-7.1438140d-05,-7.0091685d-10 /
      data fpppp( 9,11,22,1),fpppp( 9,11,22,2),fpppp( 9,11,22,3)/
     x 3.5864119d-05, 4.5242856d-05,-2.4503724d-08 /
      data fpppp( 9,11,23,1),fpppp( 9,11,23,2),fpppp( 9,11,23,3)/
     x 3.2232329d-05, 1.0085363d-04,-3.6288302d-08 /
      data fpppp( 9,12, 1,1),fpppp( 9,12, 1,2),fpppp( 9,12, 1,3)/
     x 9.0642115d-04, 8.9933838d-04, 2.7252129d-08 /
      data fpppp( 9,12, 2,1),fpppp( 9,12, 2,2),fpppp( 9,12, 2,3)/
     x 5.2635389d-04, 3.4692988d-04,-8.5431785d-08 /
      data fpppp( 9,12, 3,1),fpppp( 9,12, 3,2),fpppp( 9,12, 3,3)/
     x 1.3917858d-03,-8.1285412d-04,-3.2525771d-07 /
      data fpppp( 9,12, 4,1),fpppp( 9,12, 4,2),fpppp( 9,12, 4,3)/
     x 1.3917858d-03,-8.5476402d-04,-3.2812702d-07 /
      data fpppp( 9,12, 5,1),fpppp( 9,12, 5,2),fpppp( 9,12, 5,3)/
     x 5.2635389d-04, 5.1456946d-04,-7.3954533d-08 /
      data fpppp( 9,12, 6,1),fpppp( 9,12, 6,2),fpppp( 9,12, 6,3)/
     x 9.0642115d-04, 2.7068994d-04,-1.5787565d-08 /
      data fpppp( 9,12, 7,1),fpppp( 9,12, 7,2),fpppp( 9,12, 7,3)/
     x 5.8150779d-05, 5.5758865d-04, 3.2053797d-07 /
      data fpppp( 9,12, 8,1),fpppp( 9,12, 8,2),fpppp( 9,12, 8,3)/
     x 2.2435565d-04, 6.6672192d-04,-1.4955490d-07 /
      data fpppp( 9,12, 9,1),fpppp( 9,12, 9,2),fpppp( 9,12, 9,3)/
     x 2.2067735d-05,-4.7551077d-04, 4.3394888d-07 /
      data fpppp( 9,12,10,1),fpppp( 9,12,10,2),fpppp( 9,12,10,3)/
     x-1.0722331d-04,-3.0229260d-04,-1.1407251d-08 /
      data fpppp( 9,12,11,1),fpppp( 9,12,11,2),fpppp( 9,12,11,3)/
     x-5.5732630d-05,-1.0901883d-05, 6.7427155d-09 /
      data fpppp( 9,12,12,1),fpppp( 9,12,12,2),fpppp( 9,12,12,3)/
     x-2.3991492d-05, 1.6448830d-05,-7.2581198d-09 /
      data fpppp( 9,12,13,1),fpppp( 9,12,13,2),fpppp( 9,12,13,3)/
     x-1.9672683d-05, 3.1024968d-06, 5.8185580d-10 /
      data fpppp( 9,12,14,1),fpppp( 9,12,14,2),fpppp( 9,12,14,3)/
     x-8.8065002d-06, 3.2068803d-05,-1.4846839d-09 /
      data fpppp( 9,12,15,1),fpppp( 9,12,15,2),fpppp( 9,12,15,3)/
     x-5.5407398d-06,-5.9535577d-06,-4.3070939d-09 /
      data fpppp( 9,12,16,1),fpppp( 9,12,16,2),fpppp( 9,12,16,3)/
     x 7.7071166d-07, 3.7636116d-06,-3.6883115d-09 /
      data fpppp( 9,12,17,1),fpppp( 9,12,17,2),fpppp( 9,12,17,3)/
     x 9.4656513d-06, 1.2145817d-05, 2.0954158d-09 /
      data fpppp( 9,12,18,1),fpppp( 9,12,18,2),fpppp( 9,12,18,3)/
     x 1.8060485d-05, 2.2269249d-05,-3.7983041d-09 /
      data fpppp( 9,12,19,1),fpppp( 9,12,19,2),fpppp( 9,12,19,3)/
     x 7.8475268d-06, 1.4640169d-04,-1.3248970d-08 /
      data fpppp( 9,12,20,1),fpppp( 9,12,20,2),fpppp( 9,12,20,3)/
     x-1.1399505d-04,-1.2460052d-04, 8.0826867d-09 /
      data fpppp( 9,12,21,1),fpppp( 9,12,21,2),fpppp( 9,12,21,3)/
     x-1.1399505d-04,-1.1270494d-04, 7.1615425d-09 /
      data fpppp( 9,12,22,1),fpppp( 9,12,22,2),fpppp( 9,12,22,3)/
     x 7.8475268d-06, 9.8819382d-05,-9.5643929d-09 /
      data fpppp( 9,12,23,1),fpppp( 9,12,23,2),fpppp( 9,12,23,3)/
     x 1.8060485d-05, 2.0070289d-04,-1.7615468d-08 /
      data fpppp( 9,13, 1,1),fpppp( 9,13, 1,2),fpppp( 9,13, 1,3)/
     x-3.8014184d-04, 1.9128421d-03,-1.3585143d-06 /
      data fpppp( 9,13, 2,1),fpppp( 9,13, 2,2),fpppp( 9,13, 2,3)/
     x-8.7749149d-04, 8.0114643d-04,-6.4413245d-07 /
      data fpppp( 9,13, 3,1),fpppp( 9,13, 3,2),fpppp( 9,13, 3,3)/
     x-2.3399638d-03,-1.5329596d-03, 8.5431897d-07 /
      data fpppp( 9,13, 4,1),fpppp( 9,13, 4,2),fpppp( 9,13, 4,3)/
     x-2.3399638d-03,-1.6171327d-03, 9.1096108d-07 /
      data fpppp( 9,13, 5,1),fpppp( 9,13, 5,2),fpppp( 9,13, 5,3)/
     x-8.7749149d-04, 1.1378387d-03,-8.7070088d-07 /
      data fpppp( 9,13, 6,1),fpppp( 9,13, 6,2),fpppp( 9,13, 6,3)/
     x-3.8014184d-04, 6.5024589d-04,-5.0888274d-07 /
      data fpppp( 9,13, 7,1),fpppp( 9,13, 7,2),fpppp( 9,13, 7,3)/
     x 1.6515460d-05, 4.0642350d-04,-3.3686361d-07 /
      data fpppp( 9,13, 8,1),fpppp( 9,13, 8,2),fpppp( 9,13, 8,3)/
     x 6.7760234d-05, 6.1313205d-04, 6.0062266d-08 /
      data fpppp( 9,13, 9,1),fpppp( 9,13, 9,2),fpppp( 9,13, 9,3)/
     x 1.2489756d-04, 1.5850106d-04, 1.6771546d-07 /
      data fpppp( 9,13,10,1),fpppp( 9,13,10,2),fpppp( 9,13,10,3)/
     x-8.9998709d-05,-4.8889967d-04, 9.9856554d-08 /
      data fpppp( 9,13,11,1),fpppp( 9,13,11,2),fpppp( 9,13,11,3)/
     x-4.6497089d-05,-1.0337011d-04, 1.6670586d-08 /
      data fpppp( 9,13,12,1),fpppp( 9,13,12,2),fpppp( 9,13,12,3)/
     x-3.7808237d-05, 9.0651547d-07, 1.7618165d-08 /
      data fpppp( 9,13,13,1),fpppp( 9,13,13,2),fpppp( 9,13,13,3)/
     x-2.1021257d-05, 1.6184419d-06,-1.3127495d-09 /
      data fpppp( 9,13,14,1),fpppp( 9,13,14,2),fpppp( 9,13,14,3)/
     x-1.3238478d-05, 2.6105751d-05,-2.4474489d-09 /
      data fpppp( 9,13,15,1),fpppp( 9,13,15,2),fpppp( 9,13,15,3)/
     x-1.7821260d-05,-3.5005203d-06,-4.1504084d-09 /
      data fpppp( 9,13,16,1),fpppp( 9,13,16,2),fpppp( 9,13,16,3)/
     x-1.9813021d-05, 4.9614116d-06,-7.2402097d-10 /
      data fpppp( 9,13,17,1),fpppp( 9,13,17,2),fpppp( 9,13,17,3)/
     x-2.2739950d-05, 1.1721708d-05, 3.7206399d-09 /
      data fpppp( 9,13,18,1),fpppp( 9,13,18,2),fpppp( 9,13,18,3)/
     x-3.2358317d-05, 1.7129472d-05, 5.0190476d-09 /
      data fpppp( 9,13,19,1),fpppp( 9,13,19,2),fpppp( 9,13,19,3)/
     x-5.3092741d-05, 1.1023670d-04, 1.3402699d-08 /
      data fpppp( 9,13,20,1),fpppp( 9,13,20,2),fpppp( 9,13,20,3)/
     x-1.1264727d-04,-9.8951622d-05,-4.5397418d-09 /
      data fpppp( 9,13,21,1),fpppp( 9,13,21,2),fpppp( 9,13,21,3)/
     x-1.1264727d-04,-8.9898056d-05,-3.7443245d-09 /
      data fpppp( 9,13,22,1),fpppp( 9,13,22,2),fpppp( 9,13,22,3)/
     x-5.3092741d-05, 7.4022439d-05, 1.0221030d-08 /
      data fpppp( 9,13,23,1),fpppp( 9,13,23,2),fpppp( 9,13,23,3)/
     x-3.2358317d-05, 1.5293295d-04, 1.6950307d-08 /
      data fpppp( 9,14, 1,1),fpppp( 9,14, 1,2),fpppp( 9,14, 1,3)/
     x-4.4965026d-04, 1.6515756d-03,-7.9918266d-07 /
      data fpppp( 9,14, 2,1),fpppp( 9,14, 2,2),fpppp( 9,14, 2,3)/
     x-1.3363597d-03, 6.5843918d-04,-3.1234264d-07 /
      data fpppp( 9,14, 3,1),fpppp( 9,14, 3,2),fpppp( 9,14, 3,3)/
     x-2.4485518d-03,-1.4310742d-03, 7.2134658d-07 /
      data fpppp( 9,14, 4,1),fpppp( 9,14, 4,2),fpppp( 9,14, 4,3)/
     x-2.4485518d-03,-1.4986874d-03, 7.3804054d-07 /
      data fpppp( 9,14, 5,1),fpppp( 9,14, 5,2),fpppp( 9,14, 5,3)/
     x-1.3363597d-03, 9.2889193d-04,-3.7911847d-07 /
      data fpppp( 9,14, 6,1),fpppp( 9,14, 6,2),fpppp( 9,14, 6,3)/
     x-4.4965026d-04, 6.3737781d-04,-5.4877329d-07 /
      data fpppp( 9,14, 7,1),fpppp( 9,14, 7,2),fpppp( 9,14, 7,3)/
     x-2.2202049d-04, 3.6698389d-04,-3.4111976d-07 /
      data fpppp( 9,14, 8,1),fpppp( 9,14, 8,2),fpppp( 9,14, 8,3)/
     x 2.0275492d-04, 3.3503482d-04,-1.3249739d-07 /
      data fpppp( 9,14, 9,1),fpppp( 9,14, 9,2),fpppp( 9,14, 9,3)/
     x-2.7409085d-05, 5.7895481d-04, 1.0643842d-07 /
      data fpppp( 9,14,10,1),fpppp( 9,14,10,2),fpppp( 9,14,10,3)/
     x 3.3141671d-05,-3.2118983d-04, 7.1627748d-08 /
      data fpppp( 9,14,11,1),fpppp( 9,14,11,2),fpppp( 9,14,11,3)/
     x-2.8631624d-05,-3.0749867d-04, 7.1378953d-08 /
      data fpppp( 9,14,12,1),fpppp( 9,14,12,2),fpppp( 9,14,12,3)/
     x-1.9869717d-06, 7.1059262d-06, 2.0402690d-08 /
      data fpppp( 9,14,13,1),fpppp( 9,14,13,2),fpppp( 9,14,13,3)/
     x-1.4754847d-05,-9.6145379d-06, 1.1036208d-08 /
      data fpppp( 9,14,14,1),fpppp( 9,14,14,2),fpppp( 9,14,14,3)/
     x-2.3878823d-05, 1.1571145d-05,-1.3310161d-09 /
      data fpppp( 9,14,15,1),fpppp( 9,14,15,2),fpppp( 9,14,15,3)/
     x-1.6534872d-05, 2.3929224d-06,-1.9635651d-10 /
      data fpppp( 9,14,16,1),fpppp( 9,14,16,2),fpppp( 9,14,16,3)/
     x-1.7948103d-05, 5.6217369d-06, 1.7302271d-09 /
      data fpppp( 9,14,17,1),fpppp( 9,14,17,2),fpppp( 9,14,17,3)/
     x-2.3611160d-05, 4.4000844d-06, 4.4637817d-09 /
      data fpppp( 9,14,18,1),fpppp( 9,14,18,2),fpppp( 9,14,18,3)/
     x-2.7377365d-05, 1.5148221d-05, 9.0092528d-09 /
      data fpppp( 9,14,19,1),fpppp( 9,14,19,2),fpppp( 9,14,19,3)/
     x-2.0726314d-05, 1.5480360d-05, 1.2367860d-08 /
      data fpppp( 9,14,20,1),fpppp( 9,14,20,2),fpppp( 9,14,20,3)/
     x 6.4590027d-05,-3.0340571d-05,-4.7296039d-09 /
      data fpppp( 9,14,21,1),fpppp( 9,14,21,2),fpppp( 9,14,21,3)/
     x 6.4590027d-05,-2.9309785d-05,-4.1914350d-09 /
      data fpppp( 9,14,22,1),fpppp( 9,14,22,2),fpppp( 9,14,22,3)/
     x-2.0726314d-05, 1.1357213d-05, 1.0215185d-08 /
      data fpppp( 9,14,23,1),fpppp( 9,14,23,2),fpppp( 9,14,23,3)/
     x-2.7377365d-05, 3.0610022d-05, 1.7081786d-08 /
      data fpppp( 9,15, 1,1),fpppp( 9,15, 1,2),fpppp( 9,15, 1,3)/
     x-1.3365749d-04, 5.8687529d-04, 6.9099348d-07 /
      data fpppp( 9,15, 2,1),fpppp( 9,15, 2,2),fpppp( 9,15, 2,3)/
     x 1.6350137d-04, 1.8967129d-04, 3.1921598d-07 /
      data fpppp( 9,15, 3,1),fpppp( 9,15, 3,2),fpppp( 9,15, 3,3)/
     x 9.0034282d-04,-6.4888360d-04,-4.5754575d-07 /
      data fpppp( 9,15, 4,1),fpppp( 9,15, 4,2),fpppp( 9,15, 4,3)/
     x 9.0034282d-04,-6.7092755d-04,-4.9237832d-07 /
      data fpppp( 9,15, 5,1),fpppp( 9,15, 5,2),fpppp( 9,15, 5,3)/
     x 1.6350137d-04, 2.7784712d-04, 4.5854627d-07 /
      data fpppp( 9,15, 6,1),fpppp( 9,15, 6,2),fpppp( 9,15, 6,3)/
     x-1.3365749d-04, 2.5621594d-04, 1.6850491d-07 /
      data fpppp( 9,15, 7,1),fpppp( 9,15, 7,2),fpppp( 9,15, 7,3)/
     x 2.3811605d-04, 1.7473895d-04,-2.1544895d-08 /
      data fpppp( 9,15, 8,1),fpppp( 9,15, 8,2),fpppp( 9,15, 8,3)/
     x-7.3022971d-04, 1.3950351d-04,-2.4857151d-07 /
      data fpppp( 9,15, 9,1),fpppp( 9,15, 9,2),fpppp( 9,15, 9,3)/
     x 5.8740704d-04, 4.9406757d-04, 7.4373563d-08 /
      data fpppp( 9,15,10,1),fpppp( 9,15,10,2),fpppp( 9,15,10,3)/
     x-4.5616875d-04, 3.1493102d-04, 2.2324042d-07 /
      data fpppp( 9,15,11,1),fpppp( 9,15,11,2),fpppp( 9,15,11,3)/
     x-4.0473798d-05,-6.5155783d-04,-2.4100984d-08 /
      data fpppp( 9,15,12,1),fpppp( 9,15,12,2),fpppp( 9,15,12,3)/
     x-3.1497406d-05, 1.6757204d-05, 6.5221450d-08 /
      data fpppp( 9,15,13,1),fpppp( 9,15,13,2),fpppp( 9,15,13,3)/
     x-8.0096473d-06,-2.9765002d-05, 5.5209997d-09 /
      data fpppp( 9,15,14,1),fpppp( 9,15,14,2),fpppp( 9,15,14,3)/
     x-6.9750429d-06, 1.2372852d-05, 1.0268802d-08 /
      data fpppp( 9,15,15,1),fpppp( 9,15,15,2),fpppp( 9,15,15,3)/
     x-1.6962718d-05,-1.6575382d-06, 3.4735966d-09 /
      data fpppp( 9,15,16,1),fpppp( 9,15,16,2),fpppp( 9,15,16,3)/
     x-2.1771723d-05, 3.4623251d-06, 4.7147759d-09 /
      data fpppp( 9,15,17,1),fpppp( 9,15,17,2),fpppp( 9,15,17,3)/
     x-2.4811093d-05, 2.1364741d-06, 3.9198184d-09 /
      data fpppp( 9,15,18,1),fpppp( 9,15,18,2),fpppp( 9,15,18,3)/
     x-2.2929440d-05, 1.5716517d-06, 6.2499371d-09 /
      data fpppp( 9,15,19,1),fpppp( 9,15,19,2),fpppp( 9,15,19,3)/
     x-1.1555676d-05, 2.0923574d-06, 7.5262913d-09 /
      data fpppp( 9,15,20,1),fpppp( 9,15,20,2),fpppp( 9,15,20,3)/
     x-9.5918856d-06,-9.1764752d-06,-7.0095657d-09 /
      data fpppp( 9,15,21,1),fpppp( 9,15,21,2),fpppp( 9,15,21,3)/
     x-9.5918856d-06,-8.9021321d-06,-6.6269825d-09 /
      data fpppp( 9,15,22,1),fpppp( 9,15,22,2),fpppp( 9,15,22,3)/
     x-1.1555676d-05, 9.9498510d-07, 5.9959582d-09 /
      data fpppp( 9,15,23,1),fpppp( 9,15,23,2),fpppp( 9,15,23,3)/
     x-2.2929440d-05, 5.6867979d-06, 1.1988686d-08 /
      data fpppp( 9,16, 1,1),fpppp( 9,16, 1,2),fpppp( 9,16, 1,3)/
     x 2.9583898d-04, 6.1157383d-05, 3.1069515d-07 /
      data fpppp( 9,16, 2,1),fpppp( 9,16, 2,2),fpppp( 9,16, 2,3)/
     x 8.1770689d-04,-9.9509533d-06, 9.4835879d-08 /
      data fpppp( 9,16, 3,1),fpppp( 9,16, 3,2),fpppp( 9,16, 3,3)/
     x 1.1261216d-03,-1.6246365d-04,-3.6443869d-07 /
      data fpppp( 9,16, 4,1),fpppp( 9,16, 4,2),fpppp( 9,16, 4,3)/
     x 1.1261216d-03,-1.6222269d-04,-3.7018044d-07 /
      data fpppp( 9,16, 5,1),fpppp( 9,16, 5,2),fpppp( 9,16, 5,3)/
     x 8.1770689d-04,-1.0914786d-05, 1.1780287d-07 /
      data fpppp( 9,16, 6,1),fpppp( 9,16, 6,2),fpppp( 9,16, 6,3)/
     x 2.9583898d-04, 6.4771757d-05, 2.2456894d-07 /
      data fpppp( 9,16, 7,1),fpppp( 9,16, 7,2),fpppp( 9,16, 7,3)/
     x-1.2187184d-03,-1.1469912d-04,-2.9511262d-08 /
      data fpppp( 9,16, 8,1),fpppp( 9,16, 8,2),fpppp( 9,16, 8,3)/
     x 2.6377094d-03, 3.5068067d-04, 4.9893055d-07 /
      data fpppp( 9,16, 9,1),fpppp( 9,16, 9,2),fpppp( 9,16, 9,3)/
     x-1.8697794d-03,-9.9538631d-04,-4.2083061d-07 /
      data fpppp( 9,16,10,1),fpppp( 9,16,10,2),fpppp( 9,16,10,3)/
     x-5.2427684d-04, 2.8614659d-03,-4.0126484d-07 /
      data fpppp( 9,16,11,1),fpppp( 9,16,11,2),fpppp( 9,16,11,3)/
     x 1.9304675d-04,-2.1461264d-03, 5.7142451d-07 /
      data fpppp( 9,16,12,1),fpppp( 9,16,12,2),fpppp( 9,16,12,3)/
     x 7.8942337d-05, 3.4814785d-04,-6.7051196d-08 /
      data fpppp( 9,16,13,1),fpppp( 9,16,13,2),fpppp( 9,16,13,3)/
     x-2.0885796d-06,-1.3465708d-04, 4.7811086d-08 /
      data fpppp( 9,16,14,1),fpppp( 9,16,14,2),fpppp( 9,16,14,3)/
     x 3.1993048d-06, 3.0551743d-05, 2.9733405d-09 /
      data fpppp( 9,16,15,1),fpppp( 9,16,15,2),fpppp( 9,16,15,3)/
     x 1.8603083d-05,-7.9804128d-06, 1.1700553d-08 /
      data fpppp( 9,16,16,1),fpppp( 9,16,16,2),fpppp( 9,16,16,3)/
     x 3.0780603d-05, 1.7466281d-06, 5.0188072d-09 /
      data fpppp( 9,16,17,1),fpppp( 9,16,17,2),fpppp( 9,16,17,3)/
     x 4.1811436d-05, 2.0524423d-06, 3.5858112d-09 /
      data fpppp( 9,16,18,1),fpppp( 9,16,18,2),fpppp( 9,16,18,3)/
     x 4.9661693d-05,-2.7665745d-06,-4.5260524d-10 /
      data fpppp( 9,16,19,1),fpppp( 9,16,19,2),fpppp( 9,16,19,3)/
     x 6.0146731d-05, 5.9188304d-07,-3.1474760d-09 /
      data fpppp( 9,16,20,1),fpppp( 9,16,20,2),fpppp( 9,16,20,3)/
     x 7.1646082d-05,-2.7611261d-06,-5.4507275d-09 /
      data fpppp( 9,16,21,1),fpppp( 9,16,21,2),fpppp( 9,16,21,3)/
     x 7.1646082d-05,-2.5274301d-06,-5.5276272d-09 /
      data fpppp( 9,16,22,1),fpppp( 9,16,22,2),fpppp( 9,16,22,3)/
     x 6.0146731d-05,-3.4290085d-07,-2.8398772d-09 /
      data fpppp( 9,16,23,1),fpppp( 9,16,23,2),fpppp( 9,16,23,3)/
     x 4.9661693d-05, 7.3886505d-07,-1.6061005d-09 /
      data fpppp( 9,17, 1,1),fpppp( 9,17, 1,2),fpppp( 9,17, 1,3)/
     x-4.7528719d-04,-3.6784889d-05, 2.8387503d-08 /
      data fpppp( 9,17, 2,1),fpppp( 9,17, 2,2),fpppp( 9,17, 2,3)/
     x-9.5141625d-04,-3.3141233d-05, 7.3773723d-09 /
      data fpppp( 9,17, 3,1),fpppp( 9,17, 3,2),fpppp( 9,17, 3,3)/
     x-2.3461540d-04,-3.0747559d-05,-3.4528521d-08 /
      data fpppp( 9,17, 4,1),fpppp( 9,17, 4,2),fpppp( 9,17, 4,3)/
     x-2.3461540d-04,-2.1272781d-05,-3.9981196d-08 /
      data fpppp( 9,17, 5,1),fpppp( 9,17, 5,2),fpppp( 9,17, 5,3)/
     x-9.5141625d-04,-7.1040344d-05, 2.9188070d-08 /
      data fpppp( 9,17, 6,1),fpppp( 9,17, 6,2),fpppp( 9,17, 6,3)/
     x-4.7528719d-04, 1.0533678d-04,-5.3402615d-08 /
      data fpppp( 9,17, 7,1),fpppp( 9,17, 7,2),fpppp( 9,17, 7,3)/
     x 4.6555080d-03,-2.0796975d-04, 3.6765195d-07 /
      data fpppp( 9,17, 8,1),fpppp( 9,17, 8,2),fpppp( 9,17, 8,3)/
     x-1.1236551d-02,-1.3338535d-03,-1.4202567d-06 /
      data fpppp( 9,17, 9,1),fpppp( 9,17, 9,2),fpppp( 9,17, 9,3)/
     x 9.5264763d-04, 1.8134108d-03, 3.3827111d-07 /
      data fpppp( 9,17,10,1),fpppp( 9,17,10,2),fpppp( 9,17,10,3)/
     x 4.1116535d-03, 2.1312686d-03, 1.4482760d-06 /
      data fpppp( 9,17,11,1),fpppp( 9,17,11,2),fpppp( 9,17,11,3)/
     x 2.7706089d-04,-2.8790612d-03,-7.2322760d-07 /
      data fpppp( 9,17,12,1),fpppp( 9,17,12,2),fpppp( 9,17,12,3)/
     x-9.7084720d-05, 6.3775201d-04, 1.1348843d-07 /
      data fpppp( 9,17,13,1),fpppp( 9,17,13,2),fpppp( 9,17,13,3)/
     x 2.4318093d-05,-1.9168322d-04,-4.7315204d-08 /
      data fpppp( 9,17,14,1),fpppp( 9,17,14,2),fpppp( 9,17,14,3)/
     x-3.0944019d-05, 4.5210456d-05, 1.3852174d-08 /
      data fpppp( 9,17,15,1),fpppp( 9,17,15,2),fpppp( 9,17,15,3)/
     x-8.1274716d-05,-1.3715813d-05, 1.8166992d-09 /
      data fpppp( 9,17,16,1),fpppp( 9,17,16,2),fpppp( 9,17,16,3)/
     x-1.2326555d-04, 1.8147149d-06, 5.5056242d-09 /
      data fpppp( 9,17,17,1),fpppp( 9,17,17,2),fpppp( 9,17,17,3)/
     x-1.5676551d-04,-8.0440784d-08, 1.0619137d-09 /
      data fpppp( 9,17,18,1),fpppp( 9,17,18,2),fpppp( 9,17,18,3)/
     x-1.8238645d-04,-6.1543898d-07,-1.8750531d-09 /
      data fpppp( 9,17,19,1),fpppp( 9,17,19,2),fpppp( 9,17,19,3)/
     x-2.0391439d-04,-6.9295883d-07,-5.4392168d-09 /
      data fpppp( 9,17,20,1),fpppp( 9,17,20,2),fpppp( 9,17,20,3)/
     x-2.1706653d-04,-6.7457955d-07,-6.2606697d-09 /
      data fpppp( 9,17,21,1),fpppp( 9,17,21,2),fpppp( 9,17,21,3)/
     x-2.1706653d-04,-6.7866643d-07,-6.4116580d-09 /
      data fpppp( 9,17,22,1),fpppp( 9,17,22,2),fpppp( 9,17,22,3)/
     x-2.0391439d-04,-6.7661132d-07,-4.8352638d-09 /
      data fpppp( 9,17,23,1),fpppp( 9,17,23,2),fpppp( 9,17,23,3)/
     x-1.8238645d-04,-6.7674211d-07,-4.1398768d-09 /
      data fpppp( 9,18, 1,1),fpppp( 9,18, 1,2),fpppp( 9,18, 1,3)/
     x 1.2138279d-03, 9.7959208d-04, 4.7992292d-08 /
      data fpppp( 9,18, 2,1),fpppp( 9,18, 2,2),fpppp( 9,18, 2,3)/
     x 1.8238965d-03, 6.3093318d-04, 4.4569737d-08 /
      data fpppp( 9,18, 3,1),fpppp( 9,18, 3,2),fpppp( 9,18, 3,3)/
     x 1.1971530d-03,-4.4095515d-04, 3.4694911d-08 /
      data fpppp( 9,18, 4,1),fpppp( 9,18, 4,2),fpppp( 9,18, 4,3)/
     x 1.1971530d-03, 1.2737854d-04, 3.9141276d-08 /
      data fpppp( 9,18, 5,1),fpppp( 9,18, 5,2),fpppp( 9,18, 5,3)/
     x 1.8238965d-03,-1.6424016d-03, 2.6784276d-08 /
      data fpppp( 9,18, 6,1),fpppp( 9,18, 6,2),fpppp( 9,18, 6,3)/
     x 1.2138279d-03, 9.5045975d-03, 1.1468777d-07 /
      data fpppp( 9,18, 7,1),fpppp( 9,18, 7,2),fpppp( 9,18, 7,3)/
     x-4.3682435d-03,-2.3570815d-02,-3.4598094d-07 /
      data fpppp( 9,18, 8,1),fpppp( 9,18, 8,2),fpppp( 9,18, 8,3)/
     x 1.3004887d-02, 2.4935987d-02, 1.2001479d-06 /
      data fpppp( 9,18, 9,1),fpppp( 9,18, 9,2),fpppp( 9,18, 9,3)/
     x 2.5616832d-03,-7.7809404d-03, 2.9848517d-09 /
      data fpppp( 9,18,10,1),fpppp( 9,18,10,2),fpppp( 9,18,10,3)/
     x-2.4790792d-03,-1.8060465d-03,-1.0637655d-06 /
      data fpppp( 9,18,11,1),fpppp( 9,18,11,2),fpppp( 9,18,11,3)/
     x-3.5748858d-04, 1.7940361d-04, 1.5659208d-07 /
      data fpppp( 9,18,12,1),fpppp( 9,18,12,2),fpppp( 9,18,12,3)/
     x 1.1213052d-04, 3.2726414d-04,-9.1721125d-08 /
      data fpppp( 9,18,13,1),fpppp( 9,18,13,2),fpppp( 9,18,13,3)/
     x-4.3617070d-06,-2.1058502d-04, 2.7778685d-09 /
      data fpppp( 9,18,14,1),fpppp( 9,18,14,2),fpppp( 9,18,14,3)/
     x 4.7372841d-05, 5.5349747d-05,-1.0916004d-08 /
      data fpppp( 9,18,15,1),fpppp( 9,18,15,2),fpppp( 9,18,15,3)/
     x 9.5633284d-05,-1.3130406d-05,-2.8396219d-09 /
      data fpppp( 9,18,16,1),fpppp( 9,18,16,2),fpppp( 9,18,16,3)/
     x 1.3848997d-04, 5.8484371d-06,-4.7382500d-09 /
      data fpppp( 9,18,17,1),fpppp( 9,18,17,2),fpppp( 9,18,17,3)/
     x 1.7498392d-04, 2.0574008d-06,-5.8934094d-09 /
      data fpppp( 9,18,18,1),fpppp( 9,18,18,2),fpppp( 9,18,18,3)/
     x 2.0495298d-04, 2.2977628d-06,-8.0704626d-09 /
      data fpppp( 9,18,19,1),fpppp( 9,18,19,2),fpppp( 9,18,19,3)/
     x 2.2886341d-04, 3.6513370d-06,-9.7825931d-09 /
      data fpppp( 9,18,20,1),fpppp( 9,18,20,2),fpppp( 9,18,20,3)/
     x 2.4400228d-04, 3.8793471d-06,-1.1655568d-08 /
      data fpppp( 9,18,21,1),fpppp( 9,18,21,2),fpppp( 9,18,21,3)/
     x 2.4400228d-04, 3.9385482d-06,-1.1695350d-08 /
      data fpppp( 9,18,22,1),fpppp( 9,18,22,2),fpppp( 9,18,22,3)/
     x 2.2886341d-04, 3.4145327d-06,-9.6234648d-09 /
      data fpppp( 9,18,23,1),fpppp( 9,18,23,2),fpppp( 9,18,23,3)/
     x 2.0495298d-04, 3.1857791d-06,-8.6671937d-09 /
      data fpppp( 9,19, 1,1),fpppp( 9,19, 1,2),fpppp( 9,19, 1,3)/
     x 2.2000169d-03,-6.1169117d-17,-1.8663614d-08 /
      data fpppp( 9,19, 2,1),fpppp( 9,19, 2,2),fpppp( 9,19, 2,3)/
     x 3.3007990d-03,-8.1965474d-18, 4.6147567d-08 /
      data fpppp( 9,19, 3,1),fpppp( 9,19, 3,2),fpppp( 9,19, 3,3)/
     x 1.8310628d-03,-1.8777013d-18, 1.7840027d-07 /
      data fpppp( 9,19, 4,1),fpppp( 9,19, 4,2),fpppp( 9,19, 4,3)/
     x 1.8310628d-03, 6.4906916d-18, 1.8999997d-07 /
      data fpppp( 9,19, 5,1),fpppp( 9,19, 5,2),fpppp( 9,19, 5,3)/
     x 3.3007990d-03,-2.3134071d-17,-2.5123257d-10 /
      data fpppp( 9,19, 6,1),fpppp( 9,19, 6,2),fpppp( 9,19, 6,3)/
     x 2.2000169d-03, 1.2106427d-17, 1.5533189d-07 /
      data fpppp( 9,19, 7,1),fpppp( 9,19, 7,2),fpppp( 9,19, 7,3)/
     x-9.1354298d-03,-5.7681153d-18,-7.4224352d-07 /
      data fpppp( 9,19, 8,1),fpppp( 9,19, 8,2),fpppp( 9,19, 8,3)/
     x 2.6356125d-02, 5.5428608d-18, 2.5235262d-06 /
      data fpppp( 9,19, 9,1),fpppp( 9,19, 9,2),fpppp( 9,19, 9,3)/
     x 4.5174020d-03, 2.0279934d-18,-1.9619129d-08 /
      data fpppp( 9,19,10,1),fpppp( 9,19,10,2),fpppp( 9,19,10,3)/
     x-5.8621940d-03, 2.0578070d-17,-2.3296406d-06 /
      data fpppp( 9,19,11,1),fpppp( 9,19,11,2),fpppp( 9,19,11,3)/
     x-7.8673416d-04, 1.7393993d-18, 4.1513410d-07 /
      data fpppp( 9,19,12,1),fpppp( 9,19,12,2),fpppp( 9,19,12,3)/
     x 2.1127654d-04,-5.4963166d-18,-1.8671663d-07 /
      data fpppp( 9,19,13,1),fpppp( 9,19,13,2),fpppp( 9,19,13,3)/
     x-1.7302515d-05,-1.6993561d-17, 1.1379695d-08 /
      data fpppp( 9,19,14,1),fpppp( 9,19,14,2),fpppp( 9,19,14,3)/
     x 9.3558219d-05, 1.7348939d-17,-2.5499322d-08 /
      data fpppp( 9,19,15,1),fpppp( 9,19,15,2),fpppp( 9,19,15,3)/
     x 1.9345963d-04,-5.7262253d-18,-8.9895238d-09 /
      data fpppp( 9,19,16,1),fpppp( 9,19,16,2),fpppp( 9,19,16,3)/
     x 2.8144501d-04,-8.7438979d-20,-1.1916212d-08 /
      data fpppp( 9,19,17,1),fpppp( 9,19,17,2),fpppp( 9,19,17,3)/
     x 3.5521153d-04,-3.8619522d-18,-1.1582611d-08 /
      data fpppp( 9,19,18,1),fpppp( 9,19,18,2),fpppp( 9,19,18,3)/
     x 4.1532454d-04,-3.5350187d-18,-1.2902169d-08 /
      data fpppp( 9,19,19,1),fpppp( 9,19,19,2),fpppp( 9,19,19,3)/
     x 4.6254437d-04, 5.5406665d-18,-1.3539788d-08 /
      data fpppp( 9,19,20,1),fpppp( 9,19,20,2),fpppp( 9,19,20,3)/
     x 4.9084782d-04, 1.3161148d-18,-1.5740478d-08 /
      data fpppp( 9,19,21,1),fpppp( 9,19,21,2),fpppp( 9,19,21,3)/
     x 4.9084782d-04,-7.9061281d-18,-1.5721996d-08 /
      data fpppp( 9,19,22,1),fpppp( 9,19,22,2),fpppp( 9,19,22,3)/
     x 4.6254437d-04,-3.4522785d-17,-1.3613719d-08 /
      data fpppp( 9,19,23,1),fpppp( 9,19,23,2),fpppp( 9,19,23,3)/
     x 4.1532454d-04, 2.1520541d-18,-1.2624928d-08 /
      data fpppp(10, 1, 1,1),fpppp(10, 1, 1,2),fpppp(10, 1, 1,3)/
     x-1.5210767d-01, 2.7452337d-16, 1.6062104d-05 /
      data fpppp(10, 1, 2,1),fpppp(10, 1, 2,2),fpppp(10, 1, 2,3)/
     x-1.5685773d-01,-2.6829840d-16, 8.7682162d-06 /
      data fpppp(10, 1, 3,1),fpppp(10, 1, 3,2),fpppp(10, 1, 3,3)/
     x-2.5205772d-02, 1.3229980d-16,-4.2092988d-06 /
      data fpppp(10, 1, 4,1),fpppp(10, 1, 4,2),fpppp(10, 1, 4,3)/
     x-2.5205772d-02, 4.0705825d-17,-8.8507256d-06 /
      data fpppp(10, 1, 5,1),fpppp(10, 1, 5,2),fpppp(10, 1, 5,3)/
     x-1.5685773d-01, 9.1102343d-17, 2.7333923d-05 /
      data fpppp(10, 1, 6,1),fpppp(10, 1, 6,2),fpppp(10, 1, 6,3)/
     x-1.5210767d-01, 1.2274207d-17,-5.3559298d-05 /
      data fpppp(10, 1, 7,1),fpppp(10, 1, 7,2),fpppp(10, 1, 7,3)/
     x-1.2281413d-01,-2.5152507d-17, 3.7646310d-05 /
      data fpppp(10, 1, 8,1),fpppp(10, 1, 8,2),fpppp(10, 1, 8,3)/
     x-7.4514857d-02,-3.0177242d-17,-3.2880638d-06 /
      data fpppp(10, 1, 9,1),fpppp(10, 1, 9,2),fpppp(10, 1, 9,3)/
     x-7.8950034d-02, 1.5415003d-16, 3.0141211d-06 /
      data fpppp(10, 1,10,1),fpppp(10, 1,10,2),fpppp(10, 1,10,3)/
     x-7.5924030d-02, 2.0669448d-18, 5.4687422d-07 /
      data fpppp(10, 1,11,1),fpppp(10, 1,11,2),fpppp(10, 1,11,3)/
     x-7.9576640d-02, 9.0635139d-17, 3.1255583d-08 /
      data fpppp(10, 1,12,1),fpppp(10, 1,12,2),fpppp(10, 1,12,3)/
     x-1.1738242d-01, 6.1647094d-17,-1.5875988d-07 /
      data fpppp(10, 1,13,1),fpppp(10, 1,13,2),fpppp(10, 1,13,3)/
     x-1.0416455d-01,-2.0324514d-18, 2.7368294d-07 /
      data fpppp(10, 1,14,1),fpppp(10, 1,14,2),fpppp(10, 1,14,3)/
     x-7.4934240d-02, 1.0586640d-16, 3.6116160d-07 /
      data fpppp(10, 1,15,1),fpppp(10, 1,15,2),fpppp(10, 1,15,3)/
     x-7.2087016d-02, 2.2790096d-17, 3.2599860d-06 /
      data fpppp(10, 1,16,1),fpppp(10, 1,16,2),fpppp(10, 1,16,3)/
     x-7.8284040d-02,-5.9647676d-17,-3.9261503d-06 /
      data fpppp(10, 1,17,1),fpppp(10, 1,17,2),fpppp(10, 1,17,3)/
     x-1.2274789d-01, 1.9870732d-16, 3.8772432d-05 /
      data fpppp(10, 1,18,1),fpppp(10, 1,18,2),fpppp(10, 1,18,3)/
     x-1.6581706d-01,-3.5738781d-17,-5.5607268d-05 /
      data fpppp(10, 1,19,1),fpppp(10, 1,19,2),fpppp(10, 1,19,3)/
     x-1.3357484d-01, 3.2731566d-17, 2.8946322d-05 /
      data fpppp(10, 1,20,1),fpppp(10, 1,20,2),fpppp(10, 1,20,3)/
     x-6.3606658d-04,-6.0034404d-18,-9.0238840d-06 /
      data fpppp(10, 1,21,1),fpppp(10, 1,21,2),fpppp(10, 1,21,3)/
     x-6.3606658d-04, 2.7631918d-17,-4.1691521d-06 /
      data fpppp(10, 1,22,1),fpppp(10, 1,22,2),fpppp(10, 1,22,3)/
     x-1.3357484d-01, 5.0403406d-17, 9.5273939d-06 /
      data fpppp(10, 1,23,1),fpppp(10, 1,23,2),fpppp(10, 1,23,3)/
     x-1.6581706d-01,-1.8373272d-16, 1.7213711d-05 /
      data fpppp(10, 2, 1,1),fpppp(10, 2, 1,2),fpppp(10, 2, 1,3)/
     x-7.9549213d-02,-5.4126174d-02, 8.9297620d-06 /
      data fpppp(10, 2, 2,1),fpppp(10, 2, 2,2),fpppp(10, 2, 2,3)/
     x-8.0693967d-02,-2.8583326d-02, 5.1371238d-06 /
      data fpppp(10, 2, 3,1),fpppp(10, 2, 3,2),fpppp(10, 2, 3,3)/
     x-1.4916062d-02, 2.4593389d-02,-1.7334166d-06 /
      data fpppp(10, 2, 4,1),fpppp(10, 2, 4,2),fpppp(10, 2, 4,3)/
     x-1.4916062d-02, 2.7319816d-02,-3.9323641d-06 /
      data fpppp(10, 2, 5,1),fpppp(10, 2, 5,2),fpppp(10, 2, 5,3)/
     x-8.0693967d-02,-3.9489034d-02, 1.3932914d-05 /
      data fpppp(10, 2, 6,1),fpppp(10, 2, 6,2),fpppp(10, 2, 6,3)/
     x-7.9549213d-02,-1.3229769d-02,-2.4054450d-05 /
      data fpppp(10, 2, 7,1),fpppp(10, 2, 7,2),fpppp(10, 2, 7,3)/
     x-6.5438278d-02, 1.5576185d-03, 1.5548922d-05 /
      data fpppp(10, 2, 8,1),fpppp(10, 2, 8,2),fpppp(10, 2, 8,3)/
     x-4.1456984d-02, 1.6093682d-02,-1.4641913d-06 /
      data fpppp(10, 2, 9,1),fpppp(10, 2, 9,2),fpppp(10, 2, 9,3)/
     x-4.3678341d-02,-6.6736957d-03, 1.0543722d-06 /
      data fpppp(10, 2,10,1),fpppp(10, 2,10,2),fpppp(10, 2,10,3)/
     x-4.2111184d-02, 4.6084400d-04, 3.1007293d-07 /
      data fpppp(10, 2,11,1),fpppp(10, 2,11,2),fpppp(10, 2,11,3)/
     x-4.3528020d-02, 1.2971406d-02,-1.3335097d-07 /
      data fpppp(10, 2,12,1),fpppp(10, 2,12,2),fpppp(10, 2,12,3)/
     x-6.2377994d-02,-1.3189194d-02,-1.5830240d-07 /
      data fpppp(10, 2,13,1),fpppp(10, 2,13,2),fpppp(10, 2,13,3)/
     x-5.5984924d-02,-9.8656150d-03,-1.7737479d-08 /
      data fpppp(10, 2,14,1),fpppp(10, 2,14,2),fpppp(10, 2,14,3)/
     x-4.1213171d-02, 1.5253850d-02, 2.1720534d-07 /
      data fpppp(10, 2,15,1),fpppp(10, 2,15,2),fpppp(10, 2,15,3)/
     x-4.0694641d-02,-8.0646299d-03, 1.1931255d-06 /
      data fpppp(10, 2,16,1),fpppp(10, 2,16,2),fpppp(10, 2,16,3)/
     x-4.3293007d-02, 1.4739450d-02,-1.8281776d-06 /
      data fpppp(10, 2,17,1),fpppp(10, 2,17,2),fpppp(10, 2,17,3)/
     x-6.4836902d-02, 4.8280582d-03, 1.6202411d-05 /
      data fpppp(10, 2,18,1),fpppp(10, 2,18,2),fpppp(10, 2,18,3)/
     x-8.6025423d-02,-2.6265341d-02,-2.4918568d-05 /
      data fpppp(10, 2,19,1),fpppp(10, 2,19,2),fpppp(10, 2,19,3)/
     x-6.9316397d-02,-2.7186744d-02, 1.4605756d-05 /
      data fpppp(10, 2,20,1),fpppp(10, 2,20,2),fpppp(10, 2,20,3)/
     x-3.5321851d-03, 2.5595012d-02,-4.0584258d-06 /
      data fpppp(10, 2,21,1),fpppp(10, 2,21,2),fpppp(10, 2,21,3)/
     x-3.5321851d-03, 2.4382058d-02,-1.7688242d-06 /
      data fpppp(10, 2,22,1),fpppp(10, 2,22,2),fpppp(10, 2,22,3)/
     x-6.9316397d-02,-2.2334930d-02, 5.4473495d-06 /
      data fpppp(10, 2,23,1),fpppp(10, 2,23,2),fpppp(10, 2,23,3)/
     x-8.6025423d-02,-4.4459645d-02, 9.4254577d-06 /
      data fpppp(10, 3, 1,1),fpppp(10, 3, 1,2),fpppp(10, 3, 1,3)/
     x 3.1404309d-02, 6.6636501d-03,-3.5059249d-05 /
      data fpppp(10, 3, 2,1),fpppp(10, 3, 2,2),fpppp(10, 3, 2,3)/
     x 5.4780709d-02, 4.8315186d-03,-2.1317706d-05 /
      data fpppp(10, 3, 3,1),fpppp(10, 3, 3,2),fpppp(10, 3, 3,3)/
     x-1.0129419d-02, 2.0842183d-03, 4.0838824d-06 /
      data fpppp(10, 3, 4,1),fpppp(10, 3, 4,2),fpppp(10, 3, 4,3)/
     x-1.0129419d-02, 2.1500757d-05, 1.1161888d-05 /
      data fpppp(10, 3, 5,1),fpppp(10, 3, 5,2),fpppp(10, 3, 5,3)/
     x 5.4780709d-02, 1.3082389d-02,-4.9629728d-05 /
      data fpppp(10, 3, 6,1),fpppp(10, 3, 6,2),fpppp(10, 3, 6,3)/
     x 3.1404309d-02,-2.4277113d-02, 7.1110833d-05 /
      data fpppp(10, 3, 7,1),fpppp(10, 3, 7,2),fpppp(10, 3, 7,3)/
     x 4.3714978d-02, 1.4420351d-02,-3.4682629d-05 /
      data fpppp(10, 3, 8,1),fpppp(10, 3, 8,2),fpppp(10, 3, 8,3)/
     x 8.2891907d-03,-4.4648007d-03, 2.8773791d-06 /
      data fpppp(10, 3, 9,1),fpppp(10, 3, 9,2),fpppp(10, 3, 9,3)/
     x 9.2460372d-03, 7.9373267d-04,-1.8042195d-06 /
      data fpppp(10, 3,10,1),fpppp(10, 3,10,2),fpppp(10, 3,10,3)/
     x 5.9485127d-03,-6.2977356d-04,-2.6773572d-06 /
      data fpppp(10, 3,11,1),fpppp(10, 3,11,2),fpppp(10, 3,11,3)/
     x 2.7735970d-03,-4.8444964d-04, 5.1508319d-07 /
      data fpppp(10, 3,12,1),fpppp(10, 3,12,2),fpppp(10, 3,12,3)/
     x 2.7606665d-02, 5.0043863d-03,-2.0125885d-07 /
      data fpppp(10, 3,13,1),fpppp(10, 3,13,2),fpppp(10, 3,13,3)/
     x 1.0442802d-02,-8.8361769d-03, 4.2328529d-07 /
      data fpppp(10, 3,14,1),fpppp(10, 3,14,2),fpppp(10, 3,14,3)/
     x-2.3686951d-03, 9.4242516d-03,-2.4949479d-06 /
      data fpppp(10, 3,15,1),fpppp(10, 3,15,2),fpppp(10, 3,15,3)/
     x 2.0161259d-03,-8.8901787d-03,-2.3112864d-06 /
      data fpppp(10, 3,16,1),fpppp(10, 3,16,2),fpppp(10, 3,16,3)/
     x 9.7345577d-03, 3.4278045d-03, 4.7526996d-06 /
      data fpppp(10, 3,17,1),fpppp(10, 3,17,2),fpppp(10, 3,17,3)/
     x 3.0151249d-02, 5.2707365d-03,-3.7565554d-05 /
      data fpppp(10, 3,18,1),fpppp(10, 3,18,2),fpppp(10, 3,18,3)/
     x 4.3388871d-02,-1.3300961d-02, 7.3516967d-05 /
      data fpppp(10, 3,19,1),fpppp(10, 3,19,2),fpppp(10, 3,19,3)/
     x 4.3436263d-02, 6.8043616d-03,-5.1078823d-05 /
      data fpppp(10, 3,20,1),fpppp(10, 3,20,2),fpppp(10, 3,20,3)/
     x-1.9712532d-02, 1.0500034d-03, 1.1533225d-05 /
      data fpppp(10, 3,21,1),fpppp(10, 3,21,2),fpppp(10, 3,21,3)/
     x-1.9712532d-02, 2.1318399d-03, 4.2318926d-06 /
      data fpppp(10, 3,22,1),fpppp(10, 3,22,2),fpppp(10, 3,22,3)/
     x 4.3436263d-02, 2.4770155d-03,-2.1873492d-05 /
      data fpppp(10, 3,23,1),fpppp(10, 3,23,2),fpppp(10, 3,23,3)/
     x 4.3388871d-02, 2.9265871d-03,-3.6003026d-05 /
      data fpppp(10, 4, 1,1),fpppp(10, 4, 1,2),fpppp(10, 4, 1,3)/
     x 7.9750899d-03,-1.0284834d-02, 4.9950084d-05 /
      data fpppp(10, 4, 2,1),fpppp(10, 4, 2,2),fpppp(10, 4, 2,3)/
     x-1.7332826d-02,-5.6275581d-03, 3.2110546d-05 /
      data fpppp(10, 4, 3,1),fpppp(10, 4, 3,2),fpppp(10, 4, 3,3)/
     x 1.3917957d-02, 3.1442869d-03,-1.7937773d-06 /
      data fpppp(10, 4, 4,1),fpppp(10, 4, 4,2),fpppp(10, 4, 4,3)/
     x 1.3917957d-02, 5.2583410d-03,-9.3594766d-06 /
      data fpppp(10, 4, 5,1),fpppp(10, 4, 5,2),fpppp(10, 4, 5,3)/
     x-1.7332826d-02,-1.4083774d-02, 6.2373344d-05 /
      data fpppp(10, 4, 6,1),fpppp(10, 4, 6,2),fpppp(10, 4, 6,3)/
     x 7.9750899d-03, 2.1425978d-02,-6.3535407d-05 /
      data fpppp(10, 4, 7,1),fpppp(10, 4, 7,2),fpppp(10, 4, 7,3)/
     x-2.8352671d-02,-2.5902288d-02, 1.3555392d-05 /
      data fpppp(10, 4, 8,1),fpppp(10, 4, 8,2),fpppp(10, 4, 8,3)/
     x-3.7369499d-04, 1.4199030d-02,-1.5929930d-06 /
      data fpppp(10, 4, 9,1),fpppp(10, 4, 9,2),fpppp(10, 4, 9,3)/
     x 3.8601525d-04,-3.3341032d-03,-1.5168615d-06 /
      data fpppp(10, 4,10,1),fpppp(10, 4,10,2),fpppp(10, 4,10,3)/
     x 4.1442342d-03,-4.7921085d-03, 3.9624136d-06 /
      data fpppp(10, 4,11,1),fpppp(10, 4,11,2),fpppp(10, 4,11,3)/
     x 1.3189724d-02, 1.2735541d-02,-1.6821251d-06 /
      data fpppp(10, 4,12,1),fpppp(10, 4,12,2),fpppp(10, 4,12,3)/
     x-4.8395095d-03,-1.2909629d-02,-9.2266534d-08 /
      data fpppp(10, 4,13,1),fpppp(10, 4,13,2),fpppp(10, 4,13,3)/
     x 1.3002171d-02, 3.0740400d-03,-1.6992431d-06 /
      data fpppp(10, 4,14,1),fpppp(10, 4,14,2),fpppp(10, 4,14,3)/
     x 1.8543858d-02, 9.6672828d-03, 3.7815883d-06 /
      data fpppp(10, 4,15,1),fpppp(10, 4,15,2),fpppp(10, 4,15,3)/
     x 5.1125173d-03,-9.3280031d-03,-7.8426828d-07 /
      data fpppp(10, 4,16,1),fpppp(10, 4,16,2),fpppp(10, 4,16,3)/
     x-3.6573980d-04, 2.6632635d-03,-4.3565891d-06 /
      data fpppp(10, 4,17,1),fpppp(10, 4,17,2),fpppp(10, 4,17,3)/
     x-4.6306721d-03,-3.8018960d-03, 1.7859285d-05 /
      data fpppp(10, 4,18,1),fpppp(10, 4,18,2),fpppp(10, 4,18,3)/
     x-8.7612770d-04, 6.8361307d-03,-6.5161417d-05 /
      data fpppp(10, 4,19,1),fpppp(10, 4,19,2),fpppp(10, 4,19,3)/
     x-1.3540846d-02,-9.6626971d-03, 6.2940647d-05 /
      data fpppp(10, 4,20,1),fpppp(10, 4,20,2),fpppp(10, 4,20,3)/
     x 1.0601920d-02, 4.2628599d-03,-1.0066799d-05 /
      data fpppp(10, 4,21,1),fpppp(10, 4,21,2),fpppp(10, 4,21,3)/
     x 1.0601920d-02, 3.1712102d-03,-2.3687515d-06 /
      data fpppp(10, 4,22,1),fpppp(10, 4,22,2),fpppp(10, 4,22,3)/
     x-1.3540846d-02,-5.2960982d-03, 3.2148456d-05 /
      data fpppp(10, 4,23,1),fpppp(10, 4,23,2),fpppp(10, 4,23,3)/
     x-8.7612770d-04,-9.5386153d-03, 5.0309299d-05 /
      data fpppp(10, 5, 1,1),fpppp(10, 5, 1,2),fpppp(10, 5, 1,3)/
     x-7.6675976d-03, 1.0089220d-03,-3.4226370d-05 /
      data fpppp(10, 5, 2,1),fpppp(10, 5, 2,2),fpppp(10, 5, 2,3)/
     x 4.7080663d-03, 7.6605368d-04,-2.1594207d-05 /
      data fpppp(10, 5, 3,1),fpppp(10, 5, 3,2),fpppp(10, 5, 3,3)/
     x-2.8954971d-02, 4.6092573d-04, 3.1620672d-06 /
      data fpppp(10, 5, 4,1),fpppp(10, 5, 4,2),fpppp(10, 5, 4,3)/
     x-2.8954971d-02, 8.4143578d-05, 7.2092015d-06 /
      data fpppp(10, 5, 5,1),fpppp(10, 5, 5,2),fpppp(10, 5, 5,3)/
     x 4.7080663d-03, 2.2731823d-03,-3.7782744d-05 /
      data fpppp(10, 5, 6,1),fpppp(10, 5, 6,2),fpppp(10, 5, 6,3)/
     x-7.6675976d-03,-4.6428104d-03, 2.6480644d-05 /
      data fpppp(10, 5, 7,1),fpppp(10, 5, 7,2),fpppp(10, 5, 7,3)/
     x 1.6224904d-02, 2.7519999d-03, 1.5410002d-06 /
      data fpppp(10, 5, 8,1),fpppp(10, 5, 8,2),fpppp(10, 5, 8,3)/
     x 1.1458685d-03,-7.5401141d-04, 3.4264417d-08 /
      data fpppp(10, 5, 9,1),fpppp(10, 5, 9,2),fpppp(10, 5, 9,3)/
     x 7.2286858d-04, 1.9023388d-04, 1.8559592d-06 /
      data fpppp(10, 5,10,1),fpppp(10, 5,10,2),fpppp(10, 5,10,3)/
     x-1.5583257d-03,-6.4793168d-05,-2.6573432d-06 /
      data fpppp(10, 5,11,1),fpppp(10, 5,11,2),fpppp(10, 5,11,3)/
     x-7.8523998d-03, 3.5717549d-06, 1.0591073d-06 /
      data fpppp(10, 5,12,1),fpppp(10, 5,12,2),fpppp(10, 5,12,3)/
     x 2.0418328d-03,-8.0632178d-06,-3.0909045d-08 /
      data fpppp(10, 5,13,1),fpppp(10, 5,13,2),fpppp(10, 5,13,3)/
     x-7.2532145d-03,-2.8663110d-05, 1.0863332d-06 /
      data fpppp(10, 5,14,1),fpppp(10, 5,14,2),fpppp(10, 5,14,3)/
     x-1.0791508d-02, 5.5557579d-05,-2.5559156d-06 /
      data fpppp(10, 5,15,1),fpppp(10, 5,15,2),fpppp(10, 5,15,3)/
     x-5.5167878d-04,-2.5155227d-04, 1.3948353d-06 /
      data fpppp(10, 5,16,1),fpppp(10, 5,16,2),fpppp(10, 5,16,3)/
     x 1.2113148d-03, 3.6548764d-04, 1.6759044d-06 /
      data fpppp(10, 5,17,1),fpppp(10, 5,17,2),fpppp(10, 5,17,3)/
     x 1.3783706d-03,-3.0024319d-04,-1.1979706d-06 /
      data fpppp(10, 5,18,1),fpppp(10, 5,18,2),fpppp(10, 5,18,3)/
     x-1.6396475d-03,-7.6920271d-05, 2.6838398d-05 /
      data fpppp(10, 5,19,1),fpppp(10, 5,19,2),fpppp(10, 5,19,3)/
     x 4.0452835d-03,-6.6780243d-04,-3.7677803d-05 /
      data fpppp(10, 5,20,1),fpppp(10, 5,20,2),fpppp(10, 5,20,3)/
     x-6.3670234d-03, 6.1455684d-04, 7.8858316d-06 /
      data fpppp(10, 5,21,1),fpppp(10, 5,21,2),fpppp(10, 5,21,3)/
     x-6.3670234d-03, 5.5810194d-04, 3.8140327d-06 /
      data fpppp(10, 5,22,1),fpppp(10, 5,22,2),fpppp(10, 5,22,3)/
     x 4.0452835d-03,-4.4198284d-04,-2.1390607d-05 /
      data fpppp(10, 5,23,1),fpppp(10, 5,23,2),fpppp(10, 5,23,3)/
     x-1.6396475d-03,-9.2374371d-04,-3.4238585d-05 /
      data fpppp(10, 6, 1,1),fpppp(10, 6, 1,2),fpppp(10, 6, 1,3)/
     x 4.2026614d-03,-1.7233892d-02, 9.9231806d-06 /
      data fpppp(10, 6, 2,1),fpppp(10, 6, 2,2),fpppp(10, 6, 2,3)/
     x 2.8318135d-05,-9.2664071d-03, 6.1116643d-06 /
      data fpppp(10, 6, 3,1),fpppp(10, 6, 3,2),fpppp(10, 6, 3,3)/
     x 3.7447234d-02, 7.0155761d-03,-1.4251300d-06 /
      data fpppp(10, 6, 4,1),fpppp(10, 6, 4,2),fpppp(10, 6, 4,3)/
     x 3.7447234d-02, 8.4001735d-03,-2.5289263d-06 /
      data fpppp(10, 6, 5,1),fpppp(10, 6, 5,2),fpppp(10, 6, 5,3)/
     x 2.8318135d-05,-1.4804797d-02, 1.0526850d-05 /
      data fpppp(10, 6, 6,1),fpppp(10, 6, 6,2),fpppp(10, 6, 6,3)/
     x 4.2026614d-03, 3.5350693d-03,-6.6337641d-06 /
      data fpppp(10, 6, 7,1),fpppp(10, 6, 7,2),fpppp(10, 6, 7,3)/
     x-3.9406748d-03,-1.0261407d-03,-1.8843190d-07 /
      data fpppp(10, 6, 8,1),fpppp(10, 6, 8,2),fpppp(10, 6, 8,3)/
     x-4.0165232d-05, 2.4042387d-04,-1.2399403d-07 /
      data fpppp(10, 6, 9,1),fpppp(10, 6, 9,2),fpppp(10, 6, 9,3)/
     x 1.4417973d-05,-8.3957326d-05,-5.5841900d-07 /
      data fpppp(10, 6,10,1),fpppp(10, 6,10,2),fpppp(10, 6,10,3)/
     x 6.0672058d-04, 1.2608724d-05, 6.8278312d-07 /
      data fpppp(10, 6,11,1),fpppp(10, 6,11,2),fpppp(10, 6,11,3)/
     x 2.2874953d-03,-5.9909979d-06,-2.8855696d-07 /
      data fpppp(10, 6,12,1),fpppp(10, 6,12,2),fpppp(10, 6,12,3)/
     x-3.6945517d-04,-5.4315489d-06, 1.1689917d-08 /
      data fpppp(10, 6,13,1),fpppp(10, 6,13,2),fpppp(10, 6,13,3)/
     x 2.1198386d-03, 2.0038181d-06,-2.8834586d-07 /
      data fpppp(10, 6,14,1),fpppp(10, 6,14,2),fpppp(10, 6,14,3)/
     x 3.0593165d-03,-1.3506532d-05, 6.7455085d-07 /
      data fpppp(10, 6,15,1),fpppp(10, 6,15,2),fpppp(10, 6,15,3)/
     x 3.4078500d-04, 2.3368037d-06,-4.0260368d-07 /
      data fpppp(10, 6,16,1),fpppp(10, 6,16,2),fpppp(10, 6,16,3)/
     x-2.6616719d-04,-2.7381465d-05,-4.9638173d-07 /
      data fpppp(10, 6,17,1),fpppp(10, 6,17,2),fpppp(10, 6,17,3)/
     x-1.1284011d-04,-5.8031478d-06, 5.6110152d-07 /
      data fpppp(10, 6,18,1),fpppp(10, 6,18,2),fpppp(10, 6,18,3)/
     x 7.4729855d-04,-8.0033999d-05,-6.7625965d-06 /
      data fpppp(10, 6,19,1),fpppp(10, 6,19,2),fpppp(10, 6,19,3)/
     x-7.6427272d-04,-8.4620434d-05, 1.0592346d-05 /
      data fpppp(10, 6,20,1),fpppp(10, 6,20,2),fpppp(10, 6,20,3)/
     x 1.7412661d-03, 1.3880997d-04,-2.8363535d-06 /
      data fpppp(10, 6,21,1),fpppp(10, 6,21,2),fpppp(10, 6,21,3)/
     x 1.7412661d-03, 1.3364285d-04,-1.7150718d-06 /
      data fpppp(10, 6,22,1),fpppp(10, 6,22,2),fpppp(10, 6,22,3)/
     x-7.6427272d-04,-6.3951961d-05, 6.1072188d-06 /
      data fpppp(10, 6,23,1),fpppp(10, 6,23,2),fpppp(10, 6,23,3)/
     x 7.4729855d-04,-1.5754077d-04, 1.0056630d-05 /
      data fpppp(10, 7, 1,1),fpppp(10, 7, 1,2),fpppp(10, 7, 1,3)/
     x-1.0258084d-03, 2.3153391d-04,-1.3950991d-07 /
      data fpppp(10, 7, 2,1),fpppp(10, 7, 2,2),fpppp(10, 7, 2,3)/
     x-1.1827441d-04, 1.2159461d-04,-3.7165491d-07 /
      data fpppp(10, 7, 3,1),fpppp(10, 7, 3,2),fpppp(10, 7, 3,3)/
     x-1.9829471d-02,-1.0425831d-04,-9.4821180d-07 /
      data fpppp(10, 7, 4,1),fpppp(10, 7, 4,2),fpppp(10, 7, 4,3)/
     x-1.9829471d-02,-1.2128809d-04,-8.0978098d-07 /
      data fpppp(10, 7, 5,1),fpppp(10, 7, 5,2),fpppp(10, 7, 5,3)/
     x-1.1827441d-04, 1.8971375d-04,-9.2537821d-07 /
      data fpppp(10, 7, 6,1),fpppp(10, 7, 6,2),fpppp(10, 7, 6,3)/
     x-1.0258084d-03,-2.3912868d-05, 1.9369525d-06 /
      data fpppp(10, 7, 7,1),fpppp(10, 7, 7,2),fpppp(10, 7, 7,3)/
     x 1.0011176d-03, 2.5841930d-06, 8.8505889d-09 /
      data fpppp(10, 7, 8,1),fpppp(10, 7, 8,2),fpppp(10, 7, 8,3)/
     x 7.3747986d-05,-6.1912604d-06, 1.1859877d-07 /
      data fpppp(10, 7, 9,1),fpppp(10, 7, 9,2),fpppp(10, 7, 9,3)/
     x 7.9954922d-05, 5.0944779d-06, 1.7896542d-07 /
      data fpppp(10, 7,10,1),fpppp(10, 7,10,2),fpppp(10, 7,10,3)/
     x-8.0060727d-05, 4.5496154d-06,-1.5427086d-07 /
      data fpppp(10, 7,11,1),fpppp(10, 7,11,2),fpppp(10, 7,11,3)/
     x-5.3834949d-04, 5.7826694d-06, 9.6678096d-08 /
      data fpppp(10, 7,12,1),fpppp(10, 7,12,2),fpppp(10, 7,12,3)/
     x 1.7190426d-04, 3.2641549d-06, 1.3760703d-08 /
      data fpppp(10, 7,13,1),fpppp(10, 7,13,2),fpppp(10, 7,13,3)/
     x-5.0111755d-04,-5.0069488d-07, 1.0256732d-07 /
      data fpppp(10, 7,14,1),fpppp(10, 7,14,2),fpppp(10, 7,14,3)/
     x-7.5737863d-04, 1.8302795d-05,-1.4404771d-07 /
      data fpppp(10, 7,15,1),fpppp(10, 7,15,2),fpppp(10, 7,15,3)/
     x-6.5432845d-05,-1.9805105d-05, 1.6478185d-07 /
      data fpppp(10, 7,16,1),fpppp(10, 7,16,2),fpppp(10, 7,16,3)/
     x 9.1698071d-05, 1.7666924d-05, 1.9201274d-07 /
      data fpppp(10, 7,17,1),fpppp(10, 7,17,2),fpppp(10, 7,17,3)/
     x-2.7595620d-06, 6.5885440d-06,-6.0787498d-09 /
      data fpppp(10, 7,18,1),fpppp(10, 7,18,2),fpppp(10, 7,18,3)/
     x-3.3336502d-04, 1.3152901d-05, 1.8842509d-06 /
      data fpppp(10, 7,19,1),fpppp(10, 7,19,2),fpppp(10, 7,19,3)/
     x-1.9171397d-04, 8.3773205d-05,-1.8283491d-06 /
      data fpppp(10, 7,20,1),fpppp(10, 7,20,2),fpppp(10, 7,20,3)/
     x-1.3312910d-03,-8.4109870d-05,-2.0516665d-07 /
      data fpppp(10, 7,21,1),fpppp(10, 7,21,2),fpppp(10, 7,21,3)/
     x-1.3312910d-03,-7.7038711d-05,-4.1735423d-07 /
      data fpppp(10, 7,22,1),fpppp(10, 7,22,2),fpppp(10, 7,22,3)/
     x-1.9171397d-04, 5.5488571d-05,-9.7959873d-07 /
      data fpppp(10, 7,23,1),fpppp(10, 7,23,2),fpppp(10, 7,23,3)/
     x-3.3336502d-04, 1.1922028d-04,-1.2985629d-06 /
      data fpppp(10, 8, 1,1),fpppp(10, 8, 1,2),fpppp(10, 8, 1,3)/
     x-4.6191863d-04, 3.5727113d-03,-4.3648071d-06 /
      data fpppp(10, 8, 2,1),fpppp(10, 8, 2,2),fpppp(10, 8, 2,3)/
     x-1.9746422d-03, 1.9189054d-03,-2.3355223d-06 /
      data fpppp(10, 8, 3,1),fpppp(10, 8, 3,2),fpppp(10, 8, 3,3)/
     x-1.3290108d-03,-1.4603890d-03, 1.8793542d-06 /
      data fpppp(10, 8, 4,1),fpppp(10, 8, 4,2),fpppp(10, 8, 4,3)/
     x-1.3290108d-03,-1.7483959d-03, 2.1131380d-06 /
      data fpppp(10, 8, 5,1),fpppp(10, 8, 5,2),fpppp(10, 8, 5,3)/
     x-1.9746422d-03, 3.0709330d-03,-3.2706575d-06 /
      data fpppp(10, 8, 6,1),fpppp(10, 8, 6,2),fpppp(10, 8, 6,3)/
     x-4.6191863d-04,-7.4739225d-04,-8.5805024d-07 /
      data fpppp(10, 8, 7,1),fpppp(10, 8, 7,2),fpppp(10, 8, 7,3)/
     x 3.6218979d-05, 2.0816320d-04, 9.1244828d-07 /
      data fpppp(10, 8, 8,1),fpppp(10, 8, 8,2),fpppp(10, 8, 8,3)/
     x 4.5142267d-05,-5.8276460d-05,-2.9671496d-08 /
      data fpppp(10, 8, 9,1),fpppp(10, 8, 9,2),fpppp(10, 8, 9,3)/
     x 4.7912431d-05, 2.1399283d-05, 7.5420474d-08 /
      data fpppp(10, 8,10,1),fpppp(10, 8,10,2),fpppp(10, 8,10,3)/
     x 9.2318526d-05, 7.4135693d-06, 7.9278228d-08 /
      data fpppp(10, 8,11,1),fpppp(10, 8,11,2),fpppp(10, 8,11,3)/
     x 2.1245163d-04, 1.7717714d-05, 1.1389820d-08 /
      data fpppp(10, 8,12,1),fpppp(10, 8,12,2),fpppp(10, 8,12,3)/
     x 5.0644405d-06, 9.3159175d-06, 2.7988402d-08 /
      data fpppp(10, 8,13,1),fpppp(10, 8,13,2),fpppp(10, 8,13,3)/
     x 1.8218551d-04, 5.0593789d-06, 6.3268065d-09 /
      data fpppp(10, 8,14,1),fpppp(10, 8,14,2),fpppp(10, 8,14,3)/
     x 2.3306246d-04, 1.1480763d-05, 8.0877927d-08 /
      data fpppp(10, 8,15,1),fpppp(10, 8,15,2),fpppp(10, 8,15,3)/
     x 4.7831202d-05, 3.2235794d-06, 1.4274260d-08 /
      data fpppp(10, 8,16,1),fpppp(10, 8,16,2),fpppp(10, 8,16,3)/
     x-2.1104258d-05, 9.2799534d-06, 2.8660868d-08 /
      data fpppp(10, 8,17,1),fpppp(10, 8,17,2),fpppp(10, 8,17,3)/
     x-2.1032407d-05, 1.0483469d-05, 1.0429509d-07 /
      data fpppp(10, 8,18,1),fpppp(10, 8,18,2),fpppp(10, 8,18,3)/
     x 3.7063638d-05, 1.4006713d-05,-4.1346361d-07 /
      data fpppp(10, 8,19,1),fpppp(10, 8,19,2),fpppp(10, 8,19,3)/
     x-2.0430173d-05, 3.1722181d-05, 5.8915500d-07 /
      data fpppp(10, 8,20,1),fpppp(10, 8,20,2),fpppp(10, 8,20,3)/
     x 3.0353564d-04,-5.9260440d-05,-3.1506152d-07 /
      data fpppp(10, 8,21,1),fpppp(10, 8,21,2),fpppp(10, 8,21,3)/
     x 3.0353564d-04,-5.6404078d-05,-2.4743875d-07 /
      data fpppp(10, 8,22,1),fpppp(10, 8,22,2),fpppp(10, 8,22,3)/
     x-2.0430173d-05, 2.0296734d-05, 3.1866393d-07 /
      data fpppp(10, 8,23,1),fpppp(10, 8,23,2),fpppp(10, 8,23,3)/
     x 3.7063638d-05, 5.6852142d-05, 6.0087792d-07 /
      data fpppp(10, 9, 1,1),fpppp(10, 9, 1,2),fpppp(10, 9, 1,3)/
     x-9.0030170d-04, 1.7313233d-03, 7.7222402d-06 /
      data fpppp(10, 9, 2,1),fpppp(10, 9, 2,2),fpppp(10, 9, 2,3)/
     x 1.8019560d-03, 9.8713217d-04, 4.4402603d-06 /
      data fpppp(10, 9, 3,1),fpppp(10, 9, 3,2),fpppp(10, 9, 3,3)/
     x 2.6487631d-03,-5.5837911d-04,-2.2798109d-06 /
      data fpppp(10, 9, 4,1),fpppp(10, 9, 4,2),fpppp(10, 9, 4,3)/
     x 2.6487631d-03,-6.4445126d-04,-2.8271111d-06 /
      data fpppp(10, 9, 5,1),fpppp(10, 9, 5,2),fpppp(10, 9, 5,3)/
     x 1.8019560d-03, 1.3314208d-03, 6.6294610d-06 /
      data fpppp(10, 9, 6,1),fpppp(10, 9, 6,2),fpppp(10, 9, 6,3)/
     x-9.0030170d-04, 4.4024102d-04,-4.8726236d-07 /
      data fpppp(10, 9, 7,1),fpppp(10, 9, 7,2),fpppp(10, 9, 7,3)/
     x-9.8028201d-04,-1.1115836d-03,-2.3839330d-06 /
      data fpppp(10, 9, 8,1),fpppp(10, 9, 8,2),fpppp(10, 9, 8,3)/
     x 3.9126734d-05, 2.6806496d-04, 3.7107518d-07 /
      data fpppp(10, 9, 9,1),fpppp(10, 9, 9,2),fpppp(10, 9, 9,3)/
     x 3.3281186d-05,-6.6966848d-05,-9.5069895d-08 /
      data fpppp(10, 9,10,1),fpppp(10, 9,10,2),fpppp(10, 9,10,3)/
     x 1.6633279d-05, 4.0053423d-05, 3.1300311d-08 /
      data fpppp(10, 9,11,1),fpppp(10, 9,11,2),fpppp(10, 9,11,3)/
     x-1.3918197d-05, 5.9514556d-06, 1.7175754d-08 /
      data fpppp(10, 9,12,1),fpppp(10, 9,12,2),fpppp(10, 9,12,3)/
     x 4.8698146d-05, 3.2026146d-05, 2.2410799d-08 /
      data fpppp(10, 9,13,1),fpppp(10, 9,13,2),fpppp(10, 9,13,3)/
     x-1.7602980d-05,-6.4730984d-06, 2.6331880d-08 /
      data fpppp(10, 9,14,1),fpppp(10, 9,14,2),fpppp(10, 9,14,3)/
     x-2.5407864d-05, 2.6650981d-05, 1.2105187d-08 /
      data fpppp(10, 9,15,1),fpppp(10, 9,15,2),fpppp(10, 9,15,3)/
     x 3.5270914d-06,-4.1103274d-06, 3.3037945d-08 /
      data fpppp(10, 9,16,1),fpppp(10, 9,16,2),fpppp(10, 9,16,3)/
     x 1.2391397d-05, 1.0648774d-05, 3.1547253d-08 /
      data fpppp(10, 9,17,1),fpppp(10, 9,17,2),fpppp(10, 9,17,3)/
     x-5.4855689d-09, 8.8973296d-06, 5.0876801d-09 /
      data fpppp(10, 9,18,1),fpppp(10, 9,18,2),fpppp(10, 9,18,3)/
     x-2.0261774d-05, 1.5118537d-05, 1.2176290d-07 /
      data fpppp(10, 9,19,1),fpppp(10, 9,19,2),fpppp(10, 9,19,3)/
     x-1.0666515d-05, 2.3868799d-05,-1.8157760d-07 /
      data fpppp(10, 9,20,1),fpppp(10, 9,20,2),fpppp(10, 9,20,3)/
     x-8.5231156d-05,-5.1009038d-05,-5.9679995d-08 /
      data fpppp(10, 9,21,1),fpppp(10, 9,21,2),fpppp(10, 9,21,3)/
     x-8.5231156d-05,-4.8934991d-05,-7.6779333d-08 /
      data fpppp(10, 9,22,1),fpppp(10, 9,22,2),fpppp(10, 9,22,3)/
     x-1.0666515d-05, 1.5572612d-05,-1.1318025d-07 /
      data fpppp(10, 9,23,1),fpppp(10, 9,23,2),fpppp(10, 9,23,3)/
     x-2.0261774d-05, 4.6229239d-05,-1.3472717d-07 /
      data fpppp(10,10, 1,1),fpppp(10,10, 1,2),fpppp(10,10, 1,3)/
     x 2.1736291d-03,-4.3783996d-04,-4.4268020d-06 /
      data fpppp(10,10, 2,1),fpppp(10,10, 2,2),fpppp(10,10, 2,3)/
     x-2.8238887d-04,-3.2156181d-04,-2.7545026d-06 /
      data fpppp(10,10, 3,1),fpppp(10,10, 3,2),fpppp(10,10, 3,3)/
     x 1.5501925d-04,-1.9093236d-04, 5.6959278d-07 /
      data fpppp(10,10, 4,1),fpppp(10,10, 4,2),fpppp(10,10, 4,3)/
     x 1.5501925d-04, 1.6509158d-05, 1.0235486d-06 /
      data fpppp(10,10, 5,1),fpppp(10,10, 5,2),fpppp(10,10, 5,3)/
     x-2.8238887d-04,-1.1513279d-03,-4.5703258d-06 /
      data fpppp(10,10, 6,1),fpppp(10,10, 6,2),fpppp(10,10, 6,3)/
     x 2.1736291d-03, 2.6737828d-03, 2.3825349d-06 /
      data fpppp(10,10, 7,1),fpppp(10,10, 7,2),fpppp(10,10, 7,3)/
     x-3.0966479d-05,-1.0578179d-03, 2.1502023d-06 /
      data fpppp(10,10, 8,1),fpppp(10,10, 8,2),fpppp(10,10, 8,3)/
     x-7.1339335d-04,-5.1504108d-04,-1.1833790d-06 /
      data fpppp(10,10, 9,1),fpppp(10,10, 9,2),fpppp(10,10, 9,3)/
     x-1.6338386d-04, 3.4210540d-05,-3.2500534d-08 /
      data fpppp(10,10,10,1),fpppp(10,10,10,2),fpppp(10,10,10,3)/
     x-3.7930933d-05,-2.1634120d-06,-9.3611167d-08 /
      data fpppp(10,10,11,1),fpppp(10,10,11,2),fpppp(10,10,11,3)/
     x-1.2072626d-05, 2.4586548d-05,-8.6422027d-11 /
      data fpppp(10,10,12,1),fpppp(10,10,12,2),fpppp(10,10,12,3)/
     x-2.3686241d-05, 1.5666714d-05, 1.5544371d-09 /
      data fpppp(10,10,13,1),fpppp(10,10,13,2),fpppp(10,10,13,3)/
     x 7.1950074d-06, 1.9204958d-05, 9.4751114d-09 /
      data fpppp(10,10,14,1),fpppp(10,10,14,2),fpppp(10,10,14,3)/
     x 3.8461641d-06, 5.5594801d-06, 1.4357531d-08 /
      data fpppp(10,10,15,1),fpppp(10,10,15,2),fpppp(10,10,15,3)/
     x 2.3344545d-06, 9.0803888d-06, 1.0659698d-08 /
      data fpppp(10,10,16,1),fpppp(10,10,16,2),fpppp(10,10,16,3)/
     x 1.5392213d-06, 2.9104957d-06, 5.1909575d-09 /
      data fpppp(10,10,17,1),fpppp(10,10,17,2),fpppp(10,10,17,3)/
     x 9.2642594d-06, 1.5697797d-05,-6.5490707d-10 /
      data fpppp(10,10,18,1),fpppp(10,10,18,2),fpppp(10,10,18,3)/
     x 9.3761586d-06, 1.0764465d-05,-4.6672444d-08 /
      data fpppp(10,10,19,1),fpppp(10,10,19,2),fpppp(10,10,19,3)/
     x 1.5317345d-05, 3.9138012d-05, 2.4662347d-08 /
      data fpppp(10,10,20,1),fpppp(10,10,20,2),fpppp(10,10,20,3)/
     x 5.2217188d-05,-5.4003439d-05,-3.8001794d-08 /
      data fpppp(10,10,21,1),fpppp(10,10,21,2),fpppp(10,10,21,3)/
     x 5.2217188d-05,-5.0593334d-05,-3.3227519d-08 /
      data fpppp(10,10,22,1),fpppp(10,10,22,2),fpppp(10,10,22,3)/
     x 1.5317345d-05, 2.5497590d-05, 5.5652478d-09 /
      data fpppp(10,10,23,1),fpppp(10,10,23,2),fpppp(10,10,23,3)/
     x 9.3761586d-06, 6.1916049d-05, 2.4941679d-08 /
      data fpppp(10,11, 1,1),fpppp(10,11, 1,2),fpppp(10,11, 1,3)/
     x-8.5477393d-04, 1.0721829d-04, 1.4539371d-06 /
      data fpppp(10,11, 2,1),fpppp(10,11, 2,2),fpppp(10,11, 2,3)/
     x 4.1687027d-04,-1.0188513d-05, 7.6922145d-07 /
      data fpppp(10,11, 3,1),fpppp(10,11, 3,2),fpppp(10,11, 3,3)/
     x 7.2321203d-04,-2.6502495d-04,-5.9417485d-07 /
      data fpppp(10,11, 4,1),fpppp(10,11, 4,2),fpppp(10,11, 4,3)/
     x 7.2321203d-04,-2.5933669d-04,-7.7591483d-07 /
      data fpppp(10,11, 5,1),fpppp(10,11, 5,2),fpppp(10,11, 5,3)/
     x 4.1687027d-04,-3.2941575d-05, 1.4961814d-06 /
      data fpppp(10,11, 6,1),fpppp(10,11, 6,2),fpppp(10,11, 6,3)/
     x-8.5477393d-04, 1.9254227d-04,-1.2721627d-06 /
      data fpppp(10,11, 7,1),fpppp(10,11, 7,2),fpppp(10,11, 7,3)/
     x 8.5586123d-04, 1.2160443d-03, 9.9286803d-08 /
      data fpppp(10,11, 8,1),fpppp(10,11, 8,2),fpppp(10,11, 8,3)/
     x 1.5399377d-04,-6.8818979d-04, 1.0479544d-06 /
      data fpppp(10,11, 9,1),fpppp(10,11, 9,2),fpppp(10,11, 9,3)/
     x-2.4107514d-04,-3.1324820d-04,-1.7570535d-07 /
      data fpppp(10,11,10,1),fpppp(10,11,10,2),fpppp(10,11,10,3)/
     x-1.1091562d-04,-4.3593255d-05,-3.2339727d-08 /
      data fpppp(10,11,11,1),fpppp(10,11,11,2),fpppp(10,11,11,3)/
     x-4.3388846d-05, 1.3795016d-05,-3.2196351d-08 /
      data fpppp(10,11,12,1),fpppp(10,11,12,2),fpppp(10,11,12,3)/
     x-1.7733489d-05, 1.7635497d-05,-9.9932350d-10 /
      data fpppp(10,11,13,1),fpppp(10,11,13,2),fpppp(10,11,13,3)/
     x-1.6676310d-05, 1.7460591d-05, 2.6170627d-09 /
      data fpppp(10,11,14,1),fpppp(10,11,14,2),fpppp(10,11,14,3)/
     x-7.5305741d-06, 5.4938933d-06, 3.3579111d-09 /
      data fpppp(10,11,15,1),fpppp(10,11,15,2),fpppp(10,11,15,3)/
     x 2.0294945d-06, 1.0092581d-05, 1.8609890d-09 /
      data fpppp(10,11,16,1),fpppp(10,11,16,2),fpppp(10,11,16,3)/
     x 9.7486918d-06, 3.8147816d-06,-2.2752037d-09 /
      data fpppp(10,11,17,1),fpppp(10,11,17,2),fpppp(10,11,17,3)/
     x 1.3069943d-05, 8.5284814d-06,-5.8292953d-09 /
      data fpppp(10,11,18,1),fpppp(10,11,18,2),fpppp(10,11,18,3)/
     x 2.2338528d-05, 2.1282330d-05, 3.1359712d-09 /
      data fpppp(10,11,19,1),fpppp(10,11,19,2),fpppp(10,11,19,3)/
     x 2.3272497d-05, 5.3723340d-05,-2.9426919d-08 /
      data fpppp(10,11,20,1),fpppp(10,11,20,2),fpppp(10,11,20,3)/
     x-8.2716693d-06,-6.1937643d-05, 3.7861027d-10 /
      data fpppp(10,11,21,1),fpppp(10,11,21,2),fpppp(10,11,21,3)/
     x-8.2716693d-06,-5.7835611d-05,-1.8273456d-09 /
      data fpppp(10,11,22,1),fpppp(10,11,22,2),fpppp(10,11,22,3)/
     x 2.3272497d-05, 3.7315213d-05,-2.0603096d-08 /
      data fpppp(10,11,23,1),fpppp(10,11,23,2),fpppp(10,11,23,3)/
     x 2.2338528d-05, 8.2812806d-05,-2.9953367d-08 /
      data fpppp(10,12, 1,1),fpppp(10,12, 1,2),fpppp(10,12, 1,3)/
     x 3.6281066d-04, 6.5535497d-04,-2.2939258d-07 /
      data fpppp(10,12, 2,1),fpppp(10,12, 2,2),fpppp(10,12, 2,3)/
     x 3.3268928d-04, 2.4094626d-04,-2.2088049d-07 /
      data fpppp(10,12, 3,1),fpppp(10,12, 3,2),fpppp(10,12, 3,3)/
     x 7.3854654d-04,-6.3304684d-04,-2.2465789d-07 /
      data fpppp(10,12, 4,1),fpppp(10,12, 4,2),fpppp(10,12, 4,3)/
     x 7.3854654d-04,-6.5759158d-04,-1.8612712d-07 /
      data fpppp(10,12, 5,1),fpppp(10,12, 5,2),fpppp(10,12, 5,3)/
     x 3.3268928d-04, 3.3912523d-04,-3.7500356d-07 /
      data fpppp(10,12, 6,1),fpppp(10,12, 6,2),fpppp(10,12, 6,3)/
     x 3.6281066d-04, 2.8718382d-04, 3.4856893d-07 /
      data fpppp(10,12, 7,1),fpppp(10,12, 7,2),fpppp(10,12, 7,3)/
     x-8.4452784d-05, 7.2381672d-04,-6.7038219d-08 /
      data fpppp(10,12, 8,1),fpppp(10,12, 8,2),fpppp(10,12, 8,3)/
     x 2.3084704d-04, 2.6186000d-04, 1.3282323d-07 /
      data fpppp(10,12, 9,1),fpppp(10,12, 9,2),fpppp(10,12, 9,3)/
     x 1.1389242d-05,-4.6253824d-04, 2.5088378d-07 /
      data fpppp(10,12,10,1),fpppp(10,12,10,2),fpppp(10,12,10,3)/
     x-7.2265798d-05,-1.8873652d-04, 8.0209486d-09 /
      data fpppp(10,12,11,1),fpppp(10,12,11,2),fpppp(10,12,11,3)/
     x-4.7279646d-05,-2.1795935d-05, 5.7464749d-09 /
      data fpppp(10,12,12,1),fpppp(10,12,12,2),fpppp(10,12,12,3)/
     x-2.9470720d-05, 1.0380564d-05,-3.2666156d-09 /
      data fpppp(10,12,13,1),fpppp(10,12,13,2),fpppp(10,12,13,3)/
     x-1.7451329d-05, 1.5723123d-05, 1.0998785d-09 /
      data fpppp(10,12,14,1),fpppp(10,12,14,2),fpppp(10,12,14,3)/
     x-1.2079190d-05, 6.1013031d-06,-7.7266544d-10 /
      data fpppp(10,12,15,1),fpppp(10,12,15,2),fpppp(10,12,15,3)/
     x-8.5404380d-06, 1.0066965d-05,-3.9329340d-09 /
      data fpppp(10,12,16,1),fpppp(10,12,16,2),fpppp(10,12,16,3)/
     x-4.2678107d-06, 2.2841742d-06,-3.8295305d-09 /
      data fpppp(10,12,17,1),fpppp(10,12,17,2),fpppp(10,12,17,3)/
     x 3.1624721d-06, 6.2226899d-06, 1.5189205d-09 /
      data fpppp(10,12,18,1),fpppp(10,12,18,2),fpppp(10,12,18,3)/
     x 8.0487725d-06, 2.8413205d-05,-1.8793813d-09 /
      data fpppp(10,12,19,1),fpppp(10,12,19,2),fpppp(10,12,19,3)/
     x 3.5644357d-06, 4.0113289d-05,-4.3497395d-09 /
      data fpppp(10,12,20,1),fpppp(10,12,20,2),fpppp(10,12,20,3)/
     x-2.1920870d-06,-5.3929419d-05, 2.3555734d-09 /
      data fpppp(10,12,21,1),fpppp(10,12,21,2),fpppp(10,12,21,3)/
     x-2.1920870d-06,-5.1290810d-05, 2.0897742d-09 /
      data fpppp(10,12,22,1),fpppp(10,12,22,2),fpppp(10,12,22,3)/
     x 3.5644357d-06, 2.9558856d-05,-3.2865425d-09 /
      data fpppp(10,12,23,1),fpppp(10,12,23,2),fpppp(10,12,23,3)/
     x 8.0487725d-06, 6.7992330d-05,-5.8663701d-09 /
      data fpppp(10,13, 1,1),fpppp(10,13, 1,2),fpppp(10,13, 1,3)/
     x-1.7902576d-04, 1.3353956d-03,-9.6536128d-07 /
      data fpppp(10,13, 2,1),fpppp(10,13, 2,2),fpppp(10,13, 2,3)/
     x-5.8030156d-04, 5.4201857d-04,-4.4977039d-07 /
      data fpppp(10,13, 3,1),fpppp(10,13, 3,2),fpppp(10,13, 3,3)/
     x-1.5542640d-03,-1.1267974d-03, 6.3856460d-07 /
      data fpppp(10,13, 4,1),fpppp(10,13, 4,2),fpppp(10,13, 4,3)/
     x-1.5542640d-03,-1.1815335d-03, 6.6744420d-07 /
      data fpppp(10,13, 5,1),fpppp(10,13, 5,2),fpppp(10,13, 5,3)/
     x-5.8030156d-04, 7.6096288d-04,-5.6528880d-07 /
      data fpppp(10,13, 6,1),fpppp(10,13, 6,2),fpppp(10,13, 6,3)/
     x-1.7902576d-04, 5.1435449d-04,-5.3216722d-07 /
      data fpppp(10,13, 7,1),fpppp(10,13, 7,2),fpppp(10,13, 7,3)/
     x-3.7767546d-06, 4.9841505d-04,-2.0659560d-07 /
      data fpppp(10,13, 8,1),fpppp(10,13, 8,2),fpppp(10,13, 8,3)/
     x 3.5819453d-05, 5.1417477d-04, 4.6453535d-08 /
      data fpppp(10,13, 9,1),fpppp(10,13, 9,2),fpppp(10,13, 9,3)/
     x-1.1885293d-04,-1.1421458d-04, 1.6094857d-07 /
      data fpppp(10,13,10,1),fpppp(10,13,10,2),fpppp(10,13,10,3)/
     x-7.5948758d-05,-3.6058351d-04, 4.9481763d-08 /
      data fpppp(10,13,11,1),fpppp(10,13,11,2),fpppp(10,13,11,3)/
     x-3.1160205d-05,-7.4369279d-05, 3.3848794d-08 /
      data fpppp(10,13,12,1),fpppp(10,13,12,2),fpppp(10,13,12,3)/
     x-1.9658351d-05,-6.1081027d-06, 1.2806585d-08 /
      data fpppp(10,13,13,1),fpppp(10,13,13,2),fpppp(10,13,13,3)/
     x-1.6805911d-05, 1.1497256d-05, 7.4188387d-10 /
      data fpppp(10,13,14,1),fpppp(10,13,14,2),fpppp(10,13,14,3)/
     x-1.5435677d-05, 5.9133876d-06,-1.6018903d-09 /
      data fpppp(10,13,15,1),fpppp(10,13,15,2),fpppp(10,13,15,3)/
     x-1.3492397d-05, 9.3648776d-06,-3.3091496d-09 /
      data fpppp(10,13,16,1),fpppp(10,13,16,2),fpppp(10,13,16,3)/
     x-1.4682299d-05, 2.2162261d-06,-9.1244709d-10 /
      data fpppp(10,13,17,1),fpppp(10,13,17,2),fpppp(10,13,17,3)/
     x-1.7506155d-05, 5.3414526d-06, 3.4766005d-09 /
      data fpppp(10,13,18,1),fpppp(10,13,18,2),fpppp(10,13,18,3)/
     x-2.1244513d-05, 2.3240107d-05, 6.5553772d-09 /
      data fpppp(10,13,19,1),fpppp(10,13,19,2),fpppp(10,13,19,3)/
     x-3.3808001d-05, 1.9652289d-05, 1.1007597d-08 /
      data fpppp(10,13,20,1),fpppp(10,13,20,2),fpppp(10,13,20,3)/
     x-4.0036052d-05,-3.7444866d-05,-4.7816058d-09 /
      data fpppp(10,13,21,1),fpppp(10,13,21,2),fpppp(10,13,21,3)/
     x-4.0036052d-05,-3.6350364d-05,-4.2205054d-09 /
      data fpppp(10,13,22,1),fpppp(10,13,22,2),fpppp(10,13,22,3)/
     x-3.3808001d-05, 1.5274279d-05, 8.7631957d-09 /
      data fpppp(10,13,23,1),fpppp(10,13,23,2),fpppp(10,13,23,3)/
     x-2.1244513d-05, 3.9657646d-05, 1.4971883d-08 /
      data fpppp(10,14, 1,1),fpppp(10,14, 1,2),fpppp(10,14, 1,3)/
     x-3.5597568d-04, 1.1325350d-03,-6.0155929d-07 /
      data fpppp(10,14, 2,1),fpppp(10,14, 2,2),fpppp(10,14, 2,3)/
     x-1.0321321d-03, 4.3160055d-04,-2.3527398d-07 /
      data fpppp(10,14, 3,1),fpppp(10,14, 3,2),fpppp(10,14, 3,3)/
     x-1.8084981d-03,-1.0466629d-03, 5.4234060d-07 /
      data fpppp(10,14, 4,1),fpppp(10,14, 4,2),fpppp(10,14, 4,3)/
     x-1.8084981d-03,-1.0882062d-03, 5.5508498d-07 /
      data fpppp(10,14, 5,1),fpppp(10,14, 5,2),fpppp(10,14, 5,3)/
     x-1.0321321d-03, 5.9777382d-04,-2.8625148d-07 /
      data fpppp(10,14, 6,1),fpppp(10,14, 6,2),fpppp(10,14, 6,3)/
     x-3.5597568d-04, 5.0938526d-04,-4.1039369d-07 /
      data fpppp(10,14, 7,1),fpppp(10,14, 7,2),fpppp(10,14, 7,3)/
     x 2.6015710d-04, 3.4508406d-04,-2.9291460d-07 /
      data fpppp(10,14, 8,1),fpppp(10,14, 8,2),fpppp(10,14, 8,3)/
     x 3.7589516d-04, 4.2990410d-04,-6.8002941d-08 /
      data fpppp(10,14, 9,1),fpppp(10,14, 9,2),fpppp(10,14, 9,3)/
     x 6.0886423d-04, 3.1377917d-04, 1.0199410d-08 /
      data fpppp(10,14,10,1),fpppp(10,14,10,2),fpppp(10,14,10,3)/
     x 4.5305381d-05,-3.8494440d-04, 1.2582766d-07 /
      data fpppp(10,14,11,1),fpppp(10,14,11,2),fpppp(10,14,11,3)/
     x-2.0507516d-05,-1.8263247d-04, 3.9598219d-08 /
      data fpppp(10,14,12,1),fpppp(10,14,12,2),fpppp(10,14,12,3)/
     x-1.6250325d-05,-1.7577436d-05, 2.6985136d-08 /
      data fpppp(10,14,13,1),fpppp(10,14,13,2),fpppp(10,14,13,3)/
     x-1.2438555d-05, 2.0512887d-06, 8.2532729d-09 /
      data fpppp(10,14,14,1),fpppp(10,14,14,2),fpppp(10,14,14,3)/
     x-1.1203316d-05, 6.4339350d-06,-4.7381500d-11 /
      data fpppp(10,14,15,1),fpppp(10,14,15,2),fpppp(10,14,15,3)/
     x-1.5711553d-05, 5.7643583d-06, 2.7927859d-10 /
      data fpppp(10,14,16,1),fpppp(10,14,16,2),fpppp(10,14,16,3)/
     x-1.9541358d-05, 1.9131279d-06, 1.9879420d-09 /
      data fpppp(10,14,17,1),fpppp(10,14,17,2),fpppp(10,14,17,3)/
     x-2.3152814d-05, 5.1394320d-06, 3.9904383d-09 /
      data fpppp(10,14,18,1),fpppp(10,14,18,2),fpppp(10,14,18,3)/
     x-2.8696108d-05, 7.4514603d-06, 6.0862052d-09 /
      data fpppp(10,14,19,1),fpppp(10,14,19,2),fpppp(10,14,19,3)/
     x-2.2849643d-05, 7.6928743d-06, 7.4702583d-09 /
      data fpppp(10,14,20,1),fpppp(10,14,20,2),fpppp(10,14,20,3)/
     x-1.6028485d-05,-1.9306855d-05,-1.0211140d-09 /
      data fpppp(10,14,21,1),fpppp(10,14,21,2),fpppp(10,14,21,3)/
     x-1.6028485d-05,-1.8697301d-05,-7.6731521d-10 /
      data fpppp(10,14,22,1),fpppp(10,14,22,2),fpppp(10,14,22,3)/
     x-2.2849643d-05, 5.2546550d-06, 6.4550633d-09 /
      data fpppp(10,14,23,1),fpppp(10,14,23,2),fpppp(10,14,23,3)/
     x-2.8696108d-05, 1.6594782d-05, 9.8931863d-09 /
      data fpppp(10,15, 1,1),fpppp(10,15, 1,2),fpppp(10,15, 1,3)/
     x 2.9884857d-05, 3.6261418d-04, 4.8176094d-07 /
      data fpppp(10,15, 2,1),fpppp(10,15, 2,2),fpppp(10,15, 2,3)/
     x 3.9008368d-04, 9.3915863d-05, 2.1834134d-07 /
      data fpppp(10,15, 3,1),fpppp(10,15, 3,2),fpppp(10,15, 3,3)/
     x 7.3787670d-04,-4.7633236d-04,-3.3278956d-07 /
      data fpppp(10,15, 4,1),fpppp(10,15, 4,2),fpppp(10,15, 4,3)/
     x 7.3787670d-04,-4.8601664d-04,-3.5613396d-07 /
      data fpppp(10,15, 5,1),fpppp(10,15, 5,2),fpppp(10,15, 5,3)/
     x 3.9008368d-04, 1.3265298d-04, 3.1171894d-07 /
      data fpppp(10,15, 6,1),fpppp(10,15, 6,2),fpppp(10,15, 6,3)/
     x 2.9884857d-05, 2.1734999d-04, 1.3159494d-07 /
      data fpppp(10,15, 7,1),fpppp(10,15, 7,2),fpppp(10,15, 7,3)/
     x-1.3566865d-03, 1.4945521d-04,-1.1450207d-07 /
      data fpppp(10,15, 8,1),fpppp(10,15, 8,2),fpppp(10,15, 8,3)/
     x-1.1439486d-03, 2.6396848d-04,-2.3891049d-07 /
      data fpppp(10,15, 9,1),fpppp(10,15, 9,2),fpppp(10,15, 9,3)/
     x-1.8520596d-03, 4.6453710d-04, 4.1648474d-07 /
      data fpppp(10,15,10,1),fpppp(10,15,10,2),fpppp(10,15,10,3)/
     x-4.1747170d-04,-6.4533243d-05,-1.6976749d-07 /
      data fpppp(10,15,11,1),fpppp(10,15,11,2),fpppp(10,15,11,3)/
     x-6.7520343d-06,-4.2374809d-04, 1.3782771d-07 /
      data fpppp(10,15,12,1),fpppp(10,15,12,2),fpppp(10,15,12,3)/
     x-3.8572896d-08, 5.7839037d-07, 1.4110418d-08 /
      data fpppp(10,15,13,1),fpppp(10,15,13,2),fpppp(10,15,13,3)/
     x-5.9819400d-06,-1.6130805d-05, 1.6905454d-08 /
      data fpppp(10,15,14,1),fpppp(10,15,14,2),fpppp(10,15,14,3)/
     x-8.1043777d-06, 4.3064282d-06, 5.9321508d-09 /
      data fpppp(10,15,15,1),fpppp(10,15,15,2),fpppp(10,15,15,3)/
     x-6.7111245d-06, 2.6070113d-06, 4.0886677d-09 /
      data fpppp(10,15,16,1),fpppp(10,15,16,2),fpppp(10,15,16,3)/
     x-5.1369774d-06, 2.2468386d-06, 4.2734146d-09 /
      data fpppp(10,15,17,1),fpppp(10,15,17,2),fpppp(10,15,17,3)/
     x-4.4310554d-06, 3.1821727d-07, 3.6140715d-09 /
      data fpppp(10,15,18,1),fpppp(10,15,18,2),fpppp(10,15,18,3)/
     x-1.8869543d-06, 2.6991063d-06, 4.5373649d-09 /
      data fpppp(10,15,19,1),fpppp(10,15,19,2),fpppp(10,15,19,3)/
     x 5.8635061d-06,-1.8522501d-06, 5.2686923d-09 /
      data fpppp(10,15,20,1),fpppp(10,15,20,2),fpppp(10,15,20,3)/
     x 1.9498586d-05,-5.7434747d-06,-4.5607917d-09 /
      data fpppp(10,15,21,1),fpppp(10,15,21,2),fpppp(10,15,21,3)/
     x 1.9498586d-05,-5.8733221d-06,-4.3083351d-09 /
      data fpppp(10,15,22,1),fpppp(10,15,22,2),fpppp(10,15,22,3)/
     x 5.8635061d-06,-1.3328605d-06, 4.2588657d-09 /
      data fpppp(10,15,23,1),fpppp(10,15,23,2),fpppp(10,15,23,3)/
     x-1.8869543d-06, 7.5139555d-07, 8.3242145d-09 /
      data fpppp(10,16, 1,1),fpppp(10,16, 1,2),fpppp(10,16, 1,3)/
     x-2.8681393d-04, 2.3084642d-05, 2.3698126d-07 /
      data fpppp(10,16, 2,1),fpppp(10,16, 2,2),fpppp(10,16, 2,3)/
     x-5.7279004d-04,-2.4459341d-05, 6.7467195d-08 /
      data fpppp(10,16, 3,1),fpppp(10,16, 3,2),fpppp(10,16, 3,3)/
     x 3.8231937d-04,-1.2237841d-04,-2.8928235d-07 /
      data fpppp(10,16, 4,1),fpppp(10,16, 4,2),fpppp(10,16, 4,3)/
     x 3.8231937d-04,-1.2930998d-04,-3.0064837d-07 /
      data fpppp(10,16, 5,1),fpppp(10,16, 5,2),fpppp(10,16, 5,3)/
     x-5.7279004d-04, 3.2669313d-06, 1.1293126d-07 /
      data fpppp(10,16, 6,1),fpppp(10,16, 6,2),fpppp(10,16, 6,3)/
     x-2.8681393d-04,-8.0888881d-05, 6.6491010d-08 /
      data fpppp(10,16, 7,1),fpppp(10,16, 7,2),fpppp(10,16, 7,3)/
     x 4.9571427d-03, 4.3537266d-04, 3.8745900d-07 /
      data fpppp(10,16, 8,1),fpppp(10,16, 8,2),fpppp(10,16, 8,3)/
     x 4.1300463d-03,-1.9961596d-03, 2.4518327d-07 /
      data fpppp(10,16, 9,1),fpppp(10,16, 9,2),fpppp(10,16, 9,3)/
     x 2.1978601d-03, 3.8392641d-03,-1.2285880d-06 /
      data fpppp(10,16,10,1),fpppp(10,16,10,2),fpppp(10,16,10,3)/
     x 1.3737707d-03,-1.6634415d-03, 7.7234233d-07 /
      data fpppp(10,16,11,1),fpppp(10,16,11,2),fpppp(10,16,11,3)/
     x 1.0218340d-04,-2.5678023d-04, 2.0860458d-08 /
      data fpppp(10,16,12,1),fpppp(10,16,12,2),fpppp(10,16,12,3)/
     x-4.3464500d-06,-7.5177625d-05, 4.3995034d-08 /
      data fpppp(10,16,13,1),fpppp(10,16,13,2),fpppp(10,16,13,3)/
     x-1.0634859d-06,-8.0089443d-06, 9.7480073d-09 /
      data fpppp(10,16,14,1),fpppp(10,16,14,2),fpppp(10,16,14,3)/
     x-4.4805763d-06,-3.1179186d-06, 1.0764545d-08 /
      data fpppp(10,16,15,1),fpppp(10,16,15,2),fpppp(10,16,15,3)/
     x-9.0503264d-06, 1.4996981d-06, 7.9998867d-09 /
      data fpppp(10,16,16,1),fpppp(10,16,16,2),fpppp(10,16,16,3)/
     x-1.3517021d-05, 1.1823186d-06, 5.2572884d-09 /
      data fpppp(10,16,17,1),fpppp(10,16,17,2),fpppp(10,16,17,3)/
     x-1.6369114d-05,-2.6000604d-06, 2.8438840d-09 /
      data fpppp(10,16,18,1),fpppp(10,16,18,2),fpppp(10,16,18,3)/
     x-1.3525899d-05, 2.8494221d-06,-1.7698633d-10 /
      data fpppp(10,16,19,1),fpppp(10,16,19,2),fpppp(10,16,19,3)/
     x-1.3519052d-05,-3.5321627d-06,-3.1503490d-09 /
      data fpppp(10,16,20,1),fpppp(10,16,20,2),fpppp(10,16,20,3)/
     x-1.0786062d-05,-1.3042975d-06,-4.4931113d-09 /
      data fpppp(10,16,21,1),fpppp(10,16,21,2),fpppp(10,16,21,3)/
     x-1.0786062d-05,-1.6565722d-06,-4.6045072d-09 /
      data fpppp(10,16,22,1),fpppp(10,16,22,2),fpppp(10,16,22,3)/
     x-1.3519052d-05,-2.1230636d-06,-2.7047654d-09 /
      data fpppp(10,16,23,1),fpppp(10,16,23,2),fpppp(10,16,23,3)/
     x-1.3525899d-05,-2.4346995d-06,-1.8479248d-09 /
      data fpppp(10,17, 1,1),fpppp(10,17, 1,2),fpppp(10,17, 1,3)/
     x 1.8735875d-03, 9.6333421d-07, 2.3929023d-08 /
      data fpppp(10,17, 2,1),fpppp(10,17, 2,2),fpppp(10,17, 2,3)/
     x 3.8900918d-03,-1.0275990d-05, 9.7099189d-09 /
      data fpppp(10,17, 3,1),fpppp(10,17, 3,2),fpppp(10,17, 3,3)/
     x 1.5676510d-03,-3.0757457d-06,-3.4056150d-08 /
      data fpppp(10,17, 4,1),fpppp(10,17, 4,2),fpppp(10,17, 4,3)/
     x 1.5676510d-03,-5.7823640d-05,-1.0787168d-08 /
      data fpppp(10,17, 5,1),fpppp(10,17, 5,2),fpppp(10,17, 5,3)/
     x 3.8900918d-03, 2.0871559d-04,-8.3366008d-08 /
      data fpppp(10,17, 6,1),fpppp(10,17, 6,2),fpppp(10,17, 6,3)/
     x 1.8735875d-03,-8.2025508d-04, 3.7296375d-07 /
      data fpppp(10,17, 7,1),fpppp(10,17, 7,2),fpppp(10,17, 7,3)/
     x-1.8017910d-02, 3.0815213d-03,-1.2670228d-06 /
      data fpppp(10,17, 8,1),fpppp(10,17, 8,2),fpppp(10,17, 8,3)/
     x-7.9237199d-03,-5.9553006d-03,-2.5274979d-07 /
      data fpppp(10,17, 9,1),fpppp(10,17, 9,2),fpppp(10,17, 9,3)/
     x 1.9335798d-03, 6.0717137d-03, 1.8735847d-06 /
      data fpppp(10,17,10,1),fpppp(10,17,10,2),fpppp(10,17,10,3)/
     x-7.8862406d-04,-2.9986441d-03,-4.1214516d-07 /
      data fpppp(10,17,11,1),fpppp(10,17,11,2),fpppp(10,17,11,3)/
     x 4.7908340d-05, 7.4251872d-04,-1.5861381d-07 /
      data fpppp(10,17,12,1),fpppp(10,17,12,2),fpppp(10,17,12,3)/
     x 8.1562922d-05,-2.9061785d-04,-3.1090166d-08 /
      data fpppp(10,17,13,1),fpppp(10,17,13,2),fpppp(10,17,13,3)/
     x 1.1922702d-05, 4.9818294d-05,-1.1874770d-08 /
      data fpppp(10,17,14,1),fpppp(10,17,14,2),fpppp(10,17,14,3)/
     x 1.3137771d-05,-2.1803568d-05, 1.1184280d-09 /
      data fpppp(10,17,15,1),fpppp(10,17,15,2),fpppp(10,17,15,3)/
     x 2.3643917d-05, 3.9283489d-06, 3.4940383d-09 /
      data fpppp(10,17,16,1),fpppp(10,17,16,2),fpppp(10,17,16,3)/
     x 3.5420897d-05,-9.0080252d-07, 3.8596626d-09 /
      data fpppp(10,17,17,1),fpppp(10,17,17,2),fpppp(10,17,17,3)/
     x 4.6696826d-05, 1.0922836d-07, 1.2192163d-09 /
      data fpppp(10,17,18,1),fpppp(10,17,18,2),fpppp(10,17,18,3)/
     x 5.1427730d-05,-4.1753783d-07,-2.0669459d-09 /
      data fpppp(10,17,19,1),fpppp(10,17,19,2),fpppp(10,17,19,3)/
     x 5.8833132d-05,-6.3515336d-07,-4.7660145d-09 /
      data fpppp(10,17,20,1),fpppp(10,17,20,2),fpppp(10,17,20,3)/
     x 6.0363260d-05,-8.4161770d-07,-5.7143632d-09 /
      data fpppp(10,17,21,1),fpppp(10,17,21,2),fpppp(10,17,21,3)/
     x 6.0363260d-05,-8.4737397d-07,-5.8214758d-09 /
      data fpppp(10,17,22,1),fpppp(10,17,22,2),fpppp(10,17,22,3)/
     x 5.8833132d-05,-6.1212826d-07,-4.3375640d-09 /
      data fpppp(10,17,23,1),fpppp(10,17,23,2),fpppp(10,17,23,3)/
     x 5.1427730d-05,-5.0388194d-07,-3.6736352d-09 /
      data fpppp(10,18, 1,1),fpppp(10,18, 1,2),fpppp(10,18, 1,3)/
     x-1.4728653d-03,-3.7054222d-03, 4.0815294d-08 /
      data fpppp(10,18, 2,1),fpppp(10,18, 2,2),fpppp(10,18, 2,3)/
     x-3.4079632d-03,-2.2901717d-03, 3.6887850d-08 /
      data fpppp(10,18, 3,1),fpppp(10,18, 3,2),fpppp(10,18, 3,3)/
     x-8.3210946d-04, 1.3730641d-03, 4.2975434d-08 /
      data fpppp(10,18, 4,1),fpppp(10,18, 4,2),fpppp(10,18, 4,3)/
     x-8.3210946d-04, 2.6959071d-04, 1.7594247d-08 /
      data fpppp(10,18, 5,1),fpppp(10,18, 5,2),fpppp(10,18, 5,3)/
     x-3.4079632d-03, 2.1237219d-03, 1.3841260d-07 /
      data fpppp(10,18, 6,1),fpppp(10,18, 6,2),fpppp(10,18, 6,3)/
     x-1.4728653d-03,-2.0257523d-02,-3.3990251d-07 /
      data fpppp(10,18, 7,1),fpppp(10,18, 7,2),fpppp(10,18, 7,3)/
     x 1.9247815d-02, 3.1053312d-02, 1.3278986d-06 /
      data fpppp(10,18, 8,1),fpppp(10,18, 8,2),fpppp(10,18, 8,3)/
     x 5.7546522d-03,-1.2861257d-02, 8.1107531d-08 /
      data fpppp(10,18, 9,1),fpppp(10,18, 9,2),fpppp(10,18, 9,3)/
     x-2.4873664d-03,-2.0357248d-03,-9.6690375d-07 /
      data fpppp(10,18,10,1),fpppp(10,18,10,2),fpppp(10,18,10,3)/
     x 7.1472696d-05, 1.5634611d-03,-1.7752224d-07 /
      data fpppp(10,18,11,1),fpppp(10,18,11,2),fpppp(10,18,11,3)/
     x-6.0757886d-06,-3.5646582d-04,-9.7702139d-09 /
      data fpppp(10,18,12,1),fpppp(10,18,12,2),fpppp(10,18,12,3)/
     x-4.3354879d-05,-1.6416336d-05,-2.7853886d-08 /
      data fpppp(10,18,13,1),fpppp(10,18,13,2),fpppp(10,18,13,3)/
     x 7.0653096d-06, 3.1694956d-05,-7.9658876d-09 /
      data fpppp(10,18,14,1),fpppp(10,18,14,2),fpppp(10,18,14,3)/
     x-4.3560233d-06,-1.1449067d-05,-6.0309014d-09 /
      data fpppp(10,18,15,1),fpppp(10,18,15,2),fpppp(10,18,15,3)/
     x-1.7750418d-05, 1.8555766d-07,-3.7285013d-09 /
      data fpppp(10,18,16,1),fpppp(10,18,16,2),fpppp(10,18,16,3)/
     x-2.8807619d-05, 1.8527859d-07,-4.2534489d-09 /
      data fpppp(10,18,17,1),fpppp(10,18,17,2),fpppp(10,18,17,3)/
     x-3.8894988d-05,-3.1066228d-06,-5.6982476d-09 /
      data fpppp(10,18,18,1),fpppp(10,18,18,2),fpppp(10,18,18,3)/
     x-4.4284047d-05, 1.0603788d-06,-7.4477272d-09 /
      data fpppp(10,18,19,1),fpppp(10,18,19,2),fpppp(10,18,19,3)/
     x-4.9795316d-05,-3.0530938d-06,-9.1181062d-09 /
      data fpppp(10,18,20,1),fpppp(10,18,20,2),fpppp(10,18,20,3)/
     x-5.1169020d-05,-5.0140705d-07,-1.0706886d-08 /
      data fpppp(10,18,21,1),fpppp(10,18,21,2),fpppp(10,18,21,3)/
     x-5.1169020d-05,-7.5319153d-07,-1.0750982d-08 /
      data fpppp(10,18,22,1),fpppp(10,18,22,2),fpppp(10,18,22,3)/
     x-4.9795316d-05,-2.0459558d-06,-8.9417236d-09 /
      data fpppp(10,18,23,1),fpppp(10,18,23,2),fpppp(10,18,23,3)/
     x-4.4284047d-05,-2.7163884d-06,-8.1091619d-09 /
      data fpppp(10,19, 1,1),fpppp(10,19, 1,2),fpppp(10,19, 1,3)/
     x-3.2459311d-03, 4.8889730d-17,-7.9951495d-09 /
      data fpppp(10,19, 2,1),fpppp(10,19, 2,2),fpppp(10,19, 2,3)/
     x-7.3457505d-03, 9.4663735d-18, 3.9798580d-08 /
      data fpppp(10,19, 3,1),fpppp(10,19, 3,2),fpppp(10,19, 3,3)/
     x-2.2075579d-03,-1.0918139d-18, 1.7091977d-07 /
      data fpppp(10,19, 4,1),fpppp(10,19, 4,2),fpppp(10,19, 4,3)/
     x-2.2075579d-03,-8.5483491d-18, 1.2068417d-07 /
      data fpppp(10,19, 5,1),fpppp(10,19, 5,2),fpppp(10,19, 5,3)/
     x-7.3457505d-03, 1.3971639d-17, 2.4074096d-07 /
      data fpppp(10,19, 6,1),fpppp(10,19, 6,2),fpppp(10,19, 6,3)/
     x-3.2459311d-03,-7.6276656d-18,-7.6152906d-07 /
      data fpppp(10,19, 7,1),fpppp(10,19, 7,2),fpppp(10,19, 7,3)/
     x 3.9301889d-02,-6.6242951d-19, 2.7087047d-06 /
      data fpppp(10,19, 8,1),fpppp(10,19, 8,2),fpppp(10,19, 8,3)/
     x 1.2080985d-02,-6.3391137d-18, 1.7731046d-07 /
      data fpppp(10,19, 9,1),fpppp(10,19, 9,2),fpppp(10,19, 9,3)/
     x-5.7206937d-03, 8.0437620d-18,-2.1094890d-06 /
      data fpppp(10,19,10,1),fpppp(10,19,10,2),fpppp(10,19,10,3)/
     x 6.8000447d-05,-1.3871738d-17,-3.4835944d-07 /
      data fpppp(10,19,11,1),fpppp(10,19,11,2),fpppp(10,19,11,3)/
     x-6.0143041d-05,-4.6893011d-18, 4.5268277d-08 /
      data fpppp(10,19,12,1),fpppp(10,19,12,2),fpppp(10,19,12,3)/
     x-1.0803634d-04,-2.2713630d-18,-4.6995172d-08 /
      data fpppp(10,19,13,1),fpppp(10,19,13,2),fpppp(10,19,13,3)/
     x 7.3060829d-06, 5.8789783d-18,-1.1351765d-08 /
      data fpppp(10,19,14,1),fpppp(10,19,14,2),fpppp(10,19,14,3)/
     x-1.1817777d-05,-8.0268232d-18,-1.3893599d-08 /
      data fpppp(10,19,15,1),fpppp(10,19,15,2),fpppp(10,19,15,3)/
     x-3.7976588d-05, 1.3331505d-17,-1.0174843d-08 /
      data fpppp(10,19,16,1),fpppp(10,19,16,2),fpppp(10,19,16,3)/
     x-6.0702869d-05,-4.1321040d-18,-1.0447850d-08 /
      data fpppp(10,19,17,1),fpppp(10,19,17,2),fpppp(10,19,17,3)/
     x-8.2013158d-05, 2.7383460d-18,-1.1103484d-08 /
      data fpppp(10,19,18,1),fpppp(10,19,18,2),fpppp(10,19,18,3)/
     x-9.4091421d-05, 2.0080529d-18,-1.1831131d-08 /
      data fpppp(10,19,19,1),fpppp(10,19,19,2),fpppp(10,19,19,3)/
     x-1.0671501d-04, 1.5407771d-18,-1.2688362d-08 /
      data fpppp(10,19,20,1),fpppp(10,19,20,2),fpppp(10,19,20,3)/
     x-1.1050656d-04,-1.8939176d-18,-1.4621903d-08 /
      data fpppp(10,19,21,1),fpppp(10,19,21,2),fpppp(10,19,21,3)/
     x-1.1050656d-04, 2.3766857d-18,-1.4619763d-08 /
      data fpppp(10,19,22,1),fpppp(10,19,22,2),fpppp(10,19,22,3)/
     x-1.0671501d-04, 1.8036563d-17,-1.2696923d-08 /
      data fpppp(10,19,23,1),fpppp(10,19,23,2),fpppp(10,19,23,3)/
     x-9.4091421d-05,-8.6501177d-18,-1.1799027d-08 /
      data fpppp(11, 1, 1,1),fpppp(11, 1, 1,2),fpppp(11, 1, 1,3)/
     x 2.6049629d-02, 6.5151120d-17, 1.8292299d-06 /
      data fpppp(11, 1, 2,1),fpppp(11, 1, 2,2),fpppp(11, 1, 2,3)/
     x 3.0042288d-02, 2.2323801d-16, 2.9707203d-08 /
      data fpppp(11, 1, 3,1),fpppp(11, 1, 3,2),fpppp(11, 1, 3,3)/
     x-1.2091907d-02,-9.3891074d-17,-2.4322804d-06 /
      data fpppp(11, 1, 4,1),fpppp(11, 1, 4,2),fpppp(11, 1, 4,3)/
     x-1.2091907d-02, 1.0551750d-17,-4.8720122d-06 /
      data fpppp(11, 1, 5,1),fpppp(11, 1, 5,2),fpppp(11, 1, 5,3)/
     x 3.0042288d-02,-1.0589078d-16, 9.7886344d-06 /
      data fpppp(11, 1, 6,1),fpppp(11, 1, 6,2),fpppp(11, 1, 6,3)/
     x 2.6049629d-02, 3.9086864d-18,-3.4766747d-05 /
      data fpppp(11, 1, 7,1),fpppp(11, 1, 7,2),fpppp(11, 1, 7,3)/
     x 2.7782974d-02, 9.0750076d-17, 3.0709727d-05 /
      data fpppp(11, 1, 8,1),fpppp(11, 1, 8,2),fpppp(11, 1, 8,3)/
     x 1.4208155d-02, 1.1913676d-17,-2.5664192d-06 /
      data fpppp(11, 1, 9,1),fpppp(11, 1, 9,2),fpppp(11, 1, 9,3)/
     x 1.3560984d-02,-1.4705388d-16, 3.0489441d-06 /
      data fpppp(11, 1,10,1),fpppp(11, 1,10,2),fpppp(11, 1,10,3)/
     x 1.0354529d-02, 2.4032868d-17,-1.5295183d-07 /
      data fpppp(11, 1,11,1),fpppp(11, 1,11,2),fpppp(11, 1,11,3)/
     x 1.4696636d-02,-1.5373060d-16, 3.7520256d-07 /
      data fpppp(11, 1,12,1),fpppp(11, 1,12,2),fpppp(11, 1,12,3)/
     x 2.5982807d-02,-8.7638694d-18, 5.0117789d-08 /
      data fpppp(11, 1,13,1),fpppp(11, 1,13,2),fpppp(11, 1,13,3)/
     x 2.0520980d-02,-3.9624874d-17, 3.8004067d-07 /
      data fpppp(11, 1,14,1),fpppp(11, 1,14,2),fpppp(11, 1,14,3)/
     x 1.0169920d-02,-5.2691067d-17,-1.4003036d-07 /
      data fpppp(11, 1,15,1),fpppp(11, 1,15,2),fpppp(11, 1,15,3)/
     x-9.7544311d-03,-6.6532696d-18, 3.1392651d-06 /
      data fpppp(11, 1,16,1),fpppp(11, 1,16,2),fpppp(11, 1,16,3)/
     x 1.4913437d-02,-4.9111254d-18,-2.7533061d-06 /
      data fpppp(11, 1,17,1),fpppp(11, 1,17,2),fpppp(11, 1,17,3)/
     x 2.5029211d-02,-1.2251409d-16, 3.1126538d-05 /
      data fpppp(11, 1,18,1),fpppp(11, 1,18,2),fpppp(11, 1,18,3)/
     x 2.9370595d-02,-3.9637013d-17,-3.6339438d-05 /
      data fpppp(11, 1,19,1),fpppp(11, 1,19,2),fpppp(11, 1,19,3)/
     x 2.2967348d-02,-9.0702581d-19, 1.1232699d-05 /
      data fpppp(11, 1,20,1),fpppp(11, 1,20,2),fpppp(11, 1,20,3)/
     x-1.8597913d-02, 5.6517835d-17,-5.0067581d-06 /
      data fpppp(11, 1,21,1),fpppp(11, 1,21,2),fpppp(11, 1,21,3)/
     x-1.8597913d-02, 4.6300758d-17,-2.3888522d-06 /
      data fpppp(11, 1,22,1),fpppp(11, 1,22,2),fpppp(11, 1,22,3)/
     x 2.2967348d-02, 1.0309952d-17, 7.6107530d-07 /
      data fpppp(11, 1,23,1),fpppp(11, 1,23,2),fpppp(11, 1,23,3)/
     x 2.9370595d-02, 9.3823863d-18, 2.9291497d-06 /
      data fpppp(11, 2, 1,1),fpppp(11, 2, 1,2),fpppp(11, 2, 1,3)/
     x 1.6289888d-02, 1.4687264d-02, 3.1176792d-06 /
      data fpppp(11, 2, 2,1),fpppp(11, 2, 2,2),fpppp(11, 2, 2,3)/
     x 1.8217415d-02, 7.8126202d-03, 1.5508526d-06 /
      data fpppp(11, 2, 3,1),fpppp(11, 2, 3,2),fpppp(11, 2, 3,3)/
     x-2.6301244d-03,-6.5005058d-03,-1.0606662d-06 /
      data fpppp(11, 2, 4,1),fpppp(11, 2, 4,2),fpppp(11, 2, 4,3)/
     x-2.6301244d-03,-7.2324506d-03,-2.3661082d-06 /
      data fpppp(11, 2, 5,1),fpppp(11, 2, 5,2),fpppp(11, 2, 5,3)/
     x 1.8217415d-02, 1.0740400d-02, 6.7726204d-06 /
      data fpppp(11, 2, 6,1),fpppp(11, 2, 6,2),fpppp(11, 2, 6,3)/
     x 1.6289888d-02, 3.7080913d-03,-1.6463950d-05 /
      data fpppp(11, 2, 7,1),fpppp(11, 2, 7,2),fpppp(11, 2, 7,3)/
     x 1.7048831d-02,-1.2144058d-03, 1.2935854d-05 /
      data fpppp(11, 2, 8,1),fpppp(11, 2, 8,2),fpppp(11, 2, 8,3)/
     x 9.6210993d-03,-3.3705725d-03,-1.3057506d-06 /
      data fpppp(11, 2, 9,1),fpppp(11, 2, 9,2),fpppp(11, 2, 9,3)/
     x 9.3619803d-03, 6.4084792d-04, 1.2306997d-06 /
      data fpppp(11, 2,10,1),fpppp(11, 2,10,2),fpppp(11, 2,10,3)/
     x 7.2948217d-03, 7.8104441d-04,-1.4329873d-07 /
      data fpppp(11, 2,11,1),fpppp(11, 2,11,2),fpppp(11, 2,11,3)/
     x 9.5889507d-03,-4.1766725d-03, 8.6396566d-08 /
      data fpppp(11, 2,12,1),fpppp(11, 2,12,2),fpppp(11, 2,12,3)/
     x 1.5353008d-02, 4.4071006d-03,-5.0859900d-08 /
      data fpppp(11, 2,13,1),fpppp(11, 2,13,2),fpppp(11, 2,13,3)/
     x 1.2582042d-02, 1.6505700d-03, 8.9554265d-08 /
      data fpppp(11, 2,14,1),fpppp(11, 2,14,2),fpppp(11, 2,14,3)/
     x 7.0888408d-03,-3.4854200d-03,-1.3635738d-07 /
      data fpppp(11, 2,15,1),fpppp(11, 2,15,2),fpppp(11, 2,15,3)/
     x-6.1657041d-04, 1.9571239d-03, 1.2699865d-06 /
      data fpppp(11, 2,16,1),fpppp(11, 2,16,2),fpppp(11, 2,16,3)/
     x 9.9754004d-03,-3.9429041d-03,-1.3658569d-06 /
      data fpppp(11, 2,17,1),fpppp(11, 2,17,2),fpppp(11, 2,17,3)/
     x 1.5022297d-02,-1.4198812d-03, 1.3108063d-05 /
      data fpppp(11, 2,18,1),fpppp(11, 2,18,2),fpppp(11, 2,18,3)/
     x 1.7847375d-02, 6.9663220d-03,-1.7011574d-05 /
      data fpppp(11, 2,19,1),fpppp(11, 2,19,2),fpppp(11, 2,19,3)/
     x 1.4724091d-02, 7.2783541d-03, 7.3525237d-06 /
      data fpppp(11, 2,20,1),fpppp(11, 2,20,2),fpppp(11, 2,20,3)/
     x-5.7059013d-03,-6.6822167d-03,-2.4747385d-06 /
      data fpppp(11, 2,21,1),fpppp(11, 2,21,2),fpppp(11, 2,21,3)/
     x-5.7059013d-03,-6.3581519d-03,-1.1005223d-06 /
      data fpppp(11, 2,22,1),fpppp(11, 2,22,2),fpppp(11, 2,22,3)/
     x 1.4724091d-02, 5.9820949d-03, 1.8556592d-06 /
      data fpppp(11, 2,23,1),fpppp(11, 2,23,2),fpppp(11, 2,23,3)/
     x 1.7847375d-02, 1.1827294d-02, 3.6016682d-06 /
      data fpppp(11, 3, 1,1),fpppp(11, 3, 1,2),fpppp(11, 3, 1,3)/
     x 6.2092965d-03,-5.3911464d-03,-2.3412547d-05 /
      data fpppp(11, 3, 2,1),fpppp(11, 3, 2,2),fpppp(11, 3, 2,3)/
     x-6.6137742d-03,-3.1930307d-03,-1.4059588d-05 /
      data fpppp(11, 3, 3,1),fpppp(11, 3, 3,2),fpppp(11, 3, 3,3)/
     x 2.1612562d-02, 8.6003473d-04, 2.9570658d-06 /
      data fpppp(11, 3, 4,1),fpppp(11, 3, 4,2),fpppp(11, 3, 4,3)/
     x 2.1612562d-02, 2.0101040d-03, 8.2515182d-06 /
      data fpppp(11, 3, 5,1),fpppp(11, 3, 5,2),fpppp(11, 3, 5,3)/
     x-6.6137742d-03,-7.7933078d-03,-3.5237397d-05 /
      data fpppp(11, 3, 6,1),fpppp(11, 3, 6,2),fpppp(11, 3, 6,3)/
     x 6.2092965d-03, 1.1859892d-02, 5.6004240d-05 /
      data fpppp(11, 3, 7,1),fpppp(11, 3, 7,2),fpppp(11, 3, 7,3)/
     x-1.4149860d-02,-7.6398876d-03,-3.1231027d-05 /
      data fpppp(11, 3, 8,1),fpppp(11, 3, 8,2),fpppp(11, 3, 8,3)/
     x 4.7534279d-03, 8.6702990d-04, 4.0739130d-06 /
      data fpppp(11, 3, 9,1),fpppp(11, 3, 9,2),fpppp(11, 3, 9,3)/
     x 5.7606910d-03,-2.3385377d-04,-3.5297828d-06 /
      data fpppp(11, 3,10,1),fpppp(11, 3,10,2),fpppp(11, 3,10,3)/
     x 1.7647196d-02, 1.1039128d-03, 3.5575146d-08 /
      data fpppp(11, 3,11,1),fpppp(11, 3,11,2),fpppp(11, 3,11,3)/
     x 8.9498208d-03,-5.9525946d-04,-6.3898241d-07 /
      data fpppp(11, 3,12,1),fpppp(11, 3,12,2),fpppp(11, 3,12,3)/
     x-9.0782114d-04,-2.0964560d-03,-2.2817223d-07 /
      data fpppp(11, 3,13,1),fpppp(11, 3,13,2),fpppp(11, 3,13,3)/
     x 7.0775953d-03, 6.1406534d-03,-6.2284799d-07 /
      data fpppp(11, 3,14,1),fpppp(11, 3,14,2),fpppp(11, 3,14,3)/
     x 1.9637079d-02,-1.8622344d-02, 2.2474941d-08 /
      data fpppp(11, 3,15,1),fpppp(11, 3,15,2),fpppp(11, 3,15,3)/
     x 3.1830840d-02, 2.8892897d-02,-3.5356413d-06 /
      data fpppp(11, 3,16,1),fpppp(11, 3,16,2),fpppp(11, 3,16,3)/
     x 4.5264975d-03,-1.7865256d-02, 4.1440387d-06 /
      data fpppp(11, 3,17,1),fpppp(11, 3,17,2),fpppp(11, 3,17,3)/
     x 9.0105731d-04,-9.5411302d-04,-3.1263301d-05 /
      data fpppp(11, 3,18,1),fpppp(11, 3,18,2),fpppp(11, 3,18,3)/
     x 3.4016343d-03, 7.8338488d-03, 5.6628147d-05 /
      data fpppp(11, 3,19,1),fpppp(11, 3,19,2),fpppp(11, 3,19,3)/
     x-2.2968920d-03,-5.6709395d-03,-3.6256696d-05 /
      data fpppp(11, 3,20,1),fpppp(11, 3,20,2),fpppp(11, 3,20,3)/
     x 2.4354347d-02, 1.6058655d-03, 8.5490277d-06 /
      data fpppp(11, 3,21,1),fpppp(11, 3,21,2),fpppp(11, 3,21,3)/
     x 2.4354347d-02, 8.0362034d-04, 3.1474052d-06 /
      data fpppp(11, 3,22,1),fpppp(11, 3,22,2),fpppp(11, 3,22,3)/
     x-2.2968920d-03,-2.4619590d-03,-1.4650206d-05 /
      data fpppp(11, 3,23,1),fpppp(11, 3,23,2),fpppp(11, 3,23,3)/
     x 3.4016343d-03,-4.1998281d-03,-2.4396191d-05 /
      data fpppp(11, 4, 1,1),fpppp(11, 4, 1,2),fpppp(11, 4, 1,3)/
     x-2.7483152d-03, 9.8341962d-03, 4.7422591d-05 /
      data fpppp(11, 4, 2,1),fpppp(11, 4, 2,2),fpppp(11, 4, 2,3)/
     x 1.4077147d-02, 5.6924638d-03, 3.0290522d-05 /
      data fpppp(11, 4, 3,1),fpppp(11, 4, 3,2),fpppp(11, 4, 3,3)/
     x-5.8779159d-03,-2.0057226d-03,-2.2866147d-06 /
      data fpppp(11, 4, 4,1),fpppp(11, 4, 4,2),fpppp(11, 4, 4,3)/
     x-5.8779159d-03,-4.0653926d-03,-9.5218838d-06 /
      data fpppp(11, 4, 5,1),fpppp(11, 4, 5,2),fpppp(11, 4, 5,3)/
     x 1.4077147d-02, 1.3931144d-02, 5.9231598d-05 /
      data fpppp(11, 4, 6,1),fpppp(11, 4, 6,2),fpppp(11, 4, 6,3)/
     x-2.7483152d-03,-2.1060855d-02,-6.1106445d-05 /
      data fpppp(11, 4, 7,1),fpppp(11, 4, 7,2),fpppp(11, 4, 7,3)/
     x 2.6277369d-02, 2.5775370d-02, 1.6977616d-05 /
      data fpppp(11, 4, 8,1),fpppp(11, 4, 8,2),fpppp(11, 4, 8,3)/
     x 8.6791017d-04,-1.8757813d-02,-4.9629057d-06 /
      data fpppp(11, 4, 9,1),fpppp(11, 4, 9,2),fpppp(11, 4, 9,3)/
     x 6.7402295d-05, 1.4693947d-02, 2.0075681d-06 /
      data fpppp(11, 4,10,1),fpppp(11, 4,10,2),fpppp(11, 4,10,3)/
     x-1.8942715d-02,-1.4421466d-02,-3.7782373d-07 /
      data fpppp(11, 4,11,1),fpppp(11, 4,11,2),fpppp(11, 4,11,3)/
     x-7.3292530d-03, 3.2259812d-03, 1.6364406d-07 /
      data fpppp(11, 4,12,1),fpppp(11, 4,12,2),fpppp(11, 4,12,3)/
     x 2.5399525d-03, 3.3735295d-03,-1.3831331d-07 /
      data fpppp(11, 4,13,1),fpppp(11, 4,13,2),fpppp(11, 4,13,3)/
     x-6.9475696d-03, 5.9772242d-03, 1.4145522d-07 /
      data fpppp(11, 4,14,1),fpppp(11, 4,14,2),fpppp(11, 4,14,3)/
     x-2.2517294d-02,-1.7626928d-02,-3.6175042d-07 /
      data fpppp(11, 4,15,1),fpppp(11, 4,15,2),fpppp(11, 4,15,3)/
     x-1.7305174d-02, 1.3059564d-02, 1.9359531d-06 /
      data fpppp(11, 4,16,1),fpppp(11, 4,16,2),fpppp(11, 4,16,3)/
     x 8.6562593d-04,-3.5798782d-03,-4.7746282d-06 /
      data fpppp(11, 4,17,1),fpppp(11, 4,17,2),fpppp(11, 4,17,3)/
     x 1.1799564d-03, 7.6391182d-04, 1.6600448d-05 /
      data fpppp(11, 4,18,1),fpppp(11, 4,18,2),fpppp(11, 4,18,3)/
     x-8.1528611d-04,-4.5427023d-03,-5.9823629d-05 /
      data fpppp(11, 4,19,1),fpppp(11, 4,19,2),fpppp(11, 4,19,3)/
     x 1.1404169d-02, 8.5737449d-03, 5.9185741d-05 /
      data fpppp(11, 4,20,1),fpppp(11, 4,20,2),fpppp(11, 4,20,3)/
     x-5.6742316d-03,-2.8433906d-03,-1.0148319d-05 /
      data fpppp(11, 4,21,1),fpppp(11, 4,21,2),fpppp(11, 4,21,3)/
     x-5.6742316d-03,-1.9678632d-03,-2.9632590d-06 /
      data fpppp(11, 4,22,1),fpppp(11, 4,22,2),fpppp(11, 4,22,3)/
     x 1.1404169d-02, 5.0716353d-03, 3.0445501d-05 /
      data fpppp(11, 4,23,1),fpppp(11, 4,23,2),fpppp(11, 4,23,3)/
     x-8.1528611d-04, 8.5902086d-03, 4.7952271d-05 /
      data fpppp(11, 5, 1,1),fpppp(11, 5, 1,2),fpppp(11, 5, 1,3)/
     x 5.9624562d-04,-1.2360812d-03,-3.6303231d-05 /
      data fpppp(11, 5, 2,1),fpppp(11, 5, 2,2),fpppp(11, 5, 2,3)/
     x-9.0546275d-03,-7.0067097d-04,-2.2727601d-05 /
      data fpppp(11, 5, 3,1),fpppp(11, 5, 3,2),fpppp(11, 5, 3,3)/
     x 5.1768045d-03, 3.4827227d-04, 3.8132531d-06 /
      data fpppp(11, 5, 4,1),fpppp(11, 5, 4,2),fpppp(11, 5, 4,3)/
     x 5.1768045d-03, 5.2040994d-04, 8.2753673d-06 /
      data fpppp(11, 5, 5,1),fpppp(11, 5, 5,2),fpppp(11, 5, 5,3)/
     x-9.0546275d-03,-1.3892216d-03,-4.0576058d-05 /
      data fpppp(11, 5, 6,1),fpppp(11, 5, 6,2),fpppp(11, 5, 6,3)/
     x 5.9624562d-04, 1.3459838d-03, 3.0628482d-05 /
      data fpppp(11, 5, 7,1),fpppp(11, 5, 7,2),fpppp(11, 5, 7,3)/
     x-1.5703786d-02,-8.0344562d-04,-2.8810965d-06 /
      data fpppp(11, 5, 8,1),fpppp(11, 5, 8,2),fpppp(11, 5, 8,3)/
     x 4.1119124d-04, 2.0293421d-04, 2.5192434d-06 /
      data fpppp(11, 5, 9,1),fpppp(11, 5, 9,2),fpppp(11, 5, 9,3)/
     x 6.4602161d-04,-6.6904212d-05,-5.8692504d-07 /
      data fpppp(11, 5,10,1),fpppp(11, 5,10,2),fpppp(11, 5,10,3)/
     x 1.2624964d-02, 7.0940914d-06, 7.6767438d-08 /
      data fpppp(11, 5,11,1),fpppp(11, 5,11,2),fpppp(11, 5,11,3)/
     x 5.7586465d-03,-1.4700527d-05,-1.0958918d-07 /
      data fpppp(11, 5,12,1),fpppp(11, 5,12,2),fpppp(11, 5,12,3)/
     x-1.1599934d-04,-8.3543422d-06,-8.6408418d-09 /
      data fpppp(11, 5,13,1),fpppp(11, 5,13,2),fpppp(11, 5,13,3)/
     x 5.3058880d-03,-4.1243284d-06,-9.8272250d-08 /
      data fpppp(11, 5,14,1),fpppp(11, 5,14,2),fpppp(11, 5,14,3)/
     x 1.4965532d-02,-2.4948217d-05, 6.7390469d-08 /
      data fpppp(11, 5,15,1),fpppp(11, 5,15,2),fpppp(11, 5,15,3)/
     x 5.2947907d-03, 4.9163595d-05,-5.3304663d-07 /
      data fpppp(11, 5,16,1),fpppp(11, 5,16,2),fpppp(11, 5,16,3)/
     x 3.8705562d-04,-9.3171858d-05, 2.2828726d-06 /
      data fpppp(11, 5,17,1),fpppp(11, 5,17,2),fpppp(11, 5,17,3)/
     x 3.2752222d-04,-4.5085249d-05,-2.6445706d-06 /
      data fpppp(11, 5,18,1),fpppp(11, 5,18,2),fpppp(11, 5,18,3)/
     x-4.6018157d-04, 1.4705966d-04, 2.9091208d-05 /
      data fpppp(11, 5,19,1),fpppp(11, 5,19,2),fpppp(11, 5,19,3)/
     x-7.5290910d-03,-5.4131853d-04,-4.0265454d-05 /
      data fpppp(11, 5,20,1),fpppp(11, 5,20,2),fpppp(11, 5,20,3)/
     x 1.5191716d-03, 3.5554530d-04, 9.0490415d-06 /
      data fpppp(11, 5,21,1),fpppp(11, 5,21,2),fpppp(11, 5,21,3)/
     x 1.5191716d-03, 3.0300189d-04, 4.6643852d-06 /
      data fpppp(11, 5,22,1),fpppp(11, 5,22,2),fpppp(11, 5,22,3)/
     x-7.5290910d-03,-3.3114486d-04,-2.2726829d-05 /
      data fpppp(11, 5,23,1),fpppp(11, 5,23,2),fpppp(11, 5,23,3)/
     x-4.6018157d-04,-6.4109159d-04,-3.6678637d-05 /
      data fpppp(11, 6, 1,1),fpppp(11, 6, 1,2),fpppp(11, 6, 1,3)/
     x 1.0131218d-04, 3.6484245d-03, 1.0168530d-05 /
      data fpppp(11, 6, 2,1),fpppp(11, 6, 2,2),fpppp(11, 6, 2,3)/
     x 2.2107902d-03, 2.0058635d-03, 6.2595961d-06 /
      data fpppp(11, 6, 3,1),fpppp(11, 6, 3,2),fpppp(11, 6, 3,3)/
     x-6.1149796d-03,-1.3377448d-03,-1.4362866d-06 /
      data fpppp(11, 6, 4,1),fpppp(11, 6, 4,2),fpppp(11, 6, 4,3)/
     x-6.1149796d-03,-1.6460342d-03,-2.6269952d-06 /
      data fpppp(11, 6, 5,1),fpppp(11, 6, 5,2),fpppp(11, 6, 5,3)/
     x 2.2107902d-03, 3.2390209d-03, 1.1022430d-05 /
      data fpppp(11, 6, 6,1),fpppp(11, 6, 6,2),fpppp(11, 6, 6,3)/
     x 1.0131218d-04,-9.7591593d-04,-7.6920979d-06 /
      data fpppp(11, 6, 7,1),fpppp(11, 6, 7,2),fpppp(11, 6, 7,3)/
     x 4.5539105d-03, 1.9368804d-04, 8.9659259d-07 /
      data fpppp(11, 6, 8,1),fpppp(11, 6, 8,2),fpppp(11, 6, 8,3)/
     x 1.0916226d-04,-8.3834352d-05,-7.7102474d-07 /
      data fpppp(11, 6, 9,1),fpppp(11, 6, 9,2),fpppp(11, 6, 9,3)/
     x-2.5826516d-06, 7.7244651d-06, 9.7697085d-08 /
      data fpppp(11, 6,10,1),fpppp(11, 6,10,2),fpppp(11, 6,10,3)/
     x-3.2320417d-03,-9.6264206d-06,-4.4189374d-08 /
      data fpppp(11, 6,11,1),fpppp(11, 6,11,2),fpppp(11, 6,11,3)/
     x-1.3961365d-03,-1.8399224d-06, 2.6880975d-08 /
      data fpppp(11, 6,12,1),fpppp(11, 6,12,2),fpppp(11, 6,12,3)/
     x 1.7690196d-04, 4.3714969d-07, 7.6267255d-09 /
      data fpppp(11, 6,13,1),fpppp(11, 6,13,2),fpppp(11, 6,13,3)/
     x-1.2811898d-03,-3.4416814d-06, 3.1145274d-08 /
      data fpppp(11, 6,14,1),fpppp(11, 6,14,2),fpppp(11, 6,14,3)/
     x-3.8688080d-03,-2.4718102d-06,-2.2327483d-08 /
      data fpppp(11, 6,15,1),fpppp(11, 6,15,2),fpppp(11, 6,15,3)/
     x-1.2985957d-03,-7.1192025d-06, 1.1734604d-07 /
      data fpppp(11, 6,16,1),fpppp(11, 6,16,2),fpppp(11, 6,16,3)/
     x 9.2929770d-05,-1.1415281d-05,-6.5511657d-07 /
      data fpppp(11, 6,17,1),fpppp(11, 6,17,2),fpppp(11, 6,17,3)/
     x 1.1954074d-04,-1.6977514d-05, 9.2821921d-07 /
      data fpppp(11, 6,18,1),fpppp(11, 6,18,2),fpppp(11, 6,18,3)/
     x 4.1404237d-04,-6.1011799d-05,-7.4167269d-06 /
      data fpppp(11, 6,19,1),fpppp(11, 6,19,2),fpppp(11, 6,19,3)/
     x 2.5684151d-03, 4.7593289d-05, 1.1374914d-05 /
      data fpppp(11, 6,20,1),fpppp(11, 6,20,2),fpppp(11, 6,20,3)/
     x-5.1355828d-05, 3.3101832d-05,-3.1750348d-06 /
      data fpppp(11, 6,21,1),fpppp(11, 6,21,2),fpppp(11, 6,21,3)/
     x-5.1355828d-05, 3.8578150d-05,-1.9607175d-06 /
      data fpppp(11, 6,22,1),fpppp(11, 6,22,2),fpppp(11, 6,22,3)/
     x 2.5684151d-03, 2.5688016d-05, 6.5176453d-06 /
      data fpppp(11, 6,23,1),fpppp(11, 6,23,2),fpppp(11, 6,23,3)/
     x 4.1404237d-04, 2.1132972d-05, 1.0798033d-05 /
      data fpppp(11, 7, 1,1),fpppp(11, 7, 1,2),fpppp(11, 7, 1,3)/
     x-4.6783483d-04, 1.8181753d-04,-1.2878299d-08 /
      data fpppp(11, 7, 2,1),fpppp(11, 7, 2,2),fpppp(11, 7, 2,3)/
     x 4.3056822d-03, 9.1007119d-05,-2.7369759d-07 /
      data fpppp(11, 7, 3,1),fpppp(11, 7, 3,2),fpppp(11, 7, 3,3)/
     x 3.0283843d-03,-9.6586529d-05,-8.9370054d-07 /
      data fpppp(11, 7, 4,1),fpppp(11, 7, 4,2),fpppp(11, 7, 4,3)/
     x 3.0283843d-03,-1.0883670d-04,-7.8676772d-07 /
      data fpppp(11, 7, 5,1),fpppp(11, 7, 5,2),fpppp(11, 7, 5,3)/
     x 4.3056822d-03, 1.4000780d-04,-7.0142888d-07 /
      data fpppp(11, 7, 6,1),fpppp(11, 7, 6,2),fpppp(11, 7, 6,3)/
     x-4.6783483d-04,-1.9350257d-06, 1.5911141d-06 /
      data fpppp(11, 7, 7,1),fpppp(11, 7, 7,2),fpppp(11, 7, 7,3)/
     x-1.2698626d-03, 3.4452066d-06,-1.0206812d-08 /
      data fpppp(11, 7, 8,1),fpppp(11, 7, 8,2),fpppp(11, 7, 8,3)/
     x 1.8838264d-05,-6.2739967d-07, 2.5126264d-07 /
      data fpppp(11, 7, 9,1),fpppp(11, 7, 9,2),fpppp(11, 7, 9,3)/
     x 6.9921625d-05, 4.0770569d-06, 3.0041462d-08 /
      data fpppp(11, 7,10,1),fpppp(11, 7,10,2),fpppp(11, 7,10,3)/
     x 9.3831236d-04, 7.3449956d-06, 4.1523954d-08 /
      data fpppp(11, 7,11,1),fpppp(11, 7,11,2),fpppp(11, 7,11,3)/
     x 4.4186147d-04, 5.8840462d-06, 1.5024931d-08 /
      data fpppp(11, 7,12,1),fpppp(11, 7,12,2),fpppp(11, 7,12,3)/
     x 1.2997041d-05, 3.8746578d-06, 1.5361429d-08 /
      data fpppp(11, 7,13,1),fpppp(11, 7,13,2),fpppp(11, 7,13,3)/
     x 3.9833390d-04, 1.0007263d-05, 1.9181539d-08 /
      data fpppp(11, 7,14,1),fpppp(11, 7,14,2),fpppp(11, 7,14,3)/
     x 1.0719508d-03,-1.7776187d-05, 4.2850426d-08 /
      data fpppp(11, 7,15,1),fpppp(11, 7,15,2),fpppp(11, 7,15,3)/
     x 4.0824317d-04, 3.8567742d-05, 3.3088217d-08 /
      data fpppp(11, 7,16,1),fpppp(11, 7,16,2),fpppp(11, 7,16,3)/
     x-2.0838927d-05,-1.6872900d-05, 2.4203968d-07 /
      data fpppp(11, 7,17,1),fpppp(11, 7,17,2),fpppp(11, 7,17,3)/
     x-7.9087947d-05, 1.7394092d-05,-1.0147589d-07 /
      data fpppp(11, 7,18,1),fpppp(11, 7,18,2),fpppp(11, 7,18,3)/
     x-2.6380948d-04, 9.9952339d-06, 2.0970126d-06 /
      data fpppp(11, 7,19,1),fpppp(11, 7,19,2),fpppp(11, 7,19,3)/
     x-1.0497814d-03, 7.0955619d-05,-2.1717247d-06 /
      data fpppp(11, 7,20,1),fpppp(11, 7,20,2),fpppp(11, 7,20,3)/
     x-6.2828597d-04,-7.8157435d-05,-6.3170669d-08 /
      data fpppp(11, 7,21,1),fpppp(11, 7,21,2),fpppp(11, 7,21,3)/
     x-6.2828597d-04,-7.1960608d-05,-3.1250908d-07 /
      data fpppp(11, 7,22,1),fpppp(11, 7,22,2),fpppp(11, 7,22,3)/
     x-1.0497814d-03, 4.6168313d-05,-1.1743710d-06 /
      data fpppp(11, 7,23,1),fpppp(11, 7,23,2),fpppp(11, 7,23,3)/
     x-2.6380948d-04, 1.0294763d-04,-1.6430635d-06 /
      data fpppp(11, 8, 1,1),fpppp(11, 8, 1,2),fpppp(11, 8, 1,3)/
     x 1.1931244d-03,-1.3270888d-03,-5.0212208d-06 /
      data fpppp(11, 8, 2,1),fpppp(11, 8, 2,2),fpppp(11, 8, 2,3)/
     x-2.1307786d-02,-7.2588932d-04,-2.8774783d-06 /
      data fpppp(11, 8, 3,1),fpppp(11, 8, 3,2),fpppp(11, 8, 3,3)/
     x-3.4651833d-03, 5.0003713d-04, 1.4579827d-06 /
      data fpppp(11, 8, 4,1),fpppp(11, 8, 4,2),fpppp(11, 8, 4,3)/
     x-3.4651833d-03, 6.0916401d-04, 1.9099605d-06 /
      data fpppp(11, 8, 5,1),fpppp(11, 8, 5,2),fpppp(11, 8, 5,3)/
     x-2.1307786d-02,-1.1623968d-03,-4.6853896d-06 /
      data fpppp(11, 8, 6,1),fpppp(11, 8, 6,2),fpppp(11, 8, 6,3)/
     x 1.1931244d-03, 3.0981429d-04, 1.7584467d-06 /
      data fpppp(11, 8, 7,1),fpppp(11, 8, 7,2),fpppp(11, 8, 7,3)/
     x 4.9903569d-04,-8.1445384d-05,-5.3670547d-08 /
      data fpppp(11, 8, 8,1),fpppp(11, 8, 8,2),fpppp(11, 8, 8,3)/
     x 3.3929110d-05, 1.7952056d-05, 1.4618997d-07 /
      data fpppp(11, 8, 9,1),fpppp(11, 8, 9,2),fpppp(11, 8, 9,3)/
     x 3.3029630d-05, 3.2788641d-07, 5.4779129d-08 /
      data fpppp(11, 8,10,1),fpppp(11, 8,10,2),fpppp(11, 8,10,3)/
     x-1.9355844d-04, 1.5177712d-05, 4.4589526d-08 /
      data fpppp(11, 8,11,1),fpppp(11, 8,11,2),fpppp(11, 8,11,3)/
     x-6.4644292d-05, 1.1764559d-05, 3.0633364d-08 /
      data fpppp(11, 8,12,1),fpppp(11, 8,12,2),fpppp(11, 8,12,3)/
     x 4.6842709d-05, 1.3876671d-05, 3.0535330d-08 /
      data fpppp(11, 8,13,1),fpppp(11, 8,13,2),fpppp(11, 8,13,3)/
     x-6.6338733d-05, 4.8131925d-08, 2.7683409d-08 /
      data fpppp(11, 8,14,1),fpppp(11, 8,14,2),fpppp(11, 8,14,3)/
     x-2.3541788d-04, 2.1683374d-05, 3.3858640d-08 /
      data fpppp(11, 8,15,1),fpppp(11, 8,15,2),fpppp(11, 8,15,3)/
     x-1.0443550d-04,-2.7993758d-06, 4.5094805d-08 /
      data fpppp(11, 8,16,1),fpppp(11, 8,16,2),fpppp(11, 8,16,3)/
     x 6.2429770d-06, 1.0633302d-05, 1.3250122d-08 /
      data fpppp(11, 8,17,1),fpppp(11, 8,17,2),fpppp(11, 8,17,3)/
     x 4.5913428d-07, 8.9199907d-06, 1.2232154d-07 /
      data fpppp(11, 8,18,1),fpppp(11, 8,18,2),fpppp(11, 8,18,3)/
     x 2.8312192d-05, 1.5058788d-05,-4.7920440d-07 /
      data fpppp(11, 8,19,1),fpppp(11, 8,19,2),fpppp(11, 8,19,3)/
     x 2.1985830d-04, 1.9500242d-05, 6.4895094d-07 /
      data fpppp(11, 8,20,1),fpppp(11, 8,20,2),fpppp(11, 8,20,3)/
     x 1.2916480d-04,-5.0716374d-05,-3.1822838d-07 /
      data fpppp(11, 8,21,1),fpppp(11, 8,21,2),fpppp(11, 8,21,3)/
     x 1.2916480d-04,-4.8950114d-05,-2.4325185d-07 /
      data fpppp(11, 8,22,1),fpppp(11, 8,22,2),fpppp(11, 8,22,3)/
     x 2.1985830d-04, 1.2435202d-05, 3.4904480d-07 /
      data fpppp(11, 8,23,1),fpppp(11, 8,23,2),fpppp(11, 8,23,3)/
     x 2.8312192d-05, 4.1552686d-05, 6.4544364d-07 /
      data fpppp(11, 9, 1,1),fpppp(11, 9, 1,2),fpppp(11, 9, 1,3)/
     x-3.5702077d-03, 2.6425917d-02, 8.2801302d-06 /
      data fpppp(11, 9, 2,1),fpppp(11, 9, 2,2),fpppp(11, 9, 2,3)/
     x 3.3093138d-02, 1.5672146d-02, 4.9646434d-06 /
      data fpppp(11, 9, 3,1),fpppp(11, 9, 3,2),fpppp(11, 9, 3,3)/
     x 5.8876697d-03,-5.5705568d-03,-1.6362898d-06 /
      data fpppp(11, 9, 4,1),fpppp(11, 9, 4,2),fpppp(11, 9, 4,3)/
     x 5.8876697d-03,-8.7224703d-03,-2.5177320d-06 /
      data fpppp(11, 9, 5,1),fpppp(11, 9, 5,2),fpppp(11, 9, 5,3)/
     x 3.3093138d-02, 2.8279800d-02, 8.4904120d-06 /
      data fpppp(11, 9, 6,1),fpppp(11, 9, 6,2),fpppp(11, 9, 6,3)/
     x-3.5702077d-03,-2.0852786d-02,-4.9415019d-06 /
      data fpppp(11, 9, 7,1),fpppp(11, 9, 7,2),fpppp(11, 9, 7,3)/
     x-6.3573109d-04, 5.7757754d-03,-7.2510236d-09 /
      data fpppp(11, 9, 8,1),fpppp(11, 9, 8,2),fpppp(11, 9, 8,3)/
     x-3.8950543d-06,-1.5535481d-03,-9.5261254d-08 /
      data fpppp(11, 9, 9,1),fpppp(11, 9, 9,2),fpppp(11, 9, 9,3)/
     x 9.8383700d-06, 4.1589411d-04, 2.6656984d-08 /
      data fpppp(11, 9,10,1),fpppp(11, 9,10,2),fpppp(11, 9,10,3)/
     x 7.3514494d-05,-9.9675833d-05, 1.1136826d-08 /
      data fpppp(11, 9,11,1),fpppp(11, 9,11,2),fpppp(11, 9,11,3)/
     x 4.3494207d-05, 5.2545554d-05, 2.1551107d-08 /
      data fpppp(11, 9,12,1),fpppp(11, 9,12,2),fpppp(11, 9,12,3)/
     x 9.4912352d-06, 8.5821518d-07, 1.9240385d-08 /
      data fpppp(11, 9,13,1),fpppp(11, 9,13,2),fpppp(11, 9,13,3)/
     x 3.9766394d-05, 2.7076034d-05, 2.2882791d-08 /
      data fpppp(11, 9,14,1),fpppp(11, 9,14,2),fpppp(11, 9,14,3)/
     x 5.9593938d-05,-9.5430654d-06, 2.1460011d-08 /
      data fpppp(11, 9,15,1),fpppp(11, 9,15,2),fpppp(11, 9,15,3)/
     x 3.2734138d-05, 1.7824609d-05, 2.4554611d-08 /
      data fpppp(11, 9,16,1),fpppp(11, 9,16,2),fpppp(11, 9,16,3)/
     x-3.4505946d-06, 4.9461434d-06, 3.2366642d-08 /
      data fpppp(11, 9,17,1),fpppp(11, 9,17,2),fpppp(11, 9,17,3)/
     x-6.3836170d-06, 9.4637280d-06,-1.8995380d-09 /
      data fpppp(11, 9,18,1),fpppp(11, 9,18,2),fpppp(11, 9,18,3)/
     x-2.2442487d-05, 1.2193588d-05, 1.3575539d-07 /
      data fpppp(11, 9,19,1),fpppp(11, 9,19,2),fpppp(11, 9,19,3)/
     x-6.8387658d-05, 1.4377556d-05,-2.0215119d-07 /
      data fpppp(11, 9,20,1),fpppp(11, 9,20,2),fpppp(11, 9,20,3)/
     x-3.3886796d-05,-4.1722362d-05,-4.5777757d-08 /
      data fpppp(11, 9,21,1),fpppp(11, 9,21,2),fpppp(11, 9,21,3)/
     x-3.3886796d-05,-4.0375973d-05,-6.5281595d-08 /
      data fpppp(11, 9,22,1),fpppp(11, 9,22,2),fpppp(11, 9,22,3)/
     x-6.8387658d-05, 8.9919999d-06,-1.2413584d-07 /
      data fpppp(11, 9,23,1),fpppp(11, 9,23,2),fpppp(11, 9,23,3)/
     x-2.2442487d-05, 3.2389424d-05,-1.5680218d-07 /
      data fpppp(11,10, 1,1),fpppp(11,10, 1,2),fpppp(11,10, 1,3)/
     x 3.2388335d-03,-8.9314822d-04,-4.3793528d-06 /
      data fpppp(11,10, 2,1),fpppp(11,10, 2,2),fpppp(11,10, 2,3)/
     x-2.0765601d-02,-5.6284386d-04,-2.7927101d-06 /
      data fpppp(11,10, 3,1),fpppp(11,10, 3,2),fpppp(11,10, 3,3)/
     x-3.6039355d-03,-2.6247071d-06, 2.3816770d-07 /
      data fpppp(11,10, 4,1),fpppp(11,10, 4,2),fpppp(11,10, 4,3)/
     x-3.6039355d-03, 2.5563314d-04, 8.8404164d-07 /
      data fpppp(11,10, 5,1),fpppp(11,10, 5,2),fpppp(11,10, 5,3)/
     x-2.0765601d-02,-1.5958753d-03,-5.3762058d-06 /
      data fpppp(11,10, 6,1),fpppp(11,10, 6,2),fpppp(11,10, 6,3)/
     x 3.2388335d-03, 2.9807195d-03, 5.3087563d-06 /
      data fpppp(11,10, 7,1),fpppp(11,10, 7,2),fpppp(11,10, 7,3)/
     x-5.8072162d-04,-1.6612496d-03,-4.2859926d-07 /
      data fpppp(11,10, 8,1),fpppp(11,10, 8,2),fpppp(11,10, 8,3)/
     x-4.8992606d-04,-1.5399779d-05,-4.2168466d-07 /
      data fpppp(11,10, 9,1),fpppp(11,10, 9,2),fpppp(11,10, 9,3)/
     x-1.5137977d-04,-7.3340416d-05,-1.1673434d-07 /
      data fpppp(11,10,10,1),fpppp(11,10,10,2),fpppp(11,10,10,3)/
     x-6.7352578d-05, 1.4588274d-05,-4.3288039d-08 /
      data fpppp(11,10,11,1),fpppp(11,10,11,2),fpppp(11,10,11,3)/
     x-2.9877157d-05, 1.5821496d-05,-4.7056849d-09 /
      data fpppp(11,10,12,1),fpppp(11,10,12,2),fpppp(11,10,12,3)/
     x-8.7653957d-06, 1.9020772d-05, 5.8059155d-09 /
      data fpppp(11,10,13,1),fpppp(11,10,13,2),fpppp(11,10,13,3)/
     x-1.4617397d-05, 1.2365252d-05, 9.1621803d-09 /
      data fpppp(11,10,14,1),fpppp(11,10,14,2),fpppp(11,10,14,3)/
     x-1.1225362d-05, 6.5600958d-06, 1.1651512d-08 /
      data fpppp(11,10,15,1),fpppp(11,10,15,2),fpppp(11,10,15,3)/
     x-1.6963179d-06, 1.0318024d-05, 1.1469209d-08 /
      data fpppp(11,10,16,1),fpppp(11,10,16,2),fpppp(11,10,16,3)/
     x 9.7168481d-06, 8.7321612d-06, 5.3632734d-09 /
      data fpppp(11,10,17,1),fpppp(11,10,17,2),fpppp(11,10,17,3)/
     x 7.1055252d-06, 2.7653578d-06, 7.3430426d-10 /
      data fpppp(11,10,18,1),fpppp(11,10,18,2),fpppp(11,10,18,3)/
     x 1.5060070d-05, 2.0523021d-05,-4.8407854d-08 /
      data fpppp(11,10,19,1),fpppp(11,10,19,2),fpppp(11,10,19,3)/
     x 2.2852516d-05, 1.5704185d-05, 2.8998998d-08 /
      data fpppp(11,10,20,1),fpppp(11,10,20,2),fpppp(11,10,20,3)/
     x 2.1522831d-05,-3.9297833d-05,-3.6530524d-08 /
      data fpppp(11,10,21,1),fpppp(11,10,21,2),fpppp(11,10,21,3)/
     x 2.1522831d-05,-3.8308176d-05,-3.1404544d-08 /
      data fpppp(11,10,22,1),fpppp(11,10,22,2),fpppp(11,10,22,3)/
     x 2.2852516d-05, 1.1745558d-05, 8.4950814d-09 /
      data fpppp(11,10,23,1),fpppp(11,10,23,2),fpppp(11,10,23,3)/
     x 1.5060070d-05, 3.5367875d-05, 2.8481835d-08 /
      data fpppp(11,11, 1,1),fpppp(11,11, 1,2),fpppp(11,11, 1,3)/
     x-7.4632943d-04, 1.0651444d-05, 1.2172013d-06 /
      data fpppp(11,11, 2,1),fpppp(11,11, 2,2),fpppp(11,11, 2,3)/
     x 6.1001912d-03,-5.7474419d-05, 6.5469609d-07 /
      data fpppp(11,11, 3,1),fpppp(11,11, 3,2),fpppp(11,11, 3,3)/
     x 1.5373841d-03,-2.3273843d-04,-4.2757801d-07 /
      data fpppp(11,11, 4,1),fpppp(11,11, 4,2),fpppp(11,11, 4,3)/
     x 1.5373841d-03,-1.8149840d-04,-6.4299303d-07 /
      data fpppp(11,11, 5,1),fpppp(11,11, 5,2),fpppp(11,11, 5,3)/
     x 6.1001912d-03,-2.6243451d-04, 1.5163562d-06 /
      data fpppp(11,11, 6,1),fpppp(11,11, 6,2),fpppp(11,11, 6,3)/
     x-7.4632943d-04, 7.7925179d-04,-2.0140240d-06 /
      data fpppp(11,11, 7,1),fpppp(11,11, 7,2),fpppp(11,11, 7,3)/
     x 9.2781366d-04, 6.5502907d-04, 1.1701066d-06 /
      data fpppp(11,11, 8,1),fpppp(11,11, 8,2),fpppp(11,11, 8,3)/
     x 2.7257654d-06,-7.1596200d-04, 3.6898661d-07 /
      data fpppp(11,11, 9,1),fpppp(11,11, 9,2),fpppp(11,11, 9,3)/
     x-1.0204504d-04,-1.6781909d-04,-7.0485041d-08 /
      data fpppp(11,11,10,1),fpppp(11,11,10,2),fpppp(11,11,10,3)/
     x-7.3087593d-05,-4.5865967d-05,-3.6989762d-08 /
      data fpppp(11,11,11,1),fpppp(11,11,11,2),fpppp(11,11,11,3)/
     x-4.1122556d-05, 6.3190725d-06,-1.8942592d-08 /
      data fpppp(11,11,12,1),fpppp(11,11,12,2),fpppp(11,11,12,3)/
     x-2.7116222d-05, 1.5619116d-05,-3.6205593d-10 /
      data fpppp(11,11,13,1),fpppp(11,11,13,2),fpppp(11,11,13,3)/
     x-1.4930120d-05, 1.1292535d-05, 3.1947488d-09 /
      data fpppp(11,11,14,1),fpppp(11,11,14,2),fpppp(11,11,14,3)/
     x-7.5575358d-06, 1.1390217d-05, 3.6069057d-09 /
      data fpppp(11,11,15,1),fpppp(11,11,15,2),fpppp(11,11,15,3)/
     x-4.7949606d-06, 7.5162200d-06, 1.3504315d-09 /
      data fpppp(11,11,16,1),fpppp(11,11,16,2),fpppp(11,11,16,3)/
     x-8.0904459d-07, 4.4069944d-06,-2.2202231d-09 /
      data fpppp(11,11,17,1),fpppp(11,11,17,2),fpppp(11,11,17,3)/
     x 9.0332835d-06, 6.8171115d-06,-4.8976105d-09 /
      data fpppp(11,11,18,1),fpppp(11,11,18,2),fpppp(11,11,18,3)/
     x 1.1423624d-05, 1.5648779d-05, 3.7162445d-09 /
      data fpppp(11,11,19,1),fpppp(11,11,19,2),fpppp(11,11,19,3)/
     x 1.7296189d-05, 3.2042920d-05,-2.5265722d-08 /
      data fpppp(11,11,20,1),fpppp(11,11,20,2),fpppp(11,11,20,3)/
     x 1.9769726d-05,-4.3159564d-05,-5.3667255d-10 /
      data fpppp(11,11,21,1),fpppp(11,11,21,2),fpppp(11,11,21,3)/
     x 1.9769726d-05,-4.0715483d-05,-2.4601942d-09 /
      data fpppp(11,11,22,1),fpppp(11,11,22,2),fpppp(11,11,22,3)/
     x 1.7296189d-05, 2.2266597d-05,-1.7571635d-08 /
      data fpppp(11,11,23,1),fpppp(11,11,23,2),fpppp(11,11,23,3)/
     x 1.1423624d-05, 5.2309989d-05,-2.5136580d-08 /
      data fpppp(11,12, 1,1),fpppp(11,12, 1,2),fpppp(11,12, 1,3)/
     x 3.0692042d-04, 5.4480325d-04,-2.8305784d-07 /
      data fpppp(11,12, 2,1),fpppp(11,12, 2,2),fpppp(11,12, 2,3)/
     x-1.2300447d-03, 2.0346210d-04,-2.4147369d-07 /
      data fpppp(11,12, 3,1),fpppp(11,12, 3,2),fpppp(11,12, 3,3)/
     x 2.9564604d-04,-5.2402801d-04,-1.8125260d-07 /
      data fpppp(11,12, 4,1),fpppp(11,12, 4,2),fpppp(11,12, 4,3)/
     x 2.9564604d-04,-5.3094966d-04,-1.3069898d-07 /
      data fpppp(11,12, 5,1),fpppp(11,12, 5,2),fpppp(11,12, 5,3)/
     x-1.2300447d-03, 2.3114866d-04,-4.4368821d-07 /
      data fpppp(11,12, 6,1),fpppp(11,12, 6,2),fpppp(11,12, 6,3)/
     x 3.0692042d-04, 4.4097863d-04, 4.7524661d-07 /
      data fpppp(11,12, 7,1),fpppp(11,12, 7,2),fpppp(11,12, 7,3)/
     x-8.2656746d-05, 6.9051006d-04,-2.4270544d-07 /
      data fpppp(11,12, 8,1),fpppp(11,12, 8,2),fpppp(11,12, 8,3)/
     x 9.2839252d-05,-7.8028111d-05, 2.6822446d-07 /
      data fpppp(11,12, 9,1),fpppp(11,12, 9,2),fpppp(11,12, 9,3)/
     x-2.9183645d-04,-3.6663707d-04, 1.3704782d-07 /
      data fpppp(11,12,10,1),fpppp(11,12,10,2),fpppp(11,12,10,3)/
     x-6.3938960d-05,-1.3449194d-04, 2.0387569d-08 /
      data fpppp(11,12,11,1),fpppp(11,12,11,2),fpppp(11,12,11,3)/
     x-3.6053999d-05,-2.0691063d-05, 5.3008013d-09 /
      data fpppp(11,12,12,1),fpppp(11,12,12,2),fpppp(11,12,12,3)/
     x-2.3524306d-05, 6.8662916d-06,-7.9717244d-10 /
      data fpppp(11,12,13,1),fpppp(11,12,13,2),fpppp(11,12,13,3)/
     x-1.6449946d-05, 9.4321810d-06, 1.5519980d-09 /
      data fpppp(11,12,14,1),fpppp(11,12,14,2),fpppp(11,12,14,3)/
     x-1.1507690d-05, 1.2579920d-05,-4.9234717d-10 /
      data fpppp(11,12,15,1),fpppp(11,12,15,2),fpppp(11,12,15,3)/
     x-7.8833454d-06, 6.4427865d-06,-3.3912586d-09 /
      data fpppp(11,12,16,1),fpppp(11,12,16,2),fpppp(11,12,16,3)/
     x-4.4278452d-06, 3.4174034d-06,-3.6278764d-09 /
      data fpppp(11,12,17,1),fpppp(11,12,17,2),fpppp(11,12,17,3)/
     x-1.6362076d-06, 4.5354879d-06, 8.3844241d-10 /
      data fpppp(11,12,18,1),fpppp(11,12,18,2),fpppp(11,12,18,3)/
     x 3.8970036d-06, 1.6271960d-05,-6.4084620d-10 /
      data fpppp(11,12,19,1),fpppp(11,12,19,2),fpppp(11,12,19,3)/
     x-6.6495516d-07, 3.6396970d-05, 7.3647352d-10 /
      data fpppp(11,12,20,1),fpppp(11,12,20,2),fpppp(11,12,20,3)/
     x-2.1611778d-05,-4.3683095d-05,-7.4940612d-10 /
      data fpppp(11,12,21,1),fpppp(11,12,21,2),fpppp(11,12,21,3)/
     x-2.1611778d-05,-4.0953868d-05,-6.5111197d-10 /
      data fpppp(11,12,22,1),fpppp(11,12,22,2),fpppp(11,12,22,3)/
     x-6.6495516d-07, 2.5480064d-05, 3.4329690d-10 /
      data fpppp(11,12,23,1),fpppp(11,12,23,2),fpppp(11,12,23,3)/
     x 3.8970036d-06, 5.7210359d-05, 8.3356614d-10 /
      data fpppp(11,13, 1,1),fpppp(11,13, 1,2),fpppp(11,13, 1,3)/
     x-1.8829509d-04, 1.0363723d-03,-7.4579816d-07 /
      data fpppp(11,13, 2,1),fpppp(11,13, 2,2),fpppp(11,13, 2,3)/
     x-7.1481422d-05, 4.1928534d-04,-3.4351498d-07 /
      data fpppp(11,13, 3,1),fpppp(11,13, 3,2),fpppp(11,13, 3,3)/
     x-1.0863535d-03,-8.8267205d-04, 5.1007126d-07 /
      data fpppp(11,13, 4,1),fpppp(11,13, 4,2),fpppp(11,13, 4,3)/
     x-1.0863535d-03,-9.1832277d-04, 5.2485728d-07 /
      data fpppp(11,13, 5,1),fpppp(11,13, 5,2),fpppp(11,13, 5,3)/
     x-7.1481422d-05, 5.6188821d-04,-4.0265906d-07 /
      data fpppp(11,13, 6,1),fpppp(11,13, 6,2),fpppp(11,13, 6,3)/
     x-1.8829509d-04, 5.0161154d-04,-5.2400783d-07 /
      data fpppp(11,13, 7,1),fpppp(11,13, 7,2),fpppp(11,13, 7,3)/
     x 1.4802242d-04, 5.6083627d-04,-1.1448757d-07 /
      data fpppp(11,13, 8,1),fpppp(11,13, 8,2),fpppp(11,13, 8,3)/
     x 2.8967308d-04, 2.8801361d-04, 4.5771851d-08 /
      data fpppp(11,13, 9,1),fpppp(11,13, 9,2),fpppp(11,13, 9,3)/
     x 9.2288346d-04,-2.4154159d-04, 1.1267129d-07 /
      data fpppp(11,13,10,1),fpppp(11,13,10,2),fpppp(11,13,10,3)/
     x-3.7663103d-05,-2.5661554d-04, 4.4673103d-08 /
      data fpppp(11,13,11,1),fpppp(11,13,11,2),fpppp(11,13,11,3)/
     x-2.3799867d-05,-6.0256850d-05, 3.4307402d-08 /
      data fpppp(11,13,12,1),fpppp(11,13,12,2),fpppp(11,13,12,3)/
     x-1.7399092d-05,-5.0085297d-06, 1.1765068d-08 /
      data fpppp(11,13,13,1),fpppp(11,13,13,2),fpppp(11,13,13,3)/
     x-1.4337911d-05, 5.6343094d-06, 1.4519557d-09 /
      data fpppp(11,13,14,1),fpppp(11,13,14,2),fpppp(11,13,14,3)/
     x-1.1968474d-05, 1.0608014d-05,-7.1062492d-10 /
      data fpppp(11,13,15,1),fpppp(11,13,15,2),fpppp(11,13,15,3)/
     x-1.3540712d-05, 6.1299687d-06,-2.7076621d-09 /
      data fpppp(11,13,16,1),fpppp(11,13,16,2),fpppp(11,13,16,3)/
     x-1.5157341d-05, 3.0505322d-06,-1.1861040d-09 /
      data fpppp(11,13,17,1),fpppp(11,13,17,2),fpppp(11,13,17,3)/
     x-1.5661171d-05, 3.3161300d-06, 3.1774370d-09 /
      data fpppp(11,13,18,1),fpppp(11,13,18,2),fpppp(11,13,18,3)/
     x-1.9884005d-05, 1.1818660d-05, 6.9905888d-09 /
      data fpppp(11,13,19,1),fpppp(11,13,19,2),fpppp(11,13,19,3)/
     x-2.5686812d-05, 2.1516252d-05, 8.2724376d-09 /
      data fpppp(11,13,20,1),fpppp(11,13,20,2),fpppp(11,13,20,3)/
     x-3.0985979d-05,-3.0625915d-05,-3.8595916d-09 /
      data fpppp(11,13,21,1),fpppp(11,13,21,2),fpppp(11,13,21,3)/
     x-3.0985979d-05,-2.9010538d-05,-3.5299969d-09 /
      data fpppp(11,13,22,1),fpppp(11,13,22,2),fpppp(11,13,22,3)/
     x-2.5686812d-05, 1.5054745d-05, 6.9540586d-09 /
      data fpppp(11,13,23,1),fpppp(11,13,23,2),fpppp(11,13,23,3)/
     x-1.9884005d-05, 3.6049311d-05, 1.1934510d-08 /
      data fpppp(11,14, 1,1),fpppp(11,14, 1,2),fpppp(11,14, 1,3)/
     x 1.3512860d-04, 8.6247916d-04,-4.5973937d-07 /
      data fpppp(11,14, 2,1),fpppp(11,14, 2,2),fpppp(11,14, 2,3)/
     x-5.2786182d-04, 3.2496884d-04,-1.7593674d-07 /
      data fpppp(11,14, 3,1),fpppp(11,14, 3,2),fpppp(11,14, 3,3)/
     x-1.2019805d-03,-8.1051020d-04, 4.2631876d-07 /
      data fpppp(11,14, 4,1),fpppp(11,14, 4,2),fpppp(11,14, 4,3)/
     x-1.2019805d-03,-8.3908559d-04, 4.3663147d-07 /
      data fpppp(11,14, 5,1),fpppp(11,14, 5,2),fpppp(11,14, 5,3)/
     x-5.2786182d-04, 4.3927038d-04,-2.1718758d-07 /
      data fpppp(11,14, 6,1),fpppp(11,14, 6,2),fpppp(11,14, 6,3)/
     x 1.3512860d-04, 4.3384837d-04,-3.0504873d-07 /
      data fpppp(11,14, 7,1),fpppp(11,14, 7,2),fpppp(11,14, 7,3)/
     x-9.2814233d-05, 3.9315339d-04,-2.6777851d-07 /
      data fpppp(11,14, 8,1),fpppp(11,14, 8,2),fpppp(11,14, 8,3)/
     x-6.4056312d-04, 4.0108750d-04,-9.0621477d-08 /
      data fpppp(11,14, 9,1),fpppp(11,14, 9,2),fpppp(11,14, 9,3)/
     x-3.4617133d-03, 6.6100186d-05, 3.9539724d-08 /
      data fpppp(11,14,10,1),fpppp(11,14,10,2),fpppp(11,14,10,3)/
     x-1.9110364d-05,-3.5465796d-04, 1.0165888d-07 /
      data fpppp(11,14,11,1),fpppp(11,14,11,2),fpppp(11,14,11,3)/
     x-1.3082002d-05,-1.1764159d-04, 3.8921449d-08 /
      data fpppp(11,14,12,1),fpppp(11,14,12,2),fpppp(11,14,12,3)/
     x-9.8501111d-06,-1.7690306d-05, 2.4110604d-08 /
      data fpppp(11,14,13,1),fpppp(11,14,13,2),fpppp(11,14,13,3)/
     x-9.6317324d-06, 1.0559949d-06, 7.7735091d-09 /
      data fpppp(11,14,14,1),fpppp(11,14,14,2),fpppp(11,14,14,3)/
     x-1.1678322d-05, 5.4007907d-06, 5.8782379d-10 /
      data fpppp(11,14,15,1),fpppp(11,14,15,2),fpppp(11,14,15,3)/
     x-1.0506831d-05, 5.6723303d-06, 7.1666917d-10 /
      data fpppp(11,14,16,1),fpppp(11,14,16,2),fpppp(11,14,16,3)/
     x-1.2359863d-05, 3.1273319d-06, 2.1402668d-09 /
      data fpppp(11,14,17,1),fpppp(11,14,17,2),fpppp(11,14,17,3)/
     x-1.7753959d-05, 7.1318009d-07, 3.2851504d-09 /
      data fpppp(11,14,18,1),fpppp(11,14,18,2),fpppp(11,14,18,3)/
     x-1.8309280d-05, 5.1603875d-06, 4.0971537d-09 /
      data fpppp(11,14,19,1),fpppp(11,14,19,2),fpppp(11,14,19,3)/
     x-1.4469206d-05, 4.8193516d-06, 5.1057856d-09 /
      data fpppp(11,14,20,1),fpppp(11,14,20,2),fpppp(11,14,20,3)/
     x-1.7910842d-06,-1.3631292d-05, 7.6107283d-10 /
      data fpppp(11,14,21,1),fpppp(11,14,21,2),fpppp(11,14,21,3)/
     x-1.7910842d-06,-1.3238763d-05, 9.0519456d-10 /
      data fpppp(11,14,22,1),fpppp(11,14,22,2),fpppp(11,14,22,3)/
     x-1.4469206d-05, 3.2492381d-06, 4.5292987d-09 /
      data fpppp(11,14,23,1),fpppp(11,14,23,2),fpppp(11,14,23,3)/
     x-1.8309280d-05, 1.1048313d-05, 6.2589797d-09 /
      data fpppp(11,15, 1,1),fpppp(11,15, 1,2),fpppp(11,15, 1,3)/
     x-1.3524445d-03, 2.8154224d-04, 3.2146025d-07 /
      data fpppp(11,15, 2,1),fpppp(11,15, 2,2),fpppp(11,15, 2,3)/
     x-8.8145782d-04, 7.0316787d-05, 1.3695270d-07 /
      data fpppp(11,15, 3,1),fpppp(11,15, 3,2),fpppp(11,15, 3,3)/
     x 7.8022467d-05,-3.7766732d-04,-2.4705393d-07 /
      data fpppp(11,15, 4,1),fpppp(11,15, 4,2),fpppp(11,15, 4,3)/
     x 7.8022467d-05,-3.8579058d-04,-2.6694563d-07 /
      data fpppp(11,15, 5,1),fpppp(11,15, 5,2),fpppp(11,15, 5,3)/
     x-8.8145782d-04, 1.0280982d-04, 2.1651951d-07 /
      data fpppp(11,15, 6,1),fpppp(11,15, 6,2),fpppp(11,15, 6,3)/
     x-1.3524445d-03, 1.5969337d-04, 2.3084692d-08 /
      data fpppp(11,15, 7,1),fpppp(11,15, 7,2),fpppp(11,15, 7,3)/
     x 1.8842445d-04, 1.6613431d-04,-1.1515624d-07 /
      data fpppp(11,15, 8,1),fpppp(11,15, 8,2),fpppp(11,15, 8,3)/
     x 2.6158233d-03, 3.7053691d-04, 6.7503566d-08 /
      data fpppp(11,15, 9,1),fpppp(11,15, 9,2),fpppp(11,15, 9,3)/
     x 1.3019124d-02, 3.8143251d-04, 1.3712964d-07 /
      data fpppp(11,15,10,1),fpppp(11,15,10,2),fpppp(11,15,10,3)/
     x-5.2298927d-05,-3.5330632d-04,-1.0017744d-07 /
      data fpppp(11,15,11,1),fpppp(11,15,11,2),fpppp(11,15,11,3)/
     x 4.9944713d-06,-2.2346520d-04, 1.2008224d-07 /
      data fpppp(11,15,12,1),fpppp(11,15,12,2),fpppp(11,15,12,3)/
     x-2.3540402d-06,-1.9300906d-05, 1.0359600d-08 /
      data fpppp(11,15,13,1),fpppp(11,15,13,2),fpppp(11,15,13,3)/
     x-4.5165770d-06,-9.5758215d-06, 1.5430235d-08 /
      data fpppp(11,15,14,1),fpppp(11,15,14,2),fpppp(11,15,14,3)/
     x-5.7761487d-06, 4.4877439d-06, 5.0473375d-09 /
      data fpppp(11,15,15,1),fpppp(11,15,15,2),fpppp(11,15,15,3)/
     x-8.1095576d-06, 1.9482989d-06, 3.9527277d-09 /
      data fpppp(11,15,16,1),fpppp(11,15,16,2),fpppp(11,15,16,3)/
     x-9.6872196d-06, 5.8878737d-07, 4.0500601d-09 /
      data fpppp(11,15,17,1),fpppp(11,15,17,2),fpppp(11,15,17,3)/
     x-7.9334465d-06, 2.1179839d-06, 3.3501259d-09 /
      data fpppp(11,15,18,1),fpppp(11,15,18,2),fpppp(11,15,18,3)/
     x-7.6180621d-06,-7.1585167d-07, 3.5231155d-09 /
      data fpppp(11,15,19,1),fpppp(11,15,19,2),fpppp(11,15,19,3)/
     x-4.3104289d-06,-1.9584571d-08, 3.5069799d-09 /
      data fpppp(11,15,20,1),fpppp(11,15,20,2),fpppp(11,15,20,3)/
     x 3.0349856d-06,-4.9569417d-06,-2.9772581d-09 /
      data fpppp(11,15,21,1),fpppp(11,15,21,2),fpppp(11,15,21,3)/
     x 3.0349856d-06,-4.8145192d-06,-2.8343859d-09 /
      data fpppp(11,15,22,1),fpppp(11,15,22,2),fpppp(11,15,22,3)/
     x-4.3104289d-06,-5.8927452d-07, 2.9354909d-09 /
      data fpppp(11,15,23,1),fpppp(11,15,23,2),fpppp(11,15,23,3)/
     x-7.6180621d-06, 1.4204857d-06, 5.6661993d-09 /
      data fpppp(11,16, 1,1),fpppp(11,16, 1,2),fpppp(11,16, 1,3)/
     x 5.0968912d-03, 3.4999480d-05, 2.8283758d-07 /
      data fpppp(11,16, 2,1),fpppp(11,16, 2,2),fpppp(11,16, 2,3)/
     x 4.0894900d-03,-2.8025394d-06, 1.1267755d-07 /
      data fpppp(11,16, 3,1),fpppp(11,16, 3,2),fpppp(11,16, 3,3)/
     x 2.0280373d-03,-1.1655471d-04,-2.5432864d-07 /
      data fpppp(11,16, 4,1),fpppp(11,16, 4,2),fpppp(11,16, 4,3)/
     x 2.0280373d-03,-5.9245981d-05,-2.5016792d-07 /
      data fpppp(11,16, 5,1),fpppp(11,16, 5,2),fpppp(11,16, 5,3)/
     x 4.0894900d-03,-2.3203747d-04, 9.6034666d-08 /
      data fpppp(11,16, 6,1),fpppp(11,16, 6,2),fpppp(11,16, 6,3)/
     x 5.0968912d-03, 8.9463047d-04, 3.4524838d-07 /
      data fpppp(11,16, 7,1),fpppp(11,16, 7,2),fpppp(11,16, 7,3)/
     x-8.4322395d-04,-3.8898938d-03, 2.5828466d-07 /
      data fpppp(11,16, 8,1),fpppp(11,16, 8,2),fpppp(11,16, 8,3)/
     x-1.1396063d-02, 1.3260520d-02,-6.1341595d-07 /
      data fpppp(11,16, 9,1),fpppp(11,16, 9,2),fpppp(11,16, 9,3)/
     x-2.3065166d-02,-1.8642418d-02,-4.6084684d-07 /
      data fpppp(11,16,10,1),fpppp(11,16,10,2),fpppp(11,16,10,3)/
     x 4.1535913d-04, 1.1598728d-02, 7.9230825d-07 /
      data fpppp(11,16,11,1),fpppp(11,16,11,2),fpppp(11,16,11,3)/
     x 7.7913196d-05,-3.5325176d-03,-1.1425127d-07 /
      data fpppp(11,16,12,1),fpppp(11,16,12,2),fpppp(11,16,12,3)/
     x 1.4504795d-05, 8.5399398d-04, 5.7157133d-08 /
      data fpppp(11,16,13,1),fpppp(11,16,13,2),fpppp(11,16,13,3)/
     x-5.0073877d-07,-2.5046758d-04,-1.5811930d-10 /
      data fpppp(11,16,14,1),fpppp(11,16,14,2),fpppp(11,16,14,3)/
     x-1.4317802d-06, 6.5130366d-05, 1.1171377d-08 /
      data fpppp(11,16,15,1),fpppp(11,16,15,2),fpppp(11,16,15,3)/
     x-1.6467658d-06,-1.8099676d-05, 6.3018874d-09 /
      data fpppp(11,16,16,1),fpppp(11,16,16,2),fpppp(11,16,16,3)/
     x 1.3882850d-06, 5.0388492d-06, 4.9130729d-09 /
      data fpppp(11,16,17,1),fpppp(11,16,17,2),fpppp(11,16,17,3)/
     x 3.1164412d-06, 3.7008911d-07, 2.8305586d-09 /
      data fpppp(11,16,18,1),fpppp(11,16,18,2),fpppp(11,16,18,3)/
     x 4.0942561d-06,-2.6350245d-06,-3.4804623d-10 /
      data fpppp(11,16,19,1),fpppp(11,16,19,2),fpppp(11,16,19,3)/
     x 7.3718902d-06, 1.1301206d-06,-2.7361961d-09 /
      data fpppp(11,16,20,1),fpppp(11,16,20,2),fpppp(11,16,20,3)/
     x 7.4633885d-06,-2.3911846d-06,-3.8836458d-09 /
      data fpppp(11,16,21,1),fpppp(11,16,21,2),fpppp(11,16,21,3)/
     x 7.4633885d-06,-2.1344557d-06,-3.9715891d-09 /
      data fpppp(11,16,22,1),fpppp(11,16,22,2),fpppp(11,16,22,3)/
     x 7.3718902d-06, 1.0320522d-07,-2.3844227d-09 /
      data fpppp(11,16,23,1),fpppp(11,16,23,2),fpppp(11,16,23,3)/
     x 4.0942561d-06, 1.2159080d-06,-1.6671965d-09 /
      data fpppp(11,17, 1,1),fpppp(11,17, 1,2),fpppp(11,17, 1,3)/
     x-1.9243198d-02, 1.6980688d-06,-3.1667717d-07 /
      data fpppp(11,17, 2,1),fpppp(11,17, 2,2),fpppp(11,17, 2,3)/
     x-1.4316276d-02, 4.7121609d-06,-2.1902966d-07 /
      data fpppp(11,17, 3,1),fpppp(11,17, 3,2),fpppp(11,17, 3,3)/
     x-5.3572060d-03,-8.6783843d-05, 1.3782205d-08 /
      data fpppp(11,17, 4,1),fpppp(11,17, 4,2),fpppp(11,17, 4,3)/
     x-5.3572060d-03, 8.4637009d-05,-2.7460417d-08 /
      data fpppp(11,17, 5,1),fpppp(11,17, 5,2),fpppp(11,17, 5,3)/
     x-1.4316276d-02,-6.8097125d-04,-5.4059175d-08 /
      data fpppp(11,17, 6,1),fpppp(11,17, 6,2),fpppp(11,17, 6,3)/
     x-1.9243198d-02, 2.5730109d-03,-9.3531649d-07 /
      data fpppp(11,17, 7,1),fpppp(11,17, 7,2),fpppp(11,17, 7,3)/
     x 2.5342228d-03,-1.0679475d-02,-1.1906831d-07 /
      data fpppp(11,17, 8,1),fpppp(11,17, 8,2),fpppp(11,17, 8,3)/
     x 2.0345106d-02, 1.4610369d-02, 1.0142221d-06 /
      data fpppp(11,17, 9,1),fpppp(11,17, 9,2),fpppp(11,17, 9,3)/
     x 1.9682762d-02,-3.7345570d-03, 1.0944560d-06 /
      data fpppp(11,17,10,1),fpppp(11,17,10,2),fpppp(11,17,10,3)/
     x 1.2813673d-04,-2.4044392d-03,-9.3831046d-07 /
      data fpppp(11,17,11,1),fpppp(11,17,11,2),fpppp(11,17,11,3)/
     x 5.3819028d-05, 3.8466501d-04, 5.5584148d-08 /
      data fpppp(11,17,12,1),fpppp(11,17,12,2),fpppp(11,17,12,3)/
     x 1.8993441d-05,-1.5144851d-04,-7.9418529d-08 /
      data fpppp(11,17,13,1),fpppp(11,17,13,2),fpppp(11,17,13,3)/
     x 1.3418131d-05, 2.5402965d-05, 1.4250583d-10 /
      data fpppp(11,17,14,1),fpppp(11,17,14,2),fpppp(11,17,14,3)/
     x 1.7807604d-06,-1.1399978d-05,-4.1035031d-09 /
      data fpppp(11,17,15,1),fpppp(11,17,15,2),fpppp(11,17,15,3)/
     x-3.2042255d-06, 2.2246795d-06, 3.4220857d-09 /
      data fpppp(11,17,16,1),fpppp(11,17,16,2),fpppp(11,17,16,3)/
     x-8.4144135d-06,-1.2967557d-06, 3.0188526d-09 /
      data fpppp(11,17,17,1),fpppp(11,17,17,2),fpppp(11,17,17,3)/
     x-1.2558719d-05, 5.6226917d-07, 6.6045919d-10 /
      data fpppp(11,17,18,1),fpppp(11,17,18,2),fpppp(11,17,18,3)/
     x-1.2638567d-05,-1.9041261d-06,-1.6234135d-09 /
      data fpppp(11,17,19,1),fpppp(11,17,19,2),fpppp(11,17,19,3)/
     x-1.3575712d-05, 1.0736959d-06,-4.5250837d-09 /
      data fpppp(11,17,20,1),fpppp(11,17,20,2),fpppp(11,17,20,3)/
     x-9.2848420d-06,-1.1297277d-06,-5.0641233d-09 /
      data fpppp(11,17,21,1),fpppp(11,17,21,2),fpppp(11,17,21,3)/
     x-9.2848420d-06,-9.3956538d-07,-5.1899201d-09 /
      data fpppp(11,17,22,1),fpppp(11,17,22,2),fpppp(11,17,22,3)/
     x-1.3575712d-05, 3.1304657d-07,-4.0218967d-09 /
      data fpppp(11,17,23,1),fpppp(11,17,23,2),fpppp(11,17,23,3)/
     x-1.2638567d-05, 9.4830876d-07,-3.5103649d-09 /
      data fpppp(11,18, 1,1),fpppp(11,18, 1,2),fpppp(11,18, 1,3)/
     x 2.0971500d-02, 4.8712066d-03, 3.8666615d-07 /
      data fpppp(11,18, 2,1),fpppp(11,18, 2,2),fpppp(11,18, 2,3)/
     x 1.5797221d-02, 2.3887340d-03, 2.6966099d-07 /
      data fpppp(11,18, 3,1),fpppp(11,18, 3,2),fpppp(11,18, 3,3)/
     x 6.3787184d-03,-3.6355325d-03,-7.3147852d-09 /
      data fpppp(11,18, 4,1),fpppp(11,18, 4,2),fpppp(11,18, 4,3)/
     x 6.3787184d-03,-2.4023382d-03, 3.8623471d-08 /
      data fpppp(11,18, 5,1),fpppp(11,18, 5,2),fpppp(11,18, 5,3)/
     x 1.5797221d-02,-2.5440431d-03, 8.5907963d-08 /
      data fpppp(11,18, 6,1),fpppp(11,18, 6,2),fpppp(11,18, 6,3)/
     x 2.0971500d-02, 2.3369121d-02, 1.0757400d-06 /
      data fpppp(11,18, 7,1),fpppp(11,18, 7,2),fpppp(11,18, 7,3)/
     x-1.7072136d-03,-2.0508975d-02,-8.3286945d-08 /
      data fpppp(11,18, 8,1),fpppp(11,18, 8,2),fpppp(11,18, 8,3)/
     x-9.3876318d-03, 3.5215817d-03,-4.5809290d-07 /
      data fpppp(11,18, 9,1),fpppp(11,18, 9,2),fpppp(11,18, 9,3)/
     x-5.5060257d-03, 5.2061359d-04,-6.9606038d-07 /
      data fpppp(11,18,10,1),fpppp(11,18,10,2),fpppp(11,18,10,3)/
     x-2.6935268d-04,-4.2263558d-04, 1.6204710d-07 /
      data fpppp(11,18,11,1),fpppp(11,18,11,2),fpppp(11,18,11,3)/
     x-6.2354916d-05, 8.8235854d-05,-7.1456094d-08 /
      data fpppp(11,18,12,1),fpppp(11,18,12,2),fpppp(11,18,12,3)/
     x 5.8601520d-07, 5.3403992d-07, 4.8653476d-10 /
      data fpppp(11,18,13,1),fpppp(11,18,13,2),fpppp(11,18,13,3)/
     x 1.2356024d-06,-1.1702308d-05,-1.1039341d-08 /
      data fpppp(11,18,14,1),fpppp(11,18,14,2),fpppp(11,18,14,3)/
     x 7.8547309d-06, 2.3437039d-06,-3.6171668d-09 /
      data fpppp(11,18,15,1),fpppp(11,18,15,2),fpppp(11,18,15,3)/
     x 1.1826467d-05,-8.9305083d-07,-3.8035857d-09 /
      data fpppp(11,18,16,1),fpppp(11,18,16,2),fpppp(11,18,16,3)/
     x 1.6225187d-05,-1.3618302d-06,-4.1152598d-09 /
      data fpppp(11,18,17,1),fpppp(11,18,17,2),fpppp(11,18,17,3)/
     x 2.1292291d-05, 2.7394314d-06,-5.1119336d-09 /
      data fpppp(11,18,18,1),fpppp(11,18,18,2),fpppp(11,18,18,3)/
     x 2.3387229d-05,-2.8483627d-06,-7.1133703d-09 /
      data fpppp(11,18,19,1),fpppp(11,18,19,2),fpppp(11,18,19,3)/
     x 2.5905738d-05, 5.0270355d-06,-8.3036485d-09 /
      data fpppp(11,18,20,1),fpppp(11,18,20,2),fpppp(11,18,20,3)/
     x 2.2701898d-05,-2.2286241d-06,-9.8640724d-09 /
      data fpppp(11,18,21,1),fpppp(11,18,21,2),fpppp(11,18,21,3)/
     x 2.2701898d-05,-1.6940653d-06,-9.8860066d-09 /
      data fpppp(11,18,22,1),fpppp(11,18,22,2),fpppp(11,18,22,3)/
     x 2.5905738d-05, 2.8888002d-06,-8.2159117d-09 /
      data fpppp(11,18,23,1),fpppp(11,18,23,2),fpppp(11,18,23,3)/
     x 2.3387229d-05, 5.1700197d-06,-7.4423832d-09 /
      data fpppp(11,19, 1,1),fpppp(11,19, 1,2),fpppp(11,19, 1,3)/
     x 4.2741974d-02,-3.4839624d-17, 7.1776430d-07 /
      data fpppp(11,19, 2,1),fpppp(11,19, 2,2),fpppp(11,19, 2,3)/
     x 3.2048071d-02, 3.9921789d-18, 5.2395225d-07 /
      data fpppp(11,19, 3,1),fpppp(11,19, 3,2),fpppp(11,19, 3,3)/
     x 1.2651452d-02, 8.5426941d-19, 5.4219035d-08 /
      data fpppp(11,19, 4,1),fpppp(11,19, 4,2),fpppp(11,19, 4,3)/
     x 1.2651452d-02, 4.3274498d-18, 1.4945696d-07 /
      data fpppp(11,19, 5,1),fpppp(11,19, 5,2),fpppp(11,19, 5,3)/
     x 3.2048071d-02,-7.9168506d-19, 1.4300054d-07 /
      data fpppp(11,19, 6,1),fpppp(11,19, 6,2),fpppp(11,19, 6,3)/
     x 4.2741974d-02, 5.3693797d-18, 2.1463332d-06 /
      data fpppp(11,19, 7,1),fpppp(11,19, 7,2),fpppp(11,19, 7,3)/
     x-3.7718262d-03, 2.7617598d-18,-1.6554396d-07 /
      data fpppp(11,19, 8,1),fpppp(11,19, 8,2),fpppp(11,19, 8,3)/
     x-2.1556396d-02, 1.0756687d-17,-1.0447070d-06 /
      data fpppp(11,19, 9,1),fpppp(11,19, 9,2),fpppp(11,19, 9,3)/
     x-1.1284323d-02,-1.6154188d-17,-1.5306284d-06 /
      data fpppp(11,19,10,1),fpppp(11,19,10,2),fpppp(11,19,10,3)/
     x-6.3533723d-04, 3.4382288d-18, 4.5355429d-07 /
      data fpppp(11,19,11,1),fpppp(11,19,11,2),fpppp(11,19,11,3)/
     x-1.5222035d-04, 1.0940317d-17,-1.1367472d-07 /
      data fpppp(11,19,12,1),fpppp(11,19,12,2),fpppp(11,19,12,3)/
     x-1.1279676d-05, 3.9366132d-18, 1.8539963d-08 /
      data fpppp(11,19,13,1),fpppp(11,19,13,2),fpppp(11,19,13,3)/
     x-3.4893838d-06, 5.6830848d-18,-1.8940482d-08 /
      data fpppp(11,19,14,1),fpppp(11,19,14,2),fpppp(11,19,14,3)/
     x 1.3111150d-05,-3.1589898d-18,-7.6340352d-09 /
      data fpppp(11,19,15,1),fpppp(11,19,15,2),fpppp(11,19,15,3)/
     x 2.2117687d-05,-1.5971627d-17,-9.7875800d-09 /
      data fpppp(11,19,16,1),fpppp(11,19,16,2),fpppp(11,19,16,3)/
     x 3.1024131d-05, 4.7598560d-18,-9.7522602d-09 /
      data fpppp(11,19,17,1),fpppp(11,19,17,2),fpppp(11,19,17,3)/
     x 4.0992966d-05, 8.9244691d-19,-9.8550997d-09 /
      data fpppp(11,19,18,1),fpppp(11,19,18,2),fpppp(11,19,18,3)/
     x 4.4339134d-05, 5.6961795d-18,-1.1399159d-08 /
      data fpppp(11,19,19,1),fpppp(11,19,19,2),fpppp(11,19,19,3)/
     x 4.8121745d-05,-2.9422555d-18,-1.1513734d-08 /
      data fpppp(11,19,20,1),fpppp(11,19,20,2),fpppp(11,19,20,3)/
     x 4.0764360d-05, 7.0314705d-19,-1.3629887d-08 /
      data fpppp(11,19,21,1),fpppp(11,19,21,2),fpppp(11,19,21,3)/
     x 4.0764360d-05, 5.6964375d-18,-1.3588449d-08 /
      data fpppp(11,19,22,1),fpppp(11,19,22,2),fpppp(11,19,22,3)/
     x 4.8121745d-05,-9.5160679d-19,-1.1679486d-08 /
      data fpppp(11,19,23,1),fpppp(11,19,23,2),fpppp(11,19,23,3)/
     x 4.4339134d-05, 7.9668231d-18,-1.0777587d-08 /
      data fpppp(12, 1, 1,1),fpppp(12, 1, 1,2),fpppp(12, 1, 1,3)/
     x-1.6774265d-02,-1.1248260d-16,-1.2185552d-05 /
      data fpppp(12, 1, 2,1),fpppp(12, 1, 2,2),fpppp(12, 1, 2,3)/
     x-4.1101453d-02,-1.5004936d-16,-8.5449725d-06 /
      data fpppp(12, 1, 3,1),fpppp(12, 1, 3,2),fpppp(12, 1, 3,3)/
     x-8.3946235d-03, 7.1047229d-17,-6.3580919d-07 /
      data fpppp(12, 1, 4,1),fpppp(12, 1, 4,2),fpppp(12, 1, 4,3)/
     x-8.3946235d-03,-1.8275178d-17,-8.2467190d-07 /
      data fpppp(12, 1, 5,1),fpppp(12, 1, 5,2),fpppp(12, 1, 5,3)/
     x-4.1101453d-02, 5.0978882d-17,-7.7895217d-06 /
      data fpppp(12, 1, 6,1),fpppp(12, 1, 6,2),fpppp(12, 1, 6,3)/
     x-1.6774265d-02,-2.7683111d-17,-1.5018493d-05 /
      data fpppp(12, 1, 7,1),fpppp(12, 1, 7,2),fpppp(12, 1, 7,3)/
     x-1.4975487d-02,-1.1133394d-16, 2.2475105d-05 /
      data fpppp(12, 1, 8,1),fpppp(12, 1, 8,2),fpppp(12, 1, 8,3)/
     x-1.0099327d-02, 4.0619689d-17,-1.5232714d-06 /
      data fpppp(12, 1, 9,1),fpppp(12, 1, 9,2),fpppp(12, 1, 9,3)/
     x-8.2061474d-03, 6.9748458d-17, 2.6951096d-06 /
      data fpppp(12, 1,10,1),fpppp(12, 1,10,2),fpppp(12, 1,10,3)/
     x-8.4146861d-03,-5.6323995d-18,-1.0741828d-07 /
      data fpppp(12, 1,11,1),fpppp(12, 1,11,2),fpppp(12, 1,11,3)/
     x-9.4164034d-03, 9.7982095d-17, 3.9861419d-07 /
      data fpppp(12, 1,12,1),fpppp(12, 1,12,2),fpppp(12, 1,12,3)/
     x-1.2725826d-02,-1.9649935d-17,-7.2684289d-08 /
      data fpppp(12, 1,13,1),fpppp(12, 1,13,2),fpppp(12, 1,13,3)/
     x-1.1660131d-02, 7.9137843d-17, 9.7432923d-07 /
      data fpppp(12, 1,14,1),fpppp(12, 1,14,2),fpppp(12, 1,14,3)/
     x-8.3584056d-03, 1.0645424d-17,-2.3921116d-06 /
      data fpppp(12, 1,15,1),fpppp(12, 1,15,2),fpppp(12, 1,15,3)/
     x 2.8424880d-02,-6.1976407d-17, 6.4147015d-06 /
      data fpppp(12, 1,16,1),fpppp(12, 1,16,2),fpppp(12, 1,16,3)/
     x-9.8037705d-03,-2.6446038d-19,-3.9829323d-06 /
      data fpppp(12, 1,17,1),fpppp(12, 1,17,2),fpppp(12, 1,17,3)/
     x-1.3852112d-02, 3.0568041d-17, 2.3464879d-05 /
      data fpppp(12, 1,18,1),fpppp(12, 1,18,2),fpppp(12, 1,18,3)/
     x-1.7226297d-02, 6.7679911d-17,-1.6708948d-05 /
      data fpppp(12, 1,19,1),fpppp(12, 1,19,2),fpppp(12, 1,19,3)/
     x-3.6930814d-02, 8.7639438d-18,-6.3155467d-06 /
      data fpppp(12, 1,20,1),fpppp(12, 1,20,2),fpppp(12, 1,20,3)/
     x-6.2976501d-03,-6.5669899d-17,-9.7518514d-07 /
      data fpppp(12, 1,21,1),fpppp(12, 1,21,2),fpppp(12, 1,21,3)/
     x-6.2976501d-03,-6.3635409d-17,-6.0012664d-07 /
      data fpppp(12, 1,22,1),fpppp(12, 1,22,2),fpppp(12, 1,22,3)/
     x-3.6930814d-02,-1.4318707d-17,-7.8157807d-06 /
      data fpppp(12, 1,23,1),fpppp(12, 1,23,2),fpppp(12, 1,23,3)/
     x-1.7226297d-02,-1.6743538d-17,-1.1083070d-05 /
      data fpppp(12, 2, 1,1),fpppp(12, 2, 1,2),fpppp(12, 2, 1,3)/
     x-8.0543065d-03,-3.9799128d-03,-2.5862162d-06 /
      data fpppp(12, 2, 2,1),fpppp(12, 2, 2,2),fpppp(12, 2, 2,3)/
     x-2.0137438d-02,-2.1044961d-03,-1.9569996d-06 /
      data fpppp(12, 2, 3,1),fpppp(12, 2, 3,2),fpppp(12, 2, 3,3)/
     x-3.8237948d-03, 1.8126292d-03,-3.8786296d-07 /
      data fpppp(12, 2, 4,1),fpppp(12, 2, 4,2),fpppp(12, 2, 4,3)/
     x-3.8237948d-03, 1.9904725d-03,-7.7428990d-07 /
      data fpppp(12, 2, 5,1),fpppp(12, 2, 5,2),fpppp(12, 2, 5,3)/
     x-2.0137438d-02,-2.8158693d-03,-4.1129183d-07 /
      data fpppp(12, 2, 6,1),fpppp(12, 2, 6,2),fpppp(12, 2, 6,3)/
     x-8.0543065d-03,-1.3122633d-03,-8.3826203d-06 /
      data fpppp(12, 2, 7,1),fpppp(12, 2, 7,2),fpppp(12, 2, 7,3)/
     x-7.4238021d-03, 8.3037916d-04, 9.6090269d-06 /
      data fpppp(12, 2, 8,1),fpppp(12, 2, 8,2),fpppp(12, 2, 8,3)/
     x-4.8368887d-03,-2.3042187d-04,-8.7510082d-07 /
      data fpppp(12, 2, 9,1),fpppp(12, 2, 9,2),fpppp(12, 2, 9,3)/
     x-3.9122861d-03, 1.3040498d-03, 1.1128981d-06 /
      data fpppp(12, 2,10,1),fpppp(12, 2,10,2),fpppp(12, 2,10,3)/
     x-3.8743013d-03,-1.3937749d-03,-1.2538920d-07 /
      data fpppp(12, 2,11,1),fpppp(12, 2,11,2),fpppp(12, 2,11,3)/
     x-4.3603837d-03, 1.8049511d-03, 1.0885733d-07 /
      data fpppp(12, 2,12,1),fpppp(12, 2,12,2),fpppp(12, 2,12,3)/
     x-6.0398099d-03,-1.2635236d-03,-1.0022852d-07 /
      data fpppp(12, 2,13,1),fpppp(12, 2,13,2),fpppp(12, 2,13,3)/
     x-5.4935210d-03,-5.5747058d-04, 3.5424422d-07 /
      data fpppp(12, 2,14,1),fpppp(12, 2,14,2),fpppp(12, 2,14,3)/
     x-3.7998592d-03, 1.0105677d-03,-1.0989905d-06 /
      data fpppp(12, 2,15,1),fpppp(12, 2,15,2),fpppp(12, 2,15,3)/
     x 1.1763844d-02,-5.2881118d-04, 2.7025287d-06 /
      data fpppp(12, 2,16,1),fpppp(12, 2,16,2),fpppp(12, 2,16,3)/
     x-4.6898710d-03, 1.0096103d-03,-1.9116687d-06 /
      data fpppp(12, 2,17,1),fpppp(12, 2,17,2),fpppp(12, 2,17,3)/
     x-6.6249649d-03, 3.6023568d-04, 1.0029844d-05 /
      data fpppp(12, 2,18,1),fpppp(12, 2,18,2),fpppp(12, 2,18,3)/
     x-8.2627176d-03,-1.9308672d-03,-8.9844160d-06 /
      data fpppp(12, 2,19,1),fpppp(12, 2,19,2),fpppp(12, 2,19,3)/
     x-1.8105248d-02,-1.9513605d-03, 1.9243898d-07 /
      data fpppp(12, 2,20,1),fpppp(12, 2,20,2),fpppp(12, 2,20,3)/
     x-2.8962685d-03, 1.8443282d-03,-8.9382039d-07 /
      data fpppp(12, 2,21,1),fpppp(12, 2,21,2),fpppp(12, 2,21,3)/
     x-2.8962685d-03, 1.7592737d-03,-4.3414748d-07 /
      data fpppp(12, 2,22,1),fpppp(12, 2,22,2),fpppp(12, 2,22,3)/
     x-1.8105248d-02,-1.6111425d-03,-1.6462527d-06 /
      data fpppp(12, 2,23,1),fpppp(12, 2,23,2),fpppp(12, 2,23,3)/
     x-8.2627176d-03,-3.2066846d-03,-2.0893223d-06 /
      data fpppp(12, 3, 1,1),fpppp(12, 3, 1,2),fpppp(12, 3, 1,3)/
     x 6.2953884d-03, 1.7190335d-02,-1.2316340d-05 /
      data fpppp(12, 3, 2,1),fpppp(12, 3, 2,2),fpppp(12, 3, 2,3)/
     x 5.3941391d-02, 1.0134005d-02,-7.1721662d-06 /
      data fpppp(12, 3, 3,1),fpppp(12, 3, 3,2),fpppp(12, 3, 3,3)/
     x 6.0342107d-03,-3.8289586d-03, 1.8993259d-06 /
      data fpppp(12, 3, 4,1),fpppp(12, 3, 4,2),fpppp(12, 3, 4,3)/
     x 6.0342107d-03,-5.8550128d-03, 5.3148654d-06 /
      data fpppp(12, 3, 5,1),fpppp(12, 3, 5,2),fpppp(12, 3, 5,3)/
     x 5.3941391d-02, 1.8238221d-02,-2.0834324d-05 /
      data fpppp(12, 3, 6,1),fpppp(12, 3, 6,2),fpppp(12, 3, 6,3)/
     x 6.2953884d-03,-1.3200477d-02, 3.8916753d-05 /
      data fpppp(12, 3, 7,1),fpppp(12, 3, 7,2),fpppp(12, 3, 7,3)/
     x 1.1096005d-02, 4.2023002d-03,-2.4326118d-05 /
      data fpppp(12, 3, 8,1),fpppp(12, 3, 8,2),fpppp(12, 3, 8,3)/
     x 3.6473640d-03,-1.3973003d-03, 3.1445152d-06 /
      data fpppp(12, 3, 9,1),fpppp(12, 3, 9,2),fpppp(12, 3, 9,3)/
     x 2.5302710d-03, 5.1170782d-04,-3.0919189d-06 /
      data fpppp(12, 3,10,1),fpppp(12, 3,10,2),fpppp(12, 3,10,3)/
     x-2.2830470d-04,-7.5519776d-04,-1.7158221d-08 /
      data fpppp(12, 3,11,1),fpppp(12, 3,11,2),fpppp(12, 3,11,3)/
     x 2.5192234d-03, 1.9354276d-04,-5.6449348d-07 /
      data fpppp(12, 3,12,1),fpppp(12, 3,12,2),fpppp(12, 3,12,3)/
     x 5.3235292d-03, 2.0817366d-03,-6.1268433d-08 /
      data fpppp(12, 3,13,1),fpppp(12, 3,13,2),fpppp(12, 3,13,3)/
     x 3.3474869d-03,-7.6360879d-03,-1.2133089d-06 /
      data fpppp(12, 3,14,1),fpppp(12, 3,14,2),fpppp(12, 3,14,3)/
     x-6.3198659d-04, 2.8319030d-02, 2.5879116d-06 /
      data fpppp(12, 3,15,1),fpppp(12, 3,15,2),fpppp(12, 3,15,3)/
     x-3.8575308d-02,-4.4730181d-02,-7.2307659d-06 /
      data fpppp(12, 3,16,1),fpppp(12, 3,16,2),fpppp(12, 3,16,3)/
     x 3.4310204d-03, 2.7279604d-02, 5.8995278d-06 /
      data fpppp(12, 3,17,1),fpppp(12, 3,17,2),fpppp(12, 3,17,3)/
     x 5.8140045d-03,-4.0170563d-03,-2.5167827d-05 /
      data fpppp(12, 3,18,1),fpppp(12, 3,18,2),fpppp(12, 3,18,3)/
     x 6.8013405d-03,-9.7041328d-03, 3.9795224d-05 /
      data fpppp(12, 3,19,1),fpppp(12, 3,19,2),fpppp(12, 3,19,3)/
     x 4.8800284d-02, 1.6066562d-02,-2.1948883d-05 /
      data fpppp(12, 3,20,1),fpppp(12, 3,20,2),fpppp(12, 3,20,3)/
     x 5.3279499d-03,-5.2736295d-03, 5.6393491d-06 /
      data fpppp(12, 3,21,1),fpppp(12, 3,21,2),fpppp(12, 3,21,3)/
     x 5.3279499d-03,-3.5776113d-03, 2.0973262d-06 /
      data fpppp(12, 3,22,1),fpppp(12, 3,22,2),fpppp(12, 3,22,3)/
     x 4.8800284d-02, 9.2824892d-03,-7.7807914d-06 /
      data fpppp(12, 3,23,1),fpppp(12, 3,23,2),fpppp(12, 3,23,3)/
     x 6.8013405d-03, 1.5736141d-02,-1.3335119d-05 /
      data fpppp(12, 4, 1,1),fpppp(12, 4, 1,2),fpppp(12, 4, 1,3)/
     x 9.4100517d-04,-3.8938612d-02, 4.5606645d-05 /
      data fpppp(12, 4, 2,1),fpppp(12, 4, 2,2),fpppp(12, 4, 2,3)/
     x-5.7881629d-02,-2.2830275d-02, 2.8923656d-05 /
      data fpppp(12, 4, 3,1),fpppp(12, 4, 3,2),fpppp(12, 4, 3,3)/
     x-2.6129023d-03, 8.9151767d-03,-2.9508345d-06 /
      data fpppp(12, 4, 4,1),fpppp(12, 4, 4,2),fpppp(12, 4, 4,3)/
     x-2.6129023d-03, 1.3766899d-02,-9.7316859d-06 /
      data fpppp(12, 4, 5,1),fpppp(12, 4, 5,2),fpppp(12, 4, 5,3)/
     x-5.7881629d-02,-4.2237163d-02, 5.6047061d-05 /
      data fpppp(12, 4, 6,1),fpppp(12, 4, 6,2),fpppp(12, 4, 6,3)/
     x 9.4100517d-04, 3.3837217d-02,-5.6106127d-05 /
      data fpppp(12, 4, 7,1),fpppp(12, 4, 7,2),fpppp(12, 4, 7,3)/
     x-8.7726156d-03,-1.6802335d-02, 1.5480470d-05 /
      data fpppp(12, 4, 8,1),fpppp(12, 4, 8,2),fpppp(12, 4, 8,3)/
     x 8.5526497d-04, 8.3170159d-03,-4.6359277d-06 /
      data fpppp(12, 4, 9,1),fpppp(12, 4, 9,2),fpppp(12, 4, 9,3)/
     x 1.4523930d-03,-4.7957274d-03, 1.8823833d-06 /
      data fpppp(12, 4,10,1),fpppp(12, 4,10,2),fpppp(12, 4,10,3)/
     x 6.5480508d-03, 4.1085389d-03,-3.5063388d-07 /
      data fpppp(12, 4,11,1),fpppp(12, 4,11,2),fpppp(12, 4,11,3)/
     x 3.0162743d-03,-9.3049670d-04, 1.0473451d-07 /
      data fpppp(12, 4,12,1),fpppp(12, 4,12,2),fpppp(12, 4,12,3)/
     x 3.1623684d-04,-8.8213266d-04,-2.5507345d-07 /
      data fpppp(12, 4,13,1),fpppp(12, 4,13,2),fpppp(12, 4,13,3)/
     x 2.8281031d-03,-1.6493299d-03, 5.3527646d-07 /
      data fpppp(12, 4,14,1),fpppp(12, 4,14,2),fpppp(12, 4,14,3)/
     x 7.4032443d-03, 4.8720446d-03,-2.1034200d-06 /
      data fpppp(12, 4,15,1),fpppp(12, 4,15,2),fpppp(12, 4,15,3)/
     x 2.8958945d-02,-3.9799230d-03, 4.6098656d-06 /
      data fpppp(12, 4,16,1),fpppp(12, 4,16,2),fpppp(12, 4,16,3)/
     x 1.0274400d-03, 2.7925166d-03,-6.3790411d-06 /
      data fpppp(12, 4,17,1),fpppp(12, 4,17,2),fpppp(12, 4,17,3)/
     x 1.1596565d-05,-7.3767493d-03, 1.5803727d-05 /
      data fpppp(12, 4,18,1),fpppp(12, 4,18,2),fpppp(12, 4,18,3)/
     x 5.1372157d-04, 2.5442003d-02,-5.5118014d-05 /
      data fpppp(12, 4,19,1),fpppp(12, 4,19,2),fpppp(12, 4,19,3)/
     x-5.2574066d-02,-3.6358983d-02, 5.6182371d-05 /
      data fpppp(12, 4,20,1),fpppp(12, 4,20,2),fpppp(12, 4,20,3)/
     x-3.3277604d-03, 1.1963381d-02,-1.0408798d-05 /
      data fpppp(12, 4,21,1),fpppp(12, 4,21,2),fpppp(12, 4,21,3)/
     x-3.3277604d-03, 7.9593577d-03,-3.6504309d-06 /
      data fpppp(12, 4,22,1),fpppp(12, 4,22,2),fpppp(12, 4,22,3)/
     x-5.2574066d-02,-2.0342890d-02, 2.9148903d-05 /
      data fpppp(12, 4,23,1),fpppp(12, 4,23,2),fpppp(12, 4,23,3)/
     x 5.1372157d-04,-3.4618346d-02, 4.6257491d-05 /
      data fpppp(12, 5, 1,1),fpppp(12, 5, 1,2),fpppp(12, 5, 1,3)/
     x-1.8720464d-04,-1.1339325d-05,-3.8864184d-05 /
      data fpppp(12, 5, 2,1),fpppp(12, 5, 2,2),fpppp(12, 5, 2,3)/
     x 3.1894112d-02,-9.1854560d-06,-2.4150576d-05 /
      data fpppp(12, 5, 3,1),fpppp(12, 5, 3,2),fpppp(12, 5, 3,3)/
     x-3.0045158d-04,-2.0099825d-06, 4.6283173d-06 /
      data fpppp(12, 5, 4,1),fpppp(12, 5, 4,2),fpppp(12, 5, 4,3)/
     x-3.0045158d-04,-6.4900526d-06, 9.4412821d-06 /
      data fpppp(12, 5, 5,1),fpppp(12, 5, 5,2),fpppp(12, 5, 5,3)/
     x 3.1894112d-02, 8.7348244d-06,-4.3402436d-05 /
      data fpppp(12, 5, 6,1),fpppp(12, 5, 6,2),fpppp(12, 5, 6,3)/
     x-1.8720464d-04,-7.8540376d-05, 3.3330288d-05 /
      data fpppp(12, 5, 7,1),fpppp(12, 5, 7,2),fpppp(12, 5, 7,3)/
     x 6.2983415d-03, 1.5401425d-04,-4.3828585d-06 /
      data fpppp(12, 5, 8,1),fpppp(12, 5, 8,2),fpppp(12, 5, 8,3)/
     x 4.7545755d-04,-5.0836561d-05, 2.6069224d-06 /
      data fpppp(12, 5, 9,1),fpppp(12, 5, 9,2),fpppp(12, 5, 9,3)/
     x 1.8070291d-04, 1.1958003d-06,-6.9458650d-07 /
      data fpppp(12, 5,10,1),fpppp(12, 5,10,2),fpppp(12, 5,10,3)/
     x-3.1186219d-03,-1.4923399d-05, 7.8655298d-08 /
      data fpppp(12, 5,11,1),fpppp(12, 5,11,2),fpppp(12, 5,11,3)/
     x-1.2094362d-03,-5.2216746d-06,-1.0315866d-07 /
      data fpppp(12, 5,12,1),fpppp(12, 5,12,2),fpppp(12, 5,12,3)/
     x 3.6470569d-04,-7.3711008d-06, 2.7337132d-08 /
      data fpppp(12, 5,13,1),fpppp(12, 5,13,2),fpppp(12, 5,13,3)/
     x-1.0705905d-03,-8.5807990d-06,-2.1410236d-07 /
      data fpppp(12, 5,14,1),fpppp(12, 5,14,2),fpppp(12, 5,14,3)/
     x-3.7311663d-03,-5.1481339d-06, 5.5013518d-07 /
      data fpppp(12, 5,15,1),fpppp(12, 5,15,2),fpppp(12, 5,15,3)/
     x-7.2087308d-03,-2.1427189d-05,-1.4034989d-06 /
      data fpppp(12, 5,16,1),fpppp(12, 5,16,2),fpppp(12, 5,16,3)/
     x 4.0847879d-04,-1.7164484d-06, 2.9676799d-06 /
      data fpppp(12, 5,17,1),fpppp(12, 5,17,2),fpppp(12, 5,17,3)/
     x 7.3345690d-04, 3.0974218d-05,-4.4094930d-06 /
      data fpppp(12, 5,18,1),fpppp(12, 5,18,2),fpppp(12, 5,18,3)/
     x 3.2982781d-04,-2.2676224d-04, 3.1856831d-05 /
      data fpppp(12, 5,19,1),fpppp(12, 5,19,2),fpppp(12, 5,19,3)/
     x 3.0026244d-02, 4.5966206d-04,-4.3218223d-05 /
      data fpppp(12, 5,20,1),fpppp(12, 5,20,2),fpppp(12, 5,20,3)/
     x 2.6581983d-03,-1.6083626d-04, 1.0290607d-05 /
      data fpppp(12, 5,21,1),fpppp(12, 5,21,2),fpppp(12, 5,21,3)/
     x 2.6581983d-03,-1.1450761d-04, 5.5415953d-06 /
      data fpppp(12, 5,22,1),fpppp(12, 5,22,2),fpppp(12, 5,22,3)/
     x 3.0026244d-02, 2.7434747d-04,-2.4222177d-05 /
      data fpppp(12, 5,23,1),fpppp(12, 5,23,2),fpppp(12, 5,23,3)/
     x 3.2982781d-04, 4.6816747d-04,-3.9378341d-05 /
      data fpppp(12, 6, 1,1),fpppp(12, 6, 1,2),fpppp(12, 6, 1,3)/
     x 7.5813474d-04,-1.2247436d-03, 1.1052895d-05 /
      data fpppp(12, 6, 2,1),fpppp(12, 6, 2,2),fpppp(12, 6, 2,3)/
     x-6.6958858d-03,-6.3617183d-04, 6.7651441d-06 /
      data fpppp(12, 6, 3,1),fpppp(12, 6, 3,2),fpppp(12, 6, 3,3)/
     x 4.4213122d-03, 5.7284076d-04,-1.6745740d-06 /
      data fpppp(12, 6, 4,1),fpppp(12, 6, 4,2),fpppp(12, 6, 4,3)/
     x 4.4213122d-03, 6.6421289d-04,-2.9841318d-06 /
      data fpppp(12, 6, 5,1),fpppp(12, 6, 5,2),fpppp(12, 6, 5,3)/
     x-6.6958858d-03,-1.0016604d-03, 1.2003375d-05 /
      data fpppp(12, 6, 6,1),fpppp(12, 6, 6,2),fpppp(12, 6, 6,3)/
     x 7.5813474d-04, 1.4583840d-04,-8.5904728d-06 /
      data fpppp(12, 6, 7,1),fpppp(12, 6, 7,2),fpppp(12, 6, 7,3)/
     x-1.4183690d-03,-9.3214123d-05, 1.2864274d-06 /
      data fpppp(12, 6, 8,1),fpppp(12, 6, 8,2),fpppp(12, 6, 8,3)/
     x 4.2341496d-05, 4.8025831d-07,-7.8808813d-07 /
      data fpppp(12, 6, 9,1),fpppp(12, 6, 9,2),fpppp(12, 6, 9,3)/
     x 8.3263458d-05,-1.3004717d-05, 1.3576347d-07 /
      data fpppp(12, 6,10,1),fpppp(12, 6,10,2),fpppp(12, 6,10,3)/
     x 9.5638347d-04,-6.1302641d-07,-3.9024309d-08 /
      data fpppp(12, 6,11,1),fpppp(12, 6,11,2),fpppp(12, 6,11,3)/
     x 4.4106391d-04,-1.7451887d-06, 2.7967354d-08 /
      data fpppp(12, 6,12,1),fpppp(12, 6,12,2),fpppp(12, 6,12,3)/
     x 1.7945248d-05, 5.7643997d-07,-8.6690490d-10 /
      data fpppp(12, 6,13,1),fpppp(12, 6,13,2),fpppp(12, 6,13,3)/
     x 3.9913684d-04,-3.1517564d-07, 6.5313089d-08 /
      data fpppp(12, 6,14,1),fpppp(12, 6,14,2),fpppp(12, 6,14,3)/
     x 1.1029776d-03,-7.8738418d-07,-1.4800937d-07 /
      data fpppp(12, 6,15,1),fpppp(12, 6,15,2),fpppp(12, 6,15,3)/
     x 2.0454173d-03,-5.4572834d-06, 3.5902443d-07 /
      data fpppp(12, 6,16,1),fpppp(12, 6,16,2),fpppp(12, 6,16,3)/
     x-7.0203280d-06,-1.0387093d-05,-8.3176708d-07 /
      data fpppp(12, 6,17,1),fpppp(12, 6,17,2),fpppp(12, 6,17,3)/
     x-4.8938576d-05,-3.7707684d-06, 1.3763850d-06 /
      data fpppp(12, 6,18,1),fpppp(12, 6,18,2),fpppp(12, 6,18,3)/
     x 1.5306632d-04,-6.3753225d-05,-8.1749042d-06 /
      data fpppp(12, 6,19,1),fpppp(12, 6,19,2),fpppp(12, 6,19,3)/
     x-7.7046071d-03, 1.4426893d-04, 1.2193432d-05 /
      data fpppp(12, 6,20,1),fpppp(12, 6,20,2),fpppp(12, 6,20,3)/
     x-1.0252079d-04,-4.4669500d-05,-3.5154365d-06 /
      data fpppp(12, 6,21,1),fpppp(12, 6,21,2),fpppp(12, 6,21,3)/
     x-1.0252079d-04,-3.0609685d-05,-2.2006038d-06 /
      data fpppp(12, 6,22,1),fpppp(12, 6,22,2),fpppp(12, 6,22,3)/
     x-7.7046071d-03, 8.8029675d-05, 6.9341015d-06 /
      data fpppp(12, 6,23,1),fpppp(12, 6,23,2),fpppp(12, 6,23,3)/
     x 1.5306632d-04, 1.4714399d-04, 1.1547586d-05 /
      data fpppp(12, 7, 1,1),fpppp(12, 7, 1,2),fpppp(12, 7, 1,3)/
     x-6.3401203d-04, 1.3589253d-04,-1.4704290d-06 /
      data fpppp(12, 7, 2,1),fpppp(12, 7, 2,2),fpppp(12, 7, 2,3)/
     x-6.4129498d-04, 6.4583774d-05,-1.0903606d-06 /
      data fpppp(12, 7, 3,1),fpppp(12, 7, 3,2),fpppp(12, 7, 3,3)/
     x-4.0035735d-03,-8.3319579d-05,-4.1422420d-07 /
      data fpppp(12, 7, 4,1),fpppp(12, 7, 4,2),fpppp(12, 7, 4,3)/
     x-4.0035735d-03,-9.1896530d-05,-1.7220620d-07 /
      data fpppp(12, 7, 5,1),fpppp(12, 7, 5,2),fpppp(12, 7, 5,3)/
     x-6.4129498d-04, 9.8891580d-05,-2.0584326d-06 /
      data fpppp(12, 7, 6,1),fpppp(12, 7, 6,2),fpppp(12, 7, 6,3)/
     x-6.3401203d-04, 7.2382508d-06, 2.1598409d-06 /
      data fpppp(12, 7, 7,1),fpppp(12, 7, 7,2),fpppp(12, 7, 7,3)/
     x 3.3103588d-04, 3.0573266d-06,-1.2875417d-07 /
      data fpppp(12, 7, 8,1),fpppp(12, 7, 8,2),fpppp(12, 7, 8,3)/
     x 1.7106703d-05, 2.2261949d-06, 2.8028522d-07 /
      data fpppp(12, 7, 9,1),fpppp(12, 7, 9,2),fpppp(12, 7, 9,3)/
     x 3.3297352d-05, 6.6736049d-06, 2.6495269d-08 /
      data fpppp(12, 7,10,1),fpppp(12, 7,10,2),fpppp(12, 7,10,3)/
     x-1.9464710d-04, 7.8398242d-06, 4.5336194d-08 /
      data fpppp(12, 7,11,1),fpppp(12, 7,11,2),fpppp(12, 7,11,3)/
     x-6.2699160d-05, 5.9271476d-06, 1.6149575d-08 /
      data fpppp(12, 7,12,1),fpppp(12, 7,12,2),fpppp(12, 7,12,3)/
     x 4.5174731d-05, 7.2837849d-06, 1.9314932d-08 /
      data fpppp(12, 7,13,1),fpppp(12, 7,13,2),fpppp(12, 7,13,3)/
     x-6.2430368d-05, 1.0393589d-06, 9.4119032d-09 /
      data fpppp(12, 7,14,1),fpppp(12, 7,14,2),fpppp(12, 7,14,3)/
     x-2.4852596d-04, 1.9284526d-05, 8.2070266d-08 /
      data fpppp(12, 7,15,1),fpppp(12, 7,15,2),fpppp(12, 7,15,3)/
     x-5.4237162d-04,-1.5763869d-05,-3.2392543d-08 /
      data fpppp(12, 7,16,1),fpppp(12, 7,16,2),fpppp(12, 7,16,3)/
     x-2.8847509d-06, 1.8934122d-05, 2.9859541d-07 /
      data fpppp(12, 7,17,1),fpppp(12, 7,17,2),fpppp(12, 7,17,3)/
     x-4.1142049d-05, 7.8953149d-06,-2.2380111d-07 /
      data fpppp(12, 7,18,1),fpppp(12, 7,18,2),fpppp(12, 7,18,3)/
     x-1.8618859d-04, 1.5915811d-05, 2.3260750d-06 /
      data fpppp(12, 7,19,1),fpppp(12, 7,19,2),fpppp(12, 7,19,3)/
     x 1.7449535d-03, 5.3345501d-05,-2.5390310d-06 /
      data fpppp(12, 7,20,1),fpppp(12, 7,20,2),fpppp(12, 7,20,3)/
     x-4.2631420d-04,-7.0874765d-05, 1.0287056d-07 /
      data fpppp(12, 7,21,1),fpppp(12, 7,21,2),fpppp(12, 7,21,3)/
     x-4.2631420d-04,-6.6346325d-05,-1.8659116d-07 /
      data fpppp(12, 7,22,1),fpppp(12, 7,22,2),fpppp(12, 7,22,3)/
     x 1.7449535d-03, 3.5231739d-05,-1.3811841d-06 /
      data fpppp(12, 7,23,1),fpppp(12, 7,23,2),fpppp(12, 7,23,3)/
     x-1.8618859d-04, 8.3842419d-05,-2.0158507d-06 /
      data fpppp(12, 8, 1,1),fpppp(12, 8, 1,2),fpppp(12, 8, 1,3)/
     x 1.1144151d-03, 1.9642021d-03,-5.6249702d-07 /
      data fpppp(12, 8, 2,1),fpppp(12, 8, 2,2),fpppp(12, 8, 2,3)/
     x 7.3263554d-03, 1.0555356d-03,-4.0943462d-07 /
      data fpppp(12, 8, 3,1),fpppp(12, 8, 3,2),fpppp(12, 8, 3,3)/
     x 9.9551451d-03,-7.9985260d-04,-1.2359916d-07 /
      data fpppp(12, 8, 4,1),fpppp(12, 8, 4,2),fpppp(12, 8, 4,3)/
     x 9.9551451d-03,-9.6042283d-04,-4.9827211d-08 /
      data fpppp(12, 8, 5,1),fpppp(12, 8, 5,2),fpppp(12, 8, 5,3)/
     x 7.3263554d-03, 1.6978165d-03,-7.0452242d-07 /
      data fpppp(12, 8, 6,1),fpppp(12, 8, 6,2),fpppp(12, 8, 6,3)/
     x 1.1144151d-03,-4.4435131d-04, 5.4408225d-07 /
      data fpppp(12, 8, 7,1),fpppp(12, 8, 7,2),fpppp(12, 8, 7,3)/
     x-3.2972732d-05, 1.1800165d-04, 3.5053762d-08 /
      data fpppp(12, 8, 8,1),fpppp(12, 8, 8,2),fpppp(12, 8, 8,3)/
     x 2.2285002d-05,-3.3778623d-05, 9.6476199d-08 /
      data fpppp(12, 8, 9,1),fpppp(12, 8, 9,2),fpppp(12, 8, 9,3)/
     x 3.2863130d-05, 1.4693285d-05, 6.2195167d-08 /
      data fpppp(12, 8,10,1),fpppp(12, 8,10,2),fpppp(12, 8,10,3)/
     x 9.4811596d-05, 7.7059878d-06, 4.2271721d-08 /
      data fpppp(12, 8,11,1),fpppp(12, 8,11,2),fpppp(12, 8,11,3)/
     x 6.1723532d-05, 1.5698323d-05, 3.2605875d-08 /
      data fpppp(12, 8,12,1),fpppp(12, 8,12,2),fpppp(12, 8,12,3)/
     x 2.7598199d-05, 9.0499059d-06, 2.9968878d-08 /
      data fpppp(12, 8,13,1),fpppp(12, 8,13,2),fpppp(12, 8,13,3)/
     x 4.9402412d-05, 1.8383787d-05, 3.2940969d-08 /
      data fpppp(12, 8,14,1),fpppp(12, 8,14,2),fpppp(12, 8,14,3)/
     x 7.4751770d-05,-7.4295441d-06, 1.9719927d-08 /
      data fpppp(12, 8,15,1),fpppp(12, 8,15,2),fpppp(12, 8,15,3)/
     x 1.6461828d-04, 1.7199363d-05, 6.3357599d-08 /
      data fpppp(12, 8,16,1),fpppp(12, 8,16,2),fpppp(12, 8,16,3)/
     x-1.8296711d-06, 4.1003665d-06,-6.9336182d-09 /
      data fpppp(12, 8,17,1),fpppp(12, 8,17,2),fpppp(12, 8,17,3)/
     x-8.1747864d-06, 1.2557021d-05, 1.4832379d-07 /
      data fpppp(12, 8,18,1),fpppp(12, 8,18,2),fpppp(12, 8,18,3)/
     x 1.0319377d-05, 9.3627968d-06,-5.5033434d-07 /
      data fpppp(12, 8,19,1),fpppp(12, 8,19,2),fpppp(12, 8,19,3)/
     x-5.1503945d-04, 1.5537757d-05, 7.2186059d-07 /
      data fpppp(12, 8,20,1),fpppp(12, 8,20,2),fpppp(12, 8,20,3)/
     x 8.7479388d-05,-4.5322347d-05,-3.3042304d-07 /
      data fpppp(12, 8,21,1),fpppp(12, 8,21,2),fpppp(12, 8,21,3)/
     x 8.7479388d-05,-4.3681065d-05,-2.4672396d-07 /
      data fpppp(12, 8,22,1),fpppp(12, 8,22,2),fpppp(12, 8,22,3)/
     x-5.1503945d-04, 8.9726287d-06, 3.8706427d-07 /
      data fpppp(12, 8,23,1),fpppp(12, 8,23,2),fpppp(12, 8,23,3)/
     x 1.0319377d-05, 3.3982028d-05, 7.0515186d-07 /
      data fpppp(12, 9, 1,1),fpppp(12, 9, 1,2),fpppp(12, 9, 1,3)/
     x-4.3556839d-03, 7.2218772d-04, 8.4112847d-07 /
      data fpppp(12, 9, 2,1),fpppp(12, 9, 2,2),fpppp(12, 9, 2,3)/
     x-1.4986348d-02,-1.5677263d-05, 7.7049635d-07 /
      data fpppp(12, 9, 3,1),fpppp(12, 9, 3,2),fpppp(12, 9, 3,3)/
     x-1.9461540d-02,-1.7295285d-03, 7.6072034d-07 /
      data fpppp(12, 9, 4,1),fpppp(12, 9, 4,2),fpppp(12, 9, 4,3)/
     x-1.9461540d-02,-1.4972825d-03, 5.1295791d-07 /
      data fpppp(12, 9, 5,1),fpppp(12, 9, 5,2),fpppp(12, 9, 5,3)/
     x-1.4986348d-02,-9.4466136d-04, 1.7615461d-06 /
      data fpppp(12, 9, 6,1),fpppp(12, 9, 6,2),fpppp(12, 9, 6,3)/
     x-4.3556839d-03, 4.2058781d-03,-2.8753079d-06 /
      data fpppp(12, 9, 7,1),fpppp(12, 9, 7,2),fpppp(12, 9, 7,3)/
     x-2.4105283d-04,-1.2329849d-03, 3.2726721d-07 /
      data fpppp(12, 9, 8,1),fpppp(12, 9, 8,2),fpppp(12, 9, 8,3)/
     x-3.7529092d-05, 3.1261870d-04,-1.1560442d-07 /
      data fpppp(12, 9, 9,1),fpppp(12, 9, 9,2),fpppp(12, 9, 9,3)/
     x-3.1949758d-05,-8.7507742d-05, 3.7013564d-08 /
      data fpppp(12, 9,10,1),fpppp(12, 9,10,2),fpppp(12, 9,10,3)/
     x-1.8818301d-05, 3.4951205d-05, 1.0113320d-08 /
      data fpppp(12, 9,11,1),fpppp(12, 9,11,2),fpppp(12, 9,11,3)/
     x-2.8478116d-06, 8.7592937d-06, 2.2151825d-08 /
      data fpppp(12, 9,12,1),fpppp(12, 9,12,2),fpppp(12, 9,12,3)/
     x 9.7358585d-06, 1.8667843d-05, 1.9413555d-08 /
      data fpppp(12, 9,13,1),fpppp(12, 9,13,2),fpppp(12, 9,13,3)/
     x 6.1778210d-07, 7.5686009d-06, 2.0483327d-08 /
      data fpppp(12, 9,14,1),fpppp(12, 9,14,2),fpppp(12, 9,14,3)/
     x-1.8375311d-06, 1.2995879d-05, 2.5609608d-08 /
      data fpppp(12, 9,15,1),fpppp(12, 9,15,2),fpppp(12, 9,15,3)/
     x-3.9661764d-05, 4.7138580d-06, 1.7304717d-08 /
      data fpppp(12, 9,16,1),fpppp(12, 9,16,2),fpppp(12, 9,16,3)/
     x-1.3985477d-06, 8.0841864d-06, 3.5329208d-08 /
      data fpppp(12, 9,17,1),fpppp(12, 9,17,2),fpppp(12, 9,17,3)/
     x-5.1240218d-06, 8.0756545d-06,-1.1717209d-08 /
      data fpppp(12, 9,18,1),fpppp(12, 9,18,2),fpppp(12, 9,18,3)/
     x-1.2503878d-05, 9.4779932d-06, 1.5252479d-07 /
      data fpppp(12, 9,19,1),fpppp(12, 9,19,2),fpppp(12, 9,19,3)/
     x 1.2864894d-04, 9.5095560d-06,-2.2511810d-07 /
      data fpppp(12, 9,20,1),fpppp(12, 9,20,2),fpppp(12, 9,20,3)/
     x-2.1169566d-05,-3.5426718d-05,-3.0413905d-08 /
      data fpppp(12, 9,21,1),fpppp(12, 9,21,2),fpppp(12, 9,21,3)/
     x-2.1169566d-05,-3.4429796d-05,-5.2653059d-08 /
      data fpppp(12, 9,22,1),fpppp(12, 9,22,2),fpppp(12, 9,22,3)/
     x 1.2864894d-04, 5.5218680d-06,-1.3616148d-07 /
      data fpppp(12, 9,23,1),fpppp(12, 9,23,2),fpppp(12, 9,23,3)/
     x-1.2503878d-05, 2.4431824d-05,-1.8106252d-07 /
      data fpppp(12,10, 1,1),fpppp(12,10, 1,2),fpppp(12,10, 1,3)/
     x 5.2961082d-03, 2.6164267d-03, 7.9254486d-07 /
      data fpppp(12,10, 2,1),fpppp(12,10, 2,2),fpppp(12,10, 2,3)/
     x 1.2631577d-02, 1.4486495d-03, 1.9585574d-07 /
      data fpppp(12,10, 3,1),fpppp(12,10, 3,2),fpppp(12,10, 3,3)/
     x 1.3805312d-02,-1.0606117d-03,-1.1851900d-06 /
      data fpppp(12,10, 4,1),fpppp(12,10, 4,2),fpppp(12,10, 4,3)/
     x 1.3805312d-02,-1.0485693d-03,-1.0059442d-06 /
      data fpppp(12,10, 5,1),fpppp(12,10, 5,2),fpppp(12,10, 5,3)/
     x 1.2631577d-02, 1.4004798d-03,-5.2112782d-07 /
      data fpppp(12,10, 6,1),fpppp(12,10, 6,2),fpppp(12,10, 6,3)/
     x 5.2961082d-03, 2.7970630d-03, 3.4812332d-06 /
      data fpppp(12,10, 7,1),fpppp(12,10, 7,2),fpppp(12,10, 7,3)/
     x-7.4169924d-04,-3.0373303d-03,-1.1192720d-06 /
      data fpppp(12,10, 8,1),fpppp(12,10, 8,2),fpppp(12,10, 8,3)/
     x-3.3251582d-04, 5.3670294d-04,-9.7704868d-08 /
      data fpppp(12,10, 9,1),fpppp(12,10, 9,2),fpppp(12,10, 9,3)/
     x-4.5930782d-05,-2.0615318d-04,-1.2815471d-07 /
      data fpppp(12,10,10,1),fpppp(12,10,10,2),fpppp(12,10,10,3)/
     x-4.2646934d-05, 4.8564784d-05,-1.9097496d-08 /
      data fpppp(12,10,11,1),fpppp(12,10,11,2),fpppp(12,10,11,3)/
     x-2.6860019d-05, 1.6138995d-06,-4.9378991d-09 /
      data fpppp(12,10,12,1),fpppp(12,10,12,2),fpppp(12,10,12,3)/
     x-2.1281435d-05, 1.7950001d-05, 7.3282946d-09 /
      data fpppp(12,10,13,1),fpppp(12,10,13,2),fpppp(12,10,13,3)/
     x-1.1679915d-05, 1.1448396d-05, 9.2448729d-09 /
      data fpppp(12,10,14,1),fpppp(12,10,14,2),fpppp(12,10,14,3)/
     x-7.6088613d-06, 9.6428924d-06, 9.8136558d-09 /
      data fpppp(12,10,15,1),fpppp(12,10,15,2),fpppp(12,10,15,3)/
     x 6.9358337d-06, 6.1621297d-06, 1.2096328d-08 /
      data fpppp(12,10,16,1),fpppp(12,10,16,2),fpppp(12,10,16,3)/
     x 1.1935243d-06, 7.8596389d-06, 4.1935973d-09 /
      data fpppp(12,10,17,1),fpppp(12,10,17,2),fpppp(12,10,17,3)/
     x 4.3401978d-06, 7.5310390d-06, 3.8050076d-09 /
      data fpppp(12,10,18,1),fpppp(12,10,18,2),fpppp(12,10,18,3)/
     x 7.8941740d-06, 8.6836046d-06,-5.2021477d-08 /
      data fpppp(12,10,19,1),fpppp(12,10,19,2),fpppp(12,10,19,3)/
     x-2.6418133d-05, 1.5594365d-05, 3.5898468d-08 /
      data fpppp(12,10,20,1),fpppp(12,10,20,2),fpppp(12,10,20,3)/
     x 1.5408867d-05,-3.2941854d-05,-3.6371368d-08 /
      data fpppp(12,10,21,1),fpppp(12,10,21,2),fpppp(12,10,21,3)/
     x 1.5408867d-05,-3.1538643d-05,-3.0597039d-08 /
      data fpppp(12,10,22,1),fpppp(12,10,22,2),fpppp(12,10,22,3)/
     x-2.6418133d-05, 9.9815174d-06, 1.2801151d-08 /
      data fpppp(12,10,23,1),fpppp(12,10,23,2),fpppp(12,10,23,3)/
     x 7.8941740d-06, 2.9731782d-05, 3.4593461d-08 /
      data fpppp(12,11, 1,1),fpppp(12,11, 1,2),fpppp(12,11, 1,3)/
     x-2.3577779d-03, 3.7932532d-04,-3.7300216d-07 /
      data fpppp(12,11, 2,1),fpppp(12,11, 2,2),fpppp(12,11, 2,3)/
     x-4.5625365d-03, 1.7088742d-04,-2.6445080d-07 /
      data fpppp(12,11, 3,1),fpppp(12,11, 3,2),fpppp(12,11, 3,3)/
     x-3.2822078d-03,-2.9837567d-04,-7.7992614d-10 /
      data fpppp(12,11, 4,1),fpppp(12,11, 4,2),fpppp(12,11, 4,3)/
     x-3.2822078d-03,-2.5880736d-04,-5.5136321d-08 /
      data fpppp(12,11, 5,1),fpppp(12,11, 5,2),fpppp(12,11, 5,3)/
     x-4.5625365d-03, 1.2614163d-05,-4.7025216d-08 /
      data fpppp(12,11, 6,1),fpppp(12,11, 6,2),fpppp(12,11, 6,3)/
     x-2.3577779d-03, 9.7285004d-04,-1.1883481d-06 /
      data fpppp(12,11, 7,1),fpppp(12,11, 7,2),fpppp(12,11, 7,3)/
     x 7.1455212d-04, 9.5106955d-05, 1.3475842d-06 /
      data fpppp(12,11, 8,1),fpppp(12,11, 8,2),fpppp(12,11, 8,3)/
     x-8.7660634d-05,-5.6863171d-04, 2.7453363d-08 /
      data fpppp(12,11, 9,1),fpppp(12,11, 9,2),fpppp(12,11, 9,3)/
     x-3.6209476d-04,-1.0446498d-04,-1.0076048d-08 /
      data fpppp(12,11,10,1),fpppp(12,11,10,2),fpppp(12,11,10,3)/
     x-6.9054246d-05,-4.7915262d-05,-3.7067440d-08 /
      data fpppp(12,11,11,1),fpppp(12,11,11,2),fpppp(12,11,11,3)/
     x-3.5566660d-05, 7.8077592d-06,-1.0182476d-08 /
      data fpppp(12,11,12,1),fpppp(12,11,12,2),fpppp(12,11,12,3)/
     x-2.0883533d-05, 1.0944164d-05, 4.2636081d-10 /
      data fpppp(12,11,13,1),fpppp(12,11,13,2),fpppp(12,11,13,3)/
     x-1.5465607d-05, 1.2265710d-05, 3.5470514d-09 /
      data fpppp(12,11,14,1),fpppp(12,11,14,2),fpppp(12,11,14,3)/
     x-1.1113056d-05, 8.3033473d-06, 3.3831957d-09 /
      data fpppp(12,11,15,1),fpppp(12,11,15,2),fpppp(12,11,15,3)/
     x-8.3915960d-06, 7.5136668d-06, 9.9039586d-10 /
      data fpppp(12,11,16,1),fpppp(12,11,16,2),fpppp(12,11,16,3)/
     x-9.0353671d-07, 5.7146204d-06,-1.5127159d-09 /
      data fpppp(12,11,17,1),fpppp(12,11,17,2),fpppp(12,11,17,3)/
     x 4.1546662d-06, 5.9024262d-06,-5.0667693d-09 /
      data fpppp(12,11,18,1),fpppp(12,11,18,2),fpppp(12,11,18,3)/
     x 7.2601258d-06, 1.0167761d-05, 5.4660291d-09 /
      data fpppp(12,11,19,1),fpppp(12,11,19,2),fpppp(12,11,19,3)/
     x 1.9073860d-05, 1.9424804d-05,-2.3251469d-08 /
      data fpppp(12,11,20,1),fpppp(12,11,20,2),fpppp(12,11,20,3)/
     x 9.8711485d-06,-3.1148596d-05,-7.4275406d-10 /
      data fpppp(12,11,21,1),fpppp(12,11,21,2),fpppp(12,11,21,3)/
     x 9.8711485d-06,-2.9588883d-05,-2.6045372d-09 /
      data fpppp(12,11,22,1),fpppp(12,11,22,2),fpppp(12,11,22,3)/
     x 1.9073860d-05, 1.3185950d-05,-1.5804337d-08 /
      data fpppp(12,11,23,1),fpppp(12,11,23,2),fpppp(12,11,23,3)/
     x 7.2601258d-06, 3.3563463d-05,-2.2460719d-08 /
      data fpppp(12,12, 1,1),fpppp(12,12, 1,2),fpppp(12,12, 1,3)/
     x 7.2031432d-04, 6.1428439d-04, 5.2354344d-08 /
      data fpppp(12,12, 2,1),fpppp(12,12, 2,2),fpppp(12,12, 2,3)/
     x 1.4839104d-03, 2.6660062d-04,-3.6803653d-08 /
      data fpppp(12,12, 3,1),fpppp(12,12, 3,2),fpppp(12,12, 3,3)/
     x 1.4917179d-03,-4.7927452d-04,-2.3489640d-07 /
      data fpppp(12,12, 4,1),fpppp(12,12, 4,2),fpppp(12,12, 4,3)/
     x 1.4917179d-03,-4.7780716d-04,-2.2257658d-07 /
      data fpppp(12,12, 5,1),fpppp(12,12, 5,2),fpppp(12,12, 5,3)/
     x 1.4839104d-03, 2.6073117d-04,-8.6082941d-08 /
      data fpppp(12,12, 6,1),fpppp(12,12, 6,2),fpppp(12,12, 6,3)/
     x 7.2031432d-04, 6.3629482d-04, 2.3715167d-07 /
      data fpppp(12,12, 7,1),fpppp(12,12, 7,2),fpppp(12,12, 7,3)/
     x-1.2400657d-06, 4.5091932d-04,-1.9972335d-07 /
      data fpppp(12,12, 8,1),fpppp(12,12, 8,2),fpppp(12,12, 8,3)/
     x 1.1806458d-04,-2.6544579d-04, 2.8017254d-07 /
      data fpppp(12,12, 9,1),fpppp(12,12, 9,2),fpppp(12,12, 9,3)/
     x 8.3939053d-04,-2.6969680d-04, 8.1032835d-08 /
      data fpppp(12,12,10,1),fpppp(12,12,10,2),fpppp(12,12,10,3)/
     x-4.2709221d-05,-1.0206419d-04, 2.3190424d-08 /
      data fpppp(12,12,11,1),fpppp(12,12,11,2),fpppp(12,12,11,3)/
     x-2.9880169d-05,-1.9182658d-05, 5.6411999d-09 /
      data fpppp(12,12,12,1),fpppp(12,12,12,2),fpppp(12,12,12,3)/
     x-2.1675155d-05, 4.2941108d-06, 7.6951306d-10 /
      data fpppp(12,12,13,1),fpppp(12,12,13,2),fpppp(12,12,13,3)/
     x-1.5544804d-05, 9.7316319d-06, 1.8605230d-09 /
      data fpppp(12,12,14,1),fpppp(12,12,14,2),fpppp(12,12,14,3)/
     x-1.0930815d-05, 8.7052595d-06,-4.0409566d-10 /
      data fpppp(12,12,15,1),fpppp(12,12,15,2),fpppp(12,12,15,3)/
     x-7.8434209d-06, 7.6734464d-06,-2.8008848d-09 /
      data fpppp(12,12,16,1),fpppp(12,12,16,2),fpppp(12,12,16,3)/
     x-6.0568535d-06, 4.0737422d-06,-3.5531815d-09 /
      data fpppp(12,12,17,1),fpppp(12,12,17,2),fpppp(12,12,17,3)/
     x-3.6751715d-06, 3.2136817d-06, 7.2683458d-10 /
      data fpppp(12,12,18,1),fpppp(12,12,18,2),fpppp(12,12,18,3)/
     x 8.8000916d-07, 1.0158132d-05,-4.9125211d-10 /
      data fpppp(12,12,19,1),fpppp(12,12,19,2),fpppp(12,12,19,3)/
     x-1.7383439d-06, 2.0083798d-05, 3.9170952d-09 /
      data fpppp(12,12,20,1),fpppp(12,12,20,2),fpppp(12,12,20,3)/
     x-9.7917077d-06,-2.8537253d-05,-2.3677447d-09 /
      data fpppp(12,12,21,1),fpppp(12,12,21,2),fpppp(12,12,21,3)/
     x-9.7917077d-06,-2.6989049d-05,-2.0192665d-09 /
      data fpppp(12,12,22,1),fpppp(12,12,22,2),fpppp(12,12,22,3)/
     x-1.7383439d-06, 1.3890983d-05, 2.5231827d-09 /
      data fpppp(12,12,23,1),fpppp(12,12,23,2),fpppp(12,12,23,3)/
     x 8.8000916d-07, 3.3381186d-05, 4.7359198d-09 /
      data fpppp(12,13, 1,1),fpppp(12,13, 1,2),fpppp(12,13, 1,3)/
     x-1.3675104d-04, 1.0099264d-03,-7.1685141d-07 /
      data fpppp(12,13, 2,1),fpppp(12,13, 2,2),fpppp(12,13, 2,3)/
     x-6.0255547d-04, 4.3971744d-04,-3.3900220d-07 /
      data fpppp(12,13, 3,1),fpppp(12,13, 3,2),fpppp(12,13, 3,3)/
     x-1.1650572d-03,-7.6523522d-04, 4.5955217d-07 /
      data fpppp(12,13, 4,1),fpppp(12,13, 4,2),fpppp(12,13, 4,3)/
     x-1.1650572d-03,-7.9485177d-04, 4.7901653d-07 /
      data fpppp(12,13, 5,1),fpppp(12,13, 5,2),fpppp(12,13, 5,3)/
     x-6.0255547d-04, 5.5818365d-04,-4.1685964d-07 /
      data fpppp(12,13, 6,1),fpppp(12,13, 6,2),fpppp(12,13, 6,3)/
     x-1.3675104d-04, 5.6567815d-04,-4.2488602d-07 /
      data fpppp(12,13, 7,1),fpppp(12,13, 7,2),fpppp(12,13, 7,3)/
     x 1.0449840d-04, 5.0482528d-04,-7.3204600d-08 /
      data fpppp(12,13, 8,1),fpppp(12,13, 8,2),fpppp(12,13, 8,3)/
     x-8.1222454d-05, 4.1350322d-05, 2.3298908d-08 /
      data fpppp(12,13, 9,1),fpppp(12,13, 9,2),fpppp(12,13, 9,3)/
     x-3.3146667d-03,-2.5932254d-04, 7.4808780d-08 /
      data fpppp(12,13,10,1),fpppp(12,13,10,2),fpppp(12,13,10,3)/
     x-2.8555161d-05,-1.8891988d-04, 5.4207043d-08 /
      data fpppp(12,13,11,1),fpppp(12,13,11,2),fpppp(12,13,11,3)/
     x-1.9091355d-05,-4.7437606d-05, 2.9268413d-08 /
      data fpppp(12,13,12,1),fpppp(12,13,12,2),fpppp(12,13,12,3)/
     x-1.4290969d-05,-6.5550905d-06, 1.1591344d-08 /
      data fpppp(12,13,13,1),fpppp(12,13,13,2),fpppp(12,13,13,3)/
     x-1.1196373d-05, 5.9890358d-06, 1.8170906d-09 /
      data fpppp(12,13,14,1),fpppp(12,13,14,2),fpppp(12,13,14,3)/
     x-1.1253603d-05, 7.8577477d-06,-4.7506215d-11 /
      data fpppp(12,13,15,1),fpppp(12,13,15,2),fpppp(12,13,15,3)/
     x-1.0333847d-05, 7.2789504d-06,-2.2703180d-09 /
      data fpppp(12,13,16,1),fpppp(12,13,16,2),fpppp(12,13,16,3)/
     x-1.2553134d-05, 2.3236426d-06,-1.2200192d-09 /
      data fpppp(12,13,17,1),fpppp(12,13,17,2),fpppp(12,13,17,3)/
     x-1.3376786d-05, 2.8623354d-06, 2.5047373d-09 /
      data fpppp(12,13,18,1),fpppp(12,13,18,2),fpppp(12,13,18,3)/
     x-1.4979798d-05, 6.8700224d-06, 7.0232152d-09 /
      data fpppp(12,13,19,1),fpppp(12,13,19,2),fpppp(12,13,19,3)/
     x-1.8440951d-05, 9.6753129d-06, 5.8208385d-09 /
      data fpppp(12,13,20,1),fpppp(12,13,20,2),fpppp(12,13,20,3)/
     x-1.9774781d-05,-1.9006683d-05,-2.6215032d-09 /
      data fpppp(12,13,21,1),fpppp(12,13,21,2),fpppp(12,13,21,3)/
     x-1.9774781d-05,-1.8238160d-05,-2.4915641d-09 /
      data fpppp(12,13,22,1),fpppp(12,13,22,2),fpppp(12,13,22,3)/
     x-1.8440951d-05, 6.6012201d-06, 5.3010823d-09 /
      data fpppp(12,13,23,1),fpppp(12,13,23,2),fpppp(12,13,23,3)/
     x-1.4979798d-05, 1.8397870d-05, 8.9723010d-09 /
      data fpppp(12,14, 1,1),fpppp(12,14, 1,2),fpppp(12,14, 1,3)/
     x-1.1311674d-04, 8.1746952d-04,-3.5781631d-07 /
      data fpppp(12,14, 2,1),fpppp(12,14, 2,2),fpppp(12,14, 2,3)/
     x-2.7971084d-04, 3.3118172d-04,-1.2826237d-07 /
      data fpppp(12,14, 3,1),fpppp(12,14, 3,2),fpppp(12,14, 3,3)/
     x-6.6388851d-04,-6.9664804d-04, 3.6061463d-07 /
      data fpppp(12,14, 4,1),fpppp(12,14, 4,2),fpppp(12,14, 4,3)/
     x-6.6388851d-04,-7.2152521d-04, 3.6590717d-07 /
      data fpppp(12,14, 5,1),fpppp(12,14, 5,2),fpppp(12,14, 5,3)/
     x-2.7971084d-04, 4.3069041d-04,-1.4943253d-07 /
      data fpppp(12,14, 6,1),fpppp(12,14, 6,2),fpppp(12,14, 6,3)/
     x-1.1311674d-04, 4.4431193d-04,-2.7842820d-07 /
      data fpppp(12,14, 7,1),fpppp(12,14, 7,2),fpppp(12,14, 7,3)/
     x 1.4657438d-04, 4.2359390d-04,-2.7950184d-07 /
      data fpppp(12,14, 8,1),fpppp(12,14, 8,2),fpppp(12,14, 8,3)/
     x 5.9493146d-04, 2.6108914d-04,-4.6173225d-08 /
      data fpppp(12,14, 9,1),fpppp(12,14, 9,2),fpppp(12,14, 9,3)/
     x 1.2292098d-02,-1.0564443d-04, 6.4715857d-08 /
      data fpppp(12,14,10,1),fpppp(12,14,10,2),fpppp(12,14,10,3)/
     x-1.0307751d-05,-2.8670896d-04, 5.2971214d-08 /
      data fpppp(12,14,11,1),fpppp(12,14,11,2),fpppp(12,14,11,3)/
     x-5.9845576d-06,-8.0195874d-05, 4.6302099d-08 /
      data fpppp(12,14,12,1),fpppp(12,14,12,2),fpppp(12,14,12,3)/
     x-7.7233683d-06,-1.7797350d-05, 1.8807499d-08 /
      data fpppp(12,14,13,1),fpppp(12,14,13,2),fpppp(12,14,13,3)/
     x-9.2228775d-06,-3.3652610d-07, 7.7246042d-09 /
      data fpppp(12,14,14,1),fpppp(12,14,14,2),fpppp(12,14,14,3)/
     x-6.7899313d-06, 7.5439451d-06, 1.1577727d-09 /
      data fpppp(12,14,15,1),fpppp(12,14,15,2),fpppp(12,14,15,3)/
     x-1.0787510d-05, 3.2834065d-06, 1.0540588d-09 /
      data fpppp(12,14,16,1),fpppp(12,14,16,2),fpppp(12,14,16,3)/
     x-1.2323958d-05, 3.0481580d-06, 1.8619985d-09 /
      data fpppp(12,14,17,1),fpppp(12,14,17,2),fpppp(12,14,17,3)/
     x-1.4263328d-05, 1.9883078d-06, 2.9673537d-09 /
      data fpppp(12,14,18,1),fpppp(12,14,18,2),fpppp(12,14,18,3)/
     x-1.7542244d-05, 9.1453539d-07, 2.5971015d-09 /
      data fpppp(12,14,19,1),fpppp(12,14,19,2),fpppp(12,14,19,3)/
     x-1.4855009d-05, 1.8190764d-06, 3.8915725d-09 /
      data fpppp(12,14,20,1),fpppp(12,14,20,2),fpppp(12,14,20,3)/
     x-7.3572752d-06,-9.1329504d-06, 1.5669608d-09 /
      data fpppp(12,14,21,1),fpppp(12,14,21,2),fpppp(12,14,21,3)/
     x-7.3572752d-06,-8.8474052d-06, 1.6799018d-09 /
      data fpppp(12,14,22,1),fpppp(12,14,22,2),fpppp(12,14,22,3)/
     x-1.4855009d-05, 6.7689532d-07, 3.4398086d-09 /
      data fpppp(12,14,23,1),fpppp(12,14,23,2),fpppp(12,14,23,3)/
     x-1.7542244d-05, 5.1977143d-06, 4.2912161d-09 /
      data fpppp(12,15, 1,1),fpppp(12,15, 1,2),fpppp(12,15, 1,3)/
     x 1.2236226d-04, 2.0532901d-04, 2.4987149d-07 /
      data fpppp(12,15, 2,1),fpppp(12,15, 2,2),fpppp(12,15, 2,3)/
     x-2.6750889d-04, 3.9392711d-05, 9.8771937d-08 /
      data fpppp(12,15, 3,1),fpppp(12,15, 3,2),fpppp(12,15, 3,3)/
     x-5.2919773d-04,-3.1421339d-04,-2.1588664d-07 /
      data fpppp(12,15, 4,1),fpppp(12,15, 4,2),fpppp(12,15, 4,3)/
     x-5.2919773d-04,-3.1766382d-04,-2.3185747d-07 /
      data fpppp(12,15, 5,1),fpppp(12,15, 5,2),fpppp(12,15, 5,3)/
     x-2.6750889d-04, 5.3194413d-05, 1.6265525d-07 /
      data fpppp(12,15, 6,1),fpppp(12,15, 6,2),fpppp(12,15, 6,3)/
     x 1.2236226d-04, 1.5357263d-04, 1.0309083d-08 /
      data fpppp(12,15, 7,1),fpppp(12,15, 7,2),fpppp(12,15, 7,3)/
     x-4.9452080d-04, 4.1093649d-04, 6.1345428d-08 /
      data fpppp(12,15, 8,1),fpppp(12,15, 8,2),fpppp(12,15, 8,3)/
     x-1.7161306d-03, 9.8871993d-05, 2.3629847d-08 /
      data fpppp(12,15, 9,1),fpppp(12,15, 9,2),fpppp(12,15, 9,3)/
     x-4.6011289d-02, 3.8125144d-04,-1.2730909d-07 /
      data fpppp(12,15,10,1),fpppp(12,15,10,2),fpppp(12,15,10,3)/
     x 1.4399042d-05,-4.9330396d-04, 1.1649979d-07 /
      data fpppp(12,15,11,1),fpppp(12,15,11,2),fpppp(12,15,11,3)/
     x 8.3054967d-06,-9.2459737d-05, 4.4993320d-08 /
      data fpppp(12,15,12,1),fpppp(12,15,12,2),fpppp(12,15,12,3)/
     x-7.0302487d-07,-3.4037711d-05, 2.2346460d-08 /
      data fpppp(12,15,13,1),fpppp(12,15,13,2),fpppp(12,15,13,3)/
     x-2.6443732d-06,-8.4549716d-07, 9.8631622d-09 /
      data fpppp(12,15,14,1),fpppp(12,15,14,2),fpppp(12,15,14,3)/
     x-6.2017069d-06,-7.6110030d-08, 5.3739365d-09 /
      data fpppp(12,15,15,1),fpppp(12,15,15,2),fpppp(12,15,15,3)/
     x-4.7560058d-06, 2.9542052d-06, 3.4853290d-09 /
      data fpppp(12,15,16,1),fpppp(12,15,16,2),fpppp(12,15,16,3)/
     x-3.8302696d-06, 2.5990689d-06, 4.2095192d-09 /
      data fpppp(12,15,17,1),fpppp(12,15,17,2),fpppp(12,15,17,3)/
     x-5.3796288d-06,-5.4879291d-07, 2.8846262d-09 /
      data fpppp(12,15,18,1),fpppp(12,15,18,2),fpppp(12,15,18,3)/
     x-3.9785858d-06,-4.0219588d-07, 2.8357718d-09 /
      data fpppp(12,15,19,1),fpppp(12,15,19,2),fpppp(12,15,19,3)/
     x-2.0996820d-06,-4.4478640d-07, 2.4045208d-09 /
      data fpppp(12,15,20,1),fpppp(12,15,20,2),fpppp(12,15,20,3)/
     x 7.1660814d-07,-3.9607634d-06,-2.0603307d-09 /
      data fpppp(12,15,21,1),fpppp(12,15,21,2),fpppp(12,15,21,3)/
     x 7.1660814d-07,-3.8848995d-06,-1.9818965d-09 /
      data fpppp(12,15,22,1),fpppp(12,15,22,2),fpppp(12,15,22,3)/
     x-2.0996820d-06,-7.4824185d-07, 2.0907842d-09 /
      data fpppp(12,15,23,1),fpppp(12,15,23,2),fpppp(12,15,23,3)/
     x-3.9785858d-06, 7.3576209d-07, 4.0122842d-09 /
      data fpppp(12,16, 1,1),fpppp(12,16, 1,2),fpppp(12,16, 1,3)/
     x-7.4404995d-04,-1.2779092d-04, 2.1844187d-07 /
      data fpppp(12,16, 2,1),fpppp(12,16, 2,2),fpppp(12,16, 2,3)/
     x 1.3591461d-03,-1.3271378d-04, 1.0323154d-07 /
      data fpppp(12,16, 3,1),fpppp(12,16, 3,2),fpppp(12,16, 3,3)/
     x 3.8379646d-03,-1.8761262d-05,-1.5044727d-07 /
      data fpppp(12,16, 4,1),fpppp(12,16, 4,2),fpppp(12,16, 4,3)/
     x 3.8379646d-03,-2.3663888d-04,-1.3854811d-07 /
      data fpppp(12,16, 5,1),fpppp(12,16, 5,2),fpppp(12,16, 5,3)/
     x 1.3591461d-03, 7.3879671d-04, 5.5634902d-08 /
      data fpppp(12,16, 6,1),fpppp(12,16, 6,2),fpppp(12,16, 6,3)/
     x-7.4404995d-04,-3.3959553d-03, 3.9692925d-07 /
      data fpppp(12,16, 7,1),fpppp(12,16, 7,2),fpppp(12,16, 7,3)/
     x 2.0899165d-03, 1.3373578d-02,-7.2857275d-07 /
      data fpppp(12,16, 8,1),fpppp(12,16, 8,2),fpppp(12,16, 8,3)/
     x 8.6907765d-03,-4.7169099d-02, 1.1028799d-07 /
      data fpppp(12,16, 9,1),fpppp(12,16, 9,2),fpppp(12,16, 9,3)/
     x 7.3821301d-02, 7.3800147d-02, 1.3131680d-07 /
      data fpppp(12,16,10,1),fpppp(12,16,10,2),fpppp(12,16,10,3)/
     x 3.1931005d-04,-4.6670851d-02, 2.3969031d-07 /
      data fpppp(12,16,11,1),fpppp(12,16,11,2),fpppp(12,16,11,3)/
     x 5.4058505d-05, 1.2263430d-02,-3.1714429d-08 /
      data fpppp(12,16,12,1),fpppp(12,16,12,2),fpppp(12,16,12,3)/
     x 1.0732441d-05,-3.3477374d-03, 2.0622168d-08 /
      data fpppp(12,16,13,1),fpppp(12,16,13,2),fpppp(12,16,13,3)/
     x 8.2528789d-07, 8.8225604d-04, 4.7597750d-09 /
      data fpppp(12,16,14,1),fpppp(12,16,14,2),fpppp(12,16,14,3)/
     x-2.2430486d-06,-2.4037153d-04, 7.6228645d-09 /
      data fpppp(12,16,15,1),fpppp(12,16,15,2),fpppp(12,16,15,3)/
     x-3.0147816d-06, 6.5594152d-05, 6.0020640d-09 /
      data fpppp(12,16,16,1),fpppp(12,16,16,2),fpppp(12,16,16,3)/
     x-4.2668487d-06,-1.7150316d-05, 4.1937858d-09 /
      data fpppp(12,16,17,1),fpppp(12,16,17,2),fpppp(12,16,17,3)/
     x-2.2867926d-06, 4.0749607d-06, 2.8812582d-09 /
      data fpppp(12,16,18,1),fpppp(12,16,18,2),fpppp(12,16,18,3)/
     x-8.2450167d-07,-1.1177505d-06,-1.8251660d-10 /
      data fpppp(12,16,19,1),fpppp(12,16,19,2),fpppp(12,16,19,3)/
     x 3.9245342d-06,-1.1098710d-06,-2.7674608d-09 /
      data fpppp(12,16,20,1),fpppp(12,16,20,2),fpppp(12,16,20,3)/
     x 4.4620594d-06,-1.4363318d-06,-3.2520901d-09 /
      data fpppp(12,16,21,1),fpppp(12,16,21,2),fpppp(12,16,21,3)/
     x 4.4620594d-06,-1.4287261d-06,-3.3640577d-09 /
      data fpppp(12,16,22,1),fpppp(12,16,22,2),fpppp(12,16,22,3)/
     x 3.9245342d-06,-1.1402941d-06,-2.3195904d-09 /
      data fpppp(12,16,23,1),fpppp(12,16,23,2),fpppp(12,16,23,3)/
     x-8.2450167d-07,-1.0036642d-06,-1.8620304d-09 /
      data fpppp(12,17, 1,1),fpppp(12,17, 1,2),fpppp(12,17, 1,3)/
     x 5.5255325d-03,-1.2356650d-04,-1.5421539d-07 /
      data fpppp(12,17, 2,1),fpppp(12,17, 2,2),fpppp(12,17, 2,3)/
     x-3.2309948d-03,-6.4050864d-05,-2.0276526d-07 /
      data fpppp(12,17, 3,1),fpppp(12,17, 3,2),fpppp(12,17, 3,3)/
     x-1.2486128d-02, 1.0833485d-04,-2.9235915d-07 /
      data fpppp(12,17, 4,1),fpppp(12,17, 4,2),fpppp(12,17, 4,3)/
     x-1.2486128d-02, 2.9843499d-05,-3.1763187d-07 /
      data fpppp(12,17, 5,1),fpppp(12,17, 5,2),fpppp(12,17, 5,3)/
     x-3.2309948d-03, 2.4991455d-04,-1.0167439d-07 /
      data fpppp(12,17, 6,1),fpppp(12,17, 6,2),fpppp(12,17, 6,3)/
     x 5.5255325d-03,-1.3009368d-03,-5.3330615d-07 /
      data fpppp(12,17, 7,1),fpppp(12,17, 7,2),fpppp(12,17, 7,3)/
     x-2.2153257d-03, 7.1770288d-03, 1.5091454d-06 /
      data fpppp(12,17, 8,1),fpppp(12,17, 8,2),fpppp(12,17, 8,3)/
     x-1.3416597d-02,-1.2442421d-02,-2.8422088d-07 /
      data fpppp(12,17, 9,1),fpppp(12,17, 9,2),fpppp(12,17, 9,3)/
     x-4.6375360d-02, 7.6872523d-03, 5.0799845d-07 /
      data fpppp(12,17,10,1),fpppp(12,17,10,2),fpppp(12,17,10,3)/
     x-1.1692368d-04,-1.7079041d-03,-5.6288824d-07 /
      data fpppp(12,17,11,1),fpppp(12,17,11,2),fpppp(12,17,11,3)/
     x 2.5305437d-05, 3.8810269d-04, 7.1366305d-09 /
      data fpppp(12,17,12,1),fpppp(12,17,12,2),fpppp(12,17,12,3)/
     x 2.3400382d-05,-1.3640901d-04,-5.7656868d-08 /
      data fpppp(12,17,13,1),fpppp(12,17,13,2),fpppp(12,17,13,3)/
     x 9.6620076d-06, 2.5372004d-05,-5.3675478d-09 /
      data fpppp(12,17,14,1),fpppp(12,17,14,2),fpppp(12,17,14,3)/
     x 5.7528495d-06,-1.0184258d-05,-3.6625148d-09 /
      data fpppp(12,17,15,1),fpppp(12,17,15,2),fpppp(12,17,15,3)/
     x 3.2870307d-06, 1.9217360d-06, 1.9601807d-09 /
      data fpppp(12,17,16,1),fpppp(12,17,16,2),fpppp(12,17,16,3)/
     x 4.8757991d-06,-5.1964615d-07, 2.5173939d-09 /
      data fpppp(12,17,17,1),fpppp(12,17,17,2),fpppp(12,17,17,3)/
     x 5.0430893d-06,-1.4772224d-06, 3.6834918d-10 /
      data fpppp(12,17,18,1),fpppp(12,17,18,2),fpppp(12,17,18,3)/
     x 5.7578338d-06, 3.9171828d-06,-1.5597950d-09 /
      data fpppp(12,17,19,1),fpppp(12,17,19,2),fpppp(12,17,19,3)/
     x 1.3754331d-06,-6.0732759d-06,-3.6163274d-09 /
      data fpppp(12,17,20,1),fpppp(12,17,20,2),fpppp(12,17,20,3)/
     x 1.5027676d-06, 1.1319711d-06,-4.7506202d-09 /
      data fpppp(12,17,21,1),fpppp(12,17,21,2),fpppp(12,17,21,3)/
     x 1.5027676d-06, 4.9813057d-07,-4.8231137d-09 /
      data fpppp(12,17,22,1),fpppp(12,17,22,2),fpppp(12,17,22,3)/
     x 1.3754331d-06,-3.5379138d-06,-3.3263536d-09 /
      data fpppp(12,17,23,1),fpppp(12,17,23,2),fpppp(12,17,23,3)/
     x 5.7578338d-06,-5.5904253d-06,-2.6471971d-09 /
      data fpppp(12,18, 1,1),fpppp(12,18, 1,2),fpppp(12,18, 1,3)/
     x-6.2507439d-03,-2.3165715d-03, 2.0347177d-07 /
      data fpppp(12,18, 2,1),fpppp(12,18, 2,2),fpppp(12,18, 2,3)/
     x 3.5187973d-03,-5.7662991d-04, 2.4014533d-07 /
      data fpppp(12,18, 3,1),fpppp(12,18, 3,2),fpppp(12,18, 3,3)/
     x 1.3688808d-02, 3.5392949d-03, 3.1404850d-07 /
      data fpppp(12,18, 4,1),fpppp(12,18, 4,2),fpppp(12,18, 4,3)/
     x 1.3688808d-02, 2.8612075d-03, 3.2224383d-07 /
      data fpppp(12,18, 5,1),fpppp(12,18, 5,2),fpppp(12,18, 5,3)/
     x 3.5187973d-03, 2.1357200d-03, 2.0736398d-07 /
      data fpppp(12,18, 6,1),fpppp(12,18, 6,2),fpppp(12,18, 6,3)/
     x-6.2507439d-03,-1.2487884d-02, 3.2640183d-07 /
      data fpppp(12,18, 7,1),fpppp(12,18, 7,2),fpppp(12,18, 7,3)/
     x 4.8545199d-04, 7.1870119d-03,-6.2057597d-07 /
      data fpppp(12,18, 8,1),fpppp(12,18, 8,2),fpppp(12,18, 8,3)/
     x 5.1692726d-03,-1.3870386d-03, 4.4797908d-08 /
      data fpppp(12,18, 9,1),fpppp(12,18, 9,2),fpppp(12,18, 9,3)/
     x 8.2803075d-03,-2.0077980d-05,-4.7483289d-07 /
      data fpppp(12,18,10,1),fpppp(12,18,10,2),fpppp(12,18,10,3)/
     x-7.0976031d-05, 7.8043495d-05, 1.3386948d-07 /
      data fpppp(12,18,11,1),fpppp(12,18,11,2),fpppp(12,18,11,3)/
     x-2.7158802d-05,-1.7778444d-05,-4.8537044d-08 /
      data fpppp(12,18,12,1),fpppp(12,18,12,2),fpppp(12,18,12,3)/
     x-9.1426306d-06,-6.2787383d-06, 1.9782963d-09 /
      data fpppp(12,18,13,1),fpppp(12,18,13,2),fpppp(12,18,13,3)/
     x 2.4044998d-06, 3.4507859d-06,-8.1166012d-09 /
      data fpppp(12,18,14,1),fpppp(12,18,14,2),fpppp(12,18,14,3)/
     x 3.7331961d-06,-2.7128775d-06,-3.1577273d-09 /
      data fpppp(12,18,15,1),fpppp(12,18,15,2),fpppp(12,18,15,3)/
     x 4.6405381d-06, 1.7986504d-06,-3.3560821d-09 /
      data fpppp(12,18,16,1),fpppp(12,18,16,2),fpppp(12,18,16,3)/
     x 3.5814299d-06,-1.5988477d-06,-3.9052591d-09 /
      data fpppp(12,18,17,1),fpppp(12,18,17,2),fpppp(12,18,17,3)/
     x 4.2958141d-06,-4.1954764d-07,-4.7937686d-09 /
      data fpppp(12,18,18,1),fpppp(12,18,18,2),fpppp(12,18,18,3)/
     x 4.9833315d-06, 1.8677420d-06,-6.4999511d-09 /
      data fpppp(12,18,19,1),fpppp(12,18,19,2),fpppp(12,18,19,3)/
     x 7.0564435d-06,-5.0252834d-06,-8.0415248d-09 /
      data fpppp(12,18,20,1),fpppp(12,18,20,2),fpppp(12,18,20,3)/
     x 1.0725241d-05, 2.1621742d-06,-8.8065996d-09 /
      data fpppp(12,18,21,1),fpppp(12,18,21,2),fpppp(12,18,21,3)/
     x 1.0725241d-05, 1.6757578d-06,-8.8628278d-09 /
      data fpppp(12,18,22,1),fpppp(12,18,22,2),fpppp(12,18,22,3)/
     x 7.0564435d-06,-3.0796178d-06,-7.8166124d-09 /
      data fpppp(12,18,23,1),fpppp(12,18,23,2),fpppp(12,18,23,3)/
     x 4.9833315d-06,-5.4285040d-06,-7.3433727d-09 /
      data fpppp(12,19, 1,1),fpppp(12,19, 1,2),fpppp(12,19, 1,3)/
     x-1.2871061d-02, 2.6771581d-17, 3.5248909d-07 /
      data fpppp(12,19, 2,1),fpppp(12,19, 2,2),fpppp(12,19, 2,3)/
     x 7.0286086d-03,-1.5243376d-17, 4.6908239d-07 /
      data fpppp(12,19, 3,1),fpppp(12,19, 3,2),fpppp(12,19, 3,3)/
     x 2.7721164d-02, 1.6482707d-18, 7.0665056d-07 /
      data fpppp(12,19, 4,1),fpppp(12,19, 4,2),fpppp(12,19, 4,3)/
     x 2.7721164d-02, 1.3015354d-18, 7.2813112d-07 /
      data fpppp(12,19, 5,1),fpppp(12,19, 5,2),fpppp(12,19, 5,3)/
     x 7.0286086d-03,-9.3264782d-18, 3.8316017d-07 /
      data fpppp(12,19, 6,1),fpppp(12,19, 6,2),fpppp(12,19, 6,3)/
     x-1.2871061d-02,-1.0025234d-17, 6.7469741d-07 /
      data fpppp(12,19, 7,1),fpppp(12,19, 7,2),fpppp(12,19, 7,3)/
     x 1.1845097d-03,-4.7950477d-19,-1.5024575d-06 /
      data fpppp(12,19, 8,1),fpppp(12,19, 8,2),fpppp(12,19, 8,3)/
     x 1.2128501d-02,-1.5305213d-17, 1.6709451d-07 /
      data fpppp(12,19, 9,1),fpppp(12,19, 9,2),fpppp(12,19, 9,3)/
     x 1.2978167d-02, 1.1959751d-17,-1.0692320d-06 /
      data fpppp(12,19,10,1),fpppp(12,19,10,2),fpppp(12,19,10,3)/
     x-1.6279449d-04, 1.8215478d-18, 4.0224541d-07 /
      data fpppp(12,19,11,1),fpppp(12,19,11,2),fpppp(12,19,11,3)/
     x-7.2848421d-05,-1.5216077d-17,-7.7203652d-08 /
      data fpppp(12,19,12,1),fpppp(12,19,12,2),fpppp(12,19,12,3)/
     x-2.8768228d-05,-2.5794630d-18, 2.2209403d-08 /
      data fpppp(12,19,13,1),fpppp(12,19,13,2),fpppp(12,19,13,3)/
     x-2.5465735d-07,-8.7478777d-18,-1.2973732d-08 /
      data fpppp(12,19,14,1),fpppp(12,19,14,2),fpppp(12,19,14,3)/
     x 4.5751289d-06, 8.2902378d-18,-6.0215589d-09 /
      data fpppp(12,19,15,1),fpppp(12,19,15,2),fpppp(12,19,15,3)/
     x 7.4078470d-06, 1.0494375d-17,-8.3082365d-09 /
      data fpppp(12,19,16,1),fpppp(12,19,16,2),fpppp(12,19,16,3)/
     x 5.2690655d-06,-6.8891178d-18,-8.9718376d-09 /
      data fpppp(12,19,17,1),fpppp(12,19,17,2),fpppp(12,19,17,3)/
     x 5.8562981d-06,-3.2616091d-18,-9.1989695d-09 /
      data fpppp(12,19,18,1),fpppp(12,19,18,2),fpppp(12,19,18,3)/
     x 6.3107829d-06,-6.8777715d-18,-1.0422142d-08 /
      data fpppp(12,19,19,1),fpppp(12,19,19,2),fpppp(12,19,19,3)/
     x 1.0385994d-05,-1.3682884d-18,-1.1444913d-08 /
      data fpppp(12,19,20,1),fpppp(12,19,20,2),fpppp(12,19,20,3)/
     x 1.6467211d-05, 2.6226025d-18,-1.2131879d-08 /
      data fpppp(12,19,21,1),fpppp(12,19,21,2),fpppp(12,19,21,3)/
     x 1.6467211d-05,-5.8956602d-18,-1.2165211d-08 /
      data fpppp(12,19,22,1),fpppp(12,19,22,2),fpppp(12,19,22,3)/
     x 1.0385994d-05,-2.5489919d-18,-1.1311587d-08 /
      data fpppp(12,19,23,1),fpppp(12,19,23,2),fpppp(12,19,23,3)/
     x 6.3107829d-06, 4.3466616d-18,-1.0922117d-08 /
      data fpppp(13, 1, 1,1),fpppp(13, 1, 1,2),fpppp(13, 1, 1,3)/
     x 7.0658138d-03, 8.1943676d-18,-2.4611518d-05 /
      data fpppp(13, 1, 2,1),fpppp(13, 1, 2,2),fpppp(13, 1, 2,3)/
     x 7.1417008d-02, 9.1658817d-17,-1.6175821d-05 /
      data fpppp(13, 1, 3,1),fpppp(13, 1, 3,2),fpppp(13, 1, 3,3)/
     x 3.9867426d-03,-5.2377042d-17, 8.1929752d-07 /
      data fpppp(13, 1, 4,1),fpppp(13, 1, 4,2),fpppp(13, 1, 4,3)/
     x 3.9867426d-03, 2.2865727d-17, 2.7117035d-06 /
      data fpppp(13, 1, 5,1),fpppp(13, 1, 5,2),fpppp(13, 1, 5,3)/
     x 7.1417008d-02,-4.4140488d-17,-2.3745445d-05 /
      data fpppp(13, 1, 6,1),fpppp(13, 1, 6,2),fpppp(13, 1, 6,3)/
     x 7.0658138d-03, 2.2340898d-17, 3.7745711d-06 /
      data fpppp(13, 1, 7,1),fpppp(13, 1, 7,2),fpppp(13, 1, 7,3)/
     x 5.8219040d-03, 8.0446488d-17, 1.4310978d-05 /
      data fpppp(13, 1, 8,1),fpppp(13, 1, 8,2),fpppp(13, 1, 8,3)/
     x 2.5756459d-03,-5.4765579d-17,-3.0701004d-07 /
      data fpppp(13, 1, 9,1),fpppp(13, 1, 9,2),fpppp(13, 1, 9,3)/
     x 2.5263864d-03,-2.2023087d-17, 1.9975982d-06 /
      data fpppp(13, 1,10,1),fpppp(13, 1,10,2),fpppp(13, 1,10,3)/
     x 3.1263043d-03,-1.7160558d-17, 1.0801195d-07 /
      data fpppp(13, 1,11,1),fpppp(13, 1,11,2),fpppp(13, 1,11,3)/
     x 1.5369211d-03,-5.0161969d-17, 3.0477079d-07 /
      data fpppp(13, 1,12,1),fpppp(13, 1,12,2),fpppp(13, 1,12,3)/
     x 2.8744957d-03, 1.6005405d-17, 1.6765725d-07 /
      data fpppp(13, 1,13,1),fpppp(13, 1,13,2),fpppp(13, 1,13,3)/
     x 4.3324686d-03,-4.6252300d-17, 3.2058501d-07 /
      data fpppp(13, 1,14,1),fpppp(13, 1,14,2),fpppp(13, 1,14,3)/
     x 3.0550091d-03,-8.2357756d-18, 1.1674071d-07 /
      data fpppp(13, 1,15,1),fpppp(13, 1,15,2),fpppp(13, 1,15,3)/
     x-2.0835357d-02, 8.3095745d-17, 2.0684409d-06 /
      data fpppp(13, 1,16,1),fpppp(13, 1,16,2),fpppp(13, 1,16,3)/
     x 1.2344597d-03, 7.6334613d-17,-4.3623785d-07 /
      data fpppp(13, 1,17,1),fpppp(13, 1,17,2),fpppp(13, 1,17,3)/
     x 4.6896805d-03, 4.9058801d-17, 1.4675088d-05 /
      data fpppp(13, 1,18,1),fpppp(13, 1,18,2),fpppp(13, 1,18,3)/
     x 7.1799426d-03,-3.5444947d-17, 2.2534737d-06 /
      data fpppp(13, 1,19,1),fpppp(13, 1,19,2),fpppp(13, 1,19,3)/
     x 6.3155677d-02,-2.0320563d-17,-2.2321435d-05 /
      data fpppp(13, 1,20,1),fpppp(13, 1,20,2),fpppp(13, 1,20,3)/
     x 3.0461842d-03, 4.4955645d-17, 2.5653773d-06 /
      data fpppp(13, 1,21,1),fpppp(13, 1,21,2),fpppp(13, 1,21,3)/
     x 3.0461842d-03, 4.3454330d-17, 8.4755670d-07 /
      data fpppp(13, 1,22,1),fpppp(13, 1,22,2),fpppp(13, 1,22,3)/
     x 6.3155677d-02,-1.4542486d-17,-1.5450153d-05 /
      data fpppp(13, 1,23,1),fpppp(13, 1,23,2),fpppp(13, 1,23,3)/
     x 7.1799426d-03, 1.2967275d-16,-2.3513836d-05 /
      data fpppp(13, 2, 1,1),fpppp(13, 2, 1,2),fpppp(13, 2, 1,3)/
     x 4.1421710d-03, 9.2851638d-04,-7.6469755d-06 /
      data fpppp(13, 2, 2,1),fpppp(13, 2, 2,2),fpppp(13, 2, 2,3)/
     x 3.8501967d-02, 4.6850569d-04,-5.0819241d-06 /
      data fpppp(13, 2, 3,1),fpppp(13, 2, 3,2),fpppp(13, 2, 3,3)/
     x 2.4492202d-03,-5.0350596d-04, 1.5004261d-07 /
      data fpppp(13, 2, 4,1),fpppp(13, 2, 4,2),fpppp(13, 2, 4,3)/
     x 2.4492202d-03,-5.2752569d-04, 6.1304336d-07 /
      data fpppp(13, 2, 5,1),fpppp(13, 2, 5,2),fpppp(13, 2, 5,3)/
     x 3.8501967d-02, 5.6458460d-04,-6.9339272d-06 /
      data fpppp(13, 2, 6,1),fpppp(13, 2, 6,2),fpppp(13, 2, 6,3)/
     x 4.1421710d-03, 5.6822045d-04,-7.0196424d-07 /
      data fpppp(13, 2, 7,1),fpppp(13, 2, 7,2),fpppp(13, 2, 7,3)/
     x 3.8725182d-03,-7.7765213d-04, 6.3202295d-06 /
      data fpppp(13, 2, 8,1),fpppp(13, 2, 8,2),fpppp(13, 2, 8,3)/
     x 2.3018657d-03, 1.1531667d-03,-3.6209777d-07 /
      data fpppp(13, 2, 9,1),fpppp(13, 2, 9,2),fpppp(13, 2, 9,3)/
     x 2.2172028d-03,-1.5097328d-03, 8.2819013d-07 /
      data fpppp(13, 2,10,1),fpppp(13, 2,10,2),fpppp(13, 2,10,3)/
     x 2.5016065d-03, 1.6858905d-03,-2.0751773d-08 /
      data fpppp(13, 2,11,1),fpppp(13, 2,11,2),fpppp(13, 2,11,3)/
     x 1.7398969d-03,-1.4017882d-03, 7.3203466d-08 /
      data fpppp(13, 2,12,1),fpppp(13, 2,12,2),fpppp(13, 2,12,3)/
     x 2.4148316d-03,-1.3017263d-05, 9.4531911d-09 /
      data fpppp(13, 2,13,1),fpppp(13, 2,13,2),fpppp(13, 2,13,3)/
     x 3.1163953d-03, 1.0128122d-03, 8.0294151d-08 /
      data fpppp(13, 2,14,1),fpppp(13, 2,14,2),fpppp(13, 2,14,3)/
     x 2.4581828d-03,-5.5803925d-04,-1.5365840d-08 /
      data fpppp(13, 2,15,1),fpppp(13, 2,15,2),fpppp(13, 2,15,3)/
     x-7.7744651d-03, 2.0457509d-04, 8.5803167d-07 /
      data fpppp(13, 2,16,1),fpppp(13, 2,16,2),fpppp(13, 2,16,3)/
     x 1.6798536d-03,-2.4056571d-04,-4.0411382d-07 /
      data fpppp(13, 2,17,1),fpppp(13, 2,17,2),fpppp(13, 2,17,3)/
     x 3.1590779d-03,-1.1740147d-04, 6.4706279d-06 /
      data fpppp(13, 2,18,1),fpppp(13, 2,18,2),fpppp(13, 2,18,3)/
     x 4.1963931d-03, 5.1353509d-04,-1.2340763d-06 /
      data fpppp(13, 2,19,1),fpppp(13, 2,19,2),fpppp(13, 2,19,3)/
     x 3.4386366d-02, 5.1787394d-04,-6.3408590d-06 /
      data fpppp(13, 2,20,1),fpppp(13, 2,20,2),fpppp(13, 2,20,3)/
     x 2.0370349d-03,-5.5142941d-04, 4.9277142d-07 /
      data fpppp(13, 2,21,1),fpppp(13, 2,21,2),fpppp(13, 2,21,3)/
     x 2.0370349d-03,-5.2753635d-04, 9.8982957d-08 /
      data fpppp(13, 2,22,1),fpppp(13, 2,22,2),fpppp(13, 2,22,3)/
     x 3.4386366d-02, 4.2230171d-04,-4.7657051d-06 /
      data fpppp(13, 2,23,1),fpppp(13, 2,23,2),fpppp(13, 2,23,3)/
     x 4.1963931d-03, 8.7193096d-04,-7.1409032d-06 /
      data fpppp(13, 3, 1,1),fpppp(13, 3, 1,2),fpppp(13, 3, 1,3)/
     x-5.1736625d-04,-3.5235538d-02,-2.5072530d-06 /
      data fpppp(13, 3, 2,1),fpppp(13, 3, 2,2),fpppp(13, 3, 2,3)/
     x-1.4839700d-01,-2.0680203d-02,-1.0666361d-06 /
      data fpppp(13, 3, 3,1),fpppp(13, 3, 3,2),fpppp(13, 3, 3,3)/
     x 2.8413866d-03, 8.2408018d-03, 1.0517404d-06 /
      data fpppp(13, 3, 4,1),fpppp(13, 3, 4,2),fpppp(13, 3, 4,3)/
     x 2.8413866d-03, 1.2211549d-02, 2.7468950d-06 /
      data fpppp(13, 3, 5,1),fpppp(13, 3, 5,2),fpppp(13, 3, 5,3)/
     x-1.4839700d-01,-3.6563190d-02,-7.8472546d-06 /
      data fpppp(13, 3, 6,1),fpppp(13, 3, 6,2),fpppp(13, 3, 6,3)/
     x-5.1736625d-04, 2.4325665d-02, 2.2920067d-05 /
      data fpppp(13, 3, 7,1),fpppp(13, 3, 7,2),fpppp(13, 3, 7,3)/
     x-2.8832543d-03,-7.3975039d-03,-1.7732531d-05 /
      data fpppp(13, 3, 8,1),fpppp(13, 3, 8,2),fpppp(13, 3, 8,3)/
     x 3.4193803d-03, 3.9480834d-03, 2.2630004d-06 /
      data fpppp(13, 3, 9,1),fpppp(13, 3, 9,2),fpppp(13, 3, 9,3)/
     x 2.4976893d-03,-1.8276346d-03,-2.5136809d-06 /
      data fpppp(13, 3,10,1),fpppp(13, 3,10,2),fpppp(13, 3,10,3)/
     x 3.1530419d-03, 6.6519467d-04,-9.0235309d-08 /
      data fpppp(13, 3,11,1),fpppp(13, 3,11,2),fpppp(13, 3,11,3)/
     x 3.3984909d-03, 4.7279888d-05,-4.4594064d-07 /
      data fpppp(13, 3,12,1),fpppp(13, 3,12,2),fpppp(13, 3,12,3)/
     x 2.4825054d-03,-1.2107728d-03,-2.5973562d-07 /
      data fpppp(13, 3,13,1),fpppp(13, 3,13,2),fpppp(13, 3,13,3)/
     x 2.1689204d-03, 4.7430362d-03,-4.5394323d-07 /
      data fpppp(13, 3,14,1),fpppp(13, 3,14,2),fpppp(13, 3,14,3)/
     x 3.3136134d-03,-1.7517247d-02,-7.8725321d-08 /
      data fpppp(13, 3,15,1),fpppp(13, 3,15,2),fpppp(13, 3,15,3)/
     x 2.8699707d-02, 2.6627164d-02,-2.5453941d-06 /
      data fpppp(13, 3,16,1),fpppp(13, 3,16,2),fpppp(13, 3,16,3)/
     x 4.3147257d-03,-1.4015042d-02, 2.4180471d-06 /
      data fpppp(13, 3,17,1),fpppp(13, 3,17,2),fpppp(13, 3,17,3)/
     x 9.8082206d-04,-1.7810702d-03,-1.7881310d-05 /
      data fpppp(13, 3,18,1),fpppp(13, 3,18,2),fpppp(13, 3,18,3)/
     x-7.8633674d-04, 1.9580199d-02, 2.3646116d-05 /
      data fpppp(13, 3,19,1),fpppp(13, 3,19,2),fpppp(13, 3,19,3)/
     x-1.3232066d-01,-3.1301567d-02,-8.9593569d-06 /
      data fpppp(13, 3,20,1),fpppp(13, 3,20,2),fpppp(13, 3,20,3)/
     x 3.2259451d-03, 1.0531768d-02, 3.0735641d-06 /
      data fpppp(13, 3,21,1),fpppp(13, 3,21,2),fpppp(13, 3,21,3)/
     x 3.2259451d-03, 7.1898068d-03, 1.2592840d-06 /
      data fpppp(13, 3,22,1),fpppp(13, 3,22,2),fpppp(13, 3,22,3)/
     x-1.3232066d-01,-1.7933721d-02,-1.7022362d-06 /
      data fpppp(13, 3,23,1),fpppp(13, 3,23,2),fpppp(13, 3,23,3)/
     x-7.8633674d-04,-3.0549224d-02,-3.5680869d-06 /
      data fpppp(13, 4, 1,1),fpppp(13, 4, 1,2),fpppp(13, 4, 1,3)/
     x 8.9872679d-04, 1.5972641d-01, 4.4019340d-05 /
      data fpppp(13, 4, 2,1),fpppp(13, 4, 2,2),fpppp(13, 4, 2,3)/
     x 2.0364777d-01, 9.3314630d-02, 2.7723783d-05 /
      data fpppp(13, 4, 3,1),fpppp(13, 4, 3,2),fpppp(13, 4, 3,3)/
     x-3.5203577d-03,-3.8572706d-02,-3.5448963d-06 /
      data fpppp(13, 4, 4,1),fpppp(13, 4, 4,2),fpppp(13, 4, 4,3)/
     x-3.5203577d-03,-5.6814032d-02,-9.9330446d-06 /
      data fpppp(13, 4, 5,1),fpppp(13, 4, 5,2),fpppp(13, 4, 5,3)/
     x 2.0364777d-01, 1.6627993d-01, 5.3276376d-05 /
      data fpppp(13, 4, 6,1),fpppp(13, 4, 6,2),fpppp(13, 4, 6,3)/
     x 8.9872679d-04,-1.1389348d-01,-5.1802884d-05 /
      data fpppp(13, 4, 7,1),fpppp(13, 4, 7,2),fpppp(13, 4, 7,3)/
     x 7.1833266d-03, 3.6059798d-02, 1.4431751d-05 /
      data fpppp(13, 4, 8,1),fpppp(13, 4, 8,2),fpppp(13, 4, 8,3)/
     x-3.3263734d-04,-1.2016500d-02,-4.4925521d-06 /
      data fpppp(13, 4, 9,1),fpppp(13, 4, 9,2),fpppp(13, 4, 9,3)/
     x 7.1433032d-04, 3.9669313d-03, 1.7480685d-06 /
      data fpppp(13, 4,10,1),fpppp(13, 4,10,2),fpppp(13, 4,10,3)/
     x-6.6198880d-04,-1.7919171d-03,-3.6719951d-07 /
      data fpppp(13, 4,11,1),fpppp(13, 4,11,2),fpppp(13, 4,11,3)/
     x-3.7578816d-05, 4.4454538d-04, 4.1433998d-08 /
      data fpppp(13, 4,12,1),fpppp(13, 4,12,2),fpppp(13, 4,12,3)/
     x 7.0449641d-04, 1.4366925d-04,-1.4047781d-07 /
      data fpppp(13, 4,13,1),fpppp(13, 4,13,2),fpppp(13, 4,13,3)/
     x 2.8135094d-04, 5.8728323d-04, 4.0632198d-08 /
      data fpppp(13, 4,14,1),fpppp(13, 4,14,2),fpppp(13, 4,14,3)/
     x-9.1385491d-04,-1.7834693d-03,-3.8269955d-07 /
      data fpppp(13, 4,15,1),fpppp(13, 4,15,2),fpppp(13, 4,15,3)/
     x-1.6772601d-02, 2.8914159d-03, 1.7267380d-06 /
      data fpppp(13, 4,16,1),fpppp(13, 4,16,2),fpppp(13, 4,16,3)/
     x-7.1357599d-04,-7.3287207d-03,-4.5249211d-06 /
      data fpppp(13, 4,17,1),fpppp(13, 4,17,2),fpppp(13, 4,17,3)/
     x 1.0693527d-03, 2.6823527d-02, 1.4282923d-05 /
      data fpppp(13, 4,18,1),fpppp(13, 4,18,2),fpppp(13, 4,18,3)/
     x 1.2280644d-03,-9.8686146d-02,-5.0760789d-05 /
      data fpppp(13, 4,19,1),fpppp(13, 4,19,2),fpppp(13, 4,19,3)/
     x 1.8375432d-01, 1.4839429d-01, 5.3518905d-05 /
      data fpppp(13, 4,20,1),fpppp(13, 4,20,2),fpppp(13, 4,20,3)/
     x-3.2783533d-03,-5.0887698d-02,-1.0632538d-05 /
      data fpppp(13, 4,21,1),fpppp(13, 4,21,2),fpppp(13, 4,21,3)/
     x-3.2783533d-03,-3.4744722d-02,-4.2614767d-06 /
      data fpppp(13, 4,22,1),fpppp(13, 4,22,2),fpppp(13, 4,22,3)/
     x 1.8375432d-01, 8.3822384d-02, 2.8034658d-05 /
      data fpppp(13, 4,23,1),fpppp(13, 4,23,2),fpppp(13, 4,23,3)/
     x 1.2280644d-03, 1.4345849d-01, 4.4805137d-05 /
      data fpppp(13, 5, 1,1),fpppp(13, 5, 1,2),fpppp(13, 5, 1,3)/
     x 1.2537604d-03, 3.5659953d-04,-4.1092831d-05 /
      data fpppp(13, 5, 2,1),fpppp(13, 5, 2,2),fpppp(13, 5, 2,3)/
     x-1.1892582d-01, 1.6309074d-04,-2.5387988d-05 /
      data fpppp(13, 5, 3,1),fpppp(13, 5, 3,2),fpppp(13, 5, 3,3)/
     x 3.6641420d-03,-2.5010514d-04, 5.3236527d-06 /
      data fpppp(13, 5, 4,1),fpppp(13, 5, 4,2),fpppp(13, 5, 4,3)/
     x 3.6641420d-03,-2.5267031d-04, 1.0471445d-05 /
      data fpppp(13, 5, 5,1),fpppp(13, 5, 5,2),fpppp(13, 5, 5,3)/
     x-1.1892582d-01, 1.7335142d-04,-4.5979155d-05 /
      data fpppp(13, 5, 6,1),fpppp(13, 5, 6,2),fpppp(13, 5, 6,3)/
     x 1.2537604d-03, 3.1812199d-04, 3.6124047d-05 /
      data fpppp(13, 5, 7,1),fpppp(13, 5, 7,2),fpppp(13, 5, 7,3)/
     x-3.2854185d-03,-8.5857578d-05,-6.1423151d-06 /
      data fpppp(13, 5, 8,1),fpppp(13, 5, 8,2),fpppp(13, 5, 8,3)/
     x 7.1898344d-04, 9.8525528d-06, 2.8059132d-06 /
      data fpppp(13, 5, 9,1),fpppp(13, 5, 9,2),fpppp(13, 5, 9,3)/
     x 2.7608364d-04,-1.9194866d-05,-8.1129327d-07 /
      data fpppp(13, 5,10,1),fpppp(13, 5,10,2),fpppp(13, 5,10,3)/
     x 1.0605072d-03,-5.9775110d-06, 1.0072817d-07 /
      data fpppp(13, 5,11,1),fpppp(13, 5,11,2),fpppp(13, 5,11,3)/
     x 5.9283143d-04,-8.7888379d-06,-9.4754653d-08 /
      data fpppp(13, 5,12,1),fpppp(13, 5,12,2),fpppp(13, 5,12,3)/
     x 1.5519050d-04,-3.2799868d-06, 3.3892385d-09 /
      data fpppp(13, 5,13,1),fpppp(13, 5,13,2),fpppp(13, 5,13,3)/
     x 4.8003529d-04,-8.3014833d-06,-9.0075821d-08 /
      data fpppp(13, 5,14,1),fpppp(13, 5,14,2),fpppp(13, 5,14,3)/
     x 1.2238726d-03, 5.5516661d-08, 1.0894217d-07 /
      data fpppp(13, 5,15,1),fpppp(13, 5,15,2),fpppp(13, 5,15,3)/
     x 4.9431956d-03,-4.0764886d-05,-7.8034230d-07 /
      data fpppp(13, 5,16,1),fpppp(13, 5,16,2),fpppp(13, 5,16,3)/
     x 7.8528425d-04, 1.1636308d-04, 2.7284760d-06 /
      data fpppp(13, 5,17,1),fpppp(13, 5,17,2),fpppp(13, 5,17,3)/
     x 5.8877115d-04,-5.0240328d-04,-6.0079121d-06 /
      data fpppp(13, 5,18,1),fpppp(13, 5,18,2),fpppp(13, 5,18,3)/
     x 1.1663524d-03, 1.8548305d-03, 3.4593603d-05 /
      data fpppp(13, 5,19,1),fpppp(13, 5,19,2),fpppp(13, 5,19,3)/
     x-1.0887157d-01,-2.1211029d-03,-4.5871738d-05 /
      data fpppp(13, 5,20,1),fpppp(13, 5,20,2),fpppp(13, 5,20,3)/
     x 3.0372492d-03, 5.2245127d-04, 1.1344614d-05 /
      data fpppp(13, 5,21,1),fpppp(13, 5,21,2),fpppp(13, 5,21,3)/
     x 3.0372492d-03, 2.7516051d-04, 6.2576063d-06 /
      data fpppp(13, 5,22,1),fpppp(13, 5,22,2),fpppp(13, 5,22,3)/
     x-1.0887157d-01,-1.1319398d-03,-2.5523706d-05 /
      data fpppp(13, 5,23,1),fpppp(13, 5,23,2),fpppp(13, 5,23,3)/
     x 1.1663524d-03,-1.8545309d-03,-4.1711520d-05 /
      data fpppp(13, 6, 1,1),fpppp(13, 6, 1,2),fpppp(13, 6, 1,3)/
     x 4.3767025d-05, 4.7776494d-04, 1.1867697d-05 /
      data fpppp(13, 6, 2,1),fpppp(13, 6, 2,2),fpppp(13, 6, 2,3)/
     x 3.2707539d-02, 2.7269379d-04, 7.2182943d-06 /
      data fpppp(13, 6, 3,1),fpppp(13, 6, 3,2),fpppp(13, 6, 3,3)/
     x-1.4689471d-03,-1.4231305d-04,-1.9327712d-06 /
      data fpppp(13, 6, 4,1),fpppp(13, 6, 4,2),fpppp(13, 6, 4,3)/
     x-1.4689471d-03,-1.8506790d-04,-3.3536667d-06 /
      data fpppp(13, 6, 5,1),fpppp(13, 6, 5,2),fpppp(13, 6, 5,3)/
     x 3.2707539d-02, 4.4371320d-04, 1.2901876d-05 /
      data fpppp(13, 6, 6,1),fpppp(13, 6, 6,2),fpppp(13, 6, 6,3)/
     x 4.3767025d-05,-1.6355786d-04,-9.4457356d-06 /
      data fpppp(13, 6, 7,1),fpppp(13, 6, 7,2),fpppp(13, 6, 7,3)/
     x 1.0662855d-03, 9.5565443d-06, 1.7588849d-06 /
      data fpppp(13, 6, 8,1),fpppp(13, 6, 8,2),fpppp(13, 6, 8,3)/
     x-7.2880483d-05,-2.2718871d-05,-8.2977224d-07 /
      data fpppp(13, 6, 9,1),fpppp(13, 6, 9,2),fpppp(13, 6, 9,3)/
     x 2.3756525d-05,-1.1649329d-06, 1.7865521d-07 /
      data fpppp(13, 6,10,1),fpppp(13, 6,10,2),fpppp(13, 6,10,3)/
     x-1.9172708d-04,-3.8519342d-06,-3.8644175d-08 /
      data fpppp(13, 6,11,1),fpppp(13, 6,11,2),fpppp(13, 6,11,3)/
     x-6.5717591d-05, 2.8018563d-06, 2.8678010d-08 /
      data fpppp(13, 6,12,1),fpppp(13, 6,12,2),fpppp(13, 6,12,3)/
     x 4.9865065d-05, 1.2628342d-06, 6.4782857d-09 /
      data fpppp(13, 6,13,1),fpppp(13, 6,13,2),fpppp(13, 6,13,3)/
     x-4.2596884d-05, 1.8982296d-06, 3.4307963d-08 /
      data fpppp(13, 6,14,1),fpppp(13, 6,14,2),fpppp(13, 6,14,3)/
     x-2.4948668d-04,-1.5677794d-06,-2.4174074d-08 /
      data fpppp(13, 6,15,1),fpppp(13, 6,15,2),fpppp(13, 6,15,3)/
     x-1.2573324d-03,-6.9100412d-07, 1.9893405d-07 /
      data fpppp(13, 6,16,1),fpppp(13, 6,16,2),fpppp(13, 6,16,3)/
     x-1.4007855d-04,-8.4898595d-06,-7.5416937d-07 /
      data fpppp(13, 6,17,1),fpppp(13, 6,17,2),fpppp(13, 6,17,3)/
     x-6.9965663d-05, 1.5139778d-06, 1.7723289d-06 /
      data fpppp(13, 6,18,1),fpppp(13, 6,18,2),fpppp(13, 6,18,3)/
     x-1.6590058d-04,-4.7535347d-05,-8.8706886d-06 /
      data fpppp(13, 6,19,1),fpppp(13, 6,19,2),fpppp(13, 6,19,3)/
     x 3.0708936d-02, 1.8331777d-04, 1.2873793d-05 /
      data fpppp(13, 6,20,1),fpppp(13, 6,20,2),fpppp(13, 6,20,3)/
     x 1.6780987d-04,-9.1210965d-05,-3.8007114d-06 /
      data fpppp(13, 6,21,1),fpppp(13, 6,21,2),fpppp(13, 6,21,3)/
     x 1.6780987d-04,-7.4171414d-05,-2.3991647d-06 /
      data fpppp(13, 6,22,1),fpppp(13, 6,22,2),fpppp(13, 6,22,3)/
     x 3.0708936d-02, 1.1515957d-04, 7.2676066d-06 /
      data fpppp(13, 6,23,1),fpppp(13, 6,23,2),fpppp(13, 6,23,3)/
     x-1.6590058d-04, 2.0805791d-04, 1.2152512d-05 /
      data fpppp(13, 7, 1,1),fpppp(13, 7, 1,2),fpppp(13, 7, 1,3)/
     x-2.9217705d-04, 9.9841854d-05,-2.8374422d-06 /
      data fpppp(13, 7, 2,1),fpppp(13, 7, 2,2),fpppp(13, 7, 2,3)/
     x-8.3948494d-03, 4.4098807d-05,-1.8478580d-06 /
      data fpppp(13, 7, 3,1),fpppp(13, 7, 3,2),fpppp(13, 7, 3,3)/
     x 6.2046816d-03,-7.1928731d-05, 6.1192757d-08 /
      data fpppp(13, 7, 4,1),fpppp(13, 7, 4,2),fpppp(13, 7, 4,3)/
     x 6.2046816d-03,-7.7916966d-05, 4.3129473d-07 /
      data fpppp(13, 7, 5,1),fpppp(13, 7, 5,2),fpppp(13, 7, 5,3)/
     x-8.3948494d-03, 6.8051745d-05,-3.3282659d-06 /
      data fpppp(13, 7, 6,1),fpppp(13, 7, 6,2),fpppp(13, 7, 6,3)/
     x-2.9217705d-04, 1.0018334d-05, 2.7140874d-06 /
      data fpppp(13, 7, 7,1),fpppp(13, 7, 7,2),fpppp(13, 7, 7,3)/
     x-3.3932336d-04, 6.5543713d-06,-3.1127733d-07 /
      data fpppp(13, 7, 8,1),fpppp(13, 7, 8,2),fpppp(13, 7, 8,3)/
     x 3.6138985d-05, 2.5707712d-06, 3.1943429d-07 /
      data fpppp(13, 7, 9,1),fpppp(13, 7, 9,2),fpppp(13, 7, 9,3)/
     x 3.9861257d-05, 8.0070353d-06, 1.7531113d-08 /
      data fpppp(13, 7,10,1),fpppp(13, 7,10,2),fpppp(13, 7,10,3)/
     x 9.6631728d-05, 7.7335094d-06, 5.0075316d-08 /
      data fpppp(13, 7,11,1),fpppp(13, 7,11,2),fpppp(13, 7,11,3)/
     x 6.2795690d-05, 8.6776445d-06, 1.7396797d-08 /
      data fpppp(13, 7,12,1),fpppp(13, 7,12,2),fpppp(13, 7,12,3)/
     x 2.6498036d-05, 5.0712767d-06, 1.8734102d-08 /
      data fpppp(13, 7,13,1),fpppp(13, 7,13,2),fpppp(13, 7,13,3)/
     x 4.6783446d-05, 7.6407245d-06, 1.8543854d-08 /
      data fpppp(13, 7,14,1),fpppp(13, 7,14,2),fpppp(13, 7,14,3)/
     x 9.2950925d-05, 2.5353179d-06, 5.0238106d-08 /
      data fpppp(13, 7,15,1),fpppp(13, 7,15,2),fpppp(13, 7,15,3)/
     x 3.5721512d-04, 1.0693368d-05, 1.2410287d-08 /
      data fpppp(13, 7,16,1),fpppp(13, 7,16,2),fpppp(13, 7,16,3)/
     x 2.9043283d-05, 6.4166382d-06, 2.8262075d-07 /
      data fpppp(13, 7,17,1),fpppp(13, 7,17,2),fpppp(13, 7,17,3)/
     x-3.7347889d-05, 9.6981154d-06,-3.3412464d-07 /
      data fpppp(13, 7,18,1),fpppp(13, 7,18,2),fpppp(13, 7,18,3)/
     x-9.1746610d-05, 1.5167430d-05, 2.5254975d-06 /
      data fpppp(13, 7,19,1),fpppp(13, 7,19,2),fpppp(13, 7,19,3)/
     x-8.4936373d-03, 4.3285282d-05,-2.8641776d-06 /
      data fpppp(13, 7,20,1),fpppp(13, 7,20,2),fpppp(13, 7,20,3)/
     x-3.5195460d-04,-6.5661034d-05, 2.6405303d-07 /
      data fpppp(13, 7,21,1),fpppp(13, 7,21,2),fpppp(13, 7,21,3)/
     x-3.5195460d-04,-6.1912958d-05,-6.1082222d-08 /
      data fpppp(13, 7,22,1),fpppp(13, 7,22,2),fpppp(13, 7,22,3)/
     x-8.4936373d-03, 2.8292978d-05,-1.5636366d-06 /
      data fpppp(13, 7,23,1),fpppp(13, 7,23,2),fpppp(13, 7,23,3)/
     x-9.1746610d-05, 7.1388569d-05,-2.3515313d-06 /
      data fpppp(13, 8, 1,1),fpppp(13, 8, 1,2),fpppp(13, 8, 1,3)/
     x 4.3903727d-04,-6.4091257d-03, 3.3733734d-06 /
      data fpppp(13, 8, 2,1),fpppp(13, 8, 2,2),fpppp(13, 8, 2,3)/
     x-7.3983299d-04,-3.4779410d-03, 1.7708744d-06 /
      data fpppp(13, 8, 3,1),fpppp(13, 8, 3,2),fpppp(13, 8, 3,3)/
     x-4.2688607d-02, 2.5019312d-03,-1.5072886d-06 /
      data fpppp(13, 8, 4,1),fpppp(13, 8, 4,2),fpppp(13, 8, 4,3)/
     x-4.2688607d-02, 3.0290976d-03,-1.7798744d-06 /
      data fpppp(13, 8, 5,1),fpppp(13, 8, 5,2),fpppp(13, 8, 5,3)/
     x-7.3983299d-04,-5.5866067d-03, 2.8612178d-06 /
      data fpppp(13, 8, 6,1),fpppp(13, 8, 6,2),fpppp(13, 8, 6,3)/
     x 4.3903727d-04, 1.4983705d-03,-7.1541406d-07 /
      data fpppp(13, 8, 7,1),fpppp(13, 8, 7,2),fpppp(13, 8, 7,3)/
     x 1.0270475d-04,-4.0474184d-04, 2.7423345d-07 /
      data fpppp(13, 8, 8,1),fpppp(13, 8, 8,2),fpppp(13, 8, 8,3)/
     x-1.5331194d-06, 1.0710546d-04, 1.7238669d-08 /
      data fpppp(13, 8, 9,1),fpppp(13, 8, 9,2),fpppp(13, 8, 9,3)/
     x 7.0009785d-06,-2.9892479d-05, 7.7076921d-08 /
      data fpppp(13, 8,10,1),fpppp(13, 8,10,2),fpppp(13, 8,10,3)/
     x 1.4324187d-05, 2.7221133d-05, 3.7472996d-08 /
      data fpppp(13, 8,11,1),fpppp(13, 8,11,2),fpppp(13, 8,11,3)/
     x 1.9106561d-05, 6.5424227d-06, 3.4317880d-08 /
      data fpppp(13, 8,12,1),fpppp(13, 8,12,2),fpppp(13, 8,12,3)/
     x 2.4240476d-05, 1.3099822d-05, 3.0802904d-08 /
      data fpppp(13, 8,13,1),fpppp(13, 8,13,2),fpppp(13, 8,13,3)/
     x 1.3184906d-05, 6.6119800d-06, 3.1143146d-08 /
      data fpppp(13, 8,14,1),fpppp(13, 8,14,2),fpppp(13, 8,14,3)/
     x-3.5967185d-06, 1.2877644d-05, 2.7657949d-08 /
      data fpppp(13, 8,15,1),fpppp(13, 8,15,2),fpppp(13, 8,15,3)/
     x-9.2066061d-05, 3.6352956d-06, 4.9013078d-08 /
      data fpppp(13, 8,16,1),fpppp(13, 8,16,2),fpppp(13, 8,16,3)/
     x-1.4755610d-05, 9.9889043d-06,-6.7430354d-09 /
      data fpppp(13, 8,17,1),fpppp(13, 8,17,2),fpppp(13, 8,17,3)/
     x-1.1564623d-05, 7.5238653d-06, 1.7041903d-07 /
      data fpppp(13, 8,18,1),fpppp(13, 8,18,2),fpppp(13, 8,18,3)/
     x-9.9550354d-06, 1.0978592d-05,-6.1306926d-07 /
      data fpppp(13, 8,19,1),fpppp(13, 8,19,2),fpppp(13, 8,19,3)/
     x 2.2377954d-03, 8.1225219d-06, 7.8853936d-07 /
      data fpppp(13, 8,20,1),fpppp(13, 8,20,2),fpppp(13, 8,20,3)/
     x 8.0536256d-05,-3.9377972d-05,-3.4366309d-07 /
      data fpppp(13, 8,21,1),fpppp(13, 8,21,2),fpppp(13, 8,21,3)/
     x 8.0536256d-05,-3.8461318d-05,-2.5205060d-07 /
      data fpppp(13, 8,22,1),fpppp(13, 8,22,2),fpppp(13, 8,22,3)/
     x 2.2377954d-03, 4.4559093d-06, 4.2208941d-07 /
      data fpppp(13, 8,23,1),fpppp(13, 8,23,2),fpppp(13, 8,23,3)/
     x-9.9550354d-06, 2.4728390d-05, 7.6111808d-07 /
      data fpppp(13, 9, 1,1),fpppp(13, 9, 1,2),fpppp(13, 9, 1,3)/
     x-1.6722844d-03,-4.0528798d-02,-5.6600061d-06 /
      data fpppp(13, 9, 2,1),fpppp(13, 9, 2,2),fpppp(13, 9, 2,3)/
     x 6.0881894d-03,-2.1811078d-02,-2.9163604d-06 /
      data fpppp(13, 9, 3,1),fpppp(13, 9, 3,2),fpppp(13, 9, 3,3)/
     x 7.8746556d-02, 1.6451366d-02, 2.7557987d-06 /
      data fpppp(13, 9, 4,1),fpppp(13, 9, 4,2),fpppp(13, 9, 4,3)/
     x 7.8746556d-02, 1.9683535d-02, 3.1181917d-06 /
      data fpppp(13, 9, 5,1),fpppp(13, 9, 5,2),fpppp(13, 9, 5,3)/
     x 6.0881894d-03,-3.4739756d-02,-4.3659324d-06 /
      data fpppp(13, 9, 6,1),fpppp(13, 9, 6,2),fpppp(13, 9, 6,3)/
     x-1.6722844d-03, 7.9537427d-03,-2.2411128d-07 /
      data fpppp(13, 9, 7,1),fpppp(13, 9, 7,2),fpppp(13, 9, 7,3)/
     x-1.8161323d-04,-2.1451127d-03,-1.1289549d-09 /
      data fpppp(13, 9, 8,1),fpppp(13, 9, 8,2),fpppp(13, 9, 8,3)/
     x-4.1536628d-05, 5.6131149d-04, 9.4100443d-10 /
      data fpppp(13, 9, 9,1),fpppp(13, 9, 9,2),fpppp(13, 9, 9,3)/
     x-9.4414522d-07,-1.5753902d-04, 1.1793793d-08 /
      data fpppp(13, 9,10,1),fpppp(13, 9,10,2),fpppp(13, 9,10,3)/
     x-1.4245500d-05, 5.0336316d-05, 1.7132367d-08 /
      data fpppp(13, 9,11,1),fpppp(13, 9,11,2),fpppp(13, 9,11,3)/
     x-4.1890626d-06, 2.2319322d-06, 2.0260430d-08 /
      data fpppp(13, 9,12,1),fpppp(13, 9,12,2),fpppp(13, 9,12,3)/
     x-9.3259028d-07, 1.8346465d-05, 1.9079633d-08 /
      data fpppp(13, 9,13,1),fpppp(13, 9,13,2),fpppp(13, 9,13,3)/
     x 1.7433290d-06, 1.0130689d-05, 2.0293408d-08 /
      data fpppp(13, 9,14,1),fpppp(13, 9,14,2),fpppp(13, 9,14,3)/
     x 1.3883271d-06, 7.7589898d-06, 2.2745365d-08 /
      data fpppp(13, 9,15,1),fpppp(13, 9,15,2),fpppp(13, 9,15,3)/
     x 2.4054852d-05, 8.2410640d-06, 1.9386486d-08 /
      data fpppp(13, 9,16,1),fpppp(13, 9,16,2),fpppp(13, 9,16,3)/
     x 1.0469984d-07, 6.4332492d-06, 3.2819778d-08 /
      data fpppp(13, 9,17,1),fpppp(13, 9,17,2),fpppp(13, 9,17,3)/
     x-2.8977247d-06, 8.4479958d-06,-2.0354093d-08 /
      data fpppp(13, 9,18,1),fpppp(13, 9,18,2),fpppp(13, 9,18,3)/
     x-5.3702242d-06, 7.7209336d-06, 1.6732170d-07 /
      data fpppp(13, 9,19,1),fpppp(13, 9,19,2),fpppp(13, 9,19,3)/
     x-6.0658684d-04, 4.4639018d-06,-2.4482577d-07 /
      data fpppp(13, 9,20,1),fpppp(13, 9,20,2),fpppp(13, 9,20,3)/
     x-2.1212012d-05,-2.9915990d-05,-1.5799262d-08 /
      data fpppp(13, 9,21,1),fpppp(13, 9,21,2),fpppp(13, 9,21,3)/
     x-2.1212012d-05,-2.9309016d-05,-4.0436596d-08 /
      data fpppp(13, 9,22,1),fpppp(13, 9,22,2),fpppp(13, 9,22,3)/
     x-6.0658684d-04, 2.0360060d-06,-1.4627643d-07 /
      data fpppp(13, 9,23,1),fpppp(13, 9,23,2),fpppp(13, 9,23,3)/
     x-5.3702242d-06, 1.6825543d-05,-2.0223831d-07 /
      data fpppp(13,10, 1,1),fpppp(13,10, 1,2),fpppp(13,10, 1,3)/
     x 9.4222213d-04,-6.5269552d-03, 5.2952728d-06 /
      data fpppp(13,10, 2,1),fpppp(13,10, 2,2),fpppp(13,10, 2,3)/
     x-8.6354552d-03,-3.8127611d-03, 2.8270536d-06 /
      data fpppp(13,10, 3,1),fpppp(13,10, 3,2),fpppp(13,10, 3,3)/
     x-5.2459971d-02, 1.5282960d-03,-2.2826736d-06 /
      data fpppp(13,10, 4,1),fpppp(13,10, 4,2),fpppp(13,10, 4,3)/
     x-5.2459971d-02, 2.3596738d-03,-2.5964729d-06 /
      data fpppp(13,10, 5,1),fpppp(13,10, 5,2),fpppp(13,10, 5,3)/
     x-8.6354552d-03,-7.1382725d-03, 4.0822506d-06 /
      data fpppp(13,10, 6,1),fpppp(13,10, 6,2),fpppp(13,10, 6,3)/
     x 9.4222213d-04, 5.9437125d-03, 5.8828401d-07 /
      data fpppp(13,10, 7,1),fpppp(13,10, 7,2),fpppp(13,10, 7,3)/
     x-6.2850844d-04,-2.4375371d-03,-6.7471595d-07 /
      data fpppp(13,10, 8,1),fpppp(13,10, 8,2),fpppp(13,10, 8,3)/
     x-2.4455447d-04, 4.7353510d-04,-8.3914276d-08 /
      data fpppp(13,10, 9,1),fpppp(13,10, 9,2),fpppp(13,10, 9,3)/
     x-1.8516101d-04,-1.7492733d-04,-9.0767423d-08 /
      data fpppp(13,10,10,1),fpppp(13,10,10,2),fpppp(13,10,10,3)/
     x-4.5654969d-05, 3.7727328d-05,-1.0709553d-08 /
      data fpppp(13,10,11,1),fpppp(13,10,11,2),fpppp(13,10,11,3)/
     x-2.8094756d-05,-4.9559982d-07,-2.6159092d-09 /
      data fpppp(13,10,12,1),fpppp(13,10,12,2),fpppp(13,10,12,3)/
     x-1.8393161d-05, 1.8278508d-05, 7.9308982d-09 /
      data fpppp(13,10,13,1),fpppp(13,10,13,2),fpppp(13,10,13,3)/
     x-1.4242165d-05, 9.2625408d-06, 8.8102014d-09 /
      data fpppp(13,10,14,1),fpppp(13,10,14,2),fpppp(13,10,14,3)/
     x-9.6602382d-06, 8.0835516d-06, 9.7203423d-09 /
      data fpppp(13,10,15,1),fpppp(13,10,15,2),fpppp(13,10,15,3)/
     x-1.2186314d-05, 8.7512136d-06, 1.0354996d-08 /
      data fpppp(13,10,16,1),fpppp(13,10,16,2),fpppp(13,10,16,3)/
     x-2.4992868d-06, 5.3430382d-06, 4.0480969d-09 /
      data fpppp(13,10,17,1),fpppp(13,10,17,2),fpppp(13,10,17,3)/
     x 1.6480331d-06, 7.7377096d-06, 6.7466309d-09 /
      data fpppp(13,10,18,1),fpppp(13,10,18,2),fpppp(13,10,18,3)/
     x 3.4414678d-06, 6.7199128d-06,-5.5158836d-08 /
      data fpppp(13,10,19,1),fpppp(13,10,19,2),fpppp(13,10,19,3)/
     x 1.6843911d-04, 7.7817242d-06, 4.2179660d-08 /
      data fpppp(13,10,20,1),fpppp(13,10,20,2),fpppp(13,10,20,3)/
     x 1.7131375d-05,-2.5565573d-05,-3.6302397d-08 /
      data fpppp(13,10,21,1),fpppp(13,10,21,2),fpppp(13,10,21,3)/
     x 1.7131375d-05,-2.4776465d-05,-2.9943373d-08 /
      data fpppp(13,10,22,1),fpppp(13,10,22,2),fpppp(13,10,22,3)/
     x 1.6843911d-04, 4.6252906d-06, 1.6743561d-08 /
      data fpppp(13,10,23,1),fpppp(13,10,23,2),fpppp(13,10,23,3)/
     x 3.4414678d-06, 1.8556539d-05, 4.0226536d-08 /
      data fpppp(13,11, 1,1),fpppp(13,11, 1,2),fpppp(13,11, 1,3)/
     x 2.6311400d-04, 7.4754443d-04,-1.7273778d-06 /
      data fpppp(13,11, 2,1),fpppp(13,11, 2,2),fpppp(13,11, 2,3)/
     x 5.7214080d-03, 4.0593043d-04,-1.0621783d-06 /
      data fpppp(13,11, 3,1),fpppp(13,11, 3,2),fpppp(13,11, 3,3)/
     x 1.4484812d-02,-3.3327887d-04, 2.8812602d-07 /
      data fpppp(13,11, 4,1),fpppp(13,11, 4,2),fpppp(13,11, 4,3)/
     x 1.4484812d-02,-3.2071509d-04, 4.1959154d-07 /
      data fpppp(13,11, 5,1),fpppp(13,11, 5,2),fpppp(13,11, 5,3)/
     x 5.7214080d-03, 3.5567532d-04,-1.5880404d-06 /
      data fpppp(13,11, 6,1),fpppp(13,11, 6,2),fpppp(13,11, 6,3)/
     x 2.6311400d-04, 9.3600111d-04, 2.4460501d-07 /
      data fpppp(13,11, 7,1),fpppp(13,11, 7,2),fpppp(13,11, 7,3)/
     x 4.3284154d-04,-3.4616669d-04, 8.3548398d-07 /
      data fpppp(13,11, 8,1),fpppp(13,11, 8,2),fpppp(13,11, 8,3)/
     x-8.3160013d-05,-3.6932503d-04,-4.1358651d-08 /
      data fpppp(13,11, 9,1),fpppp(13,11, 9,2),fpppp(13,11, 9,3)/
     x 2.6558449d-04,-8.8755659d-05, 2.8643656d-08 /
      data fpppp(13,11,10,1),fpppp(13,11,10,2),fpppp(13,11,10,3)/
     x-5.1910072d-05,-3.3720410d-05,-4.9370426d-08 /
      data fpppp(13,11,11,1),fpppp(13,11,11,2),fpppp(13,11,11,3)/
     x-3.2476746d-05, 1.0742638d-06,-6.5945996d-10 /
      data fpppp(13,11,12,1),fpppp(13,11,12,2),fpppp(13,11,12,3)/
     x-2.4114540d-05, 1.0554163d-05,-3.6285032d-11 /
      data fpppp(13,11,13,1),fpppp(13,11,13,2),fpppp(13,11,13,3)/
     x-1.7671412d-05, 1.0020522d-05, 4.0606918d-09 /
      data fpppp(13,11,14,1),fpppp(13,11,14,2),fpppp(13,11,14,3)/
     x-1.2338200d-05, 7.1428752d-06, 2.7467039d-09 /
      data fpppp(13,11,15,1),fpppp(13,11,15,2),fpppp(13,11,15,3)/
     x-5.2233998d-06, 9.0672913d-06, 1.1848711d-09 /
      data fpppp(13,11,16,1),fpppp(13,11,16,2),fpppp(13,11,16,3)/
     x-2.2033577d-06, 4.4353287d-06,-9.9097251d-10 /
      data fpppp(13,11,17,1),fpppp(13,11,17,2),fpppp(13,11,17,3)/
     x 4.6808248d-07, 4.9317864d-06,-5.4685452d-09 /
      data fpppp(13,11,18,1),fpppp(13,11,18,2),fpppp(13,11,18,3)/
     x 6.2511620d-06, 8.1449620d-06, 7.1169142d-09 /
      data fpppp(13,11,19,1),fpppp(13,11,19,2),fpppp(13,11,19,3)/
     x-3.4489266d-05, 1.1040124d-05,-2.1429820d-08 /
      data fpppp(13,11,20,1),fpppp(13,11,20,2),fpppp(13,11,20,3)/
     x 3.3640584d-06,-2.3439874d-05,-9.6663034d-10 /
      data fpppp(13,11,21,1),fpppp(13,11,21,2),fpppp(13,11,21,3)/
     x 3.3640584d-06,-2.2538648d-05,-2.7749953d-09 /
      data fpppp(13,11,22,1),fpppp(13,11,22,2),fpppp(13,11,22,3)/
     x-3.4489266d-05, 7.4352197d-06,-1.4196360d-08 /
      data fpppp(13,11,23,1),fpppp(13,11,23,2),fpppp(13,11,23,3)/
     x 6.2511620d-06, 2.1663352d-05,-2.0008561d-08 /
      data fpppp(13,12, 1,1),fpppp(13,12, 1,2),fpppp(13,12, 1,3)/
     x 4.8414590d-06, 9.5670693d-04, 3.5895054d-07 /
      data fpppp(13,12, 2,1),fpppp(13,12, 2,2),fpppp(13,12, 2,3)/
     x-1.3262627d-03, 4.8933997d-04, 1.5097552d-07 /
      data fpppp(13,12, 3,1),fpppp(13,12, 3,2),fpppp(13,12, 3,3)/
     x-3.5437201d-03,-5.0113979d-04,-2.7684593d-07 /
      data fpppp(13,12, 4,1),fpppp(13,12, 4,2),fpppp(13,12, 4,3)/
     x-3.5437201d-03,-5.2042631d-04,-3.0806473d-07 /
      data fpppp(13,12, 5,1),fpppp(13,12, 5,2),fpppp(13,12, 5,3)/
     x-1.3262627d-03, 5.6648605d-04, 2.7585072d-07 /
      data fpppp(13,12, 6,1),fpppp(13,12, 6,2),fpppp(13,12, 6,3)/
     x 4.8414590d-06, 6.6740914d-04,-1.0933144d-07 /
      data fpppp(13,12, 7,1),fpppp(13,12, 7,2),fpppp(13,12, 7,3)/
     x 2.4189330d-05, 1.2378507d-04,-3.4530091d-08 /
      data fpppp(13,12, 8,1),fpppp(13,12, 8,2),fpppp(13,12, 8,3)/
     x-1.2646633d-05,-3.1004541d-04, 2.9889669d-07 /
      data fpppp(13,12, 9,1),fpppp(13,12, 9,2),fpppp(13,12, 9,3)/
     x-1.3913035d-03,-1.9712140d-04,-7.3688342d-08 /
      data fpppp(13,12,10,1),fpppp(13,12,10,2),fpppp(13,12,10,3)/
     x-3.6770266d-05,-8.0811908d-05, 1.0724801d-07 /
      data fpppp(13,12,11,1),fpppp(13,12,11,2),fpppp(13,12,11,3)/
     x-2.5149572d-05,-1.7390185d-05,-1.6652124d-08 /
      data fpppp(13,12,12,1),fpppp(13,12,12,2),fpppp(13,12,12,3)/
     x-1.6031205d-05, 3.9653978d-06, 7.9809794d-09 /
      data fpppp(13,12,13,1),fpppp(13,12,13,2),fpppp(13,12,13,3)/
     x-1.1535779d-05, 8.4206414d-06, 3.8595431d-10 /
      data fpppp(13,12,14,1),fpppp(13,12,14,2),fpppp(13,12,14,3)/
     x-1.0456175d-05, 7.0735100d-06, 1.0412800d-11 /
      data fpppp(13,12,15,1),fpppp(13,12,15,2),fpppp(13,12,15,3)/
     x-9.0646971d-06, 8.5862081d-06,-2.4436874d-09 /
      data fpppp(13,12,16,1),fpppp(13,12,16,2),fpppp(13,12,16,3)/
     x-7.2302030d-06, 2.1220392d-06,-3.3649514d-09 /
      data fpppp(13,12,17,1),fpppp(13,12,17,2),fpppp(13,12,17,3)/
     x-2.6575793d-06, 4.3493591d-06, 8.3973471d-10 /
      data fpppp(13,12,18,1),fpppp(13,12,18,2),fpppp(13,12,18,3)/
     x-3.1564294d-06, 7.1028058d-06,-7.1681565d-10 /
      data fpppp(13,12,19,1),fpppp(13,12,19,2),fpppp(13,12,19,3)/
     x 5.9897870d-06, 8.6990944d-06, 5.4594156d-09 /
      data fpppp(13,12,20,1),fpppp(13,12,20,2),fpppp(13,12,20,3)/
     x-5.5845765d-06,-1.9100206d-05,-2.9422692d-09 /
      data fpppp(13,12,21,1),fpppp(13,12,21,2),fpppp(13,12,21,3)/
     x-5.5845765d-06,-1.8408625d-05,-2.4629804d-09 /
      data fpppp(13,12,22,1),fpppp(13,12,22,2),fpppp(13,12,22,3)/
     x 5.9897870d-06, 5.9327725d-06, 3.5422604d-09 /
      data fpppp(13,12,23,1),fpppp(13,12,23,2),fpppp(13,12,23,3)/
     x-3.1564294d-06, 1.7476513d-05, 6.4725165d-09 /
      data fpppp(13,13, 1,1),fpppp(13,13, 1,2),fpppp(13,13, 1,3)/
     x 2.0314949d-04, 1.1178568d-03,-7.5325493d-07 /
      data fpppp(13,13, 2,1),fpppp(13,13, 2,2),fpppp(13,13, 2,3)/
     x 3.6451269d-04, 5.3927515d-04,-3.6524263d-07 /
      data fpppp(13,13, 3,1),fpppp(13,13, 3,2),fpppp(13,13, 3,3)/
     x 5.7122636d-04,-6.8204300d-04, 4.5008373d-07 /
      data fpppp(13,13, 4,1),fpppp(13,13, 4,2),fpppp(13,13, 4,3)/
     x 5.7122636d-04,-7.1441756d-04, 4.7830869d-07 /
      data fpppp(13,13, 5,1),fpppp(13,13, 5,2),fpppp(13,13, 5,3)/
     x 3.6451269d-04, 6.6877340d-04,-4.7814247d-07 /
      data fpppp(13,13, 6,1),fpppp(13,13, 6,2),fpppp(13,13, 6,3)/
     x 2.0314949d-04, 6.3223841d-04,-3.2988053d-07 /
      data fpppp(13,13, 7,1),fpppp(13,13, 7,2),fpppp(13,13, 7,3)/
     x 1.8123103d-04, 2.8901626d-04, 1.0615042d-09 /
      data fpppp(13,13, 8,1),fpppp(13,13, 8,2),fpppp(13,13, 8,3)/
     x 2.1488980d-04,-1.2019197d-04,-3.1168733d-07 /
      data fpppp(13,13, 9,1),fpppp(13,13, 9,2),fpppp(13,13, 9,3)/
     x 5.0365343d-03,-2.3761357d-04, 5.6288146d-07 /
      data fpppp(13,13,10,1),fpppp(13,13,10,2),fpppp(13,13,10,3)/
     x-1.6717168d-05,-1.3834651d-04,-2.6652942d-07 /
      data fpppp(13,13,11,1),fpppp(13,13,11,2),fpppp(13,13,11,3)/
     x-1.2271791d-05,-3.8981058d-05, 1.1192739d-07 /
      data fpppp(13,13,12,1),fpppp(13,13,12,2),fpppp(13,13,12,3)/
     x-1.2847615d-05,-5.7761991d-06,-1.2217582d-08 /
      data fpppp(13,13,13,1),fpppp(13,13,13,2),fpppp(13,13,13,3)/
     x-1.1352869d-05, 4.2182419d-06, 8.2158514d-09 /
      data fpppp(13,13,14,1),fpppp(13,13,14,2),fpppp(13,13,14,3)/
     x-8.3206641d-06, 7.3313080d-06,-1.0598475d-09 /
      data fpppp(13,13,15,1),fpppp(13,13,15,2),fpppp(13,13,15,3)/
     x-1.0652251d-05, 7.0642839d-06,-1.7045122d-09 /
      data fpppp(13,13,16,1),fpppp(13,13,16,2),fpppp(13,13,16,3)/
     x-1.1261726d-05, 3.0443687d-06,-1.1801662d-09 /
      data fpppp(13,13,17,1),fpppp(13,13,17,2),fpppp(13,13,17,3)/
     x-1.4173824d-05, 1.6658971d-07, 1.8477745d-09 /
      data fpppp(13,13,18,1),fpppp(13,13,18,2),fpppp(13,13,18,3)/
     x-1.2754533d-05, 4.3835330d-06, 6.6686200d-09 /
      data fpppp(13,13,19,1),fpppp(13,13,19,2),fpppp(13,13,19,3)/
     x-1.4337571d-05, 5.7213037d-06, 3.7009029d-09 /
      data fpppp(13,13,20,1),fpppp(13,13,20,2),fpppp(13,13,20,3)/
     x-1.4680532d-05,-1.3584864d-05,-1.2975468d-09 /
      data fpppp(13,13,21,1),fpppp(13,13,21,2),fpppp(13,13,21,3)/
     x-1.4680532d-05,-1.3093694d-05,-1.3276943d-09 /
      data fpppp(13,13,22,1),fpppp(13,13,22,2),fpppp(13,13,22,3)/
     x-1.4337571d-05, 3.7566235d-06, 3.8214929d-09 /
      data fpppp(13,13,23,1),fpppp(13,13,23,2),fpppp(13,13,23,3)/
     x-1.2754533d-05, 1.1751084d-05, 6.2164076d-09 /
      data fpppp(13,14, 1,1),fpppp(13,14, 1,2),fpppp(13,14, 1,3)/
     x-4.0148175d-04, 8.4434348d-04,-3.1092831d-07 /
      data fpppp(13,14, 2,1),fpppp(13,14, 2,2),fpppp(13,14, 2,3)/
     x-5.5746669d-04, 3.7800286d-04,-1.0548005d-07 /
      data fpppp(13,14, 3,1),fpppp(13,14, 3,2),fpppp(13,14, 3,3)/
     x-1.0342399d-03,-6.0919264d-04, 3.2928872d-07 /
      data fpppp(13,14, 4,1),fpppp(13,14, 4,2),fpppp(13,14, 4,3)/
     x-1.0342399d-03,-6.3037783d-04, 3.3887435d-07 /
      data fpppp(13,14, 5,1),fpppp(13,14, 5,2),fpppp(13,14, 5,3)/
     x-5.5746669d-04, 4.6274360d-04,-1.4382257d-07 /
      data fpppp(13,14, 6,1),fpppp(13,14, 6,2),fpppp(13,14, 6,3)/
     x-4.0148175d-04, 5.2656572d-04,-1.6714383d-07 /
      data fpppp(13,14, 7,1),fpppp(13,14, 7,2),fpppp(13,14, 7,3)/
     x-1.9704377d-04, 3.3904819d-04,-6.1474463d-07 /
      data fpppp(13,14, 8,1),fpppp(13,14, 8,2),fpppp(13,14, 8,3)/
     x-6.6670592d-04, 9.2985388d-05, 1.1837648d-06 /
      data fpppp(13,14, 9,1),fpppp(13,14, 9,2),fpppp(13,14, 9,3)/
     x-1.8886105d-02,-1.9581752d-04,-1.8313376d-06 /
      data fpppp(13,14,10,1),fpppp(13,14,10,2),fpppp(13,14,10,3)/
     x-5.3088699d-06,-2.1455552d-04, 1.2402777d-06 /
      data fpppp(13,14,11,1),fpppp(13,14,11,2),fpppp(13,14,11,3)/
     x-5.7072127d-06,-6.1482596d-05,-2.7814969d-07 /
      data fpppp(13,14,12,1),fpppp(13,14,12,2),fpppp(13,14,12,3)/
     x-5.3579465d-06,-1.5040247d-05, 1.0221026d-07 /
      data fpppp(13,14,13,1),fpppp(13,14,13,2),fpppp(13,14,13,3)/
     x-6.2067278d-06, 1.4776034d-06,-1.5640765d-08 /
      data fpppp(13,14,14,1),fpppp(13,14,14,2),fpppp(13,14,14,3)/
     x-8.6606312d-06, 2.3934066d-06, 7.4736867d-09 /
      data fpppp(13,14,15,1),fpppp(13,14,15,2),fpppp(13,14,15,3)/
     x-6.7079986d-06, 8.1266384d-06,-8.5695380d-11 /
      data fpppp(13,14,16,1),fpppp(13,14,16,2),fpppp(13,14,16,3)/
     x-9.9324326d-06, 9.7967935d-07, 1.9106334d-09 /
      data fpppp(13,14,17,1),fpppp(13,14,17,2),fpppp(13,14,17,3)/
     x-1.2029699d-05, 2.4207956d-09, 2.4165294d-09 /
      data fpppp(13,14,18,1),fpppp(13,14,18,2),fpppp(13,14,18,3)/
     x-1.3551427d-05, 1.4064986d-06, 1.7078693d-09 /
      data fpppp(13,14,19,1),fpppp(13,14,19,2),fpppp(13,14,19,3)/
     x-1.2929466d-05,-4.6459987d-07, 3.5074761d-09 /
      data fpppp(13,14,20,1),fpppp(13,14,20,2),fpppp(13,14,20,3)/
     x-8.1540857d-06,-6.5861625d-06, 1.6649087d-09 /
      data fpppp(13,14,21,1),fpppp(13,14,21,2),fpppp(13,14,21,3)/
     x-8.1540857d-06,-6.5393762d-06, 1.7911494d-09 /
      data fpppp(13,14,22,1),fpppp(13,14,22,2),fpppp(13,14,22,3)/
     x-1.2929466d-05,-6.5174496d-07, 3.0025132d-09 /
      data fpppp(13,14,23,1),fpppp(13,14,23,2),fpppp(13,14,23,3)/
     x-1.3551427d-05, 2.1082926d-06, 3.6014804d-09 /
      data fpppp(13,15, 1,1),fpppp(13,15, 1,2),fpppp(13,15, 1,3)/
     x 1.3652257d-03, 2.8684808d-04, 2.2679724d-07 /
      data fpppp(13,15, 2,1),fpppp(13,15, 2,2),fpppp(13,15, 2,3)/
     x 6.8497147d-04, 9.6199666d-05, 8.9524657d-08 /
      data fpppp(13,15, 3,1),fpppp(13,15, 3,2),fpppp(13,15, 3,3)/
     x 6.9922181d-04,-3.1353465d-04,-1.7939504d-07 /
      data fpppp(13,15, 4,1),fpppp(13,15, 4,2),fpppp(13,15, 4,3)/
     x 6.9922181d-04,-3.1143116d-04,-2.2355774d-07 /
      data fpppp(13,15, 5,1),fpppp(13,15, 5,2),fpppp(13,15, 5,3)/
     x 6.8497147d-04, 8.7785715d-05, 2.6617545d-07 /
      data fpppp(13,15, 6,1),fpppp(13,15, 6,2),fpppp(13,15, 6,3)/
     x 1.3652257d-03, 3.1840040d-04,-4.3564323d-07 /
      data fpppp(13,15, 7,1),fpppp(13,15, 7,2),fpppp(13,15, 7,3)/
     x 1.0374537d-03, 2.9320942d-04, 1.5108507d-06 /
      data fpppp(13,15, 8,1),fpppp(13,15, 8,2),fpppp(13,15, 8,3)/
     x 2.7671988d-03, 2.0883203d-04,-4.6265676d-06 /
      data fpppp(13,15, 9,1),fpppp(13,15, 9,2),fpppp(13,15, 9,3)/
     x 7.0402180d-02, 2.5444405d-05, 6.9192380d-06 /
      data fpppp(13,15,10,1),fpppp(13,15,10,2),fpppp(13,15,10,3)/
     x 4.4304615d-05,-3.7826542d-04,-4.3228624d-06 /
      data fpppp(13,15,11,1),fpppp(13,15,11,2),fpppp(13,15,11,3)/
     x 1.1130399d-05,-5.5828127d-05, 1.2157057d-06 /
      data fpppp(13,15,12,1),fpppp(13,15,12,2),fpppp(13,15,12,3)/
     x-2.1715171d-07,-2.9631540d-05,-2.9827979d-07 /
      data fpppp(13,15,13,1),fpppp(13,15,13,2),fpppp(13,15,13,3)/
     x-2.3097778d-06,-1.5767580d-06, 9.3218237d-08 /
      data fpppp(13,15,14,1),fpppp(13,15,14,2),fpppp(13,15,14,3)/
     x-2.1187590d-06, 1.4382570d-06,-1.7702673d-08 /
      data fpppp(13,15,15,1),fpppp(13,15,15,2),fpppp(13,15,15,3)/
     x-4.2785956d-06, 3.4832050d-06, 9.3673630d-09 /
      data fpppp(13,15,16,1),fpppp(13,15,16,2),fpppp(13,15,16,3)/
     x-4.4075907d-06, 8.0007727d-07, 2.4451295d-09 /
      data fpppp(13,15,17,1),fpppp(13,15,17,2),fpppp(13,15,17,3)/
     x-4.2580215d-06, 4.8830171d-07, 3.1360509d-09 /
      data fpppp(13,15,18,1),fpppp(13,15,18,2),fpppp(13,15,18,3)/
     x-4.9911328d-06,-3.0496086d-07, 2.1526334d-09 /
      data fpppp(13,15,19,1),fpppp(13,15,19,2),fpppp(13,15,19,3)/
     x-1.4278190d-06,-2.4939996d-06, 1.4883276d-09 /
      data fpppp(13,15,20,1),fpppp(13,15,20,2),fpppp(13,15,20,3)/
     x-8.3869919d-07,-2.5994897d-06,-1.4113586d-09 /
      data fpppp(13,15,21,1),fpppp(13,15,21,2),fpppp(13,15,21,3)/
     x-8.3869919d-07,-2.7010630d-06,-1.3786585d-09 /
      data fpppp(13,15,22,1),fpppp(13,15,22,2),fpppp(13,15,22,3)/
     x-1.4278190d-06,-2.0877066d-06, 1.3575274d-09 /
      data fpppp(13,15,23,1),fpppp(13,15,23,2),fpppp(13,15,23,3)/
     x-4.9911328d-06,-1.8285597d-06, 2.6431341d-09 /
      data fpppp(13,16, 1,1),fpppp(13,16, 1,2),fpppp(13,16, 1,3)/
     x-3.3963923d-03, 2.9029545d-04, 2.1616516d-07 /
      data fpppp(13,16, 2,1),fpppp(13,16, 2,2),fpppp(13,16, 2,3)/
     x-2.0362150d-03, 1.7819517d-04, 1.0534980d-07 /
      data fpppp(13,16, 3,1),fpppp(13,16, 3,2),fpppp(13,16, 3,3)/
     x-1.2367349d-03,-1.3748152d-04,-1.6616788d-07 /
      data fpppp(13,16, 4,1),fpppp(13,16, 4,2),fpppp(13,16, 4,3)/
     x-1.2367349d-03,-5.4233850d-06,-1.0656955d-07 /
      data fpppp(13,16, 5,1),fpppp(13,16, 5,2),fpppp(13,16, 5,3)/
     x-2.0362150d-03,-3.5003738d-04,-1.3304352d-07 /
      data fpppp(13,16, 6,1),fpppp(13,16, 6,2),fpppp(13,16, 6,3)/
     x-3.3963923d-03, 2.2711675d-03, 1.1101401d-06 /
      data fpppp(13,16, 7,1),fpppp(13,16, 7,2),fpppp(13,16, 7,3)/
     x-7.7056613d-03,-1.5266237d-02,-3.2280673d-06 /
      data fpppp(13,16, 8,1),fpppp(13,16, 8,2),fpppp(13,16, 8,3)/
     x-1.0550298d-02, 6.9238779d-02, 7.4149588d-06 /
      data fpppp(13,16, 9,1),fpppp(13,16, 9,2),fpppp(13,16, 9,3)/
     x-1.1018721d-01,-1.1081716d-01,-1.0466738d-05 /
      data fpppp(13,16,10,1),fpppp(13,16,10,2),fpppp(13,16,10,3)/
     x 1.6544346d-04, 6.9917722d-02, 6.9278931d-06 /
      data fpppp(13,16,11,1),fpppp(13,16,11,2),fpppp(13,16,11,3)/
     x 4.0792801d-05,-1.8884798d-02,-1.8570740d-06 /
      data fpppp(13,16,12,1),fpppp(13,16,12,2),fpppp(13,16,12,3)/
     x 1.0200136d-05, 5.0166903d-03, 5.0043190d-07 /
      data fpppp(13,16,13,1),fpppp(13,16,13,2),fpppp(13,16,13,3)/
     x 7.4494849d-07,-1.3566999d-03,-1.2748312d-07 /
      data fpppp(13,16,14,1),fpppp(13,16,14,2),fpppp(13,16,14,3)/
     x-2.0904055d-06, 3.6199425d-04, 4.1177758d-08 /
      data fpppp(13,16,15,1),fpppp(13,16,15,2),fpppp(13,16,15,3)/
     x-1.8805346d-06,-9.7087702d-05,-4.2558284d-09 /
      data fpppp(13,16,16,1),fpppp(13,16,16,2),fpppp(13,16,16,3)/
     x-2.6920866d-07, 2.7166983d-05, 6.4763838d-09 /
      data fpppp(13,16,17,1),fpppp(13,16,17,2),fpppp(13,16,17,3)/
     x 9.0763207d-07,-7.4774369d-06, 2.0011979d-09 /
      data fpppp(13,16,18,1),fpppp(13,16,18,2),fpppp(13,16,18,3)/
     x 2.9275856d-06, 3.1314783d-06, 5.0633874d-10 /
      data fpppp(13,16,19,1),fpppp(13,16,19,2),fpppp(13,16,19,3)/
     x-2.1034150d-06,-4.3849381d-06,-3.1216839d-09 /
      data fpppp(13,16,20,1),fpppp(13,16,20,2),fpppp(13,16,20,3)/
     x 4.6117688d-06,-3.1173299d-07,-2.6806258d-09 /
      data fpppp(13,16,21,1),fpppp(13,16,21,2),fpppp(13,16,21,3)/
     x 4.6117688d-06,-7.5875413d-07,-2.8626123d-09 /
      data fpppp(13,16,22,1),fpppp(13,16,22,2),fpppp(13,16,22,3)/
     x-2.1034150d-06,-2.5968535d-06,-2.3937378d-09 /
      data fpppp(13,16,23,1),fpppp(13,16,23,2),fpppp(13,16,23,3)/
     x 2.9275856d-06,-3.5738388d-06,-2.2234594d-09 /
      data fpppp(13,17, 1,1),fpppp(13,17, 1,2),fpppp(13,17, 1,3)/
     x 4.2904418d-03, 2.9344157d-04,-1.3251236d-07 /
      data fpppp(13,17, 2,1),fpppp(13,17, 2,2),fpppp(13,17, 2,3)/
     x 4.7321394d-03, 4.4044050d-05,-1.7893494d-07 /
      data fpppp(13,17, 3,1),fpppp(13,17, 3,2),fpppp(13,17, 3,3)/
     x 5.5398219d-03,-2.7884021d-04,-2.4763464d-07 /
      data fpppp(13,17, 4,1),fpppp(13,17, 4,2),fpppp(13,17, 4,3)/
     x 5.5398219d-03,-6.4903346d-04,-3.0149484d-07 /
      data fpppp(13,17, 5,1),fpppp(13,17, 5,2),fpppp(13,17, 5,3)/
     x 4.7321394d-03, 1.5248170d-03, 3.6505884d-08 /
      data fpppp(13,17, 6,1),fpppp(13,17, 6,2),fpppp(13,17, 6,3)/
     x 4.2904418d-03,-5.2594571d-03,-9.4041544d-07 /
      data fpppp(13,17, 7,1),fpppp(13,17, 7,2),fpppp(13,17, 7,3)/
     x 1.5568962d-02, 3.7110301d-03, 3.4315440d-06 /
      data fpppp(13,17, 8,1),fpppp(13,17, 8,2),fpppp(13,17, 8,3)/
     x 1.7735803d-02, 8.4096271d-03,-4.6422710d-06 /
      data fpppp(13,17, 9,1),fpppp(13,17, 9,2),fpppp(13,17, 9,3)/
     x 6.8779224d-02,-9.1473739d-03, 6.2031226d-06 /
      data fpppp(13,17,10,1),fpppp(13,17,10,2),fpppp(13,17,10,3)/
     x-3.2215087d-05, 2.1338295d-03,-4.4420200d-06 /
      data fpppp(13,17,11,1),fpppp(13,17,11,2),fpppp(13,17,11,3)/
     x 1.8252296d-05,-6.2925008d-04, 1.0830619d-06 /
      data fpppp(13,17,12,1),fpppp(13,17,12,2),fpppp(13,17,12,3)/
     x 1.4649537d-05, 1.4880777d-04,-3.3794382d-07 /
      data fpppp(13,17,13,1),fpppp(13,17,13,2),fpppp(13,17,13,3)/
     x 8.7562413d-06,-4.8009610d-05, 7.0906735d-08 /
      data fpppp(13,17,14,1),fpppp(13,17,14,2),fpppp(13,17,14,3)/
     x 3.8870979d-06, 1.1288293d-05,-2.4882361d-08 /
      data fpppp(13,17,15,1),fpppp(13,17,15,2),fpppp(13,17,15,3)/
     x 1.0139868d-06,-4.5981196d-06, 6.7994559d-09 /
      data fpppp(13,17,16,1),fpppp(13,17,16,2),fpppp(13,17,16,3)/
     x-6.7962021d-07, 1.3700437d-06, 1.8931440d-10 /
      data fpppp(13,17,17,1),fpppp(13,17,17,2),fpppp(13,17,17,3)/
     x-2.1126550d-07, 8.5430274d-07, 8.3573514d-10 /
      data fpppp(13,17,18,1),fpppp(13,17,18,2),fpppp(13,17,18,3)/
     x-3.6456958d-07,-4.5900382d-06,-2.1442780d-09 /
      data fpppp(13,17,19,1),fpppp(13,17,19,2),fpppp(13,17,19,3)/
     x 6.7445066d-06, 5.4134570d-06,-2.2730108d-09 /
      data fpppp(13,17,20,1),fpppp(13,17,20,2),fpppp(13,17,20,3)/
     x 9.1747317d-07,-2.5489207d-06,-4.4941725d-09 /
      data fpppp(13,17,21,1),fpppp(13,17,21,2),fpppp(13,17,21,3)/
     x 9.1747317d-07,-1.8976895d-06,-4.4510802d-09 /
      data fpppp(13,17,22,1),fpppp(13,17,22,2),fpppp(13,17,22,3)/
     x 6.7445066d-06, 2.8085321d-06,-2.4453797d-09 /
      data fpppp(13,17,23,1),fpppp(13,17,23,2),fpppp(13,17,23,3)/
     x-3.6456958d-07, 5.1784304d-06,-1.4978948d-09 /
      data fpppp(13,18, 1,1),fpppp(13,18, 1,2),fpppp(13,18, 1,3)/
     x-1.0747172d-03, 6.2872922d-04, 1.6579676d-07 /
      data fpppp(13,18, 2,1),fpppp(13,18, 2,2),fpppp(13,18, 2,3)/
     x-2.9858053d-03, 1.5538606d-04, 1.9850496d-07 /
      data fpppp(13,18, 3,1),fpppp(13,18, 3,2),fpppp(13,18, 3,3)/
     x-5.0287218d-03,-9.6289887d-04, 2.6097392d-07 /
      data fpppp(13,18, 4,1),fpppp(13,18, 4,2),fpppp(13,18, 4,3)/
     x-5.0287218d-03,-7.8093708d-04, 2.7430898d-07 /
      data fpppp(13,18, 5,1),fpppp(13,18, 5,2),fpppp(13,18, 5,3)/
     x-2.9858053d-03,-5.7246107d-04, 1.4516469d-07 /
      data fpppp(13,18, 6,1),fpppp(13,18, 6,2),fpppp(13,18, 6,3)/
     x-1.0747172d-03, 3.3581560d-03, 3.6582276d-07 /
      data fpppp(13,18, 7,1),fpppp(13,18, 7,2),fpppp(13,18, 7,3)/
     x-7.0789036d-03,-1.9160162d-03,-1.1037781d-06 /
      data fpppp(13,18, 8,1),fpppp(13,18, 8,2),fpppp(13,18, 8,3)/
     x-7.5742938d-03, 3.7620640d-04, 7.7234106d-07 /
      data fpppp(13,18, 9,1),fpppp(13,18, 9,2),fpppp(13,18, 9,3)/
     x-1.2720218d-02, 7.3071780d-06,-1.1442669d-06 /
      data fpppp(13,18,10,1),fpppp(13,18,10,2),fpppp(13,18,10,3)/
     x-7.3293751d-05,-2.2407585d-05, 7.7354976d-07 /
      data fpppp(13,18,11,1),fpppp(13,18,11,2),fpppp(13,18,11,3)/
     x-2.5522183d-05, 1.9458088d-06,-2.1123052d-07 /
      data fpppp(13,18,12,1),fpppp(13,18,12,2),fpppp(13,18,12,3)/
     x-4.2282086d-06, 1.9785500d-06, 5.0688394d-08 /
      data fpppp(13,18,13,1),fpppp(13,18,13,2),fpppp(13,18,13,3)/
     x 1.5114263d-06,-2.7592701d-06,-1.8826865d-08 /
      data fpppp(13,18,14,1),fpppp(13,18,14,2),fpppp(13,18,14,3)/
     x 4.5898399d-06, 1.3439069d-06, 8.5884988d-10 /
      data fpppp(13,18,15,1),fpppp(13,18,15,2),fpppp(13,18,15,3)/
     x 6.1662710d-06,-2.1875194d-06,-4.0876048d-09 /
      data fpppp(13,18,16,1),fpppp(13,18,16,2),fpppp(13,18,16,3)/
     x 8.5607611d-06, 2.0649953d-06,-3.1983669d-09 /
      data fpppp(13,18,17,1),fpppp(13,18,17,2),fpppp(13,18,17,3)/
     x 9.0380608d-06,-4.0636835d-07,-4.6996272d-09 /
      data fpppp(13,18,18,1),fpppp(13,18,18,2),fpppp(13,18,18,3)/
     x 1.0042817d-05,-1.5498693d-06,-5.7425462d-09 /
      data fpppp(13,18,19,1),fpppp(13,18,19,2),fpppp(13,18,19,3)/
     x 9.4197654d-06, 2.1282811d-06,-7.6975057d-09 /
      data fpppp(13,18,20,1),fpppp(13,18,20,2),fpppp(13,18,20,3)/
     x 1.1098937d-05,-9.0954119d-07,-7.9244329d-09 /
      data fpppp(13,18,21,1),fpppp(13,18,21,2),fpppp(13,18,21,3)/
     x 1.1098937d-05,-6.6765191d-07,-8.0122047d-09 /
      data fpppp(13,18,22,1),fpppp(13,18,22,2),fpppp(13,18,22,3)/
     x 9.4197654d-06, 1.1607240d-06,-7.3464183d-09 /
      data fpppp(13,18,23,1),fpppp(13,18,23,2),fpppp(13,18,23,3)/
     x 1.0042817d-05, 2.0784699d-06,-7.0591238d-09 /
      data fpppp(13,19, 1,1),fpppp(13,19, 1,2),fpppp(13,19, 1,3)/
     x-2.7107354d-03,-1.6625454d-17, 2.7925255d-07 /
      data fpppp(13,19, 2,1),fpppp(13,19, 2,2),fpppp(13,19, 2,3)/
     x-6.5648074d-03, 1.8014381d-17, 3.8688067d-07 /
      data fpppp(13,19, 3,1),fpppp(13,19, 3,2),fpppp(13,19, 3,3)/
     x-1.0641522d-02,-3.4045620d-18, 6.0098952d-07 /
      data fpppp(13,19, 4,1),fpppp(13,19, 4,2),fpppp(13,19, 4,3)/
     x-1.0641522d-02,-4.3019078d-18, 6.2990449d-07 /
      data fpppp(13,19, 5,1),fpppp(13,19, 5,2),fpppp(13,19, 5,3)/
     x-6.5648074d-03, 1.1812749d-17, 2.7122081d-07 /
      data fpppp(13,19, 6,1),fpppp(13,19, 6,2),fpppp(13,19, 6,3)/
     x-2.7107354d-03, 1.0671623d-17, 7.1297703d-07 /
      data fpppp(13,19, 7,1),fpppp(13,19, 7,2),fpppp(13,19, 7,3)/
     x-1.6606058d-02, 5.7380727d-19,-2.4405478d-06 /
      data fpppp(13,19, 8,1),fpppp(13,19, 8,2),fpppp(13,19, 8,3)/
     x-1.7571191d-02, 1.1633746d-17, 1.1949983d-06 /
      data fpppp(13,19, 9,1),fpppp(13,19, 9,2),fpppp(13,19, 9,3)/
     x-1.9800837d-02,-4.4457975d-18,-1.6295850d-06 /
      data fpppp(13,19,10,1),fpppp(13,19,10,2),fpppp(13,19,10,3)/
     x-1.5910952d-04, 3.0439929d-19, 1.2504101d-06 /
      data fpppp(13,19,11,1),fpppp(13,19,11,2),fpppp(13,19,11,3)/
     x-6.3229812d-05, 1.4383086d-17,-2.9568627d-07 /
      data fpppp(13,19,12,1),fpppp(13,19,12,2),fpppp(13,19,12,3)/
     x-1.6441055d-05, 2.9919041d-18, 8.8746912d-08 /
      data fpppp(13,19,13,1),fpppp(13,19,13,2),fpppp(13,19,13,3)/
     x-1.3745007d-06, 6.6015110d-18,-2.6239478d-08 /
      data fpppp(13,19,14,1),fpppp(13,19,14,2),fpppp(13,19,14,3)/
     x 6.7996566d-06,-6.3893891d-18, 3.7110941d-10 /
      data fpppp(13,19,15,1),fpppp(13,19,15,2),fpppp(13,19,15,3)/
     x 1.0673480d-05,-6.0344276d-19,-8.7054241d-09 /
      data fpppp(13,19,16,1),fpppp(13,19,16,2),fpppp(13,19,16,3)/
     x 1.5043773d-05, 7.1088916d-18,-7.4144448d-09 /
      data fpppp(13,19,17,1),fpppp(13,19,17,2),fpppp(13,19,17,3)/
     x 1.5325037d-05, 5.7915431d-18,-8.9864468d-09 /
      data fpppp(13,19,18,1),fpppp(13,19,18,2),fpppp(13,19,18,3)/
     x 1.6536048d-05, 1.8265769d-18,-9.0700569d-09 /
      data fpppp(13,19,19,1),fpppp(13,19,19,2),fpppp(13,19,19,3)/
     x 1.3858642d-05, 5.8363868d-18,-1.1329667d-08 /
      data fpppp(13,19,20,1),fpppp(13,19,20,2),fpppp(13,19,20,3)/
     x 1.7315897d-05,-4.6801490d-18,-1.0892775d-08 /
      data fpppp(13,19,21,1),fpppp(13,19,21,2),fpppp(13,19,21,3)/
     x 1.7315897d-05, 4.0242386d-18,-1.1009713d-08 /
      data fpppp(13,19,22,1),fpppp(13,19,22,2),fpppp(13,19,22,3)/
     x 1.3858642d-05,-3.9188228d-18,-1.0861915d-08 /
      data fpppp(13,19,23,1),fpppp(13,19,23,2),fpppp(13,19,23,3)/
     x 1.6536048d-05,-2.4171671d-18,-1.0824126d-08 /
      data fpppp(14, 1, 1,1),fpppp(14, 1, 1,2),fpppp(14, 1, 1,3)/
     x-1.8136706d-02,-4.2469191d-17,-4.1532218d-05 /
      data fpppp(14, 1, 2,1),fpppp(14, 1, 2,2),fpppp(14, 1, 2,3)/
     x-1.9082957d-01,-5.4440635d-17,-2.6412865d-05 /
      data fpppp(14, 1, 3,1),fpppp(14, 1, 3,2),fpppp(14, 1, 3,3)/
     x-3.0907808d-02, 2.7152868d-17, 3.4462010d-06 /
      data fpppp(14, 1, 4,1),fpppp(14, 1, 4,2),fpppp(14, 1, 4,3)/
     x-3.0907808d-02,-1.8893621d-17, 7.8904094d-06 /
      data fpppp(14, 1, 5,1),fpppp(14, 1, 5,2),fpppp(14, 1, 5,3)/
     x-1.9082957d-01, 4.1871919d-17,-4.4189699d-05 /
      data fpppp(14, 1, 6,1),fpppp(14, 1, 6,2),fpppp(14, 1, 6,3)/
     x-1.8136706d-02, 2.9840507d-18, 2.5130908d-05 /
      data fpppp(14, 1, 7,1),fpppp(14, 1, 7,2),fpppp(14, 1, 7,3)/
     x-2.4171989d-02,-5.3669535d-17, 5.4993474d-06 /
      data fpppp(14, 1, 8,1),fpppp(14, 1, 8,2),fpppp(14, 1, 8,3)/
     x-2.1831872d-02, 2.3459270d-18, 1.2803291d-06 /
      data fpppp(14, 1, 9,1),fpppp(14, 1, 9,2),fpppp(14, 1, 9,3)/
     x-2.1643610d-02, 2.6145889d-17, 1.2285945d-06 /
      data fpppp(14, 1,10,1),fpppp(14, 1,10,2),fpppp(14, 1,10,3)/
     x-2.1677845d-02, 4.7681354d-17, 2.6558273d-07 /
      data fpppp(14, 1,11,1),fpppp(14, 1,11,2),fpppp(14, 1,11,3)/
     x-1.4451290d-02, 4.8866379d-17, 2.8489820d-07 /
      data fpppp(14, 1,12,1),fpppp(14, 1,12,2),fpppp(14, 1,12,3)/
     x-1.6128006d-02, 2.1040696d-17, 2.1966046d-07 /
      data fpppp(14, 1,13,1),fpppp(14, 1,13,2),fpppp(14, 1,13,3)/
     x-2.3190885d-02,-3.9195926d-18, 2.9327801d-07 /
      data fpppp(14, 1,14,1),fpppp(14, 1,14,2),fpppp(14, 1,14,3)/
     x-2.1648087d-02, 4.0787962d-17, 2.9818035d-07 /
      data fpppp(14, 1,15,1),fpppp(14, 1,15,2),fpppp(14, 1,15,3)/
     x-1.5260692d-02,-4.3911818d-17, 1.1928465d-06 /
      data fpppp(14, 1,16,1),fpppp(14, 1,16,2),fpppp(14, 1,16,3)/
     x-1.9964083d-02,-1.2280225d-16, 1.3290057d-06 /
      data fpppp(14, 1,17,1),fpppp(14, 1,17,2),fpppp(14, 1,17,3)/
     x-2.1345810d-02,-9.1389812d-17, 5.8447940d-06 /
      data fpppp(14, 1,18,1),fpppp(14, 1,18,2),fpppp(14, 1,18,3)/
     x-1.8321194d-02,-1.5476416d-17, 2.3281429d-05 /
      data fpppp(14, 1,19,1),fpppp(14, 1,19,2),fpppp(14, 1,19,3)/
     x-1.7000476d-01, 1.3682998d-17,-4.2258615d-05 /
      data fpppp(14, 1,20,1),fpppp(14, 1,20,2),fpppp(14, 1,20,3)/
     x-2.9672923d-02,-1.3498288d-17, 7.5667899d-06 /
      data fpppp(14, 1,21,1),fpppp(14, 1,21,2),fpppp(14, 1,21,3)/
     x-2.9672923d-02,-2.6002547d-17, 3.3519845d-06 /
      data fpppp(14, 1,22,1),fpppp(14, 1,22,2),fpppp(14, 1,22,3)/
     x-1.7000476d-01, 4.0282303d-17,-2.5399394d-05 /
      data fpppp(14, 1,23,1),fpppp(14, 1,23,2),fpppp(14, 1,23,3)/
     x-1.8321194d-02,-1.2716145d-16,-3.9940652d-05 /
      data fpppp(14, 2, 1,1),fpppp(14, 2, 1,2),fpppp(14, 2, 1,3)/
     x-1.0287946d-02,-2.8628278d-04,-1.6172126d-05 /
      data fpppp(14, 2, 2,1),fpppp(14, 2, 2,2),fpppp(14, 2, 2,3)/
     x-8.6286441d-02,-1.8986644d-04,-1.0222874d-05 /
      data fpppp(14, 2, 3,1),fpppp(14, 2, 3,2),fpppp(14, 2, 3,3)/
     x-1.5585364d-02, 1.5684001d-05, 1.5610592d-06 /
      data fpppp(14, 2, 4,1),fpppp(14, 2, 4,2),fpppp(14, 2, 4,3)/
     x-1.5585364d-02, 1.7532028d-05, 3.2488697d-06 /
      data fpppp(14, 2, 5,1),fpppp(14, 2, 5,2),fpppp(14, 2, 5,3)/
     x-8.6286441d-02,-1.9725855d-04,-1.6974116d-05 /
      data fpppp(14, 2, 6,1),fpppp(14, 2, 6,2),fpppp(14, 2, 6,3)/
     x-1.0287946d-02,-2.5856237d-04, 9.1450325d-06 /
      data fpppp(14, 2, 7,1),fpppp(14, 2, 7,2),fpppp(14, 2, 7,3)/
     x-1.3329350d-02, 9.7559421d-04, 2.4704278d-06 /
      data fpppp(14, 2, 8,1),fpppp(14, 2, 8,2),fpppp(14, 2, 8,3)/
     x-1.1682544d-02,-1.6225605d-03, 3.7264366d-07 /
      data fpppp(14, 2, 9,1),fpppp(14, 2, 9,2),fpppp(14, 2, 9,3)/
     x-1.1447901d-02, 1.9379788d-03, 5.0448136d-07 /
      data fpppp(14, 2,10,1),fpppp(14, 2,10,2),fpppp(14, 2,10,3)/
     x-1.1426896d-02,-3.5638611d-03, 5.5751474d-08 /
      data fpppp(14, 2,11,1),fpppp(14, 2,11,2),fpppp(14, 2,11,3)/
     x-7.8877860d-03, 3.2858001d-03, 7.0045525d-08 /
      data fpppp(14, 2,12,1),fpppp(14, 2,12,2),fpppp(14, 2,12,3)/
     x-8.7070190d-03, 1.7716724d-03, 3.6774469d-08 /
      data fpppp(14, 2,13,1),fpppp(14, 2,13,2),fpppp(14, 2,13,3)/
     x-1.2154377d-02,-3.4372957d-03, 7.3700516d-08 /
      data fpppp(14, 2,14,1),fpppp(14, 2,14,2),fpppp(14, 2,14,3)/
     x-1.1405761d-02, 1.4467801d-03, 7.1617727d-08 /
      data fpppp(14, 2,15,1),fpppp(14, 2,15,2),fpppp(14, 2,15,3)/
     x-8.7033011d-03,-2.7473472d-04, 4.8535681d-07 /
      data fpppp(14, 2,16,1),fpppp(14, 2,16,2),fpppp(14, 2,16,3)/
     x-1.0783714d-02, 1.1844398d-04, 4.0755131d-07 /
      data fpppp(14, 2,17,1),fpppp(14, 2,17,2),fpppp(14, 2,17,3)/
     x-1.1473546d-02, 5.7850030d-05, 2.6240315d-06 /
      data fpppp(14, 2,18,1),fpppp(14, 2,18,2),fpppp(14, 2,18,3)/
     x-1.0362415d-02,-1.1178390d-04, 8.3947424d-06 /
      data fpppp(14, 2,19,1),fpppp(14, 2,19,2),fpppp(14, 2,19,3)/
     x-7.7059492d-02,-2.0457235d-04,-1.6040927d-05 /
      data fpppp(14, 2,20,1),fpppp(14, 2,20,2),fpppp(14, 2,20,3)/
     x-1.5200399d-02, 3.6048306d-05, 3.0130132d-06 /
      data fpppp(14, 2,21,1),fpppp(14, 2,21,2),fpppp(14, 2,21,3)/
     x-1.5200399d-02, 2.6313586d-05, 1.4310112d-06 /
      data fpppp(14, 2,22,1),fpppp(14, 2,22,2),fpppp(14, 2,22,3)/
     x-7.7059492d-02,-1.6563348d-04,-9.7129195d-06 /
      data fpppp(14, 2,23,1),fpppp(14, 2,23,2),fpppp(14, 2,23,3)/
     x-1.0362415d-02,-2.5780470d-04,-1.5335288d-05 /
      data fpppp(14, 3, 1,1),fpppp(14, 3, 1,2),fpppp(14, 3, 1,3)/
     x 8.9406607d-04, 1.6347920d-01, 2.9737297d-05 /
      data fpppp(14, 3, 2,1),fpppp(14, 3, 2,2),fpppp(14, 3, 2,3)/
     x 2.1100244d-01, 9.5970531d-02, 1.8131632d-05 /
      data fpppp(14, 3, 3,1),fpppp(14, 3, 3,2),fpppp(14, 3, 3,3)/
     x 1.3207214d-02,-3.7912131d-02,-5.3007320d-06 /
      data fpppp(14, 3, 4,1),fpppp(14, 3, 4,2),fpppp(14, 3, 4,3)/
     x 1.3207214d-02,-5.6774996d-02,-7.8153403d-06 /
      data fpppp(14, 3, 5,1),fpppp(14, 3, 5,2),fpppp(14, 3, 5,3)/
     x 2.1100244d-01, 1.7142199d-01, 2.8190065d-05 /
      data fpppp(14, 3, 6,1),fpppp(14, 3, 6,2),fpppp(14, 3, 6,3)/
     x 8.9406607d-04,-1.1946378d-01,-7.9818267d-06 /
      data fpppp(14, 3, 7,1),fpppp(14, 3, 7,2),fpppp(14, 3, 7,3)/
     x 1.4071589d-02, 3.4319455d-02,-7.0933228d-06 /
      data fpppp(14, 3, 8,1),fpppp(14, 3, 8,2),fpppp(14, 3, 8,3)/
     x 3.5924088d-03,-1.0299994d-02,-1.8978509d-08 /
      data fpppp(14, 3, 9,1),fpppp(14, 3, 9,2),fpppp(14, 3, 9,3)/
     x 4.7234871d-03, 3.5369351d-03,-1.4747566d-06 /
      data fpppp(14, 3,10,1),fpppp(14, 3,10,2),fpppp(14, 3,10,3)/
     x 4.7429359d-03,-9.0543792d-04,-2.5008712d-07 /
      data fpppp(14, 3,11,1),fpppp(14, 3,11,2),fpppp(14, 3,11,3)/
     x 1.6615504d-03, 2.5386118d-04,-3.6440966d-07 /
      data fpppp(14, 3,12,1),fpppp(14, 3,12,2),fpppp(14, 3,12,3)/
     x 2.5659082d-03, 2.4111750d-04,-2.8366239d-07 /
      data fpppp(14, 3,13,1),fpppp(14, 3,13,2),fpppp(14, 3,13,3)/
     x 5.7108399d-03,-1.0060323d-03,-3.6873449d-07 /
      data fpppp(14, 3,14,1),fpppp(14, 3,14,2),fpppp(14, 3,14,3)/
     x 4.7135433d-03, 3.9688964d-03,-2.5452955d-07 /
      data fpppp(14, 3,15,1),fpppp(14, 3,15,2),fpppp(14, 3,15,3)/
     x-2.3254073d-03,-4.1010561d-03,-1.4531861d-06 /
      data fpppp(14, 3,16,1),fpppp(14, 3,16,2),fpppp(14, 3,16,3)/
     x 2.4979739d-03,-4.9920460d-03, 9.1157130d-08 /
      data fpppp(14, 3,17,1),fpppp(14, 3,17,2),fpppp(14, 3,17,3)/
     x 3.8079043d-03, 2.9953560d-02,-7.5132397d-06 /
      data fpppp(14, 3,18,1),fpppp(14, 3,18,2),fpppp(14, 3,18,3)/
     x 1.0871680d-03,-1.0676654d-01,-5.8997272d-06 /
      data fpppp(14, 3,19,1),fpppp(14, 3,19,2),fpppp(14, 3,19,3)/
     x 1.8159755d-01, 1.5321501d-01, 2.5052960d-05 /
      data fpppp(14, 3,20,1),fpppp(14, 3,20,2),fpppp(14, 3,20,3)/
     x 1.3002218d-02,-5.0747161d-02,-6.8119743d-06 /
      data fpppp(14, 3,21,1),fpppp(14, 3,21,2),fpppp(14, 3,21,3)/
     x 1.3002218d-02,-3.3888115d-02,-4.6368323d-06 /
      data fpppp(14, 3,22,1),fpppp(14, 3,22,2),fpppp(14, 3,22,3)/
     x 1.8159755d-01, 8.5778824d-02, 1.6352393d-05 /
      data fpppp(14, 3,23,1),fpppp(14, 3,23,2),fpppp(14, 3,23,3)/
     x 1.0871680d-03, 1.4611914d-01, 2.6727402d-05 /
      data fpppp(14, 4, 1,1),fpppp(14, 4, 1,2),fpppp(14, 4, 1,3)/
     x 4.0969841d-04,-4.4265205d-02, 3.7240624d-06 /
      data fpppp(14, 4, 2,1),fpppp(14, 4, 2,2),fpppp(14, 4, 2,3)/
     x-1.6631880d-01,-2.5826958d-02, 3.9103349d-06 /
      data fpppp(14, 4, 3,1),fpppp(14, 4, 3,2),fpppp(14, 4, 3,3)/
     x-5.1456746d-03, 1.0488303d-02, 5.2557493d-06 /
      data fpppp(14, 4, 4,1),fpppp(14, 4, 4,2),fpppp(14, 4, 4,3)/
     x-5.1456746d-03, 1.6080021d-02, 3.5997956d-06 /
      data fpppp(14, 4, 5,1),fpppp(14, 4, 5,2),fpppp(14, 4, 5,3)/
     x-1.6631880d-01,-4.8193831d-02, 1.0534149d-05 /
      data fpppp(14, 4, 6,1),fpppp(14, 4, 6,2),fpppp(14, 4, 6,3)/
     x 4.0969841d-04, 3.9610567d-02,-2.1115242d-05 /
      data fpppp(14, 4, 7,1),fpppp(14, 4, 7,2),fpppp(14, 4, 7,3)/
     x-1.6481520d-02,-2.3735915d-02, 6.2148354d-06 /
      data fpppp(14, 4, 8,1),fpppp(14, 4, 8,2),fpppp(14, 4, 8,3)/
     x 9.2767803d-04, 1.2701740d-02,-2.2168220d-06 /
      data fpppp(14, 4, 9,1),fpppp(14, 4, 9,2),fpppp(14, 4, 9,3)/
     x-1.9999126d-05,-3.5095565d-03, 9.3894234d-07 /
      data fpppp(14, 4,10,1),fpppp(14, 4,10,2),fpppp(14, 4,10,3)/
     x 1.9668076d-04, 1.1598097d-03,-2.1990003d-07 /
      data fpppp(14, 4,11,1),fpppp(14, 4,11,2),fpppp(14, 4,11,3)/
     x 7.6047287d-04,-2.9804690d-04,-3.0256054d-08 /
      data fpppp(14, 4,12,1),fpppp(14, 4,12,2),fpppp(14, 4,12,3)/
     x 3.5704397d-04, 1.0237283d-06,-1.2267121d-07 /
      data fpppp(14, 4,13,1),fpppp(14, 4,13,2),fpppp(14, 4,13,3)/
     x-3.2442441d-04,-1.6051320d-04,-3.1168210d-08 /
      data fpppp(14, 4,14,1),fpppp(14, 4,14,2),fpppp(14, 4,14,3)/
     x 2.6342353d-04, 4.3990532d-04,-2.3213055d-07 /
      data fpppp(14, 4,15,1),fpppp(14, 4,15,2),fpppp(14, 4,15,3)/
     x 4.6807263d-03,-5.2052126d-04, 9.1695744d-07 /
      data fpppp(14, 4,16,1),fpppp(14, 4,16,2),fpppp(14, 4,16,3)/
     x 1.4250454d-03, 1.3146168d-03,-2.3429478d-06 /
      data fpppp(14, 4,17,1),fpppp(14, 4,17,2),fpppp(14, 4,17,3)/
     x 1.5720349d-04,-3.9015810d-03, 6.5572696d-06 /
      data fpppp(14, 4,18,1),fpppp(14, 4,18,2),fpppp(14, 4,18,3)/
     x 3.1893524d-04, 1.7272813d-02,-2.2266955d-05 /
      data fpppp(14, 4,19,1),fpppp(14, 4,19,2),fpppp(14, 4,19,3)/
     x-1.3973663d-01,-2.7492083d-02, 1.4080148d-05 /
      data fpppp(14, 4,20,1),fpppp(14, 4,20,2),fpppp(14, 4,20,3)/
     x-6.8504919d-03, 9.3572300d-03, 1.8122763d-06 /
      data fpppp(14, 4,21,1),fpppp(14, 4,21,2),fpppp(14, 4,21,3)/
     x-6.8504919d-03, 6.4160318d-03, 3.8093701d-06 /
      data fpppp(14, 4,22,1),fpppp(14, 4,22,2),fpppp(14, 4,22,3)/
     x-1.3973663d-01,-1.5727290d-02, 6.0917728d-06 /
      data fpppp(14, 4,23,1),fpppp(14, 4,23,2),fpppp(14, 4,23,3)/
     x 3.1893524d-04,-2.6845160d-02, 7.6894524d-06 /
      data fpppp(14, 5, 1,1),fpppp(14, 5, 1,2),fpppp(14, 5, 1,3)/
     x 2.0361309d-03,-4.1255791d-04,-1.7992424d-05 /
      data fpppp(14, 5, 2,1),fpppp(14, 5, 2,2),fpppp(14, 5, 2,3)/
     x 6.2469927d-02,-3.2647929d-04,-1.1814048d-05 /
      data fpppp(14, 5, 3,1),fpppp(14, 5, 3,2),fpppp(14, 5, 3,3)/
     x 8.9614249d-04,-2.0486323d-04,-7.6002991d-08 /
      data fpppp(14, 5, 4,1),fpppp(14, 5, 4,2),fpppp(14, 5, 4,3)/
     x 8.9614249d-04,-9.4896492d-05, 2.5513298d-06 /
      data fpppp(14, 5, 5,1),fpppp(14, 5, 5,2),fpppp(14, 5, 5,3)/
     x 6.2469927d-02,-7.6634622d-04,-2.2323379d-05 /
      data fpppp(14, 5, 6,1),fpppp(14, 5, 6,2),fpppp(14, 5, 6,3)/
     x 2.0361309d-03, 1.2369431d-03, 2.1417567d-05 /
      data fpppp(14, 5, 7,1),fpppp(14, 5, 7,2),fpppp(14, 5, 7,3)/
     x 1.1530074d-02,-3.0794100d-04,-3.1713548d-06 /
      data fpppp(14, 5, 8,1),fpppp(14, 5, 8,2),fpppp(14, 5, 8,3)/
     x 3.2414011d-04, 6.3163907d-05, 1.7000767d-06 /
      data fpppp(14, 5, 9,1),fpppp(14, 5, 9,2),fpppp(14, 5, 9,3)/
     x 3.7998664d-04,-3.3609502d-05,-5.3903778d-07 /
      data fpppp(14, 5,10,1),fpppp(14, 5,10,2),fpppp(14, 5,10,3)/
     x 1.0988918d-04,-4.5314579d-06, 2.9657128d-08 /
      data fpppp(14, 5,11,1),fpppp(14, 5,11,2),fpppp(14, 5,11,3)/
     x 1.6452934d-06,-4.5702071d-06,-6.6540582d-08 /
      data fpppp(14, 5,12,1),fpppp(14, 5,12,2),fpppp(14, 5,12,3)/
     x 1.6280752d-04,-4.7551190d-06,-1.2048306d-09 /
      data fpppp(14, 5,13,1),fpppp(14, 5,13,2),fpppp(14, 5,13,3)/
     x 2.9371090d-04, 5.1863362d-07,-6.2250039d-08 /
      data fpppp(14, 5,14,1),fpppp(14, 5,14,2),fpppp(14, 5,14,3)/
     x 5.0673285d-05,-2.4355371d-05, 4.0873292d-08 /
      data fpppp(14, 5,15,1),fpppp(14, 5,15,2),fpppp(14, 5,15,3)/
     x-9.0282877d-04, 5.1280584d-05,-5.1603241d-07 /
      data fpppp(14, 5,16,1),fpppp(14, 5,16,2),fpppp(14, 5,16,3)/
     x 1.4176120d-04,-2.4002984d-04, 1.7099277d-06 /
      data fpppp(14, 5,17,1),fpppp(14, 5,17,2),fpppp(14, 5,17,3)/
     x 9.0461791d-04, 8.5342094d-04,-3.3029441d-06 /
      data fpppp(14, 5,18,1),fpppp(14, 5,18,2),fpppp(14, 5,18,3)/
     x 2.0723432d-03,-3.1745940d-03, 2.1173434d-05 /
      data fpppp(14, 5,19,1),fpppp(14, 5,19,2),fpppp(14, 5,19,3)/
     x 5.4964884d-02, 5.2245040d-03,-2.4264597d-05 /
      data fpppp(14, 5,20,1),fpppp(14, 5,20,2),fpppp(14, 5,20,3)/
     x 3.0255183d-03,-1.9171527d-03, 4.1020011d-06 /
      data fpppp(14, 5,21,1),fpppp(14, 5,21,2),fpppp(14, 5,21,3)/
     x 3.0255183d-03,-1.3602601d-03, 1.3167585d-06 /
      data fpppp(14, 5,22,1),fpppp(14, 5,22,2),fpppp(14, 5,22,3)/
     x 5.4964884d-02, 2.9969335d-03,-1.3123627d-05 /
      data fpppp(14, 5,23,1),fpppp(14, 5,23,2),fpppp(14, 5,23,3)/
     x 2.0723432d-03, 5.1787953d-03,-2.0605205d-05 /
      data fpppp(14, 6, 1,1),fpppp(14, 6, 1,2),fpppp(14, 6, 1,3)/
     x-3.1908428d-04, 1.9361447d-04, 5.5319277d-06 /
      data fpppp(14, 6, 2,1),fpppp(14, 6, 2,2),fpppp(14, 6, 2,3)/
     x-1.5011578d-02, 1.0993544d-04, 3.4928568d-06 /
      data fpppp(14, 6, 3,1),fpppp(14, 6, 3,2),fpppp(14, 6, 3,3)/
     x-2.2401523d-03,-6.0074249d-05,-4.5863583d-07 /
      data fpppp(14, 6, 4,1),fpppp(14, 6, 4,2),fpppp(14, 6, 4,3)/
     x-2.2401523d-03,-7.6353644d-05,-1.1900396d-06 /
      data fpppp(14, 6, 5,1),fpppp(14, 6, 5,2),fpppp(14, 6, 5,3)/
     x-1.5011578d-02, 1.7505302d-04, 6.4184718d-06 /
      data fpppp(14, 6, 6,1),fpppp(14, 6, 6,2),fpppp(14, 6, 6,3)/
     x-3.1908428d-04,-5.0576454d-05,-5.4391285d-06 /
      data fpppp(14, 6, 7,1),fpppp(14, 6, 7,2),fpppp(14, 6, 7,3)/
     x-2.9869099d-03,-7.3795988d-06, 9.4120031d-07 /
      data fpppp(14, 6, 8,1),fpppp(14, 6, 8,2),fpppp(14, 6, 8,3)/
     x-1.2138891d-05,-8.3651165d-06,-5.0945006d-07 /
      data fpppp(14, 6, 9,1),fpppp(14, 6, 9,2),fpppp(14, 6, 9,3)/
     x-3.2901216d-05,-3.7266352d-06, 1.1645296d-07 /
      data fpppp(14, 6,10,1),fpppp(14, 6,10,2),fpppp(14, 6,10,3)/
     x 3.9764409d-05, 2.3454434d-06,-1.2180039d-08 /
      data fpppp(14, 6,11,1),fpppp(14, 6,11,2),fpppp(14, 6,11,3)/
     x 6.9635171d-05, 1.8301268d-06, 2.3620443d-08 /
      data fpppp(14, 6,12,1),fpppp(14, 6,12,2),fpppp(14, 6,12,3)/
     x 2.5027199d-05, 2.4780895d-06, 8.4138480d-09 /
      data fpppp(14, 6,13,1),fpppp(14, 6,13,2),fpppp(14, 6,13,3)/
     x-1.4078047d-05, 3.0064284d-06, 2.8473027d-08 /
      data fpppp(14, 6,14,1),fpppp(14, 6,14,2),fpppp(14, 6,14,3)/
     x 4.1732253d-05, 1.0159502d-06, 3.7542054d-10 /
      data fpppp(14, 6,15,1),fpppp(14, 6,15,2),fpppp(14, 6,15,3)/
     x 2.8735441d-04, 5.0733468d-07, 1.3327540d-07 /
      data fpppp(14, 6,16,1),fpppp(14, 6,16,2),fpppp(14, 6,16,3)/
     x 2.4451995d-06,-5.1550566d-06,-4.5751383d-07 /
      data fpppp(14, 6,17,1),fpppp(14, 6,17,2),fpppp(14, 6,17,3)/
     x-2.1084727d-04, 5.4351727d-06, 9.8696695d-07 /
      data fpppp(14, 6,18,1),fpppp(14, 6,18,2),fpppp(14, 6,18,3)/
     x-4.9630085d-04,-2.2685062d-05,-5.1095505d-06 /
      data fpppp(14, 6,19,1),fpppp(14, 6,19,2),fpppp(14, 6,19,3)/
     x-1.6432679d-02, 1.7785836d-04, 6.9250190d-06 /
      data fpppp(14, 6,20,1),fpppp(14, 6,20,2),fpppp(14, 6,20,3)/
     x-3.5710672d-04,-1.1190049d-04,-1.8455802d-06 /
      data fpppp(14, 6,21,1),fpppp(14, 6,21,2),fpppp(14, 6,21,3)/
     x-3.5710672d-04,-9.5962311d-05,-1.0800336d-06 /
      data fpppp(14, 6,22,1),fpppp(14, 6,22,2),fpppp(14, 6,22,3)/
     x-1.6432679d-02, 1.1410566d-04, 3.8628325d-06 /
      data fpppp(14, 6,23,1),fpppp(14, 6,23,2),fpppp(14, 6,23,3)/
     x-4.9630085d-04, 2.1638756d-04, 6.3736491d-06 /
      data fpppp(14, 7, 1,1),fpppp(14, 7, 1,2),fpppp(14, 7, 1,3)/
     x-1.1972165d-04, 7.2858700d-05,-9.4614768d-07 /
      data fpppp(14, 7, 2,1),fpppp(14, 7, 2,2),fpppp(14, 7, 2,3)/
     x 2.5699592d-03, 2.9283719d-05,-7.5656813d-07 /
      data fpppp(14, 7, 3,1),fpppp(14, 7, 3,2),fpppp(14, 7, 3,3)/
     x 1.4469903d-02,-6.1735015d-05,-4.5043884d-07 /
      data fpppp(14, 7, 4,1),fpppp(14, 7, 4,2),fpppp(14, 7, 4,3)/
     x 1.4469903d-02,-6.5858407d-05,-2.7524176d-07 /
      data fpppp(14, 7, 5,1),fpppp(14, 7, 5,2),fpppp(14, 7, 5,3)/
     x 2.5699592d-03, 4.5777285d-05,-1.4573565d-06 /
      data fpppp(14, 7, 6,1),fpppp(14, 7, 6,2),fpppp(14, 7, 6,3)/
     x-1.1972165d-04, 1.1007826d-05, 1.6818086d-06 /
      data fpppp(14, 7, 7,1),fpppp(14, 7, 7,2),fpppp(14, 7, 7,3)/
     x 7.4126387d-04, 4.5716871d-06,-9.7526207d-08 /
      data fpppp(14, 7, 8,1),fpppp(14, 7, 8,2),fpppp(14, 7, 8,3)/
     x 1.2483239d-05, 6.1853113d-06, 2.4218069d-07 /
      data fpppp(14, 7, 9,1),fpppp(14, 7, 9,2),fpppp(14, 7, 9,3)/
     x 4.1080132d-05, 7.4733909d-06, 3.7957049d-08 /
      data fpppp(14, 7,10,1),fpppp(14, 7,10,2),fpppp(14, 7,10,3)/
     x 3.3865967d-05, 9.8309994d-06, 4.6881401d-08 /
      data fpppp(14, 7,11,1),fpppp(14, 7,11,2),fpppp(14, 7,11,3)/
     x 1.8266680d-05, 6.7676932d-06, 1.9894198d-08 /
      data fpppp(14, 7,12,1),fpppp(14, 7,12,2),fpppp(14, 7,12,3)/
     x 2.4027080d-05, 7.8045721d-06, 1.9829518d-08 /
      data fpppp(14, 7,13,1),fpppp(14, 7,13,2),fpppp(14, 7,13,3)/
     x 2.9750003d-05, 6.2984694d-06, 2.0802226d-08 /
      data fpppp(14, 7,14,1),fpppp(14, 7,14,2),fpppp(14, 7,14,3)/
     x 1.1472547d-05, 6.7978330d-06, 4.4327761d-08 /
      data fpppp(14, 7,15,1),fpppp(14, 7,15,2),fpppp(14, 7,15,3)/
     x-6.9480357d-05, 1.3395149d-05, 3.0595576d-08 /
      data fpppp(14, 7,16,1),fpppp(14, 7,16,2),fpppp(14, 7,16,3)/
     x-2.5907997d-05,-4.8433089d-06, 2.0600580d-07 /
      data fpppp(14, 7,17,1),fpppp(14, 7,17,2),fpppp(14, 7,17,3)/
     x 1.1681856d-06, 2.0278011d-05,-1.2998126d-07 /
      data fpppp(14, 7,18,1),fpppp(14, 7,18,2),fpppp(14, 7,18,3)/
     x 1.1341777d-05, 1.1793954d-05, 1.5201204d-06 /
      data fpppp(14, 7,19,1),fpppp(14, 7,19,2),fpppp(14, 7,19,3)/
     x 4.1957258d-03, 3.3429644d-05,-1.3985498d-06 /
      data fpppp(14, 7,20,1),fpppp(14, 7,20,2),fpppp(14, 7,20,3)/
     x-9.7828711d-05,-6.0125678d-05,-1.7366786d-07 /
      data fpppp(14, 7,21,1),fpppp(14, 7,21,2),fpppp(14, 7,21,3)/
     x-9.7828711d-05,-5.7026239d-05,-3.3934579d-07 /
      data fpppp(14, 7,22,1),fpppp(14, 7,22,2),fpppp(14, 7,22,3)/
     x 4.1957258d-03, 2.1031889d-05,-7.3583808d-07 /
      data fpppp(14, 7,23,1),fpppp(14, 7,23,2),fpppp(14, 7,23,3)/
     x 1.1341777d-05, 5.8285533d-05,-9.6504860d-07 /
      data fpppp(14, 8, 1,1),fpppp(14, 8, 1,2),fpppp(14, 8, 1,3)/
     x 1.4068487d-04, 2.3724974d-02, 1.3982215d-06 /
      data fpppp(14, 8, 2,1),fpppp(14, 8, 2,2),fpppp(14, 8, 2,3)/
     x 3.4148184d-03, 1.2843281d-02, 7.3572877d-07 /
      data fpppp(14, 8, 3,1),fpppp(14, 8, 3,2),fpppp(14, 8, 3,3)/
     x 8.4388888d-03,-9.3599577d-03,-6.0941957d-07 /
      data fpppp(14, 8, 4,1),fpppp(14, 8, 4,2),fpppp(14, 8, 4,3)/
     x 8.4388888d-03,-1.1310638d-02,-7.3975760d-07 /
      data fpppp(14, 8, 5,1),fpppp(14, 8, 5,2),fpppp(14, 8, 5,3)/
     x 3.4148184d-03, 2.0646001d-02, 1.2570809d-06 /
      data fpppp(14, 8, 6,1),fpppp(14, 8, 6,2),fpppp(14, 8, 6,3)/
     x 1.4068487d-04,-5.5352230d-03,-5.5684894d-07 /
      data fpppp(14, 8, 7,1),fpppp(14, 8, 7,2),fpppp(14, 8, 7,3)/
     x-2.1013456d-04, 1.4839446d-03, 2.0375005d-07 /
      data fpppp(14, 8, 8,1),fpppp(14, 8, 8,2),fpppp(14, 8, 8,3)/
     x-1.2216718d-05,-4.0886652d-04, 2.6568225d-08 /
      data fpppp(14, 8, 9,1),fpppp(14, 8, 9,2),fpppp(14, 8, 9,3)/
     x 3.2545693d-06, 1.2119098d-04, 6.9749593d-08 /
      data fpppp(14, 8,10,1),fpppp(14, 8,10,2),fpppp(14, 8,10,3)/
     x 4.4689816d-06,-2.7224576d-05, 3.6170506d-08 /
      data fpppp(14, 8,11,1),fpppp(14, 8,11,2),fpppp(14, 8,11,3)/
     x 1.8220392d-05, 2.3553867d-05, 3.4987738d-08 /
      data fpppp(14, 8,12,1),fpppp(14, 8,12,2),fpppp(14, 8,12,3)/
     x 1.9431368d-05, 8.6973381d-06, 3.1092126d-08 /
      data fpppp(14, 8,13,1),fpppp(14, 8,13,2),fpppp(14, 8,13,3)/
     x 1.2173040d-05, 1.2360281d-05, 3.0836920d-08 /
      data fpppp(14, 8,14,1),fpppp(14, 8,14,2),fpppp(14, 8,14,3)/
     x 6.2708125d-06, 6.2044820d-06, 2.8374089d-08 /
      data fpppp(14, 8,15,1),fpppp(14, 8,15,2),fpppp(14, 8,15,3)/
     x 2.0969801d-05, 8.7254116d-06, 4.1901240d-08 /
      data fpppp(14, 8,16,1),fpppp(14, 8,16,2),fpppp(14, 8,16,3)/
     x 2.6199111d-06, 6.5946756d-06, 9.1142851d-09 /
      data fpppp(14, 8,17,1),fpppp(14, 8,17,2),fpppp(14, 8,17,3)/
     x-2.0056544d-05, 9.4789236d-06, 1.0854447d-07 /
      data fpppp(14, 8,18,1),fpppp(14, 8,18,2),fpppp(14, 8,18,3)/
     x-3.2729403d-05, 7.9465506d-06,-3.5274002d-07 /
      data fpppp(14, 8,19,1),fpppp(14, 8,19,2),fpppp(14, 8,19,3)/
     x-1.1551217d-03, 4.1458831d-06, 3.8003040d-07 /
      data fpppp(14, 8,20,1),fpppp(14, 8,20,2),fpppp(14, 8,20,3)/
     x 1.8208826d-05,-3.4684394d-05,-1.9886010d-07 /
      data fpppp(14, 8,21,1),fpppp(14, 8,21,2),fpppp(14, 8,21,3)/
     x 1.8208826d-05,-3.4004641d-05,-1.5125317d-07 /
      data fpppp(14, 8,22,1),fpppp(14, 8,22,2),fpppp(14, 8,22,3)/
     x-1.1551217d-03, 1.4268713d-06, 1.8960268d-07 /
      data fpppp(14, 8,23,1),fpppp(14, 8,23,2),fpppp(14, 8,23,3)/
     x-3.2729403d-05, 1.8142845d-05, 3.6136392d-07 /
      data fpppp(14, 9, 1,1),fpppp(14, 9, 1,2),fpppp(14, 9, 1,3)/
     x-7.2293285d-04, 4.2643991d-02,-3.5999829d-06 /
      data fpppp(14, 9, 2,1),fpppp(14, 9, 2,2),fpppp(14, 9, 2,3)/
     x-1.5319444d-02, 2.3060613d-02,-1.9805076d-06 /
      data fpppp(14, 9, 3,1),fpppp(14, 9, 3,2),fpppp(14, 9, 3,3)/
     x-5.9501762d-02,-1.6914215d-02, 1.3150042d-06 /
      data fpppp(14, 9, 4,1),fpppp(14, 9, 4,2),fpppp(14, 9, 4,3)/
     x-5.9501762d-02,-2.0395934d-02, 1.6208911d-06 /
      data fpppp(14, 9, 5,1),fpppp(14, 9, 5,2),fpppp(14, 9, 5,3)/
     x-1.5319444d-02, 3.6987490d-02,-3.2040551d-06 /
      data fpppp(14, 9, 6,1),fpppp(14, 9, 6,2),fpppp(14, 9, 6,3)/
     x-7.2293285d-04,-9.5817986d-03, 9.8832042d-07 /
      data fpppp(14, 9, 7,1),fpppp(14, 9, 7,2),fpppp(14, 9, 7,3)/
     x-5.1947399d-05, 2.5418280d-03,-2.0751896d-07 /
      data fpppp(14, 9, 8,1),fpppp(14, 9, 8,2),fpppp(14, 9, 8,3)/
     x-4.7413501d-05,-6.9888360d-04, 7.0232974d-08 /
      data fpppp(14, 9, 9,1),fpppp(14, 9, 9,2),fpppp(14, 9, 9,3)/
     x-4.4182626d-05, 1.8254744d-04,-6.1367317d-09 /
      data fpppp(14, 9,10,1),fpppp(14, 9,10,2),fpppp(14, 9,10,3)/
     x-1.3054783d-05,-4.4811991d-05, 2.4235254d-08 /
      data fpppp(14, 9,11,1),fpppp(14, 9,11,2),fpppp(14, 9,11,3)/
     x-9.8268893d-06, 2.8691446d-05, 1.7581454d-08 /
      data fpppp(14, 9,12,1),fpppp(14, 9,12,2),fpppp(14, 9,12,3)/
     x-8.3653318d-06, 6.1479447d-06, 1.8576890d-08 /
      data fpppp(14, 9,13,1),fpppp(14, 9,13,2),fpppp(14, 9,13,3)/
     x-3.7048177d-06, 1.3123586d-05, 1.9483848d-08 /
      data fpppp(14, 9,14,1),fpppp(14, 9,14,2),fpppp(14, 9,14,3)/
     x-1.8088997d-06, 8.9067504d-06, 2.1705957d-08 /
      data fpppp(14, 9,15,1),fpppp(14, 9,15,2),fpppp(14, 9,15,3)/
     x-9.6615121d-06, 6.1525894d-06, 1.9485423d-08 /
      data fpppp(14, 9,16,1),fpppp(14, 9,16,2),fpppp(14, 9,16,3)/
     x-8.2718426d-06, 7.9214140d-06, 2.6303144d-08 /
      data fpppp(14, 9,17,1),fpppp(14, 9,17,2),fpppp(14, 9,17,3)/
     x-3.5603704d-06, 6.5472698d-06,-6.4669256d-09 /
      data fpppp(14, 9,18,1),fpppp(14, 9,18,2),fpppp(14, 9,18,3)/
     x 3.3869398d-07, 5.0400455d-06, 9.5794892d-08 /
      data fpppp(14, 9,19,1),fpppp(14, 9,19,2),fpppp(14, 9,19,3)/
     x 3.0748670d-04, 1.8128370d-06,-1.3608213d-07 /
      data fpppp(14, 9,20,1),fpppp(14, 9,20,2),fpppp(14, 9,20,3)/
     x 2.6459640d-06,-2.5023095d-05,-4.4325561d-08 /
      data fpppp(14, 9,21,1),fpppp(14, 9,21,2),fpppp(14, 9,21,3)/
     x 2.6459640d-06,-2.4581818d-05,-5.7364964d-08 /
      data fpppp(14, 9,22,1),fpppp(14, 9,22,2),fpppp(14, 9,22,3)/
     x 3.0748670d-04, 4.7730761d-08,-8.3924518d-08 /
      data fpppp(14, 9,23,1),fpppp(14, 9,23,2),fpppp(14, 9,23,3)/
     x 3.3869398d-07, 1.1659194d-05,-9.9796151d-08 /
      data fpppp(14,10, 1,1),fpppp(14,10, 1,2),fpppp(14,10, 1,3)/
     x-3.9682917d-04, 1.9245543d-02, 4.7948764d-06 /
      data fpppp(14,10, 2,1),fpppp(14,10, 2,2),fpppp(14,10, 2,3)/
     x 2.1384137d-02, 1.1302998d-02, 2.7715088d-06 /
      data fpppp(14,10, 3,1),fpppp(14,10, 3,2),fpppp(14,10, 3,3)/
     x 4.9516881d-02,-4.4927313d-03,-1.3097933d-06 /
      data fpppp(14,10, 4,1),fpppp(14,10, 4,2),fpppp(14,10, 4,3)/
     x 4.9516881d-02,-6.6347498d-03,-1.7551429d-06 /
      data fpppp(14,10, 5,1),fpppp(14,10, 5,2),fpppp(14,10, 5,3)/
     x 2.1384137d-02, 1.9871071d-02, 4.5529075d-06 /
      data fpppp(14,10, 6,1),fpppp(14,10, 6,2),fpppp(14,10, 6,3)/
     x-3.9682917d-04,-1.2884735d-02,-1.8853684d-06 /
      data fpppp(14,10, 7,1),fpppp(14,10, 7,2),fpppp(14,10, 7,3)/
     x-5.0576621d-04, 2.9763033d-03, 6.2980449d-08 /
      data fpppp(14,10, 8,1),fpppp(14,10, 8,2),fpppp(14,10, 8,3)/
     x-1.7284568d-04,-9.1411974d-04,-1.9122316d-07 /
      data fpppp(14,10, 9,1),fpppp(14,10, 9,2),fpppp(14,10, 9,3)/
     x-1.6310934d-05, 2.0414370d-04,-2.1845200d-08 /
      data fpppp(14,10,10,1),fpppp(14,10,10,2),fpppp(14,10,10,3)/
     x-4.3890177d-05,-6.4922542d-05,-2.2058352d-08 /
      data fpppp(14,10,11,1),fpppp(14,10,11,2),fpppp(14,10,11,3)/
     x-2.9007319d-05, 2.7081064d-05, 3.8362998d-09 /
      data fpppp(14,10,12,1),fpppp(14,10,12,2),fpppp(14,10,12,3)/
     x-2.1698054d-05, 5.9341531d-06, 6.8277274d-09 /
      data fpppp(14,10,13,1),fpppp(14,10,13,2),fpppp(14,10,13,3)/
     x-1.8011622d-05, 1.1996130d-05, 8.8881791d-09 /
      data fpppp(14,10,14,1),fpppp(14,10,14,2),fpppp(14,10,14,3)/
     x-1.3613405d-05, 7.8459583d-06, 8.9727107d-09 /
      data fpppp(14,10,15,1),fpppp(14,10,15,2),fpppp(14,10,15,3)/
     x-6.2989513d-06, 5.0460987d-06, 9.2140751d-09 /
      data fpppp(14,10,16,1),fpppp(14,10,16,2),fpppp(14,10,16,3)/
     x-3.5781494d-07, 9.6928192d-06, 4.8744829d-09 /
      data fpppp(14,10,17,1),fpppp(14,10,17,2),fpppp(14,10,17,3)/
     x 6.5865520d-07, 4.4065964d-06, 3.3808469d-09 /
      data fpppp(14,10,18,1),fpppp(14,10,18,2),fpppp(14,10,18,3)/
     x 2.3544472d-06, 5.9582387d-06,-3.4871344d-08 /
      data fpppp(14,10,19,1),fpppp(14,10,19,2),fpppp(14,10,19,3)/
     x-7.9111845d-05, 3.5042872d-06, 1.4247702d-08 /
      data fpppp(14,10,20,1),fpppp(14,10,20,2),fpppp(14,10,20,3)/
     x 6.1189951d-06,-2.0819540d-05,-2.5044186d-08 /
      data fpppp(14,10,21,1),fpppp(14,10,21,2),fpppp(14,10,21,3)/
     x 6.1189951d-06,-2.0397206d-05,-2.1842196d-08 /
      data fpppp(14,10,22,1),fpppp(14,10,22,2),fpppp(14,10,22,3)/
     x-7.9111845d-05, 1.8149515d-06, 1.4397411d-09 /
      data fpppp(14,10,23,1),fpppp(14,10,23,2),fpppp(14,10,23,3)/
     x 2.3544472d-06, 1.2293247d-05, 1.3158509d-08 /
      data fpppp(14,11, 1,1),fpppp(14,11, 1,2),fpppp(14,11, 1,3)/
     x 9.6880563d-04, 2.7649975d-03,-2.0426950d-06 /
      data fpppp(14,11, 2,1),fpppp(14,11, 2,2),fpppp(14,11, 2,3)/
     x-1.1500434d-02, 1.5981897d-03,-1.3164234d-06 /
      data fpppp(14,11, 3,1),fpppp(14,11, 3,2),fpppp(14,11, 3,3)/
     x-1.3377603d-02,-7.8700479d-04, 9.3803365d-08 /
      data fpppp(14,11, 4,1),fpppp(14,11, 4,2),fpppp(14,11, 4,3)/
     x-1.3377603d-02,-9.8844391d-04, 3.4942515d-07 /
      data fpppp(14,11, 5,1),fpppp(14,11, 5,2),fpppp(14,11, 5,3)/
     x-1.1500434d-02, 2.4039462d-03,-2.3389105d-06 /
      data fpppp(14,11, 6,1),fpppp(14,11, 6,2),fpppp(14,11, 6,3)/
     x 9.6880563d-04,-2.5658929d-04, 1.7916318d-06 /
      data fpppp(14,11, 7,1),fpppp(14,11, 7,2),fpppp(14,11, 7,3)/
     x 2.2393164d-04,-4.1436264d-04, 9.3498277d-08 /
      data fpppp(14,11, 8,1),fpppp(14,11, 8,2),fpppp(14,11, 8,3)/
     x-1.0469268d-04,-2.4264365d-04, 7.5176522d-08 /
      data fpppp(14,11, 9,1),fpppp(14,11, 9,2),fpppp(14,11, 9,3)/
     x-3.0319122d-04,-7.2688070d-05,-3.2451065d-08 /
      data fpppp(14,11,10,1),fpppp(14,11,10,2),fpppp(14,11,10,3)/
     x-4.4622425d-05,-2.9524881d-05,-1.1804329d-08 /
      data fpppp(14,11,11,1),fpppp(14,11,11,2),fpppp(14,11,11,3)/
     x-2.8509953d-05, 1.3579993d-06,-6.2281241d-09 /
      data fpppp(14,11,12,1),fpppp(14,11,12,2),fpppp(14,11,12,3)/
     x-1.8889945d-05, 8.1097117d-06, 3.0405667d-09 /
      data fpppp(14,11,13,1),fpppp(14,11,13,2),fpppp(14,11,13,3)/
     x-1.3894236d-05, 9.5072830d-06, 3.3514412d-09 /
      data fpppp(14,11,14,1),fpppp(14,11,14,2),fpppp(14,11,14,3)/
     x-1.1588149d-05, 7.2343069d-06, 2.6428130d-09 /
      data fpppp(14,11,15,1),fpppp(14,11,15,2),fpppp(14,11,15,3)/
     x-8.7774447d-06, 5.9254677d-06, 1.0718216d-09 /
      data fpppp(14,11,16,1),fpppp(14,11,16,2),fpppp(14,11,16,3)/
     x-5.5856899d-06, 7.2017106d-06,-8.9486870d-10 /
      data fpppp(14,11,17,1),fpppp(14,11,17,2),fpppp(14,11,17,3)/
     x 2.8435333d-07, 3.6315451d-06,-3.9748354d-09 /
      data fpppp(14,11,18,1),fpppp(14,11,18,2),fpppp(14,11,18,3)/
     x 2.5233375d-06, 3.9502777d-06, 2.2977716d-09 /
      data fpppp(14,11,19,1),fpppp(14,11,19,2),fpppp(14,11,19,3)/
     x 2.6989025d-05, 8.3620380d-06,-1.1139451d-08 /
      data fpppp(14,11,20,1),fpppp(14,11,20,2),fpppp(14,11,20,3)/
     x 4.2308167d-06,-1.8779139d-05,-3.9818889d-09 /
      data fpppp(14,11,21,1),fpppp(14,11,21,2),fpppp(14,11,21,3)/
     x 4.2308167d-06,-1.7968492d-05,-4.7782853d-09 /
      data fpppp(14,11,22,1),fpppp(14,11,22,2),fpppp(14,11,22,3)/
     x 2.6989025d-05, 5.1194475d-06,-7.9538654d-09 /
      data fpppp(14,11,23,1),fpppp(14,11,23,2),fpppp(14,11,23,3)/
     x 2.5233375d-06, 1.6109992d-05,-9.6481752d-09 /
      data fpppp(14,12, 1,1),fpppp(14,12, 1,2),fpppp(14,12, 1,3)/
     x-1.6338282d-04, 1.4621579d-03, 4.5127884d-07 /
      data fpppp(14,12, 2,1),fpppp(14,12, 2,2),fpppp(14,12, 2,3)/
     x 2.7642005d-03, 8.1649938d-04, 2.2711389d-07 /
      data fpppp(14,12, 3,1),fpppp(14,12, 3,2),fpppp(14,12, 3,3)/
     x 4.3971017d-03,-5.2607593d-04,-2.1755269d-07 /
      data fpppp(14,12, 4,1),fpppp(14,12, 4,2),fpppp(14,12, 4,3)/
     x 4.3971017d-03,-5.9778873d-04,-2.8000472d-07 /
      data fpppp(14,12, 5,1),fpppp(14,12, 5,2),fpppp(14,12, 5,3)/
     x 2.7642005d-03, 1.1033506d-03, 4.7692199d-07 /
      data fpppp(14,12, 6,1),fpppp(14,12, 6,2),fpppp(14,12, 6,3)/
     x-1.6338282d-04, 3.8646604d-04,-4.8550155d-07 /
      data fpppp(14,12, 7,1),fpppp(14,12, 7,2),fpppp(14,12, 7,3)/
     x-4.2176620d-06,-1.2887518d-04, 1.9845002d-07 /
      data fpppp(14,12, 8,1),fpppp(14,12, 8,2),fpppp(14,12, 8,3)/
     x 6.0074815d-05,-2.7870763d-04, 1.2828552d-07 /
      data fpppp(14,12, 9,1),fpppp(14,12, 9,2),fpppp(14,12, 9,3)/
     x 8.2650110d-04,-1.4926172d-04, 5.4832096d-08 /
      data fpppp(14,12,10,1),fpppp(14,12,10,2),fpppp(14,12,10,3)/
     x-2.6984879d-05,-6.3376588d-05, 1.8616676d-08 /
      data fpppp(14,12,11,1),fpppp(14,12,11,2),fpppp(14,12,11,3)/
     x-1.9740800d-05,-1.4258827d-05, 6.9695274d-09 /
      data fpppp(14,12,12,1),fpppp(14,12,12,2),fpppp(14,12,12,3)/
     x-1.5921346d-05, 2.1416050d-06, 2.4156738d-09 /
      data fpppp(14,12,13,1),fpppp(14,12,13,2),fpppp(14,12,13,3)/
     x-1.3069918d-05, 6.3987986d-06, 1.9500531d-09 /
      data fpppp(14,12,14,1),fpppp(14,12,14,2),fpppp(14,12,14,3)/
     x-9.5652545d-06, 7.8514096d-06,-4.0561836d-10 /
      data fpppp(14,12,15,1),fpppp(14,12,15,2),fpppp(14,12,15,3)/
     x-7.5388585d-06, 5.9658892d-06,-1.9787357d-09 /
      data fpppp(14,12,16,1),fpppp(14,12,16,2),fpppp(14,12,16,3)/
     x-6.2502669d-06, 6.2507199d-06,-2.8038556d-09 /
      data fpppp(14,12,17,1),fpppp(14,12,17,2),fpppp(14,12,17,3)/
     x-8.1308945d-06, 1.5423761d-07, 1.9125910d-10 /
      data fpppp(14,12,18,1),fpppp(14,12,18,2),fpppp(14,12,18,3)/
     x-3.8212288d-06, 3.5566027d-06, 5.3804778d-10 /
      data fpppp(14,12,19,1),fpppp(14,12,19,2),fpppp(14,12,19,3)/
     x-6.8705539d-06, 7.8506380d-06, 4.2461780d-09 /
      data fpppp(14,12,20,1),fpppp(14,12,20,2),fpppp(14,12,20,3)/
     x-6.1561446d-06,-1.5311134d-05,-2.4303481d-09 /
      data fpppp(14,12,21,1),fpppp(14,12,21,2),fpppp(14,12,21,3)/
     x-6.1561446d-06,-1.4594226d-05,-2.1064315d-09 /
      data fpppp(14,12,22,1),fpppp(14,12,22,2),fpppp(14,12,22,3)/
     x-6.8705539d-06, 4.9830060d-06, 2.9505117d-09 /
      data fpppp(14,12,23,1),fpppp(14,12,23,2),fpppp(14,12,23,3)/
     x-3.8212288d-06, 1.4310223d-05, 5.3967964d-09 /
      data fpppp(14,13, 1,1),fpppp(14,13, 1,2),fpppp(14,13, 1,3)/
     x-1.3532004d-04, 1.9870061d-03,-7.9201328d-07 /
      data fpppp(14,13, 2,1),fpppp(14,13, 2,2),fpppp(14,13, 2,3)/
     x-8.1879704d-04, 1.0664622d-03,-3.9088640d-07 /
      data fpppp(14,13, 3,1),fpppp(14,13, 3,2),fpppp(14,13, 3,3)/
     x-1.5402425d-03,-8.4407360d-04, 4.4525708d-07 /
      data fpppp(14,13, 4,1),fpppp(14,13, 4,2),fpppp(14,13, 4,3)/
     x-1.5402425d-03,-9.5267568d-04, 4.8623177d-07 /
      data fpppp(14,13, 5,1),fpppp(14,13, 5,2),fpppp(14,13, 5,3)/
     x-8.1879704d-04, 1.5008705d-03,-5.5478513d-07 /
      data fpppp(14,13, 6,1),fpppp(14,13, 6,2),fpppp(14,13, 6,3)/
     x-1.3532004d-04, 3.5797504d-04,-1.7739303d-07 /
      data fpppp(14,13, 7,1),fpppp(14,13, 7,2),fpppp(14,13, 7,3)/
     x 3.3312920d-04, 6.2534618d-05,-1.2742099d-07 /
      data fpppp(14,13, 8,1),fpppp(14,13, 8,2),fpppp(14,13, 8,3)/
     x-1.6955483d-04,-2.0128900d-04,-1.0740634d-08 /
      data fpppp(14,13, 9,1),fpppp(14,13, 9,2),fpppp(14,13, 9,3)/
     x-3.2188336d-03,-1.9362186d-04, 6.5733511d-08 /
      data fpppp(14,13,10,1),fpppp(14,13,10,2),fpppp(14,13,10,3)/
     x-1.2158547d-05,-1.0619284d-04, 4.5276358d-08 /
      data fpppp(14,13,11,1),fpppp(14,13,11,2),fpppp(14,13,11,3)/
     x-1.1760868d-05,-3.2044437d-05, 2.4424251d-08 /
      data fpppp(14,13,12,1),fpppp(14,13,12,2),fpppp(14,13,12,3)/
     x-1.0401652d-05,-5.4162520d-06, 9.7010592d-09 /
      data fpppp(14,13,13,1),fpppp(14,13,13,2),fpppp(14,13,13,3)/
     x-8.7153077d-06, 3.6488267d-06, 2.5568250d-09 /
      data fpppp(14,13,14,1),fpppp(14,13,14,2),fpppp(14,13,14,3)/
     x-8.5266602d-06, 7.0498391d-06, 5.8142436d-10 /
      data fpppp(14,13,15,1),fpppp(14,13,15,2),fpppp(14,13,15,3)/
     x-8.4302388d-06, 5.8218096d-06,-1.7524130d-09 /
      data fpppp(14,13,16,1),fpppp(14,13,16,2),fpppp(14,13,16,3)/
     x-1.0585576d-05, 2.6344820d-06,-1.1893356d-09 /
      data fpppp(14,13,17,1),fpppp(14,13,17,2),fpppp(14,13,17,3)/
     x-8.4937332d-06, 1.7710120d-06, 1.6438402d-09 /
      data fpppp(14,13,18,1),fpppp(14,13,18,2),fpppp(14,13,18,3)/
     x-1.0922431d-05, 2.0614210d-06, 5.7534990d-09 /
      data fpppp(14,13,19,1),fpppp(14,13,19,2),fpppp(14,13,19,3)/
     x-1.2515585d-05, 2.7746506d-07, 2.0668507d-09 /
      data fpppp(14,13,20,1),fpppp(14,13,20,2),fpppp(14,13,20,3)/
     x-8.3166583d-06,-8.8714051d-06,-6.8626509d-11 /
      data fpppp(14,13,21,1),fpppp(14,13,21,2),fpppp(14,13,21,3)/
     x-8.3166583d-06,-8.7534217d-06,-1.9632077d-10 /
      data fpppp(14,13,22,1),fpppp(14,13,22,2),fpppp(14,13,22,3)/
     x-1.2515585d-05,-1.9446851d-07, 2.5776277d-09 /
      data fpppp(14,13,23,1),fpppp(14,13,23,2),fpppp(14,13,23,3)/
     x-1.0922431d-05, 3.8311719d-06, 3.8380852d-09 /
      data fpppp(14,14, 1,1),fpppp(14,14, 1,2),fpppp(14,14, 1,3)/
     x 1.3494389d-03, 1.7845281d-03,-3.4576091d-07 /
      data fpppp(14,14, 2,1),fpppp(14,14, 2,2),fpppp(14,14, 2,3)/
     x 7.0172463d-04, 9.3496386d-04,-1.2423793d-07 /
      data fpppp(14,14, 3,1),fpppp(14,14, 3,2),fpppp(14,14, 3,3)/
     x-4.1991411d-04,-8.2938097d-04, 3.4837813d-07 /
      data fpppp(14,14, 4,1),fpppp(14,14, 4,2),fpppp(14,14, 4,3)/
     x-4.1991411d-04,-9.2764324d-04, 3.5201117d-07 /
      data fpppp(14,14, 5,1),fpppp(14,14, 5,2),fpppp(14,14, 5,3)/
     x 7.0172463d-04, 1.3280129d-03,-1.3877011d-07 /
      data fpppp(14,14, 6,1),fpppp(14,14, 6,2),fpppp(14,14, 6,3)/
     x 1.3494389d-03, 3.1059415d-04,-2.9126525d-07 /
      data fpppp(14,14, 7,1),fpppp(14,14, 7,2),fpppp(14,14, 7,3)/
     x-9.1750584d-04, 2.1185982d-04,-2.7058176d-07 /
      data fpppp(14,14, 8,1),fpppp(14,14, 8,2),fpppp(14,14, 8,3)/
     x 6.6841166d-04,-6.3185598d-05, 6.5998777d-08 /
      data fpppp(14,14, 9,1),fpppp(14,14, 9,2),fpppp(14,14, 9,3)/
     x 1.1963098d-02,-2.1411239d-04,-2.0117455d-08 /
      data fpppp(14,14,10,1),fpppp(14,14,10,2),fpppp(14,14,10,3)/
     x 1.8479091d-06,-1.5720652d-04, 6.0721394d-08 /
      data fpppp(14,14,11,1),fpppp(14,14,11,2),fpppp(14,14,11,3)/
     x-1.6097908d-06,-4.7496580d-05, 3.1550772d-08 /
      data fpppp(14,14,12,1),fpppp(14,14,12,2),fpppp(14,14,12,3)/
     x-3.9911998d-06,-1.2612735d-05, 1.5667377d-08 /
      data fpppp(14,14,13,1),fpppp(14,14,13,2),fpppp(14,14,13,3)/
     x-4.2997429d-06,-4.6675577d-07, 6.3761929d-09 /
      data fpppp(14,14,14,1),fpppp(14,14,14,2),fpppp(14,14,14,3)/
     x-4.3950961d-06, 6.2249754d-06, 1.9784493d-09 /
      data fpppp(14,14,15,1),fpppp(14,14,15,2),fpppp(14,14,15,3)/
     x-7.2470700d-06, 2.5327209d-06, 1.4807281d-09 /
      data fpppp(14,14,16,1),fpppp(14,14,16,2),fpppp(14,14,16,3)/
     x-8.3759254d-06, 3.5998532d-06, 1.2933073d-09 /
      data fpppp(14,14,17,1),fpppp(14,14,17,2),fpppp(14,14,17,3)/
     x-1.1318227d-05, 2.1241348d-07, 2.0526019d-09 /
      data fpppp(14,14,18,1),fpppp(14,14,18,2),fpppp(14,14,18,3)/
     x-1.1803660d-05,-7.4887632d-07, 1.0789589d-09 /
      data fpppp(14,14,19,1),fpppp(14,14,19,2),fpppp(14,14,19,3)/
     x-9.5500947d-06,-1.3769483d-07, 3.6231859d-09 /
      data fpppp(14,14,20,1),fpppp(14,14,20,2),fpppp(14,14,20,3)/
     x-1.0085959d-05,-5.6059811d-06, 1.3667850d-09 /
      data fpppp(14,14,21,1),fpppp(14,14,21,2),fpppp(14,14,21,3)/
     x-1.0085959d-05,-5.4558364d-06, 1.5375388d-09 /
      data fpppp(14,14,22,1),fpppp(14,14,22,2),fpppp(14,14,22,3)/
     x-9.5500947d-06,-7.3827364d-07, 2.9401705d-09 /
      data fpppp(14,14,23,1),fpppp(14,14,23,2),fpppp(14,14,23,3)/
     x-1.1803660d-05, 1.5032942d-06, 3.6402664d-09 /
      data fpppp(14,15, 1,1),fpppp(14,15, 1,2),fpppp(14,15, 1,3)/
     x-5.0557726d-03, 3.1844392d-04, 2.5103842d-07 /
      data fpppp(14,15, 2,1),fpppp(14,15, 2,2),fpppp(14,15, 2,3)/
     x-1.5848634d-03, 1.1517808d-04, 1.1047510d-07 /
      data fpppp(14,15, 3,1),fpppp(14,15, 3,2),fpppp(14,15, 3,3)/
     x 2.7615338d-04,-3.4149112d-04,-1.8137896d-07 /
      data fpppp(14,15, 4,1),fpppp(14,15, 4,2),fpppp(14,15, 4,3)/
     x 2.7615338d-04,-3.0456691d-04,-1.9774681d-07 /
      data fpppp(14,15, 5,1),fpppp(14,15, 5,2),fpppp(14,15, 5,3)/
     x-1.5848634d-03,-3.2518738d-05, 1.7594652d-07 /
      data fpppp(14,15, 6,1),fpppp(14,15, 6,2),fpppp(14,15, 6,3)/
     x-5.0557726d-03, 8.7230701d-04, 5.5206028d-09 /
      data fpppp(14,15, 7,1),fpppp(14,15, 7,2),fpppp(14,15, 7,3)/
     x 4.0429805d-03,-1.9151767d-04, 3.5872082d-07 /
      data fpppp(14,15, 8,1),fpppp(14,15, 8,2),fpppp(14,15, 8,3)/
     x-2.5367243d-03, 4.3849271d-04,-5.6265215d-07 /
      data fpppp(14,15, 9,1),fpppp(14,15, 9,2),fpppp(14,15, 9,3)/
     x-4.4607569d-02,-3.3885676d-04, 2.1659422d-07 /
      data fpppp(14,15,10,1),fpppp(14,15,10,2),fpppp(14,15,10,3)/
     x 4.5546159d-05,-1.9861635d-04, 2.7764094d-08 /
      data fpppp(14,15,11,1),fpppp(14,15,11,2),fpppp(14,15,11,3)/
     x 1.2005091d-05,-5.8872054d-05, 3.3690642d-08 /
      data fpppp(14,15,12,1),fpppp(14,15,12,2),fpppp(14,15,12,3)/
     x 1.4401299d-06,-1.7476939d-05, 1.2751488d-08 /
      data fpppp(14,15,13,1),fpppp(14,15,13,2),fpppp(14,15,13,3)/
     x-3.3952321d-06,-3.6399374d-06, 7.6521964d-09 /
      data fpppp(14,15,14,1),fpppp(14,15,14,2),fpppp(14,15,14,3)/
     x-4.5501284d-06, 2.3337562d-06, 4.3675495d-09 /
      data fpppp(14,15,15,1),fpppp(14,15,15,2),fpppp(14,15,15,3)/
     x-3.6902258d-06, 1.4627440d-06, 3.3446230d-09 /
      data fpppp(14,15,16,1),fpppp(14,15,16,2),fpppp(14,15,16,3)/
     x-3.4352999d-06, 2.7908712d-06, 3.8528456d-09 /
      data fpppp(14,15,17,1),fpppp(14,15,17,2),fpppp(14,15,17,3)/
     x-3.8210640d-06,-1.1517975d-07, 2.4036735d-09 /
      data fpppp(14,15,18,1),fpppp(14,15,18,2),fpppp(14,15,18,3)/
     x-4.1300695d-06,-1.3251465d-06, 2.1822413d-09 /
      data fpppp(14,15,19,1),fpppp(14,15,19,2),fpppp(14,15,19,3)/
     x-6.1903461d-06,-6.7970610d-07, 2.9618053d-10 /
      data fpppp(14,15,20,1),fpppp(14,15,20,2),fpppp(14,15,20,3)/
     x-1.9099357d-06,-3.0921284d-06,-8.3318789d-10 /
      data fpppp(14,15,21,1),fpppp(14,15,21,2),fpppp(14,15,21,3)/
     x-1.9099357d-06,-3.0080507d-06,-8.9769844d-10 /
      data fpppp(14,15,22,1),fpppp(14,15,22,2),fpppp(14,15,22,3)/
     x-6.1903461d-06,-1.0160170d-06, 5.5422271d-10 /
      data fpppp(14,15,23,1),fpppp(14,15,23,2),fpppp(14,15,23,3)/
     x-4.1300695d-06,-6.3980569d-08, 1.2145831d-09 /
      data fpppp(14,16, 1,1),fpppp(14,16, 1,2),fpppp(14,16, 1,3)/
     x 1.3766454d-02,-1.9630807d-03, 2.7708242d-07 /
      data fpppp(14,16, 2,1),fpppp(14,16, 2,2),fpppp(14,16, 2,3)/
     x 5.6051121d-03,-1.2724872d-03, 1.2891717d-07 /
      data fpppp(14,16, 3,1),fpppp(14,16, 3,2),fpppp(14,16, 3,3)/
     x 1.0359654d-03,-8.7941526d-05,-1.5837599d-07 /
      data fpppp(14,16, 4,1),fpppp(14,16, 4,2),fpppp(14,16, 4,3)/
     x 1.0359654d-03, 4.2882921d-04,-2.1123267d-07 /
      data fpppp(14,16, 5,1),fpppp(14,16, 5,2),fpppp(14,16, 5,3)/
     x 5.6051121d-03,-3.3395701d-03, 3.4034386d-07 /
      data fpppp(14,16, 6,1),fpppp(14,16, 6,2),fpppp(14,16, 6,3)/
     x 1.3766454d-02, 5.7884803d-03,-5.1576768d-07 /
      data fpppp(14,16, 7,1),fpppp(14,16, 7,2),fpppp(14,16, 7,3)/
     x-7.3592622d-03, 2.0107144d-03,-6.4777926d-07 /
      data fpppp(14,16, 8,1),fpppp(14,16, 8,2),fpppp(14,16, 8,3)/
     x 6.9085358d-03,-3.7304183d-02, 1.2415113d-06 /
      data fpppp(14,16, 9,1),fpppp(14,16, 9,2),fpppp(14,16, 9,3)/
     x 7.0845726d-02, 6.7321808d-02,-1.2910755d-07 /
      data fpppp(14,16,10,1),fpppp(14,16,10,2),fpppp(14,16,10,3)/
     x 1.0875679d-04,-4.4171571d-02, 1.6633262d-08 /
      data fpppp(14,16,11,1),fpppp(14,16,11,2),fpppp(14,16,11,3)/
     x 2.9064757d-05, 1.1738967d-02,-2.1789335d-08 /
      data fpppp(14,16,12,1),fpppp(14,16,12,2),fpppp(14,16,12,3)/
     x 7.3393764d-06,-3.1767096d-03, 2.7396261d-09 /
      data fpppp(14,16,13,1),fpppp(14,16,13,2),fpppp(14,16,13,3)/
     x 2.0593164d-06, 8.4288210d-04, 3.0791963d-09 /
      data fpppp(14,16,14,1),fpppp(14,16,14,2),fpppp(14,16,14,3)/
     x 1.3970834d-07,-2.2767441d-04, 4.6816980d-09 /
      data fpppp(14,16,15,1),fpppp(14,16,15,2),fpppp(14,16,15,3)/
     x-7.5404926d-07, 6.1493773d-05, 4.4352236d-09 /
      data fpppp(14,16,16,1),fpppp(14,16,16,2),fpppp(14,16,16,3)/
     x-2.4297398d-07,-1.5597141d-05, 3.6671903d-09 /
      data fpppp(14,16,17,1),fpppp(14,16,17,2),fpppp(14,16,17,3)/
     x 8.8773081d-07, 5.0157628d-06, 2.7507403d-09 /
      data fpppp(14,16,18,1),fpppp(14,16,18,2),fpppp(14,16,18,3)/
     x 1.3585187d-06,-4.0525429d-06,-1.1948269d-11 /
      data fpppp(14,16,19,1),fpppp(14,16,19,2),fpppp(14,16,19,3)/
     x 7.0173104d-06, 2.8461686d-06,-2.2498472d-09 /
      data fpppp(14,16,20,1),fpppp(14,16,20,2),fpppp(14,16,20,3)/
     x 2.1429398d-06,-2.6585372d-06,-2.5822524d-09 /
      data fpppp(14,16,21,1),fpppp(14,16,21,2),fpppp(14,16,21,3)/
     x 2.1429398d-06,-2.2091270d-06,-2.6811184d-09 /
      data fpppp(14,16,22,1),fpppp(14,16,22,2),fpppp(14,16,22,3)/
     x 7.0173104d-06, 1.0485279d-06,-1.8543833d-09 /
      data fpppp(14,16,23,1),fpppp(14,16,23,2),fpppp(14,16,23,3)/
     x 1.3585187d-06, 2.6886096d-06,-1.4949378d-09 /
      data fpppp(14,17, 1,1),fpppp(14,17, 1,2),fpppp(14,17, 1,3)/
     x-1.5659332d-02,-1.6446160d-03,-1.1728774d-07 /
      data fpppp(14,17, 2,1),fpppp(14,17, 2,2),fpppp(14,17, 2,3)/
     x-7.8990701d-03,-7.5299287d-04,-1.4276449d-07 /
      data fpppp(14,17, 3,1),fpppp(14,17, 3,2),fpppp(14,17, 3,3)/
     x-1.2509646d-03, 1.5837124d-03,-2.6047453d-07 /
      data fpppp(14,17, 4,1),fpppp(14,17, 4,2),fpppp(14,17, 4,3)/
     x-1.2509646d-03, 8.3806499d-04,-1.5001976d-07 /
      data fpppp(14,17, 5,1),fpppp(14,17, 5,2),fpppp(14,17, 5,3)/
     x-7.8990701d-03, 2.2295966d-03,-5.8458356d-07 /
      data fpppp(14,17, 6,1),fpppp(14,17, 6,2),fpppp(14,17, 6,3)/
     x-1.5659332d-02,-1.2829327d-02, 1.5395338d-06 /
      data fpppp(14,17, 7,1),fpppp(14,17, 7,2),fpppp(14,17, 7,3)/
     x 7.5719678d-03, 1.5885639d-02, 7.0248316d-07 /
      data fpppp(14,17, 8,1),fpppp(14,17, 8,2),fpppp(14,17, 8,3)/
     x-7.0066335d-03,-1.0117951d-02,-1.0532443d-06 /
      data fpppp(14,17, 9,1),fpppp(14,17, 9,2),fpppp(14,17, 9,3)/
     x-4.4075709d-02, 4.2901057d-03,-1.1276540d-07 /
      data fpppp(14,17,10,1),fpppp(14,17,10,2),fpppp(14,17,10,3)/
     x-3.7942311d-05,-1.1698006d-03,-1.3372026d-07 /
      data fpppp(14,17,11,1),fpppp(14,17,11,2),fpppp(14,17,11,3)/
     x 1.0875332d-05, 2.8378214d-04,-4.5479444d-08 /
      data fpppp(14,17,12,1),fpppp(14,17,12,2),fpppp(14,17,12,3)/
     x 1.3843528d-05,-8.9573401d-05,-2.8422303d-08 /
      data fpppp(14,17,13,1),fpppp(14,17,13,2),fpppp(14,17,13,3)/
     x 8.3341509d-06, 1.9987262d-05,-1.0533599d-08 /
      data fpppp(14,17,14,1),fpppp(14,17,14,2),fpppp(14,17,14,3)/
     x 3.7854795d-06,-8.3008861d-06,-3.5635632d-09 /
      data fpppp(14,17,15,1),fpppp(14,17,15,2),fpppp(14,17,15,3)/
     x 2.1815138d-06, 2.4778007d-06, 4.3598656d-10 /
      data fpppp(14,17,16,1),fpppp(14,17,16,2),fpppp(14,17,16,3)/
     x 1.8852433d-06,-8.5679112d-07, 1.1415985d-09 /
      data fpppp(14,17,17,1),fpppp(14,17,17,2),fpppp(14,17,17,3)/
     x 2.3088856d-06,-7.6199779d-07, 1.7903971d-10 /
      data fpppp(14,17,18,1),fpppp(14,17,18,2),fpppp(14,17,18,3)/
     x 3.5961939d-06, 2.0272692d-06,-1.6203504d-09 /
      data fpppp(14,17,19,1),fpppp(14,17,19,2),fpppp(14,17,19,3)/
     x 7.3510632d-07,-3.0957396d-06,-2.2588572d-09 /
      data fpppp(14,17,20,1),fpppp(14,17,20,2),fpppp(14,17,20,3)/
     x 7.1671659d-06, 3.4016226d-07,-3.8236391d-09 /
      data fpppp(14,17,21,1),fpppp(14,17,21,2),fpppp(14,17,21,3)/
     x 7.1671659d-06, 2.0869713d-08,-3.8192851d-09 /
      data fpppp(14,17,22,1),fpppp(14,17,22,2),fpppp(14,17,22,3)/
     x 7.3510632d-07,-1.8185694d-06,-2.2762733d-09 /
      data fpppp(14,17,23,1),fpppp(14,17,23,2),fpppp(14,17,23,3)/
     x 3.5961939d-06,-2.7621190d-06,-1.5550400d-09 /
      data fpppp(14,18, 1,1),fpppp(14,18, 1,2),fpppp(14,18, 1,3)/
     x 4.6621078d-03,-1.6300240d-04, 1.2029000d-07 /
      data fpppp(14,18, 2,1),fpppp(14,18, 2,2),fpppp(14,18, 2,3)/
     x 2.8082545d-03,-4.1200299d-05, 1.4535785d-07 /
      data fpppp(14,18, 3,1),fpppp(14,18, 3,2),fpppp(14,18, 3,3)/
     x 7.3550936d-04, 2.4770136d-04, 2.2718438d-07 /
      data fpppp(14,18, 4,1),fpppp(14,18, 4,2),fpppp(14,18, 4,3)/
     x 7.3550936d-04, 1.9888133d-04, 1.7799238d-07 /
      data fpppp(14,18, 5,1),fpppp(14,18, 5,2),fpppp(14,18, 5,3)/
     x 2.8082545d-03, 1.5407984d-04, 3.4212585d-07 /
      data fpppp(14,18, 6,1),fpppp(14,18, 6,2),fpppp(14,18, 6,3)/
     x 4.6621078d-03,-8.9530292d-04,-6.1759000d-07 /
      data fpppp(14,18, 7,1),fpppp(14,18, 7,2),fpppp(14,18, 7,3)/
     x-2.8406062d-03, 5.2054818d-04,-2.0599864d-07 /
      data fpppp(14,18, 8,1),fpppp(14,18, 8,2),fpppp(14,18, 8,3)/
     x 1.9298502d-03,-9.6405504d-05, 2.2438967d-07 /
      data fpppp(14,18, 9,1),fpppp(14,18, 9,2),fpppp(14,18, 9,3)/
     x 7.8342697d-03,-1.3721193d-06, 3.1998288d-09 /
      data fpppp(14,18,10,1),fpppp(14,18,10,2),fpppp(14,18,10,3)/
     x-4.4384299d-05, 5.8908705d-06, 1.3721349d-08 /
      data fpppp(14,18,11,1),fpppp(14,18,11,2),fpppp(14,18,11,3)/
     x-1.7406739d-05,-1.9950787d-07,-2.3778283d-09 /
      data fpppp(14,18,12,1),fpppp(14,18,12,2),fpppp(14,18,12,3)/
     x-5.7851225d-06,-1.9606217d-06,-1.9842246d-09 /
      data fpppp(14,18,13,1),fpppp(14,18,13,2),fpppp(14,18,13,3)/
     x 4.0090253d-07, 1.0816514d-06,-2.9646297d-09 /
      data fpppp(14,18,14,1),fpppp(14,18,14,2),fpppp(14,18,14,3)/
     x 3.2255240d-06,-1.5190169d-06,-2.4543253d-09 /
      data fpppp(14,18,15,1),fpppp(14,18,15,2),fpppp(14,18,15,3)/
     x 5.0873803d-06, 1.6811383d-06,-2.8118222d-09 /
      data fpppp(14,18,16,1),fpppp(14,18,16,2),fpppp(14,18,16,3)/
     x 5.5919367d-06,-1.1237106d-06,-3.1960950d-09 /
      data fpppp(14,18,17,1),fpppp(14,18,17,2),fpppp(14,18,17,3)/
     x 6.8928246d-06,-4.3438072d-07,-4.3042037d-09 /
      data fpppp(14,18,18,1),fpppp(14,18,18,2),fpppp(14,18,18,3)/
     x 8.2180452d-06, 1.5119196d-06,-5.2749208d-09 /
      data fpppp(14,18,19,1),fpppp(14,18,19,2),fpppp(14,18,19,3)/
     x 9.1820475d-06,-5.2917660d-07,-7.0443362d-09 /
      data fpppp(14,18,20,1),fpppp(14,18,20,2),fpppp(14,18,20,3)/
     x 7.2676334d-06,-3.3885180d-07,-7.1964719d-09 /
      data fpppp(14,18,21,1),fpppp(14,18,21,2),fpppp(14,18,21,3)/
     x 7.2676334d-06,-4.3995533d-07,-7.2770930d-09 /
      data fpppp(14,18,22,1),fpppp(14,18,22,2),fpppp(14,18,22,3)/
     x 9.1820475d-06,-1.2476247d-07,-6.7218517d-09 /
      data fpppp(14,18,23,1),fpppp(14,18,23,2),fpppp(14,18,23,3)/
     x 8.2180452d-06,-4.6334104d-09,-6.4842380d-09 /
      data fpppp(14,19, 1,1),fpppp(14,19, 1,2),fpppp(14,19, 1,3)/
     x 1.0770055d-02, 6.2859119d-18, 1.7731119d-07 /
      data fpppp(14,19, 2,1),fpppp(14,19, 2,2),fpppp(14,19, 2,3)/
     x 6.5980058d-03,-1.3427211d-17, 2.7353619d-07 /
      data fpppp(14,19, 3,1),fpppp(14,19, 3,2),fpppp(14,19, 3,3)/
     x 1.5010108d-03, 3.6046807d-18, 5.4634117d-07 /
      data fpppp(14,19, 4,1),fpppp(14,19, 4,2),fpppp(14,19, 4,3)/
     x 1.5010108d-03, 5.7250926d-18, 4.2977617d-07 /
      data fpppp(14,19, 5,1),fpppp(14,19, 5,2),fpppp(14,19, 5,3)/
     x 6.5980058d-03,-7.1957303d-18, 7.3979616d-07 /
      data fpppp(14,19, 6,1),fpppp(14,19, 6,2),fpppp(14,19, 6,3)/
     x 1.0770055d-02,-6.9988827d-18,-1.5711637d-06 /
      data fpppp(14,19, 7,1),fpppp(14,19, 7,2),fpppp(14,19, 7,3)/
     x-6.0120933d-03,-2.0060794d-18,-4.6912494d-07 /
      data fpppp(14,19, 8,1),fpppp(14,19, 8,2),fpppp(14,19, 8,3)/
     x 4.3372902d-03,-1.8067983d-18, 4.8134092d-07 /
      data fpppp(14,19, 9,1),fpppp(14,19, 9,2),fpppp(14,19, 9,3)/
     x 1.2078130d-02, 5.1654348d-18, 9.0701318d-08 /
      data fpppp(14,19,10,1),fpppp(14,19,10,2),fpppp(14,19,10,3)/
     x-9.0899746d-05,-2.8657082d-18, 7.6078636d-08 /
      data fpppp(14,19,11,1),fpppp(14,19,11,2),fpppp(14,19,11,3)/
     x-4.2805197d-05,-7.6552467d-18, 2.1640437d-08 /
      data fpppp(14,19,12,1),fpppp(14,19,12,2),fpppp(14,19,12,3)/
     x-1.7947258d-05,-4.3603837d-19, 7.9967085d-09 /
      data fpppp(14,19,13,1),fpppp(14,19,13,2),fpppp(14,19,13,3)/
     x-3.4728936d-06,-3.7628788d-18,-1.4475932d-09 /
      data fpppp(14,19,14,1),fpppp(14,19,14,2),fpppp(14,19,14,3)/
     x 3.8672047d-06, 7.1472950d-19,-4.0178014d-09 /
      data fpppp(14,19,15,1),fpppp(14,19,15,2),fpppp(14,19,15,3)/
     x 8.0017316d-06,-1.6081756d-18,-6.2743248d-09 /
      data fpppp(14,19,16,1),fpppp(14,19,16,2),fpppp(14,19,16,3)/
     x 8.8476369d-06,-1.7966610d-18,-7.0160451d-09 /
      data fpppp(14,19,17,1),fpppp(14,19,17,2),fpppp(14,19,17,3)/
     x 1.0573111d-05,-7.2788441d-18,-8.2412920d-09 /
      data fpppp(14,19,18,1),fpppp(14,19,18,2),fpppp(14,19,18,3)/
     x 1.2158703d-05,-1.8888253d-18,-8.3448717d-09 /
      data fpppp(14,19,19,1),fpppp(14,19,19,2),fpppp(14,19,19,3)/
     x 1.3420662d-05,-6.3083312d-18,-1.0465110d-08 /
      data fpppp(14,19,20,1),fpppp(14,19,20,2),fpppp(14,19,20,3)/
     x 8.7748891d-06, 4.6523535d-18,-9.9603201d-09 /
      data fpppp(14,19,21,1),fpppp(14,19,21,2),fpppp(14,19,21,3)/
     x 8.7748891d-06,-3.5862939d-18,-1.0072146d-08 /
      data fpppp(14,19,22,1),fpppp(14,19,22,2),fpppp(14,19,22,3)/
     x 1.3420662d-05, 7.6723086d-18,-1.0017805d-08 /
      data fpppp(14,19,23,1),fpppp(14,19,23,2),fpppp(14,19,23,3)/
     x 1.2158703d-05,-6.9471421d-18,-1.0022266d-08 /
      data fpppp(15, 1, 1,1),fpppp(15, 1, 1,2),fpppp(15, 1, 1,3)/
     x 3.1722951d-02, 8.0782034d-17,-2.0377186d-05 /
      data fpppp(15, 1, 2,1),fpppp(15, 1, 2,2),fpppp(15, 1, 2,3)/
     x 5.0603009d-02, 4.2314997d-17,-1.4322364d-05 /
      data fpppp(15, 1, 3,1),fpppp(15, 1, 3,2),fpppp(15, 1, 3,3)/
     x 5.5584341d-02,-3.8226334d-17,-2.8349767d-06 /
      data fpppp(15, 1, 4,1),fpppp(15, 1, 4,2),fpppp(15, 1, 4,3)/
     x 5.5584341d-02, 1.6580442d-17,-2.3231987d-07 /
      data fpppp(15, 1, 5,1),fpppp(15, 1, 5,2),fpppp(15, 1, 5,3)/
     x 5.0603009d-02,-1.1656492d-17,-2.4732991d-05 /
      data fpppp(15, 1, 6,1),fpppp(15, 1, 6,2),fpppp(15, 1, 6,3)/
     x 3.1722951d-02,-4.2689097d-19, 1.8662666d-05 /
      data fpppp(15, 1, 7,1),fpppp(15, 1, 7,2),fpppp(15, 1, 7,3)/
     x 3.2294481d-02, 2.5073574d-17, 4.8496948d-06 /
      data fpppp(15, 1, 8,1),fpppp(15, 1, 8,2),fpppp(15, 1, 8,3)/
     x 2.7238870d-02, 2.3536622d-17, 6.3154583d-07 /
      data fpppp(15, 1, 9,1),fpppp(15, 1, 9,2),fpppp(15, 1, 9,3)/
     x 2.6048296d-02,-6.4104179d-18, 1.0875640d-06 /
      data fpppp(15, 1,10,1),fpppp(15, 1,10,2),fpppp(15, 1,10,3)/
     x 2.6186876d-02,-2.3231466d-17, 2.5621726d-07 /
      data fpppp(15, 1,11,1),fpppp(15, 1,11,2),fpppp(15, 1,11,3)/
     x-5.7948064d-04,-6.9534963d-17, 2.9969003d-07 /
      data fpppp(15, 1,12,1),fpppp(15, 1,12,2),fpppp(15, 1,12,3)/
     x 4.8492484d-03,-4.5283269d-17, 2.5083793d-07 /
      data fpppp(15, 1,13,1),fpppp(15, 1,13,2),fpppp(15, 1,13,3)/
     x 3.1588594d-02,-9.5207920d-18, 3.0324575d-07 /
      data fpppp(15, 1,14,1),fpppp(15, 1,14,2),fpppp(15, 1,14,3)/
     x 2.6149202d-02,-5.8330653d-17, 3.0220062d-07 /
      data fpppp(15, 1,15,1),fpppp(15, 1,15,2),fpppp(15, 1,15,3)/
     x 2.4302209d-02, 2.5744994d-17, 1.0254426d-06 /
      data fpppp(15, 1,16,1),fpppp(15, 1,16,2),fpppp(15, 1,16,3)/
     x 2.6153241d-02, 8.6670761d-17, 9.6841284d-07 /
      data fpppp(15, 1,17,1),fpppp(15, 1,17,2),fpppp(15, 1,17,3)/
     x 2.8002429d-02, 6.0971591d-17, 4.2766761d-06 /
      data fpppp(15, 1,18,1),fpppp(15, 1,18,2),fpppp(15, 1,18,3)/
     x 3.1772032d-02, 2.2288782d-17, 1.9244597d-05 /
      data fpppp(15, 1,19,1),fpppp(15, 1,19,2),fpppp(15, 1,19,3)/
     x 3.1739863d-02,-3.5407979d-18,-2.6113727d-05 /
      data fpppp(15, 1,20,1),fpppp(15, 1,20,2),fpppp(15, 1,20,3)/
     x 5.2140886d-02, 1.9394714d-17, 5.4567091d-07 /
      data fpppp(15, 1,21,1),fpppp(15, 1,21,2),fpppp(15, 1,21,3)/
     x 5.2140886d-02, 2.2901119d-17,-2.1979704d-06 /
      data fpppp(15, 1,22,1),fpppp(15, 1,22,2),fpppp(15, 1,22,3)/
     x 3.1739863d-02,-2.0913876d-17,-1.5139162d-05 /
      data fpppp(15, 1,23,1),fpppp(15, 1,23,2),fpppp(15, 1,23,3)/
     x 3.1772032d-02, 1.0427888d-16,-2.1910023d-05 /
      data fpppp(15, 2, 1,1),fpppp(15, 2, 1,2),fpppp(15, 2, 1,3)/
     x 1.6922734d-02, 2.8936587d-04,-8.2895358d-06 /
      data fpppp(15, 2, 2,1),fpppp(15, 2, 2,2),fpppp(15, 2, 2,3)/
     x 2.4512345d-02, 1.2385780d-04,-5.7418320d-06 /
      data fpppp(15, 2, 3,1),fpppp(15, 2, 3,2),fpppp(15, 2, 3,3)/
     x 2.6314932d-02,-2.2357213d-04,-8.6376155d-07 /
      data fpppp(15, 2, 4,1),fpppp(15, 2, 4,2),fpppp(15, 2, 4,3)/
     x 2.6314932d-02,-2.3622502d-04, 1.5350415d-07 /
      data fpppp(15, 2, 5,1),fpppp(15, 2, 5,2),fpppp(15, 2, 5,3)/
     x 2.4512345d-02, 1.7446938d-04,-9.8108948d-06 /
      data fpppp(15, 2, 6,1),fpppp(15, 2, 6,2),fpppp(15, 2, 6,3)/
     x 1.6922734d-02, 9.9572443d-05, 6.9694497d-06 /
      data fpppp(15, 2, 7,1),fpppp(15, 2, 7,2),fpppp(15, 2, 7,3)/
     x 1.8367624d-02,-7.7731813d-04, 2.2040378d-06 /
      data fpppp(15, 2, 8,1),fpppp(15, 2, 8,2),fpppp(15, 2, 8,3)/
     x 1.5396056d-02, 1.9839055d-03, 9.9856333d-08 /
      data fpppp(15, 2, 9,1),fpppp(15, 2, 9,2),fpppp(15, 2, 9,3)/
     x 1.4862318d-02,-3.9573101d-03, 4.5499261d-07 /
      data fpppp(15, 2,10,1),fpppp(15, 2,10,2),fpppp(15, 2,10,3)/
     x 1.4957581d-02, 1.2269635d-02, 5.7254958d-08 /
      data fpppp(15, 2,11,1),fpppp(15, 2,11,2),fpppp(15, 2,11,3)/
     x 1.9066853d-03,-1.1282208d-02, 8.0681393d-08 /
      data fpppp(15, 2,12,1),fpppp(15, 2,12,2),fpppp(15, 2,12,3)/
     x 4.5608022d-03,-7.0589703d-03, 5.4748826d-08 /
      data fpppp(15, 2,13,1),fpppp(15, 2,13,2),fpppp(15, 2,13,3)/
     x 1.7607665d-02, 1.3100358d-02, 8.1388276d-08 /
      data fpppp(15, 2,14,1),fpppp(15, 2,14,2),fpppp(15, 2,14,3)/
     x 1.4940731d-02,-5.1553340d-03, 8.1854968d-08 /
      data fpppp(15, 2,15,1),fpppp(15, 2,15,2),fpppp(15, 2,15,3)/
     x 1.4115702d-02, 1.2433871d-03, 4.1367020d-07 /
      data fpppp(15, 2,16,1),fpppp(15, 2,16,2),fpppp(15, 2,16,3)/
     x 1.4880664d-02,-1.5145052d-04, 3.0655642d-07 /
      data fpppp(15, 2,17,1),fpppp(15, 2,17,2),fpppp(15, 2,17,3)/
     x 1.5580367d-02, 7.0339337d-05, 1.8792840d-06 /
      data fpppp(15, 2,18,1),fpppp(15, 2,18,2),fpppp(15, 2,18,3)/
     x 1.6979068d-02, 6.4888879d-05, 7.2749191d-06 /
      data fpppp(15, 2,19,1),fpppp(15, 2,19,2),fpppp(15, 2,19,3)/
     x 1.6544367d-02, 1.3239730d-06,-1.0239634d-05 /
      data fpppp(15, 2,20,1),fpppp(15, 2,20,2),fpppp(15, 2,20,3)/
     x 2.5367403d-02,-1.8368617d-04, 3.7076186d-07 /
      data fpppp(15, 2,21,1),fpppp(15, 2,21,2),fpppp(15, 2,21,3)/
     x 2.5367403d-02,-1.8260517d-04,-6.9566560d-07 /
      data fpppp(15, 2,22,1),fpppp(15, 2,22,2),fpppp(15, 2,22,3)/
     x 1.6544367d-02,-3.0000452d-06,-5.9739246d-06 /
      data fpppp(15, 2,23,1),fpppp(15, 2,23,2),fpppp(15, 2,23,3)/
     x 1.6979068d-02, 8.1103947d-05,-8.7214928d-06 /
      data fpppp(15, 3, 1,1),fpppp(15, 3, 1,2),fpppp(15, 3, 1,3)/
     x-7.5985243d-03,-4.0508724d-03, 1.9723643d-05 /
      data fpppp(15, 3, 2,1),fpppp(15, 3, 2,2),fpppp(15, 3, 2,3)/
     x-2.5531074d-02,-3.1578281d-03, 1.2552215d-05 /
      data fpppp(15, 3, 3,1),fpppp(15, 3, 3,2),fpppp(15, 3, 3,3)/
     x-2.5924885d-02,-1.7034496d-03,-1.7800228d-06 /
      data fpppp(15, 3, 4,1),fpppp(15, 3, 4,2),fpppp(15, 3, 4,3)/
     x-2.5924885d-02,-8.9969619d-04,-3.5914613d-06 /
      data fpppp(15, 3, 5,1),fpppp(15, 3, 5,2),fpppp(15, 3, 5,3)/
     x-2.5531074d-02,-6.3728418d-03, 1.9797969d-05 /
      data fpppp(15, 3, 6,1),fpppp(15, 3, 6,2),fpppp(15, 3, 6,3)/
     x-7.5985243d-03, 8.0054290d-03,-7.4479360d-06 /
      data fpppp(15, 3, 7,1),fpppp(15, 3, 7,2),fpppp(15, 3, 7,3)/
     x-2.0361702d-02,-1.1641281d-03,-6.5476015d-06 /
      data fpppp(15, 3, 8,1),fpppp(15, 3, 8,2),fpppp(15, 3, 8,3)/
     x-3.1698298d-03, 1.2615727d-03, 1.0368817d-06 /
      data fpppp(15, 3, 9,1),fpppp(15, 3, 9,2),fpppp(15, 3, 9,3)/
     x-2.4291495d-03,-3.1501078d-04,-1.4171505d-06 /
      data fpppp(15, 3,10,1),fpppp(15, 3,10,2),fpppp(15, 3,10,3)/
     x-2.1913994d-03, 1.8929736d-04,-1.5974577d-07 /
      data fpppp(15, 3,11,1),fpppp(15, 3,11,2),fpppp(15, 3,11,3)/
     x 1.0310074d-02, 1.0018861d-05,-3.5728485d-07 /
      data fpppp(15, 3,12,1),fpppp(15, 3,12,2),fpppp(15, 3,12,3)/
     x 7.8051091d-03,-5.7011429d-05,-2.8264757d-07 /
      data fpppp(15, 3,13,1),fpppp(15, 3,13,2),fpppp(15, 3,13,3)/
     x-4.6064149d-03, 3.5760658d-04,-3.4307228d-07 /
      data fpppp(15, 3,14,1),fpppp(15, 3,14,2),fpppp(15, 3,14,3)/
     x-2.1471349d-03,-1.1622778d-03,-2.4107246d-07 /
      data fpppp(15, 3,15,1),fpppp(15, 3,15,2),fpppp(15, 3,15,3)/
     x-4.9149246d-04, 1.8927042d-03,-1.1313621d-06 /
      data fpppp(15, 3,16,1),fpppp(15, 3,16,2),fpppp(15, 3,16,3)/
     x-2.5790359d-03,-7.6020822d-04, 5.0048217d-08 /
      data fpppp(15, 3,17,1),fpppp(15, 3,17,2),fpppp(15, 3,17,3)/
     x-4.6875550d-03, 2.2801252d-03,-4.8202803d-06 /
      data fpppp(15, 3,18,1),fpppp(15, 3,18,2),fpppp(15, 3,18,3)/
     x-7.6779362d-03,-4.1361634d-03,-8.5746875d-06 /
      data fpppp(15, 3,19,1),fpppp(15, 3,19,2),fpppp(15, 3,19,3)/
     x-3.8990938d-03, 1.0560816d-02, 2.0249509d-05 /
      data fpppp(15, 3,20,1),fpppp(15, 3,20,2),fpppp(15, 3,20,3)/
     x-2.5469563d-02,-6.2192780d-03,-3.7744393d-06 /
      data fpppp(15, 3,21,1),fpppp(15, 3,21,2),fpppp(15, 3,21,3)/
     x-2.5469563d-02,-5.1499256d-03,-1.8740261d-06 /
      data fpppp(15, 3,22,1),fpppp(15, 3,22,2),fpppp(15, 3,22,3)/
     x-3.8990938d-03, 6.2834064d-03, 1.2647856d-05 /
      data fpppp(15, 3,23,1),fpppp(15, 3,23,2),fpppp(15, 3,23,3)/
     x-7.6779362d-03, 1.1904122d-02, 1.9931511d-05 /
      data fpppp(15, 4, 1,1),fpppp(15, 4, 1,2),fpppp(15, 4, 1,3)/
     x 1.9038628d-03, 5.9585537d-03,-8.0025276d-06 /
      data fpppp(15, 4, 2,1),fpppp(15, 4, 2,2),fpppp(15, 4, 2,3)/
     x 8.2601477d-03, 2.8817251d-03,-3.1510418d-06 /
      data fpppp(15, 4, 3,1),fpppp(15, 4, 3,2),fpppp(15, 4, 3,3)/
     x 2.2317263d-03,-2.8347287d-03, 7.4098833d-06 /
      data fpppp(15, 4, 4,1),fpppp(15, 4, 4,2),fpppp(15, 4, 4,3)/
     x 2.2317263d-03,-4.3690414d-03, 7.1213365d-06 /
      data fpppp(15, 4, 5,1),fpppp(15, 4, 5,2),fpppp(15, 4, 5,3)/
     x 8.2601477d-03, 9.0189761d-03,-1.9968545d-06 /
      data fpppp(15, 4, 6,1),fpppp(15, 4, 6,2),fpppp(15, 4, 6,3)/
     x 1.9038628d-03,-1.7056137d-02,-1.2330730d-05 /
      data fpppp(15, 4, 7,1),fpppp(15, 4, 7,2),fpppp(15, 4, 7,3)/
     x 2.7717612d-02, 2.6801252d-02, 6.0716973d-06 /
      data fpppp(15, 4, 8,1),fpppp(15, 4, 8,2),fpppp(15, 4, 8,3)/
     x 1.7950354d-03,-1.6234685d-02,-3.1665950d-06 /
      data fpppp(15, 4, 9,1),fpppp(15, 4, 9,2),fpppp(15, 4, 9,3)/
     x 1.6485955d-03, 4.4799970d-03, 1.0492074d-06 /
      data fpppp(15, 4,10,1),fpppp(15, 4,10,2),fpppp(15, 4,10,3)/
     x 1.3785182d-03,-1.2343073d-03,-3.1361201d-07 /
      data fpppp(15, 4,11,1),fpppp(15, 4,11,2),fpppp(15, 4,11,3)/
     x-1.9968163d-03, 3.2608222d-04,-2.8899478d-08 /
      data fpppp(15, 4,12,1),fpppp(15, 4,12,2),fpppp(15, 4,12,3)/
     x-1.3152199d-03,-7.0938649d-05,-1.2546846d-07 /
      data fpppp(15, 4,13,1),fpppp(15, 4,13,2),fpppp(15, 4,13,3)/
     x 1.9955329d-03, 5.0227481d-05,-5.8422054d-08 /
      data fpppp(15, 4,14,1),fpppp(15, 4,14,2),fpppp(15, 4,14,3)/
     x 1.3428838d-03,-8.8809253d-05,-2.0496366d-07 /
      data fpppp(15, 4,15,1),fpppp(15, 4,15,2),fpppp(15, 4,15,3)/
     x 3.7372093d-04, 9.5840255d-05, 5.9001521d-07 /
      data fpppp(15, 4,16,1),fpppp(15, 4,16,2),fpppp(15, 4,16,3)/
     x 1.6161913d-03, 1.6422664d-04,-1.6251788d-06 /
      data fpppp(15, 4,17,1),fpppp(15, 4,17,2),fpppp(15, 4,17,3)/
     x 2.5050342d-03, 3.0053376d-04, 3.5377582d-06 /
      data fpppp(15, 4,18,1),fpppp(15, 4,18,2),fpppp(15, 4,18,3)/
     x 2.1891986d-03, 2.8539713d-03,-1.0844544d-05 /
      data fpppp(15, 4,19,1),fpppp(15, 4,19,2),fpppp(15, 4,19,3)/
     x-5.9746767d-03,-2.0596085d-03,-4.1402409d-07 /
      data fpppp(15, 4,20,1),fpppp(15, 4,20,2),fpppp(15, 4,20,3)/
     x 7.9156598d-03,-8.1169043d-04, 5.9763820d-06 /
      data fpppp(15, 4,21,1),fpppp(15, 4,21,2),fpppp(15, 4,21,3)/
     x 7.9156598d-03,-1.0725737d-03, 6.3299420d-06 /
      data fpppp(15, 4,22,1),fpppp(15, 4,22,2),fpppp(15, 4,22,3)/
     x-5.9746767d-03,-1.0160753d-03,-1.8282640d-06 /
      data fpppp(15, 4,23,1),fpppp(15, 4,23,2),fpppp(15, 4,23,3)/
     x 2.1891986d-03,-1.0592782d-03,-5.5411441d-06 /
      data fpppp(15, 5, 1,1),fpppp(15, 5, 1,2),fpppp(15, 5, 1,3)/
     x 2.2770096d-03, 4.2877109d-03,-2.8709409d-06 /
      data fpppp(15, 5, 2,1),fpppp(15, 5, 2,2),fpppp(15, 5, 2,3)/
     x 6.2335804d-03, 2.4830688d-03,-2.9099804d-06 /
      data fpppp(15, 5, 3,1),fpppp(15, 5, 3,2),fpppp(15, 5, 3,3)/
     x 7.6008494d-03,-1.1222904d-03,-3.6022514d-06 /
      data fpppp(15, 5, 4,1),fpppp(15, 5, 4,2),fpppp(15, 5, 4,3)/
     x 7.6008494d-03,-1.5803197d-03,-2.5371749d-06 /
      data fpppp(15, 5, 5,1),fpppp(15, 5, 5,2),fpppp(15, 5, 5,3)/
     x 6.2335804d-03, 4.3151861d-03,-7.1702864d-06 /
      data fpppp(15, 5, 6,1),fpppp(15, 5, 6,2),fpppp(15, 5, 6,3)/
     x 2.2770096d-03,-2.5827288d-03, 1.3105207d-05 /
      data fpppp(15, 5, 7,1),fpppp(15, 5, 7,2),fpppp(15, 5, 7,3)/
     x-1.5708106d-02, 6.7820638d-04,-3.1778201d-06 /
      data fpppp(15, 5, 8,1),fpppp(15, 5, 8,2),fpppp(15, 5, 8,3)/
     x 4.8295711d-06,-2.0441304d-04, 2.0540357d-06 /
      data fpppp(15, 5, 9,1),fpppp(15, 5, 9,2),fpppp(15, 5, 9,3)/
     x-1.5783586d-04, 3.5067500d-05,-6.5611652d-07 /
      data fpppp(15, 5,10,1),fpppp(15, 5,10,2),fpppp(15, 5,10,3)/
     x-1.1885957d-04,-2.0530307d-05, 6.8646495d-08 /
      data fpppp(15, 5,11,1),fpppp(15, 5,11,2),fpppp(15, 5,11,3)/
     x 7.4503560d-04, 1.6963765d-07,-6.7210506d-08 /
      data fpppp(15, 5,12,1),fpppp(15, 5,12,2),fpppp(15, 5,12,3)/
     x 5.4012248d-04,-1.8657736d-06, 3.5617719d-09 /
      data fpppp(15, 5,13,1),fpppp(15, 5,13,2),fpppp(15, 5,13,3)/
     x-3.3108894d-04,-3.4080764d-06,-4.5467748d-08 /
      data fpppp(15, 5,14,1),fpppp(15, 5,14,2),fpppp(15, 5,14,3)/
     x-1.1170917d-04,-5.5276951d-06, 8.9996749d-09 /
      data fpppp(15, 5,15,1),fpppp(15, 5,15,2),fpppp(15, 5,15,3)/
     x 1.6183479d-04,-9.5477742d-06,-3.6668086d-07 /
      data fpppp(15, 5,16,1),fpppp(15, 5,16,2),fpppp(15, 5,16,3)/
     x 4.4979450d-06,-1.4588773d-05, 1.0834428d-06 /
      data fpppp(15, 5,17,1),fpppp(15, 5,17,2),fpppp(15, 5,17,3)/
     x 2.5106949d-04, 1.0889989d-05,-1.7274340d-06 /
      data fpppp(15, 5,18,1),fpppp(15, 5,18,2),fpppp(15, 5,18,3)/
     x 1.9662600d-03,-4.4391424d-05, 1.2265252d-05 /
      data fpppp(15, 5,19,1),fpppp(15, 5,19,2),fpppp(15, 5,19,3)/
     x 7.2342411d-03, 2.1138639d-03,-9.5922900d-06 /
      data fpppp(15, 5,20,1),fpppp(15, 5,20,2),fpppp(15, 5,20,3)/
     x 9.2006686d-04,-1.4058116d-03,-8.0956835d-07 /
      data fpppp(15, 5,21,1),fpppp(15, 5,21,2),fpppp(15, 5,21,3)/
     x 9.2006686d-04,-1.2253953d-03,-2.0416638d-06 /
      data fpppp(15, 5,22,1),fpppp(15, 5,22,2),fpppp(15, 5,22,3)/
     x 7.2342411d-03, 1.3921986d-03,-4.6639080d-06 /
      data fpppp(15, 5,23,1),fpppp(15, 5,23,2),fpppp(15, 5,23,3)/
     x 1.9662600d-03, 2.6618534d-03,-6.2161807d-06 /
      data fpppp(15, 6, 1,1),fpppp(15, 6, 1,2),fpppp(15, 6, 1,3)/
     x-5.7558665d-04, 3.1048749d-04, 9.6303761d-07 /
      data fpppp(15, 6, 2,1),fpppp(15, 6, 2,2),fpppp(15, 6, 2,3)/
     x-3.0818194d-03, 1.6564381d-04, 8.0345055d-07 /
      data fpppp(15, 6, 3,1),fpppp(15, 6, 3,2),fpppp(15, 6, 3,3)/
     x 6.4510409d-03,-1.3121777d-04, 6.0994661d-07 /
      data fpppp(15, 6, 4,1),fpppp(15, 6, 4,2),fpppp(15, 6, 4,3)/
     x 6.4510409d-03,-1.5487378d-04, 3.5012703d-07 /
      data fpppp(15, 6, 5,1),fpppp(15, 6, 5,2),fpppp(15, 6, 5,3)/
     x-3.0818194d-03, 2.6026788d-04, 1.8427288d-06 /
      data fpppp(15, 6, 6,1),fpppp(15, 6, 6,2),fpppp(15, 6, 6,3)/
     x-5.7558665d-04,-4.4352741d-05,-2.9342560d-06 /
      data fpppp(15, 6, 7,1),fpppp(15, 6, 7,2),fpppp(15, 6, 7,3)/
     x 4.2366055d-03, 8.2343384d-06, 8.7788958d-07 /
      data fpppp(15, 6, 8,1),fpppp(15, 6, 8,2),fpppp(15, 6, 8,3)/
     x 3.5632054d-05,-8.6941989d-06,-5.6533534d-07 /
      data fpppp(15, 6, 9,1),fpppp(15, 6, 9,2),fpppp(15, 6, 9,3)/
     x 8.8541634d-05, 2.8931303d-06, 1.5546190d-07 /
      data fpppp(15, 6,10,1),fpppp(15, 6,10,2),fpppp(15, 6,10,3)/
     x 8.2199718d-05, 4.5707073d-07,-1.4119216d-08 /
      data fpppp(15, 6,11,1),fpppp(15, 6,11,2),fpppp(15, 6,11,3)/
     x-1.4691225d-04, 4.3083397d-06, 2.5719305d-08 /
      data fpppp(15, 6,12,1),fpppp(15, 6,12,2),fpppp(15, 6,12,3)/
     x-9.3198479d-05, 4.3150844d-06, 7.5754026d-09 /
      data fpppp(15, 6,13,1),fpppp(15, 6,13,2),fpppp(15, 6,13,3)/
     x 1.3536314d-04, 3.2842477d-06, 2.5459109d-08 /
      data fpppp(15, 6,14,1),fpppp(15, 6,14,2),fpppp(15, 6,14,3)/
     x 6.8808568d-05, 3.1809384d-06, 1.3426672d-08 /
      data fpppp(15, 6,15,1),fpppp(15, 6,15,2),fpppp(15, 6,15,3)/
     x-1.8971419d-05, 1.9456352d-06, 1.0449532d-07 /
      data fpppp(15, 6,16,1),fpppp(15, 6,16,2),fpppp(15, 6,16,3)/
     x-9.0071728d-06,-5.0275316d-07,-2.8680248d-07 /
      data fpppp(15, 6,17,1),fpppp(15, 6,17,2),fpppp(15, 6,17,3)/
     x-8.4695246d-05, 9.1127173d-06, 5.8387062d-07 /
      data fpppp(15, 6,18,1),fpppp(15, 6,18,2),fpppp(15, 6,18,3)/
     x-5.5864031d-04,-1.5581109d-05,-2.8368256d-06 /
      data fpppp(15, 6,19,1),fpppp(15, 6,19,2),fpppp(15, 6,19,3)/
     x-1.5049774d-03, 1.8150822d-04, 3.3370992d-06 /
      data fpppp(15, 6,20,1),fpppp(15, 6,20,2),fpppp(15, 6,20,3)/
     x 2.1993207d-03,-1.2756812d-04,-7.1720663d-07 /
      data fpppp(15, 6,21,1),fpppp(15, 6,21,2),fpppp(15, 6,21,3)/
     x 2.1993207d-03,-1.1136598d-04,-3.3433001d-07 /
      data fpppp(15, 6,22,1),fpppp(15, 6,22,2),fpppp(15, 6,22,3)/
     x-1.5049774d-03, 1.1669969d-04, 1.8055927d-06 /
      data fpppp(15, 6,23,1),fpppp(15, 6,23,2),fpppp(15, 6,23,3)/
     x-5.5864031d-04, 2.2745090d-04, 2.9063237d-06 /
      data fpppp(15, 7, 1,1),fpppp(15, 7, 1,2),fpppp(15, 7, 1,3)/
     x-3.2026966d-06, 4.9716611d-05, 1.8875198d-06 /
      data fpppp(15, 7, 2,1),fpppp(15, 7, 2,2),fpppp(15, 7, 2,3)/
     x 5.4510596d-04, 1.6679790d-05, 8.3666956d-07 /
      data fpppp(15, 7, 3,1),fpppp(15, 7, 3,2),fpppp(15, 7, 3,3)/
     x-3.2995792d-02,-5.2578364d-05,-1.3668299d-06 /
      data fpppp(15, 7, 4,1),fpppp(15, 7, 4,2),fpppp(15, 7, 4,3)/
     x-3.2995792d-02,-5.5264676d-05,-1.4513942d-06 /
      data fpppp(15, 7, 5,1),fpppp(15, 7, 5,2),fpppp(15, 7, 5,3)/
     x 5.4510596d-04, 2.7425036d-05, 1.1749266d-06 /
      data fpppp(15, 7, 6,1),fpppp(15, 7, 6,2),fpppp(15, 7, 6,3)/
     x-3.2026966d-06, 9.4219382d-06, 6.1905585d-07 /
      data fpppp(15, 7, 7,1),fpppp(15, 7, 7,2),fpppp(15, 7, 7,3)/
     x-1.1935105d-03, 7.8866508d-06, 1.7831642d-08 /
      data fpppp(15, 7, 8,1),fpppp(15, 7, 8,2),fpppp(15, 7, 8,3)/
     x-1.7229416d-05, 5.1053253d-06, 2.3198741d-07 /
      data fpppp(15, 7, 9,1),fpppp(15, 7, 9,2),fpppp(15, 7, 9,3)/
     x-1.1493022d-06, 8.5022643d-06, 3.8291906d-08 /
      data fpppp(15, 7,10,1),fpppp(15, 7,10,2),fpppp(15, 7,10,3)/
     x 6.5790084d-06, 8.5136986d-06, 4.7136706d-08 /
      data fpppp(15, 7,11,1),fpppp(15, 7,11,2),fpppp(15, 7,11,3)/
     x 6.6846018d-05, 8.7638972d-06, 2.1524963d-08 /
      data fpppp(15, 7,12,1),fpppp(15, 7,12,2),fpppp(15, 7,12,3)/
     x 4.9749059d-05, 7.2899718d-06, 2.1503568d-08 /
      data fpppp(15, 7,13,1),fpppp(15, 7,13,2),fpppp(15, 7,13,3)/
     x-1.5389646d-05, 7.5349362d-06, 2.2451835d-08 /
      data fpppp(15, 7,14,1),fpppp(15, 7,14,2),fpppp(15, 7,14,3)/
     x-5.5012266d-06, 1.0015660d-05, 4.0764598d-08 /
      data fpppp(15, 7,15,1),fpppp(15, 7,15,2),fpppp(15, 7,15,3)/
     x 7.3356082d-06,-4.4127412d-06, 3.7035230d-08 /
      data fpppp(15, 7,16,1),fpppp(15, 7,16,2),fpppp(15, 7,16,3)/
     x 2.1814035d-06, 2.8969403d-05, 1.6279361d-07 /
      data fpppp(15, 7,17,1),fpppp(15, 7,17,2),fpppp(15, 7,17,3)/
     x-3.0237204d-05,-2.3226033d-06,-3.0850119d-08 /
      data fpppp(15, 7,18,1),fpppp(15, 7,18,2),fpppp(15, 7,18,3)/
     x 4.2971636d-05, 1.7693724d-05, 9.0639036d-07 /
      data fpppp(15, 7,19,1),fpppp(15, 7,19,2),fpppp(15, 7,19,3)/
     x 2.3476599d-04, 2.2760700d-05,-5.4770473d-07 /
      data fpppp(15, 7,20,1),fpppp(15, 7,20,2),fpppp(15, 7,20,3)/
     x-7.0013454d-04,-5.4531454d-05,-3.9339266d-07 /
      data fpppp(15, 7,21,1),fpppp(15, 7,21,2),fpppp(15, 7,21,3)/
     x-7.0013454d-04,-5.2578765d-05,-4.6583447d-07 /
      data fpppp(15, 7,22,1),fpppp(15, 7,22,2),fpppp(15, 7,22,3)/
     x 2.3476599d-04, 1.4949944d-05,-2.5793751d-07 /
      data fpppp(15, 7,23,1),fpppp(15, 7,23,2),fpppp(15, 7,23,3)/
     x 4.2971636d-05, 4.6984059d-05,-1.8023674d-07 /
      data fpppp(15, 8, 1,1),fpppp(15, 8, 1,2),fpppp(15, 8, 1,3)/
     x-2.5545347d-06,-3.7303413d-02,-9.2649319d-07 /
      data fpppp(15, 8, 2,1),fpppp(15, 8, 2,2),fpppp(15, 8, 2,3)/
     x-1.1762269d-04,-2.0208502d-02,-5.2234586d-07 /
      data fpppp(15, 8, 3,1),fpppp(15, 8, 3,2),fpppp(15, 8, 3,3)/
     x 2.1332763d-02, 1.4671009d-02, 3.0925778d-07 /
      data fpppp(15, 8, 4,1),fpppp(15, 8, 4,2),fpppp(15, 8, 4,3)/
     x 2.1332763d-02, 1.7737783d-02, 3.6950391d-07 /
      data fpppp(15, 8, 5,1),fpppp(15, 8, 5,2),fpppp(15, 8, 5,3)/
     x-1.1762269d-04,-3.2475600d-02,-7.6333036d-07 /
      data fpppp(15, 8, 6,1),fpppp(15, 8, 6,2),fpppp(15, 8, 6,3)/
     x-2.5545347d-06, 8.6982047d-03,-2.2801312d-08 /
      data fpppp(15, 8, 7,1),fpppp(15, 8, 7,2),fpppp(15, 8, 7,3)/
     x 2.9649589d-04,-2.3403666d-03, 8.3814554d-08 /
      data fpppp(15, 8, 8,1),fpppp(15, 8, 8,2),fpppp(15, 8, 8,3)/
     x-2.3661097d-06, 6.3079698d-04, 4.1136796d-08 /
      data fpppp(15, 8, 9,1),fpppp(15, 8, 9,2),fpppp(15, 8, 9,3)/
     x 7.5752495d-07,-1.7048691d-04, 5.9415442d-08 /
      data fpppp(15, 8,10,1),fpppp(15, 8,10,2),fpppp(15, 8,10,3)/
     x 1.1171195d-05, 5.7702772d-05, 3.6561455d-08 /
      data fpppp(15, 8,11,1),fpppp(15, 8,11,2),fpppp(15, 8,11,3)/
     x-3.3267572d-07,-1.2448113d-06, 3.4459621d-08 /
      data fpppp(15, 8,12,1),fpppp(15, 8,12,2),fpppp(15, 8,12,3)/
     x 1.4370128d-06, 1.3632902d-05, 3.0826145d-08 /
      data fpppp(15, 8,13,1),fpppp(15, 8,13,2),fpppp(15, 8,13,3)/
     x 1.6493631d-05, 8.7455095d-06, 3.0271500d-08 /
      data fpppp(15, 8,14,1),fpppp(15, 8,14,2),fpppp(15, 8,14,3)/
     x 9.7030250d-06, 8.7878949d-06, 2.8467321d-08 /
      data fpppp(15, 8,15,1),fpppp(15, 8,15,2),fpppp(15, 8,15,3)/
     x-2.6441936d-06, 9.5305760d-06, 3.8056280d-08 /
      data fpppp(15, 8,16,1),fpppp(15, 8,16,2),fpppp(15, 8,16,3)/
     x-2.0389905d-05, 5.6788546d-06, 1.5345581d-08 /
      data fpppp(15, 8,17,1),fpppp(15, 8,17,2),fpppp(15, 8,17,3)/
     x-1.2109813d-05, 8.3070767d-06, 7.5367141d-08 /
      data fpppp(15, 8,18,1),fpppp(15, 8,18,2),fpppp(15, 8,18,3)/
     x-3.7351585d-05, 6.2021980d-06,-1.9708256d-07 /
      data fpppp(15, 8,19,1),fpppp(15, 8,19,2),fpppp(15, 8,19,3)/
     x-8.2677700d-05, 2.8793387d-06, 1.4022919d-07 /
      data fpppp(15, 8,20,1),fpppp(15, 8,20,2),fpppp(15, 8,20,3)/
     x 1.8874073d-04,-3.1593016d-05,-1.1475374d-07 /
      data fpppp(15, 8,21,1),fpppp(15, 8,21,2),fpppp(15, 8,21,3)/
     x 1.8874073d-04,-3.0987119d-05,-9.3093749d-08 /
      data fpppp(15, 8,22,1),fpppp(15, 8,22,2),fpppp(15, 8,22,3)/
     x-8.2677700d-05, 4.5574895d-07, 5.3589231d-08 /
      data fpppp(15, 8,23,1),fpppp(15, 8,23,2),fpppp(15, 8,23,3)/
     x-3.7351585d-05, 1.5290660d-05, 1.2781729d-07 /
      data fpppp(15, 9, 1,1),fpppp(15, 9, 1,2),fpppp(15, 9, 1,3)/
     x-2.3180671d-04,-4.2247377d-02,-2.4974750d-06 /
      data fpppp(15, 9, 2,1),fpppp(15, 9, 2,2),fpppp(15, 9, 2,3)/
     x-6.6897975d-04,-2.2871155d-02,-1.4184101d-06 /
      data fpppp(15, 9, 3,1),fpppp(15, 9, 3,2),fpppp(15, 9, 3,3)/
     x 3.6654744d-02, 1.6668827d-02, 7.5830271d-07 /
      data fpppp(15, 9, 4,1),fpppp(15, 9, 4,2),fpppp(15, 9, 4,3)/
     x 3.6654744d-02, 2.0134688d-02, 9.9554875d-07 /
      data fpppp(15, 9, 5,1),fpppp(15, 9, 5,2),fpppp(15, 9, 5,3)/
     x-6.6897975d-04,-3.6734601d-02,-2.3673943d-06 /
      data fpppp(15, 9, 6,1),fpppp(15, 9, 6,2),fpppp(15, 9, 6,3)/
     x-2.3180671d-04, 9.7405422d-03, 1.0612156d-06 /
      data fpppp(15, 9, 7,1),fpppp(15, 9, 7,2),fpppp(15, 9, 7,3)/
     x-1.7026828d-04,-2.6285675d-03,-2.1320538d-07 /
      data fpppp(15, 9, 8,1),fpppp(15, 9, 8,2),fpppp(15, 9, 8,3)/
     x-5.4987491d-05, 6.9140593d-04, 7.9981340d-08 /
      data fpppp(15, 9, 9,1),fpppp(15, 9, 9,2),fpppp(15, 9, 9,3)/
     x-3.2864954d-05,-1.9461439d-04,-6.3818707d-09 /
      data fpppp(15, 9,10,1),fpppp(15, 9,10,2),fpppp(15, 9,10,3)/
     x-2.5295209d-05, 5.8783303d-05, 2.4454327d-08 /
      data fpppp(15, 9,11,1),fpppp(15, 9,11,2),fpppp(15, 9,11,3)/
     x-1.4633617d-05,-5.7206651d-06, 1.6237335d-08 /
      data fpppp(15, 9,12,1),fpppp(15, 9,12,2),fpppp(15, 9,12,3)/
     x-7.9733441d-06, 1.7681904d-05, 1.7831874d-08 /
      data fpppp(15, 9,13,1),fpppp(15, 9,13,2),fpppp(15, 9,13,3)/
     x-1.1600652d-05, 8.4173280d-06, 1.8501295d-08 /
      data fpppp(15, 9,14,1),fpppp(15, 9,14,2),fpppp(15, 9,14,3)/
     x-1.1050841d-05, 7.8244240d-06, 2.0609575d-08 /
      data fpppp(15, 9,15,1),fpppp(15, 9,15,2),fpppp(15, 9,15,3)/
     x-7.1139041d-06, 8.0645583d-06, 1.8726701d-08 /
      data fpppp(15, 9,16,1),fpppp(15, 9,16,2),fpppp(15, 9,16,3)/
     x-1.1465468d-06, 6.2067597d-06, 2.2512408d-08 /
      data fpppp(15, 9,17,1),fpppp(15, 9,17,2),fpppp(15, 9,17,3)/
     x-4.7459934d-06, 6.3442853d-06,-1.5887675d-10 /
      data fpppp(15, 9,18,1),fpppp(15, 9,18,2),fpppp(15, 9,18,3)/
     x 3.9202442d-06, 5.0677786d-06, 5.2813261d-08 /
      data fpppp(15, 9,19,1),fpppp(15, 9,19,2),fpppp(15, 9,19,3)/
     x 1.9284134d-05,-8.9218739d-07,-7.1845141d-08 /
      data fpppp(15, 9,20,1),fpppp(15, 9,20,2),fpppp(15, 9,20,3)/
     x-4.4017019d-05,-2.1832775d-05,-5.7373304d-08 /
      data fpppp(15, 9,21,1),fpppp(15, 9,21,2),fpppp(15, 9,21,3)/
     x-4.4017019d-05,-2.1651811d-05,-6.3611211d-08 /
      data fpppp(15, 9,22,1),fpppp(15, 9,22,2),fpppp(15, 9,22,3)/
     x 1.9284134d-05,-1.6160434d-06,-4.6893509d-08 /
      data fpppp(15, 9,23,1),fpppp(15, 9,23,2),fpppp(15, 9,23,3)/
     x 3.9202442d-06, 7.7822386d-06,-4.0755357d-08 /
      data fpppp(15,10, 1,1),fpppp(15,10, 1,2),fpppp(15,10, 1,3)/
     x-9.5283787d-04,-5.2921078d-04, 3.0254823d-06 /
      data fpppp(15,10, 2,1),fpppp(15,10, 2,2),fpppp(15,10, 2,3)/
     x 5.9254843d-04,-2.5043829d-04, 1.8054183d-06 /
      data fpppp(15,10, 3,1),fpppp(15,10, 3,2),fpppp(15,10, 3,3)/
     x-4.1023079d-02, 3.1906112d-04,-6.2580563d-07 /
      data fpppp(15,10, 4,1),fpppp(15,10, 4,2),fpppp(15,10, 4,3)/
     x-4.1023079d-02, 3.6783400d-04,-9.4640386d-07 /
      data fpppp(15,10, 5,1),fpppp(15,10, 5,2),fpppp(15,10, 5,3)/
     x 5.9254843d-04,-4.4552980d-04, 3.0878112d-06 /
      data fpppp(15,10, 6,1),fpppp(15,10, 6,2),fpppp(15,10, 6,3)/
     x-9.5283787d-04, 2.0238240d-04,-1.7834912d-06 /
      data fpppp(15,10, 7,1),fpppp(15,10, 7,2),fpppp(15,10, 7,3)/
     x-3.2400468d-04,-2.8718718d-04, 2.0570419d-07 /
      data fpppp(15,10, 8,1),fpppp(15,10, 8,2),fpppp(15,10, 8,3)/
     x-1.3098420d-04,-4.5682972d-06,-1.6554082d-07 /
      data fpppp(15,10, 9,1),fpppp(15,10, 9,2),fpppp(15,10, 9,3)/
     x-7.6613618d-05,-3.1287648d-05,-6.7905303d-09 /
      data fpppp(15,10,10,1),fpppp(15,10,10,2),fpppp(15,10,10,3)/
     x-3.8316269d-05,-3.6426205d-07,-1.8169814d-08 /
      data fpppp(15,10,11,1),fpppp(15,10,11,2),fpppp(15,10,11,3)/
     x-2.8210476d-05, 5.5199327d-06, 5.1778163d-09 /
      data fpppp(15,10,12,1),fpppp(15,10,12,2),fpppp(15,10,12,3)/
     x-2.3148540d-05, 1.1317619d-05, 6.6103045d-09 /
      data fpppp(15,10,13,1),fpppp(15,10,13,2),fpppp(15,10,13,3)/
     x-1.5775670d-05, 8.4733903d-06, 8.7607575d-09 /
      data fpppp(15,10,14,1),fpppp(15,10,14,2),fpppp(15,10,14,3)/
     x-1.1083251d-05, 7.9180676d-06, 8.2206902d-09 /
      data fpppp(15,10,15,1),fpppp(15,10,15,2),fpppp(15,10,15,3)/
     x-8.9664295d-06, 7.4021302d-06, 8.4942431d-09 /
      data fpppp(15,10,16,1),fpppp(15,10,16,2),fpppp(15,10,16,3)/
     x-7.6867132d-06, 4.3492774d-06, 4.6091746d-09 /
      data fpppp(15,10,17,1),fpppp(15,10,17,2),fpppp(15,10,17,3)/
     x-4.1243097d-08, 7.2437962d-06, 2.0734895d-09 /
      data fpppp(15,10,18,1),fpppp(15,10,18,2),fpppp(15,10,18,3)/
     x 1.4579198d-07, 2.9519748d-06,-2.2435368d-08 /
      data fpppp(15,10,19,1),fpppp(15,10,19,2),fpppp(15,10,19,3)/
     x-3.9909160d-07, 2.3738666d-06,-1.3542253d-09 /
      data fpppp(15,10,20,1),fpppp(15,10,20,2),fpppp(15,10,20,3)/
     x 1.8461052d-05,-1.7752066d-05,-1.8265764d-08 /
      data fpppp(15,10,21,1),fpppp(15,10,21,2),fpppp(15,10,21,3)/
     x 1.8461052d-05,-1.7333680d-05,-1.6890454d-08 /
      data fpppp(15,10,22,1),fpppp(15,10,22,2),fpppp(15,10,22,3)/
     x-3.9909160d-07, 7.0032347d-07,-6.8554646d-09 /
      data fpppp(15,10,23,1),fpppp(15,10,23,2),fpppp(15,10,23,3)/
     x 1.4579198d-07, 9.2277615d-06,-1.8057201d-09 /
      data fpppp(15,11, 1,1),fpppp(15,11, 1,2),fpppp(15,11, 1,3)/
     x 1.1632156d-03,-1.4407682d-03,-4.9305088d-07 /
      data fpppp(15,11, 2,1),fpppp(15,11, 2,2),fpppp(15,11, 2,3)/
     x-1.2016697d-03,-8.1002196d-04,-4.2959929d-07 /
      data fpppp(15,11, 3,1),fpppp(15,11, 3,2),fpppp(15,11, 3,3)/
     x 1.2404244d-02, 4.0786281d-04,-3.6533798d-07 /
      data fpppp(15,11, 4,1),fpppp(15,11, 4,2),fpppp(15,11, 4,3)/
     x 1.2404244d-02, 6.4186276d-04,-2.3985179d-07 /
      data fpppp(15,11, 5,1),fpppp(15,11, 5,2),fpppp(15,11, 5,3)/
     x-1.2016697d-03,-1.7460218d-03,-9.3154401d-07 /
      data fpppp(15,11, 6,1),fpppp(15,11, 6,2),fpppp(15,11, 6,3)/
     x 1.1632156d-03, 2.0692311d-03, 1.3892418d-06 /
      data fpppp(15,11, 7,1),fpppp(15,11, 7,2),fpppp(15,11, 7,3)/
     x 3.1014862d-05,-1.1521212d-03,-8.1608832d-08 /
      data fpppp(15,11, 8,1),fpppp(15,11, 8,2),fpppp(15,11, 8,3)/
     x-8.1405515d-05, 4.9978405d-05, 7.3519051d-08 /
      data fpppp(15,11, 9,1),fpppp(15,11, 9,2),fpppp(15,11, 9,3)/
     x-2.0655392d-07,-1.1786876d-04,-2.9766957d-08 /
      data fpppp(15,11,10,1),fpppp(15,11,10,2),fpppp(15,11,10,3)/
     x-3.6512596d-05,-6.7520561d-06,-6.7083784d-09 /
      data fpppp(15,11,11,1),fpppp(15,11,11,2),fpppp(15,11,11,3)/
     x-2.4015177d-05,-5.2416036d-06,-4.1044220d-09 /
      data fpppp(15,11,12,1),fpppp(15,11,12,2),fpppp(15,11,12,3)/
     x-1.7822759d-05, 9.7203497d-06, 3.4835028d-09 /
      data fpppp(15,11,13,1),fpppp(15,11,13,2),fpppp(15,11,13,3)/
     x-1.5817764d-05, 6.2322515d-06, 3.0251166d-09 /
      data fpppp(15,11,14,1),fpppp(15,11,14,2),fpppp(15,11,14,3)/
     x-1.2422666d-05, 7.2789175d-06, 2.5933042d-09 /
      data fpppp(15,11,15,1),fpppp(15,11,15,2),fpppp(15,11,15,3)/
     x-8.1675273d-06, 5.9128516d-06, 8.2432666d-10 /
      data fpppp(15,11,16,1),fpppp(15,11,16,2),fpppp(15,11,16,3)/
     x-2.8556260d-06, 6.2707542d-06,-4.6674466d-10 /
      data fpppp(15,11,17,1),fpppp(15,11,17,2),fpppp(15,11,17,3)/
     x-3.8859393d-06, 3.4083182d-06,-3.2725275d-09 /
      data fpppp(15,11,18,1),fpppp(15,11,18,2),fpppp(15,11,18,3)/
     x 1.3049735d-07, 3.4758614d-06,-3.2436846d-10 /
      data fpppp(15,11,19,1),fpppp(15,11,19,2),fpppp(15,11,19,3)/
     x 3.5185108d-06, 2.9577020d-06,-4.6702024d-09 /
      data fpppp(15,11,20,1),fpppp(15,11,20,2),fpppp(15,11,20,3)/
     x-7.1578249d-07,-1.4249413d-05,-5.7020840d-09 /
      data fpppp(15,11,21,1),fpppp(15,11,21,2),fpppp(15,11,21,3)/
     x-7.1578249d-07,-1.3892838d-05,-5.8855155d-09 /
      data fpppp(15,11,22,1),fpppp(15,11,22,2),fpppp(15,11,22,3)/
     x 3.5185108d-06, 1.5314056d-06,-3.9364766d-09 /
      data fpppp(15,11,23,1),fpppp(15,11,23,2),fpppp(15,11,23,3)/
     x 1.3049735d-07, 8.8244726d-06,-3.0758402d-09 /
      data fpppp(15,12, 1,1),fpppp(15,12, 1,2),fpppp(15,12, 1,3)/
     x-5.7078637d-04, 1.8196481d-03, 1.3450574d-07 /
      data fpppp(15,12, 2,1),fpppp(15,12, 2,2),fpppp(15,12, 2,3)/
     x 1.1958084d-03, 1.0560890d-03, 4.7809915d-08 /
      data fpppp(15,12, 3,1),fpppp(15,12, 3,2),fpppp(15,12, 3,3)/
     x-4.8933393d-03,-5.1164916d-04,-1.1947106d-07 /
      data fpppp(15,12, 4,1),fpppp(15,12, 4,2),fpppp(15,12, 4,3)/
     x-4.8933393d-03,-6.3145399d-04,-1.5183869d-07 /
      data fpppp(15,12, 5,1),fpppp(15,12, 5,2),fpppp(15,12, 5,3)/
     x 1.1958084d-03, 1.5353083d-03, 1.7728043d-07 /
      data fpppp(15,12, 6,1),fpppp(15,12, 6,2),fpppp(15,12, 6,3)/
     x-5.7078637d-04, 2.2575736d-05,-3.5100869d-07 /
      data fpppp(15,12, 7,1),fpppp(15,12, 7,2),fpppp(15,12, 7,3)/
     x 1.5432742d-04,-2.6727708d-04, 2.4218570d-07 /
      data fpppp(15,12, 8,1),fpppp(15,12, 8,2),fpppp(15,12, 8,3)/
     x-2.5861762d-06,-2.1980215d-04, 7.2218917d-08 /
      data fpppp(15,12, 9,1),fpppp(15,12, 9,2),fpppp(15,12, 9,3)/
     x-2.5333486d-04,-1.1492668d-04, 5.1706600d-08 /
      data fpppp(15,12,10,1),fpppp(15,12,10,2),fpppp(15,12,10,3)/
     x-2.2108786d-05,-5.1023889d-05, 1.5576063d-08 /
      data fpppp(15,12,11,1),fpppp(15,12,11,2),fpppp(15,12,11,3)/
     x-1.7025785d-05,-1.3110962d-05, 7.2606885d-09 /
      data fpppp(15,12,12,1),fpppp(15,12,12,2),fpppp(15,12,12,3)/
     x-1.3161187d-05, 2.9561476d-06, 2.8396814d-09 /
      data fpppp(15,12,13,1),fpppp(15,12,13,2),fpppp(15,12,13,3)/
     x-1.0655740d-05, 5.9687569d-06, 1.9019706d-09 /
      data fpppp(15,12,14,1),fpppp(15,12,14,2),fpppp(15,12,14,3)/
     x-9.2318603d-06, 5.6945158d-06,-5.5068171d-10 /
      data fpppp(15,12,15,1),fpppp(15,12,15,2),fpppp(15,12,15,3)/
     x-8.4284974d-06, 6.4709859d-06,-1.6076453d-09 /
      data fpppp(15,12,16,1),fpppp(15,12,16,2),fpppp(15,12,16,3)/
     x-8.5444966d-06, 3.4184131d-06,-2.4810390d-09 /
      data fpppp(15,12,17,1),fpppp(15,12,17,2),fpppp(15,12,17,3)/
     x-3.1384795d-06, 3.1396111d-06, 1.4808839d-10 /
      data fpppp(15,12,18,1),fpppp(15,12,18,2),fpppp(15,12,18,3)/
     x-2.8637410d-06, 2.1037689d-06, 1.0658129d-09 /
      data fpppp(15,12,19,1),fpppp(15,12,19,2),fpppp(15,12,19,3)/
     x-4.8415830d-06, 2.0604909d-06, 3.1316811d-09 /
      data fpppp(15,12,20,1),fpppp(15,12,20,2),fpppp(15,12,20,3)/
     x-3.7454243d-06,-1.0936794d-05,-1.8454556d-09 /
      data fpppp(15,12,21,1),fpppp(15,12,21,2),fpppp(15,12,21,3)/
     x-3.7454243d-06,-1.0650934d-05,-1.6371392d-09 /
      data fpppp(15,12,22,1),fpppp(15,12,22,2),fpppp(15,12,22,3)/
     x-4.8415830d-06, 9.1705014d-07, 2.2984155d-09 /
      data fpppp(15,12,23,1),fpppp(15,12,23,2),fpppp(15,12,23,3)/
     x-2.8637410d-06, 6.3916719d-06, 4.1905588d-09 /
      data fpppp(15,13, 1,1),fpppp(15,13, 1,2),fpppp(15,13, 1,3)/
     x 1.2644833d-03, 6.8296256d-04,-7.7276364d-07 /
      data fpppp(15,13, 2,1),fpppp(15,13, 2,2),fpppp(15,13, 2,3)/
     x 5.2888246d-04, 4.2978840d-04,-3.7575724d-07 /
      data fpppp(15,13, 3,1),fpppp(15,13, 3,2),fpppp(15,13, 3,3)/
     x 2.2117105d-03,-9.8155648d-05, 4.5052127d-07 /
      data fpppp(15,13, 4,1),fpppp(15,13, 4,2),fpppp(15,13, 4,3)/
     x 2.2117105d-03,-1.2365669d-04, 4.9330789d-07 /
      data fpppp(15,13, 5,1),fpppp(15,13, 5,2),fpppp(15,13, 5,3)/
     x 5.2888246d-04, 5.3179258d-04,-5.4690370d-07 /
      data fpppp(15,13, 6,1),fpppp(15,13, 6,2),fpppp(15,13, 6,3)/
     x 1.2644833d-03, 3.0044686d-04,-1.3096441d-07 /
      data fpppp(15,13, 7,1),fpppp(15,13, 7,2),fpppp(15,13, 7,3)/
     x-2.7991522d-04,-2.0594438d-04,-2.1625861d-07 /
      data fpppp(15,13, 8,1),fpppp(15,13, 8,2),fpppp(15,13, 8,3)/
     x 2.0399977d-05,-1.8367886d-04, 3.9261213d-08 /
      data fpppp(15,13, 9,1),fpppp(15,13, 9,2),fpppp(15,13, 9,3)/
     x 8.5192268d-04,-1.6260201d-04, 4.6001479d-08 /
      data fpppp(15,13,10,1),fpppp(15,13,10,2),fpppp(15,13,10,3)/
     x-8.4619941d-06,-8.0243281d-05, 4.4064507d-08 /
      data fpppp(15,13,11,1),fpppp(15,13,11,2),fpppp(15,13,11,3)/
     x-9.1987803d-06,-2.6693596d-05, 2.0799220d-08 /
      data fpppp(15,13,12,1),fpppp(15,13,12,2),fpppp(15,13,12,3)/
     x-7.3375906d-06,-4.5880293d-06, 9.2671827d-09 /
      data fpppp(15,13,13,1),fpppp(15,13,13,2),fpppp(15,13,13,3)/
     x-6.0350115d-06, 4.3558012d-06, 2.7118051d-09 /
      data fpppp(15,13,14,1),fpppp(15,13,14,2),fpppp(15,13,14,3)/
     x-7.4630221d-06, 4.6211730d-06, 6.0079577d-10 /
      data fpppp(15,13,15,1),fpppp(15,13,15,2),fpppp(15,13,15,3)/
     x-8.1315745d-06, 5.4717790d-06,-1.6240420d-09 /
      data fpppp(15,13,16,1),fpppp(15,13,16,2),fpppp(15,13,16,3)/
     x-7.8911583d-06, 4.5726606d-06,-9.1928664d-10 /
      data fpppp(15,13,17,1),fpppp(15,13,17,2),fpppp(15,13,17,3)/
     x-1.2292252d-05,-4.9376858d-07, 1.1512195d-09 /
      data fpppp(15,13,18,1),fpppp(15,13,18,2),fpppp(15,13,18,3)/
     x-1.1610411d-05,-2.1165083d-07, 4.8471219d-09 /
      data fpppp(15,13,19,1),fpppp(15,13,19,2),fpppp(15,13,19,3)/
     x-8.0493836d-06, 1.5417024d-06, 1.0084124d-09 /
      data fpppp(15,13,20,1),fpppp(15,13,20,2),fpppp(15,13,20,3)/
     x-8.6060608d-06,-7.6385464d-06, 8.7816392d-10 /
      data fpppp(15,13,21,1),fpppp(15,13,21,2),fpppp(15,13,21,3)/
     x-8.6060608d-06,-7.3519577d-06, 6.9883195d-10 /
      data fpppp(15,13,22,1),fpppp(15,13,22,2),fpppp(15,13,22,3)/
     x-8.0493836d-06, 3.9534745d-07, 1.7257403d-09 /
      data fpppp(15,13,23,1),fpppp(15,13,23,2),fpppp(15,13,23,3)/
     x-1.1610411d-05, 4.0871802d-06, 2.1571423d-09 /
      data fpppp(15,14, 1,1),fpppp(15,14, 1,2),fpppp(15,14, 1,3)/
     x-3.8966083d-03, 4.7688394d-04,-4.4486017d-07 /
      data fpppp(15,14, 2,1),fpppp(15,14, 2,2),fpppp(15,14, 2,3)/
     x-2.1834074d-03, 2.9166238d-04,-1.7553293d-07 /
      data fpppp(15,14, 3,1),fpppp(15,14, 3,2),fpppp(15,14, 3,3)/
     x 1.7708214d-04,-1.0270590d-04, 4.0496290d-07 /
      data fpppp(15,14, 4,1),fpppp(15,14, 4,2),fpppp(15,14, 4,3)/
     x 1.7708214d-04,-1.0714227d-04, 3.9907236d-07 /
      data fpppp(15,14, 5,1),fpppp(15,14, 5,2),fpppp(15,14, 5,3)/
     x-2.1834074d-03, 3.0940786d-04,-1.5197078d-07 /
      data fpppp(15,14, 6,1),fpppp(15,14, 6,2),fpppp(15,14, 6,3)/
     x-3.8966083d-03, 4.1033837d-04,-5.3321822d-07 /
      data fpppp(15,14, 7,1),fpppp(15,14, 7,2),fpppp(15,14, 7,3)/
     x 1.1964905d-03,-7.5813295d-05, 8.2772098d-08 /
      data fpppp(15,14, 8,1),fpppp(15,14, 8,2),fpppp(15,14, 8,3)/
     x-7.5088963d-05,-1.2262036d-04,-1.3343262d-07 /
      data fpppp(15,14, 9,1),fpppp(15,14, 9,2),fpppp(15,14, 9,3)/
     x-3.2021445d-03,-2.0329766d-04, 3.1559555d-08 /
      data fpppp(15,14,10,1),fpppp(15,14,10,2),fpppp(15,14,10,3)/
     x 6.3892046d-06,-1.1238214d-04, 4.2206474d-08 /
      data fpppp(15,14,11,1),fpppp(15,14,11,2),fpppp(15,14,11,3)/
     x 5.4110856d-07,-3.7511344d-05, 3.0188094d-08 /
      data fpppp(15,14,12,1),fpppp(15,14,12,2),fpppp(15,14,12,3)/
     x-5.8322238d-06,-1.1624015d-05, 1.2788374d-08 /
      data fpppp(15,14,13,1),fpppp(15,14,13,2),fpppp(15,14,13,3)/
     x-6.3266633d-06, 2.3049642d-07, 6.0980036d-09 /
      data fpppp(15,14,14,1),fpppp(15,14,14,2),fpppp(15,14,14,3)/
     x-4.2486227d-06, 3.6575891d-06, 2.1819347d-09 /
      data fpppp(15,14,15,1),fpppp(15,14,15,2),fpppp(15,14,15,3)/
     x-5.4359711d-06, 5.6978121d-06, 1.5588743d-09 /
      data fpppp(15,14,16,1),fpppp(15,14,16,2),fpppp(15,14,16,3)/
     x-8.2073461d-06, 1.8486743d-06, 9.4350533d-10 /
      data fpppp(15,14,17,1),fpppp(15,14,17,2),fpppp(15,14,17,3)/
     x-8.2137169d-06,-1.1847416d-07, 1.7706934d-09 /
      data fpppp(15,14,18,1),fpppp(15,14,18,2),fpppp(15,14,18,3)/
     x-9.3101813d-06,-5.7316192d-07, 7.8574021d-10 /
      data fpppp(15,14,19,1),fpppp(15,14,19,2),fpppp(15,14,19,3)/
     x-1.0738960d-05,-1.8695469d-06, 3.5908467d-09 /
      data fpppp(15,14,20,1),fpppp(15,14,20,2),fpppp(15,14,20,3)/
     x-8.1345958d-06,-4.0880404d-06, 1.0280494d-09 /
      data fpppp(15,14,21,1),fpppp(15,14,21,2),fpppp(15,14,21,3)/
     x-8.1345958d-06,-4.1004338d-06, 1.2179740d-09 /
      data fpppp(15,14,22,1),fpppp(15,14,22,2),fpppp(15,14,22,3)/
     x-1.0738960d-05,-1.8199732d-06, 2.8311482d-09 /
      data fpppp(15,14,23,1),fpppp(15,14,23,2),fpppp(15,14,23,3)/
     x-9.3101813d-06,-7.5906316d-07, 3.6346094d-09 /
      data fpppp(15,15, 1,1),fpppp(15,15, 1,2),fpppp(15,15, 1,3)/
     x 1.5487649d-02, 2.2682611d-03, 1.4024324d-07 /
      data fpppp(15,15, 2,1),fpppp(15,15, 2,2),fpppp(15,15, 2,3)/
     x 7.1133771d-03, 1.2974181d-03, 4.7821160d-08 /
      data fpppp(15,15, 3,1),fpppp(15,15, 3,2),fpppp(15,15, 3,3)/
     x-2.5214536d-04,-6.6390642d-04,-1.8754055d-07 /
      data fpppp(15,15, 4,1),fpppp(15,15, 4,2),fpppp(15,15, 4,3)/
     x-2.5214536d-04,-8.7224964d-04,-1.2224037d-07 /
      data fpppp(15,15, 5,1),fpppp(15,15, 5,2),fpppp(15,15, 5,3)/
     x 7.1133771d-03, 2.1307910d-03,-2.1337959d-07 /
      data fpppp(15,15, 6,1),fpppp(15,15, 6,2),fpppp(15,15, 6,3)/
     x 1.5487649d-02,-8.5688715d-04, 1.1197461d-06 /
      data fpppp(15,15, 7,1),fpppp(15,15, 7,2),fpppp(15,15, 7,3)/
     x-4.1321019d-03, 4.7019432d-04,-1.0588984d-06 /
      data fpppp(15,15, 8,1),fpppp(15,15, 8,2),fpppp(15,15, 8,3)/
     x 2.1762107d-04, 7.5236905d-06, 2.2147509d-07 /
      data fpppp(15,15, 9,1),fpppp(15,15, 9,2),fpppp(15,15, 9,3)/
     x 1.2069996d-02,-3.2425663d-04, 4.2925698d-08 /
      data fpppp(15,15,10,1),fpppp(15,15,10,2),fpppp(15,15,10,3)/
     x 4.0236214d-05,-1.2423869d-04, 4.4362195d-08 /
      data fpppp(15,15,11,1),fpppp(15,15,11,2),fpppp(15,15,11,3)/
     x 8.9843488d-06,-4.8566307d-05, 1.6472612d-08 /
      data fpppp(15,15,12,1),fpppp(15,15,12,2),fpppp(15,15,12,3)/
     x 2.8683226d-06,-1.2360589d-05, 1.2509897d-08 /
      data fpppp(15,15,13,1),fpppp(15,15,13,2),fpppp(15,15,13,3)/
     x-1.3073248d-07,-2.7813095d-06, 5.9096782d-09 /
      data fpppp(15,15,14,1),fpppp(15,15,14,2),fpppp(15,15,14,3)/
     x-2.2318464d-06, 3.9786964d-07, 4.2069008d-09 /
      data fpppp(15,15,15,1),fpppp(15,15,15,2),fpppp(15,15,15,3)/
     x-1.5267215d-06, 4.4990306d-06, 3.2733047d-09 /
      data fpppp(15,15,16,1),fpppp(15,15,16,2),fpppp(15,15,16,3)/
     x-1.7821005d-06, 7.3244076d-07, 3.5507893d-09 /
      data fpppp(15,15,17,1),fpppp(15,15,17,2),fpppp(15,15,17,3)/
     x-3.5514144d-06, 1.5519514d-07, 2.1791508d-09 /
      data fpppp(15,15,18,1),fpppp(15,15,18,2),fpppp(15,15,18,3)/
     x-4.5289317d-06,-6.2156722d-07, 1.9118179d-09 /
      data fpppp(15,15,19,1),fpppp(15,15,19,2),fpppp(15,15,19,3)/
     x-3.0862827d-06,-2.4614976d-06,-2.3254541d-10 /
      data fpppp(15,15,20,1),fpppp(15,15,20,2),fpppp(15,15,20,3)/
     x-3.6382590d-06,-2.1075963d-06,-5.6927741d-10 /
      data fpppp(15,15,21,1),fpppp(15,15,21,2),fpppp(15,15,21,3)/
     x-3.6382590d-06,-2.2027744d-06,-6.6360756d-10 /
      data fpppp(15,15,22,1),fpppp(15,15,22,2),fpppp(15,15,22,3)/
     x-3.0862827d-06,-2.0807854d-06, 1.4477516d-10 /
      data fpppp(15,15,23,1),fpppp(15,15,23,2),fpppp(15,15,23,3)/
     x-4.5289317d-06,-2.0492380d-06, 4.9686572d-10 /
      data fpppp(15,16, 1,1),fpppp(15,16, 1,2),fpppp(15,16, 1,3)/
     x-4.6772629d-02, 3.4453408d-03, 6.1090008d-07 /
      data fpppp(15,16, 2,1),fpppp(15,16, 2,2),fpppp(15,16, 2,3)/
     x-2.2621038d-02, 2.1426271d-03, 3.1261254d-07 /
      data fpppp(15,16, 3,1),fpppp(15,16, 3,2),fpppp(15,16, 3,3)/
     x-3.2794724d-03,-9.6359202d-05,-1.6419054d-07 /
      data fpppp(15,16, 4,1),fpppp(15,16, 4,2),fpppp(15,16, 4,3)/
     x-3.2794724d-03,-1.0633096d-03,-4.4836344d-07 /
      data fpppp(15,16, 5,1),fpppp(15,16, 5,2),fpppp(15,16, 5,3)/
     x-2.2621038d-02, 6.0104288d-03, 1.4493041d-06 /
      data fpppp(15,16, 6,1),fpppp(15,16, 6,2),fpppp(15,16, 6,3)/
     x-4.6772629d-02,-1.1058916d-02,-3.6516934d-06 /
      data fpppp(15,16, 7,1),fpppp(15,16, 7,2),fpppp(15,16, 7,3)/
     x 7.9125915d-03, 8.3641784d-03, 3.2109560d-06 /
      data fpppp(15,16, 8,1),fpppp(15,16, 8,2),fpppp(15,16, 8,3)/
     x 3.0861303d-04, 6.9045843d-03,-4.6075781d-07 /
      data fpppp(15,16, 9,1),fpppp(15,16, 9,2),fpppp(15,16, 9,3)/
     x-1.8567042d-02,-1.7977403d-02, 1.0672354d-07 /
      data fpppp(15,16,10,1),fpppp(15,16,10,2),fpppp(15,16,10,3)/
     x 7.0155564d-05, 1.1545640d-02,-7.8028743d-08 /
      data fpppp(15,16,11,1),fpppp(15,16,11,2),fpppp(15,16,11,3)/
     x 2.4812984d-05,-3.1572664d-03,-4.1704678d-09 /
      data fpppp(15,16,12,1),fpppp(15,16,12,2),fpppp(15,16,12,3)/
     x 7.9505653d-06, 8.2424612d-04,-5.4467677d-09 /
      data fpppp(15,16,13,1),fpppp(15,16,13,2),fpppp(15,16,13,3)/
     x 2.0359033d-06,-2.2822656d-04, 3.0704373d-09 /
      data fpppp(15,16,14,1),fpppp(15,16,14,2),fpppp(15,16,14,3)/
     x-1.7431350d-07, 5.9397348d-05, 3.3406548d-09 /
      data fpppp(15,16,15,1),fpppp(15,16,15,2),fpppp(15,16,15,3)/
     x-1.3061371d-06,-1.4265137d-05, 3.8999824d-09 /
      data fpppp(15,16,16,1),fpppp(15,16,16,2),fpppp(15,16,16,3)/
     x-5.9185256d-07, 4.0386173d-06, 3.4948421d-09 /
      data fpppp(15,16,17,1),fpppp(15,16,17,2),fpppp(15,16,17,3)/
     x 2.2325374d-06,-8.7602020d-07, 2.5946087d-09 /
      data fpppp(15,16,18,1),fpppp(15,16,18,2),fpppp(15,16,18,3)/
     x 3.8759571d-06, 1.0232788d-06, 1.5786271d-10 /
      data fpppp(15,16,19,1),fpppp(15,16,19,2),fpppp(15,16,19,3)/
     x 1.8049223d-06,-2.8876722d-06,-2.2260677d-09 /
      data fpppp(15,16,20,1),fpppp(15,16,20,2),fpppp(15,16,20,3)/
     x 5.5157940d-06,-6.4696057d-07,-2.2402034d-09 /
      data fpppp(15,16,21,1),fpppp(15,16,21,2),fpppp(15,16,21,3)/
     x 5.5157940d-06,-8.8224299d-07,-2.3530515d-09 /
      data fpppp(15,16,22,1),fpppp(15,16,22,2),fpppp(15,16,22,3)/
     x 1.8049223d-06,-1.9465425d-06,-1.7746752d-09 /
      data fpppp(15,16,23,1),fpppp(15,16,23,2),fpppp(15,16,23,3)/
     x 3.8759571d-06,-2.5059576d-06,-1.5348591d-09 /
      data fpppp(15,17, 1,1),fpppp(15,17, 1,2),fpppp(15,17, 1,3)/
     x 6.4687519d-02, 3.5381082d-03,-1.2709396d-07 /
      data fpppp(15,17, 2,1),fpppp(15,17, 2,2),fpppp(15,17, 2,3)/
     x 3.4460465d-02, 1.0649559d-03,-1.1454049d-07 /
      data fpppp(15,17, 3,1),fpppp(15,17, 3,2),fpppp(15,17, 3,3)/
     x 7.4549295d-03,-5.7628089d-03,-3.0261015d-07 /
      data fpppp(15,17, 4,1),fpppp(15,17, 4,2),fpppp(15,17, 4,3)/
     x 7.4549295d-03,-3.0885417d-03, 7.3587304d-08 /
      data fpppp(15,17, 5,1),fpppp(15,17, 5,2),fpppp(15,17, 5,3)/
     x 3.4460465d-02,-9.6321132d-03,-1.6193303d-06 /
      data fpppp(15,17, 6,1),fpppp(15,17, 6,2),fpppp(15,17, 6,3)/
     x 6.4687519d-02, 4.3652117d-02, 5.5158679d-06 /
      data fpppp(15,17, 7,1),fpppp(15,17, 7,2),fpppp(15,17, 7,3)/
     x-5.2440320d-03,-3.6677292d-02,-4.0456739d-06 /
      data fpppp(15,17, 8,1),fpppp(15,17, 8,2),fpppp(15,17, 8,3)/
     x 3.6377659d-04, 1.0982440d-02, 6.3458950d-07 /
      data fpppp(15,17, 9,1),fpppp(15,17, 9,2),fpppp(15,17, 9,3)/
     x 1.1505912d-02,-3.4680051d-03,-3.5988484d-07 /
      data fpppp(15,17,10,1),fpppp(15,17,10,2),fpppp(15,17,10,3)/
     x-2.5645792d-05, 8.8013236d-04,-9.4206458d-09 /
      data fpppp(15,17,11,1),fpppp(15,17,11,2),fpppp(15,17,11,3)/
     x 6.6520048d-06,-2.5476080d-04,-5.9792063d-08 /
      data fpppp(15,17,12,1),fpppp(15,17,12,2),fpppp(15,17,12,3)/
     x 8.7318330d-06, 6.0255468d-05,-1.8584113d-08 /
      data fpppp(15,17,13,1),fpppp(15,17,13,2),fpppp(15,17,13,3)/
     x 5.4561236d-06,-2.0935645d-05,-1.1624957d-08 /
      data fpppp(15,17,14,1),fpppp(15,17,14,2),fpppp(15,17,14,3)/
     x 3.1456455d-06, 4.7304513d-06,-3.3741160d-09 /
      data fpppp(15,17,15,1),fpppp(15,17,15,2),fpppp(15,17,15,3)/
     x 3.2376536d-06,-1.5776757d-06,-1.4132062d-10 /
      data fpppp(15,17,16,1),fpppp(15,17,16,2),fpppp(15,17,16,3)/
     x 2.4013661d-06, 7.0029102d-07, 6.2678365d-10 /
      data fpppp(15,17,17,1),fpppp(15,17,17,2),fpppp(15,17,17,3)/
     x 1.7050443d-06, 2.8559985d-07, 1.2273541d-10 /
      data fpppp(15,17,18,1),fpppp(15,17,18,2),fpppp(15,17,18,3)/
     x 2.6696662d-06,-1.7298546d-06,-1.5814936d-09 /
      data fpppp(15,17,19,1),fpppp(15,17,19,2),fpppp(15,17,19,3)/
     x 5.7075588d-06, 1.7208541d-06,-1.6306048d-09 /
      data fpppp(15,17,20,1),fpppp(15,17,20,2),fpppp(15,17,20,3)/
     x 1.3332768d-06,-1.2063232d-06,-3.4419993d-09 /
      data fpppp(15,17,21,1),fpppp(15,17,21,2),fpppp(15,17,21,3)/
     x 1.3332768d-06,-9.7768117d-07,-3.4042047d-09 /
      data fpppp(15,17,22,1),fpppp(15,17,22,2),fpppp(15,17,22,3)/
     x 5.7075588d-06, 8.0628611d-07,-1.7817832d-09 /
      data fpppp(15,17,23,1),fpppp(15,17,23,2),fpppp(15,17,23,3)/
     x 2.6696662d-06, 1.6997754d-06,-1.0145746d-09 /
      data fpppp(15,18, 1,1),fpppp(15,18, 1,2),fpppp(15,18, 1,3)/
     x-2.4861437d-02, 4.6539247d-05, 4.2046285d-08 /
      data fpppp(15,18, 2,1),fpppp(15,18, 2,2),fpppp(15,18, 2,3)/
     x-1.4230506d-02, 1.0597373d-05, 6.7668406d-08 /
      data fpppp(15,18, 3,1),fpppp(15,18, 3,2),fpppp(15,18, 3,3)/
     x-3.8113423d-03,-7.3894431d-05, 2.0238468d-07 /
      data fpppp(15,18, 4,1),fpppp(15,18, 4,2),fpppp(15,18, 4,3)/
     x-3.8113423d-03,-6.0815799d-05, 6.2714152d-08 /
      data fpppp(15,18, 5,1),fpppp(15,18, 5,2),fpppp(15,18, 5,3)/
     x-1.4230506d-02,-4.1717152d-05, 6.2635053d-07 /
      data fpppp(15,18, 6,1),fpppp(15,18, 6,2),fpppp(15,18, 6,3)/
     x-2.4861437d-02, 2.4271872d-04,-2.0530117d-06 /
      data fpppp(15,18, 7,1),fpppp(15,18, 7,2),fpppp(15,18, 7,3)/
     x 6.3984224d-04,-1.3536979d-04, 1.4916197d-06 /
      data fpppp(15,18, 8,1),fpppp(15,18, 8,2),fpppp(15,18, 8,3)/
     x-5.4574882d-04, 2.8525659d-05,-2.7944773d-07 /
      data fpppp(15,18, 9,1),fpppp(15,18, 9,2),fpppp(15,18, 9,3)/
     x-2.1795188d-03, 2.5343942d-06, 1.1808568d-07 /
      data fpppp(15,18,10,1),fpppp(15,18,10,2),fpppp(15,18,10,3)/
     x-3.4874735d-05,-1.6783211d-06,-1.6000577d-08 /
      data fpppp(15,18,11,1),fpppp(15,18,11,2),fpppp(15,18,11,3)/
     x-1.4738182d-05, 1.8882282d-07, 8.5164794d-09 /
      data fpppp(15,18,12,1),fpppp(15,18,12,2),fpppp(15,18,12,3)/
     x-3.9614392d-06, 1.0399600d-06,-2.6559080d-09 /
      data fpppp(15,18,13,1),fpppp(15,18,13,2),fpppp(15,18,13,3)/
     x 8.7097259d-07,-1.6080280d-06,-1.4718550d-09 /
      data fpppp(15,18,14,1),fpppp(15,18,14,2),fpppp(15,18,14,3)/
     x 3.5153037d-06, 2.5189073d-06,-2.1200846d-09 /
      data fpppp(15,18,15,1),fpppp(15,18,15,2),fpppp(15,18,15,3)/
     x 3.3762948d-06,-2.8433272d-06,-2.5698806d-09 /
      data fpppp(15,18,16,1),fpppp(15,18,16,2),fpppp(15,18,16,3)/
     x 5.8535724d-06, 1.4682739d-06,-2.9053603d-09 /
      data fpppp(15,18,17,1),fpppp(15,18,17,2),fpppp(15,18,17,3)/
     x 7.3822632d-06, 6.9647739d-07,-3.9968351d-09 /
      data fpppp(15,18,18,1),fpppp(15,18,18,2),fpppp(15,18,18,3)/
     x 7.6878964d-06,-1.3465804d-06,-4.8033657d-09 /
      data fpppp(15,18,19,1),fpppp(15,18,19,2),fpppp(15,18,19,3)/
     x 8.5113328d-06,-3.6907529d-07,-6.5743184d-09 /
      data fpppp(15,18,20,1),fpppp(15,18,20,2),fpppp(15,18,20,3)/
     x 1.1853555d-05, 5.4372208d-07,-6.4091002d-09 /
      data fpppp(15,18,21,1),fpppp(15,18,21,2),fpppp(15,18,21,3)/
     x 1.1853555d-05, 5.6990244d-07,-6.4968244d-09 /
      data fpppp(15,18,22,1),fpppp(15,18,22,2),fpppp(15,18,22,3)/
     x 8.5113328d-06,-4.7379675d-07,-6.2234219d-09 /
      data fpppp(15,18,23,1),fpppp(15,18,23,2),fpppp(15,18,23,3)/
     x 7.6878964d-06,-9.5387494d-07,-6.1192272d-09 /
      data fpppp(15,19, 1,1),fpppp(15,19, 1,2),fpppp(15,19, 1,3)/
     x-5.6979221d-02, 3.1957517d-18,-4.7994691d-08 /
      data fpppp(15,19, 2,1),fpppp(15,19, 2,2),fpppp(15,19, 2,3)/
     x-3.2700769d-02, 7.6403565d-18, 7.5773894d-08 /
      data fpppp(15,19, 3,1),fpppp(15,19, 3,2),fpppp(15,19, 3,3)/
     x-8.7917073d-03,-2.5580524d-18, 5.2354682d-07 /
      data fpppp(15,19, 4,1),fpppp(15,19, 4,2),fpppp(15,19, 4,3)/
     x-8.7917073d-03,-4.3813207d-18, 2.0407640d-07 /
      data fpppp(15,19, 5,1),fpppp(15,19, 5,2),fpppp(15,19, 5,3)/
     x-3.2700769d-02, 2.4137482d-18, 1.3536556d-06 /
      data fpppp(15,19, 6,1),fpppp(15,19, 6,2),fpppp(15,19, 6,3)/
     x-5.6979221d-02, 2.2805608d-18,-4.8400510d-06 /
      data fpppp(15,19, 7,1),fpppp(15,19, 7,2),fpppp(15,19, 7,3)/
     x 1.0835743d-03, 2.9612919d-18, 3.3735066d-06 /
      data fpppp(15,19, 8,1),fpppp(15,19, 8,2),fpppp(15,19, 8,3)/
     x-1.1796488d-03,-3.2821188d-18,-6.1937509d-07 /
      data fpppp(15,19, 9,1),fpppp(15,19, 9,2),fpppp(15,19, 9,3)/
     x-3.3625538d-03,-7.2104013d-18, 3.2617652d-07 /
      data fpppp(15,19,10,1),fpppp(15,19,10,2),fpppp(15,19,10,3)/
     x-6.8838652d-05, 1.7768173d-18,-1.0982150d-09 /
      data fpppp(15,19,11,1),fpppp(15,19,11,2),fpppp(15,19,11,3)/
     x-3.5205738d-05,-5.1456654d-19, 4.1416411d-08 /
      data fpppp(15,19,12,1),fpppp(15,19,12,2),fpppp(15,19,12,3)/
     x-1.2804843d-05,-3.5210628d-18, 4.9678540d-09 /
      data fpppp(15,19,13,1),fpppp(15,19,13,2),fpppp(15,19,13,3)/
     x-1.4269295d-06, 3.7829636d-18, 1.5816765d-09 /
      data fpppp(15,19,14,1),fpppp(15,19,14,2),fpppp(15,19,14,3)/
     x 4.7279049d-06, 1.1717275d-18,-3.1428538d-09 /
      data fpppp(15,19,15,1),fpppp(15,19,15,2),fpppp(15,19,15,3)/
     x 4.7735501d-06,-2.6611463d-18,-5.4592242d-09 /
      data fpppp(15,19,16,1),fpppp(15,19,16,2),fpppp(15,19,16,3)/
     x 9.1746394d-06,-1.3035167d-18,-6.2477656d-09 /
      data fpppp(15,19,17,1),fpppp(15,19,17,2),fpppp(15,19,17,3)/
     x 1.1286707d-05, 4.5291948d-18,-7.6456349d-09 /
      data fpppp(15,19,18,1),fpppp(15,19,18,2),fpppp(15,19,18,3)/
     x 1.0927692d-05, 2.4708041d-18,-7.6016618d-09 /
      data fpppp(15,19,19,1),fpppp(15,19,19,2),fpppp(15,19,19,3)/
     x 1.1629067d-05, 3.2410974d-18,-9.9354101d-09 /
      data fpppp(15,19,20,1),fpppp(15,19,20,2),fpppp(15,19,20,3)/
     x 1.8173034d-05,-2.9442987d-18,-8.8718283d-09 /
      data fpppp(15,19,21,1),fpppp(15,19,21,2),fpppp(15,19,21,3)/
     x 1.8173034d-05, 2.0137452d-18,-9.0061679d-09 /
      data fpppp(15,19,22,1),fpppp(15,19,22,2),fpppp(15,19,22,3)/
     x 1.1629067d-05,-6.8991244d-18,-9.3980519d-09 /
      data fpppp(15,19,23,1),fpppp(15,19,23,2),fpppp(15,19,23,3)/
     x 1.0927692d-05, 8.0080150d-18,-9.6167550d-09 /
      data fpppp(16, 1, 1,1),fpppp(16, 1, 1,2),fpppp(16, 1, 1,3)/
     x-4.6721831d-02,-4.1954482d-17, 4.9007641d-06 /
      data fpppp(16, 1, 2,1),fpppp(16, 1, 2,2),fpppp(16, 1, 2,3)/
     x-3.6028276d-02,-3.7311399d-17, 2.4304158d-07 /
      data fpppp(16, 1, 3,1),fpppp(16, 1, 3,2),fpppp(16, 1, 3,3)/
     x-1.6967746d-01, 5.4325770d-17,-9.8709880d-06 /
      data fpppp(16, 1, 4,1),fpppp(16, 1, 4,2),fpppp(16, 1, 4,3)/
     x-1.6967746d-01,-1.2687444d-17,-9.6378957d-06 /
      data fpppp(16, 1, 5,1),fpppp(16, 1, 5,2),fpppp(16, 1, 5,3)/
     x-3.6028276d-02,-1.8022328d-17,-6.8932756d-07 /
      data fpppp(16, 1, 6,1),fpppp(16, 1, 6,2),fpppp(16, 1, 6,3)/
     x-4.6721831d-02,-2.9248745d-17, 8.3971484d-06 /
      data fpppp(16, 1, 7,1),fpppp(16, 1, 7,2),fpppp(16, 1, 7,3)/
     x-5.4026226d-02,-2.3606194d-17, 5.0489294d-06 /
      data fpppp(16, 1, 8,1),fpppp(16, 1, 8,2),fpppp(16, 1, 8,3)/
     x-5.1714749d-02,-4.2649716d-18,-6.7238531d-08 /
      data fpppp(16, 1, 9,1),fpppp(16, 1, 9,2),fpppp(16, 1, 9,3)/
     x-5.0130083d-02,-6.0564836d-18, 1.5557991d-06 /
      data fpppp(16, 1,10,1),fpppp(16, 1,10,2),fpppp(16, 1,10,3)/
     x-5.0120469d-02,-4.1179615d-18,-1.7883030d-06 /
      data fpppp(16, 1,11,1),fpppp(16, 1,11,2),fpppp(16, 1,11,3)/
     x-9.0231313d-03, 8.4729419d-17, 1.9187124d-06 /
      data fpppp(16, 1,12,1),fpppp(16, 1,12,2),fpppp(16, 1,12,3)/
     x-2.8406493d-02, 4.3736360d-17, 1.8398850d-06 /
      data fpppp(16, 1,13,1),fpppp(16, 1,13,2),fpppp(16, 1,13,3)/
     x-6.9393902d-02, 3.8494679d-17,-1.6972697d-06 /
      data fpppp(16, 1,14,1),fpppp(16, 1,14,2),fpppp(16, 1,14,3)/
     x-5.0056978d-02, 2.5300515d-17, 8.1178968d-07 /
      data fpppp(16, 1,15,1),fpppp(16, 1,15,2),fpppp(16, 1,15,3)/
     x-4.9660135d-02,-1.0066540d-17, 8.7365813d-07 /
      data fpppp(16, 1,16,1),fpppp(16, 1,16,2),fpppp(16, 1,16,3)/
     x-5.1408164d-02,-4.3045805d-17, 1.9541832d-07 /
      data fpppp(16, 1,17,1),fpppp(16, 1,17,2),fpppp(16, 1,17,3)/
     x-5.1362780d-02,-1.7064308d-17, 4.8533152d-06 /
      data fpppp(16, 1,18,1),fpppp(16, 1,18,2),fpppp(16, 1,18,3)/
     x-4.6743563d-02,-1.3352904d-17, 8.7073224d-06 /
      data fpppp(16, 1,19,1),fpppp(16, 1,19,2),fpppp(16, 1,19,3)/
     x-3.0592826d-02,-1.3321904d-17,-1.9501986d-06 /
      data fpppp(16, 1,20,1),fpppp(16, 1,20,2),fpppp(16, 1,20,3)/
     x-1.5674672d-01,-2.8547838d-17,-8.9052158d-06 /
      data fpppp(16, 1,21,1),fpppp(16, 1,21,2),fpppp(16, 1,21,3)/
     x-1.5674672d-01,-1.8693784d-17,-9.2570439d-06 /
      data fpppp(16, 1,22,1),fpppp(16, 1,22,2),fpppp(16, 1,22,3)/
     x-3.0592826d-02, 7.9483332d-18,-5.4288597d-07 /
      data fpppp(16, 1,23,1),fpppp(16, 1,23,2),fpppp(16, 1,23,3)/
     x-4.6743563d-02,-8.6046512d-17, 3.4299002d-06 /
      data fpppp(16, 2, 1,1),fpppp(16, 2, 1,2),fpppp(16, 2, 1,3)/
     x-2.6532721d-02,-4.0655536d-04, 1.6600790d-06 /
      data fpppp(16, 2, 2,1),fpppp(16, 2, 2,2),fpppp(16, 2, 2,3)/
     x-2.2655913d-02,-2.8441543d-04,-2.3327574d-08 /
      data fpppp(16, 2, 3,1),fpppp(16, 2, 3,2),fpppp(16, 2, 3,3)/
     x-7.6138958d-02,-3.7818139d-05,-3.6862935d-06 /
      data fpppp(16, 2, 4,1),fpppp(16, 2, 4,2),fpppp(16, 2, 4,3)/
     x-7.6138958d-02,-1.1338632d-05,-3.5888778d-06 /
      data fpppp(16, 2, 5,1),fpppp(16, 2, 5,2),fpppp(16, 2, 5,3)/
     x-2.2655913d-02,-3.9033346d-04,-4.1299064d-07 /
      data fpppp(16, 2, 6,1),fpppp(16, 2, 6,2),fpppp(16, 2, 6,3)/
     x-2.6532721d-02,-9.3627582d-06, 3.1213155d-06 /
      data fpppp(16, 2, 7,1),fpppp(16, 2, 7,2),fpppp(16, 2, 7,3)/
     x-3.0006961d-02, 7.3873423d-04, 2.1432382d-06 /
      data fpppp(16, 2, 8,1),fpppp(16, 2, 8,2),fpppp(16, 2, 8,3)/
     x-2.8312797d-02,-2.2712500d-03,-1.0366263d-07 /
      data fpppp(16, 2, 9,1),fpppp(16, 2, 9,2),fpppp(16, 2, 9,3)/
     x-2.7463952d-02, 6.1965591d-03, 6.7222361d-07 /
      data fpppp(16, 2,10,1),fpppp(16, 2,10,2),fpppp(16, 2,10,3)/
     x-2.7431404d-02,-1.9753280d-02,-9.2878193d-07 /
      data fpppp(16, 2,11,1),fpppp(16, 2,11,2),fpppp(16, 2,11,3)/
     x-7.3646679d-03, 2.1994940d-02, 8.7152490d-07 /
      data fpppp(16, 2,12,1),fpppp(16, 2,12,2),fpppp(16, 2,12,3)/
     x-1.6822179d-02, 7.1699780d-03, 8.3317890d-07 /
      data fpppp(16, 2,13,1),fpppp(16, 2,13,2),fpppp(16, 2,13,3)/
     x-3.6827064d-02,-2.3690723d-02,-8.9340587d-07 /
      data fpppp(16, 2,14,1),fpppp(16, 2,14,2),fpppp(16, 2,14,3)/
     x-2.7398048d-02, 1.2690726d-02, 3.3903287d-07 /
      data fpppp(16, 2,15,1),fpppp(16, 2,15,2),fpppp(16, 2,15,3)/
     x-2.7256722d-02,-2.6581109d-03, 3.4008010d-07 /
      data fpppp(16, 2,16,1),fpppp(16, 2,16,2),fpppp(16, 2,16,3)/
     x-2.8156177d-02, 3.0237702d-04, 1.9865696d-08 /
      data fpppp(16, 2,17,1),fpppp(16, 2,17,2),fpppp(16, 2,17,3)/
     x-2.8253578d-02, 4.8414310d-05, 2.0723838d-06 /
      data fpppp(16, 2,18,1),fpppp(16, 2,18,2),fpppp(16, 2,18,3)/
     x-2.6520395d-02,-1.5967729d-04, 3.2321556d-06 /
      data fpppp(16, 2,19,1),fpppp(16, 2,19,2),fpppp(16, 2,19,3)/
     x-2.0285916d-02, 6.4477456d-05,-7.4847892d-07 /
      data fpppp(16, 2,20,1),fpppp(16, 2,20,2),fpppp(16, 2,20,3)/
     x-7.2548407d-02,-1.6860192d-04,-3.3989847d-06 /
      data fpppp(16, 2,21,1),fpppp(16, 2,21,2),fpppp(16, 2,21,3)/
     x-7.2548407d-02,-1.5279851d-04,-3.5292252d-06 /
      data fpppp(16, 2,22,1),fpppp(16, 2,22,2),fpppp(16, 2,22,3)/
     x-2.0285916d-02, 1.2638260d-06,-2.2751719d-07 /
      data fpppp(16, 2,23,1),fpppp(16, 2,23,2),fpppp(16, 2,23,3)/
     x-2.6520395d-02, 7.7373825d-05, 1.2785491d-06 /
      data fpppp(16, 3, 1,1),fpppp(16, 3, 1,2),fpppp(16, 3, 1,3)/
     x 3.5664905d-03,-9.3960744d-02, 2.5575437d-06 /
      data fpppp(16, 3, 2,1),fpppp(16, 3, 2,2),fpppp(16, 3, 2,3)/
     x-1.9480331d-03,-5.1614558d-02, 2.7162811d-06 /
      data fpppp(16, 3, 3,1),fpppp(16, 3, 3,2),fpppp(16, 3, 3,3)/
     x 1.0364101d-01, 3.4576318d-02, 3.2546886d-06 /
      data fpppp(16, 3, 4,1),fpppp(16, 3, 4,2),fpppp(16, 3, 4,3)/
     x 1.0364101d-01, 4.2540483d-02, 2.9077410d-06 /
      data fpppp(16, 3, 5,1),fpppp(16, 3, 5,2),fpppp(16, 3, 5,3)/
     x-1.9480331d-03,-8.3471217d-02, 4.1040714d-06 /
      data fpppp(16, 3, 6,1),fpppp(16, 3, 6,2),fpppp(16, 3, 6,3)/
     x 3.5664905d-03, 2.5501728d-02,-2.6466696d-06 /
      data fpppp(16, 3, 7,1),fpppp(16, 3, 7,2),fpppp(16, 3, 7,3)/
     x 1.7423575d-02,-4.5718020d-03,-4.8850261d-06 /
      data fpppp(16, 3, 8,1),fpppp(16, 3, 8,2),fpppp(16, 3, 8,3)/
     x 8.1853198d-03, 1.3282784d-03, 6.6476481d-07 /
      data fpppp(16, 3, 9,1),fpppp(16, 3, 9,2),fpppp(16, 3, 9,3)/
     x 8.0071467d-03,-8.8731751d-05,-1.2779325d-06 /
      data fpppp(16, 3,10,1),fpppp(16, 3,10,2),fpppp(16, 3,10,3)/
     x 8.2389800d-03, 1.1983272d-04, 7.6079055d-07 /
      data fpppp(16, 3,11,1),fpppp(16, 3,11,2),fpppp(16, 3,11,3)/
     x-1.0712251d-02, 7.5661424d-06,-1.0754525d-06 /
      data fpppp(16, 3,12,1),fpppp(16, 3,12,2),fpppp(16, 3,12,3)/
     x-1.6772811d-03, 5.1332912d-05,-1.0160386d-06 /
      data fpppp(16, 3,13,1),fpppp(16, 3,13,2),fpppp(16, 3,13,3)/
     x 1.7312351d-02,-8.3515499d-05, 6.0240559d-07 /
      data fpppp(16, 3,14,1),fpppp(16, 3,14,2),fpppp(16, 3,14,3)/
     x 8.2255901d-03, 4.6189612d-04,-4.4601280d-07 /
      data fpppp(16, 3,15,1),fpppp(16, 3,15,2),fpppp(16, 3,15,3)/
     x 7.5322286d-03,-6.3336499d-04,-9.4204443d-07 /
      data fpppp(16, 3,16,1),fpppp(16, 3,16,2),fpppp(16, 3,16,3)/
     x 8.0691984d-03, 1.7152148d-03, 5.6935408d-07 /
      data fpppp(16, 3,17,1),fpppp(16, 3,17,2),fpppp(16, 3,17,3)/
     x 7.7178046d-03,-4.9145997d-03,-4.6850454d-06 /
      data fpppp(16, 3,18,1),fpppp(16, 3,18,2),fpppp(16, 3,18,3)/
     x 3.5197675d-03, 2.6665418d-02,-2.7196405d-06 /
      data fpppp(16, 3,19,1),fpppp(16, 3,19,2),fpppp(16, 3,19,3)/
     x-7.8708824d-03,-8.0454611d-02, 4.1952922d-06 /
      data fpppp(16, 3,20,1),fpppp(16, 3,20,2),fpppp(16, 3,20,3)/
     x 1.0188132d-01, 3.9862618d-02, 2.8001385d-06 /
      data fpppp(16, 3,21,1),fpppp(16, 3,21,2),fpppp(16, 3,21,3)/
     x 1.0188132d-01, 3.2112552d-02, 3.1592843d-06 /
      data fpppp(16, 3,22,1),fpppp(16, 3,22,2),fpppp(16, 3,22,3)/
     x-7.8708824d-03,-4.9454345d-02, 2.7587091d-06 /
      data fpppp(16, 3,23,1),fpppp(16, 3,23,2),fpppp(16, 3,23,3)/
     x 3.5197675d-03,-8.9585581d-02, 2.6675462d-06 /
      data fpppp(16, 4, 1,1),fpppp(16, 4, 1,2),fpppp(16, 4, 1,3)/
     x-1.0196558d-03,-5.1825204d-02,-1.1028516d-05 /
      data fpppp(16, 4, 2,1),fpppp(16, 4, 2,2),fpppp(16, 4, 2,3)/
     x-6.9144620d-03,-2.8683954d-02,-5.0650327d-06 /
      data fpppp(16, 4, 3,1),fpppp(16, 4, 3,2),fpppp(16, 4, 3,3)/
     x-1.8424158d-02, 1.7897253d-02, 7.5486640d-06 /
      data fpppp(16, 4, 4,1),fpppp(16, 4, 4,2),fpppp(16, 4, 4,3)/
     x-1.8424158d-02, 2.3159827d-02, 7.8377570d-06 /
      data fpppp(16, 4, 5,1),fpppp(16, 4, 5,2),fpppp(16, 4, 5,3)/
     x-6.9144620d-03,-4.9734251d-02,-6.2214044d-06 /
      data fpppp(16, 4, 6,1),fpppp(16, 4, 6,2),fpppp(16, 4, 6,3)/
     x-1.0196558d-03, 2.7113412d-02,-6.6921218d-06 /
      data fpppp(16, 4, 7,1),fpppp(16, 4, 7,2),fpppp(16, 4, 7,3)/
     x-1.7085341d-02,-1.9290236d-02, 2.5157153d-06 /
      data fpppp(16, 4, 8,1),fpppp(16, 4, 8,2),fpppp(16, 4, 8,3)/
     x-1.1531401d-03, 1.1243732d-02,-1.3837881d-06 /
      data fpppp(16, 4, 9,1),fpppp(16, 4, 9,2),fpppp(16, 4, 9,3)/
     x-1.3391452d-03,-2.9530237d-03, 5.0494337d-07 /
      data fpppp(16, 4,10,1),fpppp(16, 4,10,2),fpppp(16, 4,10,3)/
     x-1.5252501d-03, 8.1665449d-04,-4.5481692d-07 /
      data fpppp(16, 4,11,1),fpppp(16, 4,11,2),fpppp(16, 4,11,3)/
     x 3.4613290d-03,-2.2103060d-04, 1.2683460d-07 /
      data fpppp(16, 4,12,1),fpppp(16, 4,12,2),fpppp(16, 4,12,3)/
     x 1.0055712d-03, 5.2090176d-05, 8.3533816d-08 /
      data fpppp(16, 4,13,1),fpppp(16, 4,13,2),fpppp(16, 4,13,3)/
     x-4.0522544d-03,-4.3485335d-05,-3.2359965d-07 /
      data fpppp(16, 4,14,1),fpppp(16, 4,14,2),fpppp(16, 4,14,3)/
     x-1.5272501d-03, 9.3526807d-05,-1.3804742d-07 /
      data fpppp(16, 4,15,1),fpppp(16, 4,15,2),fpppp(16, 4,15,3)/
     x-1.0282015d-03,-2.2333161d-04, 3.9574381d-07 /
      data fpppp(16, 4,16,1),fpppp(16, 4,16,2),fpppp(16, 4,16,3)/
     x-1.1122888d-03, 1.0238490d-03,-1.4188011d-06 /
      data fpppp(16, 4,17,1),fpppp(16, 4,17,2),fpppp(16, 4,17,3)/
     x-1.3284414d-03,-2.7295514d-03, 2.4752676d-06 /
      data fpppp(16, 4,18,1),fpppp(16, 4,18,2),fpppp(16, 4,18,3)/
     x-7.9955205d-04, 1.4191519d-02,-7.0032342d-06 /
      data fpppp(16, 4,19,1),fpppp(16, 4,19,2),fpppp(16, 4,19,3)/
     x-2.8342794d-03,-3.7758554d-02,-3.9581169d-06 /
      data fpppp(16, 4,20,1),fpppp(16, 4,20,2),fpppp(16, 4,20,3)/
     x-3.9498880d-02, 1.7776798d-02, 6.5741390d-06 /
      data fpppp(16, 4,21,1),fpppp(16, 4,21,2),fpppp(16, 4,21,3)/
     x-3.9498880d-02, 1.4080600d-02, 6.4853762d-06 /
      data fpppp(16, 4,22,1),fpppp(16, 4,22,2),fpppp(16, 4,22,3)/
     x-2.8342794d-03,-2.2973762d-02,-3.6030659d-06 /
      data fpppp(16, 4,23,1),fpppp(16, 4,23,2),fpppp(16, 4,23,3)/
     x-7.9955205d-04,-4.1251450d-02,-8.3346756d-06 /
      data fpppp(16, 5, 1,1),fpppp(16, 5, 1,2),fpppp(16, 5, 1,3)/
     x 3.0213962d-03, 4.6402342d-03, 6.5211672d-06 /
      data fpppp(16, 5, 2,1),fpppp(16, 5, 2,2),fpppp(16, 5, 2,3)/
     x 1.0536730d-02, 2.4915643d-03, 2.6400652d-06 /
      data fpppp(16, 5, 3,1),fpppp(16, 5, 3,2),fpppp(16, 5, 3,3)/
     x-2.6408911d-02,-1.9083360d-03,-5.6656143d-06 /
      data fpppp(16, 5, 4,1),fpppp(16, 5, 4,2),fpppp(16, 5, 4,3)/
     x-2.6408911d-02,-2.2660229d-03,-5.6848079d-06 /
      data fpppp(16, 5, 5,1),fpppp(16, 5, 5,2),fpppp(16, 5, 5,3)/
     x 1.0536730d-02, 3.9223122d-03, 2.7168394d-06 /
      data fpppp(16, 5, 6,1),fpppp(16, 5, 6,2),fpppp(16, 5, 6,3)/
     x 3.0213962d-03,-7.2507060d-04, 6.2332639d-06 /
      data fpppp(16, 5, 7,1),fpppp(16, 5, 7,2),fpppp(16, 5, 7,3)/
     x 1.1297645d-02, 1.6457571d-04,-7.1947594d-07 /
      data fpppp(16, 5, 8,1),fpppp(16, 5, 8,2),fpppp(16, 5, 8,3)/
     x 6.8981387d-04,-7.1510005d-05, 6.2916352d-07 /
      data fpppp(16, 5, 9,1),fpppp(16, 5, 9,2),fpppp(16, 5, 9,3)/
     x 5.6396961d-04, 1.4723012d-06,-2.9854334d-07 /
      data fpppp(16, 5,10,1),fpppp(16, 5,10,2),fpppp(16, 5,10,3)/
     x 5.5001639d-04,-9.4802525d-06, 4.7110748d-08 /
      data fpppp(16, 5,11,1),fpppp(16, 5,11,2),fpppp(16, 5,11,3)/
     x-7.9552793d-04,-5.0938642d-07,-8.7438112d-08 /
      data fpppp(16, 5,12,1),fpppp(16, 5,12,2),fpppp(16, 5,12,3)/
     x-1.3730305d-04,-4.4676334d-08,-5.3121567d-08 /
      data fpppp(16, 5,13,1),fpppp(16, 5,13,2),fpppp(16, 5,13,3)/
     x 1.2137014d-03,-1.8337261d-06, 3.6404744d-08 /
      data fpppp(16, 5,14,1),fpppp(16, 5,14,2),fpppp(16, 5,14,3)/
     x 5.3793520d-04,-2.8136612d-07,-2.5619490d-08 /
      data fpppp(16, 5,15,1),fpppp(16, 5,15,2),fpppp(16, 5,15,3)/
     x 4.5860385d-04,-2.7152018d-05,-2.6117461d-07 /
      data fpppp(16, 5,16,1),fpppp(16, 5,16,2),fpppp(16, 5,16,3)/
     x 6.2753062d-04, 5.9382572d-05, 6.8736732d-07 /
      data fpppp(16, 5,17,1),fpppp(16, 5,17,2),fpppp(16, 5,17,3)/
     x 1.1824203d-03,-2.6890894d-04,-8.5772981d-07 /
      data fpppp(16, 5,18,1),fpppp(16, 5,18,2),fpppp(16, 5,18,3)/
     x 2.7151157d-03, 9.9967421d-04, 6.6755993d-06 /
      data fpppp(16, 5,19,1),fpppp(16, 5,19,2),fpppp(16, 5,19,3)/
     x 9.7635112d-03,-4.3976895d-03,-3.4312776d-07 /
      data fpppp(16, 5,20,1),fpppp(16, 5,20,2),fpppp(16, 5,20,3)/
     x 2.9530617d-03, 2.5142049d-03,-3.8490240d-06 /
      data fpppp(16, 5,21,1),fpppp(16, 5,21,2),fpppp(16, 5,21,3)/
     x 2.9530617d-03, 2.1048894d-03,-4.1045292d-06 /
      data fpppp(16, 5,22,1),fpppp(16, 5,22,2),fpppp(16, 5,22,3)/
     x 9.7635112d-03,-2.7604272d-03, 6.7889291d-07 /
      data fpppp(16, 5,23,1),fpppp(16, 5,23,2),fpppp(16, 5,23,3)/
     x 2.7151157d-03,-5.1400591d-03, 2.8430218d-06 /
      data fpppp(16, 6, 1,1),fpppp(16, 6, 1,2),fpppp(16, 6, 1,3)/
     x-9.0832419d-04, 2.5127544d-04,-7.2159426d-07 /
      data fpppp(16, 6, 2,1),fpppp(16, 6, 2,2),fpppp(16, 6, 2,3)/
     x-2.7423875d-03, 1.2820956d-04,-2.4505548d-07 /
      data fpppp(16, 6, 3,1),fpppp(16, 6, 3,2),fpppp(16, 6, 3,3)/
     x 5.4608023d-03,-1.2557558d-04, 7.9642422d-07 /
      data fpppp(16, 6, 4,1),fpppp(16, 6, 4,2),fpppp(16, 6, 4,3)/
     x 5.4608023d-03,-1.4294866d-04, 7.6085517d-07 /
      data fpppp(16, 6, 5,1),fpppp(16, 6, 5,2),fpppp(16, 6, 5,3)/
     x-2.7423875d-03, 1.9770189d-04,-1.0277928d-07 /
      data fpppp(16, 6, 6,1),fpppp(16, 6, 6,2),fpppp(16, 6, 6,3)/
     x-9.0832419d-04,-9.3208170d-06,-1.2551300d-06 /
      data fpppp(16, 6, 7,1),fpppp(16, 6, 7,2),fpppp(16, 6, 7,3)/
     x-3.0570869d-03, 6.6487703d-06, 2.7539960d-07 /
      data fpppp(16, 6, 8,1),fpppp(16, 6, 8,2),fpppp(16, 6, 8,3)/
     x-1.7695797d-04, 4.2404693d-07,-1.7687447d-07 /
      data fpppp(16, 6, 9,1),fpppp(16, 6, 9,2),fpppp(16, 6, 9,3)/
     x-1.2535428d-04, 1.2190494d-06, 7.5412882d-08 /
      data fpppp(16, 6,10,1),fpppp(16, 6,10,2),fpppp(16, 6,10,3)/
     x-1.1153609d-04, 5.8843967d-06,-2.3090850d-09 /
      data fpppp(16, 6,11,1),fpppp(16, 6,11,2),fpppp(16, 6,11,3)/
     x 2.5083826d-04, 3.6390869d-06, 3.3346995d-08 /
      data fpppp(16, 6,12,1),fpppp(16, 6,12,2),fpppp(16, 6,12,3)/
     x 7.4053676d-05, 5.3931595d-06, 2.2638868d-08 /
      data fpppp(16, 6,13,1),fpppp(16, 6,13,2),fpppp(16, 6,13,3)/
     x-2.9305350d-04, 4.6276626d-06, 4.7658717d-09 /
      data fpppp(16, 6,14,1),fpppp(16, 6,14,2),fpppp(16, 6,14,3)/
     x-1.2096236d-04, 4.0443830d-06, 2.6658200d-08 /
      data fpppp(16, 6,15,1),fpppp(16, 6,15,2),fpppp(16, 6,15,3)/
     x-1.1613431d-04, 4.2026955d-06, 8.6438153d-08 /
      data fpppp(16, 6,16,1),fpppp(16, 6,16,2),fpppp(16, 6,16,3)/
     x-1.7667287d-04, 6.1169866d-07,-1.7965520d-07 /
      data fpppp(16, 6,17,1),fpppp(16, 6,17,2),fpppp(16, 6,17,3)/
     x-3.6773503d-04, 1.5038869d-05, 3.8415598d-07 /
      data fpppp(16, 6,18,1),fpppp(16, 6,18,2),fpppp(16, 6,18,3)/
     x-8.2691091d-04,-2.9357770d-06,-1.5073936d-06 /
      data fpppp(16, 6,19,1),fpppp(16, 6,19,2),fpppp(16, 6,19,3)/
     x-3.0104369d-03, 1.5776494d-04, 1.3924853d-06 /
      data fpppp(16, 6,20,1),fpppp(16, 6,20,2),fpppp(16, 6,20,3)/
     x-5.5400333d-03,-1.2730652d-04,-1.9192178d-07 /
      data fpppp(16, 6,21,1),fpppp(16, 6,21,2),fpppp(16, 6,21,3)/
     x-5.5400333d-03,-1.1336345d-04,-1.9171682d-08 /
      data fpppp(16, 6,22,1),fpppp(16, 6,22,2),fpppp(16, 6,22,3)/
     x-3.0104369d-03, 1.0199265d-04, 7.0148486d-07 /
      data fpppp(16, 6,23,1),fpppp(16, 6,23,2),fpppp(16, 6,23,3)/
     x-8.2691091d-04, 2.0621031d-04, 1.0838579d-06 /
      data fpppp(16, 7, 1,1),fpppp(16, 7, 1,2),fpppp(16, 7, 1,3)/
     x 1.1118734d-04, 3.4048469d-05, 7.4459053d-07 /
      data fpppp(16, 7, 2,1),fpppp(16, 7, 2,2),fpppp(16, 7, 2,3)/
     x 5.1200833d-04, 8.5498926d-06, 2.6037533d-07 /
      data fpppp(16, 7, 3,1),fpppp(16, 7, 3,2),fpppp(16, 7, 3,3)/
     x 1.6668984d-02,-4.5136226d-05,-7.6753762d-07 /
      data fpppp(16, 7, 4,1),fpppp(16, 7, 4,2),fpppp(16, 7, 4,3)/
     x 1.6668984d-02,-4.6805182d-05,-7.8449699d-07 /
      data fpppp(16, 7, 5,1),fpppp(16, 7, 5,2),fpppp(16, 7, 5,3)/
     x 5.1200833d-04, 1.5225716d-05, 3.2821284d-07 /
      data fpppp(16, 7, 6,1),fpppp(16, 7, 6,2),fpppp(16, 7, 6,3)/
     x 1.1118734d-04, 9.0141320d-06, 4.9019986d-07 /
      data fpppp(16, 7, 7,1),fpppp(16, 7, 7,2),fpppp(16, 7, 7,3)/
     x 7.5897978d-04, 5.1397217d-06, 7.9727608d-08 /
      data fpppp(16, 7, 8,1),fpppp(16, 7, 8,2),fpppp(16, 7, 8,3)/
     x 3.7436726d-05, 6.2516293d-06, 1.5247032d-07 /
      data fpppp(16, 7, 9,1),fpppp(16, 7, 9,2),fpppp(16, 7, 9,3)/
     x 4.8060147d-05, 9.0265730d-06, 5.4257832d-08 /
      data fpppp(16, 7,10,1),fpppp(16, 7,10,2),fpppp(16, 7,10,3)/
     x 5.2041924d-05, 9.2198796d-06, 4.6605542d-08 /
      data fpppp(16, 7,11,1),fpppp(16, 7,11,2),fpppp(16, 7,11,3)/
     x-4.6008239d-05, 8.4450026d-06, 2.0644311d-08 /
      data fpppp(16, 7,12,1),fpppp(16, 7,12,2),fpppp(16, 7,12,3)/
     x-3.7655241d-06, 7.6567292d-06, 1.9229429d-08 /
      data fpppp(16, 7,13,1),fpppp(16, 7,13,2),fpppp(16, 7,13,3)/
     x 9.2268074d-05, 8.4087470d-06, 2.8564258d-08 /
      data fpppp(16, 7,14,1),fpppp(16, 7,14,2),fpppp(16, 7,14,3)/
     x 4.2343871d-05, 6.3304924d-06, 3.6313402d-08 /
      data fpppp(16, 7,15,1),fpppp(16, 7,15,2),fpppp(16, 7,15,3)/
     x 3.5285944d-05, 1.6644987d-05, 4.1762653d-08 /
      data fpppp(16, 7,16,1),fpppp(16, 7,16,2),fpppp(16, 7,16,3)/
     x 1.6924203d-05,-4.9819543d-06, 1.3144411d-07 /
      data fpppp(16, 7,17,1),fpppp(16, 7,17,2),fpppp(16, 7,17,3)/
     x 4.9917626d-05, 2.0413831d-05, 1.5122650d-08 /
      data fpppp(16, 7,18,1),fpppp(16, 7,18,2),fpppp(16, 7,18,3)/
     x 1.3176483d-04, 9.7730840d-06, 5.3887727d-07 /
      data fpppp(16, 7,19,1),fpppp(16, 7,19,2),fpppp(16, 7,19,3)/
     x 6.8315404d-04, 1.8358385d-05,-1.1675947d-07 /
      data fpppp(16, 7,20,1),fpppp(16, 7,20,2),fpppp(16, 7,20,3)/
     x 1.4317491d-03,-5.0613755d-05,-4.5848637d-07 /
      data fpppp(16, 7,21,1),fpppp(16, 7,21,2),fpppp(16, 7,21,3)/
     x 1.4317491d-03,-4.8678361d-05,-4.8203847d-07 /
      data fpppp(16, 7,22,1),fpppp(16, 7,22,2),fpppp(16, 7,22,3)/
     x 6.8315404d-04, 1.0616809d-05,-2.2551080d-08 /
      data fpppp(16, 7,23,1),fpppp(16, 7,23,2),fpppp(16, 7,23,3)/
     x 1.3176483d-04, 3.8803994d-05, 1.8559581d-07 /
      data fpppp(16, 8, 1,1),fpppp(16, 8, 1,2),fpppp(16, 8, 1,3)/
     x-5.4131288d-05, 2.3153454d-02,-3.5507239d-07 /
      data fpppp(16, 8, 2,1),fpppp(16, 8, 2,2),fpppp(16, 8, 2,3)/
     x-6.1450383d-05, 1.2535073d-02,-2.1959679d-07 /
      data fpppp(16, 8, 3,1),fpppp(16, 8, 3,2),fpppp(16, 8, 3,3)/
     x-8.3752257d-03,-9.1306451d-03, 5.9034608d-08 /
      data fpppp(16, 8, 4,1),fpppp(16, 8, 4,2),fpppp(16, 8, 4,3)/
     x-8.3752257d-03,-1.1034566d-02, 7.9463184d-08 /
      data fpppp(16, 8, 5,1),fpppp(16, 8, 5,2),fpppp(16, 8, 5,3)/
     x-6.1450383d-05, 2.0150758d-02,-3.0131109d-07 /
      data fpppp(16, 8, 6,1),fpppp(16, 8, 6,2),fpppp(16, 8, 6,3)/
     x-5.4131288d-05,-5.4053644d-03,-4.8643742d-08 /
      data fpppp(16, 8, 7,1),fpppp(16, 8, 7,2),fpppp(16, 8, 7,3)/
     x-2.3028018d-04, 1.4446361d-03, 6.8586302d-08 /
      data fpppp(16, 8, 8,1),fpppp(16, 8, 8,2),fpppp(16, 8, 8,3)/
     x-3.2159406d-05,-3.9340965d-04, 4.9902159d-08 /
      data fpppp(16, 8, 9,1),fpppp(16, 8, 9,2),fpppp(16, 8, 9,3)/
     x-2.1967984d-05, 1.0999549d-04, 5.1343535d-08 /
      data fpppp(16, 8,10,1),fpppp(16, 8,10,2),fpppp(16, 8,10,3)/
     x-1.3476655d-05,-2.0653499d-05, 3.5026953d-08 /
      data fpppp(16, 8,11,1),fpppp(16, 8,11,2),fpppp(16, 8,11,3)/
     x 1.8915828d-05, 1.7254516d-05, 3.4247863d-08 /
      data fpppp(16, 8,12,1),fpppp(16, 8,12,2),fpppp(16, 8,12,3)/
     x 1.2302458d-05, 1.0121492d-05, 3.1374971d-08 /
      data fpppp(16, 8,13,1),fpppp(16, 8,13,2),fpppp(16, 8,13,3)/
     x-1.7906523d-05, 8.6267967d-06, 2.8238773d-08 /
      data fpppp(16, 8,14,1),fpppp(16, 8,14,2),fpppp(16, 8,14,3)/
     x-1.1933128d-05, 1.4217038d-05, 2.8629935d-08 /
      data fpppp(16, 8,15,1),fpppp(16, 8,15,2),fpppp(16, 8,15,3)/
     x-2.1519538d-05,-1.1092312d-06, 3.3682595d-08 /
      data fpppp(16, 8,16,1),fpppp(16, 8,16,2),fpppp(16, 8,16,3)/
     x-1.2171212d-05, 1.2962869d-05, 2.0051580d-08 /
      data fpppp(16, 8,17,1),fpppp(16, 8,17,2),fpppp(16, 8,17,3)/
     x-3.4288904d-05, 5.2624335d-06, 5.5650789d-08 /
      data fpppp(16, 8,18,1),fpppp(16, 8,18,2),fpppp(16, 8,18,3)/
     x-5.8063845d-05, 6.6930386d-06,-1.0631782d-07 /
      data fpppp(16, 8,19,1),fpppp(16, 8,19,2),fpppp(16, 8,19,3)/
     x-2.0011695d-04,-1.8264272d-06, 1.5704391d-08 /
      data fpppp(16, 8,20,1),fpppp(16, 8,20,2),fpppp(16, 8,20,3)/
     x-3.7724314d-04,-2.7339166d-05,-7.4097515d-08 /
      data fpppp(16, 8,21,1),fpppp(16, 8,21,2),fpppp(16, 8,21,3)/
     x-3.7724314d-04,-2.7178416d-05,-6.6316039d-08 /
      data fpppp(16, 8,22,1),fpppp(16, 8,22,2),fpppp(16, 8,22,3)/
     x-2.0011695d-04,-2.4694296d-06,-1.5421514d-08 /
      data fpppp(16, 8,23,1),fpppp(16, 8,23,2),fpppp(16, 8,23,3)/
     x-5.8063845d-05, 9.1042975d-06, 1.0404325d-08 /
      data fpppp(16, 9, 1,1),fpppp(16, 9, 1,2),fpppp(16, 9, 1,3)/
     x-1.0983699d-04, 2.4457039d-02, 1.3058621d-06 /
      data fpppp(16, 9, 2,1),fpppp(16, 9, 2,2),fpppp(16, 9, 2,3)/
     x-3.5373772d-04, 1.3242763d-02, 6.5338563d-07 /
      data fpppp(16, 9, 3,1),fpppp(16, 9, 3,2),fpppp(16, 9, 3,3)/
     x-4.3642600d-02,-9.6396355d-03,-6.9673914d-07 /
      data fpppp(16, 9, 4,1),fpppp(16, 9, 4,2),fpppp(16, 9, 4,3)/
     x-4.3642600d-02,-1.1648973d-02,-7.8080767d-07 /
      data fpppp(16, 9, 5,1),fpppp(16, 9, 5,2),fpppp(16, 9, 5,3)/
     x-3.5373772d-04, 2.1280111d-02, 9.8965973d-07 /
      data fpppp(16, 9, 6,1),fpppp(16, 9, 6,2),fpppp(16, 9, 6,3)/
     x-1.0983699d-04,-5.6830164d-03, 4.4834239d-08 /
      data fpppp(16, 9, 7,1),fpppp(16, 9, 7,2),fpppp(16, 9, 7,3)/
     x-1.5856243d-05, 1.5082263d-03, 6.0022482d-08 /
      data fpppp(16, 9, 8,1),fpppp(16, 9, 8,2),fpppp(16, 9, 8,3)/
     x-4.1876585d-05,-4.1843101d-04, 6.2007191d-09 /
      data fpppp(16, 9, 9,1),fpppp(16, 9, 9,2),fpppp(16, 9, 9,3)/
     x-2.9767369d-05, 1.0688940d-04, 1.4994012d-08 /
      data fpppp(16, 9,10,1),fpppp(16, 9,10,2),fpppp(16, 9,10,3)/
     x-2.1896735d-05,-2.6547393d-05, 1.8263021d-08 /
      data fpppp(16, 9,11,1),fpppp(16, 9,11,2),fpppp(16, 9,11,3)/
     x-2.2903224d-05, 1.8916645d-05, 1.6472738d-08 /
      data fpppp(16, 9,12,1),fpppp(16, 9,12,2),fpppp(16, 9,12,3)/
     x-1.9326593d-05, 6.0488914d-06, 1.5860296d-08 /
      data fpppp(16, 9,13,1),fpppp(16, 9,13,2),fpppp(16, 9,13,3)/
     x-6.5162276d-06, 1.0783859d-05, 1.7973707d-08 /
      data fpppp(16, 9,14,1),fpppp(16, 9,14,2),fpppp(16, 9,14,3)/
     x-3.1983875d-06, 1.0164073d-05, 1.9365027d-08 /
      data fpppp(16, 9,15,1),fpppp(16, 9,15,2),fpppp(16, 9,15,3)/
     x-2.5248457d-06, 4.9383410d-06, 1.8221242d-08 /
      data fpppp(16, 9,16,1),fpppp(16, 9,16,2),fpppp(16, 9,16,3)/
     x-7.6401028d-06, 6.2863724d-06, 1.9014301d-08 /
      data fpppp(16, 9,17,1),fpppp(16, 9,17,2),fpppp(16, 9,17,3)/
     x 3.1461499d-06, 6.1871244d-06, 2.8210026d-09 /
      data fpppp(16, 9,18,1),fpppp(16, 9,18,2),fpppp(16, 9,18,3)/
     x 1.0585532d-05, 2.8078730d-06, 2.7342026d-08 /
      data fpppp(16, 9,19,1),fpppp(16, 9,19,2),fpppp(16, 9,19,3)/
     x 5.5230671d-05,-1.2317545d-06,-3.7597031d-08 /
      data fpppp(16, 9,20,1),fpppp(16, 9,20,2),fpppp(16, 9,20,3)/
     x 1.1032549d-04,-1.9014169d-05,-5.9595850d-08 /
      data fpppp(16, 9,21,1),fpppp(16, 9,21,2),fpppp(16, 9,21,3)/
     x 1.1032549d-04,-1.8812009d-05,-6.2191084d-08 /
      data fpppp(16, 9,22,1),fpppp(16, 9,22,2),fpppp(16, 9,22,3)/
     x 5.5230671d-05,-2.0403936d-06,-2.7216093d-08 /
      data fpppp(16, 9,23,1),fpppp(16, 9,23,2),fpppp(16, 9,23,3)/
     x 1.0585532d-05, 5.8402698d-06,-1.1586493d-08 /
      data fpppp(16,10, 1,1),fpppp(16,10, 1,2),fpppp(16,10, 1,3)/
     x-7.5136816d-04,-1.6170903d-02,-2.2034117d-06 /
      data fpppp(16,10, 2,1),fpppp(16,10, 2,2),fpppp(16,10, 2,3)/
     x-2.3916067d-03,-8.6840375d-03,-1.1078846d-06 /
      data fpppp(16,10, 3,1),fpppp(16,10, 3,2),fpppp(16,10, 3,3)/
     x 6.0752252d-02, 6.6186626d-03, 1.1557129d-06 /
      data fpppp(16,10, 4,1),fpppp(16,10, 4,2),fpppp(16,10, 4,3)/
     x 6.0752252d-02, 7.9146830d-03, 1.3026440d-06 /
      data fpppp(16,10, 5,1),fpppp(16,10, 5,2),fpppp(16,10, 5,3)/
     x-2.3916067d-03,-1.3868119d-02,-1.6956088d-06 /
      data fpppp(16,10, 6,1),fpppp(16,10, 6,2),fpppp(16,10, 6,3)/
     x-7.5136816d-04, 3.2694033d-03, 5.5409853d-10 /
      data fpppp(16,10, 7,1),fpppp(16,10, 7,2),fpppp(16,10, 7,3)/
     x-2.6467678d-04,-1.0075813d-03,-1.4038453d-07 /
      data fpppp(16,10, 8,1),fpppp(16,10, 8,2),fpppp(16,10, 8,3)/
     x-1.0401674d-04, 2.1230133d-04,-2.9519143d-08 /
      data fpppp(16,10, 9,1),fpppp(16,10, 9,2),fpppp(16,10, 9,3)/
     x-5.3112037d-05,-8.5000008d-05,-2.8354853d-08 /
      data fpppp(16,10,10,1),fpppp(16,10,10,2),fpppp(16,10,10,3)/
     x-3.5592434d-05, 1.4898803d-05,-6.3238546d-09 /
      data fpppp(16,10,11,1),fpppp(16,10,11,2),fpppp(16,10,11,3)/
     x-2.5697974d-05, 7.6925510d-07, 3.5157143d-09 /
      data fpppp(16,10,12,1),fpppp(16,10,12,2),fpppp(16,10,12,3)/
     x-1.9648460d-05, 9.3559579d-06, 7.2905381d-09 /
      data fpppp(16,10,13,1),fpppp(16,10,13,2),fpppp(16,10,13,3)/
     x-1.9032129d-05, 1.1137915d-05, 8.0651007d-09 /
      data fpppp(16,10,14,1),fpppp(16,10,14,2),fpppp(16,10,14,3)/
     x-1.9560778d-05, 3.0107597d-06, 7.7284546d-09 /
      data fpppp(16,10,15,1),fpppp(16,10,15,2),fpppp(16,10,15,3)/
     x-1.0940922d-05, 8.2018207d-06, 7.4797416d-09 /
      data fpppp(16,10,16,1),fpppp(16,10,16,2),fpppp(16,10,16,3)/
     x-4.5918792d-06, 7.3553219d-06, 4.5635041d-09 /
      data fpppp(16,10,17,1),fpppp(16,10,17,2),fpppp(16,10,17,3)/
     x-7.3162059d-06, 1.9807758d-06, 1.3287482d-09 /
      data fpppp(16,10,18,1),fpppp(16,10,18,2),fpppp(16,10,18,3)/
     x-2.3588385d-06, 4.3383833d-06,-1.4616765d-08 /
      data fpppp(16,10,19,1),fpppp(16,10,19,2),fpppp(16,10,19,3)/
     x-1.0757982d-05, 1.9604818d-08,-8.9938981d-09 /
      data fpppp(16,10,20,1),fpppp(16,10,20,2),fpppp(16,10,20,3)/
     x-2.1905325d-05,-1.4754150d-05,-1.4562081d-08 /
      data fpppp(16,10,21,1),fpppp(16,10,21,2),fpppp(16,10,21,3)/
     x-2.1905325d-05,-1.4631888d-05,-1.4171827d-08 /
      data fpppp(16,10,22,1),fpppp(16,10,22,2),fpppp(16,10,22,3)/
     x-1.0757982d-05,-4.6944080d-07,-1.0554914d-08 /
      data fpppp(16,10,23,1),fpppp(16,10,23,2),fpppp(16,10,23,3)/
     x-2.3588385d-06, 6.1723044d-06,-8.7629541d-09 /
      data fpppp(16,11, 1,1),fpppp(16,11, 1,2),fpppp(16,11, 1,3)/
     x 5.4332376d-04, 5.9883691d-03, 2.1123855d-06 /
      data fpppp(16,11, 2,1),fpppp(16,11, 2,2),fpppp(16,11, 2,3)/
     x 4.2493175d-03, 3.4847102d-03, 1.0790908d-06 /
      data fpppp(16,11, 3,1),fpppp(16,11, 3,2),fpppp(16,11, 3,3)/
     x-3.3387259d-02,-1.5435885d-03,-1.0544661d-06 /
      data fpppp(16,11, 4,1),fpppp(16,11, 4,2),fpppp(16,11, 4,3)/
     x-3.3387259d-02,-2.1327869d-03,-1.1955968d-06 /
      data fpppp(16,11, 5,1),fpppp(16,11, 5,2),fpppp(16,11, 5,3)/
     x 4.2493175d-03, 5.8415035d-03, 1.6436136d-06 /
      data fpppp(16,11, 6,1),fpppp(16,11, 6,2),fpppp(16,11, 6,3)/
     x 5.4332376d-04,-2.8496057d-03,-4.5751150d-09 /
      data fpppp(16,11, 7,1),fpppp(16,11, 7,2),fpppp(16,11, 7,3)/
     x-1.2867390d-05, 2.9016712d-04, 1.3593532d-07 /
      data fpppp(16,11, 8,1),fpppp(16,11, 8,2),fpppp(16,11, 8,3)/
     x-6.7648274d-05,-2.6247769d-04,-7.6383485d-09 /
      data fpppp(16,11, 9,1),fpppp(16,11, 9,2),fpppp(16,11, 9,3)/
     x-6.0662986d-05,-7.5255608d-06,-5.0974633d-09 /
      data fpppp(16,11,10,1),fpppp(16,11,10,2),fpppp(16,11,10,3)/
     x-3.1004083d-05,-3.0704457d-05,-9.0819503d-09 /
      data fpppp(16,11,11,1),fpppp(16,11,11,2),fpppp(16,11,11,3)/
     x-2.1175970d-05, 2.2473422d-06,-7.9534289d-10 /
      data fpppp(16,11,12,1),fpppp(16,11,12,2),fpppp(16,11,12,3)/
     x-1.6471026d-05, 5.2907436d-06, 2.9708897d-09 /
      data fpppp(16,11,13,1),fpppp(16,11,13,2),fpppp(16,11,13,3)/
     x-1.2825336d-05, 7.7973671d-06, 3.0922871d-09 /
      data fpppp(16,11,14,1),fpppp(16,11,14,2),fpppp(16,11,14,3)/
     x-7.8817982d-06, 5.2335442d-06, 2.3422278d-09 /
      data fpppp(16,11,15,1),fpppp(16,11,15,2),fpppp(16,11,15,3)/
     x-7.8881067d-06, 6.6553860d-06, 8.8910040d-10 /
      data fpppp(16,11,16,1),fpppp(16,11,16,2),fpppp(16,11,16,3)/
     x-6.9074849d-06, 4.4027111d-06,-5.2662471d-10 /
      data fpppp(16,11,17,1),fpppp(16,11,17,2),fpppp(16,11,17,3)/
     x 7.4769064d-07, 4.9531677d-06,-2.5320735d-09 /
      data fpppp(16,11,18,1),fpppp(16,11,18,2),fpppp(16,11,18,3)/
     x 4.3436382d-07, 5.8689505d-07,-1.7523450d-09 /
      data fpppp(16,11,19,1),fpppp(16,11,19,2),fpppp(16,11,19,3)/
     x 3.7477992d-06, 2.6266949d-06,-6.8177665d-10 /
      data fpppp(16,11,20,1),fpppp(16,11,20,2),fpppp(16,11,20,3)/
     x 5.8974186d-06,-1.2341991d-05,-6.5808443d-09 /
      data fpppp(16,11,21,1),fpppp(16,11,21,2),fpppp(16,11,21,3)/
     x 5.8974186d-06,-1.1913581d-05,-6.3993506d-09 /
      data fpppp(16,11,22,1),fpppp(16,11,22,2),fpppp(16,11,22,3)/
     x 3.7477992d-06, 9.1305182d-07,-1.4077513d-09 /
      data fpppp(16,11,23,1),fpppp(16,11,23,2),fpppp(16,11,23,3)/
     x 4.3436382d-07, 7.0130566d-06, 9.7006001d-10 /
      data fpppp(16,12, 1,1),fpppp(16,12, 1,2),fpppp(16,12, 1,3)/
     x 2.3490967d-04, 2.8234559d-05,-5.7131744d-07 /
      data fpppp(16,12, 2,1),fpppp(16,12, 2,2),fpppp(16,12, 2,3)/
     x-2.5417776d-03, 1.2667511d-04,-3.6183448d-07 /
      data fpppp(16,12, 3,1),fpppp(16,12, 3,2),fpppp(16,12, 3,3)/
     x 1.5085785d-02, 3.3876608d-04, 5.7682138d-08 /
      data fpppp(16,12, 4,1),fpppp(16,12, 4,2),fpppp(16,12, 4,3)/
     x 1.5085785d-02, 3.3675897d-04, 1.0908915d-07 /
      data fpppp(16,12, 5,1),fpppp(16,12, 5,2),fpppp(16,12, 5,3)/
     x-2.5417776d-03, 1.3470354d-04,-5.6746252d-07 /
      data fpppp(16,12, 6,1),fpppp(16,12, 6,2),fpppp(16,12, 6,3)/
     x 2.3490967d-04,-1.8720195d-06, 1.9978770d-07 /
      data fpppp(16,12, 7,1),fpppp(16,12, 7,2),fpppp(16,12, 7,3)/
     x 6.9674913d-05,-3.5889156d-04, 7.6974692d-08 /
      data fpppp(16,12, 8,1),fpppp(16,12, 8,2),fpppp(16,12, 8,3)/
     x-3.8788097d-06,-1.4548051d-04, 8.2505401d-08 /
      data fpppp(16,12, 9,1),fpppp(16,12, 9,2),fpppp(16,12, 9,3)/
     x 3.7837443d-05,-9.7769552d-05, 3.6321800d-08 /
      data fpppp(16,12,10,1),fpppp(16,12,10,2),fpppp(16,12,10,3)/
     x-1.7924714d-05,-3.7379223d-05, 1.6270416d-08 /
      data fpppp(16,12,11,1),fpppp(16,12,11,2),fpppp(16,12,11,3)/
     x-1.4822333d-05,-1.2353876d-05, 6.3735244d-09 /
      data fpppp(16,12,12,1),fpppp(16,12,12,2),fpppp(16,12,12,3)/
     x-1.1685208d-05, 2.3113824d-06, 3.4156750d-09 /
      data fpppp(16,12,13,1),fpppp(16,12,13,2),fpppp(16,12,13,3)/
     x-9.7981816d-06, 5.2724152d-06, 1.6587961d-09 /
      data fpppp(16,12,14,1),fpppp(16,12,14,2),fpppp(16,12,14,3)/
     x-9.7576736d-06, 5.3079844d-06,-6.1931920d-10 /
      data fpppp(16,12,15,1),fpppp(16,12,15,2),fpppp(16,12,15,3)/
     x-7.0989190d-06, 4.8540973d-06,-1.4813751d-09 /
      data fpppp(16,12,16,1),fpppp(16,12,16,2),fpppp(16,12,16,3)/
     x-4.6124836d-06, 6.1224493d-06,-1.7141243d-09 /
      data fpppp(16,12,17,1),fpppp(16,12,17,2),fpppp(16,12,17,3)/
     x-8.0458109d-06, 1.1961008d-06,-1.2674591d-10 /
      data fpppp(16,12,18,1),fpppp(16,12,18,2),fpppp(16,12,18,3)/
     x-6.4213465d-06,-5.3630902d-08, 1.1484313d-09 /
      data fpppp(16,12,19,1),fpppp(16,12,19,2),fpppp(16,12,19,3)/
     x-3.9403896d-06, 1.5264253d-06, 2.4781524d-09 /
      data fpppp(16,12,20,1),fpppp(16,12,20,2),fpppp(16,12,20,3)/
     x-4.7804588d-06,-8.9358470d-06,-1.3854184d-09 /
      data fpppp(16,12,21,1),fpppp(16,12,21,2),fpppp(16,12,21,3)/
     x-4.7804588d-06,-8.6290851d-06,-1.2367133d-09 /
      data fpppp(16,12,22,1),fpppp(16,12,22,2),fpppp(16,12,22,3)/
     x-3.9403896d-06, 2.9937787d-07, 1.8833320d-09 /
      data fpppp(16,12,23,1),fpppp(16,12,23,2),fpppp(16,12,23,3)/
     x-6.4213465d-06, 4.5477971d-06, 3.3790079d-09 /
      data fpppp(16,13, 1,1),fpppp(16,13, 1,2),fpppp(16,13, 1,3)/
     x-9.9553045d-04, 5.3305747d-03,-7.0293044d-07 /
      data fpppp(16,13, 2,1),fpppp(16,13, 2,2),fpppp(16,13, 2,3)/
     x 9.0483642d-04, 3.0229220d-03,-3.2950351d-07 /
      data fpppp(16,13, 3,1),fpppp(16,13, 3,2),fpppp(16,13, 3,3)/
     x-5.0736315d-03,-1.6628860d-03, 4.5639481d-07 /
      data fpppp(16,13, 4,1),fpppp(16,13, 4,2),fpppp(16,13, 4,3)/
     x-5.0736315d-03,-2.1164198d-03, 4.8142375d-07 /
      data fpppp(16,13, 5,1),fpppp(16,13, 5,2),fpppp(16,13, 5,3)/
     x 9.0483642d-04, 4.8370573d-03,-4.2961925d-07 /
      data fpppp(16,13, 6,1),fpppp(16,13, 6,2),fpppp(16,13, 6,3)/
     x-9.9553045d-04,-1.4724326d-03,-3.2749640d-07 /
      data fpppp(16,13, 7,1),fpppp(16,13, 7,2),fpppp(16,13, 7,3)/
     x-2.2459759d-05, 1.1162532d-04,-8.8815550d-08 /
      data fpppp(16,13, 8,1),fpppp(16,13, 8,2),fpppp(16,13, 8,3)/
     x 6.5127375d-06,-2.6445502d-04, 1.3463286d-08 /
      data fpppp(16,13, 9,1),fpppp(16,13, 9,2),fpppp(16,13, 9,3)/
     x-2.2537319d-04,-1.0171465d-04, 4.4925550d-08 /
      data fpppp(16,13,10,1),fpppp(16,13,10,2),fpppp(16,13,10,3)/
     x-5.3376379d-06,-6.8596413d-05, 3.8052597d-08 /
      data fpppp(16,13,11,1),fpppp(16,13,11,2),fpppp(16,13,11,3)/
     x-7.0322816d-06,-2.1187129d-05, 1.8776721d-08 /
      data fpppp(16,13,12,1),fpppp(16,13,12,2),fpppp(16,13,12,3)/
     x-7.7907639d-06,-3.2454457d-06, 8.4521994d-09 /
      data fpppp(16,13,13,1),fpppp(16,13,13,2),fpppp(16,13,13,3)/
     x-7.5897829d-06, 2.1891803d-06, 2.6938961d-09 /
      data fpppp(16,13,14,1),fpppp(16,13,14,2),fpppp(16,13,14,3)/
     x-5.8591633d-06, 5.6344367d-06, 6.0378880d-10 /
      data fpppp(16,13,15,1),fpppp(16,13,15,2),fpppp(16,13,15,3)/
     x-7.9007348d-06, 4.3539921d-06,-1.3399269d-09 /
      data fpppp(16,13,16,1),fpppp(16,13,16,2),fpppp(16,13,16,3)/
     x-9.3711642d-06, 3.2542374d-06,-1.0603101d-09 /
      data fpppp(16,13,17,1),fpppp(16,13,17,2),fpppp(16,13,17,3)/
     x-7.3030498d-06, 1.0236975d-06, 1.0691126d-09 /
      data fpppp(16,13,18,1),fpppp(16,13,18,2),fpppp(16,13,18,3)/
     x-6.9254590d-06, 1.2727995d-07, 4.1218300d-09 /
      data fpppp(16,13,19,1),fpppp(16,13,19,2),fpppp(16,13,19,3)/
     x-8.9886458d-06,-1.8323002d-06,-1.9372991d-10 /
      data fpppp(16,13,20,1),fpppp(16,13,20,2),fpppp(16,13,20,3)/
     x-4.8510015d-06,-5.5644044d-06, 1.7708948d-09 /
      data fpppp(16,13,21,1),fpppp(16,13,21,2),fpppp(16,13,21,3)/
     x-4.8510015d-06,-5.5747493d-06, 1.5225221d-09 /
      data fpppp(16,13,22,1),fpppp(16,13,22,2),fpppp(16,13,22,3)/
     x-8.9886458d-06,-1.7909208d-06, 7.9976087d-10 /
      data fpppp(16,13,23,1),fpppp(16,13,23,2),fpppp(16,13,23,3)/
     x-6.9254590d-06,-2.7892815d-08, 3.9623956d-10 /
      data fpppp(16,14, 1,1),fpppp(16,14, 1,2),fpppp(16,14, 1,3)/
     x 4.0486819d-03, 6.0495506d-03,-5.1606994d-07 /
      data fpppp(16,14, 2,1),fpppp(16,14, 2,2),fpppp(16,14, 2,3)/
     x 1.2831713d-03, 3.3784577d-03,-2.1793319d-07 /
      data fpppp(16,14, 3,1),fpppp(16,14, 3,2),fpppp(16,14, 3,3)/
     x-3.5174154d-03,-2.0644943d-03, 4.0609460d-07 /
      data fpppp(16,14, 4,1),fpppp(16,14, 4,2),fpppp(16,14, 4,3)/
     x-3.5174154d-03,-2.5559267d-03, 4.3205877d-07 /
      data fpppp(16,14, 5,1),fpppp(16,14, 5,2),fpppp(16,14, 5,3)/
     x 1.2831713d-03, 5.3441875d-03,-3.2178987d-07 /
      data fpppp(16,14, 6,1),fpppp(16,14, 6,2),fpppp(16,14, 6,3)/
     x 4.0486819d-03,-1.3219361d-03,-1.2660739d-07 /
      data fpppp(16,14, 7,1),fpppp(16,14, 7,2),fpppp(16,14, 7,3)/
     x 1.3554250d-04, 1.6631540d-04,-2.3832186d-07 /
      data fpppp(16,14, 8,1),fpppp(16,14, 8,2),fpppp(16,14, 8,3)/
     x-5.3383548d-06,-2.5363262d-04,-6.6995760d-08 /
      data fpppp(16,14, 9,1),fpppp(16,14, 9,2),fpppp(16,14, 9,3)/
     x 8.5254472d-04,-1.3842038d-04, 2.2774228d-08 /
      data fpppp(16,14,10,1),fpppp(16,14,10,2),fpppp(16,14,10,3)/
     x 8.9166540d-06,-8.9871646d-05, 3.8163490d-08 /
      data fpppp(16,14,11,1),fpppp(16,14,11,2),fpppp(16,14,11,3)/
     x 4.6471566d-07,-2.9907692d-05, 2.4944185d-08 /
      data fpppp(16,14,12,1),fpppp(16,14,12,2),fpppp(16,14,12,3)/
     x-1.0574878d-06,-8.4858669d-06, 1.1552866d-08 /
      data fpppp(16,14,13,1),fpppp(16,14,13,2),fpppp(16,14,13,3)/
     x-2.3219983d-06, 5.7307440d-07, 5.7116748d-09 /
      data fpppp(16,14,14,1),fpppp(16,14,14,2),fpppp(16,14,14,3)/
     x-4.6083966d-06, 3.0261144d-06, 2.1226047d-09 /
      data fpppp(16,14,15,1),fpppp(16,14,15,2),fpppp(16,14,15,3)/
     x-4.4281928d-06, 4.1219408d-06, 1.4612648d-09 /
      data fpppp(16,14,16,1),fpppp(16,14,16,2),fpppp(16,14,16,3)/
     x-6.4684600d-06, 2.1403622d-06, 8.7619611d-10 /
      data fpppp(16,14,17,1),fpppp(16,14,17,2),fpppp(16,14,17,3)/
     x-9.2331102d-06, 1.0759228d-06, 1.3867885d-09 /
      data fpppp(16,14,18,1),fpppp(16,14,18,2),fpppp(16,14,18,3)/
     x-1.0499944d-05,-2.5511473d-06, 5.7744526d-10 /
      data fpppp(16,14,19,1),fpppp(16,14,19,2),fpppp(16,14,19,3)/
     x-8.5097303d-06, 3.7212774d-07, 3.7874879d-09 /
      data fpppp(16,14,20,1),fpppp(16,14,20,2),fpppp(16,14,20,3)/
     x-1.1089744d-05,-4.6741677d-06, 5.6575975d-10 /
      data fpppp(16,14,21,1),fpppp(16,14,21,2),fpppp(16,14,21,3)/
     x-1.1089744d-05,-4.4236196d-06, 7.8950258d-10 /
      data fpppp(16,14,22,1),fpppp(16,14,22,2),fpppp(16,14,22,3)/
     x-8.5097303d-06,-6.3006458d-07, 2.8925165d-09 /
      data fpppp(16,14,23,1),fpppp(16,14,23,2),fpppp(16,14,23,3)/
     x-1.0499944d-05, 1.2070739d-06, 3.9335878d-09 /
      data fpppp(16,15, 1,1),fpppp(16,15, 1,2),fpppp(16,15, 1,3)/
     x-1.3772258d-02, 6.9972058d-04,-6.6952374d-08 /
      data fpppp(16,15, 2,1),fpppp(16,15, 2,2),fpppp(16,15, 2,3)/
     x-9.9888054d-04, 3.4153119d-04,-3.2058543d-08 /
      data fpppp(16,15, 3,1),fpppp(16,15, 3,2),fpppp(16,15, 3,3)/
     x 1.0195064d-02,-4.2601976d-04, 5.6168663d-08 /
      data fpppp(16,15, 4,1),fpppp(16,15, 4,2),fpppp(16,15, 4,3)/
     x 1.0195064d-02,-4.2601579d-04, 3.2622920d-08 /
      data fpppp(16,15, 5,1),fpppp(16,15, 5,2),fpppp(16,15, 5,3)/
     x-9.9888054d-04, 3.4151534d-04, 6.2124429d-08 /
      data fpppp(16,15, 6,1),fpppp(16,15, 6,2),fpppp(16,15, 6,3)/
     x-1.3772258d-02, 6.9978005d-04,-4.2013852d-07 /
      data fpppp(16,15, 7,1),fpppp(16,15, 7,2),fpppp(16,15, 7,3)/
     x-7.0557652d-04, 2.4482584d-04, 1.1845530d-07 /
      data fpppp(16,15, 8,1),fpppp(16,15, 8,2),fpppp(16,15, 8,3)/
     x 1.2401243d-04,-3.0146773d-04, 7.6055010d-08 /
      data fpppp(16,15, 9,1),fpppp(16,15, 9,2),fpppp(16,15, 9,3)/
     x-3.0197606d-03,-2.0348117d-04, 4.7084203d-08 /
      data fpppp(16,15,10,1),fpppp(16,15,10,2),fpppp(16,15,10,3)/
     x 3.4367619d-05,-9.5290919d-05, 1.8531521d-08 /
      data fpppp(16,15,11,1),fpppp(16,15,11,2),fpppp(16,15,11,3)/
     x 1.0768348d-05,-3.2450225d-05, 1.4107558d-08 /
      data fpppp(16,15,12,1),fpppp(16,15,12,2),fpppp(16,15,12,3)/
     x 5.3968874d-07,-1.2268658d-05, 8.9741849d-09 /
      data fpppp(16,15,13,1),fpppp(16,15,13,2),fpppp(16,15,13,3)/
     x-7.2312463d-07,-2.0954990d-06, 5.2070000d-09 /
      data fpppp(16,15,14,1),fpppp(16,15,14,2),fpppp(16,15,14,3)/
     x-2.9263973d-07, 2.3054178d-06, 4.0775653d-09 /
      data fpppp(16,15,15,1),fpppp(16,15,15,2),fpppp(16,15,15,3)/
     x-2.0690283d-06, 1.2791981d-06, 3.1401816d-09 /
      data fpppp(16,15,16,1),fpppp(16,15,16,2),fpppp(16,15,16,3)/
     x-2.8198461d-06, 2.2964557d-06, 3.1224973d-09 /
      data fpppp(16,15,17,1),fpppp(16,15,17,2),fpppp(16,15,17,3)/
     x-2.1826654d-06, 6.8797518d-07, 1.9905329d-09 /
      data fpppp(16,15,18,1),fpppp(16,15,18,2),fpppp(16,15,18,3)/
     x-2.8873532d-06,-1.7799785d-06, 1.8142187d-09 /
      data fpppp(16,15,19,1),fpppp(16,15,19,2),fpppp(16,15,19,3)/
     x-4.1001051d-06,-7.0230419d-07,-7.4634035d-10 /
      data fpppp(16,15,20,1),fpppp(16,15,20,2),fpppp(16,15,20,3)/
     x-1.8887787d-06,-2.7740900d-06,-3.5928878d-10 /
      data fpppp(16,15,21,1),fpppp(16,15,21,2),fpppp(16,15,21,3)/
     x-1.8887787d-06,-2.6770406d-06,-4.8940823d-10 /
      data fpppp(16,15,22,1),fpppp(16,15,22,2),fpppp(16,15,22,3)/
     x-4.1001051d-06,-1.0905018d-06,-2.2586254d-10 /
      data fpppp(16,15,23,1),fpppp(16,15,23,2),fpppp(16,15,23,3)/
     x-2.8873532d-06,-3.2423726d-07,-1.3757307d-10 /
      data fpppp(16,16, 1,1),fpppp(16,16, 1,2),fpppp(16,16, 1,3)/
     x 3.5991709d-02,-3.1098101d-03, 1.1291969d-06 /
      data fpppp(16,16, 2,1),fpppp(16,16, 2,2),fpppp(16,16, 2,3)/
     x 6.6591726d-04,-2.1948655d-03, 4.8536251d-07 /
      data fpppp(16,16, 3,1),fpppp(16,16, 3,2),fpppp(16,16, 3,3)/
     x-2.4764419d-02,-7.8731591d-04,-8.8594728d-07 /
      data fpppp(16,16, 4,1),fpppp(16,16, 4,2),fpppp(16,16, 4,3)/
     x-2.4764419d-02, 1.8051436d-04,-9.0053395d-07 /
      data fpppp(16,16, 5,1),fpppp(16,16, 5,2),fpppp(16,16, 5,3)/
     x 6.6591726d-04,-6.0661866d-03, 5.4370919d-07 /
      data fpppp(16,16, 6,1),fpppp(16,16, 6,2),fpppp(16,16, 6,3)/
     x 3.5991709d-02, 1.1407644d-02, 9.1039684d-07 /
      data fpppp(16,16, 7,1),fpppp(16,16, 7,2),fpppp(16,16, 7,3)/
     x 2.8113117d-03,-4.8408283d-03, 4.7582152d-08 /
      data fpppp(16,16, 8,1),fpppp(16,16, 8,2),fpppp(16,16, 8,3)/
     x 7.9520506d-04,-2.3906135d-03,-3.2505655d-08 /
      data fpppp(16,16, 9,1),fpppp(16,16, 9,2),fpppp(16,16, 9,3)/
     x 5.0599567d-03, 4.4470395d-03,-7.1067039d-08 /
      data fpppp(16,16,10,1),fpppp(16,16,10,2),fpppp(16,16,10,3)/
     x 4.7265036d-05,-3.1090745d-03,-3.8744196d-08 /
      data fpppp(16,16,11,1),fpppp(16,16,11,2),fpppp(16,16,11,3)/
     x 1.7420607d-05, 7.8999630d-04,-1.7719927d-08 /
      data fpppp(16,16,12,1),fpppp(16,16,12,2),fpppp(16,16,12,3)/
     x 7.4235086d-06,-2.2738388d-04,-3.7329453d-09 /
      data fpppp(16,16,13,1),fpppp(16,16,13,2),fpppp(16,16,13,3)/
     x 6.9061097d-07, 5.4961883d-05, 9.7919540d-10 /
      data fpppp(16,16,14,1),fpppp(16,16,14,2),fpppp(16,16,14,3)/
     x-1.1638565d-06,-1.5356930d-05, 2.7349935d-09 /
      data fpppp(16,16,15,1),fpppp(16,16,15,2),fpppp(16,16,15,3)/
     x 4.6230530d-07, 3.5968411d-06, 3.3877015d-09 /
      data fpppp(16,16,16,1),fpppp(16,16,16,2),fpppp(16,16,16,3)/
     x 3.0183455d-06, 1.5643478d-06, 3.4671851d-09 /
      data fpppp(16,16,17,1),fpppp(16,16,17,2),fpppp(16,16,17,3)/
     x 2.0258729d-06,-2.8454740d-08, 2.3879058d-09 /
      data fpppp(16,16,18,1),fpppp(16,16,18,2),fpppp(16,16,18,3)/
     x 2.8145794d-06,-8.9515745d-07, 2.5005860d-11 /
      data fpppp(16,16,19,1),fpppp(16,16,19,2),fpppp(16,16,19,3)/
     x 4.1209913d-06,-1.6036596d-07,-1.8562566d-09 /
      data fpppp(16,16,20,1),fpppp(16,16,20,2),fpppp(16,16,20,3)/
     x 2.1149720d-06,-1.6394911d-06,-2.0514103d-09 /
      data fpppp(16,16,21,1),fpppp(16,16,21,2),fpppp(16,16,21,3)/
     x 2.1149720d-06,-1.5718463d-06,-2.1363877d-09 /
      data fpppp(16,16,22,1),fpppp(16,16,22,2),fpppp(16,16,22,3)/
     x 4.1209913d-06,-4.3094505d-07,-1.5163470d-09 /
      data fpppp(16,16,23,1),fpppp(16,16,23,2),fpppp(16,16,23,3)/
     x 2.8145794d-06, 1.1951414d-07,-1.2496553d-09 /
      data fpppp(16,17, 1,1),fpppp(16,17, 1,2),fpppp(16,17, 1,3)/
     x-4.2901902d-02,-2.5696571d-03,-5.1717382d-07 /
      data fpppp(16,17, 2,1),fpppp(16,17, 2,2),fpppp(16,17, 2,3)/
     x-8.9325774d-04,-1.1305045d-04,-1.4192403d-07 /
      data fpppp(16,17, 3,1),fpppp(16,17, 3,2),fpppp(16,17, 3,3)/
     x 3.3372385d-02, 6.2882423d-03, 6.6104928d-07 /
      data fpppp(16,17, 4,1),fpppp(16,17, 4,2),fpppp(16,17, 4,3)/
     x 3.3372385d-02, 4.2982549d-03, 6.6303271d-07 /
      data fpppp(16,17, 5,1),fpppp(16,17, 5,2),fpppp(16,17, 5,3)/
     x-8.9325774d-04, 7.8468992d-03,-1.4985774d-07 /
      data fpppp(16,17, 6,1),fpppp(16,17, 6,2),fpppp(16,17, 6,3)/
     x-4.2901902d-02,-3.2419468d-02,-4.8742240d-07 /
      data fpppp(16,17, 7,1),fpppp(16,17, 7,2),fpppp(16,17, 7,3)/
     x-2.1932976d-03, 2.2425190d-02,-7.2113069d-08 /
      data fpppp(16,17, 8,1),fpppp(16,17, 8,2),fpppp(16,17, 8,3)/
     x-9.0301713d-04,-6.3497272d-03,-9.1902192d-08 /
      data fpppp(16,17, 9,1),fpppp(16,17, 9,2),fpppp(16,17, 9,3)/
     x-3.1926474d-03, 1.7959199d-03,-6.4727682d-08 /
      data fpppp(16,17,10,1),fpppp(16,17,10,2),fpppp(16,17,10,3)/
     x-2.1709464d-05,-4.9763294d-04,-5.2638385d-08 /
      data fpppp(16,17,11,1),fpppp(16,17,11,2),fpppp(16,17,11,3)/
     x 4.8566065d-06, 1.2247214d-04,-3.4101614d-08 /
      data fpppp(16,17,12,1),fpppp(16,17,12,2),fpppp(16,17,12,3)/
     x 7.1154465d-06,-3.9388755d-05,-2.0343701d-08 /
      data fpppp(16,17,13,1),fpppp(16,17,13,2),fpppp(16,17,13,3)/
     x 6.5084784d-06, 8.7053731d-06,-9.6048300d-09 /
      data fpppp(16,17,14,1),fpppp(16,17,14,2),fpppp(16,17,14,3)/
     x 4.2877005d-06,-3.2808577d-06,-3.7120489d-09 /
      data fpppp(16,17,15,1),fpppp(16,17,15,2),fpppp(16,17,15,3)/
     x 7.9918150d-07, 7.2260076d-07,-5.9190140d-10 /
      data fpppp(16,17,16,1),fpppp(16,17,16,2),fpppp(16,17,16,3)/
     x 2.6099514d-07,-4.4322919d-07, 1.8692788d-10 /
      data fpppp(16,17,17,1),fpppp(16,17,17,2),fpppp(16,17,17,3)/
     x 3.3053113d-06, 3.2532459d-07, 1.2609633d-10 /
      data fpppp(16,17,18,1),fpppp(16,17,18,2),fpppp(16,17,18,3)/
     x 4.1505843d-06, 5.6810058d-07,-1.3254170d-09 /
      data fpppp(16,17,19,1),fpppp(16,17,19,2),fpppp(16,17,19,3)/
     x 4.8382761d-06,-1.5972086d-06,-1.5321865d-09 /
      data fpppp(16,17,20,1),fpppp(16,17,20,2),fpppp(16,17,20,3)/
     x 8.5671266d-06, 4.7306227d-08,-2.8896828d-09 /
      data fpppp(16,17,21,1),fpppp(16,17,21,2),fpppp(16,17,21,3)/
     x 8.5671266d-06,-9.1906565d-08,-2.8694267d-09 /
      data fpppp(16,17,22,1),fpppp(16,17,22,2),fpppp(16,17,22,3)/
     x 4.8382761d-06,-1.0403575d-06,-1.6132109d-09 /
      data fpppp(16,17,23,1),fpppp(16,17,23,2),fpppp(16,17,23,3)/
     x 4.1505843d-06,-1.5200913d-06,-1.0215753d-09 /
      data fpppp(16,18, 1,1),fpppp(16,18, 1,2),fpppp(16,18, 1,3)/
     x 1.4564230d-02,-1.3240091d-05, 1.8462468d-07 /
      data fpppp(16,18, 2,1),fpppp(16,18, 2,2),fpppp(16,18, 2,3)/
     x-3.3241898d-05,-5.1181934d-06, 5.4521119d-08 /
      data fpppp(16,18, 3,1),fpppp(16,18, 3,2),fpppp(16,18, 3,3)/
     x-1.2783151d-02, 1.4077857d-05,-2.2324611d-07 /
      data fpppp(16,18, 4,1),fpppp(16,18, 4,2),fpppp(16,18, 4,3)/
     x-1.2783151d-02, 1.0941885d-05,-2.2504182d-07 /
      data fpppp(16,18, 5,1),fpppp(16,18, 5,2),fpppp(16,18, 5,3)/
     x-3.3241898d-05, 7.4256945d-06, 6.1703973d-08 /
      data fpppp(16,18, 6,1),fpppp(16,18, 6,2),fpppp(16,18, 6,3)/
     x 1.4564230d-02,-6.0279670d-05, 1.5768898d-07 /
      data fpppp(16,18, 7,1),fpppp(16,18, 7,2),fpppp(16,18, 7,3)/
     x 1.3745378d-04, 3.7124945d-05, 6.8423091d-08 /
      data fpppp(16,18, 8,1),fpppp(16,18, 8,2),fpppp(16,18, 8,3)/
     x 9.4329124d-05,-4.1651956d-06, 4.4786336d-08 /
      data fpppp(16,18, 9,1),fpppp(16,18, 9,2),fpppp(16,18, 9,3)/
     x 5.0992169d-04, 1.1285596d-07, 2.1497144d-08 /
      data fpppp(16,18,10,1),fpppp(16,18,10,2),fpppp(16,18,10,3)/
     x-2.5021065d-05, 2.1772243d-06, 1.0108320d-08 /
      data fpppp(16,18,11,1),fpppp(16,18,11,2),fpppp(16,18,11,3)/
     x-1.1937664d-05,-4.5333873d-07, 3.1246722d-09 /
      data fpppp(16,18,12,1),fpppp(16,18,12,2),fpppp(16,18,12,3)/
     x-3.6794941d-06,-3.6380748d-07, 2.2400267d-10 /
      data fpppp(16,18,13,1),fpppp(16,18,13,2),fpppp(16,18,13,3)/
     x 5.5317176d-07, 1.5063727d-06,-1.2231839d-09 /
      data fpppp(16,18,14,1),fpppp(16,18,14,2),fpppp(16,18,14,3)/
     x 2.6116150d-06,-2.2156716d-06,-1.7898187d-09 /
      data fpppp(16,18,15,1),fpppp(16,18,15,2),fpppp(16,18,15,3)/
     x 5.9984951d-06, 2.5724961d-06,-2.1447052d-09 /
      data fpppp(16,18,16,1),fpppp(16,18,16,2),fpppp(16,18,16,3)/
     x 6.3790014d-06,-6.1162772d-07,-2.7334385d-09 /
      data fpppp(16,18,17,1),fpppp(16,18,17,2),fpppp(16,18,17,3)/
     x 6.3968727d-06,-9.8288325d-07,-3.7335139d-09 /
      data fpppp(16,18,18,1),fpppp(16,18,18,2),fpppp(16,18,18,3)/
     x 8.0516713d-06, 1.4620624d-06,-4.3599049d-09 /
      data fpppp(16,18,19,1),fpppp(16,18,19,2),fpppp(16,18,19,3)/
     x 8.4001591d-06,-5.1380937d-07,-5.9075073d-09 /
      data fpppp(16,18,20,1),fpppp(16,18,20,2),fpppp(16,18,20,3)/
     x 7.5274628d-06,-1.4654837d-07,-5.7832531d-09 /
      data fpppp(16,18,21,1),fpppp(16,18,21,2),fpppp(16,18,21,3)/
     x 7.5274628d-06,-2.4847528d-07,-5.8594677d-09 /
      data fpppp(16,18,22,1),fpppp(16,18,22,2),fpppp(16,18,22,3)/
     x 8.4001591d-06,-1.0610173d-07,-5.6026488d-09 /
      data fpppp(16,18,23,1),fpppp(16,18,23,2),fpppp(16,18,23,3)/
     x 8.0516713d-06,-6.6841247d-08,-5.5031239d-09 /
      data fpppp(16,19, 1,1),fpppp(16,19, 1,2),fpppp(16,19, 1,3)/
     x 3.3070435d-02,-9.5867563d-18, 2.1551770d-07 /
      data fpppp(16,19, 2,1),fpppp(16,19, 2,2),fpppp(16,19, 2,3)/
     x 1.3557656d-04,-5.2624267d-18, 1.5614356d-08 /
      data fpppp(16,19, 3,1),fpppp(16,19, 3,2),fpppp(16,19, 3,3)/
     x-2.9140876d-02, 9.3443104d-19,-4.1288665d-07 /
      data fpppp(16,19, 4,1),fpppp(16,19, 4,2),fpppp(16,19, 4,3)/
     x-2.9140876d-02, 1.8761564d-18,-4.1264744d-07 /
      data fpppp(16,19, 5,1),fpppp(16,19, 5,2),fpppp(16,19, 5,3)/
     x 1.3557656d-04,-5.6779100d-20, 1.4657504d-08 /
      data fpppp(16,19, 6,1),fpppp(16,19, 6,2),fpppp(16,19, 6,3)/
     x 3.3070435d-02, 3.4825258d-19, 2.1910590d-07 /
      data fpppp(16,19, 7,1),fpppp(16,19, 7,2),fpppp(16,19, 7,3)/
     x 3.7238783d-04,-1.3636013d-18, 1.3460743d-07 /
      data fpppp(16,19, 8,1),fpppp(16,19, 8,2),fpppp(16,19, 8,3)/
     x 3.2151297d-04, 2.8973057d-18, 1.2545056d-07 /
      data fpppp(16,19, 9,1),fpppp(16,19, 9,2),fpppp(16,19, 9,3)/
     x 7.9672702d-04, 3.7687523d-18, 8.4897550d-08 /
      data fpppp(16,19,10,1),fpppp(16,19,10,2),fpppp(16,19,10,3)/
     x-4.7093495d-05, 1.1796213d-18, 5.0957627d-08 /
      data fpppp(16,19,11,1),fpppp(16,19,11,2),fpppp(16,19,11,3)/
     x-2.7523286d-05, 4.6707182d-18, 2.5034395d-08 /
      data fpppp(16,19,12,1),fpppp(16,19,12,2),fpppp(16,19,12,3)/
     x-1.1478184d-05, 4.7301374d-18, 1.0169289d-08 /
      data fpppp(16,19,13,1),fpppp(16,19,13,2),fpppp(16,19,13,3)/
     x-2.0383708d-06,-1.1324961d-18, 1.7396989d-09 /
      data fpppp(16,19,14,1),fpppp(16,19,14,2),fpppp(16,19,14,3)/
     x 2.9719988d-06, 9.8336068d-19,-2.2588092d-09 /
      data fpppp(16,19,15,1),fpppp(16,19,15,2),fpppp(16,19,15,3)/
     x 9.8085409d-06, 4.9805418d-18,-4.3908802d-09 /
      data fpppp(16,19,16,1),fpppp(16,19,16,2),fpppp(16,19,16,3)/
     x 9.9611915d-06,-1.0982526d-18,-5.7566309d-09 /
      data fpppp(16,19,17,1),fpppp(16,19,17,2),fpppp(16,19,17,3)/
     x 8.9706846d-06,-1.6537789d-18,-7.1366096d-09 /
      data fpppp(16,19,18,1),fpppp(16,19,18,2),fpppp(16,19,18,3)/
     x 1.1219878d-05,-1.3315521d-18,-6.9132313d-09 /
      data fpppp(16,19,19,1),fpppp(16,19,19,2),fpppp(16,19,19,3)/
     x 1.1149300d-05,-2.1066444d-18,-8.9401449d-09 /
      data fpppp(16,19,20,1),fpppp(16,19,20,2),fpppp(16,19,20,3)/
     x 8.6283185d-06, 1.6615366d-18,-8.0895954d-09 /
      data fpppp(16,19,21,1),fpppp(16,19,21,2),fpppp(16,19,21,3)/
     x 8.6283185d-06,-4.0817313d-19,-8.2046510d-09 /
      data fpppp(16,19,22,1),fpppp(16,19,22,2),fpppp(16,19,22,3)/
     x 1.1149300d-05, 4.5684973d-18,-8.4799228d-09 /
      data fpppp(16,19,23,1),fpppp(16,19,23,2),fpppp(16,19,23,3)/
     x 1.1219878d-05, 3.4354576d-18,-8.6390644d-09 /
      data fpppp(17, 1, 1,1),fpppp(17, 1, 1,2),fpppp(17, 1, 1,3)/
     x 1.2969810d-01,-1.7573036d-17, 8.9143193d-06 /
      data fpppp(17, 1, 2,1),fpppp(17, 1, 2,2),fpppp(17, 1, 2,3)/
     x 1.4020148d-01,-1.3739209d-17, 3.0821476d-06 /
      data fpppp(17, 1, 3,1),fpppp(17, 1, 3,2),fpppp(17, 1, 3,3)/
     x 1.3698126d-01,-4.5657647d-17,-9.2367349d-06 /
      data fpppp(17, 1, 4,1),fpppp(17, 1, 4,2),fpppp(17, 1, 4,3)/
     x 1.3698126d-01, 9.7626866d-18,-9.5493345d-06 /
      data fpppp(17, 1, 5,1),fpppp(17, 1, 5,2),fpppp(17, 1, 5,3)/
     x 1.4020148d-01, 2.2037819d-17, 4.3325459d-06 /
      data fpppp(17, 1, 6,1),fpppp(17, 1, 6,2),fpppp(17, 1, 6,3)/
     x 1.2969810d-01, 7.7610587d-18, 4.2253256d-06 /
      data fpppp(17, 1, 7,1),fpppp(17, 1, 7,2),fpppp(17, 1, 7,3)/
     x 1.2988493d-01,-8.3985224d-18, 4.2650177d-06 /
      data fpppp(17, 1, 8,1),fpppp(17, 1, 8,2),fpppp(17, 1, 8,3)/
     x 1.2452306d-01,-3.5940702d-17,-1.9836979d-07 /
      data fpppp(17, 1, 9,1),fpppp(17, 1, 9,2),fpppp(17, 1, 9,3)/
     x 1.1863720d-01,-2.2374196d-18, 7.7994889d-07 /
      data fpppp(17, 1,10,1),fpppp(17, 1,10,2),fpppp(17, 1,10,3)/
     x 1.1912258d-01, 4.1025806d-17, 7.1588339d-07 /
      data fpppp(17, 1,11,1),fpppp(17, 1,11,2),fpppp(17, 1,11,3)/
     x 1.0144012d-01,-6.4304481d-17,-1.4851940d-06 /
      data fpppp(17, 1,12,1),fpppp(17, 1,12,2),fpppp(17, 1,12,3)/
     x 1.2044382d-01,-3.7409430d-18, 1.6677845d-06 /
      data fpppp(17, 1,13,1),fpppp(17, 1,13,2),fpppp(17, 1,13,3)/
     x 1.3842802d-01,-2.1840705d-17, 1.7572278d-06 /
      data fpppp(17, 1,14,1),fpppp(17, 1,14,2),fpppp(17, 1,14,3)/
     x 1.1915485d-01, 2.2570511d-17,-1.5514034d-06 /
      data fpppp(17, 1,15,1),fpppp(17, 1,15,2),fpppp(17, 1,15,3)/
     x 1.1857502d-01,-1.2781622d-17, 1.4105319d-06 /
      data fpppp(17, 1,16,1),fpppp(17, 1,16,2),fpppp(17, 1,16,3)/
     x 1.2444758d-01,-8.8884117d-18,-3.0233574d-07 /
      data fpppp(17, 1,17,1),fpppp(17, 1,17,2),fpppp(17, 1,17,3)/
     x 1.2929782d-01, 1.3136412d-17, 4.2552838d-06 /
      data fpppp(17, 1,18,1),fpppp(17, 1,18,2),fpppp(17, 1,18,3)/
     x 1.2987112d-01, 2.4973811d-19, 4.1873703d-06 /
      data fpppp(17, 1,19,1),fpppp(17, 1,19,2),fpppp(17, 1,19,3)/
     x 1.3800211d-01, 1.4453546d-18, 4.3069112d-06 /
      data fpppp(17, 1,20,1),fpppp(17, 1,20,2),fpppp(17, 1,20,3)/
     x 1.2739214d-01, 2.3272731d-17,-9.5003801d-06 /
      data fpppp(17, 1,21,1),fpppp(17, 1,21,2),fpppp(17, 1,21,3)/
     x 1.2739214d-01,-7.6557593d-18,-9.1888480d-06 /
      data fpppp(17, 1,22,1),fpppp(17, 1,22,2),fpppp(17, 1,22,3)/
     x 1.3800211d-01, 1.6688418d-17, 3.0607827d-06 /
      data fpppp(17, 1,23,1),fpppp(17, 1,23,2),fpppp(17, 1,23,3)/
     x 1.2987112d-01, 1.0176885d-16, 8.8603523d-06 /
      data fpppp(17, 2, 1,1),fpppp(17, 2, 1,2),fpppp(17, 2, 1,3)/
     x 7.0879705d-02, 1.0370265d-03, 3.1833304d-06 /
      data fpppp(17, 2, 2,1),fpppp(17, 2, 2,2),fpppp(17, 2, 2,3)/
     x 7.4826345d-02, 5.3826214d-04, 1.0525420d-06 /
      data fpppp(17, 2, 3,1),fpppp(17, 2, 3,2),fpppp(17, 2, 3,3)/
     x 7.4587571d-02,-4.9035912d-04,-3.4531078d-06 /
      data fpppp(17, 2, 4,1),fpppp(17, 2, 4,2),fpppp(17, 2, 4,3)/
     x 7.4587571d-02,-5.6063814d-04,-3.5586768d-06 /
      data fpppp(17, 2, 5,1),fpppp(17, 2, 5,2),fpppp(17, 2, 5,3)/
     x 7.4826345d-02, 8.1937821d-04, 1.4748177d-06 /
      data fpppp(17, 2, 6,1),fpppp(17, 2, 6,2),fpppp(17, 2, 6,3)/
     x 7.0879705d-02,-1.7158781d-05, 1.5997965d-06 /
      data fpppp(17, 2, 7,1),fpppp(17, 2, 7,2),fpppp(17, 2, 7,3)/
     x 7.1342599d-02,-8.1798308d-04, 1.7915043d-06 /
      data fpppp(17, 2, 8,1),fpppp(17, 2, 8,2),fpppp(17, 2, 8,3)/
     x 6.9018462d-02, 3.2879888d-03,-1.2304705d-07 /
      data fpppp(17, 2, 9,1),fpppp(17, 2, 9,2),fpppp(17, 2, 9,3)/
     x 6.6210357d-02,-5.2729400d-03, 3.0110899d-07 /
      data fpppp(17, 2,10,1),fpppp(17, 2,10,2),fpppp(17, 2,10,3)/
     x 6.6469672d-02, 1.0575445d-02, 2.9755279d-07 /
      data fpppp(17, 2,11,1),fpppp(17, 2,11,2),fpppp(17, 2,11,3)/
     x 5.7846751d-02,-1.4126580d-02,-7.8793704d-07 /
      data fpppp(17, 2,12,1),fpppp(17, 2,12,2),fpppp(17, 2,12,3)/
     x 6.7122733d-02, 4.1080633d-04, 7.5115179d-07 /
      data fpppp(17, 2,13,1),fpppp(17, 2,13,2),fpppp(17, 2,13,3)/
     x 7.5898586d-02, 1.3822168d-02, 7.9424657d-07 /
      data fpppp(17, 2,14,1),fpppp(17, 2,14,2),fpppp(17, 2,14,3)/
     x 6.6486590d-02,-9.2358587d-03,-8.0972264d-07 /
      data fpppp(17, 2,15,1),fpppp(17, 2,15,2),fpppp(17, 2,15,3)/
     x 6.6187798d-02, 4.8970463d-05, 6.0821203d-07 /
      data fpppp(17, 2,16,1),fpppp(17, 2,16,2),fpppp(17, 2,16,3)/
     x 6.8989320d-02, 1.8817739d-03,-1.7506199d-07 /
      data fpppp(17, 2,17,1),fpppp(17, 2,17,2),fpppp(17, 2,17,3)/
     x 7.0997887d-02,-6.7803649d-04, 1.7917105d-06 /
      data fpppp(17, 2,18,1),fpppp(17, 2,18,2),fpppp(17, 2,18,3)/
     x 7.1003517d-02, 8.5974843d-04, 1.5945603d-06 /
      data fpppp(17, 2,19,1),fpppp(17, 2,19,2),fpppp(17, 2,19,3)/
     x 7.3865550d-02,-5.9290653d-04, 1.4985956d-06 /
      data fpppp(17, 2,20,1),fpppp(17, 2,20,2),fpppp(17, 2,20,3)/
     x 7.1830157d-02,-8.0343379d-05,-3.5603330d-06 /
      data fpppp(17, 2,21,1),fpppp(17, 2,21,2),fpppp(17, 2,21,3)/
     x 7.1830157d-02,-1.6065277d-04,-3.4528234d-06 /
      data fpppp(17, 2,22,1),fpppp(17, 2,22,2),fpppp(17, 2,22,3)/
     x 7.3865550d-02,-2.7166898d-04, 1.0685573d-06 /
      data fpppp(17, 2,23,1),fpppp(17, 2,23,2),fpppp(17, 2,23,3)/
     x 7.1003517d-02,-3.4489238d-04, 3.2072042d-06 /
      data fpppp(17, 3, 1,1),fpppp(17, 3, 1,2),fpppp(17, 3, 1,3)/
     x-2.1982176d-02,-1.2271674d-02, 1.2047069d-06 /
      data fpppp(17, 3, 2,1),fpppp(17, 3, 2,2),fpppp(17, 3, 2,3)/
     x-2.8410326d-02,-7.2542935d-03, 1.5852591d-06 /
      data fpppp(17, 3, 3,1),fpppp(17, 3, 3,2),fpppp(17, 3, 3,3)/
     x-4.8372389d-02, 2.6891127d-03, 2.4983994d-06 /
      data fpppp(17, 3, 4,1),fpppp(17, 3, 4,2),fpppp(17, 3, 4,3)/
     x-4.8372389d-02, 4.1033287d-03, 2.3274748d-06 /
      data fpppp(17, 3, 5,1),fpppp(17, 3, 5,2),fpppp(17, 3, 5,3)/
     x-2.8410326d-02,-1.2911158d-02, 2.2689572d-06 /
      data fpppp(17, 3, 6,1),fpppp(17, 3, 6,2),fpppp(17, 3, 6,3)/
     x-2.1982176d-02, 8.9415660d-03,-1.3591610d-06 /
      data fpppp(17, 3, 7,1),fpppp(17, 3, 7,2),fpppp(17, 3, 7,3)/
     x-2.5462620d-02,-4.5698250d-03,-3.7496109d-06 /
      data fpppp(17, 3, 8,1),fpppp(17, 3, 8,2),fpppp(17, 3, 8,3)/
     x-1.8334103d-02, 3.2476516d-03, 7.3331147d-07 /
      data fpppp(17, 3, 9,1),fpppp(17, 3, 9,2),fpppp(17, 3, 9,3)/
     x-1.5088066d-02,-6.4105182d-04,-7.8354282d-07 /
      data fpppp(17, 3,10,1),fpppp(17, 3,10,2),fpppp(17, 3,10,3)/
     x-1.5074654d-02, 2.6819248d-04,-3.8957617d-07 /
      data fpppp(17, 3,11,1),fpppp(17, 3,11,2),fpppp(17, 3,11,3)/
     x-6.7766452d-03,-3.9376661d-05, 5.1642658d-07 /
      data fpppp(17, 3,12,1),fpppp(17, 3,12,2),fpppp(17, 3,12,3)/
     x-1.5571546d-02, 3.8031994d-05,-9.3416766d-07 /
      data fpppp(17, 3,13,1),fpppp(17, 3,13,2),fpppp(17, 3,13,3)/
     x-2.3935972d-02,-2.4660198d-05,-9.8895438d-07 /
      data fpppp(17, 3,14,1),fpppp(17, 3,14,2),fpppp(17, 3,14,3)/
     x-1.5073878d-02, 2.0560353d-04, 6.6031116d-07 /
      data fpppp(17, 3,15,1),fpppp(17, 3,15,2),fpppp(17, 3,15,3)/
     x-1.4975767d-02,-5.6016966d-04,-1.0603484d-06 /
      data fpppp(17, 3,16,1),fpppp(17, 3,16,2),fpppp(17, 3,16,3)/
     x-1.8241415d-02, 3.2085406d-03, 7.8932020d-07 /
      data fpppp(17, 3,17,1),fpppp(17, 3,17,2),fpppp(17, 3,17,3)/
     x-2.3571368d-02,-4.7363667d-03,-3.6087034d-06 /
      data fpppp(17, 3,18,1),fpppp(17, 3,18,2),fpppp(17, 3,18,3)/
     x-2.2369246d-02, 1.0039061d-02,-1.3033179d-06 /
      data fpppp(17, 3,19,1),fpppp(17, 3,19,2),fpppp(17, 3,19,3)/
     x-2.7316266d-02,-1.8249612d-02, 2.1398291d-06 /
      data fpppp(17, 3,20,1),fpppp(17, 3,20,2),fpppp(17, 3,20,3)/
     x-4.6550765d-02, 7.1567929d-03, 2.3118867d-06 /
      data fpppp(17, 3,21,1),fpppp(17, 3,21,2),fpppp(17, 3,21,3)/
     x-4.6550765d-02, 5.2511761d-03, 2.4715158d-06 /
      data fpppp(17, 3,22,1),fpppp(17, 3,22,2),fpppp(17, 3,22,3)/
     x-2.7316266d-02,-1.0627144d-02, 1.5013126d-06 /
      data fpppp(17, 3,23,1),fpppp(17, 3,23,2),fpppp(17, 3,23,3)/
     x-2.2369246d-02,-1.8545191d-02, 1.0911189d-06 /
      data fpppp(17, 4, 1,1),fpppp(17, 4, 1,2),fpppp(17, 4, 1,3)/
     x 4.3081606d-03,-3.2949019d-02,-1.3907196d-05 /
      data fpppp(17, 4, 2,1),fpppp(17, 4, 2,2),fpppp(17, 4, 2,3)/
     x 8.6839162d-04,-1.8352251d-02,-6.8501530d-06 /
      data fpppp(17, 4, 3,1),fpppp(17, 4, 3,2),fpppp(17, 4, 3,3)/
     x 4.0649612d-02, 1.1358761d-02, 7.8623260d-06 /
      data fpppp(17, 4, 4,1),fpppp(17, 4, 4,2),fpppp(17, 4, 4,3)/
     x 4.0649612d-02, 1.4102371d-02, 8.5793977d-06 /
      data fpppp(17, 4, 5,1),fpppp(17, 4, 5,2),fpppp(17, 4, 5,3)/
     x 8.6839162d-04,-2.9326691d-02,-9.7184399d-06 /
      data fpppp(17, 4, 6,1),fpppp(17, 4, 6,2),fpppp(17, 4, 6,3)/
     x 4.3081606d-03, 8.2051317d-03,-3.1511194d-06 /
      data fpppp(17, 4, 7,1),fpppp(17, 4, 7,2),fpppp(17, 4, 7,3)/
     x 1.1652253d-02, 1.8234485d-03, 1.4458802d-06 /
      data fpppp(17, 4, 8,1),fpppp(17, 4, 8,2),fpppp(17, 4, 8,3)/
     x 5.7812081d-03,-1.2443144d-03,-1.1439552d-06 /
      data fpppp(17, 4, 9,1),fpppp(17, 4, 9,2),fpppp(17, 4, 9,3)/
     x 4.6640358d-03, 3.9221870d-04, 2.5214707d-07 /
      data fpppp(17, 4,10,1),fpppp(17, 4,10,2),fpppp(17, 4,10,3)/
     x 4.5009781d-03,-1.0192518d-04,-1.3591088d-07 /
      data fpppp(17, 4,11,1),fpppp(17, 4,11,2),fpppp(17, 4,11,3)/
     x 2.2050399d-03, 2.1177084d-05,-3.0408304d-07 /
      data fpppp(17, 4,12,1),fpppp(17, 4,12,2),fpppp(17, 4,12,3)/
     x 4.5403636d-03,-6.7551274d-06, 7.0916606d-08 /
      data fpppp(17, 4,13,1),fpppp(17, 4,13,2),fpppp(17, 4,13,3)/
     x 6.7974145d-03,-1.3290735d-05, 9.8613653d-08 /
      data fpppp(17, 4,14,1),fpppp(17, 4,14,2),fpppp(17, 4,14,3)/
     x 4.4883953d-03, 3.8453472d-05,-4.1889063d-07 /
      data fpppp(17, 4,15,1),fpppp(17, 4,15,2),fpppp(17, 4,15,3)/
     x 4.5778519d-03,-1.3731500d-04, 3.0293322d-07 /
      data fpppp(17, 4,16,1),fpppp(17, 4,16,2),fpppp(17, 4,16,3)/
     x 5.7315188d-03, 7.2543085d-04,-1.1761772d-06 /
      data fpppp(17, 4,17,1),fpppp(17, 4,17,2),fpppp(17, 4,17,3)/
     x 8.8020077d-03,-1.7205403d-03, 1.2698248d-06 /
      data fpppp(17, 4,18,1),fpppp(17, 4,18,2),fpppp(17, 4,18,3)/
     x 5.0260566d-03, 1.2010549d-02,-3.1334572d-06 /
      data fpppp(17, 4,19,1),fpppp(17, 4,19,2),fpppp(17, 4,19,3)/
     x 1.1602984d-03,-3.5979144d-02,-9.2923590d-06 /
      data fpppp(17, 4,20,1),fpppp(17, 4,20,2),fpppp(17, 4,20,3)/
     x 5.4934589d-02, 1.7485774d-02, 8.4215026d-06 /
      data fpppp(17, 4,21,1),fpppp(17, 4,21,2),fpppp(17, 4,21,3)/
     x 5.4934589d-02, 1.4023433d-02, 7.7367540d-06 /
      data fpppp(17, 4,22,1),fpppp(17, 4,22,2),fpppp(17, 4,22,3)/
     x 1.1602984d-03,-2.2129779d-02,-6.5533646d-06 /
      data fpppp(17, 4,23,1),fpppp(17, 4,23,2),fpppp(17, 4,23,3)/
     x 5.0260566d-03,-3.9924569d-02,-1.3404686d-05 /
      data fpppp(17, 5, 1,1),fpppp(17, 5, 1,2),fpppp(17, 5, 1,3)/
     x 2.0161431d-03,-6.6263092d-03, 8.7747161d-06 /
      data fpppp(17, 5, 2,1),fpppp(17, 5, 2,2),fpppp(17, 5, 2,3)/
     x 8.4250655d-03,-3.5513028d-03, 4.2137517d-06 /
      data fpppp(17, 5, 3,1),fpppp(17, 5, 3,2),fpppp(17, 5, 3,3)/
     x-1.1211987d-02, 2.7368036d-03,-5.3328996d-06 /
      data fpppp(17, 5, 4,1),fpppp(17, 5, 4,2),fpppp(17, 5, 4,3)/
     x-1.1211987d-02, 3.2638916d-03,-5.7298765d-06 /
      data fpppp(17, 5, 5,1),fpppp(17, 5, 5,2),fpppp(17, 5, 5,3)/
     x 8.4250655d-03,-5.6596546d-03, 5.8016592d-06 /
      data fpppp(17, 5, 6,1),fpppp(17, 5, 6,2),fpppp(17, 5, 6,3)/
     x 2.0161431d-03, 1.2800099d-03, 2.8200631d-06 /
      data fpppp(17, 5, 7,1),fpppp(17, 5, 7,2),fpppp(17, 5, 7,3)/
     x-3.3716674d-03,-3.8128442d-04,-2.7790377d-07 /
      data fpppp(17, 5, 8,1),fpppp(17, 5, 8,2),fpppp(17, 5, 8,3)/
     x-1.2753642d-03, 7.6955144d-05, 3.7722139d-07 /
      data fpppp(17, 5, 9,1),fpppp(17, 5, 9,2),fpppp(17, 5, 9,3)/
     x-1.1196156d-03,-3.6989845d-05,-2.0473909d-07 /
      data fpppp(17, 5,10,1),fpppp(17, 5,10,2),fpppp(17, 5,10,3)/
     x-1.1098569d-03, 2.4817911d-06,-4.1957747d-08 /
      data fpppp(17, 5,11,1),fpppp(17, 5,11,2),fpppp(17, 5,11,3)/
     x-5.0070562d-04,-1.4208480d-06, 3.6028907d-08 /
      data fpppp(17, 5,12,1),fpppp(17, 5,12,2),fpppp(17, 5,12,3)/
     x-1.1274625d-03, 2.7690291d-06,-4.6014616d-08 /
      data fpppp(17, 5,13,1),fpppp(17, 5,13,2),fpppp(17, 5,13,3)/
     x-1.7352552d-03, 3.3353628d-07,-6.8200150d-08 /
      data fpppp(17, 5,14,1),fpppp(17, 5,14,2),fpppp(17, 5,14,3)/
     x-1.1160941d-03,-2.8336119d-06, 4.2926845d-08 /
      data fpppp(17, 5,15,1),fpppp(17, 5,15,2),fpppp(17, 5,15,3)/
     x-1.1165731d-03,-9.8876215d-06,-1.9982662d-07 /
      data fpppp(17, 5,16,1),fpppp(17, 5,16,2),fpppp(17, 5,16,3)/
     x-1.3083833d-03,-8.0864952d-08, 4.0184145d-07 /
      data fpppp(17, 5,17,1),fpppp(17, 5,17,2),fpppp(17, 5,17,3)/
     x-1.6969500d-03,-3.3453360d-05,-2.1096551d-07 /
      data fpppp(17, 5,18,1),fpppp(17, 5,18,2),fpppp(17, 5,18,3)/
     x 1.3508017d-03, 1.2203043d-04, 2.7487727d-06 /
      data fpppp(17, 5,19,1),fpppp(17, 5,19,2),fpppp(17, 5,19,3)/
     x 7.3173871d-03,-5.2945031d-04, 5.3311133d-06 /
      data fpppp(17, 5,20,1),fpppp(17, 5,20,2),fpppp(17, 5,20,3)/
     x-3.1635368d-02, 3.1123335d-04,-5.4453086d-06 /
      data fpppp(17, 5,21,1),fpppp(17, 5,21,2),fpppp(17, 5,21,3)/
     x-3.1635368d-02, 2.6168589d-04,-5.0840109d-06 /
      data fpppp(17, 5,22,1),fpppp(17, 5,22,2),fpppp(17, 5,22,3)/
     x 7.3173871d-03,-3.3126048d-04, 3.8859227d-06 /
      data fpppp(17, 5,23,1),fpppp(17, 5,23,2),fpppp(17, 5,23,3)/
     x 1.3508017d-03,-6.2118144d-04, 8.1682377d-06 /
      data fpppp(17, 6, 1,1),fpppp(17, 6, 1,2),fpppp(17, 6, 1,3)/
     x-7.3466643d-04, 2.1609091d-04,-5.1972539d-07 /
      data fpppp(17, 6, 2,1),fpppp(17, 6, 2,2),fpppp(17, 6, 2,3)/
     x-2.9307875d-03, 1.0535760d-04,-2.3885076d-07 /
      data fpppp(17, 6, 3,1),fpppp(17, 6, 3,2),fpppp(17, 6, 3,3)/
     x-2.4602242d-03,-1.2391869d-04, 3.6303701d-07 /
      data fpppp(17, 6, 4,1),fpppp(17, 6, 4,2),fpppp(17, 6, 4,3)/
     x-2.4602242d-03,-1.3793508d-04, 3.6301328d-07 /
      data fpppp(17, 6, 5,1),fpppp(17, 6, 5,2),fpppp(17, 6, 5,3)/
     x-2.9307875d-03, 1.6142319d-04,-2.3875583d-07 /
      data fpppp(17, 6, 6,1),fpppp(17, 6, 6,2),fpppp(17, 6, 6,3)/
     x-7.3466643d-04, 5.8449737d-06,-5.2008139d-07 /
      data fpppp(17, 6, 7,1),fpppp(17, 6, 7,2),fpppp(17, 6, 7,3)/
     x 8.3000547d-04, 1.3436084d-05, 2.1400809d-07 /
      data fpppp(17, 6, 8,1),fpppp(17, 6, 8,2),fpppp(17, 6, 8,3)/
     x 3.2523349d-04, 1.3270303d-06,-1.0543442d-07 /
      data fpppp(17, 6, 9,1),fpppp(17, 6, 9,2),fpppp(17, 6, 9,3)/
     x 3.1311705d-04, 6.2490914d-06, 6.5592464d-08 /
      data fpppp(17, 6,10,1),fpppp(17, 6,10,2),fpppp(17, 6,10,3)/
     x 3.2165200d-04, 4.8026461d-06, 2.6633280d-08 /
      data fpppp(17, 6,11,1),fpppp(17, 6,11,2),fpppp(17, 6,11,3)/
     x 1.6034671d-04, 6.7276797d-06, 2.3785842d-09 /
      data fpppp(17, 6,12,1),fpppp(17, 6,12,2),fpppp(17, 6,12,3)/
     x 3.2496401d-04, 4.9455060d-06, 2.0165760d-08 /
      data fpppp(17, 6,13,1),fpppp(17, 6,13,2),fpppp(17, 6,13,3)/
     x 4.8507524d-04, 5.6798212d-06, 3.3720169d-08 /
      data fpppp(17, 6,14,1),fpppp(17, 6,14,2),fpppp(17, 6,14,3)/
     x 3.1261225d-04, 5.5094236d-06, 1.1746453d-08 /
      data fpppp(17, 6,15,1),fpppp(17, 6,15,2),fpppp(17, 6,15,3)/
     x 2.9843342d-04, 5.4972875d-06, 7.8107193d-08 /
      data fpppp(17, 6,16,1),fpppp(17, 6,16,2),fpppp(17, 6,16,3)/
     x 3.1819519d-04, 5.7732458d-06,-9.6247610d-08 /
      data fpppp(17, 6,17,1),fpppp(17, 6,17,2),fpppp(17, 6,17,3)/
     x 3.8035706d-04, 1.2408952d-05, 2.1313928d-07 /
      data fpppp(17, 6,18,1),fpppp(17, 6,18,2),fpppp(17, 6,18,3)/
     x-5.0646096d-04, 1.6898344d-05,-5.1098281d-07 /
      data fpppp(17, 6,19,1),fpppp(17, 6,19,2),fpppp(17, 6,19,3)/
     x-2.2872705d-03, 1.1945836d-04,-7.5120008d-08 /
      data fpppp(17, 6,20,1),fpppp(17, 6,20,2),fpppp(17, 6,20,3)/
     x 7.2947019d-03,-1.1808529d-04, 2.2126326d-07 /
      data fpppp(17, 6,21,1),fpppp(17, 6,21,2),fpppp(17, 6,21,3)/
     x 7.2947019d-03,-1.0795490d-04, 2.3538750d-07 /
      data fpppp(17, 6,22,1),fpppp(17, 6,22,2),fpppp(17, 6,22,3)/
     x-2.2872705d-03, 7.8936770d-05,-1.3161696d-07 /
      data fpppp(17, 6,23,1),fpppp(17, 6,23,2),fpppp(17, 6,23,3)/
     x-5.0646096d-04, 1.6885432d-04,-2.9911924d-07 /
      data fpppp(17, 7, 1,1),fpppp(17, 7, 1,2),fpppp(17, 7, 1,3)/
     x 8.8315233d-05, 2.2734141d-05, 5.3097984d-07 /
      data fpppp(17, 7, 2,1),fpppp(17, 7, 2,2),fpppp(17, 7, 2,3)/
     x 6.7832118d-04, 2.8313799d-06, 1.8000257d-07 /
      data fpppp(17, 7, 3,1),fpppp(17, 7, 3,2),fpppp(17, 7, 3,3)/
     x-2.4794624d-03,-3.9164322d-05,-5.6248765d-07 /
      data fpppp(17, 7, 4,1),fpppp(17, 7, 4,2),fpppp(17, 7, 4,3)/
     x-2.4794624d-03,-4.0307197d-05,-5.7929456d-07 /
      data fpppp(17, 7, 5,1),fpppp(17, 7, 5,2),fpppp(17, 7, 5,3)/
     x 6.7832118d-04, 7.4028787d-06, 2.4723018d-07 /
      data fpppp(17, 7, 6,1),fpppp(17, 7, 6,2),fpppp(17, 7, 6,3)/
     x 8.8315233d-05, 5.5910205d-06, 2.7887629d-07 /
      data fpppp(17, 7, 7,1),fpppp(17, 7, 7,2),fpppp(17, 7, 7,3)/
     x-2.7827093d-04, 6.3457379d-06, 8.3350205d-08 /
      data fpppp(17, 7, 8,1),fpppp(17, 7, 8,2),fpppp(17, 7, 8,3)/
     x-1.0377302d-04, 6.4535689d-06, 1.3154740d-07 /
      data fpppp(17, 7, 9,1),fpppp(17, 7, 9,2),fpppp(17, 7, 9,3)/
     x-7.9284459d-05, 8.3385230d-06, 5.5966014d-08 /
      data fpppp(17, 7,10,1),fpppp(17, 7,10,2),fpppp(17, 7,10,3)/
     x-7.3725327d-05, 8.6530548d-06, 3.9126405d-08 /
      data fpppp(17, 7,11,1),fpppp(17, 7,11,2),fpppp(17, 7,11,3)/
     x-2.9381394d-05, 8.7239250d-06, 3.0132870d-08 /
      data fpppp(17, 7,12,1),fpppp(17, 7,12,2),fpppp(17, 7,12,3)/
     x-7.4055744d-05, 8.9655088d-06, 2.1905341d-08 /
      data fpppp(17, 7,13,1),fpppp(17, 7,13,2),fpppp(17, 7,13,3)/
     x-1.2144156d-04, 8.0326537d-06, 2.0948298d-08 /
      data fpppp(17, 7,14,1),fpppp(17, 7,14,2),fpppp(17, 7,14,3)/
     x-8.0497338d-05, 8.9696620d-06, 3.9778282d-08 /
      data fpppp(17, 7,15,1),fpppp(17, 7,15,2),fpppp(17, 7,15,3)/
     x-8.9855540d-05, 6.6010481d-06, 4.0965263d-08 /
      data fpppp(17, 7,16,1),fpppp(17, 7,16,2),fpppp(17, 7,16,3)/
     x-1.0370153d-04, 1.3578102d-05, 1.0750837d-07 /
      data fpppp(17, 7,17,1),fpppp(17, 7,17,2),fpppp(17, 7,17,3)/
     x-1.4892068d-04, 6.2202738d-06, 5.1643464d-08 /
      data fpppp(17, 7,18,1),fpppp(17, 7,18,2),fpppp(17, 7,18,3)/
     x 6.1424241d-05, 1.3982278d-05, 2.5741890d-07 /
      data fpppp(17, 7,19,1),fpppp(17, 7,19,2),fpppp(17, 7,19,3)/
     x 5.2772696d-04, 1.0379412d-05, 2.0469002d-07 /
      data fpppp(17, 7,20,1),fpppp(17, 7,20,2),fpppp(17, 7,20,3)/
     x-1.9657641d-03,-4.5676478d-05,-5.0141823d-07 /
      data fpppp(17, 7,21,1),fpppp(17, 7,21,2),fpppp(17, 7,21,3)/
     x-1.9657641d-03,-4.4605756d-05,-4.8827954d-07 /
      data fpppp(17, 7,22,1),fpppp(17, 7,22,2),fpppp(17, 7,22,3)/
     x 5.2772696d-04, 6.0965230d-06, 1.5213528d-07 /
      data fpppp(17, 7,23,1),fpppp(17, 7,23,2),fpppp(17, 7,23,3)/
     x 6.1424241d-05, 3.0043112d-05, 4.5449918d-07 /
      data fpppp(17, 8, 1,1),fpppp(17, 8, 1,2),fpppp(17, 8, 1,3)/
     x-5.2818122d-05,-4.1659552d-03,-1.6154285d-07 /
      data fpppp(17, 8, 2,1),fpppp(17, 8, 2,2),fpppp(17, 8, 2,3)/
     x-3.1586086d-04,-2.2603820d-03,-1.2046176d-07 /
      data fpppp(17, 8, 3,1),fpppp(17, 8, 3,2),fpppp(17, 8, 3,3)/
     x 6.8939321d-04, 1.6274943d-03,-3.8048527d-08 /
      data fpppp(17, 8, 4,1),fpppp(17, 8, 4,2),fpppp(17, 8, 4,3)/
     x 6.8939321d-04, 1.9696101d-03,-2.8217575d-08 /
      data fpppp(17, 8, 5,1),fpppp(17, 8, 5,2),fpppp(17, 8, 5,3)/
     x-3.1586086d-04,-3.6288453d-03,-1.5978556d-07 /
      data fpppp(17, 8, 6,1),fpppp(17, 8, 6,2),fpppp(17, 8, 6,3)/
     x-5.2818122d-05, 9.6578214d-04,-1.4078574d-08 /
      data fpppp(17, 8, 7,1),fpppp(17, 8, 7,2),fpppp(17, 8, 7,3)/
     x 4.3010746d-05,-2.6528088d-04, 6.0511039d-08 /
      data fpppp(17, 8, 8,1),fpppp(17, 8, 8,2),fpppp(17, 8, 8,3)/
     x 2.9921996d-06, 6.8325149d-05, 4.5979850d-08 /
      data fpppp(17, 8, 9,1),fpppp(17, 8, 9,2),fpppp(17, 8, 9,3)/
     x 6.0455583d-06,-1.6325875d-05, 4.6203350d-08 /
      data fpppp(17, 8,10,1),fpppp(17, 8,10,2),fpppp(17, 8,10,3)/
     x 1.4142542d-05, 1.2751028d-05, 3.5006569d-08 /
      data fpppp(17, 8,11,1),fpppp(17, 8,11,2),fpppp(17, 8,11,3)/
     x 8.9551732d-06, 8.4983575d-06, 3.1088189d-08 /
      data fpppp(17, 8,12,1),fpppp(17, 8,12,2),fpppp(17, 8,12,3)/
     x 2.1648045d-05, 9.3548916d-06, 2.9714388d-08 /
      data fpppp(17, 8,13,1),fpppp(17, 8,13,2),fpppp(17, 8,13,3)/
     x 3.4343736d-05, 1.1780653d-05, 2.9882333d-08 /
      data fpppp(17, 8,14,1),fpppp(17, 8,14,2),fpppp(17, 8,14,3)/
     x 1.9350414d-05, 3.5367925d-06, 2.5816134d-08 /
      data fpppp(17, 8,15,1),fpppp(17, 8,15,2),fpppp(17, 8,15,3)/
     x 2.1302199d-05, 1.5901634d-05, 3.2453208d-08 /
      data fpppp(17, 8,16,1),fpppp(17, 8,16,2),fpppp(17, 8,16,3)/
     x 1.1471451d-05, 1.6956888d-06, 2.1012596d-08 /
      data fpppp(17, 8,17,1),fpppp(17, 8,17,2),fpppp(17, 8,17,3)/
     x 2.2093248d-05, 7.9438303d-06, 3.9831497d-08 /
      data fpppp(17, 8,18,1),fpppp(17, 8,18,2),fpppp(17, 8,18,3)/
     x-3.6268837d-05, 3.3970657d-06,-3.8309805d-08 /
      data fpppp(17, 8,19,1),fpppp(17, 8,19,2),fpppp(17, 8,19,3)/
     x-1.5049536d-04,-1.9599425d-06,-7.6596693d-08 /
      data fpppp(17, 8,20,1),fpppp(17, 8,20,2),fpppp(17, 8,20,3)/
     x 5.3955163d-04,-2.4676486d-05,-4.1506843d-08 /
      data fpppp(17, 8,21,1),fpppp(17, 8,21,2),fpppp(17, 8,21,3)/
     x 5.3955163d-04,-2.4427560d-05,-4.4101565d-08 /
      data fpppp(17, 8,22,1),fpppp(17, 8,22,2),fpppp(17, 8,22,3)/
     x-1.5049536d-04,-2.9556473d-06,-6.6217804d-08 /
      data fpppp(17, 8,23,1),fpppp(17, 8,23,2),fpppp(17, 8,23,3)/
     x-3.6268837d-05, 7.1309587d-06,-7.7230641d-08 /
      data fpppp(17, 9, 1,1),fpppp(17, 9, 1,2),fpppp(17, 9, 1,3)/
     x-6.3516007d-05,-4.3696340d-03, 6.0453556d-07 /
      data fpppp(17, 9, 2,1),fpppp(17, 9, 2,2),fpppp(17, 9, 2,3)/
     x 4.5321052d-04,-2.3668885d-03, 2.8810644d-07 /
      data fpppp(17, 9, 3,1),fpppp(17, 9, 3,2),fpppp(17, 9, 3,3)/
     x 1.0681959d-02, 1.7197340d-03,-3.6951020d-07 /
      data fpppp(17, 9, 4,1),fpppp(17, 9, 4,2),fpppp(17, 9, 4,3)/
     x 1.0681959d-02, 2.0784401d-03,-4.0529026d-07 /
      data fpppp(17, 9, 5,1),fpppp(17, 9, 5,2),fpppp(17, 9, 5,3)/
     x 4.5321052d-04,-3.8017129d-03, 4.3122670d-07 /
      data fpppp(17, 9, 6,1),fpppp(17, 9, 6,2),fpppp(17, 9, 6,3)/
     x-6.3516007d-05, 1.0109576d-03, 6.7834599d-08 /
      data fpppp(17, 9, 7,1),fpppp(17, 9, 7,2),fpppp(17, 9, 7,3)/
     x-7.6788115d-05,-2.8220670d-04, 4.4024645d-08 /
      data fpppp(17, 9, 8,1),fpppp(17, 9, 8,2),fpppp(17, 9, 8,3)/
     x-5.0204495d-05, 6.3959324d-05, 1.1300588d-08 /
      data fpppp(17, 9, 9,1),fpppp(17, 9, 9,2),fpppp(17, 9, 9,3)/
     x-3.8796986d-05,-2.3639291d-05, 1.4492019d-08 /
      data fpppp(17, 9,10,1),fpppp(17, 9,10,2),fpppp(17, 9,10,3)/
     x-3.2567704d-05, 9.7493230d-06, 1.7034194d-08 /
      data fpppp(17, 9,11,1),fpppp(17, 9,11,2),fpppp(17, 9,11,3)/
     x-2.6728394d-05, 4.5779383d-06, 1.5455444d-08 /
      data fpppp(17, 9,12,1),fpppp(17, 9,12,2),fpppp(17, 9,12,3)/
     x-2.4131059d-05, 1.0884067d-05, 1.5045947d-08 /
      data fpppp(17, 9,13,1),fpppp(17, 9,13,2),fpppp(17, 9,13,3)/
     x-2.5020627d-05, 8.4772380d-06, 1.6385940d-08 /
      data fpppp(17, 9,14,1),fpppp(17, 9,14,2),fpppp(17, 9,14,3)/
     x-2.0816239d-05, 7.8377398d-06, 1.8334068d-08 /
      data fpppp(17, 9,15,1),fpppp(17, 9,15,2),fpppp(17, 9,15,3)/
     x-2.0129971d-05, 7.2782454d-06, 1.6850793d-08 /
      data fpppp(17, 9,16,1),fpppp(17, 9,16,2),fpppp(17, 9,16,3)/
     x-1.3656519d-05, 5.9446225d-06, 1.7228806d-08 /
      data fpppp(17, 9,17,1),fpppp(17, 9,17,2),fpppp(17, 9,17,3)/
     x-1.6462494d-05, 4.2235625d-06, 4.2914050d-09 /
      data fpppp(17, 9,18,1),fpppp(17, 9,18,2),fpppp(17, 9,18,3)/
     x 5.7856533d-06, 3.1384752d-06, 8.5893187d-09 /
      data fpppp(17, 9,19,1),fpppp(17, 9,19,2),fpppp(17, 9,19,3)/
     x 4.2847580d-05,-2.8481241d-06,-1.1680112d-08 /
      data fpppp(17, 9,20,1),fpppp(17, 9,20,2),fpppp(17, 9,20,3)/
     x-1.3406194d-04,-1.6478976d-05,-6.0295939d-08 /
      data fpppp(17, 9,21,1),fpppp(17, 9,21,2),fpppp(17, 9,21,3)/
     x-1.3406194d-04,-1.6461201d-05,-6.0181162d-08 /
      data fpppp(17, 9,22,1),fpppp(17, 9,22,2),fpppp(17, 9,22,3)/
     x 4.2847580d-05,-2.9192251d-06,-1.2139217d-08 /
      data fpppp(17, 9,23,1),fpppp(17, 9,23,2),fpppp(17, 9,23,3)/
     x 5.7856533d-06, 3.4051038d-06, 1.0310964d-08 /
      data fpppp(17,10, 1,1),fpppp(17,10, 1,2),fpppp(17,10, 1,3)/
     x-5.2070902d-04, 3.4511341d-03,-3.3971291d-07 /
      data fpppp(17,10, 2,1),fpppp(17,10, 2,2),fpppp(17,10, 2,3)/
     x-2.7599563d-03, 1.8856653d-03,-1.5882701d-07 /
      data fpppp(17,10, 3,1),fpppp(17,10, 3,2),fpppp(17,10, 3,3)/
     x-2.2773204d-02,-1.3063310d-03, 2.1533477d-07 /
      data fpppp(17,10, 4,1),fpppp(17,10, 4,2),fpppp(17,10, 4,3)/
     x-2.2773204d-02,-1.5908455d-03, 2.3887379d-07 /
      data fpppp(17,10, 5,1),fpppp(17,10, 5,2),fpppp(17,10, 5,3)/
     x-2.7599563d-03, 3.0237233d-03,-2.5298309d-07 /
      data fpppp(17,10, 6,1),fpppp(17,10, 6,2),fpppp(17,10, 6,3)/
     x-5.2070902d-04,-8.1658331d-04, 1.3372391d-08 /
      data fpppp(17,10, 7,1),fpppp(17,10, 7,2),fpppp(17,10, 7,3)/
     x-1.7414865d-04, 1.4734596d-04,-6.0876630d-08 /
      data fpppp(17,10, 8,1),fpppp(17,10, 8,2),fpppp(17,10, 8,3)/
     x-7.7343985d-05,-7.9784297d-05,-2.3626373d-08 /
      data fpppp(17,10, 9,1),fpppp(17,10, 9,2),fpppp(17,10, 9,3)/
     x-4.4143714d-05,-1.1569306d-06,-1.9127724d-08 /
      data fpppp(17,10,10,1),fpppp(17,10,10,2),fpppp(17,10,10,3)/
     x-2.9721701d-05,-7.5052328d-06,-4.3539823d-09 /
      data fpppp(17,10,11,1),fpppp(17,10,11,2),fpppp(17,10,11,3)/
     x-2.2583811d-05, 5.7447817d-06, 3.9688832d-09 /
      data fpppp(17,10,12,1),fpppp(17,10,12,2),fpppp(17,10,12,3)/
     x-1.8909412d-05, 7.7658919d-06, 6.9970615d-09 /
      data fpppp(17,10,13,1),fpppp(17,10,13,2),fpppp(17,10,13,3)/
     x-1.4562334d-05, 5.4038465d-06, 7.2741016d-09 /
      data fpppp(17,10,14,1),fpppp(17,10,14,2),fpppp(17,10,14,3)/
     x-8.5520475d-06, 1.0215964d-05, 8.0315817d-09 /
      data fpppp(17,10,15,1),fpppp(17,10,15,2),fpppp(17,10,15,3)/
     x-7.6767044d-06, 3.8534099d-06, 6.2674792d-09 /
      data fpppp(17,10,16,1),fpppp(17,10,16,2),fpppp(17,10,16,3)/
     x-4.8885571d-06, 4.6010730d-06, 3.7127595d-09 /
      data fpppp(17,10,17,1),fpppp(17,10,17,2),fpppp(17,10,17,3)/
     x 3.7738014d-06, 6.8837265d-06, 1.5967130d-09 /
      data fpppp(17,10,18,1),fpppp(17,10,18,2),fpppp(17,10,18,3)/
     x-1.0267360d-06, 7.2035108d-07,-9.0633686d-09 /
      data fpppp(17,10,19,1),fpppp(17,10,19,2),fpppp(17,10,19,3)/
     x-8.3457019d-06,-6.0634789d-07,-1.4253094d-08 /
      data fpppp(17,10,20,1),fpppp(17,10,20,2),fpppp(17,10,20,3)/
     x 4.1748450d-05,-1.2840946d-05,-1.1532567d-08 /
      data fpppp(17,10,21,1),fpppp(17,10,21,2),fpppp(17,10,21,3)/
     x 4.1748450d-05,-1.2632903d-05,-1.1839179d-08 /
      data fpppp(17,10,22,1),fpppp(17,10,22,2),fpppp(17,10,22,3)/
     x-8.3457019d-06,-1.4385214d-06,-1.3026644d-08 /
      data fpppp(17,10,23,1),fpppp(17,10,23,2),fpppp(17,10,23,3)/
     x-1.0267360d-06, 3.8410016d-06,-1.3662557d-08 /
      data fpppp(17,11, 1,1),fpppp(17,11, 1,2),fpppp(17,11, 1,3)/
     x 2.2303813d-04,-5.1789171d-03, 5.8946135d-08 /
      data fpppp(17,11, 2,1),fpppp(17,11, 2,2),fpppp(17,11, 2,3)/
     x 2.7320577d-03,-2.6020014d-03, 2.1581437d-08 /
      data fpppp(17,11, 3,1),fpppp(17,11, 3,2),fpppp(17,11, 3,3)/
     x 2.2275982d-02, 2.7302304d-03,-5.6378367d-08 /
      data fpppp(17,11, 4,1),fpppp(17,11, 4,2),fpppp(17,11, 4,3)/
     x 2.2275982d-02, 3.0622587d-03,-6.0066328d-08 /
      data fpppp(17,11, 5,1),fpppp(17,11, 5,2),fpppp(17,11, 5,3)/
     x 2.7320577d-03,-3.9301148d-03, 3.6333281d-08 /
      data fpppp(17,11, 6,1),fpppp(17,11, 6,2),fpppp(17,11, 6,3)/
     x 2.2303813d-04,-1.9849172d-04, 3.6267184d-09 /
      data fpppp(17,11, 7,1),fpppp(17,11, 7,2),fpppp(17,11, 7,3)/
     x-4.4022110d-05,-2.5169061d-04, 6.2250711d-08 /
      data fpppp(17,11, 8,1),fpppp(17,11, 8,2),fpppp(17,11, 8,3)/
     x-5.6522409d-05,-5.9410669d-05, 2.0986731d-09 /
      data fpppp(17,11, 9,1),fpppp(17,11, 9,2),fpppp(17,11, 9,3)/
     x-3.7188163d-05,-4.4313476d-05,-5.5250323d-09 /
      data fpppp(17,11,10,1),fpppp(17,11,10,2),fpppp(17,11,10,3)/
     x-2.5990399d-05,-1.4749156d-05,-5.4563946d-09 /
      data fpppp(17,11,11,1),fpppp(17,11,11,2),fpppp(17,11,11,3)/
     x-1.8761302d-05,-9.8712843d-07, 1.6545163d-10 /
      data fpppp(17,11,12,1),fpppp(17,11,12,2),fpppp(17,11,12,3)/
     x-1.5475195d-05, 5.1931682d-06, 2.7782208d-09 /
      data fpppp(17,11,13,1),fpppp(17,11,13,2),fpppp(17,11,13,3)/
     x-1.3128628d-05, 6.3116742d-06, 3.2915671d-09 /
      data fpppp(17,11,14,1),fpppp(17,11,14,2),fpppp(17,11,14,3)/
     x-1.3075875d-05, 5.5768365d-06, 1.6715375d-09 /
      data fpppp(17,11,15,1),fpppp(17,11,15,2),fpppp(17,11,15,3)/
     x-8.9094999d-06, 4.5724872d-06, 1.0176481d-09 /
      data fpppp(17,11,16,1),fpppp(17,11,16,2),fpppp(17,11,16,3)/
     x-5.5798085d-06, 6.3009396d-06,-5.2068073d-12 /
      data fpppp(17,11,17,1),fpppp(17,11,17,2),fpppp(17,11,17,3)/
     x-7.1518736d-06, 2.5419754d-06,-2.6351609d-09 /
      data fpppp(17,11,18,1),fpppp(17,11,18,2),fpppp(17,11,18,3)/
     x-1.8507855d-06, 1.3421626d-06,-2.3828647d-09 /
      data fpppp(17,11,19,1),fpppp(17,11,19,2),fpppp(17,11,19,3)/
     x 2.7427734d-06, 5.1013718d-07, 2.2774728d-09 /
      data fpppp(17,11,20,1),fpppp(17,11,20,2),fpppp(17,11,20,3)/
     x-1.0849699d-05,-1.0246700d-05,-7.1867163d-09 /
      data fpppp(17,11,21,1),fpppp(17,11,21,2),fpppp(17,11,21,3)/
     x-1.0849699d-05,-1.0047911d-05,-6.7558480d-09 /
      data fpppp(17,11,22,1),fpppp(17,11,22,2),fpppp(17,11,22,3)/
     x 2.7427734d-06,-2.8502082d-07, 5.5399956d-10 /
      data fpppp(17,11,23,1),fpppp(17,11,23,2),fpppp(17,11,23,3)/
     x-1.8507855d-06, 4.3240051d-06, 4.0801600d-09 /
      data fpppp(17,12, 1,1),fpppp(17,12, 1,2),fpppp(17,12, 1,3)/
     x 7.7972136d-05,-2.3054256d-04, 7.9304705d-07 /
      data fpppp(17,12, 2,1),fpppp(17,12, 2,2),fpppp(17,12, 2,3)/
     x-6.0069589d-04, 6.2023051d-05, 3.7798388d-07 /
      data fpppp(17,12, 3,1),fpppp(17,12, 3,2),fpppp(17,12, 3,3)/
     x-1.5511693d-02, 7.1489113d-04,-4.8031049d-07 /
      data fpppp(17,12, 4,1),fpppp(17,12, 4,2),fpppp(17,12, 4,3)/
     x-1.5511693d-02, 6.6949301d-04,-5.3478222d-07 /
      data fpppp(17,12, 5,1),fpppp(17,12, 5,2),fpppp(17,12, 5,3)/
     x-6.0069589d-04, 2.4361552d-04, 5.9587077d-07 /
      data fpppp(17,12, 6,1),fpppp(17,12, 6,2),fpppp(17,12, 6,3)/
     x 7.7972136d-05,-9.1151433d-04,-2.4028783d-08 /
      data fpppp(17,12, 7,1),fpppp(17,12, 7,2),fpppp(17,12, 7,3)/
     x 3.8940609d-05,-9.6387935d-05, 1.0277105d-07 /
      data fpppp(17,12, 8,1),fpppp(17,12, 8,2),fpppp(17,12, 8,3)/
     x-5.8193381d-06,-1.6252417d-04, 5.1272153d-08 /
      data fpppp(17,12, 9,1),fpppp(17,12, 9,2),fpppp(17,12, 9,3)/
     x-2.5022789d-05,-5.8570462d-05, 3.5288701d-08 /
      data fpppp(17,12,10,1),fpppp(17,12,10,2),fpppp(17,12,10,3)/
     x-1.5307348d-05,-3.6509479d-05, 1.3175698d-08 /
      data fpppp(17,12,11,1),fpppp(17,12,11,2),fpppp(17,12,11,3)/
     x-1.2577257d-05,-8.6971390d-06, 6.5239132d-09 /
      data fpppp(17,12,12,1),fpppp(17,12,12,2),fpppp(17,12,12,3)/
     x-9.5179550d-06, 2.1430074d-06, 3.5555058d-09 /
      data fpppp(17,12,13,1),fpppp(17,12,13,2),fpppp(17,12,13,3)/
     x-8.6940706d-06, 4.7864499d-06, 1.2632239d-09 /
      data fpppp(17,12,14,1),fpppp(17,12,14,2),fpppp(17,12,14,3)/
     x-7.3561014d-06, 4.1493911d-06,-4.3755847d-10 /
      data fpppp(17,12,15,1),fpppp(17,12,15,2),fpppp(17,12,15,3)/
     x-7.0511889d-06, 5.1643788d-06,-1.3223588d-09 /
      data fpppp(17,12,16,1),fpppp(17,12,16,2),fpppp(17,12,16,3)/
     x-6.6012848d-06, 4.0089294d-06,-1.4749572d-09 /
      data fpppp(17,12,17,1),fpppp(17,12,17,2),fpppp(17,12,17,3)/
     x-4.1578100d-06, 2.5556731d-06, 6.0317614d-11 /
      data fpppp(17,12,18,1),fpppp(17,12,18,2),fpppp(17,12,18,3)/
     x-4.4032434d-06,-1.2513526d-07, 1.1523040d-09 /
      data fpppp(17,12,19,1),fpppp(17,12,19,2),fpppp(17,12,19,3)/
     x-5.4300630d-06,-5.0232017d-07, 1.7169092d-09 /
      data fpppp(17,12,20,1),fpppp(17,12,20,2),fpppp(17,12,20,3)/
     x-1.4177158d-06,-7.3394167d-06,-9.3287106d-10 /
      data fpppp(17,12,21,1),fpppp(17,12,21,2),fpppp(17,12,21,3)/
     x-1.4177158d-06,-7.2058664d-06,-8.4737251d-10 /
      data fpppp(17,12,22,1),fpppp(17,12,22,2),fpppp(17,12,22,3)/
     x-5.4300630d-06,-1.0365215d-06, 1.3749151d-09 /
      data fpppp(17,12,23,1),fpppp(17,12,23,2),fpppp(17,12,23,3)/
     x-4.4032434d-06, 1.8781196d-06, 2.4347822d-09 /
      data fpppp(17,13, 1,1),fpppp(17,13, 1,2),fpppp(17,13, 1,3)/
     x 1.2479195d-04,-7.0745077d-03,-1.3689264d-06 /
      data fpppp(17,13, 2,1),fpppp(17,13, 2,2),fpppp(17,13, 2,3)/
     x-4.9789459d-04,-3.6382841d-03,-6.9886293d-07 /
      data fpppp(17,13, 3,1),fpppp(17,13, 3,2),fpppp(17,13, 3,3)/
     x 6.2527899d-03, 3.4281767d-03, 6.8819618d-07 /
      data fpppp(17,13, 4,1),fpppp(17,13, 4,2),fpppp(17,13, 4,3)/
     x 6.2527899d-03, 3.9477089d-03, 7.7358064d-07 /
      data fpppp(17,13, 5,1),fpppp(17,13, 5,2),fpppp(17,13, 5,3)/
     x-4.9789459d-04,-5.7164130d-03,-1.0404008d-06 /
      data fpppp(17,13, 6,1),fpppp(17,13, 6,2),fpppp(17,13, 6,3)/
     x 1.2479195d-04, 7.1847567d-04,-8.8159473d-08 /
      data fpppp(17,13, 7,1),fpppp(17,13, 7,2),fpppp(17,13, 7,3)/
     x 4.7560331d-05,-5.0813392d-04,-1.2539896d-07 /
      data fpppp(17,13, 8,1),fpppp(17,13, 8,2),fpppp(17,13, 8,3)/
     x 1.4953107d-05,-6.4184987d-05, 1.9196841d-08 /
      data fpppp(17,13, 9,1),fpppp(17,13, 9,2),fpppp(17,13, 9,3)/
     x 4.2048225d-05,-1.1782664d-04, 3.6497778d-08 /
      data fpppp(17,13,10,1),fpppp(17,13,10,2),fpppp(17,13,10,3)/
     x-2.4081701d-06,-4.3738141d-05, 3.4339281d-08 /
      data fpppp(17,13,11,1),fpppp(17,13,11,2),fpppp(17,13,11,3)/
     x-5.2222324d-06,-1.9802343d-05, 1.6348633d-08 /
      data fpppp(17,13,12,1),fpppp(17,13,12,2),fpppp(17,13,12,3)/
     x-5.8373972d-06,-2.2852858d-06, 7.8151257d-09 /
      data fpppp(17,13,13,1),fpppp(17,13,13,2),fpppp(17,13,13,3)/
     x-5.5879735d-06, 3.1523269d-06, 2.7843196d-09 /
      data fpppp(17,13,14,1),fpppp(17,13,14,2),fpppp(17,13,14,3)/
     x-6.3999668d-06, 3.2367811d-06, 2.2819711d-10 /
      data fpppp(17,13,15,1),fpppp(17,13,15,2),fpppp(17,13,15,3)/
     x-6.1345831d-06, 4.8645995d-06,-9.7499832d-10 /
      data fpppp(17,13,16,1),fpppp(17,13,16,2),fpppp(17,13,16,3)/
     x-7.3759477d-06, 3.0053015d-06,-9.7732414d-10 /
      data fpppp(17,13,17,1),fpppp(17,13,17,2),fpppp(17,13,17,3)/
     x-8.5303659d-06, 1.4669850d-06, 9.7011530d-10 /
      data fpppp(17,13,18,1),fpppp(17,13,18,2),fpppp(17,13,18,3)/
     x-8.8954383d-06,-1.5644057d-06, 3.1511089d-09 /
      data fpppp(17,13,19,1),fpppp(17,13,19,2),fpppp(17,13,19,3)/
     x-6.3156964d-06,-1.4127607d-06,-7.9117615d-10 /
      data fpppp(17,13,20,1),fpppp(17,13,20,2),fpppp(17,13,20,3)/
     x-5.6742246d-06,-4.8358624d-06, 2.3650055d-09 /
      data fpppp(17,13,21,1),fpppp(17,13,21,2),fpppp(17,13,21,3)/
     x-5.6742246d-06,-4.7528358d-06, 2.1079563d-09 /
      data fpppp(17,13,22,1),fpppp(17,13,22,2),fpppp(17,13,22,3)/
     x-6.3156964d-06,-1.7448669d-06, 2.3702066d-10 /
      data fpppp(17,13,23,1),fpppp(17,13,23,2),fpppp(17,13,23,3)/
     x-8.8954383d-06,-3.1900758d-07,-7.0462911d-10 /
      data fpppp(17,14, 1,1),fpppp(17,14, 1,2),fpppp(17,14, 1,3)/
     x-5.3755776d-04,-7.5507505d-03,-8.1766364d-07 /
      data fpppp(17,14, 2,1),fpppp(17,14, 2,2),fpppp(17,14, 2,3)/
     x 2.0437857d-03,-3.8731652d-03,-3.6826801d-07 /
      data fpppp(17,14, 3,1),fpppp(17,14, 3,2),fpppp(17,14, 3,3)/
     x 7.1445731d-03, 3.6926349d-03, 5.7199123d-07 /
      data fpppp(17,14, 4,1),fpppp(17,14, 4,2),fpppp(17,14, 4,3)/
     x 7.1445731d-03, 4.2434296d-03, 6.1177120d-07 /
      data fpppp(17,14, 5,1),fpppp(17,14, 5,2),fpppp(17,14, 5,3)/
     x 2.0437857d-03,-6.0763440d-03,-5.2738789d-07 /
      data fpppp(17,14, 6,1),fpppp(17,14, 6,2),fpppp(17,14, 6,3)/
     x-5.3755776d-04, 7.1116987d-04,-2.2096409d-07 /
      data fpppp(17,14, 7,1),fpppp(17,14, 7,2),fpppp(17,14, 7,3)/
     x-1.3705253d-04,-5.0631774d-04,-2.1241197d-07 /
      data fpppp(17,14, 8,1),fpppp(17,14, 8,2),fpppp(17,14, 8,3)/
     x-2.8529987d-06,-7.6335212d-05,-4.1801749d-08 /
      data fpppp(17,14, 9,1),fpppp(17,14, 9,2),fpppp(17,14, 9,3)/
     x-1.3013911d-04,-1.4580713d-04, 1.9765861d-08 /
      data fpppp(17,14,10,1),fpppp(17,14,10,2),fpppp(17,14,10,3)/
     x 8.7420323d-06,-5.6700028d-05, 3.1826713d-08 /
      data fpppp(17,14,11,1),fpppp(17,14,11,2),fpppp(17,14,11,3)/
     x 1.0929602d-06,-2.6196568d-05, 2.1077738d-08 /
      data fpppp(17,14,12,1),fpppp(17,14,12,2),fpppp(17,14,12,3)/
     x-2.3656772d-06,-6.5090357d-06, 1.0239718d-08 /
      data fpppp(17,14,13,1),fpppp(17,14,13,2),fpppp(17,14,13,3)/
     x-2.7143398d-06, 3.2196253d-07, 5.2604064d-09 /
      data fpppp(17,14,14,1),fpppp(17,14,14,2),fpppp(17,14,14,3)/
     x-2.9005662d-06, 3.3354459d-06, 2.2654088d-09 /
      data fpppp(17,14,15,1),fpppp(17,14,15,2),fpppp(17,14,15,3)/
     x-5.0995088d-06, 2.9796977d-06, 1.0788884d-09 /
      data fpppp(17,14,16,1),fpppp(17,14,16,2),fpppp(17,14,16,3)/
     x-5.7160471d-06, 3.0312917d-06, 8.5746961d-10 /
      data fpppp(17,14,17,1),fpppp(17,14,17,2),fpppp(17,14,17,3)/
     x-6.8350384d-06,-3.1614985d-07, 1.0298216d-09 /
      data fpppp(17,14,18,1),fpppp(17,14,18,2),fpppp(17,14,18,3)/
     x-7.3069310d-06,-1.3993325d-07, 7.6764276d-10 /
      data fpppp(17,14,19,1),fpppp(17,14,19,2),fpppp(17,14,19,3)/
     x-8.7102630d-06,-3.0172944d-06, 3.5396653d-09 /
      data fpppp(17,14,20,1),fpppp(17,14,20,2),fpppp(17,14,20,3)/
     x-8.0842859d-06,-3.1042830d-06, 2.6098667d-10 /
      data fpppp(17,14,21,1),fpppp(17,14,21,2),fpppp(17,14,21,3)/
     x-8.0842859d-06,-3.2389396d-06, 4.6519897d-10 /
      data fpppp(17,14,22,1),fpppp(17,14,22,2),fpppp(17,14,22,3)/
     x-8.7102630d-06,-2.4786679d-06, 2.7228161d-09 /
      data fpppp(17,14,23,1),fpppp(17,14,23,2),fpppp(17,14,23,3)/
     x-7.3069310d-06,-2.1597829d-06, 3.8308273d-09 /
      data fpppp(17,15, 1,1),fpppp(17,15, 1,2),fpppp(17,15, 1,3)/
     x 1.0667825d-03,-1.0784222d-03,-1.4970281d-07 /
      data fpppp(17,15, 2,1),fpppp(17,15, 2,2),fpppp(17,15, 2,3)/
     x-7.4588433d-03,-3.7588542d-04,-1.3396751d-07 /
      data fpppp(17,15, 3,1),fpppp(17,15, 3,2),fpppp(17,15, 3,3)/
     x-1.4417660d-02, 1.0978342d-03,-1.1066744d-07 /
      data fpppp(17,15, 4,1),fpppp(17,15, 4,2),fpppp(17,15, 4,3)/
     x-1.4417660d-02, 1.1533378d-03,-9.2435188d-08 /
      data fpppp(17,15, 5,1),fpppp(17,15, 5,2),fpppp(17,15, 5,3)/
     x-7.4588433d-03,-5.9789976d-04,-2.0689652d-07 /
      data fpppp(17,15, 6,1),fpppp(17,15, 6,2),fpppp(17,15, 6,3)/
     x 1.0667825d-03,-2.4586843d-04, 1.2378095d-07 /
      data fpppp(17,15, 7,1),fpppp(17,15, 7,2),fpppp(17,15, 7,3)/
     x 4.9936992d-04,-4.0950870d-04, 1.3243518d-07 /
      data fpppp(17,15, 8,1),fpppp(17,15, 8,2),fpppp(17,15, 8,3)/
     x 2.6290671d-04,-2.0837336d-04, 3.5531615d-08 /
      data fpppp(17,15, 9,1),fpppp(17,15, 9,2),fpppp(17,15, 9,3)/
     x 6.5178712d-04,-1.5012540d-04, 1.8484577d-08 /
      data fpppp(17,15,10,1),fpppp(17,15,10,2),fpppp(17,15,10,3)/
     x 2.9322613d-05,-6.2650275d-05, 8.6492050d-09 /
      data fpppp(17,15,11,1),fpppp(17,15,11,2),fpppp(17,15,11,3)/
     x 8.9206713d-06,-2.6715549d-05, 9.6732610d-09 /
      data fpppp(17,15,12,1),fpppp(17,15,12,2),fpppp(17,15,12,3)/
     x 2.6223745d-06,-8.1811195d-06, 7.0392810d-09 /
      data fpppp(17,15,13,1),fpppp(17,15,13,2),fpppp(17,15,13,3)/
     x-4.7866785d-07,-2.0885680d-06, 4.3880939d-09 /
      data fpppp(17,15,14,1),fpppp(17,15,14,2),fpppp(17,15,14,3)/
     x-9.6685106d-07, 1.4042959d-06, 3.8407329d-09 /
      data fpppp(17,15,15,1),fpppp(17,15,15,2),fpppp(17,15,15,3)/
     x-5.3506498d-07, 2.7407032d-06, 3.0431452d-09 /
      data fpppp(17,15,16,1),fpppp(17,15,16,2),fpppp(17,15,16,3)/
     x-1.7978201d-06, 1.6317943d-06, 2.8020789d-09 /
      data fpppp(17,15,17,1),fpppp(17,15,17,2),fpppp(17,15,17,3)/
     x-3.3583215d-06,-2.6385375d-07, 1.7083650d-09 /
      data fpppp(17,15,18,1),fpppp(17,15,18,2),fpppp(17,15,18,3)/
     x-3.6464117d-06, 1.8454746d-08, 1.6526195d-09 /
      data fpppp(17,15,19,1),fpppp(17,15,19,2),fpppp(17,15,19,3)/
     x-4.2410594d-06,-2.4804223d-06,-9.0244976d-10 /
      data fpppp(17,15,20,1),fpppp(17,15,20,2),fpppp(17,15,20,3)/
     x-4.4109017d-06,-2.0684708d-06,-3.0339282d-10 /
      data fpppp(17,15,21,1),fpppp(17,15,21,2),fpppp(17,15,21,3)/
     x-4.4109017d-06,-2.1962138d-06,-4.3794800d-10 /
      data fpppp(17,15,22,1),fpppp(17,15,22,2),fpppp(17,15,22,3)/
     x-4.2410594d-06,-1.9694499d-06,-3.6422903d-10 /
      data fpppp(17,15,23,1),fpppp(17,15,23,2),fpppp(17,15,23,3)/
     x-3.6464117d-06,-1.8976916d-06,-3.6570823d-10 /
      data fpppp(17,16, 1,1),fpppp(17,16, 1,2),fpppp(17,16, 1,3)/
     x-9.3236684d-04, 3.8237494d-03, 1.7777712d-06 /
      data fpppp(17,16, 2,1),fpppp(17,16, 2,2),fpppp(17,16, 2,3)/
     x 1.6113859d-02, 2.6791351d-03, 9.9409543d-07 /
      data fpppp(17,16, 3,1),fpppp(17,16, 3,2),fpppp(17,16, 3,3)/
     x 2.3096950d-02, 5.6577234d-04,-6.1104728d-07 /
      data fpppp(17,16, 4,1),fpppp(17,16, 4,2),fpppp(17,16, 4,3)/
     x 2.3096950d-02,-2.8146399d-05,-7.4083172d-07 /
      data fpppp(17,16, 5,1),fpppp(17,16, 5,2),fpppp(17,16, 5,3)/
     x 1.6113859d-02, 5.0548101d-03, 1.5132332d-06 /
      data fpppp(17,16, 6,1),fpppp(17,16, 6,2),fpppp(17,16, 6,3)/
     x-9.3236684d-04,-5.0850317d-03,-1.6899533d-07 /
      data fpppp(17,16, 7,1),fpppp(17,16, 7,2),fpppp(17,16, 7,3)/
     x 6.4710598d-04, 2.7692823d-04,-8.1205492d-08 /
      data fpppp(17,16, 8,1),fpppp(17,16, 8,2),fpppp(17,16, 8,3)/
     x 1.3755216d-04, 1.5166721d-04,-7.3222135d-08 /
      data fpppp(17,16, 9,1),fpppp(17,16, 9,2),fpppp(17,16, 9,3)/
     x-8.1524275d-04,-9.1573875d-04,-6.6717737d-08 /
      data fpppp(17,16,10,1),fpppp(17,16,10,2),fpppp(17,16,10,3)/
     x 3.1869222d-05, 5.0519552d-04,-3.8751839d-08 /
      data fpppp(17,16,11,1),fpppp(17,16,11,2),fpppp(17,16,11,3)/
     x 1.4498004d-05,-1.6388677d-04,-1.7803990d-08 /
      data fpppp(17,16,12,1),fpppp(17,16,12,2),fpppp(17,16,12,3)/
     x 5.3854441d-06, 3.1823382d-05,-4.9757023d-09 /
      data fpppp(17,16,13,1),fpppp(17,16,13,2),fpppp(17,16,13,3)/
     x 2.3382442d-06,-1.2588851d-05, 2.5586685d-10 /
      data fpppp(17,16,14,1),fpppp(17,16,14,2),fpppp(17,16,14,3)/
     x 1.0895400d-06, 2.5679383d-06, 2.1159242d-09 /
      data fpppp(17,16,15,1),fpppp(17,16,15,2),fpppp(17,16,15,3)/
     x 6.5676529d-07, 6.9538223d-07, 3.1428235d-09 /
      data fpppp(17,16,16,1),fpppp(17,16,16,2),fpppp(17,16,16,3)/
     x 1.3529234d-06, 2.9598310d-07, 3.0527798d-09 /
      data fpppp(17,16,17,1),fpppp(17,16,17,2),fpppp(17,16,17,3)/
     x 3.4067581d-06, 1.0042630d-06, 2.3881657d-09 /
      data fpppp(17,16,18,1),fpppp(17,16,18,2),fpppp(17,16,18,3)/
     x 3.5816393d-06,-8.9233585d-07,-1.4247496d-10 /
      data fpppp(17,16,19,1),fpppp(17,16,19,2),fpppp(17,16,19,3)/
     x 4.1103064d-06,-6.8654020d-07,-1.6838971d-09 /
      data fpppp(17,16,20,1),fpppp(17,16,20,2),fpppp(17,16,20,3)/
     x 4.6192785d-06,-1.2826833d-06,-1.7869379d-09 /
      data fpppp(17,16,21,1),fpppp(17,16,21,2),fpppp(17,16,21,3)/
     x 4.6192785d-06,-1.2597089d-06,-1.8578241d-09 /
      data fpppp(17,16,22,1),fpppp(17,16,22,2),fpppp(17,16,22,3)/
     x 4.1103064d-06,-7.7843813d-07,-1.4003522d-09 /
      data fpppp(17,16,23,1),fpppp(17,16,23,2),fpppp(17,16,23,3)/
     x 3.5816393d-06,-5.4771860d-07,-1.2057683d-09 /
      data fpppp(17,17, 1,1),fpppp(17,17, 1,2),fpppp(17,17, 1,3)/
     x 2.9789340d-03, 6.0916796d-04,-7.3304218d-07 /
      data fpppp(17,17, 2,1),fpppp(17,17, 2,2),fpppp(17,17, 2,3)/
     x-1.2184005d-02, 8.9150253d-05,-4.0071390d-07 /
      data fpppp(17,17, 3,1),fpppp(17,17, 3,2),fpppp(17,17, 3,3)/
     x-2.0618924d-02,-1.2272255d-03, 2.7387551d-07 /
      data fpppp(17,17, 4,1),fpppp(17,17, 4,2),fpppp(17,17, 4,3)/
     x-2.0618924d-02,-8.7363434d-04, 3.3957508d-07 /
      data fpppp(17,17, 5,1),fpppp(17,17, 5,2),fpppp(17,17, 5,3)/
     x-1.2184005d-02,-1.3252143d-03,-6.6351220d-07 /
      data fpppp(17,17, 6,1),fpppp(17,17, 6,2),fpppp(17,17, 6,3)/
     x 2.9789340d-03, 5.9130350d-03, 2.5245144d-07 /
      data fpppp(17,17, 7,1),fpppp(17,17, 7,2),fpppp(17,17, 7,3)/
     x-9.2431626d-04,-4.0092529d-03, 7.6338564d-08 /
      data fpppp(17,17, 8,1),fpppp(17,17, 8,2),fpppp(17,17, 8,3)/
     x-2.3382722d-04, 1.1335322d-03,-1.5141235d-08 /
      data fpppp(17,17, 9,1),fpppp(17,17, 9,2),fpppp(17,17, 9,3)/
     x 4.6417024d-04,-3.3614389d-04,-3.5252761d-08 /
      data fpppp(17,17,10,1),fpppp(17,17,10,2),fpppp(17,17,10,3)/
     x-1.6885372d-05, 7.9613599d-05,-3.7427163d-08 /
      data fpppp(17,17,11,1),fpppp(17,17,11,2),fpppp(17,17,11,3)/
     x 2.5694960d-06,-2.7915026d-05,-2.7756909d-08 /
      data fpppp(17,17,12,1),fpppp(17,17,12,2),fpppp(17,17,12,3)/
     x 6.2367537d-06, 4.0344270d-06,-1.7472719d-08 /
      data fpppp(17,17,13,1),fpppp(17,17,13,2),fpppp(17,17,13,3)/
     x 4.6654960d-06,-2.8380866d-06,-8.9669634d-09 /
      data fpppp(17,17,14,1),fpppp(17,17,14,2),fpppp(17,17,14,3)/
     x 2.6336063d-06,-1.3294066d-07,-3.7465746d-09 /
      data fpppp(17,17,15,1),fpppp(17,17,15,2),fpppp(17,17,15,3)/
     x 2.7041225d-06, 1.4319243d-07,-9.3045807d-10 /
      data fpppp(17,17,16,1),fpppp(17,17,16,2),fpppp(17,17,16,3)/
     x 3.2761468d-06, 1.7486668d-07, 1.3302279d-10 /
      data fpppp(17,17,17,1),fpppp(17,17,17,2),fpppp(17,17,17,3)/
     x 3.3429600d-06, 5.4821822d-07,-1.2989308d-10 /
      data fpppp(17,17,18,1),fpppp(17,17,18,2),fpppp(17,17,18,3)/
     x 4.7890967d-06,-9.8525438d-07,-9.9348027d-10 /
      data fpppp(17,17,19,1),fpppp(17,17,19,2),fpppp(17,17,19,3)/
     x 6.2703230d-06, 7.0369055d-07,-1.3300544d-09 /
      data fpppp(17,17,20,1),fpppp(17,17,20,2),fpppp(17,17,20,3)/
     x 6.4226505d-06,-6.8303573d-07,-2.4857251d-09 /
      data fpppp(17,17,21,1),fpppp(17,17,21,2),fpppp(17,17,21,3)/
     x 6.4226505d-06,-5.7214567d-07,-2.4761014d-09 /
      data fpppp(17,17,22,1),fpppp(17,17,22,2),fpppp(17,17,22,3)/
     x 6.2703230d-06, 2.6013033d-07,-1.3685491d-09 /
      data fpppp(17,17,23,1),fpppp(17,17,23,2),fpppp(17,17,23,3)/
     x 4.7890967d-06, 6.7809647d-07,-8.4912504d-10 /
      data fpppp(17,18, 1,1),fpppp(17,18, 1,2),fpppp(17,18, 1,3)/
     x-2.0438944d-03, 3.9189337d-06, 2.0908472d-07 /
      data fpppp(17,18, 2,1),fpppp(17,18, 2,2),fpppp(17,18, 2,3)/
     x 1.9292647d-03, 4.7976604d-07, 9.3925784d-08 /
      data fpppp(17,18, 3,1),fpppp(17,18, 3,2),fpppp(17,18, 3,3)/
     x 4.6811631d-03,-7.1322763d-06,-1.4524434d-07 /
      data fpppp(17,18, 4,1),fpppp(17,18, 4,2),fpppp(17,18, 4,3)/
     x 4.6811631d-03,-6.7080811d-06,-1.5854262d-07 /
      data fpppp(17,18, 5,1),fpppp(17,18, 5,2),fpppp(17,18, 5,3)/
     x 1.9292647d-03,-1.2170147d-06, 1.4711888d-07 /
      data fpppp(17,18, 6,1),fpppp(17,18, 6,2),fpppp(17,18, 6,3)/
     x-2.0438944d-03, 1.0281862d-05, 9.6106014d-09 /
      data fpppp(17,18, 7,1),fpppp(17,18, 7,2),fpppp(17,18, 7,3)/
     x 1.3953744d-05,-4.2261882d-06, 3.6903816d-08 /
      data fpppp(17,18, 8,1),fpppp(17,18, 8,2),fpppp(17,18, 8,3)/
     x-6.3676488d-05, 1.8380311d-06, 3.2315716d-08 /
      data fpppp(17,18, 9,1),fpppp(17,18, 9,2),fpppp(17,18, 9,3)/
     x-1.3288017d-04, 1.6987536d-06, 1.9561645d-08 /
      data fpppp(17,18,10,1),fpppp(17,18,10,2),fpppp(17,18,10,3)/
     x-2.0249856d-05, 1.2822955d-07, 1.0120402d-08 /
      data fpppp(17,18,11,1),fpppp(17,18,11,2),fpppp(17,18,11,3)/
     x-9.8962842d-06, 7.0473756d-07, 3.9991250d-09 /
      data fpppp(17,18,12,1),fpppp(17,18,12,2),fpppp(17,18,12,3)/
     x-3.6721196d-06, 5.3564232d-07, 8.5667482d-10 /
      data fpppp(17,18,13,1),fpppp(17,18,13,2),fpppp(17,18,13,3)/
     x-4.2383380d-08,-3.7915778d-07,-7.1589598d-10 /
      data fpppp(17,18,14,1),fpppp(17,18,14,2),fpppp(17,18,14,3)/
     x 2.4582209d-06, 8.7018694d-07,-1.4481917d-09 /
      data fpppp(17,18,15,1),fpppp(17,18,15,2),fpppp(17,18,15,3)/
     x 3.2758672d-06,-3.9059288d-07,-1.9388458d-09 /
      data fpppp(17,18,16,1),fpppp(17,18,16,2),fpppp(17,18,16,3)/
     x 4.5099952d-06,-1.7242754d-07,-2.5948867d-09 /
      data fpppp(17,18,17,1),fpppp(17,18,17,2),fpppp(17,18,17,3)/
     x 6.2104605d-06, 7.8164954d-07,-3.3106758d-09 /
      data fpppp(17,18,18,1),fpppp(17,18,18,2),fpppp(17,18,18,3)/
     x 7.1451041d-06,-7.3738044d-07,-4.0652587d-09 /
      data fpppp(17,18,19,1),fpppp(17,18,19,2),fpppp(17,18,19,3)/
     x 8.1648920d-06, 6.2056373d-07,-5.2671840d-09 /
      data fpppp(17,18,20,1),fpppp(17,18,20,2),fpppp(17,18,20,3)/
     x 8.9438989d-06,-1.0682124d-07,-5.1633132d-09 /
      data fpppp(17,18,21,1),fpppp(17,18,21,2),fpppp(17,18,21,3)/
     x 8.9438989d-06,-2.6248905d-08,-5.2226675d-09 /
      data fpppp(17,18,22,1),fpppp(17,18,22,2),fpppp(17,18,22,3)/
     x 8.1648920d-06, 2.9827440d-07,-5.0297666d-09 /
      data fpppp(17,18,23,1),fpppp(17,18,23,2),fpppp(17,18,23,3)/
     x 7.1451041d-06, 4.7120456d-07,-4.9555740d-09 /
      data fpppp(17,19, 1,1),fpppp(17,19, 1,2),fpppp(17,19, 1,3)/
     x-4.5141144d-03, 6.2734102d-18, 1.6465725d-07 /
      data fpppp(17,19, 2,1),fpppp(17,19, 2,2),fpppp(17,19, 2,3)/
     x 3.9250674d-03, 2.3164354d-18, 4.8722895d-08 /
      data fpppp(17,19, 3,1),fpppp(17,19, 3,2),fpppp(17,19, 3,3)/
     x 1.0262404d-02,-2.7664683d-19,-1.9178058d-07 /
      data fpppp(17,19, 4,1),fpppp(17,19, 4,2),fpppp(17,19, 4,3)/
     x 1.0262404d-02,-2.8598932d-19,-2.0565332d-07 /
      data fpppp(17,19, 5,1),fpppp(17,19, 5,2),fpppp(17,19, 5,3)/
     x 3.9250674d-03,-5.2661513d-19, 1.0421384d-07 /
      data fpppp(17,19, 6,1),fpppp(17,19, 6,2),fpppp(17,19, 6,3)/
     x-4.5141144d-03,-3.8578341d-19,-4.3433778d-08 /
      data fpppp(17,19, 7,1),fpppp(17,19, 7,2),fpppp(17,19, 7,3)/
     x 2.3516882d-04,-6.8010813d-19, 5.3748727d-08 /
      data fpppp(17,19, 8,1),fpppp(17,19, 8,2),fpppp(17,19, 8,3)/
     x-4.8248645d-05,-1.3406582d-18, 8.2808081d-08 /
      data fpppp(17,19, 9,1),fpppp(17,19, 9,2),fpppp(17,19, 9,3)/
     x-1.9379818d-04,-1.2576524d-18, 6.7704785d-08 /
      data fpppp(17,19,10,1),fpppp(17,19,10,2),fpppp(17,19,10,3)/
     x-3.6582944d-05,-1.1717110d-18, 4.4461428d-08 /
      data fpppp(17,19,11,1),fpppp(17,19,11,2),fpppp(17,19,11,3)/
     x-2.2208558d-05,-2.7540244d-18, 2.3838315d-08 /
      data fpppp(17,19,12,1),fpppp(17,19,12,2),fpppp(17,19,12,3)/
     x-1.0506655d-05,-2.5336889d-18, 1.0378523d-08 /
      data fpppp(17,19,13,1),fpppp(17,19,13,2),fpppp(17,19,13,3)/
     x-2.7402253d-06,-1.1576326d-18, 2.5426292d-09 /
      data fpppp(17,19,14,1),fpppp(17,19,14,2),fpppp(17,19,14,3)/
     x 2.7741075d-06,-8.5355436d-19,-1.4814894d-09 /
      data fpppp(17,19,15,1),fpppp(17,19,15,2),fpppp(17,19,15,3)/
     x 4.2692154d-06,-2.7569001d-18,-3.8229175d-09 /
      data fpppp(17,19,16,1),fpppp(17,19,16,2),fpppp(17,19,16,3)/
     x 5.9408079d-06, 1.2929490d-18,-5.3776099d-09 /
      data fpppp(17,19,17,1),fpppp(17,19,17,2),fpppp(17,19,17,3)/
     x 8.2404471d-06, 4.0174973d-19,-6.3021088d-09 /
      data fpppp(17,19,18,1),fpppp(17,19,18,2),fpppp(17,19,18,3)/
     x 9.1729543d-06, 6.0461479d-19,-6.5025306d-09 /
      data fpppp(17,19,19,1),fpppp(17,19,19,2),fpppp(17,19,19,3)/
     x 1.0135303d-05, 1.0209196d-18,-7.9783215d-09 /
      data fpppp(17,19,20,1),fpppp(17,19,20,2),fpppp(17,19,20,3)/
     x 1.1260040d-05,-4.9710927d-19,-7.2755296d-09 /
      data fpppp(17,19,21,1),fpppp(17,19,21,2),fpppp(17,19,21,3)/
     x 1.1260040d-05,-5.0316634d-19,-7.3611511d-09 /
      data fpppp(17,19,22,1),fpppp(17,19,22,2),fpppp(17,19,22,3)/
     x 1.0135303d-05,-1.7050424d-18,-7.6358353d-09 /
      data fpppp(17,19,23,1),fpppp(17,19,23,2),fpppp(17,19,23,3)/
     x 9.1729543d-06,-6.4543781d-18,-7.7868537d-09 /
      data fpppp(18, 1, 1,1),fpppp(18, 1, 1,2),fpppp(18, 1, 1,3)/
     x-1.0036118d-01, 2.8535622d-17, 3.2069917d-06 /
      data fpppp(18, 1, 2,1),fpppp(18, 1, 2,2),fpppp(18, 1, 2,3)/
     x-9.6384426d-02, 2.5706688d-17, 8.5592486d-07 /
      data fpppp(18, 1, 3,1),fpppp(18, 1, 3,2),fpppp(18, 1, 3,3)/
     x-8.2962469d-02, 2.2374446d-17,-4.1748401d-06 /
      data fpppp(18, 1, 4,1),fpppp(18, 1, 4,2),fpppp(18, 1, 4,3)/
     x-8.2962469d-02,-8.5110927d-18,-4.1875019d-06 /
      data fpppp(18, 1, 5,1),fpppp(18, 1, 5,2),fpppp(18, 1, 5,3)/
     x-9.6384426d-02,-9.5747422d-18, 9.0657220d-07 /
      data fpppp(18, 1, 6,1),fpppp(18, 1, 6,2),fpppp(18, 1, 6,3)/
     x-1.0036118d-01, 1.3678679d-18, 3.0170641d-06 /
      data fpppp(18, 1, 7,1),fpppp(18, 1, 7,2),fpppp(18, 1, 7,3)/
     x-1.0558102d-01, 1.8758683d-17, 6.3424400d-07 /
      data fpppp(18, 1, 8,1),fpppp(18, 1, 8,2),fpppp(18, 1, 8,3)/
     x-1.0193396d-01, 2.6056433d-17,-5.3273526d-07 /
      data fpppp(18, 1, 9,1),fpppp(18, 1, 9,2),fpppp(18, 1, 9,3)/
     x-9.5446293d-02, 1.5519078d-18, 1.9417051d-06 /
      data fpppp(18, 1,10,1),fpppp(18, 1,10,2),fpppp(18, 1,10,3)/
     x-9.4984434d-02,-3.2471705d-17,-1.3731472d-07 /
      data fpppp(18, 1,11,1),fpppp(18, 1,11,2),fpppp(18, 1,11,3)/
     x-9.0813637d-02, 2.9643443d-17, 3.3953618d-07 /
      data fpppp(18, 1,12,1),fpppp(18, 1,12,2),fpppp(18, 1,12,3)/
     x-9.7723092d-02,-1.0470323d-17, 1.5012041d-07 /
      data fpppp(18, 1,13,1),fpppp(18, 1,13,2),fpppp(18, 1,13,3)/
     x-1.0173205d-01, 1.2819098d-17, 3.4353260d-07 /
      data fpppp(18, 1,14,1),fpppp(18, 1,14,2),fpppp(18, 1,14,3)/
     x-9.4914674d-02,-2.0474819d-17,-1.2701131d-07 /
      data fpppp(18, 1,15,1),fpppp(18, 1,15,2),fpppp(18, 1,15,3)/
     x-9.5294278d-02, 9.2922740d-18, 1.9690668d-06 /
      data fpppp(18, 1,16,1),fpppp(18, 1,16,2),fpppp(18, 1,16,3)/
     x-1.0175645d-01, 1.9553986d-17,-5.0692563d-07 /
      data fpppp(18, 1,17,1),fpppp(18, 1,17,2),fpppp(18, 1,17,3)/
     x-1.0533718d-01,-3.4172012d-18, 6.9525043d-07 /
      data fpppp(18, 1,18,1),fpppp(18, 1,18,2),fpppp(18, 1,18,3)/
     x-1.0062200d-01,-6.0137865d-18, 2.9132230d-06 /
      data fpppp(18, 1,19,1),fpppp(18, 1,19,2),fpppp(18, 1,19,3)/
     x-9.2431967d-02, 2.0952118d-18, 8.8755961d-07 /
      data fpppp(18, 1,20,1),fpppp(18, 1,20,2),fpppp(18, 1,20,3)/
     x-8.0431233d-02,-1.4489239d-17,-4.1479907d-06 /
      data fpppp(18, 1,21,1),fpppp(18, 1,21,2),fpppp(18, 1,21,3)/
     x-8.0431233d-02, 1.2514795d-17,-4.1325986d-06 /
      data fpppp(18, 1,22,1),fpppp(18, 1,22,2),fpppp(18, 1,22,3)/
     x-9.2431967d-02,-2.2154716d-17, 8.2599125d-07 /
      data fpppp(18, 1,23,1),fpppp(18, 1,23,2),fpppp(18, 1,23,3)/
     x-1.0062200d-01,-6.1024352d-17, 3.1441044d-06 /
      data fpppp(18, 2, 1,1),fpppp(18, 2, 1,2),fpppp(18, 2, 1,3)/
     x-5.5813127d-02,-2.8330965d-03, 1.2322808d-06 /
      data fpppp(18, 2, 2,1),fpppp(18, 2, 2,2),fpppp(18, 2, 2,3)/
     x-5.4724356d-02,-1.6679643d-03, 3.2854213d-07 /
      data fpppp(18, 2, 3,1),fpppp(18, 2, 3,2),fpppp(18, 2, 3,3)/
     x-5.0204827d-02, 7.0192331d-04,-1.6083913d-06 /
      data fpppp(18, 2, 4,1),fpppp(18, 2, 4,2),fpppp(18, 2, 4,3)/
     x-5.0204827d-02, 9.2386589d-04,-1.6077777d-06 /
      data fpppp(18, 2, 5,1),fpppp(18, 2, 5,2),fpppp(18, 2, 5,3)/
     x-5.4724356d-02,-2.5557346d-03, 3.2608766d-07 /
      data fpppp(18, 2, 6,1),fpppp(18, 2, 6,2),fpppp(18, 2, 6,3)/
     x-5.5813127d-02, 4.9604230d-04, 1.2414850d-06 /
      data fpppp(18, 2, 7,1),fpppp(18, 2, 7,2),fpppp(18, 2, 7,3)/
     x-5.7858808d-02, 7.4651050d-04, 2.6266676d-07 /
      data fpppp(18, 2, 8,1),fpppp(18, 2, 8,2),fpppp(18, 2, 8,3)/
     x-5.6101844d-02,-2.4263396d-03,-3.3476177d-07 /
      data fpppp(18, 2, 9,1),fpppp(18, 2, 9,2),fpppp(18, 2, 9,3)/
     x-5.2903641d-02, 3.3865044d-03, 9.0270414d-07 /
      data fpppp(18, 2,10,1),fpppp(18, 2,10,2),fpppp(18, 2,10,3)/
     x-5.2673863d-02,-3.0888533d-03,-1.2185595d-07 /
      data fpppp(18, 2,11,1),fpppp(18, 2,11,2),fpppp(18, 2,11,3)/
     x-5.0639904d-02, 4.4935369d-03, 1.0745477d-07 /
      data fpppp(18, 2,12,1),fpppp(18, 2,12,2),fpppp(18, 2,12,3)/
     x-5.4013073d-02,-1.0823221d-03, 1.2896016d-08 /
      data fpppp(18, 2,13,1),fpppp(18, 2,13,2),fpppp(18, 2,13,3)/
     x-5.5968921d-02,-3.7812532d-03, 1.0934031d-07 /
      data fpppp(18, 2,14,1),fpppp(18, 2,14,2),fpppp(18, 2,14,3)/
     x-5.2640648d-02, 2.7546739d-03,-1.1717626d-07 /
      data fpppp(18, 2,15,1),fpppp(18, 2,15,2),fpppp(18, 2,15,3)/
     x-5.2831091d-02, 1.8636116d-03, 9.1527637d-07 /
      data fpppp(18, 2,16,1),fpppp(18, 2,16,2),fpppp(18, 2,16,3)/
     x-5.6013718d-02,-2.1881415d-03,-3.2282984d-07 /
      data fpppp(18, 2,17,1),fpppp(18, 2,17,2),fpppp(18, 2,17,3)/
     x-5.7716360d-02, 1.3984596d-03, 2.9207355d-07 /
      data fpppp(18, 2,18,1),fpppp(18, 2,18,2),fpppp(18, 2,18,3)/
     x-5.5914646d-02,-2.1806044d-03, 1.1947774d-06 /
      data fpppp(18, 2,19,1),fpppp(18, 2,19,2),fpppp(18, 2,19,3)/
     x-5.2683819d-02, 1.4301146d-03, 3.2899259d-07 /
      data fpppp(18, 2,20,1),fpppp(18, 2,20,2),fpppp(18, 2,20,3)/
     x-4.9229883d-02,-4.3260592d-04,-1.5904893d-06 /
      data fpppp(18, 2,21,1),fpppp(18, 2,21,2),fpppp(18, 2,21,3)/
     x-4.9229883d-02,-2.1994824d-04,-1.5890665d-06 /
      data fpppp(18, 2,22,1),fpppp(18, 2,22,2),fpppp(18, 2,22,3)/
     x-5.2683819d-02, 5.7948383d-04, 3.2330144d-07 /
      data fpppp(18, 2,23,1),fpppp(18, 2,23,2),fpppp(18, 2,23,3)/
     x-5.5914646d-02, 1.0092608d-03, 1.2161192d-06 /
      data fpppp(18, 3, 1,1),fpppp(18, 3, 1,2),fpppp(18, 3, 1,3)/
     x 1.0814186d-02, 5.7345477d-03, 9.3957766d-07 /
      data fpppp(18, 3, 2,1),fpppp(18, 3, 2,2),fpppp(18, 3, 2,3)/
     x 8.8567454d-03, 2.6445274d-03, 9.1666186d-07 /
      data fpppp(18, 3, 3,1),fpppp(18, 3, 3,2),fpppp(18, 3, 3,3)/
     x 1.3970567d-02,-3.6792225d-03, 9.8001209d-07 /
      data fpppp(18, 3, 4,1),fpppp(18, 3, 4,2),fpppp(18, 3, 4,3)/
     x 1.3970567d-02,-4.2002361d-03, 7.8321493d-07 /
      data fpppp(18, 3, 5,1),fpppp(18, 3, 5,2),fpppp(18, 3, 5,3)/
     x 8.8567454d-03, 4.7285819d-03, 1.7038505d-06 /
      data fpppp(18, 3, 6,1),fpppp(18, 3, 6,2),fpppp(18, 3, 6,3)/
     x 1.0814186d-02,-2.0806567d-03,-2.0123797d-06 /
      data fpppp(18, 3, 7,1),fpppp(18, 3, 7,2),fpppp(18, 3, 7,3)/
     x 1.8771666d-02, 4.8732537d-03, 5.0725761d-07 /
      data fpppp(18, 3, 8,1),fpppp(18, 3, 8,2),fpppp(18, 3, 8,3)/
     x 1.5961922d-02,-1.9906103d-03,-4.0716702d-08 /
      data fpppp(18, 3, 9,1),fpppp(18, 3, 9,2),fpppp(18, 3, 9,3)/
     x 1.3311733d-02, 7.0960863d-04,-9.1945413d-07 /
      data fpppp(18, 3,10,1),fpppp(18, 3,10,2),fpppp(18, 3,10,3)/
     x 1.3200996d-02,-1.4622674d-04,-6.1792752d-08 /
      data fpppp(18, 3,11,1),fpppp(18, 3,11,2),fpppp(18, 3,11,3)/
     x 1.1288135d-02, 4.8091353d-05,-3.0513774d-07 /
      data fpppp(18, 3,12,1),fpppp(18, 3,12,2),fpppp(18, 3,12,3)/
     x 1.4497328d-02,-2.6907268d-05,-2.4308327d-07 /
      data fpppp(18, 3,13,1),fpppp(18, 3,13,2),fpppp(18, 3,13,3)/
     x 1.6355879d-02, 4.4673223d-05,-3.0847615d-07 /
      data fpppp(18, 3,14,1),fpppp(18, 3,14,2),fpppp(18, 3,14,3)/
     x 1.3172367d-02,-1.3635333d-04,-6.7455592d-08 /
      data fpppp(18, 3,15,1),fpppp(18, 3,15,2),fpppp(18, 3,15,3)/
     x 1.3245691d-02, 6.8783534d-04,-9.3386226d-07 /
      data fpppp(18, 3,16,1),fpppp(18, 3,16,2),fpppp(18, 3,16,3)/
     x 1.5929938d-02,-2.0134099d-03,-2.8783244d-08 /
      data fpppp(18, 3,17,1),fpppp(18, 3,17,2),fpppp(18, 3,17,3)/
     x 1.8418857d-02, 4.9908791d-03, 4.8005833d-07 /
      data fpppp(18, 3,18,1),fpppp(18, 3,18,2),fpppp(18, 3,18,3)/
     x 1.1232951d-02,-2.8614289d-03,-1.7577161d-06 /
      data fpppp(18, 3,19,1),fpppp(18, 3,19,2),fpppp(18, 3,19,3)/
     x 7.1749851d-03, 6.9864043d-03, 1.6746814d-06 /
      data fpppp(18, 3,20,1),fpppp(18, 3,20,2),fpppp(18, 3,20,3)/
     x 1.1994565d-02,-5.2890085d-03, 6.7392582d-07 /
      data fpppp(18, 3,21,1),fpppp(18, 3,21,2),fpppp(18, 3,21,3)/
     x 1.1994565d-02,-4.5496244d-03, 8.5902472d-07 /
      data fpppp(18, 3,22,1),fpppp(18, 3,22,2),fpppp(18, 3,22,3)/
     x 7.1749851d-03, 4.0288677d-03, 9.3428581d-07 /
      data fpppp(18, 3,23,1),fpppp(18, 3,23,2),fpppp(18, 3,23,3)/
     x 1.1232951d-02, 8.2293331d-03, 1.0187674d-06 /
      data fpppp(18, 4, 1,1),fpppp(18, 4, 1,2),fpppp(18, 4, 1,3)/
     x 1.6410704d-04, 1.6535829d-02,-5.2401527d-06 /
      data fpppp(18, 4, 2,1),fpppp(18, 4, 2,2),fpppp(18, 4, 2,3)/
     x-4.2857633d-03, 8.5402617d-03,-2.3994771d-06 /
      data fpppp(18, 4, 3,1),fpppp(18, 4, 3,2),fpppp(18, 4, 3,3)/
     x-3.1816174d-02,-7.9917103d-03, 3.4915742d-06 /
      data fpppp(18, 4, 4,1),fpppp(18, 4, 4,2),fpppp(18, 4, 4,3)/
     x-3.1816174d-02,-9.0441352d-03, 3.8347681d-06 /
      data fpppp(18, 4, 5,1),fpppp(18, 4, 5,2),fpppp(18, 4, 5,3)/
     x-4.2857633d-03, 1.2749961d-02,-3.7722525d-06 /
      data fpppp(18, 4, 6,1),fpppp(18, 4, 6,2),fpppp(18, 4, 6,3)/
     x 1.6410704d-04, 7.4945579d-04,-9.2244758d-08 /
      data fpppp(18, 4, 7,1),fpppp(18, 4, 7,2),fpppp(18, 4, 7,3)/
     x-5.7767777d-03,-7.1181763d-04,-1.4047399d-06 /
      data fpppp(18, 4, 8,1),fpppp(18, 4, 8,2),fpppp(18, 4, 8,3)/
     x-3.7850948d-03, 5.5188088d-04,-8.2922180d-08 /
      data fpppp(18, 4, 9,1),fpppp(18, 4, 9,2),fpppp(18, 4, 9,3)/
     x-3.3274207d-03,-1.3707013d-04,-5.6191129d-10 /
      data fpppp(18, 4,10,1),fpppp(18, 4,10,2),fpppp(18, 4,10,3)/
     x-3.3991519d-03, 2.8747826d-05,-1.5784506d-07 /
      data fpppp(18, 4,11,1),fpppp(18, 4,11,2),fpppp(18, 4,11,3)/
     x-2.9238947d-03,-1.4288188d-05,-8.5941416d-08 /
      data fpppp(18, 4,12,1),fpppp(18, 4,12,2),fpppp(18, 4,12,3)/
     x-3.7936077d-03, 9.7173927d-09,-8.3420435d-08 /
      data fpppp(18, 4,13,1),fpppp(18, 4,13,2),fpppp(18, 4,13,3)/
     x-4.2851734d-03,-5.5705814d-06,-8.3608045d-08 /
      data fpppp(18, 4,14,1),fpppp(18, 4,14,2),fpppp(18, 4,14,3)/
     x-3.4010770d-03,-2.6714285d-06,-1.5733458d-07 /
      data fpppp(18, 4,15,1),fpppp(18, 4,15,2),fpppp(18, 4,15,3)/
     x-3.3251123d-03,-1.0113311d-05, 7.1777866d-10 /
      data fpppp(18, 4,16,1),fpppp(18, 4,16,2),fpppp(18, 4,16,3)/
     x-3.8296349d-03, 9.6327019d-05,-1.1956450d-07 /
      data fpppp(18, 4,17,1),fpppp(18, 4,17,2),fpppp(18, 4,17,3)/
     x-5.2463320d-03, 1.5194458d-04,-1.4010227d-06 /
      data fpppp(18, 4,18,1),fpppp(18, 4,18,2),fpppp(18, 4,18,3)/
     x-1.6028503d-04,-4.4404176d-04,-3.9104235d-07 /
      data fpppp(18, 4,19,1),fpppp(18, 4,19,2),fpppp(18, 4,19,3)/
     x-3.3535080d-03, 1.4242804d-02,-3.6445252d-06 /
      data fpppp(18, 4,20,1),fpppp(18, 4,20,2),fpppp(18, 4,20,3)/
     x-3.1861825d-02,-9.6258636d-03, 3.9641432d-06 /
      data fpppp(18, 4,21,1),fpppp(18, 4,21,2),fpppp(18, 4,21,3)/
     x-3.1861825d-02,-8.3999669d-03, 3.6411593d-06 /
      data fpppp(18, 4,22,1),fpppp(18, 4,22,2),fpppp(18, 4,22,3)/
     x-3.3535080d-03, 9.3392170d-03,-2.3525895d-06 /
      data fpppp(18, 4,23,1),fpppp(18, 4,23,2),fpppp(18, 4,23,3)/
     x-1.6028503d-04, 1.7944409d-02,-5.2358013d-06 /
      data fpppp(18, 5, 1,1),fpppp(18, 5, 1,2),fpppp(18, 5, 1,3)/
     x 5.7702616d-04, 1.1910116d-03, 1.9512651d-06 /
      data fpppp(18, 5, 2,1),fpppp(18, 5, 2,2),fpppp(18, 5, 2,3)/
     x 5.9336667d-03, 6.4554936d-04, 8.9550213d-07 /
      data fpppp(18, 5, 3,1),fpppp(18, 5, 3,2),fpppp(18, 5, 3,3)/
     x 2.7069286d-02,-4.6823629d-04,-1.3102041d-06 /
      data fpppp(18, 5, 4,1),fpppp(18, 5, 4,2),fpppp(18, 5, 4,3)/
     x 2.7069286d-02,-5.6459473d-04,-1.4093294d-06 /
      data fpppp(18, 5, 5,1),fpppp(18, 5, 5,2),fpppp(18, 5, 5,3)/
     x 5.9336667d-03, 1.0309831d-03, 1.2920031d-06 /
      data fpppp(18, 5, 6,1),fpppp(18, 5, 6,2),fpppp(18, 5, 6,3)/
     x 5.7702616d-04,-2.5436504d-04, 4.6438660d-07 /
      data fpppp(18, 5, 7,1),fpppp(18, 5, 7,2),fpppp(18, 5, 7,3)/
     x 2.0666366d-03, 6.2472159d-05, 5.2378691d-07 /
      data fpppp(18, 5, 8,1),fpppp(18, 5, 8,2),fpppp(18, 5, 8,3)/
     x 1.0738735d-03,-2.8466882d-05,-6.0402608d-08 /
      data fpppp(18, 5, 9,1),fpppp(18, 5, 9,2),fpppp(18, 5, 9,3)/
     x 9.0929741d-04,-4.7558566d-08,-1.0171115d-07 /
      data fpppp(18, 5,10,1),fpppp(18, 5,10,2),fpppp(18, 5,10,3)/
     x 9.3020936d-04,-9.2502765d-07,-2.6647259d-08 /
      data fpppp(18, 5,11,1),fpppp(18, 5,11,2),fpppp(18, 5,11,3)/
     x 8.1124856d-04, 4.1773010d-06,-9.2426700d-09 /
      data fpppp(18, 5,12,1),fpppp(18, 5,12,2),fpppp(18, 5,12,3)/
     x 1.0467157d-03, 4.7947763d-06, 3.0095643d-09 /
      data fpppp(18, 5,13,1),fpppp(18, 5,13,2),fpppp(18, 5,13,3)/
     x 1.1721047d-03, 3.7380886d-06,-7.1638020d-09 /
      data fpppp(18, 5,14,1),fpppp(18, 5,14,2),fpppp(18, 5,14,3)/
     x 9.2295070d-04, 9.7465589d-07,-1.8602147d-08 /
      data fpppp(18, 5,15,1),fpppp(18, 5,15,2),fpppp(18, 5,15,3)/
     x 8.9504325d-04,-1.9155094d-06,-8.8672545d-08 /
      data fpppp(18, 5,16,1),fpppp(18, 5,16,2),fpppp(18, 5,16,3)/
     x 1.0607830d-03,-5.8642954d-06,-2.6907963d-08 /
      data fpppp(18, 5,17,1),fpppp(18, 5,17,2),fpppp(18, 5,17,3)/
     x 1.6369043d-03, 2.0931350d-05, 5.3013306d-07 /
      data fpppp(18, 5,18,1),fpppp(18, 5,18,2),fpppp(18, 5,18,3)/
     x 5.2710582d-04, 3.8199999d-06, 6.0731254d-07 /
      data fpppp(18, 5,19,1),fpppp(18, 5,19,2),fpppp(18, 5,19,3)/
     x 4.9432487d-03, 2.0618524d-04, 1.1993705d-06 /
      data fpppp(18, 5,20,1),fpppp(18, 5,20,2),fpppp(18, 5,20,3)/
     x 2.8404936d-02,-1.5840927d-04,-1.4859306d-06 /
      data fpppp(18, 5,21,1),fpppp(18, 5,21,2),fpppp(18, 5,21,3)/
     x 2.8404936d-02,-1.4072687d-04,-1.3983421d-06 /
      data fpppp(18, 5,22,1),fpppp(18, 5,22,2),fpppp(18, 5,22,3)/
     x 4.9432487d-03, 1.3545562d-04, 8.4901636d-07 /
      data fpppp(18, 5,23,1),fpppp(18, 5,23,2),fpppp(18, 5,23,3)/
     x 5.2710582d-04, 2.6905609d-04, 1.9211406d-06 /
      data fpppp(18, 6, 1,1),fpppp(18, 6, 1,2),fpppp(18, 6, 1,3)/
     x-3.8121355d-04, 1.2756157d-04, 9.4710176d-07 /
      data fpppp(18, 6, 2,1),fpppp(18, 6, 2,2),fpppp(18, 6, 2,3)/
     x-2.0245373d-03, 5.3903369d-05, 4.5543942d-07 /
      data fpppp(18, 6, 3,1),fpppp(18, 6, 3,2),fpppp(18, 6, 3,3)/
     x-7.3647928d-03,-9.9952001d-05,-5.6565071d-07 /
      data fpppp(18, 6, 4,1),fpppp(18, 6, 4,2),fpppp(18, 6, 4,3)/
     x-7.3647928d-03,-1.0692334d-04,-6.2247676d-07 /
      data fpppp(18, 6, 5,1),fpppp(18, 6, 5,2),fpppp(18, 6, 5,3)/
     x-2.0245373d-03, 8.1788738d-05, 6.8274364d-07 /
      data fpppp(18, 6, 6,1),fpppp(18, 6, 6,2),fpppp(18, 6, 6,3)/
     x-3.8121355d-04, 2.2991433d-05, 9.4710935d-08 /
      data fpppp(18, 6, 7,1),fpppp(18, 6, 7,2),fpppp(18, 6, 7,3)/
     x-6.5881332d-04, 1.5594337d-05,-3.6814374d-09 /
      data fpppp(18, 6, 8,1),fpppp(18, 6, 8,2),fpppp(18, 6, 8,3)/
     x-3.2493200d-04, 9.2330403d-06, 3.9414649d-08 /
      data fpppp(18, 6, 9,1),fpppp(18, 6, 9,2),fpppp(18, 6, 9,3)/
     x-2.4763012d-04, 8.1116070d-06, 5.5832007d-08 /
      data fpppp(18, 6,10,1),fpppp(18, 6,10,2),fpppp(18, 6,10,3)/
     x-2.4093324d-04, 8.7500855d-06, 3.2010085d-08 /
      data fpppp(18, 6,11,1),fpppp(18, 6,11,2),fpppp(18, 6,11,3)/
     x-2.0861982d-04, 7.2281236d-06, 1.6742647d-08 /
      data fpppp(18, 6,12,1),fpppp(18, 6,12,2),fpppp(18, 6,12,3)/
     x-2.7409454d-04, 6.8438556d-06, 6.6839830d-09 /
      data fpppp(18, 6,13,1),fpppp(18, 6,13,2),fpppp(18, 6,13,3)/
     x-3.0990136d-04, 6.9081851d-06, 1.7865480d-08 /
      data fpppp(18, 6,14,1),fpppp(18, 6,14,2),fpppp(18, 6,14,3)/
     x-2.4738272d-04, 7.7266647d-06, 3.3592452d-08 /
      data fpppp(18, 6,15,1),fpppp(18, 6,15,2),fpppp(18, 6,15,3)/
     x-2.5327889d-04, 8.4368024d-06, 5.7653028d-08 /
      data fpppp(18, 6,16,1),fpppp(18, 6,16,2),fpppp(18, 6,16,3)/
     x-3.2441977d-04, 9.0772361d-06, 3.5624553d-08 /
      data fpppp(18, 6,17,1),fpppp(18, 6,17,2),fpppp(18, 6,17,3)/
     x-5.2653196d-04, 1.7612407d-05,-1.2942946d-08 /
      data fpppp(18, 6,18,1),fpppp(18, 6,18,2),fpppp(18, 6,18,3)/
     x-2.9034579d-04, 2.1135247d-05, 3.5897701d-08 /
      data fpppp(18, 6,19,1),fpppp(18, 6,19,2),fpppp(18, 6,19,3)/
     x-1.5633795d-03, 7.9334178d-05, 6.3613448d-07 /
      data fpppp(18, 6,20,1),fpppp(18, 6,20,2),fpppp(18, 6,20,3)/
     x-7.9073384d-03,-1.0332019d-04,-5.5453159d-07 /
      data fpppp(18, 6,21,1),fpppp(18, 6,21,2),fpppp(18, 6,21,3)/
     x-7.9073384d-03,-9.6511443d-05,-4.9966383d-07 /
      data fpppp(18, 6,22,1),fpppp(18, 6,22,2),fpppp(18, 6,22,3)/
     x-1.5633795d-03, 5.2099183d-05, 4.1666342d-07 /
      data fpppp(18, 6,23,1),fpppp(18, 6,23,2),fpppp(18, 6,23,3)/
     x-2.9034579d-04, 1.2326648d-04, 8.5891420d-07 /
      data fpppp(18, 7, 1,1),fpppp(18, 7, 1,2),fpppp(18, 7, 1,3)/
     x 3.2406862d-05, 7.0715829d-06,-4.9428331d-08 /
      data fpppp(18, 7, 2,1),fpppp(18, 7, 2,2),fpppp(18, 7, 2,3)/
     x 4.8377792d-04,-4.5405668d-06,-9.1647469d-08 /
      data fpppp(18, 7, 3,1),fpppp(18, 7, 3,2),fpppp(18, 7, 3,3)/
     x 2.7220821d-03,-2.9251238d-05,-1.8692621d-07 /
      data fpppp(18, 7, 4,1),fpppp(18, 7, 4,2),fpppp(18, 7, 4,3)/
     x 2.7220821d-03,-2.9553125d-05,-1.7851018d-07 /
      data fpppp(18, 7, 5,1),fpppp(18, 7, 5,2),fpppp(18, 7, 5,3)/
     x 4.8377792d-04,-3.3330188d-06,-1.2531157d-07 /
      data fpppp(18, 7, 6,1),fpppp(18, 7, 6,2),fpppp(18, 7, 6,3)/
     x 3.2406862d-05, 2.5432779d-06, 7.6812040d-08 /
      data fpppp(18, 7, 7,1),fpppp(18, 7, 7,2),fpppp(18, 7, 7,3)/
     x 1.2682726d-04, 4.2108293d-06, 1.1498327d-07 /
      data fpppp(18, 7, 8,1),fpppp(18, 7, 8,2),fpppp(18, 7, 8,3)/
     x 6.1054955d-05, 6.1184582d-06, 8.2923885d-08 /
      data fpppp(18, 7, 9,1),fpppp(18, 7, 9,2),fpppp(18, 7, 9,3)/
     x 5.6912288d-05, 7.5333229d-06, 5.3179187d-08 /
      data fpppp(18, 7,10,1),fpppp(18, 7,10,2),fpppp(18, 7,10,3)/
     x 6.4089236d-05, 8.5772027d-06, 3.6242784d-08 /
      data fpppp(18, 7,11,1),fpppp(18, 7,11,2),fpppp(18, 7,11,3)/
     x 5.9322744d-05, 9.0583174d-06, 2.8372564d-08 /
      data fpppp(18, 7,12,1),fpppp(18, 7,12,2),fpppp(18, 7,12,3)/
     x 7.6675895d-05, 9.0184276d-06, 2.8216709d-08 /
      data fpppp(18, 7,13,1),fpppp(18, 7,13,2),fpppp(18, 7,13,3)/
     x 8.3710382d-05, 9.0717974d-06, 2.5992581d-08 /
      data fpppp(18, 7,14,1),fpppp(18, 7,14,2),fpppp(18, 7,14,3)/
     x 6.1992787d-05, 8.3859216d-06, 2.9947344d-08 /
      data fpppp(18, 7,15,1),fpppp(18, 7,15,2),fpppp(18, 7,15,3)/
     x 5.8680936d-05, 1.0159616d-05, 4.1709711d-08 /
      data fpppp(18, 7,16,1),fpppp(18, 7,16,2),fpppp(18, 7,16,3)/
     x 6.4926716d-05, 6.8555044d-06, 6.3217633d-08 /
      data fpppp(18, 7,17,1),fpppp(18, 7,17,2),fpppp(18, 7,17,3)/
     x 1.0655188d-04, 1.3451681d-05, 9.4797926d-08 /
      data fpppp(18, 7,18,1),fpppp(18, 7,18,2),fpppp(18, 7,18,3)/
     x 2.8012600d-05, 6.0901209d-06, 7.8851972d-08 /
      data fpppp(18, 7,19,1),fpppp(18, 7,19,2),fpppp(18, 7,19,3)/
     x 3.8121432d-04, 3.5691655d-06,-8.6168926d-08 /
      data fpppp(18, 7,20,1),fpppp(18, 7,20,2),fpppp(18, 7,20,3)/
     x 2.1545536d-03,-3.8233564d-05,-1.8085638d-07 /
      data fpppp(18, 7,21,1),fpppp(18, 7,21,2),fpppp(18, 7,21,3)/
     x 2.1545536d-03,-3.7427220d-05,-1.8659215d-07 /
      data fpppp(18, 7,22,1),fpppp(18, 7,22,2),fpppp(18, 7,22,3)/
     x 3.8121432d-04, 3.4378858d-07,-6.3225872d-08 /
      data fpppp(18, 7,23,1),fpppp(18, 7,23,2),fpppp(18, 7,23,3)/
     x 2.8012600d-05, 1.8185284d-05,-7.1844807d-09 /
      data fpppp(18, 8, 1,1),fpppp(18, 8, 1,2),fpppp(18, 8, 1,3)/
     x-3.0089981d-05, 9.0058898d-04, 5.3704257d-08 /
      data fpppp(18, 8, 2,1),fpppp(18, 8, 2,2),fpppp(18, 8, 2,3)/
     x-1.2318130d-04, 4.8435936d-04,-5.1049286d-09 /
      data fpppp(18, 8, 3,1),fpppp(18, 8, 3,2),fpppp(18, 8, 3,3)/
     x-8.7014923d-04,-3.6500922d-04,-1.2963561d-07 /
      data fpppp(18, 8, 4,1),fpppp(18, 8, 4,2),fpppp(18, 8, 4,3)/
     x-8.7014923d-04,-4.3947525d-04,-1.3224137d-07 /
      data fpppp(18, 8, 5,1),fpppp(18, 8, 5,2),fpppp(18, 8, 5,3)/
     x-1.2318130d-04, 7.8222350d-04, 5.3181146d-09 /
      data fpppp(18, 8, 6,1),fpppp(18, 8, 6,2),fpppp(18, 8, 6,3)/
     x-3.0089981d-05,-2.1640153d-04, 1.4617845d-08 /
      data fpppp(18, 8, 7,1),fpppp(18, 8, 7,2),fpppp(18, 8, 7,3)/
     x-6.2769216d-05, 5.2607466d-05, 3.6385106d-08 /
      data fpppp(18, 8, 8,1),fpppp(18, 8, 8,2),fpppp(18, 8, 8,3)/
     x-4.5703375d-05,-1.7164709d-05, 4.2205835d-08 /
      data fpppp(18, 8, 9,1),fpppp(18, 8, 9,2),fpppp(18, 8, 9,3)/
     x-4.0052502d-05, 6.3733903d-06, 3.7150392d-08 /
      data fpppp(18, 8,10,1),fpppp(18, 8,10,2),fpppp(18, 8,10,3)/
     x-3.5680882d-05, 4.2937113d-06, 3.1186172d-08 /
      data fpppp(18, 8,11,1),fpppp(18, 8,11,2),fpppp(18, 8,11,3)/
     x-2.8860652d-05, 8.2039723d-06, 2.8478386d-08 /
      data fpppp(18, 8,12,1),fpppp(18, 8,12,2),fpppp(18, 8,12,3)/
     x-2.9523303d-05, 9.2493224d-06, 2.5996634d-08 /
      data fpppp(18, 8,13,1),fpppp(18, 8,13,2),fpppp(18, 8,13,3)/
     x-3.1654485d-05, 8.6193671d-06, 2.5743103d-08 /
      data fpppp(18, 8,14,1),fpppp(18, 8,14,2),fpppp(18, 8,14,3)/
     x-2.8048372d-05, 1.0507459d-05, 2.6595100d-08 /
      data fpppp(18, 8,15,1),fpppp(18, 8,15,2),fpppp(18, 8,15,3)/
     x-3.3330207d-05, 4.9695662d-06, 2.5461505d-08 /
      data fpppp(18, 8,16,1),fpppp(18, 8,16,2),fpppp(18, 8,16,3)/
     x-3.5095056d-05, 7.3257367d-06, 2.5714477d-08 /
      data fpppp(18, 8,17,1),fpppp(18, 8,17,2),fpppp(18, 8,17,3)/
     x-4.7701597d-05, 5.1404907d-06, 1.5519626d-08 /
      data fpppp(18, 8,18,1),fpppp(18, 8,18,2),fpppp(18, 8,18,3)/
     x-2.0648379d-05, 2.2552524d-06,-1.6286815d-09 /
      data fpppp(18, 8,19,1),fpppp(18, 8,19,2),fpppp(18, 8,19,3)/
     x-1.0273484d-04,-4.2820324d-06,-5.5348002d-09 /
      data fpppp(18, 8,20,1),fpppp(18, 8,20,2),fpppp(18, 8,20,3)/
     x-5.5812744d-04,-1.9693634d-05,-9.0855700d-08 /
      data fpppp(18, 8,21,1),fpppp(18, 8,21,2),fpppp(18, 8,21,3)/
     x-5.5812744d-04,-1.9662552d-05,-8.9151097d-08 /
      data fpppp(18, 8,22,1),fpppp(18, 8,22,2),fpppp(18, 8,22,3)/
     x-1.0273484d-04,-4.4063607d-06,-1.2353212d-08 /
      data fpppp(18, 8,23,1),fpppp(18, 8,23,2),fpppp(18, 8,23,3)/
     x-2.0648379d-05, 2.7214838d-06, 2.3940362d-08 /
      data fpppp(18, 9, 1,1),fpppp(18, 9, 1,2),fpppp(18, 9, 1,3)/
     x-4.0639753d-05, 9.6811255d-04, 1.3076838d-07 /
      data fpppp(18, 9, 2,1),fpppp(18, 9, 2,2),fpppp(18, 9, 2,3)/
     x-2.0452052d-05, 5.2304856d-04, 4.4303038d-08 /
      data fpppp(18, 9, 3,1),fpppp(18, 9, 3,2),fpppp(18, 9, 3,3)/
     x-1.4830335d-03,-3.8527294d-04,-1.3863186d-07 /
      data fpppp(18, 9, 4,1),fpppp(18, 9, 4,2),fpppp(18, 9, 4,3)/
     x-1.4830335d-03,-4.6470029d-04,-1.4274081d-07 /
      data fpppp(18, 9, 5,1),fpppp(18, 9, 5,2),fpppp(18, 9, 5,3)/
     x-2.0452052d-05, 8.4075792d-04, 6.0738844d-08 /
      data fpppp(18, 9, 6,1),fpppp(18, 9, 6,2),fpppp(18, 9, 6,3)/
     x-4.0639753d-05,-2.2329755d-04, 6.9134104d-08 /
      data fpppp(18, 9, 7,1),fpppp(18, 9, 7,2),fpppp(18, 9, 7,3)/
     x-3.1503629d-05, 5.1864117d-05, 3.0346473d-08 /
      data fpppp(18, 9, 8,1),fpppp(18, 9, 8,2),fpppp(18, 9, 8,3)/
     x-2.8276551d-05,-2.3058176d-05, 1.4394569d-08 /
      data fpppp(18, 9, 9,1),fpppp(18, 9, 9,2),fpppp(18, 9, 9,3)/
     x-2.3915066d-05, 1.8988199d-06, 1.3461897d-08 /
      data fpppp(18, 9,10,1),fpppp(18, 9,10,2),fpppp(18, 9,10,3)/
     x-2.1316409d-05, 3.1884139d-07, 1.4020124d-08 /
      data fpppp(18, 9,11,1),fpppp(18, 9,11,2),fpppp(18, 9,11,3)/
     x-1.9588772d-05, 6.4097582d-06, 1.3080855d-08 /
      data fpppp(18, 9,12,1),fpppp(18, 9,12,2),fpppp(18, 9,12,3)/
     x-1.6957675d-05, 6.0226574d-06, 1.2721310d-08 /
      data fpppp(18, 9,13,1),fpppp(18, 9,13,2),fpppp(18, 9,13,3)/
     x-1.2493584d-05, 8.5772460d-06, 1.4729831d-08 /
      data fpppp(18, 9,14,1),fpppp(18, 9,14,2),fpppp(18, 9,14,3)/
     x-9.6700281d-06, 7.0018820d-06, 1.4448413d-08 /
      data fpppp(18, 9,15,1),fpppp(18, 9,15,2),fpppp(18, 9,15,3)/
     x-4.3714388d-06, 7.2066516d-06, 1.6124822d-08 /
      data fpppp(18, 9,16,1),fpppp(18, 9,16,2),fpppp(18, 9,16,3)/
     x-2.7293892d-06, 3.6835753d-06, 1.1746089d-08 /
      data fpppp(18, 9,17,1),fpppp(18, 9,17,2),fpppp(18, 9,17,3)/
     x 5.4309805d-06, 4.3826764d-06, 7.5165072d-09 /
      data fpppp(18, 9,18,1),fpppp(18, 9,18,2),fpppp(18, 9,18,3)/
     x 3.7297807d-06, 9.3230470d-07,-2.6906144d-09 /
      data fpppp(18, 9,19,1),fpppp(18, 9,19,2),fpppp(18, 9,19,3)/
     x 3.3487262d-05,-3.0933437d-06,-2.7231336d-08 /
      data fpppp(18, 9,20,1),fpppp(18, 9,20,2),fpppp(18, 9,20,3)/
     x 1.6346364d-04,-1.2693280d-05,-3.2969596d-08 /
      data fpppp(18, 9,21,1),fpppp(18, 9,21,2),fpppp(18, 9,21,3)/
     x 1.6346364d-04,-1.2671715d-05,-3.4007390d-08 /
      data fpppp(18, 9,22,1),fpppp(18, 9,22,2),fpppp(18, 9,22,3)/
     x 3.3487262d-05,-3.1796074d-06,-2.3080159d-08 /
      data fpppp(18, 9,23,1),fpppp(18, 9,23,2),fpppp(18, 9,23,3)/
     x 3.7297807d-06, 1.2557935d-06,-1.8257529d-08 /
      data fpppp(18,10, 1,1),fpppp(18,10, 1,2),fpppp(18,10, 1,3)/
     x-2.0495380d-04,-4.8353308d-04, 4.7931593d-07 /
      data fpppp(18,10, 2,1),fpppp(18,10, 2,2),fpppp(18,10, 2,3)/
     x-2.9108147d-04,-2.5803796d-04, 2.5124540d-07 /
      data fpppp(18,10, 3,1),fpppp(18,10, 3,2),fpppp(18,10, 3,3)/
     x 2.0167955d-03, 2.0178692d-04,-2.1926115d-07 /
      data fpppp(18,10, 4,1),fpppp(18,10, 4,2),fpppp(18,10, 4,3)/
     x 2.0167955d-03, 2.4270010d-04,-2.5113917d-07 /
      data fpppp(18,10, 5,1),fpppp(18,10, 5,2),fpppp(18,10, 5,3)/
     x-2.9108147d-04,-4.2169065d-04, 3.7875745d-07 /
      data fpppp(18,10, 6,1),fpppp(18,10, 6,2),fpppp(18,10, 6,3)/
     x-2.0495380d-04, 1.3016451d-04, 1.1457283d-09 /
      data fpppp(18,10, 7,1),fpppp(18,10, 7,2),fpppp(18,10, 7,3)/
     x-9.5454222d-05,-5.4431916d-05, 1.0518104d-08 /
      data fpppp(18,10, 8,1),fpppp(18,10, 8,2),fpppp(18,10, 8,3)/
     x-5.2739882d-05,-7.7753240d-06,-1.5120506d-08 /
      data fpppp(18,10, 9,1),fpppp(18,10, 9,2),fpppp(18,10, 9,3)/
     x-3.4254184d-05,-1.2834325d-05,-7.9014934d-09 /
      data fpppp(18,10,10,1),fpppp(18,10,10,2),fpppp(18,10,10,3)/
     x-2.5675541d-05,-2.0356706d-06,-1.3962098d-09 /
      data fpppp(18,10,11,1),fpppp(18,10,11,2),fpppp(18,10,11,3)/
     x-2.1960096d-05, 2.4940163d-06, 3.8198822d-09 /
      data fpppp(18,10,12,1),fpppp(18,10,12,2),fpppp(18,10,12,3)/
     x-1.9063002d-05, 4.9743563d-06, 6.3609177d-09 /
      data fpppp(18,10,13,1),fpppp(18,10,13,2),fpppp(18,10,13,3)/
     x-1.6766079d-05, 7.2064704d-06, 6.4247143d-09 /
      data fpppp(18,10,14,1),fpppp(18,10,14,2),fpppp(18,10,14,3)/
     x-1.5028020d-05, 5.2488494d-06, 7.2998925d-09 /
      data fpppp(18,10,15,1),fpppp(18,10,15,2),fpppp(18,10,15,3)/
     x-1.2520949d-05, 5.5434128d-06, 4.4374911d-09 /
      data fpppp(18,10,16,1),fpppp(18,10,16,2),fpppp(18,10,16,3)/
     x-8.4960836d-06, 4.2987883d-06, 3.4193873d-09 /
      data fpppp(18,10,17,1),fpppp(18,10,17,2),fpppp(18,10,17,3)/
     x-6.9632884d-06, 3.2352071d-06, 1.4318881d-10 /
      data fpppp(18,10,18,1),fpppp(18,10,18,2),fpppp(18,10,18,3)/
     x-1.2715880d-06, 1.2829890d-06,-4.3624521d-09 /
      data fpppp(18,10,19,1),fpppp(18,10,19,2),fpppp(18,10,19,3)/
     x-5.4858722d-06,-1.4204686d-06,-6.8143340d-09 /
      data fpppp(18,10,20,1),fpppp(18,10,20,2),fpppp(18,10,20,3)/
     x-3.7760769d-05,-9.7944809d-06,-1.3774410d-08 /
      data fpppp(18,10,21,1),fpppp(18,10,21,2),fpppp(18,10,21,3)/
     x-3.7760769d-05,-9.7373093d-06,-1.3736618d-08 /
      data fpppp(18,10,22,1),fpppp(18,10,22,2),fpppp(18,10,22,3)/
     x-5.4858722d-06,-1.6491550d-06,-6.9655024d-09 /
      data fpppp(18,10,23,1),fpppp(18,10,23,2),fpppp(18,10,23,3)/
     x-1.2715880d-06, 2.1405628d-06,-3.7955705d-09 /
      data fpppp(18,11, 1,1),fpppp(18,11, 1,2),fpppp(18,11, 1,3)/
     x-4.6810234d-05,-4.2915628d-04, 7.5524836d-08 /
      data fpppp(18,11, 2,1),fpppp(18,11, 2,2),fpppp(18,11, 2,3)/
     x-4.1602824d-04,-2.0300489d-04, 3.7271506d-08 /
      data fpppp(18,11, 3,1),fpppp(18,11, 3,2),fpppp(18,11, 3,3)/
     x-4.5543999d-03, 2.6244195d-04,-4.0785038d-08 /
      data fpppp(18,11, 4,1),fpppp(18,11, 4,2),fpppp(18,11, 4,3)/
     x-4.5543999d-03, 2.9597772d-04,-4.7636074d-08 /
      data fpppp(18,11, 5,1),fpppp(18,11, 5,2),fpppp(18,11, 5,3)/
     x-4.1602824d-04,-3.3714797d-04, 6.4675650d-08 /
      data fpppp(18,11, 6,1),fpppp(18,11, 6,2),fpppp(18,11, 6,3)/
     x-4.6810234d-05, 7.3880280d-05,-2.7240706d-08 /
      data fpppp(18,11, 7,1),fpppp(18,11, 7,2),fpppp(18,11, 7,3)/
     x-4.6749667d-05,-1.1508007d-04, 3.3711558d-08 /
      data fpppp(18,11, 8,1),fpppp(18,11, 8,2),fpppp(18,11, 8,3)/
     x-3.6159472d-05,-2.7858044d-05, 3.4893635d-09 /
      data fpppp(18,11, 9,1),fpppp(18,11, 9,2),fpppp(18,11, 9,3)/
     x-2.6148927d-05,-2.8112865d-05,-2.5539992d-09 /
      data fpppp(18,11,10,1),fpppp(18,11,10,2),fpppp(18,11,10,3)/
     x-1.8211425d-05,-1.0307121d-05,-1.4848863d-09 /
      data fpppp(18,11,11,1),fpppp(18,11,11,2),fpppp(18,11,11,3)/
     x-1.3760479d-05,-1.0189457d-06, 1.2561011d-09 /
      data fpppp(18,11,12,1),fpppp(18,11,12,2),fpppp(18,11,12,3)/
     x-1.1462885d-05, 3.7085806d-06, 2.3786824d-09 /
      data fpppp(18,11,13,1),fpppp(18,11,13,2),fpppp(18,11,13,3)/
     x-1.0111286d-05, 4.7891264d-06, 2.8601725d-09 /
      data fpppp(18,11,14,1),fpppp(18,11,14,2),fpppp(18,11,14,3)/
     x-7.9553305d-06, 4.8279318d-06, 1.4929113d-09 /
      data fpppp(18,11,15,1),fpppp(18,11,15,2),fpppp(18,11,15,3)/
     x-6.5175779d-06, 4.4311592d-06, 1.1127765d-09 /
      data fpppp(18,11,16,1),fpppp(18,11,16,2),fpppp(18,11,16,3)/
     x-5.0570551d-06, 3.8153568d-06,-2.7478327d-10 /
      data fpppp(18,11,17,1),fpppp(18,11,17,2),fpppp(18,11,17,3)/
     x-2.3348492d-06, 3.7430510d-06,-1.4722434d-09 /
      data fpppp(18,11,18,1),fpppp(18,11,18,2),fpppp(18,11,18,3)/
     x-2.5194706d-06,-2.1711406d-08,-2.3165082d-09 /
      data fpppp(18,11,19,1),fpppp(18,11,19,2),fpppp(18,11,19,3)/
     x-3.3968314d-07,-5.8221627d-07, 2.3393768d-09 /
      data fpppp(18,11,20,1),fpppp(18,11,20,2),fpppp(18,11,20,3)/
     x 7.8321725d-06,-7.9332978d-06,-5.9586501d-09 /
      data fpppp(18,11,21,1),fpppp(18,11,21,2),fpppp(18,11,21,3)/
     x 7.8321725d-06,-7.7970636d-06,-5.5538258d-09 /
      data fpppp(18,11,22,1),fpppp(18,11,22,2),fpppp(18,11,22,3)/
     x-3.3968314d-07,-1.1271529d-06, 7.2007980d-10 /
      data fpppp(18,11,23,1),fpppp(18,11,23,2),fpppp(18,11,23,3)/
     x-2.5194706d-06, 2.0218011d-06, 3.7558556d-09 /
      data fpppp(18,12, 1,1),fpppp(18,12, 1,2),fpppp(18,12, 1,3)/
     x 1.2172955d-04,-3.1376925d-03,-4.9862072d-07 /
      data fpppp(18,12, 2,1),fpppp(18,12, 2,2),fpppp(18,12, 2,3)/
     x 6.3901549d-04,-1.6148759d-03,-2.8726053d-07 /
      data fpppp(18,12, 3,1),fpppp(18,12, 3,2),fpppp(18,12, 3,3)/
     x 6.4006082d-03, 1.5153231d-03, 1.4340318d-07 /
      data fpppp(18,12, 4,1),fpppp(18,12, 4,2),fpppp(18,12, 4,3)/
     x 6.4006082d-03, 1.7480374d-03, 1.8234240d-07 /
      data fpppp(18,12, 5,1),fpppp(18,12, 5,2),fpppp(18,12, 5,3)/
     x 6.3901549d-04,-2.5457330d-03,-4.4301742d-07 /
      data fpppp(18,12, 6,1),fpppp(18,12, 6,2),fpppp(18,12, 6,3)/
     x 1.2172955d-04, 3.5302169d-04, 8.5467621d-08 /
      data fpppp(18,12, 7,1),fpppp(18,12, 7,2),fpppp(18,12, 7,3)/
     x 2.7378032d-05,-2.5462649d-04, 1.0950927d-08 /
      data fpppp(18,12, 8,1),fpppp(18,12, 8,2),fpppp(18,12, 8,3)/
     x-1.4190280d-06,-2.6885635d-05, 4.3011481d-08 /
      data fpppp(18,12, 9,1),fpppp(18,12, 9,2),fpppp(18,12, 9,3)/
     x-7.2293709d-06,-5.2274189d-05, 2.2728514d-08 /
      data fpppp(18,12,10,1),fpppp(18,12,10,2),fpppp(18,12,10,3)/
     x-1.0140088d-05,-1.9402157d-05, 1.1123232d-08 /
      data fpppp(18,12,11,1),fpppp(18,12,11,2),fpppp(18,12,11,3)/
     x-8.5670689d-06,-6.6804721d-06, 5.9547810d-09 /
      data fpppp(18,12,12,1),fpppp(18,12,12,2),fpppp(18,12,12,3)/
     x-7.8921361d-06, 1.5308004d-06, 3.2206055d-09 /
      data fpppp(18,12,13,1),fpppp(18,12,13,2),fpppp(18,12,13,3)/
     x-7.5102024d-06, 3.4912143d-06, 7.5051654d-10 /
      data fpppp(18,12,14,1),fpppp(18,12,14,2),fpppp(18,12,14,3)/
     x-6.9928908d-06, 3.6352342d-06,-2.7147409d-10 /
      data fpppp(18,12,15,1),fpppp(18,12,15,2),fpppp(18,12,15,3)/
     x-6.0149262d-06, 3.6434452d-06,-1.0247724d-09 /
      data fpppp(18,12,16,1),fpppp(18,12,16,2),fpppp(18,12,16,3)/
     x-5.3313172d-06, 4.1200671d-06,-6.9561680d-10 /
      data fpppp(18,12,17,1),fpppp(18,12,17,2),fpppp(18,12,17,3)/
     x-5.7371782d-06, 2.2389799d-06, 2.3410146d-11 /
      data fpppp(18,12,18,1),fpppp(18,12,18,2),fpppp(18,12,18,3)/
     x-5.1297999d-06,-5.2205764d-07, 6.9334551d-10 /
      data fpppp(18,12,19,1),fpppp(18,12,19,2),fpppp(18,12,19,3)/
     x-4.6877940d-06,-1.5631864d-06, 1.6397594d-09 /
      data fpppp(18,12,20,1),fpppp(18,12,20,2),fpppp(18,12,20,3)/
     x-6.2156794d-06,-5.6618106d-06,-7.4758028d-10 /
      data fpppp(18,12,21,1),fpppp(18,12,21,2),fpppp(18,12,21,3)/
     x-6.2156794d-06,-5.6204389d-06,-6.4977147d-10 /
      data fpppp(18,12,22,1),fpppp(18,12,22,2),fpppp(18,12,22,3)/
     x-4.6877940d-06,-1.7286730d-06, 1.2485242d-09 /
      data fpppp(18,12,23,1),fpppp(18,12,23,2),fpppp(18,12,23,3)/
     x-5.1297999d-06, 9.8516929d-08, 2.1604778d-09 /
      data fpppp(18,13, 1,1),fpppp(18,13, 1,2),fpppp(18,13, 1,3)/
     x 5.0520150d-05,-4.8439479d-04,-4.9636775d-07 /
      data fpppp(18,13, 2,1),fpppp(18,13, 2,2),fpppp(18,13, 2,3)/
     x 1.5590589d-04,-1.7452276d-04,-2.3421782d-07 /
      data fpppp(18,13, 3,1),fpppp(18,13, 3,2),fpppp(18,13, 3,3)/
     x-2.4649561d-03, 4.7929957d-04, 3.1557183d-07 /
      data fpppp(18,13, 4,1),fpppp(18,13, 4,2),fpppp(18,13, 4,3)/
     x-2.4649561d-03, 4.9713064d-04, 3.3650219d-07 /
      data fpppp(18,13, 5,1),fpppp(18,13, 5,2),fpppp(18,13, 5,3)/
     x 1.5590589d-04,-2.4584704d-04,-3.1793922d-07 /
      data fpppp(18,13, 6,1),fpppp(18,13, 6,2),fpppp(18,13, 6,3)/
     x 5.0520150d-05,-2.1692874d-04,-1.8241248d-07 /
      data fpppp(18,13, 7,1),fpppp(18,13, 7,2),fpppp(18,13, 7,3)/
     x 3.0649311d-05,-9.8181422d-05,-8.1891218d-08 /
      data fpppp(18,13, 8,1),fpppp(18,13, 8,2),fpppp(18,13, 8,3)/
     x 1.5500936d-05,-8.3317380d-05, 3.5112269d-09 /
      data fpppp(18,13, 9,1),fpppp(18,13, 9,2),fpppp(18,13, 9,3)/
     x-2.2971016d-06,-5.4092825d-05, 2.9989840d-08 /
      data fpppp(18,13,10,1),fpppp(18,13,10,2),fpppp(18,13,10,3)/
     x-8.2405821d-07,-3.1667251d-05, 2.4905859d-08 /
      data fpppp(18,13,11,1),fpppp(18,13,11,2),fpppp(18,13,11,3)/
     x-3.9447663d-06,-1.2149819d-05, 1.2959270d-08 /
      data fpppp(18,13,12,1),fpppp(18,13,12,2),fpppp(18,13,12,3)/
     x-4.3140238d-06,-1.2398850d-06, 6.6070123d-09 /
      data fpppp(18,13,13,1),fpppp(18,13,13,2),fpppp(18,13,13,3)/
     x-4.4653306d-06, 2.4727040d-06, 2.5507984d-09 /
      data fpppp(18,13,14,1),fpppp(18,13,14,2),fpppp(18,13,14,3)/
     x-5.1865367d-06, 2.6938044d-06,-1.2728028d-10 /
      data fpppp(18,13,15,1),fpppp(18,13,15,2),fpppp(18,13,15,3)/
     x-5.6839430d-06, 2.9194667d-06,-7.8566270d-10 /
      data fpppp(18,13,16,1),fpppp(18,13,16,2),fpppp(18,13,16,3)/
     x-5.5706984d-06, 3.3745655d-06,-4.9458104d-10 /
      data fpppp(18,13,17,1),fpppp(18,13,17,2),fpppp(18,13,17,3)/
     x-6.0066976d-06, 1.2265798d-06, 6.3790469d-10 /
      data fpppp(18,13,18,1),fpppp(18,13,18,2),fpppp(18,13,18,3)/
     x-6.2954965d-06,-6.4554594d-07, 2.0977501d-09 /
      data fpppp(18,13,19,1),fpppp(18,13,19,2),fpppp(18,13,19,3)/
     x-6.1284139d-06,-2.3844588d-06,-2.1762119d-09 /
      data fpppp(18,13,20,1),fpppp(18,13,20,2),fpppp(18,13,20,3)/
     x-3.6473856d-06,-3.9795237d-06, 3.2655368d-09 /
      data fpppp(18,13,21,1),fpppp(18,13,21,2),fpppp(18,13,21,3)/
     x-3.6473856d-06,-4.0267333d-06, 2.9421138d-09 /
      data fpppp(18,13,22,1),fpppp(18,13,22,2),fpppp(18,13,22,3)/
     x-6.1284139d-06,-2.1956203d-06,-8.8251985d-10 /
      data fpppp(18,13,23,1),fpppp(18,13,23,2),fpppp(18,13,23,3)/
     x-6.2954965d-06,-1.3536902d-06,-2.7535950d-09 /
      data fpppp(18,14, 1,1),fpppp(18,14, 1,2),fpppp(18,14, 1,3)/
     x-1.0189163d-04,-1.4991127d-04,-4.2158802d-07 /
      data fpppp(18,14, 2,1),fpppp(18,14, 2,2),fpppp(18,14, 2,3)/
     x-1.1908430d-03, 1.4141900d-05,-1.8781874d-07 /
      data fpppp(18,14, 3,1),fpppp(18,14, 3,2),fpppp(18,14, 3,3)/
     x-3.0165247d-03, 3.7142971d-04, 3.0167137d-07 /
      data fpppp(18,14, 4,1),fpppp(18,14, 4,2),fpppp(18,14, 4,3)/
     x-3.0165247d-03, 3.6137543d-04, 3.2169848d-07 /
      data fpppp(18,14, 5,1),fpppp(18,14, 5,2),fpppp(18,14, 5,3)/
     x-1.1908430d-03, 5.4359034d-05,-2.6792716d-07 /
      data fpppp(18,14, 6,1),fpppp(18,14, 6,2),fpppp(18,14, 6,3)/
     x-1.0189163d-04,-3.0072552d-04,-1.2118147d-07 /
      data fpppp(18,14, 7,1),fpppp(18,14, 7,2),fpppp(18,14, 7,3)/
     x 2.8047319d-05,-8.0689486d-05,-1.2634958d-07 /
      data fpppp(18,14, 8,1),fpppp(18,14, 8,2),fpppp(18,14, 8,3)/
     x 4.3078123d-05,-1.0055407d-04,-2.7958535d-08 /
      data fpppp(18,14, 9,1),fpppp(18,14, 9,2),fpppp(18,14, 9,3)/
     x 5.6680082d-05,-6.2779325d-05, 1.1084237d-08 /
      data fpppp(18,14,10,1),fpppp(18,14,10,2),fpppp(18,14,10,3)/
     x 9.7096132d-06,-3.6244419d-05, 2.1227039d-08 /
      data fpppp(18,14,11,1),fpppp(18,14,11,2),fpppp(18,14,11,3)/
     x 2.3091855d-06,-1.5824231d-05, 1.4741196d-08 /
      data fpppp(18,14,12,1),fpppp(18,14,12,2),fpppp(18,14,12,3)/
     x-1.9922950d-07,-3.8785083d-06, 8.3254069d-09 /
      data fpppp(18,14,13,1),fpppp(18,14,13,2),fpppp(18,14,13,3)/
     x-1.5079063d-06, 9.0955261d-07, 4.3769848d-09 /
      data fpppp(18,14,14,1),fpppp(18,14,14,2),fpppp(18,14,14,3)/
     x-2.3899958d-06, 2.0812445d-06, 1.9237530d-09 /
      data fpppp(18,14,15,1),fpppp(18,14,15,2),fpppp(18,14,15,3)/
     x-3.4171866d-06, 2.6354013d-06, 8.2409708d-10 /
      data fpppp(18,14,16,1),fpppp(18,14,16,2),fpppp(18,14,16,3)/
     x-5.3397214d-06, 1.7934458d-06, 5.0408770d-10 /
      data fpppp(18,14,17,1),fpppp(18,14,17,2),fpppp(18,14,17,3)/
     x-6.0475348d-06, 1.0450156d-06, 8.0771035d-10 /
      data fpppp(18,14,18,1),fpppp(18,14,18,2),fpppp(18,14,18,3)/
     x-6.2008679d-06,-1.1002386d-06, 7.9455043d-10 /
      data fpppp(18,14,19,1),fpppp(18,14,19,2),fpppp(18,14,19,3)/
     x-6.5868647d-06,-1.2862600d-06, 3.4067638d-09 /
      data fpppp(18,14,20,1),fpppp(18,14,20,2),fpppp(18,14,20,3)/
     x-8.0609729d-06,-3.4461371d-06,-3.6016599d-10 /
      data fpppp(18,14,21,1),fpppp(18,14,21,2),fpppp(18,14,21,3)/
     x-8.0609729d-06,-3.4071219d-06,-1.5272387d-10 /
      data fpppp(18,14,22,1),fpppp(18,14,22,2),fpppp(18,14,22,3)/
     x-6.5868647d-06,-1.4423210d-06, 2.5769953d-09 /
      data fpppp(18,14,23,1),fpppp(18,14,23,2),fpppp(18,14,23,3)/
     x-6.2008679d-06,-5.1500991d-07, 3.9061822d-09 /
      data fpppp(18,15, 1,1),fpppp(18,15, 1,2),fpppp(18,15, 1,3)/
     x 9.3374635d-04,-1.9509662d-03,-2.4649745d-07 /
      data fpppp(18,15, 2,1),fpppp(18,15, 2,2),fpppp(18,15, 2,3)/
     x 4.1473311d-03,-9.2463928d-04,-1.1650264d-07 /
      data fpppp(18,15, 3,1),fpppp(18,15, 3,2),fpppp(18,15, 3,3)/
     x 7.3333024d-03, 1.2080996d-03, 1.5506166d-07 /
      data fpppp(18,15, 4,1),fpppp(18,15, 4,2),fpppp(18,15, 4,3)/
     x 7.3333024d-03, 1.3245325d-03, 1.6730466d-07 /
      data fpppp(18,15, 5,1),fpppp(18,15, 5,2),fpppp(18,15, 5,3)/
     x 4.1473311d-03,-1.3903709d-03,-1.6547462d-07 /
      data fpppp(18,15, 6,1),fpppp(18,15, 6,2),fpppp(18,15, 6,3)/
     x 9.3374635d-04,-2.0447259d-04,-6.2852495d-08 /
      data fpppp(18,15, 7,1),fpppp(18,15, 7,2),fpppp(18,15, 7,3)/
     x 3.6523413d-04,-1.4392285d-04,-6.7846420d-09 /
      data fpppp(18,15, 8,1),fpppp(18,15, 8,2),fpppp(18,15, 8,3)/
     x 1.3185723d-04,-9.4714087d-05,-1.8549554d-08 /
      data fpppp(18,15, 9,1),fpppp(18,15, 9,2),fpppp(18,15, 9,3)/
     x-7.1682444d-05,-6.1575034d-05,-1.1722750d-08 /
      data fpppp(18,15,10,1),fpppp(18,15,10,2),fpppp(18,15,10,3)/
     x 1.9389589d-05,-3.1868354d-05,-2.2377020d-09 /
      data fpppp(18,15,11,1),fpppp(18,15,11,2),fpppp(18,15,11,3)/
     x 7.2997203d-06,-1.4677860d-05, 3.9666574d-09 /
      data fpppp(18,15,12,1),fpppp(18,15,12,2),fpppp(18,15,12,3)/
     x 2.0846494d-06,-5.5592000d-06, 3.9922014d-09 /
      data fpppp(18,15,13,1),fpppp(18,15,13,2),fpppp(18,15,13,3)/
     x 7.6940760d-07,-3.8937648d-07, 3.4871851d-09 /
      data fpppp(18,15,14,1),fpppp(18,15,14,2),fpppp(18,15,14,3)/
     x 2.4646310d-07, 1.3826105d-06, 3.3877361d-09 /
      data fpppp(18,15,15,1),fpppp(18,15,15,2),fpppp(18,15,15,3)/
     x-8.0299394d-07, 1.5482920d-06, 2.4814809d-09 /
      data fpppp(18,15,16,1),fpppp(18,15,16,2),fpppp(18,15,16,3)/
     x-1.0241221d-06, 1.3681789d-06, 2.1139364d-09 /
      data fpppp(18,15,17,1),fpppp(18,15,17,2),fpppp(18,15,17,3)/
     x-1.7075621d-06, 8.9041387d-07, 1.4362226d-09 /
      data fpppp(18,15,18,1),fpppp(18,15,18,2),fpppp(18,15,18,3)/
     x-3.0860153d-06,-1.1485256d-06, 1.1884672d-09 /
      data fpppp(18,15,19,1),fpppp(18,15,19,2),fpppp(18,15,19,3)/
     x-3.0668676d-06,-9.1781875d-07,-8.5348791d-10 /
      data fpppp(18,15,20,1),fpppp(18,15,20,2),fpppp(18,15,20,3)/
     x-2.9925351d-06,-2.3834413d-06,-2.7871345d-10 /
      data fpppp(18,15,21,1),fpppp(18,15,21,2),fpppp(18,15,21,3)/
     x-2.9925351d-06,-2.3400237d-06,-3.8837405d-10 /
      data fpppp(18,15,22,1),fpppp(18,15,22,2),fpppp(18,15,22,3)/
     x-3.0668676d-06,-1.0914891d-06,-4.1484554d-10 /
      data fpppp(18,15,23,1),fpppp(18,15,23,2),fpppp(18,15,23,3)/
     x-3.0860153d-06,-4.9726166d-07,-4.5644172d-10 /
      data fpppp(18,16, 1,1),fpppp(18,16, 1,2),fpppp(18,16, 1,3)/
     x 5.8110196d-05,-2.3517434d-03, 7.8481480d-07 /
      data fpppp(18,16, 2,1),fpppp(18,16, 2,2),fpppp(18,16, 2,3)/
     x-3.9327795d-03,-1.3289721d-03, 4.2848530d-07 /
      data fpppp(18,16, 3,1),fpppp(18,16, 3,2),fpppp(18,16, 3,3)/
     x-4.8518446d-03, 7.3133929d-04,-3.0677903d-07 /
      data fpppp(18,16, 4,1),fpppp(18,16, 4,2),fpppp(18,16, 4,3)/
     x-4.8518446d-03, 9.6118672d-04,-3.5630211d-07 /
      data fpppp(18,16, 5,1),fpppp(18,16, 5,2),fpppp(18,16, 5,3)/
     x-3.9327795d-03,-2.2483618d-03, 6.2657762d-07 /
      data fpppp(18,16, 6,1),fpppp(18,16, 6,2),fpppp(18,16, 6,3)/
     x 5.8110196d-05, 1.0959681d-03, 4.1968579d-08 /
      data fpppp(18,16, 7,1),fpppp(18,16, 7,2),fpppp(18,16, 7,3)/
     x-9.2757258d-05,-1.3112576d-04, 8.2765373d-10 /
      data fpppp(18,16, 8,1),fpppp(18,16, 8,2),fpppp(18,16, 8,3)/
     x 1.7356736d-05,-1.1056906d-04,-5.2418410d-08 /
      data fpppp(18,16, 9,1),fpppp(18,16, 9,2),fpppp(18,16, 9,3)/
     x 2.1262036d-04, 1.5344837d-04,-4.8232099d-08 /
      data fpppp(18,16,10,1),fpppp(18,16,10,2),fpppp(18,16,10,3)/
     x 1.5400824d-05,-1.3568256d-04,-3.2745622d-08 /
      data fpppp(18,16,11,1),fpppp(18,16,11,2),fpppp(18,16,11,3)/
     x 9.1916275d-06, 2.3343278d-05,-1.6251400d-08 /
      data fpppp(18,16,12,1),fpppp(18,16,12,2),fpppp(18,16,12,3)/
     x 4.6704491d-06,-1.2469463d-05,-5.8105246d-09 /
      data fpppp(18,16,13,1),fpppp(18,16,13,2),fpppp(18,16,13,3)/
     x 2.1645197d-06, 1.1695163d-06,-7.7690228d-10 /
      data fpppp(18,16,14,1),fpppp(18,16,14,2),fpppp(18,16,14,3)/
     x 1.2108407d-06,-3.6971260d-07, 1.3263231d-09 /
      data fpppp(18,16,15,1),fpppp(18,16,15,2),fpppp(18,16,15,3)/
     x 1.8991729d-06, 1.2089776d-06, 2.7770751d-09 /
      data fpppp(18,16,16,1),fpppp(18,16,16,2),fpppp(18,16,16,3)/
     x 1.9641719d-06, 8.0005990d-07, 2.5707631d-09 /
      data fpppp(18,16,17,1),fpppp(18,16,17,2),fpppp(18,16,17,3)/
     x 2.1314319d-06, 2.7161143d-08, 1.8379171d-09 /
      data fpppp(18,16,18,1),fpppp(18,16,18,2),fpppp(18,16,18,3)/
     x 2.9951336d-06, 2.5151211d-07,-2.4108751d-10 /
      data fpppp(18,16,19,1),fpppp(18,16,19,2),fpppp(18,16,19,3)/
     x 3.0414981d-06,-1.0936225d-06,-1.5326566d-09 /
      data fpppp(18,16,20,1),fpppp(18,16,20,2),fpppp(18,16,20,3)/
     x 3.4218987d-06,-1.1254259d-06,-1.2729341d-09 /
      data fpppp(18,16,21,1),fpppp(18,16,21,2),fpppp(18,16,21,3)/
     x 3.4218987d-06,-1.1885727d-06,-1.3399961d-09 /
      data fpppp(18,16,22,1),fpppp(18,16,22,2),fpppp(18,16,22,3)/
     x 3.0414981d-06,-8.4103523d-07,-1.2644086d-09 /
      data fpppp(18,16,23,1),fpppp(18,16,23,2),fpppp(18,16,23,3)/
     x 2.9951336d-06,-6.9569021d-07,-1.2470176d-09 /
      data fpppp(18,17, 1,1),fpppp(18,17, 1,2),fpppp(18,17, 1,3)/
     x-1.4047719d-03,-8.1313819d-05, 1.2525104d-07 /
      data fpppp(18,17, 2,1),fpppp(18,17, 2,2),fpppp(18,17, 2,3)/
     x 1.1546565d-03, 5.0145569d-07, 3.5885835d-08 /
      data fpppp(18,17, 3,1),fpppp(18,17, 3,2),fpppp(18,17, 3,3)/
     x 1.0267389d-03, 2.2048582d-04,-1.5713587d-07 /
      data fpppp(18,17, 4,1),fpppp(18,17, 4,2),fpppp(18,17, 4,3)/
     x 1.0267389d-03, 1.4232046d-04,-1.5446740d-07 /
      data fpppp(18,17, 5,1),fpppp(18,17, 5,2),fpppp(18,17, 5,3)/
     x 1.1546565d-03, 3.1316289d-04, 2.5211972d-08 /
      data fpppp(18,17, 6,1),fpppp(18,17, 6,2),fpppp(18,17, 6,3)/
     x-1.4047719d-03,-1.2537942d-03, 1.6527802d-07 /
      data fpppp(18,17, 7,1),fpppp(18,17, 7,2),fpppp(18,17, 7,3)/
     x-2.1332417d-04, 8.9188722d-04, 8.9266814d-08 /
      data fpppp(18,17, 8,1),fpppp(18,17, 8,2),fpppp(18,17, 8,3)/
     x-1.2685632d-04,-2.4300350d-04, 2.8032203d-08 /
      data fpppp(18,17, 9,1),fpppp(18,17, 9,2),fpppp(18,17, 9,3)/
     x-1.6406752d-04, 7.1330490d-05,-7.3776787d-09 /
      data fpppp(18,17,10,1),fpppp(18,17,10,2),fpppp(18,17,10,3)/
     x-1.2094424d-05,-2.0488853d-05,-1.9433527d-08 /
      data fpppp(18,17,11,1),fpppp(18,17,11,2),fpppp(18,17,11,3)/
     x 3.3532058d-08, 3.5083506d-06,-1.8477371d-08 /
      data fpppp(18,17,12,1),fpppp(18,17,12,2),fpppp(18,17,12,3)/
     x 3.4562560d-06,-2.0417441d-06,-1.2951135d-08 /
      data fpppp(18,17,13,1),fpppp(18,17,13,2),fpppp(18,17,13,3)/
     x 3.2791996d-06,-4.0640754d-07,-7.6991337d-09 /
      data fpppp(18,17,14,1),fpppp(18,17,14,2),fpppp(18,17,14,3)/
     x 3.2656107d-06, 2.4401488d-07,-3.3737654d-09 /
      data fpppp(18,17,15,1),fpppp(18,17,15,2),fpppp(18,17,15,3)/
     x 2.8282589d-06, 1.5804707d-07,-1.2672762d-09 /
      data fpppp(18,17,16,1),fpppp(18,17,16,2),fpppp(18,17,16,3)/
     x 3.7401080d-06, 3.9655149d-07,-4.6272268d-11 /
      data fpppp(18,17,17,1),fpppp(18,17,17,2),fpppp(18,17,17,3)/
     x 5.3337528d-06,-1.5438949d-07,-3.1326207d-10 /
      data fpppp(18,17,18,1),fpppp(18,17,18,2),fpppp(18,17,18,3)/
     x 6.8369796d-06, 7.6046602d-07,-3.9334895d-10 /
      data fpppp(18,17,19,1),fpppp(18,17,19,2),fpppp(18,17,19,3)/
     x 7.8783394d-06,-7.2040754d-07,-1.1735873d-09 /
      data fpppp(18,17,20,1),fpppp(18,17,20,2),fpppp(18,17,20,3)/
     x 8.4692335d-06,-2.3153834d-07,-1.7895122d-09 /
      data fpppp(18,17,21,1),fpppp(18,17,21,2),fpppp(18,17,21,3)/
     x 8.4692335d-06,-3.1266235d-07,-1.8129049d-09 /
      data fpppp(18,17,22,1),fpppp(18,17,22,2),fpppp(18,17,22,3)/
     x 7.8783394d-06,-3.9591149d-07,-1.0800164d-09 /
      data fpppp(18,17,23,1),fpppp(18,17,23,2),fpppp(18,17,23,3)/
     x 6.8369796d-06,-4.5639416d-07,-7.4423977d-10 /
      data fpppp(18,18, 1,1),fpppp(18,18, 1,2),fpppp(18,18, 1,3)/
     x 4.4958845d-04,-1.3386183d-06, 4.6260109d-08 /
      data fpppp(18,18, 2,1),fpppp(18,18, 2,2),fpppp(18,18, 2,3)/
     x-3.2028408d-04,-1.4514764d-06, 1.3323237d-08 /
      data fpppp(18,18, 3,1),fpppp(18,18, 3,2),fpppp(18,18, 3,3)/
     x-6.4004477d-04,-1.6551372d-06,-5.5804060d-08 /
      data fpppp(18,18, 4,1),fpppp(18,18, 4,2),fpppp(18,18, 4,3)/
     x-6.4004477d-04,-1.7219485d-06,-5.8344558d-08 /
      data fpppp(18,18, 5,1),fpppp(18,18, 5,2),fpppp(18,18, 5,3)/
     x-3.2028408d-04,-1.1842313d-06, 2.3485226d-08 /
      data fpppp(18,18, 6,1),fpppp(18,18, 6,2),fpppp(18,18, 6,3)/
     x 4.4958845d-04,-2.3407873d-06, 8.1526486d-09 /
      data fpppp(18,18, 7,1),fpppp(18,18, 7,2),fpppp(18,18, 7,3)/
     x-2.6417616d-05, 1.7786718d-06, 2.3541071d-08 /
      data fpppp(18,18, 8,1),fpppp(18,18, 8,2),fpppp(18,18, 8,3)/
     x-1.8464656d-05, 8.5322224d-07, 2.1712359d-08 /
      data fpppp(18,18, 9,1),fpppp(18,18, 9,2),fpppp(18,18, 9,3)/
     x 2.5312436d-06, 6.4585958d-07, 1.5735793d-08 /
      data fpppp(18,18,10,1),fpppp(18,18,10,2),fpppp(18,18,10,3)/
     x-1.2659820d-05, 7.4778730d-07, 9.2450526d-09 /
      data fpppp(18,18,11,1),fpppp(18,18,11,2),fpppp(18,18,11,3)/
     x-7.0195505d-06, 5.2955575d-07, 4.5066135d-09 /
      data fpppp(18,18,12,1),fpppp(18,18,12,2),fpppp(18,18,12,3)/
     x-2.9793915d-06, 1.8549237d-07, 1.4268206d-09 /
      data fpppp(18,18,13,1),fpppp(18,18,13,2),fpppp(18,18,13,3)/
     x 6.2994800d-09, 5.2512554d-07,-1.9311456d-11 /
      data fpppp(18,18,14,1),fpppp(18,18,14,2),fpppp(18,18,14,3)/
     x 1.6808784d-06,-7.6594761d-08,-1.1120218d-09 /
      data fpppp(18,18,15,1),fpppp(18,18,15,2),fpppp(18,18,15,3)/
     x 3.4116603d-06, 3.4017106d-07,-1.5521810d-09 /
      data fpppp(18,18,16,1),fpppp(18,18,16,2),fpppp(18,18,16,3)/
     x 4.6522148d-06, 2.7840438d-07,-2.1680705d-09 /
      data fpppp(18,18,17,1),fpppp(18,18,17,2),fpppp(18,18,17,3)/
     x 5.6443854d-06,-1.2937906d-07,-2.6510720d-09 /
      data fpppp(18,18,18,1),fpppp(18,18,18,2),fpppp(18,18,18,3)/
     x 6.6732629d-06, 5.2929045d-07,-3.4583074d-09 /
      data fpppp(18,18,19,1),fpppp(18,18,19,2),fpppp(18,18,19,3)/
     x 7.5385456d-06,-4.2163580d-07,-4.0956285d-09 /
      data fpppp(18,18,20,1),fpppp(18,18,20,2),fpppp(18,18,20,3)/
     x 8.3843580d-06, 2.1295475d-07,-4.0456899d-09 /
      data fpppp(18,18,21,1),fpppp(18,18,21,2),fpppp(18,18,21,3)/
     x 8.3843580d-06, 1.5375846d-07,-4.0770488d-09 /
      data fpppp(18,18,22,1),fpppp(18,18,22,2),fpppp(18,18,22,3)/
     x 7.5385456d-06,-1.8485064d-07,-3.9701932d-09 /
      data fpppp(18,18,23,1),fpppp(18,18,23,2),fpppp(18,18,23,3)/
     x 6.6732629d-06,-3.5865389d-07,-3.9286897d-09 /
      data fpppp(18,19, 1,1),fpppp(18,19, 1,2),fpppp(18,19, 1,3)/
     x 1.3561653d-03,-2.1392359d-18,-1.9860877d-07 /
      data fpppp(18,19, 2,1),fpppp(18,19, 2,2),fpppp(18,19, 2,3)/
     x 7.9740076d-05,-6.6461143d-19,-1.1496418d-07 /
      data fpppp(18,19, 3,1),fpppp(18,19, 3,2),fpppp(18,19, 3,3)/
     x-1.5100925d-04, 1.6333791d-19, 5.9330991d-08 /
      data fpppp(18,19, 4,1),fpppp(18,19, 4,2),fpppp(18,19, 4,3)/
     x-1.5100925d-04, 8.3958411d-20, 6.7981676d-08 /
      data fpppp(18,19, 5,1),fpppp(18,19, 5,2),fpppp(18,19, 5,3)/
     x 7.9740076d-05, 2.0507747d-19,-1.4956692d-07 /
      data fpppp(18,19, 6,1),fpppp(18,19, 6,2),fpppp(18,19, 6,3)/
     x 1.3561653d-03, 1.2170289d-19,-6.8848492d-08 /
      data fpppp(18,19, 7,1),fpppp(18,19, 7,2),fpppp(18,19, 7,3)/
     x 7.2639375d-05, 3.1079241d-19, 1.8624429d-09 /
      data fpppp(18,19, 8,1),fpppp(18,19, 8,2),fpppp(18,19, 8,3)/
     x 1.7754231d-05, 3.9494028d-19, 4.0184075d-08 /
      data fpppp(18,19, 9,1),fpppp(18,19, 9,2),fpppp(18,19, 9,3)/
     x 1.3905252d-05, 6.1126153d-19, 4.3918106d-08 /
      data fpppp(18,19,10,1),fpppp(18,19,10,2),fpppp(18,19,10,3)/
     x-2.0919460d-05, 2.3201800d-19, 3.3533208d-08 /
      data fpppp(18,19,11,1),fpppp(18,19,11,2),fpppp(18,19,11,3)/
     x-1.4674065d-05, 7.2238090d-19, 2.0287753d-08 /
      data fpppp(18,19,12,1),fpppp(18,19,12,2),fpppp(18,19,12,3)/
     x-7.9231948d-06, 1.0627003d-18, 9.6566147d-09 /
      data fpppp(18,19,13,1),fpppp(18,19,13,2),fpppp(18,19,13,3)/
     x-2.0130064d-06, 6.0557091d-19, 3.4884955d-09 /
      data fpppp(18,19,14,1),fpppp(18,19,14,2),fpppp(18,19,14,3)/
     x 1.1360039d-06, 3.6126451d-19,-8.3937306d-10 /
      data fpppp(18,19,15,1),fpppp(18,19,15,2),fpppp(18,19,15,3)/
     x 4.0938288d-06, 7.9597884d-19,-2.9112134d-09 /
      data fpppp(18,19,16,1),fpppp(18,19,16,2),fpppp(18,19,16,3)/
     x 5.8111299d-06,-4.8654477d-19,-4.4313651d-09 /
      data fpppp(18,19,17,1),fpppp(18,19,17,2),fpppp(18,19,17,3)/
     x 6.7812147d-06, 8.1048413d-21,-4.9355588d-09 /
      data fpppp(18,19,18,1),fpppp(18,19,18,2),fpppp(18,19,18,3)/
     x 7.6539927d-06,-2.0544357d-19,-5.6910666d-09 /
      data fpppp(18,19,19,1),fpppp(18,19,19,2),fpppp(18,19,19,3)/
     x 8.6777904d-06,-2.2012552d-19,-6.0802096d-09 /
      data fpppp(18,19,20,1),fpppp(18,19,20,2),fpppp(18,19,20,3)/
     x 9.7658282d-06, 1.1645840d-19,-5.8048392d-09 /
      data fpppp(18,19,21,1),fpppp(18,19,21,2),fpppp(18,19,21,3)/
     x 9.7658282d-06, 3.6468533d-19,-5.8294112d-09 /
      data fpppp(18,19,22,1),fpppp(18,19,22,2),fpppp(18,19,22,3)/
     x 8.6777904d-06, 6.4089827d-19,-5.9819218d-09 /
      data fpppp(18,19,23,1),fpppp(18,19,23,2),fpppp(18,19,23,3)/
     x 7.6539927d-06, 2.4181643d-18,-6.0596460d-09 /
      data fpppp(19, 1, 1,1),fpppp(19, 1, 1,2),fpppp(19, 1, 1,3)/
     x 3.9113878d-02,-1.1497730d-17, 2.3996506d-06 /
      data fpppp(19, 1, 2,1),fpppp(19, 1, 2,2),fpppp(19, 1, 2,3)/
     x 4.3090010d-02,-1.2809259d-17, 1.0638354d-06 /
      data fpppp(19, 1, 3,1),fpppp(19, 1, 3,2),fpppp(19, 1, 3,3)/
     x 4.3421403d-02,-6.8202856d-18,-1.7034539d-06 /
      data fpppp(19, 1, 4,1),fpppp(19, 1, 4,2),fpppp(19, 1, 4,3)/
     x 4.3421403d-02, 7.2138450d-18,-1.8700046d-06 /
      data fpppp(19, 1, 5,1),fpppp(19, 1, 5,2),fpppp(19, 1, 5,3)/
     x 4.3090010d-02, 2.6264938d-18, 1.7300383d-06 /
      data fpppp(19, 1, 6,1),fpppp(19, 1, 6,2),fpppp(19, 1, 6,3)/
     x 3.9113878d-02, 4.2177916d-18,-9.8610527d-08 /
      data fpppp(19, 1, 7,1),fpppp(19, 1, 7,2),fpppp(19, 1, 7,3)/
     x 3.8937309d-02,-7.8610690d-18, 5.4329384d-07 /
      data fpppp(19, 1, 8,1),fpppp(19, 1, 8,2),fpppp(19, 1, 8,3)/
     x 3.6650884d-02,-2.7681305d-18, 2.2075504d-07 /
      data fpppp(19, 1, 9,1),fpppp(19, 1, 9,2),fpppp(19, 1, 9,3)/
     x 3.2856828d-02, 1.3046803d-18, 1.5951986d-07 /
      data fpppp(19, 1,10,1),fpppp(19, 1,10,2),fpppp(19, 1,10,3)/
     x 3.2303594d-02, 9.6856331d-18, 8.9194634d-08 /
      data fpppp(19, 1,11,1),fpppp(19, 1,11,2),fpppp(19, 1,11,3)/
     x 3.0926159d-02,-1.0786486d-17, 6.0554130d-08 /
      data fpppp(19, 1,12,1),fpppp(19, 1,12,2),fpppp(19, 1,12,3)/
     x 3.2712241d-02, 8.2576065d-18, 4.9727462d-08 /
      data fpppp(19, 1,13,1),fpppp(19, 1,13,2),fpppp(19, 1,13,3)/
     x 3.3872196d-02,-1.0261549d-17, 6.0940812d-08 /
      data fpppp(19, 1,14,1),fpppp(19, 1,14,2),fpppp(19, 1,14,3)/
     x 3.2259213d-02, 1.0340834d-17, 1.1059871d-07 /
      data fpppp(19, 1,15,1),fpppp(19, 1,15,2),fpppp(19, 1,15,3)/
     x 3.2786276d-02,-1.6764506d-18, 1.1594524d-07 /
      data fpppp(19, 1,16,1),fpppp(19, 1,16,2),fpppp(19, 1,16,3)/
     x 3.6597091d-02,-6.8311335d-18, 4.2795218d-07 /
      data fpppp(19, 1,17,1),fpppp(19, 1,17,2),fpppp(19, 1,17,3)/
     x 3.8942740d-02,-6.3879511d-18,-2.0860762d-07 /
      data fpppp(19, 1,18,1),fpppp(19, 1,18,2),fpppp(19, 1,18,3)/
     x 3.9415641d-02, 1.2704232d-17, 2.6515148d-06 /
      data fpppp(19, 1,19,1),fpppp(19, 1,19,2),fpppp(19, 1,19,3)/
     x 3.7822981d-02, 2.9179704d-18,-2.1754988d-06 /
      data fpppp(19, 1,20,1),fpppp(19, 1,20,2),fpppp(19, 1,20,3)/
     x 4.2058552d-02, 7.4087802d-18,-5.9987797d-07 /
      data fpppp(19, 1,21,1),fpppp(19, 1,21,2),fpppp(19, 1,21,3)/
     x 4.2058552d-02,-7.7868901d-18,-8.6391135d-07 /
      data fpppp(19, 1,22,1),fpppp(19, 1,22,2),fpppp(19, 1,22,3)/
     x 3.7822981d-02, 1.4837065d-17,-1.1193652d-06 /
      data fpppp(19, 1,23,1),fpppp(19, 1,23,2),fpppp(19, 1,23,3)/
     x 3.9415641d-02, 1.7187967d-17,-1.3089860d-06 /
      data fpppp(19, 2, 1,1),fpppp(19, 2, 1,2),fpppp(19, 2, 1,3)/
     x 2.1175567d-02, 4.2580979d-03, 1.1007128d-06 /
      data fpppp(19, 2, 2,1),fpppp(19, 2, 2,2),fpppp(19, 2, 2,3)/
     x 2.3016912d-02, 2.3436347d-03, 5.3628654d-07 /
      data fpppp(19, 2, 3,1),fpppp(19, 2, 3,2),fpppp(19, 2, 3,3)/
     x 2.3083588d-02,-1.5732134d-03,-6.2747518d-07 /
      data fpppp(19, 2, 4,1),fpppp(19, 2, 4,2),fpppp(19, 2, 4,3)/
     x 2.3083588d-02,-1.8979666d-03,-7.0749047d-07 /
      data fpppp(19, 2, 5,1),fpppp(19, 2, 5,2),fpppp(19, 2, 5,3)/
     x 2.3016912d-02, 3.6426474d-03, 8.5634768d-07 /
      data fpppp(19, 2, 6,1),fpppp(19, 2, 6,2),fpppp(19, 2, 6,3)/
     x 2.1175567d-02,-6.1319978d-04,-9.9516547d-08 /
      data fpppp(19, 2, 7,1),fpppp(19, 2, 7,2),fpppp(19, 2, 7,3)/
     x 2.1012132d-02,-1.5637196d-04, 2.1529838d-07 /
      data fpppp(19, 2, 8,1),fpppp(19, 2, 8,2),fpppp(19, 2, 8,3)/
     x 1.9915268d-02, 1.1574736d-03, 6.3283249d-08 /
      data fpppp(19, 2, 9,1),fpppp(19, 2, 9,2),fpppp(19, 2, 9,3)/
     x 1.8042190d-02,-1.5581986d-03, 3.1480879d-08 /
      data fpppp(19, 2,10,1),fpppp(19, 2,10,2),fpppp(19, 2,10,3)/
     x 1.7757689d-02, 9.4858966d-04,-7.2249757d-09 /
      data fpppp(19, 2,11,1),fpppp(19, 2,11,2),fpppp(19, 2,11,3)/
     x 1.7077577d-02,-1.3084272d-03,-2.3666025d-08 /
      data fpppp(19, 2,12,1),fpppp(19, 2,12,2),fpppp(19, 2,12,3)/
     x 1.7946369d-02, 2.7272272d-04,-2.9428155d-08 /
      data fpppp(19, 2,13,1),fpppp(19, 2,13,2),fpppp(19, 2,13,3)/
     x 1.8513862d-02, 9.3067599d-04,-2.3330932d-08 /
      data fpppp(19, 2,14,1),fpppp(19, 2,14,2),fpppp(19, 2,14,3)/
     x 1.7732805d-02,-6.1956856d-04, 3.7930466d-09 /
      data fpppp(19, 2,15,1),fpppp(19, 2,15,2),fpppp(19, 2,15,3)/
     x 1.8002306d-02,-1.2081176d-03, 9.8569681d-09 /
      data fpppp(19, 2,16,1),fpppp(19, 2,16,2),fpppp(19, 2,16,3)/
     x 1.9879612d-02, 1.2965783d-03, 1.6809541d-07 /
      data fpppp(19, 2,17,1),fpppp(19, 2,17,2),fpppp(19, 2,17,3)/
     x 2.0996539d-02,-1.1798326d-03,-1.6183126d-07 /
      data fpppp(19, 2,18,1),fpppp(19, 2,18,2),fpppp(19, 2,18,3)/
     x 2.1305430d-02, 3.0523268d-03, 1.2843966d-06 /
      data fpppp(19, 2,19,1),fpppp(19, 2,19,2),fpppp(19, 2,19,3)/
     x 2.0356897d-02,-1.7450969d-03,-1.1086408d-06 /
      data fpppp(19, 2,20,1),fpppp(19, 2,20,2),fpppp(19, 2,20,3)/
     x 2.2514331d-02,-5.6751450d-05,-6.5856781d-08 /
      data fpppp(19, 2,21,1),fpppp(19, 2,21,2),fpppp(19, 2,21,3)/
     x 2.2514331d-02,-3.2187731d-04,-2.0254997d-07 /
      data fpppp(19, 2,22,1),fpppp(19, 2,22,2),fpppp(19, 2,22,3)/
     x 2.0356897d-02,-6.8459345d-04,-5.6186803d-07 /
      data fpppp(19, 2,23,1),fpppp(19, 2,23,2),fpppp(19, 2,23,3)/
     x 2.1305430d-02,-9.2456121d-04,-7.6600130d-07 /
      data fpppp(19, 3, 1,1),fpppp(19, 3, 1,2),fpppp(19, 3, 1,3)/
     x-7.3622882d-03, 3.0392111d-03, 2.2737074d-06 /
      data fpppp(19, 3, 2,1),fpppp(19, 3, 2,2),fpppp(19, 3, 2,3)/
     x-1.1726791d-02, 1.5212796d-03, 1.2850306d-06 /
      data fpppp(19, 3, 3,1),fpppp(19, 3, 3,2),fpppp(19, 3, 3,3)/
     x-2.2020016d-02,-1.6776220d-03,-7.5686273d-07 /
      data fpppp(19, 3, 4,1),fpppp(19, 3, 4,2),fpppp(19, 3, 4,3)/
     x-2.2020016d-02,-1.7717874d-03,-8.9108753d-07 /
      data fpppp(19, 3, 5,1),fpppp(19, 3, 5,2),fpppp(19, 3, 5,3)/
     x-1.1726791d-02, 1.8979411d-03, 1.8219298d-06 /
      data fpppp(19, 3, 6,1),fpppp(19, 3, 6,2),fpppp(19, 3, 6,3)/
     x-7.3622882d-03, 1.6267305d-03, 2.6033547d-07 /
      data fpppp(19, 3, 7,1),fpppp(19, 3, 7,2),fpppp(19, 3, 7,3)/
     x-8.5725551d-03,-1.4014799d-03,-4.5681206d-08 /
      data fpppp(19, 3, 8,1),fpppp(19, 3, 8,2),fpppp(19, 3, 8,3)/
     x-7.0223977d-03, 7.3361740d-04,-1.5325149d-07 /
      data fpppp(19, 3, 9,1),fpppp(19, 3, 9,2),fpppp(19, 3, 9,3)/
     x-5.3819548d-03,-2.2454704d-04,-1.4867576d-07 /
      data fpppp(19, 3,10,1),fpppp(19, 3,10,2),fpppp(19, 3,10,3)/
     x-5.2168632d-03, 3.0887811d-05,-1.6624172d-07 /
      data fpppp(19, 3,11,1),fpppp(19, 3,11,2),fpppp(19, 3,11,3)/
     x-4.6327317d-03,-3.1141988d-05,-1.8610967d-07 /
      data fpppp(19, 3,12,1),fpppp(19, 3,12,2),fpppp(19, 3,12,3)/
     x-5.4815917d-03,-4.9697789d-06,-1.9510930d-07 /
      data fpppp(19, 3,13,1),fpppp(19, 3,13,2),fpppp(19, 3,13,3)/
     x-6.0071829d-03,-3.0757990d-05,-1.8721962d-07 /
      data fpppp(19, 3,14,1),fpppp(19, 3,14,2),fpppp(19, 3,14,3)/
     x-5.2110618d-03, 3.4297605d-05,-1.7334628d-07 /
      data fpppp(19, 3,15,1),fpppp(19, 3,15,2),fpppp(19, 3,15,3)/
     x-5.3702250d-03,-2.3087276d-04,-1.3534902d-07 /
      data fpppp(19, 3,16,1),fpppp(19, 3,16,2),fpppp(19, 3,16,3)/
     x-7.0294073d-03, 7.9322285d-04,-2.1233477d-07 /
      data fpppp(19, 3,17,1),fpppp(19, 3,17,2),fpppp(19, 3,17,3)/
     x-8.4921005d-03,-1.6554849d-03, 1.8227245d-07 /
      data fpppp(19, 3,18,1),fpppp(19, 3,18,2),fpppp(19, 3,18,3)/
     x-7.4168682d-03, 2.5209014d-03,-5.8029930d-07 /
      data fpppp(19, 3,19,1),fpppp(19, 3,19,2),fpppp(19, 3,19,3)/
     x-9.3686721d-03, 1.8342276d-05, 2.9418349d-06 /
      data fpppp(19, 3,20,1),fpppp(19, 3,20,2),fpppp(19, 3,20,3)/
     x-1.9953952d-02,-9.4527456d-04,-1.2115086d-06 /
      data fpppp(19, 3,21,1),fpppp(19, 3,21,2),fpppp(19, 3,21,3)/
     x-1.9953952d-02,-1.0427210d-03,-9.5231422d-07 /
      data fpppp(19, 3,22,1),fpppp(19, 3,22,2),fpppp(19, 3,22,3)/
     x-9.3686721d-03, 4.0812795d-04, 1.9050575d-06 /
      data fpppp(19, 3,23,1),fpppp(19, 3,23,2),fpppp(19, 3,23,3)/
     x-7.4168682d-03, 1.0592051d-03, 3.3076161d-06 /
      data fpppp(19, 4, 1,1),fpppp(19, 4, 1,2),fpppp(19, 4, 1,3)/
     x 1.1982648d-03,-4.3162276d-03,-5.2050615d-06 /
      data fpppp(19, 4, 2,1),fpppp(19, 4, 2,2),fpppp(19, 4, 2,3)/
     x 4.8766244d-03,-2.2982660d-03,-2.4332504d-06 /
      data fpppp(19, 4, 3,1),fpppp(19, 4, 3,2),fpppp(19, 4, 3,3)/
     x 1.9556642d-02, 1.8553820d-03, 3.3325317d-06 /
      data fpppp(19, 4, 4,1),fpppp(19, 4, 4,2),fpppp(19, 4, 4,3)/
     x 1.9556642d-02, 2.1538536d-03, 3.6367047d-06 /
      data fpppp(19, 4, 5,1),fpppp(19, 4, 5,2),fpppp(19, 4, 5,3)/
     x 4.8766244d-03,-3.4921523d-03,-3.6499427d-06 /
      data fpppp(19, 4, 6,1),fpppp(19, 4, 6,2),fpppp(19, 4, 6,3)/
     x 1.1982648d-03, 1.6084602d-04,-6.4246564d-07 /
      data fpppp(19, 4, 7,1),fpppp(19, 4, 7,2),fpppp(19, 4, 7,3)/
     x 2.6510405d-03, 3.3202301d-04,-5.4121633d-07 /
      data fpppp(19, 4, 8,1),fpppp(19, 4, 8,2),fpppp(19, 4, 8,3)/
     x 1.7471139d-03,-1.4729937d-04,-1.6306592d-07 /
      data fpppp(19, 4, 9,1),fpppp(19, 4, 9,2),fpppp(19, 4, 9,3)/
     x 1.3271736d-03, 2.7648817d-05,-1.4642058d-07 /
      data fpppp(19, 4,10,1),fpppp(19, 4,10,2),fpppp(19, 4,10,3)/
     x 1.3088452d-03,-1.5146626d-05,-1.0616849d-07 /
      data fpppp(19, 4,11,1),fpppp(19, 4,11,2),fpppp(19, 4,11,3)/
     x 1.1730031d-03, 3.9643672d-06,-7.4771099d-08 /
      data fpppp(19, 4,12,1),fpppp(19, 4,12,2),fpppp(19, 4,12,3)/
     x 1.4077580d-03, 1.9211612d-06,-5.7951094d-08 /
      data fpppp(19, 4,13,1),fpppp(19, 4,13,2),fpppp(19, 4,13,3)/
     x 1.5412585d-03, 2.1734266d-06,-7.2448996d-08 /
      data fpppp(19, 4,14,1),fpppp(19, 4,14,2),fpppp(19, 4,14,3)/
     x 1.3061809d-03,-4.1583489d-06,-1.0431778d-07 /
      data fpppp(19, 4,15,1),fpppp(19, 4,15,2),fpppp(19, 4,15,3)/
     x 1.3172082d-03,-3.1801132d-06,-1.4364299d-07 /
      data fpppp(19, 4,16,1),fpppp(19, 4,16,2),fpppp(19, 4,16,3)/
     x 1.7319638d-03,-8.1452410d-06,-1.7075804d-07 /
      data fpppp(19, 4,17,1),fpppp(19, 4,17,2),fpppp(19, 4,17,3)/
     x 2.4177939d-03, 1.0711789d-04,-5.1426957d-07 /
      data fpppp(19, 4,18,1),fpppp(19, 4,18,2),fpppp(19, 4,18,3)/
     x 1.0031389d-03, 5.7764948d-04,-7.0347349d-07 /
      data fpppp(19, 4,19,1),fpppp(19, 4,19,2),fpppp(19, 4,19,3)/
     x 3.8139591d-03,-3.9492610d-03,-3.4503514d-06 /
      data fpppp(19, 4,20,1),fpppp(19, 4,20,2),fpppp(19, 4,20,3)/
     x 1.7811983d-02, 2.2614647d-03, 3.5216951d-06 /
      data fpppp(19, 4,21,1),fpppp(19, 4,21,2),fpppp(19, 4,21,3)/
     x 1.7811983d-02, 1.9090003d-03, 3.2368612d-06 /
      data fpppp(19, 4,22,1),fpppp(19, 4,22,2),fpppp(19, 4,22,3)/
     x 3.8139591d-03,-2.5394036d-03,-2.3110160d-06 /
      data fpppp(19, 4,23,1),fpppp(19, 4,23,2),fpppp(19, 4,23,3)/
     x 1.0031389d-03,-4.7093159d-03,-4.9759811d-06 /
      data fpppp(19, 5, 1,1),fpppp(19, 5, 1,2),fpppp(19, 5, 1,3)/
     x-3.1551137d-04, 3.5553807d-04, 2.4323805d-06 /
      data fpppp(19, 5, 2,1),fpppp(19, 5, 2,2),fpppp(19, 5, 2,3)/
     x-2.0907729d-03, 1.6481297d-04, 1.2083775d-06 /
      data fpppp(19, 5, 3,1),fpppp(19, 5, 3,2),fpppp(19, 5, 3,3)/
     x-1.0407847d-02,-2.3322124d-04,-1.3317313d-06 /
      data fpppp(19, 5, 4,1),fpppp(19, 5, 4,2),fpppp(19, 5, 4,3)/
     x-1.0407847d-02,-2.5188047d-04,-1.4765523d-06 /
      data fpppp(19, 5, 5,1),fpppp(19, 5, 5,2),fpppp(19, 5, 5,3)/
     x-2.0907729d-03, 2.3944990d-04, 1.7876612d-06 /
      data fpppp(19, 5, 6,1),fpppp(19, 5, 6,2),fpppp(19, 5, 6,3)/
     x-3.1551137d-04, 7.5649570d-05, 2.6006677d-07 /
      data fpppp(19, 5, 7,1),fpppp(19, 5, 7,2),fpppp(19, 5, 7,3)/
     x-8.8653164d-04, 2.4567610d-05, 1.8916746d-07 /
      data fpppp(19, 5, 8,1),fpppp(19, 5, 8,2),fpppp(19, 5, 8,3)/
     x-5.3889000d-04, 7.2060238d-06,-2.7268293d-08 /
      data fpppp(19, 5, 9,1),fpppp(19, 5, 9,2),fpppp(19, 5, 9,3)/
     x-3.9007303d-04, 6.5205110d-06,-2.7008961d-08 /
      data fpppp(19, 5,10,1),fpppp(19, 5,10,2),fpppp(19, 5,10,3)/
     x-3.6184487d-04, 7.2007068d-06,-1.3552685d-08 /
      data fpppp(19, 5,11,1),fpppp(19, 5,11,2),fpppp(19, 5,11,3)/
     x-3.1383566d-04, 7.6335743d-06,-5.4526056d-12 /
      data fpppp(19, 5,12,1),fpppp(19, 5,12,2),fpppp(19, 5,12,3)/
     x-3.7364574d-04, 7.7568680d-06, 2.5401046d-09 /
      data fpppp(19, 5,13,1),fpppp(19, 5,13,2),fpppp(19, 5,13,3)/
     x-4.1490460d-04, 7.5647676d-06, 1.1094028d-09 /
      data fpppp(19, 5,14,1),fpppp(19, 5,14,2),fpppp(19, 5,14,3)/
     x-3.6549997d-04, 6.6650652d-06,-9.6242072d-09 /
      data fpppp(19, 5,15,1),fpppp(19, 5,15,2),fpppp(19, 5,15,3)/
     x-3.9233547d-04, 7.8299843d-06,-2.0406368d-08 /
      data fpppp(19, 5,16,1),fpppp(19, 5,16,2),fpppp(19, 5,16,3)/
     x-5.3683893d-04, 5.1638960d-06,-1.7202037d-08 /
      data fpppp(19, 5,17,1),fpppp(19, 5,17,2),fpppp(19, 5,17,3)/
     x-7.4899487d-04, 4.0828528d-05, 1.8112905d-07 /
      data fpppp(19, 5,18,1),fpppp(19, 5,18,2),fpppp(19, 5,18,3)/
     x-2.0846438d-04, 2.3960890d-05, 2.6634929d-07 /
      data fpppp(19, 5,19,1),fpppp(19, 5,19,2),fpppp(19, 5,19,3)/
     x-1.4883795d-03, 4.0819389d-04, 1.6682232d-06 /
      data fpppp(19, 5,20,1),fpppp(19, 5,20,2),fpppp(19, 5,20,3)/
     x-1.0006193d-02,-3.4415050d-04,-1.4130381d-06 /
      data fpppp(19, 5,21,1),fpppp(19, 5,21,2),fpppp(19, 5,21,3)/
     x-1.0006193d-02,-3.0924574d-04,-1.2782377d-06 /
      data fpppp(19, 5,22,1),fpppp(19, 5,22,2),fpppp(19, 5,22,3)/
     x-1.4883795d-03, 2.6857483d-04, 1.1290214d-06 /
      data fpppp(19, 5,23,1),fpppp(19, 5,23,2),fpppp(19, 5,23,3)/
     x-2.0846438d-04, 5.4753237d-04, 2.2883558d-06 /
      data fpppp(19, 6, 1,1),fpppp(19, 6, 1,2),fpppp(19, 6, 1,3)/
     x-3.5724098d-05, 4.8877475d-05,-7.7020074d-08 /
      data fpppp(19, 6, 2,1),fpppp(19, 6, 2,2),fpppp(19, 6, 2,3)/
     x 4.8093646d-04, 1.1780428d-05,-8.6210793d-08 /
      data fpppp(19, 6, 3,1),fpppp(19, 6, 3,2),fpppp(19, 6, 3,3)/
     x 2.9755974d-03,-6.6544414d-05,-1.1256223d-07 /
      data fpppp(19, 6, 4,1),fpppp(19, 6, 4,2),fpppp(19, 6, 4,3)/
     x 2.9755974d-03,-6.8589869d-05,-1.0091242d-07 /
      data fpppp(19, 6, 5,1),fpppp(19, 6, 5,2),fpppp(19, 6, 5,3)/
     x 4.8093646d-04, 1.9962249d-05,-1.3281002d-07 /
      data fpppp(19, 6, 6,1),fpppp(19, 6, 6,2),fpppp(19, 6, 6,3)/
     x-3.5724098d-05, 1.8195644d-05, 9.7727025d-08 /
      data fpppp(19, 6, 7,1),fpppp(19, 6, 7,2),fpppp(19, 6, 7,3)/
     x 1.5990852d-04, 1.5533047d-05, 4.3700612d-08 /
      data fpppp(19, 6, 8,1),fpppp(19, 6, 8,2),fpppp(19, 6, 8,3)/
     x 1.0903214d-04, 1.1721873d-05, 5.1114198d-08 /
      data fpppp(19, 6, 9,1),fpppp(19, 6, 9,2),fpppp(19, 6, 9,3)/
     x 9.4128767d-05, 1.1590246d-05, 4.7801900d-08 /
      data fpppp(19, 6,10,1),fpppp(19, 6,10,2),fpppp(19, 6,10,3)/
     x 9.5491298d-05, 1.0267935d-05, 3.4422215d-08 /
      data fpppp(19, 6,11,1),fpppp(19, 6,11,2),fpppp(19, 6,11,3)/
     x 8.2097782d-05, 9.0795332d-06, 1.5955486d-08 /
      data fpppp(19, 6,12,1),fpppp(19, 6,12,2),fpppp(19, 6,12,3)/
     x 9.5438522d-05, 7.8198996d-06, 7.6973818d-09 /
      data fpppp(19, 6,13,1),fpppp(19, 6,13,2),fpppp(19, 6,13,3)/
     x 1.0616758d-04, 8.6087478d-06, 1.5421982d-08 /
      data fpppp(19, 6,14,1),fpppp(19, 6,14,2),fpppp(19, 6,14,3)/
     x 9.1721516d-05, 9.5514305d-06, 3.2545513d-08 /
      data fpppp(19, 6,15,1),fpppp(19, 6,15,2),fpppp(19, 6,15,3)/
     x 9.2065683d-05, 1.0870174d-05, 4.3934247d-08 /
      data fpppp(19, 6,16,1),fpppp(19, 6,16,2),fpppp(19, 6,16,3)/
     x 1.1354659d-04, 1.2482959d-05, 4.3052144d-08 /
      data fpppp(19, 6,17,1),fpppp(19, 6,17,2),fpppp(19, 6,17,3)/
     x 1.4489833d-04, 1.6804661d-05, 3.3903771d-08 /
      data fpppp(19, 6,18,1),fpppp(19, 6,18,2),fpppp(19, 6,18,3)/
     x-1.9657968d-05, 2.1553093d-05, 7.1908802d-08 /
      data fpppp(19, 6,19,1),fpppp(19, 6,19,2),fpppp(19, 6,19,3)/
     x 3.8168360d-04, 2.7850595d-05,-1.0046168d-07 /
      data fpppp(19, 6,20,1),fpppp(19, 6,20,2),fpppp(19, 6,20,3)/
     x 3.0235753d-03,-7.3692358d-05,-9.8613773d-08 /
      data fpppp(19, 6,21,1),fpppp(19, 6,21,2),fpppp(19, 6,21,3)/
     x 3.0235753d-03,-7.1144057d-05,-1.0683685d-07 /
      data fpppp(19, 6,22,1),fpppp(19, 6,22,2),fpppp(19, 6,22,3)/
     x 3.8168360d-04, 1.7657390d-05,-6.7569367d-08 /
      data fpppp(19, 6,23,1),fpppp(19, 6,23,2),fpppp(19, 6,23,3)/
     x-1.9657968d-05, 5.9777612d-05,-5.1437362d-08 /
      data fpppp(19, 7, 1,1),fpppp(19, 7, 1,2),fpppp(19, 7, 1,3)/
     x-2.0850084d-05,-1.5646325d-06, 9.9140303d-08 /
      data fpppp(19, 7, 2,1),fpppp(19, 7, 2,2),fpppp(19, 7, 2,3)/
     x-1.2611572d-04,-7.4625064d-06, 7.4745475d-09 /
      data fpppp(19, 7, 3,1),fpppp(19, 7, 3,2),fpppp(19, 7, 3,3)/
     x-9.3043501d-04,-2.0109160d-05,-1.8617586d-07 /
      data fpppp(19, 7, 4,1),fpppp(19, 7, 4,2),fpppp(19, 7, 4,3)/
     x-9.3043501d-04,-2.0094543d-05,-1.9103423d-07 /
      data fpppp(19, 7, 5,1),fpppp(19, 7, 5,2),fpppp(19, 7, 5,3)/
     x-1.2611572d-04,-7.5209776d-06, 2.6908039d-08 /
      data fpppp(19, 7, 6,1),fpppp(19, 7, 6,2),fpppp(19, 7, 6,3)/
     x-2.0850084d-05,-1.3453656d-06, 2.6264711d-08 /
      data fpppp(19, 7, 7,1),fpppp(19, 7, 7,2),fpppp(19, 7, 7,3)/
     x-7.8926774d-05, 2.3909011d-06, 6.5622641d-08 /
      data fpppp(19, 7, 8,1),fpppp(19, 7, 8,2),fpppp(19, 7, 8,3)/
     x-5.9971319d-05, 4.4132234d-06, 5.8081745d-08 /
      data fpppp(19, 7, 9,1),fpppp(19, 7, 9,2),fpppp(19, 7, 9,3)/
     x-4.8118203d-05, 6.0305648d-06, 4.1927833d-08 /
      data fpppp(19, 7,10,1),fpppp(19, 7,10,2),fpppp(19, 7,10,3)/
     x-4.1089699d-05, 7.3275321d-06, 3.0367693d-08 /
      data fpppp(19, 7,11,1),fpppp(19, 7,11,2),fpppp(19, 7,11,3)/
     x-3.1262130d-05, 8.7413590d-06, 2.8961568d-08 /
      data fpppp(19, 7,12,1),fpppp(19, 7,12,2),fpppp(19, 7,12,3)/
     x-3.2111527d-05, 9.4678576d-06, 2.9654260d-08 /
      data fpppp(19, 7,13,1),fpppp(19, 7,13,2),fpppp(19, 7,13,3)/
     x-3.7333841d-05, 8.8287179d-06, 2.5929042d-08 /
      data fpppp(19, 7,14,1),fpppp(19, 7,14,2),fpppp(19, 7,14,3)/
     x-3.7999818d-05, 8.6682845d-06, 2.4592768d-08 /
      data fpppp(19, 7,15,1),fpppp(19, 7,15,2),fpppp(19, 7,15,3)/
     x-4.3492745d-05, 7.9062463d-06, 3.3580554d-08 /
      data fpppp(19, 7,16,1),fpppp(19, 7,16,2),fpppp(19, 7,16,3)/
     x-5.3246883d-05, 1.0205797d-05, 4.6518144d-08 /
      data fpppp(19, 7,17,1),fpppp(19, 7,17,2),fpppp(19, 7,17,3)/
     x-6.5997954d-05, 6.0036992d-06, 5.4445959d-08 /
      data fpppp(19, 7,18,1),fpppp(19, 7,18,2),fpppp(19, 7,18,3)/
     x-1.7142665d-05, 6.5105938d-06, 2.9890454d-08 /
      data fpppp(19, 7,19,1),fpppp(19, 7,19,2),fpppp(19, 7,19,3)/
     x-1.0119275d-04,-4.9363727d-06, 3.6253613d-08 /
      data fpppp(19, 7,20,1),fpppp(19, 7,20,2),fpppp(19, 7,20,3)/
     x-7.5707849d-04,-2.8358131d-05,-1.8386209d-07 /
      data fpppp(19, 7,21,1),fpppp(19, 7,21,2),fpppp(19, 7,21,3)/
     x-7.5707849d-04,-2.8382663d-05,-1.7868407d-07 /
      data fpppp(19, 7,22,1),fpppp(19, 7,22,2),fpppp(19, 7,22,3)/
     x-1.0119275d-04,-4.8382437d-06, 1.5541495d-08 /
      data fpppp(19, 7,23,1),fpppp(19, 7,23,2),fpppp(19, 7,23,3)/
     x-1.7142665d-05, 6.1426102d-06, 1.0756090d-07 /
      data fpppp(19, 8, 1,1),fpppp(19, 8, 1,2),fpppp(19, 8, 1,3)/
     x-8.7288581d-07,-2.4986413d-04,-9.0351604d-09 /
      data fpppp(19, 8, 2,1),fpppp(19, 8, 2,2),fpppp(19, 8, 2,3)/
     x 4.3791766d-05,-1.3790116d-04,-2.9829355d-08 /
      data fpppp(19, 8, 3,1),fpppp(19, 8, 3,2),fpppp(19, 8, 3,3)/
     x 3.2817504d-04, 9.0470796d-05,-7.5272484d-08 /
      data fpppp(19, 8, 4,1),fpppp(19, 8, 4,2),fpppp(19, 8, 4,3)/
     x 3.2817504d-04, 1.1068100d-04,-7.3725239d-08 /
      data fpppp(19, 8, 5,1),fpppp(19, 8, 5,2),fpppp(19, 8, 5,3)/
     x 4.3791766d-05,-2.1874196d-04,-3.6018334d-08 /
      data fpppp(19, 8, 6,1),fpppp(19, 8, 6,2),fpppp(19, 8, 6,3)/
     x-8.7288581d-07, 5.3288869d-05, 1.4173510d-08 /
      data fpppp(19, 8, 7,1),fpppp(19, 8, 7,2),fpppp(19, 8, 7,3)/
     x 4.8853805d-07,-1.8764537d-05, 2.6927512d-08 /
      data fpppp(19, 8, 8,1),fpppp(19, 8, 8,2),fpppp(19, 8, 8,3)/
     x-1.1650749d-05, 3.1013746d-06, 2.8684701d-08 /
      data fpppp(19, 8, 9,1),fpppp(19, 8, 9,2),fpppp(19, 8, 9,3)/
     x-1.6294237d-05,-4.4357979d-07, 2.6624566d-08 /
      data fpppp(19, 8,10,1),fpppp(19, 8,10,2),fpppp(19, 8,10,3)/
     x-1.5670747d-05, 4.2826158d-06, 2.5029941d-08 /
      data fpppp(19, 8,11,1),fpppp(19, 8,11,2),fpppp(19, 8,11,3)/
     x-1.5335143d-05, 5.8880269d-06, 2.2328737d-08 /
      data fpppp(19, 8,12,1),fpppp(19, 8,12,2),fpppp(19, 8,12,3)/
     x-1.3070924d-05, 7.2359674d-06, 1.9800672d-08 /
      data fpppp(19, 8,13,1),fpppp(19, 8,13,2),fpppp(19, 8,13,3)/
     x-9.8862978d-06, 7.9002892d-06, 2.0670984d-08 /
      data fpppp(19, 8,14,1),fpppp(19, 8,14,2),fpppp(19, 8,14,3)/
     x-9.0379739d-06, 6.9725124d-06, 2.2331782d-08 /
      data fpppp(19, 8,15,1),fpppp(19, 8,15,2),fpppp(19, 8,15,3)/
     x-6.2858420d-06, 6.7274600d-06, 2.0780937d-08 /
      data fpppp(19, 8,16,1),fpppp(19, 8,16,2),fpppp(19, 8,16,3)/
     x-3.1061999d-06, 6.1201024d-06, 1.8837313d-08 /
      data fpppp(19, 8,17,1),fpppp(19, 8,17,2),fpppp(19, 8,17,3)/
     x 4.3352670d-06, 2.7966388d-06, 1.2546865d-08 /
      data fpppp(19, 8,18,1),fpppp(19, 8,18,2),fpppp(19, 8,18,3)/
     x-1.0035834d-06, 6.3811840d-07,-5.7053760d-10 /
      data fpppp(19, 8,19,1),fpppp(19, 8,19,2),fpppp(19, 8,19,3)/
     x 3.6249760d-05,-5.1287730d-06,-3.9187573d-08 /
      data fpppp(19, 8,20,1),fpppp(19, 8,20,2),fpppp(19, 8,20,3)/
     x 2.2877927d-04,-1.4088529d-05,-4.7538736d-08 /
      data fpppp(19, 8,21,1),fpppp(19, 8,21,2),fpppp(19, 8,21,3)/
     x 2.2877927d-04,-1.4163798d-05,-4.9186829d-08 /
      data fpppp(19, 8,22,1),fpppp(19, 8,22,2),fpppp(19, 8,22,3)/
     x 3.6249760d-05,-4.8276961d-06,-3.2595201d-08 /
      data fpppp(19, 8,23,1),fpppp(19, 8,23,2),fpppp(19, 8,23,3)/
     x-1.0035834d-06,-4.9092012d-07,-2.5291933d-08 /
      data fpppp(19, 9, 1,1),fpppp(19, 9, 1,2),fpppp(19, 9, 1,3)/
     x-2.4300155d-05,-2.5235813d-04, 7.7626853d-08 /
      data fpppp(19, 9, 2,1),fpppp(19, 9, 2,2),fpppp(19, 9, 2,3)/
     x-7.3124427d-06,-1.3787499d-04, 2.3849844d-08 /
      data fpppp(19, 9, 3,1),fpppp(19, 9, 3,2),fpppp(19, 9, 3,3)/
     x 4.1204973d-04, 9.5581257d-05,-8.9788602d-08 /
      data fpppp(19, 9, 4,1),fpppp(19, 9, 4,2),fpppp(19, 9, 4,3)/
     x 4.1204973d-04, 1.1634461d-04,-9.2585107d-08 /
      data fpppp(19, 9, 5,1),fpppp(19, 9, 5,2),fpppp(19, 9, 5,3)/
     x-7.3124427d-06,-2.2092840d-04, 3.5035864d-08 /
      data fpppp(19, 9, 6,1),fpppp(19, 9, 6,2),fpppp(19, 9, 6,3)/
     x-2.4300155d-05, 5.9092151d-05, 3.5679277d-08 /
      data fpppp(19, 9, 7,1),fpppp(19, 9, 7,2),fpppp(19, 9, 7,3)/
     x-2.8239238d-05,-1.9820114d-05, 2.3204636d-08 /
      data fpppp(19, 9, 8,1),fpppp(19, 9, 8,2),fpppp(19, 9, 8,3)/
     x-2.4636215d-05, 7.9244004d-07, 1.3912134d-08 /
      data fpppp(19, 9, 9,1),fpppp(19, 9, 9,2),fpppp(19, 9, 9,3)/
     x-2.3862762d-05,-2.9779524d-06, 1.0785853d-08 /
      data fpppp(19, 9,10,1),fpppp(19, 9,10,2),fpppp(19, 9,10,3)/
     x-2.4709735d-05, 1.0985666d-06, 9.2920597d-09 /
      data fpppp(19, 9,11,1),fpppp(19, 9,11,2),fpppp(19, 9,11,3)/
     x-2.4309106d-05, 2.5465813d-06, 9.7534608d-09 /
      data fpppp(19, 9,12,1),fpppp(19, 9,12,2),fpppp(19, 9,12,3)/
     x-2.2691730d-05, 5.3499076d-06, 1.0363621d-08 /
      data fpppp(19, 9,13,1),fpppp(19, 9,13,2),fpppp(19, 9,13,3)/
     x-2.0792334d-05, 5.6673799d-06, 1.1154773d-08 /
      data fpppp(19, 9,14,1),fpppp(19, 9,14,2),fpppp(19, 9,14,3)/
     x-1.7737910d-05, 6.5149889d-06, 1.1028537d-08 /
      data fpppp(19, 9,15,1),fpppp(19, 9,15,2),fpppp(19, 9,15,3)/
     x-1.5074978d-05, 4.2969502d-06, 1.1454220d-08 /
      data fpppp(19, 9,16,1),fpppp(19, 9,16,2),fpppp(19, 9,16,3)/
     x-1.0670494d-05, 4.9934352d-06, 9.5100790d-09 /
      data fpppp(19, 9,17,1),fpppp(19, 9,17,2),fpppp(19, 9,17,3)/
     x-7.8578886d-06, 1.4636801d-06, 4.5381568d-09 /
      data fpppp(19, 9,18,1),fpppp(19, 9,18,2),fpppp(19, 9,18,3)/
     x 5.7107676d-07, 4.1166060d-07,-3.8320760d-09 /
      data fpppp(19, 9,19,1),fpppp(19, 9,19,2),fpppp(19, 9,19,3)/
     x-1.6090666d-06,-2.9250535d-06,-1.2139807d-08 /
      data fpppp(19, 9,20,1),fpppp(19, 9,20,2),fpppp(19, 9,20,3)/
     x-4.6783732d-05,-8.7749460d-06,-2.7853248d-08 /
      data fpppp(19, 9,21,1),fpppp(19, 9,21,2),fpppp(19, 9,21,3)/
     x-4.6783732d-05,-8.8037481d-06,-2.7899520d-08 /
      data fpppp(19, 9,22,1),fpppp(19, 9,22,2),fpppp(19, 9,22,3)/
     x-1.6090666d-06,-2.8098451d-06,-1.1954720d-08 /
      data fpppp(19, 9,23,1),fpppp(19, 9,23,2),fpppp(19, 9,23,3)/
     x 5.7107676d-07,-2.0370926d-08,-4.5261521d-09 /
      data fpppp(19,10, 1,1),fpppp(19,10, 1,2),fpppp(19,10, 1,3)/
     x-6.1656426d-05, 2.4700611d-04, 1.7226515d-07 /
      data fpppp(19,10, 2,1),fpppp(19,10, 2,2),fpppp(19,10, 2,3)/
     x-1.0098872d-04, 1.3189576d-04, 8.1985173d-08 /
      data fpppp(19,10, 3,1),fpppp(19,10, 3,2),fpppp(19,10, 3,3)/
     x-6.1363147d-04,-1.0423881d-04,-1.0645128d-07 /
      data fpppp(19,10, 4,1),fpppp(19,10, 4,2),fpppp(19,10, 4,3)/
     x-6.1363147d-04,-1.2266710d-04,-1.1523741d-07 /
      data fpppp(19,10, 5,1),fpppp(19,10, 5,2),fpppp(19,10, 5,3)/
     x-1.0098872d-04, 2.0560890d-04, 1.1712968d-07 /
      data fpppp(19,10, 6,1),fpppp(19,10, 6,2),fpppp(19,10, 6,3)/
     x-6.1656426d-05,-2.9418148d-05, 4.0473247d-08 /
      data fpppp(19,10, 7,1),fpppp(19,10, 7,2),fpppp(19,10, 7,3)/
     x-4.0878168d-05, 7.3214542d-06, 1.3983678d-08 /
      data fpppp(19,10, 8,1),fpppp(19,10, 8,2),fpppp(19,10, 8,3)/
     x-2.7793012d-05,-1.1016880d-05,-2.6560367d-09 /
      data fpppp(19,10, 9,1),fpppp(19,10, 9,2),fpppp(19,10, 9,3)/
     x-1.9840816d-05,-4.6633708d-06,-1.7265179d-09 /
      data fpppp(19,10,10,1),fpppp(19,10,10,2),fpppp(19,10,10,3)/
     x-1.6516803d-05,-1.8238235d-06, 8.3877585d-10 /
      data fpppp(19,10,11,1),fpppp(19,10,11,2),fpppp(19,10,11,3)/
     x-1.4480836d-05, 7.2402036d-07, 2.9481340d-09 /
      data fpppp(19,10,12,1),fpppp(19,10,12,2),fpppp(19,10,12,3)/
     x-1.2981740d-05, 3.3853815d-06, 5.1850309d-09 /
      data fpppp(19,10,13,1),fpppp(19,10,13,2),fpppp(19,10,13,3)/
     x-1.1427297d-05, 4.3332842d-06, 5.3384696d-09 /
      data fpppp(19,10,14,1),fpppp(19,10,14,2),fpppp(19,10,14,3)/
     x-9.3776456d-06, 5.3196971d-06, 5.4397057d-09 /
      data fpppp(19,10,15,1),fpppp(19,10,15,2),fpppp(19,10,15,3)/
     x-7.4949474d-06, 4.0895847d-06, 3.6310959d-09 /
      data fpppp(19,10,16,1),fpppp(19,10,16,2),fpppp(19,10,16,3)/
     x-5.8873776d-06, 2.8305496d-06, 1.4410861d-09 /
      data fpppp(19,10,17,1),fpppp(19,10,17,2),fpppp(19,10,17,3)/
     x-2.0452163d-06, 2.1813539d-06, 2.3673431d-10 /
      data fpppp(19,10,18,1),fpppp(19,10,18,2),fpppp(19,10,18,3)/
     x-3.0927139d-07, 5.9779650d-07,-2.3647778d-09 /
      data fpppp(19,10,19,1),fpppp(19,10,19,2),fpppp(19,10,19,3)/
     x 4.0592138d-06,-1.6340427d-06,-6.5749486d-09 /
      data fpppp(19,10,20,1),fpppp(19,10,20,2),fpppp(19,10,20,3)/
     x 1.8699664d-05,-6.6530800d-06,-8.8976581d-09 /
      data fpppp(19,10,21,1),fpppp(19,10,21,2),fpppp(19,10,21,3)/
     x 1.8699664d-05,-6.6478405d-06,-9.0460555d-09 /
      data fpppp(19,10,22,1),fpppp(19,10,22,2),fpppp(19,10,22,3)/
     x 4.0592138d-06,-1.6550006d-06,-5.9813588d-09 /
      data fpppp(19,10,23,1),fpppp(19,10,23,2),fpppp(19,10,23,3)/
     x-3.0927139d-07, 6.7638863d-07,-4.5907396d-09 /
      data fpppp(19,11, 1,1),fpppp(19,11, 1,2),fpppp(19,11, 1,3)/
     x-3.2647600d-05, 5.6087716d-04, 6.5891541d-08 /
      data fpppp(19,11, 2,1),fpppp(19,11, 2,2),fpppp(19,11, 2,3)/
     x 1.5859112d-05, 3.0396093d-04, 2.9321459d-08 /
      data fpppp(19,11, 3,1),fpppp(19,11, 3,2),fpppp(19,11, 3,3)/
     x 1.0606301d-03,-2.2234644d-04,-4.6833251d-08 /
      data fpppp(19,11, 4,1),fpppp(19,11, 4,2),fpppp(19,11, 4,3)/
     x 1.0606301d-03,-2.6474439d-04,-5.0700315d-08 /
      data fpppp(19,11, 5,1),fpppp(19,11, 5,2),fpppp(19,11, 5,3)/
     x 1.5859112d-05, 4.7355272d-04, 4.4789717d-08 /
      data fpppp(19,11, 6,1),fpppp(19,11, 6,2),fpppp(19,11, 6,3)/
     x-3.2647600d-05,-7.5092051d-05, 7.8855758d-09 /
      data fpppp(19,11, 7,1),fpppp(19,11, 7,2),fpppp(19,11, 7,3)/
     x-2.4544271d-05, 1.7153443d-05, 1.6244979d-08 /
      data fpppp(19,11, 8,1),fpppp(19,11, 8,2),fpppp(19,11, 8,3)/
     x-1.9804670d-05,-2.3018303d-05, 4.0768701d-09 /
      data fpppp(19,11, 9,1),fpppp(19,11, 9,2),fpppp(19,11, 9,3)/
     x-1.4798208d-05,-1.1365344d-05, 1.5646353d-10 /
      data fpppp(19,11,10,1),fpppp(19,11,10,2),fpppp(19,11,10,3)/
     x-1.0426458d-05,-5.2557587d-06, 1.2829995d-09 /
      data fpppp(19,11,11,1),fpppp(19,11,11,2),fpppp(19,11,11,3)/
     x-9.4521402d-06,-1.3458194d-06, 1.4971079d-09 /
      data fpppp(19,11,12,1),fpppp(19,11,12,2),fpppp(19,11,12,3)/
     x-8.8434833d-06, 1.6231159d-06, 1.3936751d-09 /
      data fpppp(19,11,13,1),fpppp(19,11,13,2),fpppp(19,11,13,3)/
     x-7.5354603d-06, 3.6402006d-06, 2.3785671d-09 /
      data fpppp(19,11,14,1),fpppp(19,11,14,2),fpppp(19,11,14,3)/
     x-6.8265064d-06, 3.8948882d-06, 1.4463468d-09 /
      data fpppp(19,11,15,1),fpppp(19,11,15,2),fpppp(19,11,15,3)/
     x-5.6716578d-06, 3.5458659d-06, 9.1935193d-10 /
      data fpppp(19,11,16,1),fpppp(19,11,16,2),fpppp(19,11,16,3)/
     x-4.6836959d-06, 2.7167469d-06,-1.3995143d-10 /
      data fpppp(19,11,17,1),fpppp(19,11,17,2),fpppp(19,11,17,3)/
     x-4.1583967d-06, 1.9228742d-06,-1.1209373d-09 /
      data fpppp(19,11,18,1),fpppp(19,11,18,2),fpppp(19,11,18,3)/
     x-2.6991334d-06, 7.6492167d-07,-9.3991170d-10 /
      data fpppp(19,11,19,1),fpppp(19,11,19,2),fpppp(19,11,19,3)/
     x-3.3131204d-06,-1.4430335d-06, 3.5198398d-09 /
      data fpppp(19,11,20,1),fpppp(19,11,20,2),fpppp(19,11,20,3)/
     x-7.4454640d-06,-5.5372141d-06,-5.8459758d-09 /
      data fpppp(19,11,21,1),fpppp(19,11,21,2),fpppp(19,11,21,3)/
     x-7.4454640d-06,-5.5513282d-06,-5.4268081d-09 /
      data fpppp(19,11,22,1),fpppp(19,11,22,2),fpppp(19,11,22,3)/
     x-3.3131204d-06,-1.3865770d-06, 1.8431691d-09 /
      data fpppp(19,11,23,1),fpppp(19,11,23,2),fpppp(19,11,23,3)/
     x-2.6991334d-06, 5.5320980d-07, 5.3476032d-09 /
      data fpppp(19,12, 1,1),fpppp(19,12, 1,2),fpppp(19,12, 1,3)/
     x 5.5386997d-05, 1.5994737d-03,-2.5195365d-07 /
      data fpppp(19,12, 2,1),fpppp(19,12, 2,2),fpppp(19,12, 2,3)/
     x 6.7962904d-05, 8.6384703d-04,-1.3547634d-07 /
      data fpppp(19,12, 3,1),fpppp(19,12, 3,2),fpppp(19,12, 3,3)/
     x-1.4573239d-03,-6.4257942d-04, 1.0564796d-07 /
      data fpppp(19,12, 4,1),fpppp(19,12, 4,2),fpppp(19,12, 4,3)/
     x-1.4573239d-03,-7.6493330d-04, 1.2047032d-07 /
      data fpppp(19,12, 5,1),fpppp(19,12, 5,2),fpppp(19,12, 5,3)/
     x 6.7962904d-05, 1.3532625d-03,-1.9476580d-07 /
      data fpppp(19,12, 6,1),fpppp(19,12, 6,2),fpppp(19,12, 6,3)/
     x 5.5386997d-05,-2.3583441d-04,-2.9618185d-08 /
      data fpppp(19,12, 7,1),fpppp(19,12, 7,2),fpppp(19,12, 7,3)/
     x 1.7235757d-05, 5.7804048d-05,-8.7580076d-10 /
      data fpppp(19,12, 8,1),fpppp(19,12, 8,2),fpppp(19,12, 8,3)/
     x 1.4363188d-06,-4.2021950d-05, 1.9680026d-08 /
      data fpppp(19,12, 9,1),fpppp(19,12, 9,2),fpppp(19,12, 9,3)/
     x-5.1560321d-06,-1.5735473d-05, 1.4326993d-08 /
      data fpppp(19,12,10,1),fpppp(19,12,10,2),fpppp(19,12,10,3)/
     x-6.2458457d-06,-1.2677337d-05, 8.2324393d-09 /
      data fpppp(19,12,11,1),fpppp(19,12,11,2),fpppp(19,12,11,3)/
     x-5.8094876d-06,-3.1405400d-06, 4.5442530d-09 /
      data fpppp(19,12,12,1),fpppp(19,12,12,2),fpppp(19,12,12,3)/
     x-5.5366348d-06, 5.8699765d-07, 2.1137817d-09 /
      data fpppp(19,12,13,1),fpppp(19,12,13,2),fpppp(19,12,13,3)/
     x-5.5788266d-06, 2.3051758d-06, 4.5239070d-10 /
      data fpppp(19,12,14,1),fpppp(19,12,14,2),fpppp(19,12,14,3)/
     x-4.9677862d-06, 3.0638610d-06, 8.7868747d-13 /
      data fpppp(19,12,15,1),fpppp(19,12,15,2),fpppp(19,12,15,3)/
     x-4.5538685d-06, 2.6884643d-06,-5.5751833d-10 /
      data fpppp(19,12,16,1),fpppp(19,12,16,2),fpppp(19,12,16,3)/
     x-3.9197180d-06, 2.5414519d-06,-2.3119303d-10 /
      data fpppp(19,12,17,1),fpppp(19,12,17,2),fpppp(19,12,17,3)/
     x-3.7273167d-06, 2.1662373d-06, 2.9568016d-10 /
      data fpppp(19,12,18,1),fpppp(19,12,18,2),fpppp(19,12,18,3)/
     x-4.4078789d-06,-2.5715527d-07, 3.9675705d-11 /
      data fpppp(19,12,19,1),fpppp(19,12,19,2),fpppp(19,12,19,3)/
     x-4.0956221d-06,-1.6647005d-06, 9.8591954d-10 /
      data fpppp(19,12,20,1),fpppp(19,12,20,2),fpppp(19,12,20,3)/
     x-2.7132377d-06,-4.3127747d-06,-2.7501059d-10 /
      data fpppp(19,12,21,1),fpppp(19,12,21,2),fpppp(19,12,21,3)/
     x-2.7132377d-06,-4.3209287d-06,-2.0216195d-10 /
      data fpppp(19,12,22,1),fpppp(19,12,22,2),fpppp(19,12,22,3)/
     x-4.0956221d-06,-1.6320846d-06, 6.9452501d-10 /
      data fpppp(19,12,23,1),fpppp(19,12,23,2),fpppp(19,12,23,3)/
     x-4.4078789d-06,-3.7946510d-07, 1.1324052d-09 /
      data fpppp(19,13, 1,1),fpppp(19,13, 1,2),fpppp(19,13, 1,3)/
     x 3.5660101d-05, 1.0467554d-03,-3.1178860d-07 /
      data fpppp(19,13, 2,1),fpppp(19,13, 2,2),fpppp(19,13, 2,3)/
     x-4.0291357d-06, 5.5991326d-04,-1.4373277d-07 /
      data fpppp(19,13, 3,1),fpppp(19,13, 3,2),fpppp(19,13, 3,3)/
     x 6.8641023d-04,-4.4127605d-04, 2.0921983d-07 /
      data fpppp(19,13, 4,1),fpppp(19,13, 4,2),fpppp(19,13, 4,3)/
     x 6.8641023d-04,-5.1485288d-04, 2.2176215d-07 /
      data fpppp(19,13, 5,1),fpppp(19,13, 5,2),fpppp(19,13, 5,3)/
     x-4.0291357d-06, 8.5422056d-04,-1.9390204d-07 /
      data fpppp(19,13, 6,1),fpppp(19,13, 6,2),fpppp(19,13, 6,3)/
     x 3.5660101d-05,-5.6896960d-05,-1.2365385d-07 /
      data fpppp(19,13, 7,1),fpppp(19,13, 7,2),fpppp(19,13, 7,3)/
     x 2.9228231d-05, 2.6674811d-05,-6.2442184d-08 /
      data fpppp(19,13, 8,1),fpppp(19,13, 8,2),fpppp(19,13, 8,3)/
     x 1.7872658d-05,-3.2466255d-05,-3.9432507d-10 /
      data fpppp(19,13, 9,1),fpppp(19,13, 9,2),fpppp(19,13, 9,3)/
     x 9.3214423d-06,-2.2663559d-05, 1.7945370d-08 /
      data fpppp(19,13,10,1),fpppp(19,13,10,2),fpppp(19,13,10,3)/
     x 8.1459439d-07,-1.7006621d-05, 1.5185369d-08 /
      data fpppp(19,13,11,1),fpppp(19,13,11,2),fpppp(19,13,11,3)/
     x-1.3364663d-06,-5.6834388d-06, 9.3635719d-09 /
      data fpppp(19,13,12,1),fpppp(19,13,12,2),fpppp(19,13,12,3)/
     x-2.4021916d-06,-4.8304790d-07, 4.9623056d-09 /
      data fpppp(19,13,13,1),fpppp(19,13,13,2),fpppp(19,13,13,3)/
     x-3.1625552d-06, 1.5985873d-06, 1.4897481d-09 /
      data fpppp(19,13,14,1),fpppp(19,13,14,2),fpppp(19,13,14,3)/
     x-3.6574160d-06, 2.0323785d-06,-9.2480982d-11 /
      data fpppp(19,13,15,1),fpppp(19,13,15,2),fpppp(19,13,15,3)/
     x-3.8095574d-06, 2.0045707d-06,-4.3667875d-10 /
      data fpppp(19,13,16,1),fpppp(19,13,16,2),fpppp(19,13,16,3)/
     x-4.4867610d-06, 2.0615626d-06,-1.4305634d-10 /
      data fpppp(19,13,17,1),fpppp(19,13,17,2),fpppp(19,13,17,3)/
     x-4.6891512d-06, 1.6996232d-06, 3.9673644d-10 /
      data fpppp(19,13,18,1),fpppp(19,13,18,2),fpppp(19,13,18,3)/
     x-4.7826639d-06,-5.8374185d-07, 8.7490954d-10 /
      data fpppp(19,13,19,1),fpppp(19,13,19,2),fpppp(19,13,19,3)/
     x-4.5780316d-06,-1.7621808d-06,-2.5368404d-09 /
      data fpppp(19,13,20,1),fpppp(19,13,20,2),fpppp(19,13,20,3)/
     x-4.1786253d-06,-3.3236448d-06, 3.3456073d-09 /
      data fpppp(19,13,21,1),fpppp(19,13,21,2),fpppp(19,13,21,3)/
     x-4.1786253d-06,-3.3449940d-06, 3.0533497d-09 /
      data fpppp(19,13,22,1),fpppp(19,13,22,2),fpppp(19,13,22,3)/
     x-4.5780316d-06,-1.6767842d-06,-1.3678103d-09 /
      data fpppp(19,13,23,1),fpppp(19,13,23,2),fpppp(19,13,23,3)/
     x-4.7826639d-06,-9.0397934d-07,-3.5089536d-09 /
      data fpppp(19,14, 1,1),fpppp(19,14, 1,2),fpppp(19,14, 1,3)/
     x 1.1385605d-04, 1.0354041d-03,-1.6318716d-07 /
      data fpppp(19,14, 2,1),fpppp(19,14, 2,2),fpppp(19,14, 2,3)/
     x 4.4069261d-04, 5.4387148d-04,-5.7572130d-08 /
      data fpppp(19,14, 3,1),fpppp(19,14, 3,2),fpppp(19,14, 3,3)/
     x 8.4725932d-04,-4.7052578d-04, 1.6684615d-07 /
      data fpppp(19,14, 4,1),fpppp(19,14, 4,2),fpppp(19,14, 4,3)/
     x 8.4725932d-04,-5.3857782d-04, 1.7017053d-07 /
      data fpppp(19,14, 5,1),fpppp(19,14, 5,2),fpppp(19,14, 5,3)/
     x 4.4069261d-04, 8.1607965d-04,-7.0869633d-08 /
      data fpppp(19,14, 6,1),fpppp(19,14, 6,2),fpppp(19,14, 6,3)/
     x 1.1385605d-04, 1.4623443d-05,-1.1332153d-07 /
      data fpppp(19,14, 7,1),fpppp(19,14, 7,2),fpppp(19,14, 7,3)/
     x 6.2823071d-05, 3.0056515d-05,-7.7571392d-08 /
      data fpppp(19,14, 8,1),fpppp(19,14, 8,2),fpppp(19,14, 8,3)/
     x 3.4836866d-05,-2.7833516d-05,-2.7883887d-08 /
      data fpppp(19,14, 9,1),fpppp(19,14, 9,2),fpppp(19,14, 9,3)/
     x 8.9752496d-06,-2.1861650d-05, 1.8721007d-09 /
      data fpppp(19,14,10,1),fpppp(19,14,10,2),fpppp(19,14,10,3)/
     x 7.2084903d-06,-1.7558065d-05, 1.0444949d-08 /
      data fpppp(19,14,11,1),fpppp(19,14,11,2),fpppp(19,14,11,3)/
     x 2.1939991d-06,-7.3661033d-06, 8.8254314d-09 /
      data fpppp(19,14,12,1),fpppp(19,14,12,2),fpppp(19,14,12,3)/
     x 3.2575186d-07,-1.4477908d-06, 6.0022450d-09 /
      data fpppp(19,14,13,1),fpppp(19,14,13,2),fpppp(19,14,13,3)/
     x-8.6597959d-07, 1.1934717d-06, 3.3436493d-09 /
      data fpppp(19,14,14,1),fpppp(19,14,14,2),fpppp(19,14,14,3)/
     x-2.0680813d-06, 1.3945752d-06, 1.0636673d-09 /
      data fpppp(19,14,15,1),fpppp(19,14,15,2),fpppp(19,14,15,3)/
     x-2.9222662d-06, 9.6615900d-07, 2.1071268d-10 /
      data fpppp(19,14,16,1),fpppp(19,14,16,2),fpppp(19,14,16,3)/
     x-2.6063823d-06, 1.8961190d-06, 5.6287892d-10 /
      data fpppp(19,14,17,1),fpppp(19,14,17,2),fpppp(19,14,17,3)/
     x-3.2681921d-06, 8.0955518d-07, 8.1305269d-10 /
      data fpppp(19,14,18,1),fpppp(19,14,18,2),fpppp(19,14,18,3)/
     x-4.2246680d-06,-2.6307804d-07, 6.7851121d-10 /
      data fpppp(19,14,19,1),fpppp(19,14,19,2),fpppp(19,14,19,3)/
     x-4.8291295d-06,-1.4877953d-06, 2.5544633d-09 /
      data fpppp(19,14,20,1),fpppp(19,14,20,2),fpppp(19,14,20,3)/
     x-5.4856782d-06,-2.6720917d-06,-6.1732811d-10 /
      data fpppp(19,14,21,1),fpppp(19,14,21,2),fpppp(19,14,21,3)/
     x-5.4856782d-06,-2.7039926d-06,-4.5801855d-10 /
      data fpppp(19,14,22,1),fpppp(19,14,22,2),fpppp(19,14,22,3)/
     x-4.8291295d-06,-1.3601917d-06, 1.9172250d-09 /
      data fpppp(19,14,23,1),fpppp(19,14,23,2),fpppp(19,14,23,3)/
     x-4.2246680d-06,-7.4159153d-07, 3.0681546d-09 /
      data fpppp(19,15, 1,1),fpppp(19,15, 1,2),fpppp(19,15, 1,3)/
     x 3.1286756d-05, 1.3199502d-03, 1.0425472d-07 /
      data fpppp(19,15, 2,1),fpppp(19,15, 2,2),fpppp(19,15, 2,3)/
     x-8.2576064d-04, 6.7617508d-04, 6.8356347d-08 /
      data fpppp(19,15, 3,1),fpppp(19,15, 3,2),fpppp(19,15, 3,3)/
     x-1.9990878d-03,-6.5628502d-04,-4.3421434d-09 /
      data fpppp(19,15, 4,1),fpppp(19,15, 4,2),fpppp(19,15, 4,3)/
     x-1.9990878d-03,-7.3863643d-04,-1.1738686d-08 /
      data fpppp(19,15, 5,1),fpppp(19,15, 5,2),fpppp(19,15, 5,3)/
     x-8.2576064d-04, 1.0055807d-03, 9.7942518d-08 /
      data fpppp(19,15, 6,1),fpppp(19,15, 6,2),fpppp(19,15, 6,3)/
     x 3.1286756d-05, 8.4679135d-05,-6.6934168d-09 /
      data fpppp(19,15, 7,1),fpppp(19,15, 7,2),fpppp(19,15, 7,3)/
     x 6.0956992d-05, 4.1371207d-05,-2.6580697d-08 /
      data fpppp(19,15, 8,1),fpppp(19,15, 8,2),fpppp(19,15, 8,3)/
     x 4.1179150d-05,-1.5652712d-05,-3.2442953d-08 /
      data fpppp(19,15, 9,1),fpppp(19,15, 9,2),fpppp(19,15, 9,3)/
     x 5.4722359d-05,-1.4561231d-05,-2.0274010d-08 /
      data fpppp(19,15,10,1),fpppp(19,15,10,2),fpppp(19,15,10,3)/
     x 1.0949785d-05,-1.2543602d-05,-7.3913883d-09 /
      data fpppp(19,15,11,1),fpppp(19,15,11,2),fpppp(19,15,11,3)/
     x 5.2079637d-06,-6.4152920d-06,-8.0162773d-11 /
      data fpppp(19,15,12,1),fpppp(19,15,12,2),fpppp(19,15,12,3)/
     x 2.4386465d-06,-1.8695270d-06, 1.9544008d-09 /
      data fpppp(19,15,13,1),fpppp(19,15,13,2),fpppp(19,15,13,3)/
     x 1.3343012d-06, 6.5925057d-07, 2.6077753d-09 /
      data fpppp(19,15,14,1),fpppp(19,15,14,2),fpppp(19,15,14,3)/
     x 3.0931973d-07, 1.0335729d-06, 2.3036430d-09 /
      data fpppp(19,15,15,1),fpppp(19,15,15,2),fpppp(19,15,15,3)/
     x-4.7064429d-07, 9.2905283d-07, 1.9783817d-09 /
      data fpppp(19,15,16,1),fpppp(19,15,16,2),fpppp(19,15,16,3)/
     x-1.9500516d-06, 9.0442228d-07, 9.6749462d-10 /
      data fpppp(19,15,17,1),fpppp(19,15,17,2),fpppp(19,15,17,3)/
     x-2.1375234d-06, 7.9168464d-08, 7.4268332d-10 /
      data fpppp(19,15,18,1),fpppp(19,15,18,2),fpppp(19,15,18,3)/
     x-1.3223366d-06, 1.7798527d-07, 1.3285696d-09 /
      data fpppp(19,15,19,1),fpppp(19,15,19,2),fpppp(19,15,19,3)/
     x-1.5644435d-06,-1.2057802d-06,-7.8273924d-10 /
      data fpppp(19,15,20,1),fpppp(19,15,20,2),fpppp(19,15,20,3)/
     x-1.3844407d-06,-1.7629214d-06,-2.6691244d-10 /
      data fpppp(19,15,21,1),fpppp(19,15,21,2),fpppp(19,15,21,3)/
     x-1.3844407d-06,-1.8162647d-06,-3.7855934d-10 /
      data fpppp(19,15,22,1),fpppp(19,15,22,2),fpppp(19,15,22,3)/
     x-1.5644435d-06,-9.9240686d-07,-3.3615163d-10 /
      data fpppp(19,15,23,1),fpppp(19,15,23,2),fpppp(19,15,23,3)/
     x-1.3223366d-06,-6.2216475d-07,-3.4613388d-10 /
      data fpppp(19,16, 1,1),fpppp(19,16, 1,2),fpppp(19,16, 1,3)/
     x-2.3442005d-04, 8.4485576d-04, 2.2237892d-07 /
      data fpppp(19,16, 2,1),fpppp(19,16, 2,2),fpppp(19,16, 2,3)/
     x 6.7349658d-04, 4.5949569d-04, 1.0975545d-07 /
      data fpppp(19,16, 3,1),fpppp(19,16, 3,2),fpppp(19,16, 3,3)/
     x 1.1275026d-03,-3.2577138d-04,-1.2704307d-07 /
      data fpppp(19,16, 4,1),fpppp(19,16, 4,2),fpppp(19,16, 4,3)/
     x 1.1275026d-03,-3.9665425d-04,-1.3498368d-07 /
      data fpppp(19,16, 5,1),fpppp(19,16, 5,2),fpppp(19,16, 5,3)/
     x 6.7349658d-04, 7.4302716d-04, 1.4151789d-07 /
      data fpppp(19,16, 6,1),fpppp(19,16, 6,2),fpppp(19,16, 6,3)/
     x-2.3442005d-04,-2.1838724d-04, 1.0326977d-07 /
      data fpppp(19,16, 7,1),fpppp(19,16, 7,2),fpppp(19,16, 7,3)/
     x-4.9028440d-05, 5.6831924d-05, 3.3657552d-08 /
      data fpppp(19,16, 8,1),fpppp(19,16, 8,2),fpppp(19,16, 8,3)/
     x-1.7583348d-05, 2.4374009d-05,-1.4212368d-08 /
      data fpppp(19,16, 9,1),fpppp(19,16, 9,2),fpppp(19,16, 9,3)/
     x-5.0811336d-05,-5.2054789d-05,-2.6987158d-08 /
      data fpppp(19,16,10,1),fpppp(19,16,10,2),fpppp(19,16,10,3)/
     x 5.4952566d-06, 2.8167161d-05,-2.1726941d-08 /
      data fpppp(19,16,11,1),fpppp(19,16,11,2),fpppp(19,16,11,3)/
     x 4.7260662d-06,-1.1656212d-05,-1.2503504d-08 /
      data fpppp(19,16,12,1),fpppp(19,16,12,2),fpppp(19,16,12,3)/
     x 3.4140945d-06, 1.2728404d-06,-5.2174077d-09 /
      data fpppp(19,16,13,1),fpppp(19,16,13,2),fpppp(19,16,13,3)/
     x 2.2084734d-06,-4.9689991d-07,-1.3457889d-09 /
      data fpppp(19,16,14,1),fpppp(19,16,14,2),fpppp(19,16,14,3)/
     x 2.2607652d-06, 1.1611823d-06, 1.2434726d-09 /
      data fpppp(19,16,15,1),fpppp(19,16,15,2),fpppp(19,16,15,3)/
     x 1.7601439d-06, 3.3450257d-07, 1.7599503d-09 /
      data fpppp(19,16,16,1),fpppp(19,16,16,2),fpppp(19,16,16,3)/
     x 2.0163181d-06, 7.8298133d-07, 2.1086719d-09 /
      data fpppp(19,16,17,1),fpppp(19,16,17,2),fpppp(19,16,17,3)/
     x 1.8805006d-06, 2.2325920d-07, 1.2059072d-09 /
      data fpppp(19,16,18,1),fpppp(19,16,18,2),fpppp(19,16,18,3)/
     x 1.3539590d-06,-4.2387292d-07,-8.1309180d-10 /
      data fpppp(19,16,19,1),fpppp(19,16,19,2),fpppp(19,16,19,3)/
     x 1.9724902d-06,-3.5864408d-07,-1.0119914d-09 /
      data fpppp(19,16,20,1),fpppp(19,16,20,2),fpppp(19,16,20,3)/
     x 2.0598989d-06,-9.6608461d-07,-7.4077967d-10 /
      data fpppp(19,16,21,1),fpppp(19,16,21,2),fpppp(19,16,21,3)/
     x 2.0598989d-06,-9.4953234d-07,-7.5622896d-10 /
      data fpppp(19,16,22,1),fpppp(19,16,22,2),fpppp(19,16,22,3)/
     x 1.9724902d-06,-4.2485315d-07,-9.5019425d-10 /
      data fpppp(19,16,23,1),fpppp(19,16,23,2),fpppp(19,16,23,3)/
     x 1.3539590d-06,-1.7558892d-07,-1.0448312d-09 /
      data fpppp(19,17, 1,1),fpppp(19,17, 1,2),fpppp(19,17, 1,3)/
     x 2.4184334d-04, 3.5172433d-05, 5.1190456d-08 /
      data fpppp(19,17, 2,1),fpppp(19,17, 2,2),fpppp(19,17, 2,3)/
     x-3.7511593d-04, 1.7849645d-06, 1.0870124d-08 /
      data fpppp(19,17, 3,1),fpppp(19,17, 3,2),fpppp(19,17, 3,3)/
     x-2.4541010d-04,-8.1800700d-05,-7.5719553d-08 /
      data fpppp(19,17, 4,1),fpppp(19,17, 4,2),fpppp(19,17, 4,3)/
     x-2.4541010d-04,-6.0728794d-05,-7.5388862d-08 /
      data fpppp(19,17, 5,1),fpppp(19,17, 5,2),fpppp(19,17, 5,3)/
     x-3.7511593d-04,-8.2502660d-05, 9.5473608d-09 /
      data fpppp(19,17, 6,1),fpppp(19,17, 6,2),fpppp(19,17, 6,3)/
     x 2.4184334d-04, 3.5125103d-04, 5.6150819d-08 /
      data fpppp(19,17, 7,1),fpppp(19,17, 7,2),fpppp(19,17, 7,3)/
     x-6.2964736d-05,-2.3146122d-04, 5.4203149d-08 /
      data fpppp(19,17, 8,1),fpppp(19,17, 8,2),fpppp(19,17, 8,3)/
     x-3.7530675d-05, 7.1719508d-05, 2.7505307d-08 /
      data fpppp(19,17, 9,1),fpppp(19,17, 9,2),fpppp(19,17, 9,3)/
     x 1.1027108d-05,-1.7317146d-05, 4.3184501d-09 /
      data fpppp(19,17,10,1),fpppp(19,17,10,2),fpppp(19,17,10,3)/
     x-8.0684316d-06, 5.8035591d-06,-7.4569704d-09 /
      data fpppp(19,17,11,1),fpppp(19,17,11,2),fpppp(19,17,11,3)/
     x-1.0328909d-06,-9.7217339d-07,-1.0097147d-08 /
      data fpppp(19,17,12,1),fpppp(19,17,12,2),fpppp(19,17,12,3)/
     x 1.4953669d-06, 8.3835679d-08,-8.6433441d-09 /
      data fpppp(19,17,13,1),fpppp(19,17,13,2),fpppp(19,17,13,3)/
     x 2.8496484d-06, 6.6387761d-07,-5.3589974d-09 /
      data fpppp(19,17,14,1),fpppp(19,17,14,2),fpppp(19,17,14,3)/
     x 2.9795541d-06, 2.3909181d-07,-2.9814495d-09 /
      data fpppp(19,17,15,1),fpppp(19,17,15,2),fpppp(19,17,15,3)/
     x 3.9594675d-06, 5.0519627d-07,-7.8814167d-10 /
      data fpppp(19,17,16,1),fpppp(19,17,16,2),fpppp(19,17,16,3)/
     x 4.4491879d-06, 4.8781040d-07,-1.7843072d-10 /
      data fpppp(19,17,17,1),fpppp(19,17,17,2),fpppp(19,17,17,3)/
     x 5.0346793d-06, 1.1676543d-07,-2.9135910d-10 /
      data fpppp(19,17,18,1),fpppp(19,17,18,2),fpppp(19,17,18,3)/
     x 5.9553439d-06,-7.4727421d-08, 4.0233974d-11 /
      data fpppp(19,17,19,1),fpppp(19,17,19,2),fpppp(19,17,19,3)/
     x 6.3692758d-06,-4.8673472d-08,-1.1899937d-09 /
      data fpppp(19,17,20,1),fpppp(19,17,20,2),fpppp(19,17,20,3)/
     x 7.2046254d-06,-2.5255186d-07,-1.0436107d-09 /
      data fpppp(19,17,21,1),fpppp(19,17,21,2),fpppp(19,17,21,3)/
     x 7.2046254d-06,-2.4679883d-07,-1.1052502d-09 /
      data fpppp(19,17,22,1),fpppp(19,17,22,2),fpppp(19,17,22,3)/
     x 6.3692758d-06,-7.1685598d-08,-9.4343553d-10 /
      data fpppp(19,17,23,1),fpppp(19,17,23,2),fpppp(19,17,23,3)/
     x 5.9553439d-06, 1.1568051d-08,-8.8435923d-10 /
      data fpppp(19,18, 1,1),fpppp(19,18, 1,2),fpppp(19,18, 1,3)/
     x-1.3303942d-04,-3.3242448d-07, 1.2022998d-08 /
      data fpppp(19,18, 2,1),fpppp(19,18, 2,2),fpppp(19,18, 2,3)/
     x 8.0155429d-05,-8.3453036d-07,-1.5134352d-09 /
      data fpppp(19,18, 3,1),fpppp(19,18, 3,2),fpppp(19,18, 3,3)/
     x 1.9103950d-04,-1.9343988d-06,-3.0412514d-08 /
      data fpppp(19,18, 4,1),fpppp(19,18, 4,2),fpppp(19,18, 4,3)/
     x 1.9103950d-04,-1.8925261d-06,-3.0600750d-08 /
      data fpppp(19,18, 5,1),fpppp(19,18, 5,2),fpppp(19,18, 5,3)/
     x 8.0155429d-05,-1.0020213d-06,-7.6049144d-10 /
      data fpppp(19,18, 6,1),fpppp(19,18, 6,2),fpppp(19,18, 6,3)/
     x-1.3303942d-04, 2.9566637d-07, 9.1994591d-09 /
      data fpppp(19,18, 7,1),fpppp(19,18, 7,2),fpppp(19,18, 7,3)/
     x-8.4039266d-06,-3.4111082d-07, 1.4373002d-08 /
      data fpppp(19,18, 8,1),fpppp(19,18, 8,2),fpppp(19,18, 8,3)/
     x-1.2294471d-05, 5.0160966d-07, 1.3986040d-08 /
      data fpppp(19,18, 9,1),fpppp(19,18, 9,2),fpppp(19,18, 9,3)/
     x-1.5807515d-05, 4.6014430d-07, 1.0930600d-08 /
      data fpppp(19,18,10,1),fpppp(19,18,10,2),fpppp(19,18,10,3)/
     x-7.6178108d-06, 4.6880340d-07, 7.0909486d-09 /
      data fpppp(19,18,11,1),fpppp(19,18,11,2),fpppp(19,18,11,3)/
     x-5.0016555d-06, 4.3182071d-07, 3.8103423d-09 /
      data fpppp(19,18,12,1),fpppp(19,18,12,2),fpppp(19,18,12,3)/
     x-2.4893933d-06, 3.1035679d-07, 1.5816544d-09 /
      data fpppp(19,18,13,1),fpppp(19,18,13,2),fpppp(19,18,13,3)/
     x-5.3768869d-07, 2.9248356d-07, 6.0046166d-11 /
      data fpppp(19,18,14,1),fpppp(19,18,14,2),fpppp(19,18,14,3)/
     x 1.4523551d-06, 4.2891095d-07,-6.2161522d-10 /
      data fpppp(19,18,15,1),fpppp(19,18,15,2),fpppp(19,18,15,3)/
     x 2.9563411d-06, 1.2148272d-07,-1.2298890d-09 /
      data fpppp(19,18,16,1),fpppp(19,18,16,2),fpppp(19,18,16,3)/
     x 4.6191981d-06, 2.5325342d-07,-1.5609868d-09 /
      data fpppp(19,18,17,1),fpppp(19,18,17,2),fpppp(19,18,17,3)/
     x 6.2186476d-06, 2.4990758d-07,-1.7938141d-09 /
      data fpppp(19,18,18,1),fpppp(19,18,18,2),fpppp(19,18,18,3)/
     x 7.5148616d-06,-9.8005807d-08,-2.6084330d-09 /
      data fpppp(19,18,19,1),fpppp(19,18,19,2),fpppp(19,18,19,3)/
     x 8.7347423d-06, 5.5316481d-07,-2.4723346d-09 /
      data fpppp(19,18,20,1),fpppp(19,18,20,2),fpppp(19,18,20,3)/
     x 9.0751112d-06,-5.9028953d-08,-2.7669851d-09 /
      data fpppp(19,18,21,1),fpppp(19,18,21,2),fpppp(19,18,21,3)/
     x 9.0751112d-06,-1.4557701d-08,-2.7539977d-09 /
      data fpppp(19,18,22,1),fpppp(19,18,22,2),fpppp(19,18,22,3)/
     x 8.7347423d-06, 3.7527981d-07,-2.5242844d-09 /
      data fpppp(19,18,23,1),fpppp(19,18,23,2),fpppp(19,18,23,3)/
     x 7.5148616d-06, 5.6906297d-07,-2.4136215d-09 /
      data fpppp(19,19, 1,1),fpppp(19,19, 1,2),fpppp(19,19, 1,3)/
     x-2.6473757d-04, 7.5844934d-19,-6.4864748d-08 /
      data fpppp(19,19, 2,1),fpppp(19,19, 2,2),fpppp(19,19, 2,3)/
     x 1.0574569d-04, 2.1379350d-19,-3.8611785d-08 /
      data fpppp(19,19, 3,1),fpppp(19,19, 3,2),fpppp(19,19, 3,3)/
     x 1.1052845d-04,-1.4909997d-19, 1.6613517d-08 /
      data fpppp(19,19, 4,1),fpppp(19,19, 4,2),fpppp(19,19, 4,3)/
     x 1.1052845d-04,-3.0434001d-20, 1.8417848d-08 /
      data fpppp(19,19, 5,1),fpppp(19,19, 5,2),fpppp(19,19, 5,3)/
     x 1.0574569d-04,-4.9087281d-20,-4.5829109d-08 /
      data fpppp(19,19, 6,1),fpppp(19,19, 6,2),fpppp(19,19, 6,3)/
     x-2.6473757d-04,-6.5281212d-20,-3.7799783d-08 /
      data fpppp(19,19, 7,1),fpppp(19,19, 7,2),fpppp(19,19, 7,3)/
     x 2.6586281d-05,-8.5031461d-20,-8.2069319d-09 /
      data fpppp(19,19, 8,1),fpppp(19,19, 8,2),fpppp(19,19, 8,3)/
     x 3.2152455d-08,-1.7065844d-19, 1.6248757d-08 /
      data fpppp(19,19, 9,1),fpppp(19,19, 9,2),fpppp(19,19, 9,3)/
     x-1.7306977d-05,-1.6710072d-19, 2.4598024d-08 /
      data fpppp(19,19,10,1),fpppp(19,19,10,2),fpppp(19,19,10,3)/
     x-1.1171278d-05,-1.9697047d-20, 2.1559454d-08 /
      data fpppp(19,19,11,1),fpppp(19,19,11,2),fpppp(19,19,11,3)/
     x-9.4819036d-06,-1.6702191d-19, 1.4431794d-08 /
      data fpppp(19,19,12,1),fpppp(19,19,12,2),fpppp(19,19,12,3)/
     x-5.8838584d-06,-3.8271117d-19, 7.9063857d-09 /
      data fpppp(19,19,13,1),fpppp(19,19,13,2),fpppp(19,19,13,3)/
     x-2.7740223d-06,-1.9472513d-19, 2.7841606d-09 /
      data fpppp(19,19,14,1),fpppp(19,19,14,2),fpppp(19,19,14,3)/
     x 5.6686686d-07,-1.9699422d-19,-1.4313991d-10 /
      data fpppp(19,19,15,1),fpppp(19,19,15,2),fpppp(19,19,15,3)/
     x 2.8682003d-06,-2.1612410d-19,-2.2734491d-09 /
      data fpppp(19,19,16,1),fpppp(19,19,16,2),fpppp(19,19,16,3)/
     x 5.4357396d-06, 1.5822568d-19,-3.2019848d-09 /
      data fpppp(19,19,17,1),fpppp(19,19,17,2),fpppp(19,19,17,3)/
     x 7.9655332d-06,-4.0216713d-20,-3.2947866d-09 /
      data fpppp(19,19,18,1),fpppp(19,19,18,2),fpppp(19,19,18,3)/
     x 9.9434843d-06,-2.5998613d-20,-4.2565307d-09 /
      data fpppp(19,19,19,1),fpppp(19,19,19,2),fpppp(19,19,19,3)/
     x 1.1680586d-05,-4.2549019d-20,-3.4391502d-09 /
      data fpppp(19,19,20,1),fpppp(19,19,20,2),fpppp(19,19,20,3)/
     x 1.1881094d-05,-9.4161571d-23,-4.0844900d-09 /
      data fpppp(19,19,21,1),fpppp(19,19,21,2),fpppp(19,19,21,3)/
     x 1.1881094d-05,-1.2245885d-19,-4.0313948d-09 /
      data fpppp(19,19,22,1),fpppp(19,19,22,2),fpppp(19,19,22,3)/
     x 1.1680586d-05,-1.8332513d-19,-3.6515311d-09 /
      data fpppp(19,19,23,1),fpppp(19,19,23,2),fpppp(19,19,23,3)/
     x 9.9434843d-06,-5.8338124d-19,-3.4601026d-09 /
      data fpppp(20, 1, 1,1),fpppp(20, 1, 1,2),fpppp(20, 1, 1,3)/
     x-1.9906769d-03,-1.0069243d-17, 1.4553321d-06 /
      data fpppp(20, 1, 2,1),fpppp(20, 1, 2,2),fpppp(20, 1, 2,3)/
     x-1.3359369d-03, 2.6379828d-18, 6.6299290d-07 /
      data fpppp(20, 1, 3,1),fpppp(20, 1, 3,2),fpppp(20, 1, 3,3)/
     x-3.5120936d-04, 6.0926200d-18,-9.8347314d-07 /
      data fpppp(20, 1, 4,1),fpppp(20, 1, 4,2),fpppp(20, 1, 4,3)/
     x-3.5120936d-04,-4.3376202d-18,-1.0734297d-06 /
      data fpppp(20, 1, 5,1),fpppp(20, 1, 5,2),fpppp(20, 1, 5,3)/
     x-1.3359369d-03,-2.4562834d-18, 1.0228192d-06 /
      data fpppp(20, 1, 6,1),fpppp(20, 1, 6,2),fpppp(20, 1, 6,3)/
     x-1.9906769d-03,-3.1054435d-18, 1.0598335d-07 /
      data fpppp(20, 1, 7,1),fpppp(20, 1, 7,2),fpppp(20, 1, 7,3)/
     x-3.8073718d-03, 2.5584034d-18, 2.1585600d-07 /
      data fpppp(20, 1, 8,1),fpppp(20, 1, 8,2),fpppp(20, 1, 8,3)/
     x-4.3817631d-03,-8.2572427d-18, 1.0272366d-07 /
      data fpppp(20, 1, 9,1),fpppp(20, 1, 9,2),fpppp(20, 1, 9,3)/
     x-4.0208039d-03,-1.3199059d-18, 7.0797400d-08 /
      data fpppp(20, 1,10,1),fpppp(20, 1,10,2),fpppp(20, 1,10,3)/
     x-4.3512587d-03,-4.9535641d-18, 3.4836824d-08 /
      data fpppp(20, 1,11,1),fpppp(20, 1,11,2),fpppp(20, 1,11,3)/
     x-4.2037709d-03, 1.1048908d-17, 1.2642179d-08 /
      data fpppp(20, 1,12,1),fpppp(20, 1,12,2),fpppp(20, 1,12,3)/
     x-4.8552481d-03,-4.9032924d-18, 3.2913217d-09 /
      data fpppp(20, 1,13,1),fpppp(20, 1,13,2),fpppp(20, 1,13,3)/
     x-5.1425451d-03, 8.7598808d-18, 1.5602360d-08 /
      data fpppp(20, 1,14,1),fpppp(20, 1,14,2),fpppp(20, 1,14,3)/
     x-4.3913297d-03,-8.3341255d-18, 4.1021818d-08 /
      data fpppp(20, 1,15,1),fpppp(20, 1,15,2),fpppp(20, 1,15,3)/
     x-4.0868947d-03,-3.4149420d-18, 7.9103912d-08 /
      data fpppp(20, 1,16,1),fpppp(20, 1,16,2),fpppp(20, 1,16,3)/
     x-4.4955831d-03,-2.1381880d-18, 1.1027523d-07 /
      data fpppp(20, 1,17,1),fpppp(20, 1,17,2),fpppp(20, 1,17,3)/
     x-3.9947033d-03, 1.0002209d-17, 2.1879288d-07 /
      data fpppp(20, 1,18,1),fpppp(20, 1,18,2),fpppp(20, 1,18,3)/
     x-2.3325534d-03,-9.9975223d-18, 8.6883340d-08 /
      data fpppp(20, 1,19,1),fpppp(20, 1,19,2),fpppp(20, 1,19,3)/
     x 2.2899970d-03,-2.0519910d-18, 9.9759789d-07 /
      data fpppp(20, 1,20,1),fpppp(20, 1,20,2),fpppp(20, 1,20,3)/
     x 5.0939514d-04,-5.8649882d-18,-1.0450408d-06 /
      data fpppp(20, 1,21,1),fpppp(20, 1,21,2),fpppp(20, 1,21,3)/
     x 5.0939514d-04, 2.4226275d-18,-9.5656232d-07 /
      data fpppp(20, 1,22,1),fpppp(20, 1,22,2),fpppp(20, 1,22,3)/
     x 2.2899970d-03,-6.2091499d-18, 6.4368411d-07 /
      data fpppp(20, 1,23,1),fpppp(20, 1,23,2),fpppp(20, 1,23,3)/
     x-2.3325534d-03,-1.2580772d-17, 1.4140600d-06 /
      data fpppp(20, 2, 1,1),fpppp(20, 2, 1,2),fpppp(20, 2, 1,3)/
     x-1.2433740d-03,-3.6590598d-03, 5.3814905d-07 /
      data fpppp(20, 2, 2,1),fpppp(20, 2, 2,2),fpppp(20, 2, 2,3)/
     x-7.5231229d-04,-1.8354788d-03, 2.7734255d-07 /
      data fpppp(20, 2, 3,1),fpppp(20, 2, 3,2),fpppp(20, 2, 3,3)/
     x 1.6974482d-04, 1.9243120d-03,-2.6204042d-07 /
      data fpppp(20, 2, 4,1),fpppp(20, 2, 4,2),fpppp(20, 2, 4,3)/
     x 1.6974482d-04, 2.1831072d-03,-2.9614459d-07 /
      data fpppp(20, 2, 5,1),fpppp(20, 2, 5,2),fpppp(20, 2, 5,3)/
     x-7.5231229d-04,-2.8706596d-03, 4.1375924d-07 /
      data fpppp(20, 2, 6,1),fpppp(20, 2, 6,2),fpppp(20, 2, 6,3)/
     x-1.2433740d-03, 2.2286847d-04, 2.6586482d-08 /
      data fpppp(20, 2, 7,1),fpppp(20, 2, 7,2),fpppp(20, 2, 7,3)/
     x-2.1653417d-03,-2.5366466d-04, 6.3797530d-08 /
      data fpppp(20, 2, 8,1),fpppp(20, 2, 8,2),fpppp(20, 2, 8,3)/
     x-2.4867917d-03,-4.6549840d-04, 1.3261359d-08 /
      data fpppp(20, 2, 9,1),fpppp(20, 2, 9,2),fpppp(20, 2, 9,3)/
     x-2.3260823d-03, 3.9030637d-04,-6.6590319d-09 /
      data fpppp(20, 2,10,1),fpppp(20, 2,10,2),fpppp(20, 2,10,3)/
     x-2.4954624d-03,-3.5162687d-04,-2.6645397d-08 /
      data fpppp(20, 2,11,1),fpppp(20, 2,11,2),fpppp(20, 2,11,3)/
     x-2.4273250d-03, 3.5944161d-04,-3.8333127d-08 /
      data fpppp(20, 2,12,1),fpppp(20, 2,12,2),fpppp(20, 2,12,3)/
     x-2.7467192d-03,-1.2592698d-04,-4.2655818d-08 /
      data fpppp(20, 2,13,1),fpppp(20, 2,13,2),fpppp(20, 2,13,3)/
     x-2.8868373d-03,-3.3128800d-04,-3.6583251d-08 /
      data fpppp(20, 2,14,1),fpppp(20, 2,14,2),fpppp(20, 2,14,3)/
     x-2.5180005d-03, 1.2950759d-04,-2.3016334d-08 /
      data fpppp(20, 2,15,1),fpppp(20, 2,15,2),fpppp(20, 2,15,3)/
     x-2.3635325d-03, 3.1586711d-04,-1.6385029d-09 /
      data fpppp(20, 2,16,1),fpppp(20, 2,16,2),fpppp(20, 2,16,3)/
     x-2.5508545d-03,-6.0571173d-04, 1.8624954d-08 /
      data fpppp(20, 2,17,1),fpppp(20, 2,17,2),fpppp(20, 2,17,3)/
     x-2.2704237d-03, 4.8442249d-04, 6.7523285d-08 /
      data fpppp(20, 2,18,1),fpppp(20, 2,18,2),fpppp(20, 2,18,3)/
     x-1.4394868d-03,-2.3689690d-03, 2.1821752d-08 /
      data fpppp(20, 2,19,1),fpppp(20, 2,19,2),fpppp(20, 2,19,3)/
     x 1.0140541d-03, 8.7858668d-04, 3.9906144d-07 /
      data fpppp(20, 2,20,1),fpppp(20, 2,20,2),fpppp(20, 2,20,3)/
     x 4.7134890d-04, 9.0182362d-04,-2.8471581d-07 /
      data fpppp(20, 2,21,1),fpppp(20, 2,21,2),fpppp(20, 2,21,3)/
     x 4.7134890d-04, 1.0554650d-03,-2.5166190d-07 /
      data fpppp(20, 2,22,1),fpppp(20, 2,22,2),fpppp(20, 2,22,3)/
     x 1.0140541d-03, 2.6402116d-04, 2.6684579d-07 /
      data fpppp(20, 2,23,1),fpppp(20, 2,23,2),fpppp(20, 2,23,3)/
     x-1.4394868d-03,-6.4348266d-05, 5.1763043d-07 /
      data fpppp(20, 3, 1,1),fpppp(20, 3, 1,2),fpppp(20, 3, 1,3)/
     x 1.0024280d-04,-4.0304719d-03,-1.0287985d-06 /
      data fpppp(20, 3, 2,1),fpppp(20, 3, 2,2),fpppp(20, 3, 2,3)/
     x 2.4944222d-03,-2.0415864d-03,-4.1981283d-07 /
      data fpppp(20, 3, 3,1),fpppp(20, 3, 3,2),fpppp(20, 3, 3,3)/
     x 1.0873693d-02, 2.0825522d-03, 8.4306386d-07 /
      data fpppp(20, 3, 4,1),fpppp(20, 3, 4,2),fpppp(20, 3, 4,3)/
     x 1.0873693d-02, 2.3236304d-03, 9.1672586d-07 /
      data fpppp(20, 3, 5,1),fpppp(20, 3, 5,2),fpppp(20, 3, 5,3)/
     x 2.4944222d-03,-3.0058989d-03,-7.1446081d-07 /
      data fpppp(20, 3, 6,1),fpppp(20, 3, 6,2),fpppp(20, 3, 6,3)/
     x 1.0024280d-04,-4.1429984d-04, 7.6131436d-08 /
      data fpppp(20, 3, 7,1),fpppp(20, 3, 7,2),fpppp(20, 3, 7,3)/
     x 6.5500154d-04, 2.6075723d-04,-1.3156438d-07 /
      data fpppp(20, 3, 8,1),fpppp(20, 3, 8,2),fpppp(20, 3, 8,3)/
     x 4.6170149d-04,-2.4699074d-04,-1.0331681d-07 /
      data fpppp(20, 3, 9,1),fpppp(20, 3, 9,2),fpppp(20, 3, 9,3)/
     x 1.6052558d-04, 3.2613697d-05,-1.2329217d-07 /
      data fpppp(20, 3,10,1),fpppp(20, 3,10,2),fpppp(20, 3,10,3)/
     x 2.4045517d-04,-2.5929808d-05,-1.3434392d-07 /
      data fpppp(20, 3,11,1),fpppp(20, 3,11,2),fpppp(20, 3,11,3)/
     x 1.3404899d-04,-7.3639203d-07,-1.4814403d-07 /
      data fpppp(20, 3,12,1),fpppp(20, 3,12,2),fpppp(20, 3,12,3)/
     x 4.2287772d-04,-4.5563511d-06,-1.5244193d-07 /
      data fpppp(20, 3,13,1),fpppp(20, 3,13,2),fpppp(20, 3,13,3)/
     x 5.6351151d-04, 9.4266789d-07,-1.4885948d-07 /
      data fpppp(20, 3,14,1),fpppp(20, 3,14,2),fpppp(20, 3,14,3)/
     x 2.4513982d-04,-2.7030074d-05,-1.3514211d-07 /
      data fpppp(20, 3,15,1),fpppp(20, 3,15,2),fpppp(20, 3,15,3)/
     x 1.6607145d-04, 4.7443720d-05,-1.2281726d-07 /
      data fpppp(20, 3,16,1),fpppp(20, 3,16,2),fpppp(20, 3,16,3)/
     x 4.7266185d-04,-2.8284049d-04,-9.9199981d-08 /
      data fpppp(20, 3,17,1),fpppp(20, 3,17,2),fpppp(20, 3,17,3)/
     x 6.2857799d-04, 4.6870860d-04,-1.2031892d-07 /
      data fpppp(20, 3,18,1),fpppp(20, 3,18,2),fpppp(20, 3,18,3)/
     x 6.4964990d-05,-1.0222099d-03, 1.0126618d-07 /
      data fpppp(20, 3,19,1),fpppp(20, 3,19,2),fpppp(20, 3,19,3)/
     x 8.4165006d-04,-1.8144881d-03,-6.7871689d-07 /
      data fpppp(20, 3,20,1),fpppp(20, 3,20,2),fpppp(20, 3,20,3)/
     x 9.4109056d-03, 1.7789992d-03, 8.7232039d-07 /
      data fpppp(20, 3,21,1),fpppp(20, 3,21,2),fpppp(20, 3,21,3)/
     x 9.4109056d-03, 1.6617885d-03, 8.0093746d-07 /
      data fpppp(20, 3,22,1),fpppp(20, 3,22,2),fpppp(20, 3,22,3)/
     x 8.4165006d-04,-1.3456453d-03,-3.9318515d-07 /
      data fpppp(20, 3,23,1),fpppp(20, 3,23,2),fpppp(20, 3,23,3)/
     x 6.4964990d-05,-2.7803706d-03,-9.6947782d-07 /
      data fpppp(20, 4, 1,1),fpppp(20, 4, 1,2),fpppp(20, 4, 1,3)/
     x-6.4323915d-04, 2.2116442d-03,-3.2157042d-07 /
      data fpppp(20, 4, 2,1),fpppp(20, 4, 2,2),fpppp(20, 4, 2,3)/
     x-3.5797279d-03, 1.1364772d-03,-2.6700565d-08 /
      data fpppp(20, 4, 3,1),fpppp(20, 4, 3,2),fpppp(20, 4, 3,3)/
     x-1.4062838d-02,-1.0846795d-03, 6.0531769d-07 /
      data fpppp(20, 4, 4,1),fpppp(20, 4, 4,2),fpppp(20, 4, 4,3)/
     x-1.4062838d-02,-1.2295317d-03, 6.0504772d-07 /
      data fpppp(20, 4, 5,1),fpppp(20, 4, 5,2),fpppp(20, 4, 5,3)/
     x-3.5797279d-03, 1.7158860d-03,-2.5620680d-08 /
      data fpppp(20, 4, 6,1),fpppp(20, 4, 6,2),fpppp(20, 4, 6,3)/
     x-6.4323915d-04, 3.8861438d-05,-3.2562000d-07 /
      data fpppp(20, 4, 7,1),fpppp(20, 4, 7,2),fpppp(20, 4, 7,3)/
     x-6.4875099d-04,-2.0317456d-05,-1.7536426d-07 /
      data fpppp(20, 4, 8,1),fpppp(20, 4, 8,2),fpppp(20, 4, 8,3)/
     x-2.7713143d-04, 4.8587492d-05,-1.2498943d-07 /
      data fpppp(20, 4, 9,1),fpppp(20, 4, 9,2),fpppp(20, 4, 9,3)/
     x-1.2446868d-04,-6.1656649d-06,-1.0280683d-07 /
      data fpppp(20, 4,10,1),fpppp(20, 4,10,2),fpppp(20, 4,10,3)/
     x-1.0405202d-04, 9.1299006d-06,-8.0285387d-08 /
      data fpppp(20, 4,11,1),fpppp(20, 4,11,2),fpppp(20, 4,11,3)/
     x-5.1825243d-05, 6.7063504d-06,-5.2030343d-08 /
      data fpppp(20, 4,12,1),fpppp(20, 4,12,2),fpppp(20, 4,12,3)/
     x-1.2126320d-04, 8.7118866d-06,-3.8791643d-08 /
      data fpppp(20, 4,13,1),fpppp(20, 4,13,2),fpppp(20, 4,13,3)/
     x-1.6738338d-04, 7.7762479d-06,-5.0818551d-08 /
      data fpppp(20, 4,14,1),fpppp(20, 4,14,2),fpppp(20, 4,14,3)/
     x-1.0605863d-04, 6.5010829d-06,-7.8961202d-08 /
      data fpppp(20, 4,15,1),fpppp(20, 4,15,2),fpppp(20, 4,15,3)/
     x-1.2617102d-04, 5.5493562d-06,-1.0246882d-07 /
      data fpppp(20, 4,16,1),fpppp(20, 4,16,2),fpppp(20, 4,16,3)/
     x-2.7957903d-04, 1.1395317d-05,-1.2541360d-07 /
      data fpppp(20, 4,17,1),fpppp(20, 4,17,2),fpppp(20, 4,17,3)/
     x-5.8394747d-04, 5.5102771d-05,-1.8015699d-07 /
      data fpppp(20, 4,18,1),fpppp(20, 4,18,2),fpppp(20, 4,18,3)/
     x-5.7043115d-04,-6.4973230d-05,-3.2506045d-07 /
      data fpppp(20, 4,19,1),fpppp(20, 4,19,2),fpppp(20, 4,19,3)/
     x-3.1931403d-03, 1.7959895d-03,-7.9148645d-08 /
      data fpppp(20, 4,20,1),fpppp(20, 4,20,2),fpppp(20, 4,20,3)/
     x-1.3071148d-02,-1.2497753d-03, 6.4086722d-07 /
      data fpppp(20, 4,21,1),fpppp(20, 4,21,2),fpppp(20, 4,21,3)/
     x-1.3071148d-02,-1.0939690d-03, 6.3659053d-07 /
      data fpppp(20, 4,22,1),fpppp(20, 4,22,2),fpppp(20, 4,22,3)/
     x-3.1931403d-03, 1.1727643d-03,-6.2041886d-08 /
      data fpppp(20, 4,23,1),fpppp(20, 4,23,2),fpppp(20, 4,23,3)/
     x-5.7043115d-04, 2.2721214d-03,-3.8921080d-07 /
      data fpppp(20, 5, 1,1),fpppp(20, 5, 1,2),fpppp(20, 5, 1,3)/
     x-4.3653409d-06, 2.4847031d-04, 5.3821792d-07 /
      data fpppp(20, 5, 2,1),fpppp(20, 5, 2,2),fpppp(20, 5, 2,3)/
     x 9.6059669d-04, 1.0769711d-04, 2.5305962d-07 /
      data fpppp(20, 5, 3,1),fpppp(20, 5, 3,2),fpppp(20, 5, 3,3)/
     x 5.1600936d-03,-1.8610636d-04,-3.4357047d-07 /
      data fpppp(20, 5, 4,1),fpppp(20, 5, 4,2),fpppp(20, 5, 4,3)/
     x 5.1600936d-03,-1.9984977d-04,-3.6881143d-07 /
      data fpppp(20, 5, 5,1),fpppp(20, 5, 5,2),fpppp(20, 5, 5,3)/
     x 9.6059669d-04, 1.6267075d-04, 3.5402345d-07 /
      data fpppp(20, 5, 6,1),fpppp(20, 5, 6,2),fpppp(20, 5, 6,3)/
     x-4.3653409d-06, 4.2319160d-05, 1.5960358d-07 /
      data fpppp(20, 5, 7,1),fpppp(20, 5, 7,2),fpppp(20, 5, 7,3)/
     x 1.1250914d-04, 3.5194308d-05, 5.7081380d-08 /
      data fpppp(20, 5, 8,1),fpppp(20, 5, 8,2),fpppp(20, 5, 8,3)/
     x 3.6736012d-05, 1.5342752d-05,-8.4603199d-09 /
      data fpppp(20, 5, 9,1),fpppp(20, 5, 9,2),fpppp(20, 5, 9,3)/
     x 2.4534308d-05, 1.3628746d-05,-1.0721021d-08 /
      data fpppp(20, 5,10,1),fpppp(20, 5,10,2),fpppp(20, 5,10,3)/
     x 3.2863316d-05, 1.1369311d-05,-1.1775764d-09 /
      data fpppp(20, 5,11,1),fpppp(20, 5,11,2),fpppp(20, 5,11,3)/
     x 2.3267800d-05, 9.8367293d-06,-2.8189362d-10 /
      data fpppp(20, 5,12,1),fpppp(20, 5,12,2),fpppp(20, 5,12,3)/
     x 4.1783775d-05, 8.7373306d-06,-3.0192754d-09 /
      data fpppp(20, 5,13,1),fpppp(20, 5,13,2),fpppp(20, 5,13,3)/
     x 5.2946422d-05, 9.6161972d-06, 3.5208351d-10 /
      data fpppp(20, 5,14,1),fpppp(20, 5,14,2),fpppp(20, 5,14,3)/
     x 3.1037360d-05, 1.0952080d-05, 1.0109451d-10 /
      data fpppp(20, 5,15,1),fpppp(20, 5,15,2),fpppp(20, 5,15,3)/
     x 2.3238466d-05, 1.2634231d-05,-8.7425513d-09 /
      data fpppp(20, 5,16,1),fpppp(20, 5,16,2),fpppp(20, 5,16,3)/
     x 3.9836047d-05, 1.5667080d-05,-9.1994027d-09 /
      data fpppp(20, 5,17,1),fpppp(20, 5,17,2),fpppp(20, 5,17,3)/
     x 8.8858178d-05, 3.0282406d-05, 5.0517094d-08 /
      data fpppp(20, 5,18,1),fpppp(20, 5,18,2),fpppp(20, 5,18,3)/
     x 1.3351365d-05, 5.4566601d-05, 1.3378847d-07 /
      data fpppp(20, 5,19,1),fpppp(20, 5,19,2),fpppp(20, 5,19,3)/
     x 8.8396995d-04, 1.0999067d-04, 3.5632983d-07 /
      data fpppp(20, 5,20,1),fpppp(20, 5,20,2),fpppp(20, 5,20,3)/
     x 5.0711349d-03,-1.6702484d-04,-3.5611557d-07 /
      data fpppp(20, 5,21,1),fpppp(20, 5,21,2),fpppp(20, 5,21,3)/
     x 5.0711349d-03,-1.5825753d-04,-3.2976988d-07 /
      data fpppp(20, 5,22,1),fpppp(20, 5,22,2),fpppp(20, 5,22,3)/
     x 8.8396995d-04, 7.4921436d-05, 2.5094707d-07 /
      data fpppp(20, 5,23,1),fpppp(20, 5,23,2),fpppp(20, 5,23,3)/
     x 1.3351365d-05, 1.8607624d-04, 5.2897382d-07 /
      data fpppp(20, 6, 1,1),fpppp(20, 6, 1,2),fpppp(20, 6, 1,3)/
     x-3.8678592d-05, 1.7005867d-05, 4.1004827d-08 /
      data fpppp(20, 6, 2,1),fpppp(20, 6, 2,2),fpppp(20, 6, 2,3)/
     x-2.3130117d-04,-2.8464151d-06,-1.4240122d-08 /
      data fpppp(20, 6, 3,1),fpppp(20, 6, 3,2),fpppp(20, 6, 3,3)/
     x-1.1683148d-03,-4.5062339d-05,-1.3249314d-07 /
      data fpppp(20, 6, 4,1),fpppp(20, 6, 4,2),fpppp(20, 6, 4,3)/
     x-1.1683148d-03,-4.5630531d-05,-1.3271892d-07 /
      data fpppp(20, 6, 5,1),fpppp(20, 6, 5,2),fpppp(20, 6, 5,3)/
     x-2.3130117d-04,-5.7364696d-07,-1.3337021d-08 /
      data fpppp(20, 6, 6,1),fpppp(20, 6, 6,2),fpppp(20, 6, 6,3)/
     x-3.8678592d-05, 8.4829864d-06, 3.7618198d-08 /
      data fpppp(20, 6, 7,1),fpppp(20, 6, 7,2),fpppp(20, 6, 7,3)/
     x-6.9930872d-05, 1.1381401d-05, 4.2492562d-08 /
      data fpppp(20, 6, 8,1),fpppp(20, 6, 8,2),fpppp(20, 6, 8,3)/
     x-3.3223999d-05, 1.1190764d-05, 4.4362916d-08 /
      data fpppp(20, 6, 9,1),fpppp(20, 6, 9,2),fpppp(20, 6, 9,3)/
     x-1.7048506d-05, 1.1174297d-05, 4.2268287d-08 /
      data fpppp(20, 6,10,1),fpppp(20, 6,10,2),fpppp(20, 6,10,3)/
     x-1.3981847d-05, 1.0279323d-05, 2.8514015d-08 /
      data fpppp(20, 6,11,1),fpppp(20, 6,11,2),fpppp(20, 6,11,3)/
     x-1.0358521d-05, 9.2022564d-06, 1.6387259d-08 /
      data fpppp(20, 6,12,1),fpppp(20, 6,12,2),fpppp(20, 6,12,3)/
     x-1.5486658d-05, 9.1813450d-06, 1.2513053d-08 /
      data fpppp(20, 6,13,1),fpppp(20, 6,13,2),fpppp(20, 6,13,3)/
     x-1.9376861d-05, 8.6891145d-06, 1.4963641d-08 /
      data fpppp(20, 6,14,1),fpppp(20, 6,14,2),fpppp(20, 6,14,3)/
     x-1.4244140d-05, 1.0233651d-05, 2.5738821d-08 /
      data fpppp(20, 6,15,1),fpppp(20, 6,15,2),fpppp(20, 6,15,3)/
     x-1.5892736d-05, 1.1386059d-05, 3.6837618d-08 /
      data fpppp(20, 6,16,1),fpppp(20, 6,16,2),fpppp(20, 6,16,3)/
     x-2.8261409d-05, 1.2010656d-05, 3.7474851d-08 /
      data fpppp(20, 6,17,1),fpppp(20, 6,17,2),fpppp(20, 6,17,3)/
     x-5.0289202d-05, 1.4586473d-05, 3.5115457d-08 /
      data fpppp(20, 6,18,1),fpppp(20, 6,18,2),fpppp(20, 6,18,3)/
     x-2.4460325d-05, 1.3162550d-05, 3.5735530d-08 /
      data fpppp(20, 6,19,1),fpppp(20, 6,19,2),fpppp(20, 6,19,3)/
     x-1.9854531d-04, 7.0052481d-06,-3.6733857d-09 /
      data fpppp(20, 6,20,1),fpppp(20, 6,20,2),fpppp(20, 6,20,3)/
     x-1.1811208d-03,-5.2987759d-05,-1.2954303d-07 /
      data fpppp(20, 6,21,1),fpppp(20, 6,21,2),fpppp(20, 6,21,3)/
     x-1.1811208d-03,-5.1951077d-05,-1.2862545d-07 /
      data fpppp(20, 6,22,1),fpppp(20, 6,22,2),fpppp(20, 6,22,3)/
     x-1.9854531d-04, 2.8585200d-06,-7.3436863d-09 /
      data fpppp(20, 6,23,1),fpppp(20, 6,23,2),fpppp(20, 6,23,3)/
     x-2.4460325d-05, 2.8712780d-05, 4.9499158d-08 /
      data fpppp(20, 7, 1,1),fpppp(20, 7, 1,2),fpppp(20, 7, 1,3)/
     x 2.3322547d-06,-3.5366788d-06, 1.5280326d-08 /
      data fpppp(20, 7, 2,1),fpppp(20, 7, 2,2),fpppp(20, 7, 2,3)/
     x 8.3883831d-05,-6.9954890d-06,-2.2414250d-08 /
      data fpppp(20, 7, 3,1),fpppp(20, 7, 3,2),fpppp(20, 7, 3,3)/
     x 4.3453864d-04,-1.4444169d-05,-1.0311406d-07 /
      data fpppp(20, 7, 4,1),fpppp(20, 7, 4,2),fpppp(20, 7, 4,3)/
     x 4.3453864d-04,-1.4379517d-05,-1.0324405d-07 /
      data fpppp(20, 7, 5,1),fpppp(20, 7, 5,2),fpppp(20, 7, 5,3)/
     x 8.3883831d-05,-7.2540979d-06,-2.1894270d-08 /
      data fpppp(20, 7, 6,1),fpppp(20, 7, 6,2),fpppp(20, 7, 6,3)/
     x 2.3322547d-06,-2.5668955d-06, 1.3330403d-08 /
      data fpppp(20, 7, 7,1),fpppp(20, 7, 7,2),fpppp(20, 7, 7,3)/
     x-4.4988653d-06, 9.1691290d-07, 3.7260184d-08 /
      data fpppp(20, 7, 8,1),fpppp(20, 7, 8,2),fpppp(20, 7, 8,3)/
     x-1.8509464d-05, 2.8683417d-06, 3.8314635d-08 /
      data fpppp(20, 7, 9,1),fpppp(20, 7, 9,2),fpppp(20, 7, 9,3)/
     x-2.1724828d-05, 4.2942971d-06, 2.8992153d-08 /
      data fpppp(20, 7,10,1),fpppp(20, 7,10,2),fpppp(20, 7,10,3)/
     x-1.7624083d-05, 6.4734587d-06, 2.5558428d-08 /
      data fpppp(20, 7,11,1),fpppp(20, 7,11,2),fpppp(20, 7,11,3)/
     x-1.3899115d-05, 7.7832087d-06, 2.5960931d-08 /
      data fpppp(20, 7,12,1),fpppp(20, 7,12,2),fpppp(20, 7,12,3)/
     x-1.0437813d-05, 8.3215049d-06, 2.5617849d-08 /
      data fpppp(20, 7,13,1),fpppp(20, 7,13,2),fpppp(20, 7,13,3)/
     x-1.0176024d-05, 8.1609180d-06, 2.3442128d-08 /
      data fpppp(20, 7,14,1),fpppp(20, 7,14,2),fpppp(20, 7,14,3)/
     x-1.4618527d-05, 7.5392294d-06, 2.0697731d-08 /
      data fpppp(20, 7,15,1),fpppp(20, 7,15,2),fpppp(20, 7,15,3)/
     x-1.6014246d-05, 7.6746560d-06, 2.3966873d-08 /
      data fpppp(20, 7,16,1),fpppp(20, 7,16,2),fpppp(20, 7,16,3)/
     x-1.2423295d-05, 6.6859916d-06, 3.2046719d-08 /
      data fpppp(20, 7,17,1),fpppp(20, 7,17,2),fpppp(20, 7,17,3)/
     x-3.4316135d-06, 7.2155298d-06, 3.2579399d-08 /
      data fpppp(20, 7,18,1),fpppp(20, 7,18,2),fpppp(20, 7,18,3)/
     x-6.8965705d-07, 7.7479026d-07, 1.2769398d-08 /
      data fpppp(20, 7,19,1),fpppp(20, 7,19,2),fpppp(20, 7,19,3)/
     x 7.1017838d-05,-4.9348276d-06,-1.4994574d-08 /
      data fpppp(20, 7,20,1),fpppp(20, 7,20,2),fpppp(20, 7,20,3)/
     x 3.7069290d-04,-2.1596587d-05,-9.9339155d-08 /
      data fpppp(20, 7,21,1),fpppp(20, 7,21,2),fpppp(20, 7,21,3)/
     x 3.7069290d-04,-2.1498523d-05,-9.8788673d-08 /
      data fpppp(20, 7,22,1),fpppp(20, 7,22,2),fpppp(20, 7,22,3)/
     x 7.1017838d-05,-5.3270813d-06,-1.7196504d-08 /
      data fpppp(20, 7,23,1),fpppp(20, 7,23,2),fpppp(20, 7,23,3)/
     x-6.8965705d-07, 2.2457418d-06, 2.1026637d-08 /
      data fpppp(20, 8, 1,1),fpppp(20, 8, 1,2),fpppp(20, 8, 1,3)/
     x 1.8149340d-06, 7.3113937d-05, 3.5870156d-09 /
      data fpppp(20, 8, 2,1),fpppp(20, 8, 2,2),fpppp(20, 8, 2,3)/
     x-6.8860048d-07, 3.7652501d-05,-1.5909172d-08 /
      data fpppp(20, 8, 3,1),fpppp(20, 8, 3,2),fpppp(20, 8, 3,3)/
     x-9.3755801d-05,-3.4749210d-05,-5.7858592d-08 /
      data fpppp(20, 8, 4,1),fpppp(20, 8, 4,2),fpppp(20, 8, 4,3)/
     x-9.3755801d-05,-4.1026605d-05,-5.7557813d-08 /
      data fpppp(20, 8, 5,1),fpppp(20, 8, 5,2),fpppp(20, 8, 5,3)/
     x-6.8860048d-07, 6.2762080d-05,-1.7112291d-08 /
      data fpppp(20, 8, 6,1),fpppp(20, 8, 6,2),fpppp(20, 8, 6,3)/
     x 1.8149340d-06,-2.1046987d-05, 8.0987115d-09 /
      data fpppp(20, 8, 7,1),fpppp(20, 8, 7,2),fpppp(20, 8, 7,3)/
     x-1.0960015d-05, 3.2051195d-06, 1.8499017d-08 /
      data fpppp(20, 8, 8,1),fpppp(20, 8, 8,2),fpppp(20, 8, 8,3)/
     x-1.7107046d-05,-3.1654910d-06, 1.8810764d-08 /
      data fpppp(20, 8, 9,1),fpppp(20, 8, 9,2),fpppp(20, 8, 9,3)/
     x-2.0265577d-05, 1.1453011d-06, 1.9881905d-08 /
      data fpppp(20, 8,10,1),fpppp(20, 8,10,2),fpppp(20, 8,10,3)/
     x-2.2711664d-05, 2.3230384d-06, 1.8544840d-08 /
      data fpppp(20, 8,11,1),fpppp(20, 8,11,2),fpppp(20, 8,11,3)/
     x-2.3511999d-05, 4.7106957d-06, 1.6359946d-08 /
      data fpppp(20, 8,12,1),fpppp(20, 8,12,2),fpppp(20, 8,12,3)/
     x-2.3133793d-05, 5.7924926d-06, 1.4479265d-08 /
      data fpppp(20, 8,13,1),fpppp(20, 8,13,2),fpppp(20, 8,13,3)/
     x-2.1388384d-05, 5.7699627d-06, 1.5142056d-08 /
      data fpppp(20, 8,14,1),fpppp(20, 8,14,2),fpppp(20, 8,14,3)/
     x-1.7758885d-05, 6.0548615d-06, 1.7469704d-08 /
      data fpppp(20, 8,15,1),fpppp(20, 8,15,2),fpppp(20, 8,15,3)/
     x-1.5000372d-05, 5.5206280d-06, 1.7022884d-08 /
      data fpppp(20, 8,16,1),fpppp(20, 8,16,2),fpppp(20, 8,16,3)/
     x-1.2048890d-05, 3.3413469d-06, 1.3746847d-08 /
      data fpppp(20, 8,17,1),fpppp(20, 8,17,2),fpppp(20, 8,17,3)/
     x-7.7253954d-06, 3.6829466d-06, 8.3246592d-09 /
      data fpppp(20, 8,18,1),fpppp(20, 8,18,2),fpppp(20, 8,18,3)/
     x 1.8915671d-06,-7.9518985d-07,-1.8525516d-09 /
      data fpppp(20, 8,19,1),fpppp(20, 8,19,2),fpppp(20, 8,19,3)/
     x-4.5183978d-06,-4.0630130d-06,-2.1548321d-08 /
      data fpppp(20, 8,20,1),fpppp(20, 8,20,2),fpppp(20, 8,20,3)/
     x-7.2561560d-05,-1.0524236d-05,-3.9500917d-08 /
      data fpppp(20, 8,21,1),fpppp(20, 8,21,2),fpppp(20, 8,21,3)/
     x-7.2561560d-05,-1.0536226d-05,-4.0038158d-08 /
      data fpppp(20, 8,22,1),fpppp(20, 8,22,2),fpppp(20, 8,22,3)/
     x-4.5183978d-06,-4.0150537d-06,-1.9399354d-08 /
      data fpppp(20, 8,23,1),fpppp(20, 8,23,2),fpppp(20, 8,23,3)/
     x 1.8915671d-06,-9.7503732d-07,-9.9111765d-09 /
      data fpppp(20, 9, 1,1),fpppp(20, 9, 1,2),fpppp(20, 9, 1,3)/
     x-1.0032050d-05, 8.3275777d-05, 3.7133024d-08 /
      data fpppp(20, 9, 2,1),fpppp(20, 9, 2,2),fpppp(20, 9, 2,3)/
     x 1.1430555d-07, 4.3873110d-05, 7.7281149d-09 /
      data fpppp(20, 9, 3,1),fpppp(20, 9, 3,2),fpppp(20, 9, 3,3)/
     x-9.8426704d-05,-3.6694754d-05,-5.4681685d-08 /
      data fpppp(20, 9, 4,1),fpppp(20, 9, 4,2),fpppp(20, 9, 4,3)/
     x-9.8426704d-05,-4.3460990d-05,-5.5732944d-08 /
      data fpppp(20, 9, 5,1),fpppp(20, 9, 5,2),fpppp(20, 9, 5,3)/
     x 1.1430555d-07, 7.0938054d-05, 1.1933149d-08 /
      data fpppp(20, 9, 6,1),fpppp(20, 9, 6,2),fpppp(20, 9, 6,3)/
     x-1.0032050d-05,-1.8217762d-05, 2.1364146d-08 /
      data fpppp(20, 9, 7,1),fpppp(20, 9, 7,2),fpppp(20, 9, 7,3)/
     x-1.2260404d-05, 3.6207908d-06, 1.7396457d-08 /
      data fpppp(20, 9, 8,1),fpppp(20, 9, 8,2),fpppp(20, 9, 8,3)/
     x-1.4185132d-05,-3.3826788d-06, 1.1062080d-08 /
      data fpppp(20, 9, 9,1),fpppp(20, 9, 9,2),fpppp(20, 9, 9,3)/
     x-1.6568430d-05,-1.1070808d-06, 6.6684337d-09 /
      data fpppp(20, 9,10,1),fpppp(20, 9,10,2),fpppp(20, 9,10,3)/
     x-1.8048866d-05,-1.6172964d-07, 6.0896194d-09 /
      data fpppp(20, 9,11,1),fpppp(20, 9,11,2),fpppp(20, 9,11,3)/
     x-1.7497017d-05, 2.3184754d-06, 7.3014530d-09 /
      data fpppp(20, 9,12,1),fpppp(20, 9,12,2),fpppp(20, 9,12,3)/
     x-1.6704222d-05, 3.5680994d-06, 8.3890171d-09 /
      data fpppp(20, 9,13,1),fpppp(20, 9,13,2),fpppp(20, 9,13,3)/
     x-1.5383835d-05, 4.2771274d-06, 8.3117820d-09 /
      data fpppp(20, 9,14,1),fpppp(20, 9,14,2),fpppp(20, 9,14,3)/
     x-1.3316710d-05, 4.2522033d-06, 7.6509904d-09 /
      data fpppp(20, 9,15,1),fpppp(20, 9,15,2),fpppp(20, 9,15,3)/
     x-1.0128572d-05, 4.4254907d-06, 7.7093020d-09 /
      data fpppp(20, 9,16,1),fpppp(20, 9,16,2),fpppp(20, 9,16,3)/
     x-6.6295376d-06, 2.1488707d-06, 6.7875119d-09 /
      data fpppp(20, 9,17,1),fpppp(20, 9,17,2),fpppp(20, 9,17,3)/
     x-1.9841735d-06, 2.5179127d-06, 3.7477753d-09 /
      data fpppp(20, 9,18,1),fpppp(20, 9,18,2),fpppp(20, 9,18,3)/
     x 1.1182083d-06,-6.0637209d-07,-3.2840579d-09 /
      data fpppp(20, 9,19,1),fpppp(20, 9,19,2),fpppp(20, 9,19,3)/
     x 9.3046491d-06,-2.6520519d-06,-1.1298490d-08 /
      data fpppp(20, 9,20,1),fpppp(20, 9,20,2),fpppp(20, 9,20,3)/
     x 3.3426512d-05,-5.9970721d-06,-1.7666924d-08 /
      data fpppp(20, 9,21,1),fpppp(20, 9,21,2),fpppp(20, 9,21,3)/
     x 3.3426512d-05,-6.0200786d-06,-1.7906283d-08 /
      data fpppp(20, 9,22,1),fpppp(20, 9,22,2),fpppp(20, 9,22,3)/
     x 9.3046491d-06,-2.5600258d-06,-1.0341054d-08 /
      data fpppp(20, 9,23,1),fpppp(20, 9,23,2),fpppp(20, 9,23,3)/
     x 1.1182083d-06,-9.5146963d-07,-6.8744435d-09 /
      data fpppp(20,10, 1,1),fpppp(20,10, 1,2),fpppp(20,10, 1,3)/
     x-2.7164228d-05,-2.2650125d-05, 7.4220410d-08 /
      data fpppp(20,10, 2,1),fpppp(20,10, 2,2),fpppp(20,10, 2,3)/
     x-1.2710749d-05,-1.4294214d-05, 3.2087671d-08 /
      data fpppp(20,10, 3,1),fpppp(20,10, 3,2),fpppp(20,10, 3,3)/
     x 1.9398025d-04, 1.9235688d-06,-5.6398020d-08 /
      data fpppp(20,10, 4,1),fpppp(20,10, 4,2),fpppp(20,10, 4,3)/
     x 1.9398025d-04, 4.8771146d-06,-5.9545830d-08 /
      data fpppp(20,10, 5,1),fpppp(20,10, 5,2),fpppp(20,10, 5,3)/
     x-1.2710749d-05,-2.6108397d-05, 4.4678909d-08 /
      data fpppp(20,10, 6,1),fpppp(20,10, 6,2),fpppp(20,10, 6,3)/
     x-2.7164228d-05, 2.1653061d-05, 2.7003267d-08 /
      data fpppp(20,10, 7,1),fpppp(20,10, 7,2),fpppp(20,10, 7,3)/
     x-2.2374083d-05,-3.2703543d-06, 1.1021690d-08 /
      data fpppp(20,10, 8,1),fpppp(20,10, 8,2),fpppp(20,10, 8,3)/
     x-1.6248480d-05,-2.2363180d-06, 1.7162114d-09 /
      data fpppp(20,10, 9,1),fpppp(20,10, 9,2),fpppp(20,10, 9,3)/
     x-1.2749348d-05,-2.9790952d-06, 5.9664594d-10 /
      data fpppp(20,10,10,1),fpppp(20,10,10,2),fpppp(20,10,10,3)/
     x-9.5648534d-06,-1.5222614d-06, 7.1224616d-10 /
      data fpppp(20,10,11,1),fpppp(20,10,11,2),fpppp(20,10,11,3)/
     x-1.0714486d-05, 4.8970924d-07, 2.4597025d-09 /
      data fpppp(20,10,12,1),fpppp(20,10,12,2),fpppp(20,10,12,3)/
     x-9.9539824d-06, 2.0181158d-06, 3.8872618d-09 /
      data fpppp(20,10,13,1),fpppp(20,10,13,2),fpppp(20,10,13,3)/
     x-8.7496536d-06, 3.4445941d-06, 4.4149761d-09 /
      data fpppp(20,10,14,1),fpppp(20,10,14,2),fpppp(20,10,14,3)/
     x-8.1487359d-06, 3.4015590d-06, 3.7870983d-09 /
      data fpppp(20,10,15,1),fpppp(20,10,15,2),fpppp(20,10,15,3)/
     x-6.8256184d-06, 3.1972594d-06, 2.5726914d-09 /
      data fpppp(20,10,16,1),fpppp(20,10,16,2),fpppp(20,10,16,3)/
     x-5.0220432d-06, 2.4537718d-06, 1.0712084d-09 /
      data fpppp(20,10,17,1),fpppp(20,10,17,2),fpppp(20,10,17,3)/
     x-3.6309319d-06, 1.0413318d-06,-4.2095684d-10 /
      data fpppp(20,10,18,1),fpppp(20,10,18,2),fpppp(20,10,18,3)/
     x-4.4936561d-07, 2.4324918d-07,-1.1985350d-09 /
      data fpppp(20,10,19,1),fpppp(20,10,19,2),fpppp(20,10,19,3)/
     x 4.8063845d-07,-1.5150116d-06,-3.7232477d-09 /
      data fpppp(20,10,20,1),fpppp(20,10,20,2),fpppp(20,10,20,3)/
     x-4.0868411d-06,-4.4240196d-06,-6.8619483d-09 /
      data fpppp(20,10,21,1),fpppp(20,10,21,2),fpppp(20,10,21,3)/
     x-4.0868411d-06,-4.4430413d-06,-6.9122640d-09 /
      data fpppp(20,10,22,1),fpppp(20,10,22,2),fpppp(20,10,22,3)/
     x 4.8063845d-07,-1.4389248d-06,-3.5219846d-09 /
      data fpppp(20,10,23,1),fpppp(20,10,23,2),fpppp(20,10,23,3)/
     x-4.4936561d-07,-4.2076276d-08,-1.9532717d-09 /
      data fpppp(20,11, 1,1),fpppp(20,11, 1,2),fpppp(20,11, 1,3)/
     x-1.0152042d-05, 1.1049705d-05, 2.0894281d-08 /
      data fpppp(20,11, 2,1),fpppp(20,11, 2,2),fpppp(20,11, 2,3)/
     x-2.5232315d-05, 1.6904043d-06, 7.0933122d-09 /
      data fpppp(20,11, 3,1),fpppp(20,11, 3,2),fpppp(20,11, 3,3)/
     x-3.2465884d-04,-1.9775169d-05,-2.2003624d-08 /
      data fpppp(20,11, 4,1),fpppp(20,11, 4,2),fpppp(20,11, 4,3)/
     x-3.2465884d-04,-1.7307793d-05,-2.2837619d-08 /
      data fpppp(20,11, 5,1),fpppp(20,11, 5,2),fpppp(20,11, 5,3)/
     x-2.5232315d-05,-8.1791013d-06, 1.0429295d-08 /
      data fpppp(20,11, 6,1),fpppp(20,11, 6,2),fpppp(20,11, 6,3)/
     x-1.0152042d-05, 4.8060351d-05, 8.3843477d-09 /
      data fpppp(20,11, 7,1),fpppp(20,11, 7,2),fpppp(20,11, 7,3)/
     x-1.2188361d-05,-3.5072093d-06, 7.9124479d-09 /
      data fpppp(20,11, 8,1),fpppp(20,11, 8,2),fpppp(20,11, 8,3)/
     x-1.0973671d-05,-5.3471203d-06, 3.0488458d-09 /
      data fpppp(20,11, 9,1),fpppp(20,11, 9,2),fpppp(20,11, 9,3)/
     x-8.4565165d-06,-4.1387368d-06, 1.8062315d-09 /
      data fpppp(20,11,10,1),fpppp(20,11,10,2),fpppp(20,11,10,3)/
     x-1.0248107d-05,-6.1395565d-06, 1.8806290d-09 /
      data fpppp(20,11,11,1),fpppp(20,11,11,2),fpppp(20,11,11,3)/
     x-6.9170501d-06, 7.9405023d-07, 7.2155586d-10 /
      data fpppp(20,11,12,1),fpppp(20,11,12,2),fpppp(20,11,12,3)/
     x-6.1585899d-06, 5.0136090d-07, 1.0754272d-09 /
      data fpppp(20,11,13,1),fpppp(20,11,13,2),fpppp(20,11,13,3)/
     x-5.8004376d-06, 2.2486238d-06, 1.5525287d-09 /
      data fpppp(20,11,14,1),fpppp(20,11,14,2),fpppp(20,11,14,3)/
     x-4.4509121d-06, 3.2958999d-06, 1.5702637d-09 /
      data fpppp(20,11,15,1),fpppp(20,11,15,2),fpppp(20,11,15,3)/
     x-3.8904365d-06, 2.5732864d-06, 6.3712731d-10 /
      data fpppp(20,11,16,1),fpppp(20,11,16,2),fpppp(20,11,16,3)/
     x-3.0967090d-06, 2.0626341d-06,-1.9077270d-10 /
      data fpppp(20,11,17,1),fpppp(20,11,17,2),fpppp(20,11,17,3)/
     x-2.3464740d-06, 1.1976291d-06,-5.0743355d-10 /
      data fpppp(20,11,18,1),fpppp(20,11,18,2),fpppp(20,11,18,3)/
     x-2.3841349d-06, 8.8338545d-08,-3.8943237d-10 /
      data fpppp(20,11,19,1),fpppp(20,11,19,2),fpppp(20,11,19,3)/
     x-1.6899655d-06,-1.1830819d-06, 3.0654881d-09 /
      data fpppp(20,11,20,1),fpppp(20,11,20,2),fpppp(20,11,20,3)/
     x-9.7214844d-09,-3.6944309d-06,-4.7536807d-09 /
      data fpppp(20,11,21,1),fpppp(20,11,21,2),fpppp(20,11,21,3)/
     x-9.7214844d-09,-3.6991520d-06,-4.4164718d-09 /
      data fpppp(20,11,22,1),fpppp(20,11,22,2),fpppp(20,11,22,3)/
     x-1.6899655d-06,-1.1641976d-06, 1.7166528d-09 /
      data fpppp(20,11,23,1),fpppp(20,11,23,2),fpppp(20,11,23,3)/
     x-2.3841349d-06, 1.7522229d-08, 4.6687000d-09 /
      data fpppp(20,12, 1,1),fpppp(20,12, 1,2),fpppp(20,12, 1,3)/
     x 2.6076881d-05,-1.4779179d-04,-1.2373378d-07 /
      data fpppp(20,12, 2,1),fpppp(20,12, 2,2),fpppp(20,12, 2,3)/
     x 5.3776402d-05,-8.6133477d-05,-6.3428429d-08 /
      data fpppp(20,12, 3,1),fpppp(20,12, 3,2),fpppp(20,12, 3,3)/
     x 4.9659092d-04, 3.6268907d-05, 6.2458798d-08 /
      data fpppp(20,12, 4,1),fpppp(20,12, 4,2),fpppp(20,12, 4,3)/
     x 4.9659092d-04, 5.3283412d-05, 6.8301217d-08 /
      data fpppp(20,12, 5,1),fpppp(20,12, 5,2),fpppp(20,12, 5,3)/
     x 5.3776402d-05,-1.5419150d-04,-8.6798105d-08 /
      data fpppp(20,12, 6,1),fpppp(20,12, 6,2),fpppp(20,12, 6,3)/
     x 2.6076881d-05, 1.0742578d-04,-3.6097494d-08 /
      data fpppp(20,12, 7,1),fpppp(20,12, 7,2),fpppp(20,12, 7,3)/
     x 1.1080360d-05,-8.1546750d-06,-6.8421194d-09 /
      data fpppp(20,12, 8,1),fpppp(20,12, 8,2),fpppp(20,12, 8,3)/
     x 1.6414498d-06,-3.8765186d-06, 8.7677921d-09 /
      data fpppp(20,12, 9,1),fpppp(20,12, 9,2),fpppp(20,12, 9,3)/
     x-2.1865966d-06,-1.1019131d-05, 9.2715197d-09 /
      data fpppp(20,12,10,1),fpppp(20,12,10,2),fpppp(20,12,10,3)/
     x-1.3074752d-06,-5.2976970d-06, 6.1934849d-09 /
      data fpppp(20,12,11,1),fpppp(20,12,11,2),fpppp(20,12,11,3)/
     x-3.6526981d-06,-2.0853541d-06, 3.0079940d-09 /
      data fpppp(20,12,12,1),fpppp(20,12,12,2),fpppp(20,12,12,3)/
     x-4.2357479d-06,-3.5764558d-07, 8.4710254d-10 /
      data fpppp(20,12,13,1),fpppp(20,12,13,2),fpppp(20,12,13,3)/
     x-3.5353098d-06, 1.7314869d-06, 6.7669620d-10 /
      data fpppp(20,12,14,1),fpppp(20,12,14,2),fpppp(20,12,14,3)/
     x-3.5995529d-06, 2.4145589d-06, 1.2862458d-10 /
      data fpppp(20,12,15,1),fpppp(20,12,15,2),fpppp(20,12,15,3)/
     x-3.2646591d-06, 2.3383449d-06, 2.9901090d-11 /
      data fpppp(20,12,16,1),fpppp(20,12,16,2),fpppp(20,12,16,3)/
     x-3.5679836d-06, 1.6662994d-06,-1.4930228d-10 /
      data fpppp(20,12,17,1),fpppp(20,12,17,2),fpppp(20,12,17,3)/
     x-3.3188289d-06, 9.5172805d-07,-9.5671823d-11 /
      data fpppp(20,12,18,1),fpppp(20,12,18,2),fpppp(20,12,18,3)/
     x-3.0800883d-06, 1.7587596d-07, 1.8290065d-10 /
      data fpppp(20,12,19,1),fpppp(20,12,19,2),fpppp(20,12,19,3)/
     x-3.4328175d-06,-1.3344575d-06, 7.0111342d-10 /
      data fpppp(20,12,20,1),fpppp(20,12,20,2),fpppp(20,12,20,3)/
     x-4.0447963d-06,-3.0865034d-06,-2.2923820d-10 /
      data fpppp(20,12,21,1),fpppp(20,12,21,2),fpppp(20,12,21,3)/
     x-4.0447963d-06,-3.1193853d-06,-1.8403044d-10 /
      data fpppp(20,12,22,1),fpppp(20,12,22,2),fpppp(20,12,22,3)/
     x-3.4328175d-06,-1.2029299d-06, 5.2028237d-10 /
      data fpppp(20,12,23,1),fpppp(20,12,23,2),fpppp(20,12,23,3)/
     x-3.0800883d-06,-3.1735257d-07, 8.6101709d-10 /
      data fpppp(20,13, 1,1),fpppp(20,13, 1,2),fpppp(20,13, 1,3)/
     x 2.8574425d-05, 9.5293703d-05,-1.5940541d-07 /
      data fpppp(20,13, 2,1),fpppp(20,13, 2,2),fpppp(20,13, 2,3)/
     x 2.6260729d-05, 4.0961848d-05,-6.9347087d-08 /
      data fpppp(20,13, 3,1),fpppp(20,13, 3,2),fpppp(20,13, 3,3)/
     x-2.5776033d-04,-7.4884470d-05, 1.2076465d-07 /
      data fpppp(20,13, 4,1),fpppp(20,13, 4,2),fpppp(20,13, 4,3)/
     x-2.5776033d-04,-7.5897870d-05, 1.2578783d-07 /
      data fpppp(20,13, 5,1),fpppp(20,13, 5,2),fpppp(20,13, 5,3)/
     x 2.6260729d-05, 4.5015446d-05,-8.9439810d-08 /
      data fpppp(20,13, 6,1),fpppp(20,13, 6,2),fpppp(20,13, 6,3)/
     x 2.8574425d-05, 8.0092708d-05,-8.4057705d-08 /
      data fpppp(20,13, 7,1),fpppp(20,13, 7,2),fpppp(20,13, 7,3)/
     x 2.3147195d-05, 1.4727013d-05,-4.2807697d-08 /
      data fpppp(20,13, 8,1),fpppp(20,13, 8,2),fpppp(20,13, 8,3)/
     x 1.3489468d-05,-4.5730717d-06,-3.1617727d-09 /
      data fpppp(20,13, 9,1),fpppp(20,13, 9,2),fpppp(20,13, 9,3)/
     x 4.9699933d-06,-1.1875888d-05, 9.8984514d-09 /
      data fpppp(20,13,10,1),fpppp(20,13,10,2),fpppp(20,13,10,3)/
     x 6.5482675d-07,-7.6589970d-06, 9.6241436d-09 /
      data fpppp(20,13,11,1),fpppp(20,13,11,2),fpppp(20,13,11,3)/
     x-7.9240904d-07,-3.0825563d-06, 6.4608578d-09 /
      data fpppp(20,13,12,1),fpppp(20,13,12,2),fpppp(20,13,12,3)/
     x-1.5841092d-06,-4.1066987d-07, 3.3598919d-09 /
      data fpppp(20,13,13,1),fpppp(20,13,13,2),fpppp(20,13,13,3)/
     x-2.5876088d-06, 6.3006336d-07, 6.7137981d-10 /
      data fpppp(20,13,14,1),fpppp(20,13,14,2),fpppp(20,13,14,3)/
     x-2.6171772d-06, 1.9709613d-06, 2.4873533d-10 /
      data fpppp(20,13,15,1),fpppp(20,13,15,2),fpppp(20,13,15,3)/
     x-2.8029449d-06, 1.5880155d-06,-2.6141438d-10 /
      data fpppp(20,13,16,1),fpppp(20,13,16,2),fpppp(20,13,16,3)/
     x-2.0810190d-06, 1.4818443d-06, 7.3215348d-11 /
      data fpppp(20,13,17,1),fpppp(20,13,17,2),fpppp(20,13,17,3)/
     x-3.2606923d-06, 6.3852146d-07, 3.7386949d-10 /
      data fpppp(20,13,18,1),fpppp(20,13,18,2),fpppp(20,13,18,3)/
     x-3.9080929d-06, 2.3476663d-08,-8.2398354d-11 /
      data fpppp(20,13,19,1),fpppp(20,13,19,2),fpppp(20,13,19,3)/
     x-3.8649293d-06,-1.4022654d-06,-2.0727780d-09 /
      data fpppp(20,13,20,1),fpppp(20,13,20,2),fpppp(20,13,20,3)/
     x-3.6250023d-06,-2.4270705d-06, 2.8222063d-09 /
      data fpppp(20,13,21,1),fpppp(20,13,21,2),fpppp(20,13,21,3)/
     x-3.6250023d-06,-2.4720467d-06, 2.6192931d-09 /
      data fpppp(20,13,22,1),fpppp(20,13,22,2),fpppp(20,13,22,3)/
     x-3.8649293d-06,-1.2223604d-06,-1.2611250d-09 /
      data fpppp(20,13,23,1),fpppp(20,13,23,2),fpppp(20,13,23,3)/
     x-3.9080929d-06,-6.5116708d-07,-3.1260970d-09 /
      data fpppp(20,14, 1,1),fpppp(20,14, 1,2),fpppp(20,14, 1,3)/
     x 1.4573084d-05, 4.5524077d-05,-5.9136579d-08 /
      data fpppp(20,14, 2,1),fpppp(20,14, 2,2),fpppp(20,14, 2,3)/
     x-1.2197124d-04, 1.2747224d-05,-1.3079188d-08 /
      data fpppp(20,14, 3,1),fpppp(20,14, 3,2),fpppp(20,14, 3,3)/
     x-3.3371414d-04,-5.8855938d-05, 8.5678466d-08 /
      data fpppp(20,14, 4,1),fpppp(20,14, 4,2),fpppp(20,14, 4,3)/
     x-3.3371414d-04,-5.6463603d-05, 8.5567788d-08 /
      data fpppp(20,14, 5,1),fpppp(20,14, 5,2),fpppp(20,14, 5,3)/
     x-1.2197124d-04, 3.1778841d-06,-1.2636478d-08 /
      data fpppp(20,14, 6,1),fpppp(20,14, 6,2),fpppp(20,14, 6,3)/
     x 1.4573084d-05, 8.1409101d-05,-6.0796742d-08 /
      data fpppp(20,14, 7,1),fpppp(20,14, 7,2),fpppp(20,14, 7,3)/
     x 2.6821254d-05, 2.1498485d-05,-5.0713051d-08 /
      data fpppp(20,14, 8,1),fpppp(20,14, 8,2),fpppp(20,14, 8,3)/
     x 2.0482579d-05, 5.7055323d-07,-2.1971813d-08 /
      data fpppp(20,14, 9,1),fpppp(20,14, 9,2),fpppp(20,14, 9,3)/
     x 1.4024371d-05,-9.9387985d-06,-2.5149192d-09 /
      data fpppp(20,14,10,1),fpppp(20,14,10,2),fpppp(20,14,10,3)/
     x 5.5307873d-06,-7.5468385d-06, 4.9194280d-09 /
      data fpppp(20,14,11,1),fpppp(20,14,11,2),fpppp(20,14,11,3)/
     x 2.3046979d-06,-3.2525661d-06, 5.7202200d-09 /
      data fpppp(20,14,12,1),fpppp(20,14,12,2),fpppp(20,14,12,3)/
     x 3.9824351d-07,-5.4197132d-07, 4.0972621d-09 /
      data fpppp(20,14,13,1),fpppp(20,14,13,2),fpppp(20,14,13,3)/
     x-4.5471567d-07, 5.0434159d-07, 2.2904107d-09 /
      data fpppp(20,14,14,1),fpppp(20,14,14,2),fpppp(20,14,14,3)/
     x-1.1405784d-06, 1.0009733d-06, 3.6199737d-10 /
      data fpppp(20,14,15,1),fpppp(20,14,15,2),fpppp(20,14,15,3)/
     x-1.6982199d-06, 1.8701078d-06, 2.2087723d-10 /
      data fpppp(20,14,16,1),fpppp(20,14,16,2),fpppp(20,14,16,3)/
     x-3.2615308d-06,-3.1902070d-07, 4.7039445d-10 /
      data fpppp(20,14,17,1),fpppp(20,14,17,2),fpppp(20,14,17,3)/
     x-2.4184439d-06, 1.1110136d-06, 5.3925883d-10 /
      data fpppp(20,14,18,1),fpppp(20,14,18,2),fpppp(20,14,18,3)/
     x-2.1220761d-06,-8.3350085d-08, 7.7647936d-10 /
      data fpppp(20,14,19,1),fpppp(20,14,19,2),fpppp(20,14,19,3)/
     x-2.7716381d-06,-1.2132052d-06, 1.3317873d-09 /
      data fpppp(20,14,20,1),fpppp(20,14,20,2),fpppp(20,14,20,3)/
     x-2.9353319d-06,-1.8270093d-06,-3.3652839d-10 /
      data fpppp(20,14,21,1),fpppp(20,14,21,2),fpppp(20,14,21,3)/
     x-2.9353319d-06,-1.8670448d-06,-2.7321248d-10 /
      data fpppp(20,14,22,1),fpppp(20,14,22,2),fpppp(20,14,22,3)/
     x-2.7716381d-06,-1.0530635d-06, 1.0785236d-09 /
      data fpppp(20,14,23,1),fpppp(20,14,23,2),fpppp(20,14,23,3)/
     x-2.1220761d-06,-6.8388165d-07, 1.7262180d-09 /
      data fpppp(20,15, 1,1),fpppp(20,15, 1,2),fpppp(20,15, 1,3)/
     x 2.3749029d-05,-2.0091222d-04, 7.0850083d-08 /
      data fpppp(20,15, 2,1),fpppp(20,15, 2,2),fpppp(20,15, 2,3)/
     x 2.5383668d-04,-1.1290555d-04, 4.3977135d-08 /
      data fpppp(20,15, 3,1),fpppp(20,15, 3,2),fpppp(20,15, 3,3)/
     x 5.8893042d-04, 6.6096301d-05,-1.1590053d-08 /
      data fpppp(20,15, 4,1),fpppp(20,15, 4,2),fpppp(20,15, 4,3)/
     x 5.8893042d-04, 8.2868067d-05,-1.5121029d-08 /
      data fpppp(20,15, 5,1),fpppp(20,15, 5,2),fpppp(20,15, 5,3)/
     x 2.5383668d-04,-1.7999261d-04, 5.8101038d-08 /
      data fpppp(20,15, 6,1),fpppp(20,15, 6,2),fpppp(20,15, 6,3)/
     x 2.3749029d-05, 5.0664276d-05, 1.7885445d-08 /
      data fpppp(20,15, 7,1),fpppp(20,15, 7,2),fpppp(20,15, 7,3)/
     x 1.7985035d-05, 1.7245872d-05,-1.2898507d-08 /
      data fpppp(20,15, 8,1),fpppp(20,15, 8,2),fpppp(20,15, 8,3)/
     x 1.4112475d-05, 5.1852899d-06,-2.3358119d-08 /
      data fpppp(20,15, 9,1),fpppp(20,15, 9,2),fpppp(20,15, 9,3)/
     x 1.2543011d-08,-4.4293200d-06,-1.6611787d-08 /
      data fpppp(20,15,10,1),fpppp(20,15,10,2),fpppp(20,15,10,3)/
     x 6.2246783d-06,-4.8204765d-06,-7.2826600d-09 /
      data fpppp(20,15,11,1),fpppp(20,15,11,2),fpppp(20,15,11,3)/
     x 3.5919472d-06,-2.3587364d-06,-1.2855072d-09 /
      data fpppp(20,15,12,1),fpppp(20,15,12,2),fpppp(20,15,12,3)/
     x 2.4595784d-06,-1.0839606d-07, 1.5269421d-09 /
      data fpppp(20,15,13,1),fpppp(20,15,13,2),fpppp(20,15,13,3)/
     x 9.0270917d-07, 6.3295417d-07, 1.5672170d-09 /
      data fpppp(20,15,14,1),fpppp(20,15,14,2),fpppp(20,15,14,3)/
     x-2.3876619d-07, 5.0648192d-07, 1.6264344d-09 /
      data fpppp(20,15,15,1),fpppp(20,15,15,2),fpppp(20,15,15,3)/
     x-7.7142599d-07, 9.6138044d-07, 9.6502903d-10 /
      data fpppp(20,15,16,1),fpppp(20,15,16,2),fpppp(20,15,16,3)/
     x-2.6978437d-07, 8.7212980d-08, 6.1355341d-10 /
      data fpppp(20,15,17,1),fpppp(20,15,17,2),fpppp(20,15,17,3)/
     x-7.6336148d-07, 6.7470450d-07, 7.2858538d-10 /
      data fpppp(20,15,18,1),fpppp(20,15,18,2),fpppp(20,15,18,3)/
     x-1.4039289d-06,-5.6366540d-07, 8.1017362d-10 /
      data fpppp(20,15,19,1),fpppp(20,15,19,2),fpppp(20,15,19,3)/
     x-8.6980480d-07,-5.3985295d-07,-2.4863196d-10 /
      data fpppp(20,15,20,1),fpppp(20,15,20,2),fpppp(20,15,20,3)/
     x-9.2674231d-07,-1.2414532d-06,-4.1274163d-10 /
      data fpppp(20,15,21,1),fpppp(20,15,21,2),fpppp(20,15,21,3)/
     x-9.2674231d-07,-1.2247811d-06,-4.5936605d-10 /
      data fpppp(20,15,22,1),fpppp(20,15,22,2),fpppp(20,15,22,3)/
     x-8.6980480d-07,-6.0654141d-07,-6.2134288d-11 /
      data fpppp(20,15,23,1),fpppp(20,15,23,2),fpppp(20,15,23,3)/
     x-1.4039289d-06,-3.1358366d-07, 1.1080736d-10 /
      data fpppp(20,16, 1,1),fpppp(20,16, 1,2),fpppp(20,16, 1,3)/
     x-8.7052793d-06,-2.0861319d-04, 9.1326475d-08 /
      data fpppp(20,16, 2,1),fpppp(20,16, 2,2),fpppp(20,16, 2,3)/
     x-2.8966369d-04,-1.2351015d-04, 4.1940196d-08 /
      data fpppp(20,16, 3,1),fpppp(20,16, 3,2),fpppp(20,16, 3,3)/
     x-3.6049060d-04, 4.7077797d-05,-6.2666670d-08 /
      data fpppp(20,16, 4,1),fpppp(20,16, 4,2),fpppp(20,16, 4,3)/
     x-3.6049060d-04, 6.7685309d-05,-6.4803201d-08 /
      data fpppp(20,16, 5,1),fpppp(20,16, 5,2),fpppp(20,16, 5,3)/
     x-2.8966369d-04,-2.0594020d-04, 5.0486321d-08 /
      data fpppp(20,16, 6,1),fpppp(20,16, 6,2),fpppp(20,16, 6,3)/
     x-8.7052793d-06, 1.0049949d-04, 5.9278506d-08 /
      data fpppp(20,16, 7,1),fpppp(20,16, 7,2),fpppp(20,16, 7,3)/
     x-3.1078387d-05, 3.1171450d-06, 2.8958910d-08 /
      data fpppp(20,16, 8,1),fpppp(20,16, 8,2),fpppp(20,16, 8,3)/
     x-1.1476716d-05,-3.2189471d-07,-2.1465781d-09 /
      data fpppp(20,16, 9,1),fpppp(20,16, 9,2),fpppp(20,16, 9,3)/
     x 1.3941392d-05, 1.6231371d-05,-1.4606288d-08 /
      data fpppp(20,16,10,1),fpppp(20,16,10,2),fpppp(20,16,10,3)/
     x 1.6901574d-06,-1.1033495d-05,-1.3924495d-08 /
      data fpppp(20,16,11,1),fpppp(20,16,11,2),fpppp(20,16,11,3)/
     x 2.8201396d-06, 2.4106472d-06,-8.5470079d-09 /
      data fpppp(20,16,12,1),fpppp(20,16,12,2),fpppp(20,16,12,3)/
     x 2.1758964d-06,-6.9079671d-07,-4.2740570d-09 /
      data fpppp(20,16,13,1),fpppp(20,16,13,2),fpppp(20,16,13,3)/
     x 2.3908408d-06, 1.1645974d-06,-5.5435626d-10 /
      data fpppp(20,16,14,1),fpppp(20,16,14,2),fpppp(20,16,14,3)/
     x 1.7690945d-06, 4.0782541d-07, 5.4160207d-10 /
      data fpppp(20,16,15,1),fpppp(20,16,15,2),fpppp(20,16,15,3)/
     x 1.2927112d-06, 7.7512973d-07, 1.4767359d-09 /
      data fpppp(20,16,16,1),fpppp(20,16,16,2),fpppp(20,16,16,3)/
     x 5.7378877d-07, 9.6702233d-08, 1.2751379d-09 /
      data fpppp(20,16,17,1),fpppp(20,16,17,2),fpppp(20,16,17,3)/
     x 3.6938146d-07, 4.2934629d-08, 4.6968629d-10 /
      data fpppp(20,16,18,1),fpppp(20,16,18,2),fpppp(20,16,18,3)/
     x 1.1278096d-06,-3.7238257d-08,-5.1006642d-10 /
      data fpppp(20,16,19,1),fpppp(20,16,19,2),fpppp(20,16,19,3)/
     x 1.3213482d-06,-5.1006249d-07,-1.0089757d-09 /
      data fpppp(20,16,20,1),fpppp(20,16,20,2),fpppp(20,16,20,3)/
     x 1.9056848d-06,-5.7597250d-07,-2.7274728d-10 /
      data fpppp(20,16,21,1),fpppp(20,16,21,2),fpppp(20,16,21,3)/
     x 1.9056848d-06,-5.9695665d-07,-3.1273854d-10 /
      data fpppp(20,16,22,1),fpppp(20,16,22,2),fpppp(20,16,22,3)/
     x 1.3213482d-06,-4.2612587d-07,-8.4901067d-10 /
      data fpppp(20,16,23,1),fpppp(20,16,23,2),fpppp(20,16,23,3)/
     x 1.1278096d-06,-3.5200061d-07,-1.1099353d-09 /
      data fpppp(20,17, 1,1),fpppp(20,17, 1,2),fpppp(20,17, 1,3)/
     x-1.1374268d-04,-7.7463321d-06, 2.3030040d-08 /
      data fpppp(20,17, 2,1),fpppp(20,17, 2,2),fpppp(20,17, 2,3)/
     x 1.0790971d-04,-2.2671417d-06, 2.8100339d-09 /
      data fpppp(20,17, 3,1),fpppp(20,17, 3,2),fpppp(20,17, 3,3)/
     x 1.0511974d-04, 1.3190712d-05,-4.0641104d-08 /
      data fpppp(20,17, 4,1),fpppp(20,17, 4,2),fpppp(20,17, 4,3)/
     x 1.0511974d-04, 6.6864324d-06,-4.0426636d-08 /
      data fpppp(20,17, 5,1),fpppp(20,17, 5,2),fpppp(20,17, 5,3)/
     x 1.0790971d-04, 2.3749975d-05, 1.9521641d-09 /
      data fpppp(20,17, 6,1),fpppp(20,17, 6,2),fpppp(20,17, 6,3)/
     x-1.1374268d-04,-1.0531052d-04, 2.6247052d-08 /
      data fpppp(20,17, 7,1),fpppp(20,17, 7,2),fpppp(20,17, 7,3)/
     x-2.5266409d-05, 7.7057855d-05, 3.0718290d-08 /
      data fpppp(20,17, 8,1),fpppp(20,17, 8,2),fpppp(20,17, 8,3)/
     x-2.2293789d-05,-1.8174696d-05, 1.8876213d-08 /
      data fpppp(20,17, 9,1),fpppp(20,17, 9,2),fpppp(20,17, 9,3)/
     x-2.2926095d-05, 7.6385483d-06, 5.5343885d-09 /
      data fpppp(20,17,10,1),fpppp(20,17,10,2),fpppp(20,17,10,3)/
     x-5.7332880d-06,-4.2703151d-07,-2.7009374d-09 /
      data fpppp(20,17,11,1),fpppp(20,17,11,2),fpppp(20,17,11,3)/
     x-1.6896179d-06, 6.8648365d-07,-5.9776031d-09 /
      data fpppp(20,17,12,1),fpppp(20,17,12,2),fpppp(20,17,12,3)/
     x 1.0525688d-06, 9.8348682d-07,-5.3045700d-09 /
      data fpppp(20,17,13,1),fpppp(20,17,13,2),fpppp(20,17,13,3)/
     x 1.9558692d-06, 3.3641446d-07,-4.0032269d-09 /
      data fpppp(20,17,14,1),fpppp(20,17,14,2),fpppp(20,17,14,3)/
     x 3.0792124d-06, 7.8046296d-07,-1.7452472d-09 /
      data fpppp(20,17,15,1),fpppp(20,17,15,2),fpppp(20,17,15,3)/
     x 3.4610293d-06, 5.1227024d-07,-6.8891955d-10 /
      data fpppp(20,17,16,1),fpppp(20,17,16,2),fpppp(20,17,16,3)/
     x 3.9443212d-06, 1.0695227d-07,-9.3912463d-11 /
      data fpppp(20,17,17,1),fpppp(20,17,17,2),fpppp(20,17,17,3)/
     x 4.2572848d-06, 3.7724400d-07, 4.8845654d-11 /
      data fpppp(20,17,18,1),fpppp(20,17,18,2),fpppp(20,17,18,3)/
     x 4.1658195d-06,-7.5966598d-08,-2.5480541d-10 /
      data fpppp(20,17,19,1),fpppp(20,17,19,2),fpppp(20,17,19,3)/
     x 4.2277761d-06,-1.1717377d-07,-7.1205147d-10 /
      data fpppp(20,17,20,1),fpppp(20,17,20,2),fpppp(20,17,20,3)/
     x 3.9005884d-06,-2.1474318d-07,-7.8502654d-10 /
      data fpppp(20,17,21,1),fpppp(20,17,21,2),fpppp(20,17,21,3)/
     x 3.9005884d-06,-2.1453787d-07,-8.0511472d-10 /
      data fpppp(20,17,22,1),fpppp(20,17,22,2),fpppp(20,17,22,3)/
     x 4.2277761d-06,-1.1799501d-07,-6.3169875d-10 /
      data fpppp(20,17,23,1),fpppp(20,17,23,2),fpppp(20,17,23,3)/
     x 4.1658195d-06,-7.2886932d-08,-5.5612814d-10 /
      data fpppp(20,18, 1,1),fpppp(20,18, 1,2),fpppp(20,18, 1,3)/
     x 4.0209604d-05,-7.3218891d-07, 3.9678610d-09 /
      data fpppp(20,18, 2,1),fpppp(20,18, 2,2),fpppp(20,18, 2,3)/
     x-1.6290733d-05,-8.4272535d-07,-2.8793261d-09 /
      data fpppp(20,18, 3,1),fpppp(20,18, 3,2),fpppp(20,18, 3,3)/
     x-3.8661296d-05,-1.0774699d-06,-1.7587434d-08 /
      data fpppp(20,18, 4,1),fpppp(20,18, 4,2),fpppp(20,18, 4,3)/
     x-3.8661296d-05,-1.0811786d-06,-1.7525196d-08 /
      data fpppp(20,18, 5,1),fpppp(20,18, 5,2),fpppp(20,18, 5,3)/
     x-1.6290733d-05,-8.2789063d-07,-3.1282778d-09 /
      data fpppp(20,18, 6,1),fpppp(20,18, 6,2),fpppp(20,18, 6,3)/
     x 4.0209604d-05,-7.8781913d-07, 4.9014298d-09 /
      data fpppp(20,18, 7,1),fpppp(20,18, 7,2),fpppp(20,18, 7,3)/
     x-4.2191953d-06, 1.8974218d-07, 8.7686554d-09 /
      data fpppp(20,18, 8,1),fpppp(20,18, 8,2),fpppp(20,18, 8,3)/
     x-5.6128468d-06,-1.2960272d-07, 8.9506846d-09 /
      data fpppp(20,18, 9,1),fpppp(20,18, 9,2),fpppp(20,18, 9,3)/
     x-4.2768425d-06, 3.8935995d-07, 7.3521683d-09 /
      data fpppp(20,18,10,1),fpppp(20,18,10,2),fpppp(20,18,10,3)/
     x-5.1351921d-06, 3.4375408d-07, 4.9255477d-09 /
      data fpppp(20,18,11,1),fpppp(20,18,11,2),fpppp(20,18,11,3)/
     x-3.5392611d-06, 2.0034481d-07, 2.8247734d-09 /
      data fpppp(20,18,12,1),fpppp(20,18,12,2),fpppp(20,18,12,3)/
     x-1.9269285d-06, 5.7759192d-07, 1.1056214d-09 /
      data fpppp(20,18,13,1),fpppp(20,18,13,2),fpppp(20,18,13,3)/
     x-1.7944827d-07, 2.2971108d-07, 1.0677248d-10 /
      data fpppp(20,18,14,1),fpppp(20,18,14,2),fpppp(20,18,14,3)/
     x 1.4345472d-06, 2.5735608d-07,-5.3193282d-10 /
      data fpppp(20,18,15,1),fpppp(20,18,15,2),fpppp(20,18,15,3)/
     x 3.2218826d-06, 4.6350676d-07,-8.1528830d-10 /
      data fpppp(20,18,16,1),fpppp(20,18,16,2),fpppp(20,18,16,3)/
     x 4.7430365d-06, 5.3742116d-08,-1.0312460d-09 /
      data fpppp(20,18,17,1),fpppp(20,18,17,2),fpppp(20,18,17,3)/
     x 6.1391895d-06, 4.5949942d-07,-1.2838066d-09 /
      data fpppp(20,18,18,1),fpppp(20,18,18,2),fpppp(20,18,18,3)/
     x 7.2318120d-06,-1.4300979d-09,-1.6240033d-09 /
      data fpppp(20,18,19,1),fpppp(20,18,19,2),fpppp(20,18,19,3)/
     x 8.1368038d-06,-6.4122636d-08,-1.6309152d-09 /
      data fpppp(20,18,20,1),fpppp(20,18,20,2),fpppp(20,18,20,3)/
     x 8.9947240d-06, 1.7972066d-07,-1.7214679d-09 /
      data fpppp(20,18,21,1),fpppp(20,18,21,2),fpppp(20,18,21,3)/
     x 8.9947240d-06, 1.7134315d-07,-1.7197901d-09 /
      data fpppp(20,18,22,1),fpppp(20,18,22,2),fpppp(20,18,22,3)/
     x 8.1368038d-06,-3.0612621d-08,-1.6376265d-09 /
      data fpppp(20,18,23,1),fpppp(20,18,23,2),fpppp(20,18,23,3)/
     x 7.2318120d-06,-1.2709265d-07,-1.5988360d-09 /
      data fpppp(20,19, 1,1),fpppp(20,19, 1,2),fpppp(20,19, 1,3)/
     x 1.2016484d-04,-3.9901253d-19,-2.9161248d-08 /
      data fpppp(20,19, 2,1),fpppp(20,19, 2,2),fpppp(20,19, 2,3)/
     x 8.5870635d-06,-7.1755364d-20,-1.8123201d-08 /
      data fpppp(20,19, 3,1),fpppp(20,19, 3,2),fpppp(20,19, 3,3)/
     x-8.3305102d-06, 6.4204469d-20, 5.1724913d-09 /
      data fpppp(20,19, 4,1),fpppp(20,19, 4,2),fpppp(20,19, 4,3)/
     x-8.3305102d-06, 4.6623332d-20, 5.7977078d-09 /
      data fpppp(20,19, 5,1),fpppp(20,19, 5,2),fpppp(20,19, 5,3)/
     x 8.5870635d-06, 1.5804824d-21,-2.0624067d-08 /
      data fpppp(20,19, 6,1),fpppp(20,19, 6,2),fpppp(20,19, 6,3)/
     x 1.2016484d-04, 5.2829066d-20,-1.9783002d-08 /
      data fpppp(20,19, 7,1),fpppp(20,19, 7,2),fpppp(20,19, 7,3)/
     x 1.2475094d-05,-5.8310003d-20,-6.4069749d-09 /
      data fpppp(20,19, 8,1),fpppp(20,19, 8,2),fpppp(20,19, 8,3)/
     x 3.2115199d-06, 7.3923681d-20, 7.8675330d-09 /
      data fpppp(20,19, 9,1),fpppp(20,19, 9,2),fpppp(20,19, 9,3)/
     x-1.4895155d-06,-2.2314757d-20, 1.4405062d-08 /
      data fpppp(20,19,10,1),fpppp(20,19,10,2),fpppp(20,19,10,3)/
     x-6.8289652d-06, 8.3643175d-20, 1.3579768d-08 /
      data fpppp(20,19,11,1),fpppp(20,19,11,2),fpppp(20,19,11,3)/
     x-6.1489369d-06, 2.4691649d-20, 9.8463009d-09 /
      data fpppp(20,19,12,1),fpppp(20,19,12,2),fpppp(20,19,12,3)/
     x-4.3760916d-06, 1.3328342d-19, 5.3898972d-09 /
      data fpppp(20,19,13,1),fpppp(20,19,13,2),fpppp(20,19,13,3)/
     x-1.8289527d-06, 9.6565522d-20, 2.0570947d-09 /
      data fpppp(20,19,14,1),fpppp(20,19,14,2),fpppp(20,19,14,3)/
     x 6.3410573d-07, 6.7784559d-20,-3.1866519d-10 /
      data fpppp(20,19,15,1),fpppp(20,19,15,2),fpppp(20,19,15,3)/
     x 3.6705829d-06, 6.6726682d-20,-1.5243104d-09 /
      data fpppp(20,19,16,1),fpppp(20,19,16,2),fpppp(20,19,16,3)/
     x 6.2765567d-06,-8.9604313d-20,-2.0919272d-09 /
      data fpppp(20,19,17,1),fpppp(20,19,17,2),fpppp(20,19,17,3)/
     x 8.5942366d-06, 3.3157941d-20,-2.3559412d-09 /
      data fpppp(20,19,18,1),fpppp(20,19,18,2),fpppp(20,19,18,3)/
     x 1.0289809d-05, 4.7937092d-20,-2.5290701d-09 /
      data fpppp(20,19,19,1),fpppp(20,19,19,2),fpppp(20,19,19,3)/
     x 1.1759374d-05, 2.5988030d-21,-2.2024110d-09 /
      data fpppp(20,19,20,1),fpppp(20,19,20,2),fpppp(20,19,20,3)/
     x 1.3203365d-05, 3.9743624d-21,-2.5367201d-09 /
      data fpppp(20,19,21,1),fpppp(20,19,21,2),fpppp(20,19,21,3)/
     x 1.3203365d-05,-7.9978052d-21,-2.5138085d-09 /
      data fpppp(20,19,22,1),fpppp(20,19,22,2),fpppp(20,19,22,3)/
     x 1.1759374d-05, 1.0512654d-19,-2.2940572d-09 /
      data fpppp(20,19,23,1),fpppp(20,19,23,2),fpppp(20,19,23,3)/
     x 1.0289809d-05, 1.5248358d-19,-2.1853968d-09 /
      data fpppp(21, 1, 1,1),fpppp(21, 1, 1,2),fpppp(21, 1, 1,3)/
     x 1.0832001d-03, 8.3710598d-18, 6.2999988d-07 /
      data fpppp(21, 1, 2,1),fpppp(21, 1, 2,2),fpppp(21, 1, 2,3)/
     x 2.1311593d-04, 5.9120374d-19, 1.8884734d-07 /
      data fpppp(21, 1, 3,1),fpppp(21, 1, 3,2),fpppp(21, 1, 3,3)/
     x 6.5363440d-06,-4.6977416d-18,-7.4149747d-07 /
      data fpppp(21, 1, 4,1),fpppp(21, 1, 4,2),fpppp(21, 1, 4,3)/
     x 6.5363440d-06,-7.6783358d-19,-7.6771609d-07 /
      data fpppp(21, 1, 5,1),fpppp(21, 1, 5,2),fpppp(21, 1, 5,3)/
     x 2.1311593d-04, 2.1576636d-18, 2.9372180d-07 /
      data fpppp(21, 1, 6,1),fpppp(21, 1, 6,2),fpppp(21, 1, 6,3)/
     x 1.0832001d-03,-3.7421958d-19, 2.3672065d-07 /
      data fpppp(21, 1, 7,1),fpppp(21, 1, 7,2),fpppp(21, 1, 7,3)/
     x 1.9362616d-03,-1.2539058d-18, 2.2683633d-07 /
      data fpppp(21, 1, 8,1),fpppp(21, 1, 8,2),fpppp(21, 1, 8,3)/
     x 2.3469427d-03, 3.8461963d-18, 1.5434658d-07 /
      data fpppp(21, 1, 9,1),fpppp(21, 1, 9,2),fpppp(21, 1, 9,3)/
     x 2.4520379d-03, 5.6813186d-19, 1.0502326d-07 /
      data fpppp(21, 1,10,1),fpppp(21, 1,10,2),fpppp(21, 1,10,3)/
     x 2.5775280d-03, 4.6720710d-18, 6.4614528d-08 /
      data fpppp(21, 1,11,1),fpppp(21, 1,11,2),fpppp(21, 1,11,3)/
     x 2.5822446d-03,-6.7297113d-18, 3.6316186d-08 /
      data fpppp(21, 1,12,1),fpppp(21, 1,12,2),fpppp(21, 1,12,3)/
     x 2.6924120d-03, 4.6695053d-19, 2.6217495d-08 /
      data fpppp(21, 1,13,1),fpppp(21, 1,13,2),fpppp(21, 1,13,3)/
     x 2.7317374d-03,-4.9587889d-18, 3.8574039d-08 /
      data fpppp(21, 1,14,1),fpppp(21, 1,14,2),fpppp(21, 1,14,3)/
     x 2.5883402d-03, 3.4183928d-18, 6.8137391d-08 /
      data fpppp(21, 1,15,1),fpppp(21, 1,15,2),fpppp(21, 1,15,3)/
     x 2.4763005d-03, 2.9106729d-18, 1.1035545d-07 /
      data fpppp(21, 1,16,1),fpppp(21, 1,16,2),fpppp(21, 1,16,3)/
     x 2.3964247d-03, 3.2243703d-18, 1.5861013d-07 /
      data fpppp(21, 1,17,1),fpppp(21, 1,17,2),fpppp(21, 1,17,3)/
     x 2.0251229d-03,-5.1297413d-18, 2.3090219d-07 /
      data fpppp(21, 1,18,1),fpppp(21, 1,18,2),fpppp(21, 1,18,3)/
     x 1.2238746d-03, 2.8607480d-18, 2.3522003d-07 /
      data fpppp(21, 1,19,1),fpppp(21, 1,19,2),fpppp(21, 1,19,3)/
     x-3.0374506d-04,-1.0581436d-18, 3.4437202d-07 /
      data fpppp(21, 1,20,1),fpppp(21, 1,20,2),fpppp(21, 1,20,3)/
     x-2.3991397d-04, 3.0131125d-18,-7.9819819d-07 /
      data fpppp(21, 1,21,1),fpppp(21, 1,21,2),fpppp(21, 1,21,3)/
     x-2.3991397d-04, 1.5522659d-18,-7.6770682d-07 /
      data fpppp(21, 1,22,1),fpppp(21, 1,22,2),fpppp(21, 1,22,3)/
     x-3.0374506d-04,-1.4626355d-18, 2.2240656d-07 /
      data fpppp(21, 1,23,1),fpppp(21, 1,23,2),fpppp(21, 1,23,3)/
     x 1.2238746d-03, 1.0682030d-17, 6.9259050d-07 /
      data fpppp(21, 2, 1,1),fpppp(21, 2, 1,2),fpppp(21, 2, 1,3)/
     x 7.2145562d-04, 9.2544213d-04, 2.6249487d-07 /
      data fpppp(21, 2, 2,1),fpppp(21, 2, 2,2),fpppp(21, 2, 2,3)/
     x 2.2100026d-04, 4.2786193d-04, 1.0195605d-07 /
      data fpppp(21, 2, 3,1),fpppp(21, 2, 3,2),fpppp(21, 2, 3,3)/
     x-9.5442600d-05,-6.0631031d-04,-2.3598263d-07 /
      data fpppp(21, 2, 4,1),fpppp(21, 2, 4,2),fpppp(21, 2, 4,3)/
     x-9.5442600d-05,-6.6243464d-04,-2.4661049d-07 /
      data fpppp(21, 2, 5,1),fpppp(21, 2, 5,2),fpppp(21, 2, 5,3)/
     x 2.2100026d-04, 6.5235921d-04, 1.4446752d-07 /
      data fpppp(21, 2, 6,1),fpppp(21, 2, 6,2),fpppp(21, 2, 6,3)/
     x 7.2145562d-04, 8.3577314d-05, 1.0307687d-07 /
      data fpppp(21, 2, 7,1),fpppp(21, 2, 7,2),fpppp(21, 2, 7,3)/
     x 1.1556783d-03, 1.1906906d-04, 8.5783509d-08 /
      data fpppp(21, 2, 8,1),fpppp(21, 2, 8,2),fpppp(21, 2, 8,3)/
     x 1.3636004d-03, 1.1061037d-04, 4.6004004d-08 /
      data fpppp(21, 2, 9,1),fpppp(21, 2, 9,2),fpppp(21, 2, 9,3)/
     x 1.4162064d-03,-4.2436825d-05, 1.7028652d-08 /
      data fpppp(21, 2,10,1),fpppp(21, 2,10,2),fpppp(21, 2,10,3)/
     x 1.4781268d-03, 6.5732716d-05,-5.4468995d-09 /
      data fpppp(21, 2,11,1),fpppp(21, 2,11,2),fpppp(21, 2,11,3)/
     x 1.4810026d-03,-5.0295810d-05,-1.9756169d-08 /
      data fpppp(21, 2,12,1),fpppp(21, 2,12,2),fpppp(21, 2,12,3)/
     x 1.5347255d-03, 2.5482015d-05,-2.4421960d-08 /
      data fpppp(21, 2,13,1),fpppp(21, 2,13,2),fpppp(21, 2,13,3)/
     x 1.5529828d-03, 5.8529831d-05,-1.8396397d-08 /
      data fpppp(21, 2,14,1),fpppp(21, 2,14,2),fpppp(21, 2,14,3)/
     x 1.4814229d-03,-1.1231478d-05,-3.1745310d-09 /
      data fpppp(21, 2,15,1),fpppp(21, 2,15,2),fpppp(21, 2,15,3)/
     x 1.4249699d-03,-3.2277421d-05, 2.0456412d-08 /
      data fpppp(21, 2,16,1),fpppp(21, 2,16,2),fpppp(21, 2,16,3)/
     x 1.3836123d-03, 1.2961078d-04, 4.9370221d-08 /
      data fpppp(21, 2,17,1),fpppp(21, 2,17,2),fpppp(21, 2,17,3)/
     x 1.1942781d-03,-1.1236919d-06, 8.9186396d-08 /
      data fpppp(21, 2,18,1),fpppp(21, 2,18,2),fpppp(21, 2,18,3)/
     x 7.8785102d-04, 4.8787577d-04, 1.0402637d-07 /
      data fpppp(21, 2,19,1),fpppp(21, 2,19,2),fpppp(21, 2,19,3)/
     x-3.2490279d-05, 8.4387871d-05, 1.6493948d-07 /
      data fpppp(21, 2,20,1),fpppp(21, 2,20,2),fpppp(21, 2,20,3)/
     x-1.8822174d-04,-4.6841564d-04,-2.6058415d-07 /
      data fpppp(21, 2,21,1),fpppp(21, 2,21,2),fpppp(21, 2,21,3)/
     x-1.8822174d-04,-4.7532289d-04,-2.4826655d-07 /
      data fpppp(21, 2,22,1),fpppp(21, 2,22,2),fpppp(21, 2,22,3)/
     x-3.2490279d-05, 1.1201691d-04, 1.1566907d-07 /
      data fpppp(21, 2,23,1),fpppp(21, 2,23,2),fpppp(21, 2,23,3)/
     x 7.8785102d-04, 3.8426688d-04, 2.8879039d-07 /
      data fpppp(21, 3, 1,1),fpppp(21, 3, 1,2),fpppp(21, 3, 1,3)/
     x 5.4044064d-04, 1.5341314d-03,-2.6983203d-07 /
      data fpppp(21, 3, 2,1),fpppp(21, 3, 2,2),fpppp(21, 3, 2,3)/
     x 5.6000125d-04, 7.6891005d-04,-1.4006225d-08 /
      data fpppp(21, 3, 3,1),fpppp(21, 3, 3,2),fpppp(21, 3, 3,3)/
     x-1.0871876d-03,-8.1580747d-04, 5.2581932d-07 /
      data fpppp(21, 3, 4,1),fpppp(21, 3, 4,2),fpppp(21, 3, 4,3)/
     x-1.0871876d-03,-9.1213192d-04, 5.4047138d-07 /
      data fpppp(21, 3, 5,1),fpppp(21, 3, 5,2),fpppp(21, 3, 5,3)/
     x 5.6000125d-04, 1.1542079d-03,-7.2614492d-08 /
      data fpppp(21, 3, 6,1),fpppp(21, 3, 6,2),fpppp(21, 3, 6,3)/
     x 5.4044064d-04, 8.9264592d-05,-5.0051031d-08 /
      data fpppp(21, 3, 7,1),fpppp(21, 3, 7,2),fpppp(21, 3, 7,3)/
     x 1.2958896d-04, 2.6964397d-05,-1.1157617d-07 /
      data fpppp(21, 3, 8,1),fpppp(21, 3, 8,2),fpppp(21, 3, 8,3)/
     x-3.1441973d-05, 4.6043576d-05,-1.1555646d-07 /
      data fpppp(21, 3, 9,1),fpppp(21, 3, 9,2),fpppp(21, 3, 9,3)/
     x-9.0674043d-05, 1.9575305d-06,-1.2235660d-07 /
      data fpppp(21, 3,10,1),fpppp(21, 3,10,2),fpppp(21, 3,10,3)/
     x-1.5839709d-04, 8.4795375d-06,-1.2999814d-07 /
      data fpppp(21, 3,11,1),fpppp(21, 3,11,2),fpppp(21, 3,11,3)/
     x-1.6694811d-04, 6.7406231d-06,-1.3674794d-07 /
      data fpppp(21, 3,12,1),fpppp(21, 3,12,2),fpppp(21, 3,12,3)/
     x-2.2136783d-04, 7.5914870d-06,-1.3909273d-07 /
      data fpppp(21, 3,13,1),fpppp(21, 3,13,2),fpppp(21, 3,13,3)/
     x-2.3984304d-04, 6.4577135d-06,-1.3703971d-07 /
      data fpppp(21, 3,14,1),fpppp(21, 3,14,2),fpppp(21, 3,14,3)/
     x-1.7043164d-04, 9.2126312d-06,-1.2939116d-07 /
      data fpppp(21, 3,15,1),fpppp(21, 3,15,2),fpppp(21, 3,15,3)/
     x-1.1262829d-04,-4.7819025d-07,-1.2104227d-07 /
      data fpppp(21, 3,16,1),fpppp(21, 3,16,2),fpppp(21, 3,16,3)/
     x-6.7875481d-05, 5.0734431d-05,-1.1165444d-07 /
      data fpppp(21, 3,17,1),fpppp(21, 3,17,2),fpppp(21, 3,17,3)/
     x 8.2673434d-05,-9.9120272d-06,-1.0509288d-07 /
      data fpppp(21, 3,18,1),fpppp(21, 3,18,2),fpppp(21, 3,18,3)/
     x 4.8485978d-04, 1.6821658d-04,-3.9941645d-08 /
      data fpppp(21, 3,19,1),fpppp(21, 3,19,2),fpppp(21, 3,19,3)/
     x 7.9724065d-04, 9.3474672d-04,-9.8580237d-08 /
      data fpppp(21, 3,20,1),fpppp(21, 3,20,2),fpppp(21, 3,20,3)/
     x-7.3976941d-04,-7.9268110d-04, 5.4707211d-07 /
      data fpppp(21, 3,21,1),fpppp(21, 3,21,2),fpppp(21, 3,21,3)/
     x-7.3976941d-04,-7.1802937d-04, 5.2998620d-07 /
      data fpppp(21, 3,22,1),fpppp(21, 3,22,2),fpppp(21, 3,22,3)/
     x 7.9724065d-04, 6.3613980d-04,-3.0236625d-08 /
      data fpppp(21, 3,23,1),fpppp(21, 3,23,2),fpppp(21, 3,23,3)/
     x 4.8485978d-04, 1.2879925d-03,-2.9623019d-07 /
      data fpppp(21, 4, 1,1),fpppp(21, 4, 1,2),fpppp(21, 4, 1,3)/
     x-2.7312749d-04, 2.3641713d-04,-2.2528232d-07 /
      data fpppp(21, 4, 2,1),fpppp(21, 4, 2,2),fpppp(21, 4, 2,3)/
     x-2.5990604d-04, 8.6968952d-05,-2.8220023d-08 /
      data fpppp(21, 4, 3,1),fpppp(21, 4, 3,2),fpppp(21, 4, 3,3)/
     x 1.0352486d-03,-2.2799629d-04, 3.9061641d-07 /
      data fpppp(21, 4, 4,1),fpppp(21, 4, 4,2),fpppp(21, 4, 4,3)/
     x 1.0352486d-03,-2.3723777d-04, 3.9663626d-07 /
      data fpppp(21, 4, 5,1),fpppp(21, 4, 5,2),fpppp(21, 4, 5,3)/
     x-2.5990604d-04, 1.2393487d-04,-5.2299435d-08 /
      data fpppp(21, 4, 6,1),fpppp(21, 4, 6,2),fpppp(21, 4, 6,3)/
     x-2.7312749d-04, 9.7794943d-05,-1.3498452d-07 /
      data fpppp(21, 4, 7,1),fpppp(21, 4, 7,2),fpppp(21, 4, 7,3)/
     x-3.7229160d-05, 7.3331948d-05,-1.1186184d-07 /
      data fpppp(21, 4, 8,1),fpppp(21, 4, 8,2),fpppp(21, 4, 8,3)/
     x 1.4465672d-05, 1.3523698d-05,-9.0854312d-08 /
      data fpppp(21, 4, 9,1),fpppp(21, 4, 9,2),fpppp(21, 4, 9,3)/
     x 5.1116580d-05, 1.6527490d-05,-8.1874594d-08 /
      data fpppp(21, 4,10,1),fpppp(21, 4,10,2),fpppp(21, 4,10,3)/
     x 8.5008669d-05, 1.1068762d-05,-6.3835035d-08 /
      data fpppp(21, 4,11,1),fpppp(21, 4,11,2),fpppp(21, 4,11,3)/
     x 9.8581535d-05, 1.1555997d-05,-4.0521753d-08 /
      data fpppp(21, 4,12,1),fpppp(21, 4,12,2),fpppp(21, 4,12,3)/
     x 1.1696255d-04, 1.0923299d-05,-2.9653892d-08 /
      data fpppp(21, 4,13,1),fpppp(21, 4,13,2),fpppp(21, 4,13,3)/
     x 1.1658026d-04, 1.1266427d-05,-3.9827957d-08 /
      data fpppp(21, 4,14,1),fpppp(21, 4,14,2),fpppp(21, 4,14,3)/
     x 8.4994070d-05, 1.1436411d-05,-6.3441313d-08 /
      data fpppp(21, 4,15,1),fpppp(21, 4,15,2),fpppp(21, 4,15,3)/
     x 5.1709997d-05, 1.4298375d-05,-8.1942210d-08 /
      data fpppp(21, 4,16,1),fpppp(21, 4,16,2),fpppp(21, 4,16,3)/
     x 1.6000651d-05, 1.8637029d-05,-9.1432454d-08 /
      data fpppp(21, 4,17,1),fpppp(21, 4,17,2),fpppp(21, 4,17,3)/
     x-4.6271700d-05, 5.9851299d-05,-1.1539997d-07 /
      data fpppp(21, 4,18,1),fpppp(21, 4,18,2),fpppp(21, 4,18,3)/
     x-2.8374451d-04, 1.0182819d-04,-1.3919944d-07 /
      data fpppp(21, 4,19,1),fpppp(21, 4,19,2),fpppp(21, 4,19,3)/
     x-3.2769496d-04, 1.1385693d-04,-6.7794838d-08 /
      data fpppp(21, 4,20,1),fpppp(21, 4,20,2),fpppp(21, 4,20,3)/
     x 8.2002258d-04,-2.2650872d-04, 4.0958060d-07 /
      data fpppp(21, 4,21,1),fpppp(21, 4,21,2),fpppp(21, 4,21,3)/
     x 8.2002258d-04,-2.1839799d-04, 4.0239528d-07 /
      data fpppp(21, 4,22,1),fpppp(21, 4,22,2),fpppp(21, 4,22,3)/
     x-3.2769496d-04, 8.1414011d-05,-3.9053585d-08 /
      data fpppp(21, 4,23,1),fpppp(21, 4,23,2),fpppp(21, 4,23,3)/
     x-2.8374451d-04, 2.2348914d-04,-2.4697914d-07 /
      data fpppp(21, 5, 1,1),fpppp(21, 5, 1,2),fpppp(21, 5, 1,3)/
     x 6.0475409d-05, 8.3349497d-05, 2.1589742d-07 /
      data fpppp(21, 5, 2,1),fpppp(21, 5, 2,2),fpppp(21, 5, 2,3)/
     x 1.0318678d-04, 2.2753737d-05, 1.0033408d-07 /
      data fpppp(21, 5, 3,1),fpppp(21, 5, 3,2),fpppp(21, 5, 3,3)/
     x-1.6472914d-04,-1.0537943d-04,-1.4213212d-07 /
      data fpppp(21, 5, 4,1),fpppp(21, 5, 4,2),fpppp(21, 5, 4,3)/
     x-1.6472914d-04,-1.0838049d-04,-1.5117883d-07 /
      data fpppp(21, 5, 5,1),fpppp(21, 5, 5,2),fpppp(21, 5, 5,3)/
     x 1.0318678d-04, 3.4757999d-05, 1.3652094d-07 /
      data fpppp(21, 5, 6,1),fpppp(21, 5, 6,2),fpppp(21, 5, 6,3)/
     x 6.0475409d-05, 3.8333515d-05, 8.0196675d-08 /
      data fpppp(21, 5, 7,1),fpppp(21, 5, 7,2),fpppp(21, 5, 7,3)/
     x-1.2218753d-05, 2.5775754d-05, 2.4404589d-08 /
      data fpppp(21, 5, 8,1),fpppp(21, 5, 8,2),fpppp(21, 5, 8,3)/
     x-4.4315668d-06, 1.8178686d-05,-6.9181147d-09 /
      data fpppp(21, 5, 9,1),fpppp(21, 5, 9,2),fpppp(21, 5, 9,3)/
     x 5.8160051d-07, 1.5170875d-05,-4.5187869d-09 /
      data fpppp(21, 5,10,1),fpppp(21, 5,10,2),fpppp(21, 5,10,3)/
     x-1.8989802d-06, 1.3169425d-05, 2.4051502d-09 /
      data fpppp(21, 5,11,1),fpppp(21, 5,11,2),fpppp(21, 5,11,3)/
     x-6.0244129d-06, 1.0502466d-05,-1.7787726d-09 /
      data fpppp(21, 5,12,1),fpppp(21, 5,12,2),fpppp(21, 5,12,3)/
     x-1.2517939d-05, 9.2151079d-06,-6.2236748d-09 /
      data fpppp(21, 5,13,1),fpppp(21, 5,13,2),fpppp(21, 5,13,3)/
     x-1.1719682d-05, 1.0287135d-05,-1.5068355d-09 /
      data fpppp(21, 5,14,1),fpppp(21, 5,14,2),fpppp(21, 5,14,3)/
     x-3.1007700d-06, 1.2743849d-05, 2.8818722d-09 /
      data fpppp(21, 5,15,1),fpppp(21, 5,15,2),fpppp(21, 5,15,3)/
     x-4.9386426d-08, 1.4561217d-05,-4.5523609d-09 /
      data fpppp(21, 5,16,1),fpppp(21, 5,16,2),fpppp(21, 5,16,3)/
     x-2.4497017d-06, 1.7307521d-05,-9.8073196d-09 /
      data fpppp(21, 5,17,1),fpppp(21, 5,17,2),fpppp(21, 5,17,3)/
     x 1.3619051d-06, 2.6812778d-05, 1.7542559d-08 /
      data fpppp(21, 5,18,1),fpppp(21, 5,18,2),fpppp(21, 5,18,3)/
     x 7.5725105d-05, 3.7266500d-05, 6.5731814d-08 /
      data fpppp(21, 5,19,1),fpppp(21, 5,19,2),fpppp(21, 5,19,3)/
     x 1.3216703d-04, 5.4824844d-05, 1.3918017d-07 /
      data fpppp(21, 5,20,1),fpppp(21, 5,20,2),fpppp(21, 5,20,3)/
     x-1.3834532d-04,-1.1926707d-04,-1.4202922d-07 /
      data fpppp(21, 5,21,1),fpppp(21, 5,21,2),fpppp(21, 5,21,3)/
     x-1.3834532d-04,-1.1457713d-04,-1.3231343d-07 /
      data fpppp(21, 5,22,1),fpppp(21, 5,22,2),fpppp(21, 5,22,3)/
     x 1.3216703d-04, 3.6065115d-05, 1.0031699d-07 /
      data fpppp(21, 5,23,1),fpppp(21, 5,23,2),fpppp(21, 5,23,3)/
     x 7.5725105d-05, 1.0761548d-04, 2.1146873d-07 /
      data fpppp(21, 6, 1,1),fpppp(21, 6, 1,2),fpppp(21, 6, 1,3)/
     x-2.7021492d-05, 6.1298247d-06, 2.3944853d-08 /
      data fpppp(21, 6, 2,1),fpppp(21, 6, 2,2),fpppp(21, 6, 2,3)/
     x 1.2766984d-05,-6.8393115d-06,-1.6330745d-08 /
      data fpppp(21, 6, 3,1),fpppp(21, 6, 3,2),fpppp(21, 6, 3,3)/
     x 1.7568656d-04,-3.4544077d-05,-1.0248233d-07 /
      data fpppp(21, 6, 4,1),fpppp(21, 6, 4,2),fpppp(21, 6, 4,3)/
     x 1.7568656d-04,-3.4694998d-05,-1.0275054d-07 /
      data fpppp(21, 6, 5,1),fpppp(21, 6, 5,2),fpppp(21, 6, 5,3)/
     x 1.2766984d-05,-6.2356264d-06,-1.5257898d-08 /
      data fpppp(21, 6, 6,1),fpppp(21, 6, 6,2),fpppp(21, 6, 6,3)/
     x-2.7021492d-05, 3.8660056d-06, 1.9921677d-08 /
      data fpppp(21, 6, 7,1),fpppp(21, 6, 7,2),fpppp(21, 6, 7,3)/
     x-1.7902914d-05, 8.1562976d-06, 3.2941623d-08 /
      data fpppp(21, 6, 8,1),fpppp(21, 6, 8,2),fpppp(21, 6, 8,3)/
     x-1.4561557d-05, 1.0037481d-05, 3.8170344d-08 /
      data fpppp(21, 6, 9,1),fpppp(21, 6, 9,2),fpppp(21, 6, 9,3)/
     x-9.9586586d-06, 1.0183831d-05, 3.5117306d-08 /
      data fpppp(21, 6,10,1),fpppp(21, 6,10,2),fpppp(21, 6,10,3)/
     x-5.8453155d-06, 9.3646304d-06, 2.3460605d-08 /
      data fpppp(21, 6,11,1),fpppp(21, 6,11,2),fpppp(21, 6,11,3)/
     x-2.3583880d-06, 9.1761467d-06, 1.6604594d-08 /
      data fpppp(21, 6,12,1),fpppp(21, 6,12,2),fpppp(21, 6,12,3)/
     x 4.6259711d-07, 9.1733651d-06, 1.5391416d-08 /
      data fpppp(21, 6,13,1),fpppp(21, 6,13,2),fpppp(21, 6,13,3)/
     x-7.4026890d-07, 9.2948194d-06, 1.5356250d-08 /
      data fpppp(21, 6,14,1),fpppp(21, 6,14,2),fpppp(21, 6,14,3)/
     x-4.9781809d-06, 9.4806057d-06, 2.0467196d-08 /
      data fpppp(21, 6,15,1),fpppp(21, 6,15,2),fpppp(21, 6,15,3)/
     x-7.4610079d-06, 1.0906902d-05, 3.0357215d-08 /
      data fpppp(21, 6,16,1),fpppp(21, 6,16,2),fpppp(21, 6,16,3)/
     x-1.0052657d-05, 1.1876436d-05, 3.2686115d-08 /
      data fpppp(21, 6,17,1),fpppp(21, 6,17,2),fpppp(21, 6,17,3)/
     x-1.3725142d-05, 1.1301572d-05, 2.8126647d-08 /
      data fpppp(21, 6,18,1),fpppp(21, 6,18,2),fpppp(21, 6,18,3)/
     x-2.2560925d-05, 8.5397412d-06, 1.9980163d-08 /
      data fpppp(21, 6,19,1),fpppp(21, 6,19,2),fpppp(21, 6,19,3)/
     x 1.0268727d-05,-1.5715773d-06,-8.4146724d-09 /
      data fpppp(21, 6,20,1),fpppp(21, 6,20,2),fpppp(21, 6,20,3)/
     x 1.7652350d-04,-4.1127018d-05,-1.0073639d-07 /
      data fpppp(21, 6,21,1),fpppp(21, 6,21,2),fpppp(21, 6,21,3)/
     x 1.7652350d-04,-4.0730758d-05,-1.0003914d-07 /
      data fpppp(21, 6,22,1),fpppp(21, 6,22,2),fpppp(21, 6,22,3)/
     x 1.0268727d-05,-3.1566192d-06,-1.1203653d-08 /
      data fpppp(21, 6,23,1),fpppp(21, 6,23,2),fpppp(21, 6,23,3)/
     x-2.2560925d-05, 1.4483648d-05, 3.0438841d-08 /
      data fpppp(21, 7, 1,1),fpppp(21, 7, 1,2),fpppp(21, 7, 1,3)/
     x 9.7345910d-06,-3.4865780d-06, 4.5082405d-09 /
      data fpppp(21, 7, 2,1),fpppp(21, 7, 2,2),fpppp(21, 7, 2,3)/
     x 2.5080306d-05,-6.0699535d-06,-2.1001248d-08 /
      data fpppp(21, 7, 3,1),fpppp(21, 7, 3,2),fpppp(21, 7, 3,3)/
     x-3.4332967d-07,-1.1633861d-05,-7.5763026d-08 /
      data fpppp(21, 7, 4,1),fpppp(21, 7, 4,2),fpppp(21, 7, 4,3)/
     x-3.4332967d-07,-1.1584681d-05,-7.5590493d-08 /
      data fpppp(21, 7, 5,1),fpppp(21, 7, 5,2),fpppp(21, 7, 5,3)/
     x 2.5080306d-05,-6.2666712d-06,-2.1691379d-08 /
      data fpppp(21, 7, 6,1),fpppp(21, 7, 6,2),fpppp(21, 7, 6,3)/
     x 9.7345910d-06,-2.7488866d-06, 7.0962347d-09 /
      data fpppp(21, 7, 7,1),fpppp(21, 7, 7,2),fpppp(21, 7, 7,3)/
     x-9.1669773d-06, 2.5336076d-07, 2.6072474d-08 /
      data fpppp(21, 7, 8,1),fpppp(21, 7, 8,2),fpppp(21, 7, 8,3)/
     x-1.8675833d-05, 1.9427610d-06, 2.7482896d-08 /
      data fpppp(21, 7, 9,1),fpppp(21, 7, 9,2),fpppp(21, 7, 9,3)/
     x-2.1909994d-05, 3.8411707d-06, 2.3101381d-08 /
      data fpppp(21, 7,10,1),fpppp(21, 7,10,2),fpppp(21, 7,10,3)/
     x-2.1224913d-05, 5.4030890d-06, 2.2379008d-08 /
      data fpppp(21, 7,11,1),fpppp(21, 7,11,2),fpppp(21, 7,11,3)/
     x-1.9355056d-05, 6.8666921d-06, 2.2522263d-08 /
      data fpppp(21, 7,12,1),fpppp(21, 7,12,2),fpppp(21, 7,12,3)/
     x-1.8424332d-05, 7.2499123d-06, 2.1343959d-08 /
      data fpppp(21, 7,13,1),fpppp(21, 7,13,2),fpppp(21, 7,13,3)/
     x-1.8081799d-05, 7.4206664d-06, 2.0296178d-08 /
      data fpppp(21, 7,14,1),fpppp(21, 7,14,2),fpppp(21, 7,14,3)/
     x-1.8077287d-05, 6.9688695d-06, 1.8826024d-08 /
      data fpppp(21, 7,15,1),fpppp(21, 7,15,2),fpppp(21, 7,15,3)/
     x-1.8124739d-05, 6.5292442d-06, 1.9322434d-08 /
      data fpppp(21, 7,16,1),fpppp(21, 7,16,2),fpppp(21, 7,16,3)/
     x-1.4726089d-05, 6.1463287d-06, 2.3410449d-08 /
      data fpppp(21, 7,17,1),fpppp(21, 7,17,2),fpppp(21, 7,17,3)/
     x-6.2108354d-06, 4.7149794d-06, 2.3241564d-08 /
      data fpppp(21, 7,18,1),fpppp(21, 7,18,2),fpppp(21, 7,18,3)/
     x 9.0749340d-06, 1.0824669d-06, 6.5571036d-09 /
      data fpppp(21, 7,19,1),fpppp(21, 7,19,2),fpppp(21, 7,19,3)/
     x 2.1782060d-05,-5.8087160d-06,-1.8050478d-08 /
      data fpppp(21, 7,20,1),fpppp(21, 7,20,2),fpppp(21, 7,20,3)/
     x 3.1840332d-06,-1.7452528d-05,-7.2318810d-08 /
      data fpppp(21, 7,21,1),fpppp(21, 7,21,2),fpppp(21, 7,21,3)/
     x 3.1840332d-06,-1.7521708d-05,-7.2284745d-08 /
      data fpppp(21, 7,22,1),fpppp(21, 7,22,2),fpppp(21, 7,22,3)/
     x 2.1782060d-05,-5.5319937d-06,-1.8186739d-08 /
      data fpppp(21, 7,23,1),fpppp(21, 7,23,2),fpppp(21, 7,23,3)/
     x 9.0749340d-06, 4.4758342d-08, 7.0680816d-09 /
      data fpppp(21, 8, 1,1),fpppp(21, 8, 1,2),fpppp(21, 8, 1,3)/
     x 3.0523036d-06,-1.4501791d-05, 2.3191442d-09 /
      data fpppp(21, 8, 2,1),fpppp(21, 8, 2,2),fpppp(21, 8, 2,3)/
     x 1.5286015d-05,-9.4041601d-06,-1.2678182d-08 /
      data fpppp(21, 8, 3,1),fpppp(21, 8, 3,2),fpppp(21, 8, 3,3)/
     x 3.9318364d-05, 9.4175866d-07,-4.4946851d-08 /
      data fpppp(21, 8, 4,1),fpppp(21, 8, 4,2),fpppp(21, 8, 4,3)/
     x 3.9318364d-05, 1.9525176d-06,-4.4716656d-08 /
      data fpppp(21, 8, 5,1),fpppp(21, 8, 5,2),fpppp(21, 8, 5,3)/
     x 1.5286015d-05,-1.3447196d-05,-1.3598964d-08 /
      data fpppp(21, 8, 6,1),fpppp(21, 8, 6,2),fpppp(21, 8, 6,3)/
     x 3.0523036d-06, 6.5959309d-07, 5.7720752d-09 /
      data fpppp(21, 8, 7,1),fpppp(21, 8, 7,2),fpppp(21, 8, 7,3)/
     x-6.1323719d-06,-2.8609069d-06, 1.3356097d-08 /
      data fpppp(21, 8, 8,1),fpppp(21, 8, 8,2),fpppp(21, 8, 8,3)/
     x-1.2634779d-05,-8.5410930d-07, 1.4828921d-08 /
      data fpppp(21, 8, 9,1),fpppp(21, 8, 9,2),fpppp(21, 8, 9,3)/
     x-1.6876956d-05, 1.3898965d-07, 1.5886166d-08 /
      data fpppp(21, 8,10,1),fpppp(21, 8,10,2),fpppp(21, 8,10,3)/
     x-1.9598439d-05, 2.2898846d-06, 1.4816538d-08 /
      data fpppp(21, 8,11,1),fpppp(21, 8,11,2),fpppp(21, 8,11,3)/
     x-2.1157672d-05, 3.7983532d-06, 1.3084658d-08 /
      data fpppp(21, 8,12,1),fpppp(21, 8,12,2),fpppp(21, 8,12,3)/
     x-2.1288992d-05, 4.5190972d-06, 1.1606348d-08 /
      data fpppp(21, 8,13,1),fpppp(21, 8,13,2),fpppp(21, 8,13,3)/
     x-1.9604708d-05, 4.9738364d-06, 1.2066333d-08 /
      data fpppp(21, 8,14,1),fpppp(21, 8,14,2),fpppp(21, 8,14,3)/
     x-1.6453415d-05, 4.6350791d-06, 1.4065921d-08 /
      data fpppp(21, 8,15,1),fpppp(21, 8,15,2),fpppp(21, 8,15,3)/
     x-1.2302865d-05, 4.5589668d-06, 1.4356895d-08 /
      data fpppp(21, 8,16,1),fpppp(21, 8,16,2),fpppp(21, 8,16,3)/
     x-8.5048886d-06, 3.9317693d-06, 1.1659493d-08 /
      data fpppp(21, 8,17,1),fpppp(21, 8,17,2),fpppp(21, 8,17,3)/
     x-4.1889227d-06, 1.5623814d-06, 5.9536321d-09 /
      data fpppp(21, 8,18,1),fpppp(21, 8,18,2),fpppp(21, 8,18,3)/
     x 1.6464373d-06,-1.8817696d-07,-2.2621211d-09 /
      data fpppp(21, 8,19,1),fpppp(21, 8,19,2),fpppp(21, 8,19,3)/
     x 1.0321253d-05,-4.0360537d-06,-1.7375779d-08 /
      data fpppp(21, 8,20,1),fpppp(21, 8,20,2),fpppp(21, 8,20,3)/
     x 2.6633464d-05,-8.1619642d-06,-3.1285378d-08 /
      data fpppp(21, 8,21,1),fpppp(21, 8,21,2),fpppp(21, 8,21,3)/
     x 2.6633464d-05,-8.2532198d-06,-3.1694675d-08 /
      data fpppp(21, 8,22,1),fpppp(21, 8,22,2),fpppp(21, 8,22,3)/
     x 1.0321253d-05,-3.6710312d-06,-1.5738593d-08 /
      data fpppp(21, 8,23,1),fpppp(21, 8,23,2),fpppp(21, 8,23,3)/
     x 1.6464373d-06,-1.5570113d-06,-8.4015672d-09 /
      data fpppp(21, 9, 1,1),fpppp(21, 9, 1,2),fpppp(21, 9, 1,3)/
     x-3.4808348d-06,-9.8723231d-06, 2.4496810d-08 /
      data fpppp(21, 9, 2,1),fpppp(21, 9, 2,2),fpppp(21, 9, 2,3)/
     x 4.4486135d-06,-6.4167976d-06, 3.7907216d-09 /
      data fpppp(21, 9, 3,1),fpppp(21, 9, 3,2),fpppp(21, 9, 3,3)/
     x 3.3853881d-05, 4.8743517d-07,-4.0238176d-08 /
      data fpppp(21, 9, 4,1),fpppp(21, 9, 4,2),fpppp(21, 9, 4,3)/
     x 3.3853881d-05, 1.3632484d-06,-4.0835438d-08 /
      data fpppp(21, 9, 5,1),fpppp(21, 9, 5,2),fpppp(21, 9, 5,3)/
     x 4.4486135d-06,-9.9200506d-06, 6.1797682d-09 /
      data fpppp(21, 9, 6,1),fpppp(21, 9, 6,2),fpppp(21, 9, 6,3)/
     x-3.4808348d-06, 3.2648756d-06, 1.5537886d-08 /
      data fpppp(21, 9, 7,1),fpppp(21, 9, 7,2),fpppp(21, 9, 7,3)/
     x-7.6891013d-06,-1.1085823d-06, 1.4160920d-08 /
      data fpppp(21, 9, 8,1),fpppp(21, 9, 8,2),fpppp(21, 9, 8,3)/
     x-1.1055367d-05,-1.3503620d-06, 8.3678717d-09 /
      data fpppp(21, 9, 9,1),fpppp(21, 9, 9,2),fpppp(21, 9, 9,3)/
     x-1.3467473d-05,-1.3624842d-06, 4.2303723d-09 /
      data fpppp(21, 9,10,1),fpppp(21, 9,10,2),fpppp(21, 9,10,3)/
     x-1.4059670d-05,-1.0483800d-07, 5.0827235d-09 /
      data fpppp(21, 9,11,1),fpppp(21, 9,11,2),fpppp(21, 9,11,3)/
     x-1.4425911d-05, 1.7151134d-06, 5.7511531d-09 /
      data fpppp(21, 9,12,1),fpppp(21, 9,12,2),fpppp(21, 9,12,3)/
     x-1.3703247d-05, 2.9908288d-06, 7.2545656d-09 /
      data fpppp(21, 9,13,1),fpppp(21, 9,13,2),fpppp(21, 9,13,3)/
     x-1.2925348d-05, 3.4611822d-06, 6.8507692d-09 /
      data fpppp(21, 9,14,1),fpppp(21, 9,14,2),fpppp(21, 9,14,3)/
     x-1.1820744d-05, 3.2187562d-06, 5.7972585d-09 /
      data fpppp(21, 9,15,1),fpppp(21, 9,15,2),fpppp(21, 9,15,3)/
     x-9.6756385d-06, 2.9702072d-06, 5.6098416d-09 /
      data fpppp(21, 9,16,1),fpppp(21, 9,16,2),fpppp(21, 9,16,3)/
     x-5.9991229d-06, 2.8408924d-06, 5.2651855d-09 /
      data fpppp(21, 9,17,1),fpppp(21, 9,17,2),fpppp(21, 9,17,3)/
     x-1.9744683d-06, 1.0702346d-06, 3.1296178d-09 /
      data fpppp(21, 9,18,1),fpppp(21, 9,18,2),fpppp(21, 9,18,3)/
     x 2.2441006d-06,-1.8230166d-07,-2.4850676d-09 /
      data fpppp(21, 9,19,1),fpppp(21, 9,19,2),fpppp(21, 9,19,3)/
     x 5.4926165d-06,-2.2207938d-06,-8.9663248d-09 /
      data fpppp(21, 9,20,1),fpppp(21, 9,20,2),fpppp(21, 9,20,3)/
     x 5.1339971d-06,-4.6810162d-06,-1.3763561d-08 /
      data fpppp(21, 9,21,1),fpppp(21, 9,21,2),fpppp(21, 9,21,3)/
     x 5.1339971d-06,-4.7232815d-06,-1.3964948d-08 /
      data fpppp(21, 9,22,1),fpppp(21, 9,22,2),fpppp(21, 9,22,3)/
     x 5.4926165d-06,-2.0517327d-06,-8.1607779d-09 /
      data fpppp(21, 9,23,1),fpppp(21, 9,23,2),fpppp(21, 9,23,3)/
     x 2.2441006d-06,-8.1628066d-07,-5.5058685d-09 /
      data fpppp(21,10, 1,1),fpppp(21,10, 1,2),fpppp(21,10, 1,3)/
     x-1.4946597d-05, 2.8597716d-05, 4.3576902d-08 /
      data fpppp(21,10, 2,1),fpppp(21,10, 2,2),fpppp(21,10, 2,3)/
     x-9.6997466d-06, 1.3464925d-05, 1.7458720d-08 /
      data fpppp(21,10, 3,1),fpppp(21,10, 3,2),fpppp(21,10, 3,3)/
     x-1.8835780d-05,-1.8065871d-05,-3.7557428d-08 /
      data fpppp(21,10, 4,1),fpppp(21,10, 4,2),fpppp(21,10, 4,3)/
     x-1.8835780d-05,-1.9634946d-05,-3.9222353d-08 /
      data fpppp(21,10, 5,1),fpppp(21,10, 5,2),fpppp(21,10, 5,3)/
     x-9.6997466d-06, 1.9741226d-05, 2.4118420d-08 /
      data fpppp(21,10, 6,1),fpppp(21,10, 6,2),fpppp(21,10, 6,3)/
     x-1.4946597d-05, 5.0615885d-06, 1.8603028d-08 /
      data fpppp(21,10, 7,1),fpppp(21,10, 7,2),fpppp(21,10, 7,3)/
     x-1.3312781d-05, 2.5583182d-06, 9.0951120d-09 /
      data fpppp(21,10, 8,1),fpppp(21,10, 8,2),fpppp(21,10, 8,3)/
     x-1.0480565d-05,-1.4476743d-06, 2.3933916d-09 /
      data fpppp(21,10, 9,1),fpppp(21,10, 9,2),fpppp(21,10, 9,3)/
     x-9.1307775d-06,-1.7798602d-06, 2.1222602d-09 /
      data fpppp(21,10,10,1),fpppp(21,10,10,2),fpppp(21,10,10,3)/
     x-1.0763236d-05,-1.4168037d-06,-1.6408925d-09 /
      data fpppp(21,10,11,1),fpppp(21,10,11,2),fpppp(21,10,11,3)/
     x-8.3873160d-06, 2.9119920d-07, 3.3946562d-09 /
      data fpppp(21,10,12,1),fpppp(21,10,12,2),fpppp(21,10,12,3)/
     x-7.8453368d-06, 1.6920910d-06, 3.0131422d-09 /
      data fpppp(21,10,13,1),fpppp(21,10,13,2),fpppp(21,10,13,3)/
     x-7.2026259d-06, 2.5083586d-06, 3.5356517d-09 /
      data fpppp(21,10,14,1),fpppp(21,10,14,2),fpppp(21,10,14,3)/
     x-6.0404273d-06, 2.6268953d-06, 3.0470463d-09 /
      data fpppp(21,10,15,1),fpppp(21,10,15,2),fpppp(21,10,15,3)/
     x-4.9721326d-06, 2.5911265d-06, 1.9906722d-09 /
      data fpppp(21,10,16,1),fpppp(21,10,16,2),fpppp(21,10,16,3)/
     x-3.8398671d-06, 1.9238786d-06, 7.9002867d-10 /
      data fpppp(21,10,17,1),fpppp(21,10,17,2),fpppp(21,10,17,3)/
     x-2.2358424d-06, 1.0552611d-06,-1.4009259d-10 /
      data fpppp(21,10,18,1),fpppp(21,10,18,2),fpppp(21,10,18,3)/
     x-8.5519200d-07,-1.8730563d-07,-1.0359148d-09 /
      data fpppp(21,10,19,1),fpppp(21,10,19,2),fpppp(21,10,19,3)/
     x 8.9503622d-07,-1.5103687d-06,-2.8577081d-09 /
      data fpppp(21,10,20,1),fpppp(21,10,20,2),fpppp(21,10,20,3)/
     x 3.0263066d-06,-3.1799534d-06,-5.4269274d-09 /
      data fpppp(21,10,21,1),fpppp(21,10,21,2),fpppp(21,10,21,3)/
     x 3.0263066d-06,-3.2057725d-06,-5.4564918d-09 /
      data fpppp(21,10,22,1),fpppp(21,10,22,2),fpppp(21,10,22,3)/
     x 8.9503622d-07,-1.4070921d-06,-2.7394503d-09 /
      data fpppp(21,10,23,1),fpppp(21,10,23,2),fpppp(21,10,23,3)/
     x-8.5519200d-07,-5.7459298d-07,-1.4793814d-09 /
      data fpppp(21,11, 1,1),fpppp(21,11, 1,2),fpppp(21,11, 1,3)/
     x-5.3675726d-06, 7.5607958d-05, 9.0294506d-09 /
      data fpppp(21,11, 2,1),fpppp(21,11, 2,2),fpppp(21,11, 2,3)/
     x 4.0677096d-06, 3.6887148d-05, 2.0166575d-09 /
      data fpppp(21,11, 3,1),fpppp(21,11, 3,2),fpppp(21,11, 3,3)/
     x 6.5081127d-05,-4.3798963d-05,-1.2855017d-08 /
      data fpppp(21,11, 4,1),fpppp(21,11, 4,2),fpppp(21,11, 4,3)/
     x 6.5081127d-05,-4.7801305d-05,-1.3127560d-08 /
      data fpppp(21,11, 5,1),fpppp(21,11, 5,2),fpppp(21,11, 5,3)/
     x 4.0677096d-06, 5.2896515d-05, 3.1068316d-09 /
      data fpppp(21,11, 6,1),fpppp(21,11, 6,2),fpppp(21,11, 6,3)/
     x-5.3675726d-06, 1.5572832d-05, 4.9412977d-09 /
      data fpppp(21,11, 7,1),fpppp(21,11, 7,2),fpppp(21,11, 7,3)/
     x-7.5900286d-06, 6.3297541d-06, 4.4931725d-09 /
      data fpppp(21,11, 8,1),fpppp(21,11, 8,2),fpppp(21,11, 8,3)/
     x-6.8393706d-06,-2.0689408d-06, 3.2691054d-09 /
      data fpppp(21,11, 9,1),fpppp(21,11, 9,2),fpppp(21,11, 9,3)/
     x-5.7613837d-06,-4.8541817d-06, 4.3873125d-11 /
      data fpppp(21,11,10,1),fpppp(21,11,10,2),fpppp(21,11,10,3)/
     x-2.2003436d-06, 7.9694511d-07, 4.8171585d-09 /
      data fpppp(21,11,11,1),fpppp(21,11,11,2),fpppp(21,11,11,3)/
     x-5.2378866d-06,-2.9177396d-06,-1.5183122d-09 /
      data fpppp(21,11,12,1),fpppp(21,11,12,2),fpppp(21,11,12,3)/
     x-5.0284401d-06, 1.0078670d-06, 1.1506913d-09 /
      data fpppp(21,11,13,1),fpppp(21,11,13,2),fpppp(21,11,13,3)/
     x-4.2942443d-06, 1.8654159d-06, 1.4038562d-09 /
      data fpppp(21,11,14,1),fpppp(21,11,14,2),fpppp(21,11,14,3)/
     x-3.9922221d-06, 2.1534793d-06, 1.2078023d-09 /
      data fpppp(21,11,15,1),fpppp(21,11,15,2),fpppp(21,11,15,3)/
     x-3.3387803d-06, 2.4446893d-06, 6.5725328d-10 /
      data fpppp(21,11,16,1),fpppp(21,11,16,2),fpppp(21,11,16,3)/
     x-2.8137604d-06, 1.6167173d-06,-2.9768060d-10 /
      data fpppp(21,11,17,1),fpppp(21,11,17,2),fpppp(21,11,17,3)/
     x-2.2145599d-06, 6.7758999d-07,-3.4950919d-10 /
      data fpppp(21,11,18,1),fpppp(21,11,18,2),fpppp(21,11,18,3)/
     x-1.5586743d-06, 5.7301974d-09, 6.2154427d-11 /
      data fpppp(21,11,19,1),fpppp(21,11,19,2),fpppp(21,11,19,3)/
     x-1.4309504d-06,-1.2493084d-06, 2.6837083d-09 /
      data fpppp(21,11,20,1),fpppp(21,11,20,2),fpppp(21,11,20,3)/
     x-1.7405455d-06,-2.5997566d-06,-4.1083617d-09 /
      data fpppp(21,11,21,1),fpppp(21,11,21,2),fpppp(21,11,21,3)/
     x-1.7405455d-06,-2.6294162d-06,-3.8334636d-09 /
      data fpppp(21,11,22,1),fpppp(21,11,22,2),fpppp(21,11,22,3)/
     x-1.4309504d-06,-1.1306699d-06, 1.5841159d-09 /
      data fpppp(21,11,23,1),fpppp(21,11,23,2),fpppp(21,11,23,3)/
     x-1.5586743d-06,-4.3916423d-07, 4.1856258d-09 /
      data fpppp(21,12, 1,1),fpppp(21,12, 1,2),fpppp(21,12, 1,3)/
     x 1.6384201d-05, 1.6305435d-04,-7.9579767d-08 /
      data fpppp(21,12, 2,1),fpppp(21,12, 2,2),fpppp(21,12, 2,3)/
     x 1.7330989d-05, 8.0934853d-05,-3.9675225d-08 /
      data fpppp(21,12, 3,1),fpppp(21,12, 3,2),fpppp(21,12, 3,3)/
     x-7.0915174d-05,-8.9733421d-05, 4.3942058d-08 /
      data fpppp(21,12, 4,1),fpppp(21,12, 4,2),fpppp(21,12, 4,3)/
     x-7.0915174d-05,-9.9012046d-05, 4.7253845d-08 /
      data fpppp(21,12, 5,1),fpppp(21,12, 5,2),fpppp(21,12, 5,3)/
     x 1.7330989d-05, 1.1804936d-04,-5.2922373d-08 /
      data fpppp(21,12, 6,1),fpppp(21,12, 6,2),fpppp(21,12, 6,3)/
     x 1.6384201d-05, 2.3874960d-05,-2.9902961d-08 /
      data fpppp(21,12, 7,1),fpppp(21,12, 7,2),fpppp(21,12, 7,3)/
     x 7.6379637d-06, 1.4872619d-05,-7.8322051d-09 /
      data fpppp(21,12, 8,1),fpppp(21,12, 8,2),fpppp(21,12, 8,3)/
     x 1.5096775d-06,-3.8580008d-06, 4.6025412d-09 /
      data fpppp(21,12, 9,1),fpppp(21,12, 9,2),fpppp(21,12, 9,3)/
     x-9.2911457d-07,-4.5123762d-06, 8.6972330d-09 /
      data fpppp(21,12,10,1),fpppp(21,12,10,2),fpppp(21,12,10,3)/
     x-4.2088837d-06,-3.3770309d-06, 2.9199616d-09 /
      data fpppp(21,12,11,1),fpppp(21,12,11,2),fpppp(21,12,11,3)/
     x-3.0358883d-06,-1.9250956d-06, 3.0927941d-09 /
      data fpppp(21,12,12,1),fpppp(21,12,12,2),fpppp(21,12,12,3)/
     x-3.0819905d-06,-1.6004345d-07, 4.1958323d-10 /
      data fpppp(21,12,13,1),fpppp(21,12,13,2),fpppp(21,12,13,3)/
     x-3.1648808d-06, 1.1185773d-06, 4.1276021d-10 /
      data fpppp(21,12,14,1),fpppp(21,12,14,2),fpppp(21,12,14,3)/
     x-2.6538112d-06, 1.9640873d-06, 5.5090776d-10 /
      data fpppp(21,12,15,1),fpppp(21,12,15,2),fpppp(21,12,15,3)/
     x-2.6094571d-06, 2.1111113d-06,-2.0175688d-11 /
      data fpppp(21,12,16,1),fpppp(21,12,16,2),fpppp(21,12,16,3)/
     x-2.5079586d-06, 1.3815233d-06, 2.1349175d-10 /
      data fpppp(21,12,17,1),fpppp(21,12,17,2),fpppp(21,12,17,3)/
     x-2.9184529d-06, 4.5567940d-07,-5.1257238d-10 /
      data fpppp(21,12,18,1),fpppp(21,12,18,2),fpppp(21,12,18,3)/
     x-3.0096179d-06,-1.7354754d-07, 1.7730604d-10 /
      data fpppp(21,12,19,1),fpppp(21,12,19,2),fpppp(21,12,19,3)/
     x-2.8776942d-06,-1.1747346d-06, 5.7354103d-10 /
      data fpppp(21,12,20,1),fpppp(21,12,20,2),fpppp(21,12,20,3)/
     x-2.6183637d-06,-2.1421279d-06,-1.7229870d-10 /
      data fpppp(21,12,21,1),fpppp(21,12,21,2),fpppp(21,12,21,3)/
     x-2.6183637d-06,-2.1682230d-06,-1.3696832d-10 /
      data fpppp(21,12,22,1),fpppp(21,12,22,2),fpppp(21,12,22,3)/
     x-2.8776942d-06,-1.0703542d-06, 4.3221947d-10 /
      data fpppp(21,12,23,1),fpppp(21,12,23,2),fpppp(21,12,23,3)/
     x-3.0096179d-06,-5.6497413d-07, 7.0726187d-10 /
      data fpppp(21,13, 1,1),fpppp(21,13, 1,2),fpppp(21,13, 1,3)/
     x 1.6840493d-05, 1.4732020d-04,-1.0285354d-07 /
      data fpppp(21,13, 2,1),fpppp(21,13, 2,2),fpppp(21,13, 2,3)/
     x-6.8416404d-07, 6.9152170d-05,-4.3169445d-08 /
      data fpppp(21,13, 3,1),fpppp(21,13, 3,2),fpppp(21,13, 3,3)/
     x 1.7400280d-06,-9.4410614d-05, 8.3124691d-08 /
      data fpppp(21,13, 4,1),fpppp(21,13, 4,2),fpppp(21,13, 4,3)/
     x 1.7400280d-06,-1.0130587d-04, 8.5925300d-08 /
      data fpppp(21,13, 5,1),fpppp(21,13, 5,2),fpppp(21,13, 5,3)/
     x-6.8416404d-07, 9.6733183d-05,-5.4371884d-08 /
      data fpppp(21,13, 6,1),fpppp(21,13, 6,2),fpppp(21,13, 6,3)/
     x 1.6840493d-05, 4.3891405d-05,-6.0844394d-08 /
      data fpppp(21,13, 7,1),fpppp(21,13, 7,2),fpppp(21,13, 7,3)/
     x 1.6496326d-05, 2.1173438d-05,-3.2710041d-08 /
      data fpppp(21,13, 8,1),fpppp(21,13, 8,2),fpppp(21,13, 8,3)/
     x 1.0272787d-05,-8.2764882d-07,-3.6215745d-09 /
      data fpppp(21,13, 9,1),fpppp(21,13, 9,2),fpppp(21,13, 9,3)/
     x 4.4937311d-06,-5.6763838d-06, 6.1221013d-09 /
      data fpppp(21,13,10,1),fpppp(21,13,10,2),fpppp(21,13,10,3)/
     x 1.9446536d-06,-3.9980436d-06, 7.9056746d-09 /
      data fpppp(21,13,11,1),fpppp(21,13,11,2),fpppp(21,13,11,3)/
     x-2.7746647d-07,-2.0990593d-06, 4.6615116d-09 /
      data fpppp(21,13,12,1),fpppp(21,13,12,2),fpppp(21,13,12,3)/
     x-1.4268237d-06,-7.7112380d-07, 2.1507929d-09 /
      data fpppp(21,13,13,1),fpppp(21,13,13,2),fpppp(21,13,13,3)/
     x-1.4798223d-06, 7.8498112d-07, 7.5145887d-10 /
      data fpppp(21,13,14,1),fpppp(21,13,14,2),fpppp(21,13,14,3)/
     x-1.7284265d-06, 1.3129553d-06, 1.4332611d-10 /
      data fpppp(21,13,15,1),fpppp(21,13,15,2),fpppp(21,13,15,3)/
     x-1.9182694d-06, 1.7545701d-06, 4.7805556d-10 /
      data fpppp(21,13,16,1),fpppp(21,13,16,2),fpppp(21,13,16,3)/
     x-2.9320998d-06, 9.7608978d-07,-7.6947029d-10 /
      data fpppp(21,13,17,1),fpppp(21,13,17,2),fpppp(21,13,17,3)/
     x-2.4639965d-06, 4.4583327d-07, 7.5792816d-10 /
      data fpppp(21,13,18,1),fpppp(21,13,18,2),fpppp(21,13,18,3)/
     x-2.6699791d-06,-3.7092727d-07,-4.7071255d-10 /
      data fpppp(21,13,19,1),fpppp(21,13,19,2),fpppp(21,13,19,3)/
     x-3.0169879d-06,-1.0166503d-06,-1.6586659d-09 /
      data fpppp(21,13,20,1),fpppp(21,13,20,2),fpppp(21,13,20,3)/
     x-3.2008956d-06,-1.7650296d-06, 2.3800647d-09 /
      data fpppp(21,13,21,1),fpppp(21,13,21,2),fpppp(21,13,21,3)/
     x-3.2008956d-06,-1.7791030d-06, 2.2342090d-09 /
      data fpppp(21,13,22,1),fpppp(21,13,22,2),fpppp(21,13,22,3)/
     x-3.0169879d-06,-9.6035678d-07,-1.0752429d-09 /
      data fpppp(21,13,23,1),fpppp(21,13,23,2),fpppp(21,13,23,3)/
     x-2.6699791d-06,-5.8202811d-07,-2.6585487d-09 /
      data fpppp(21,14, 1,1),fpppp(21,14, 1,2),fpppp(21,14, 1,3)/
     x 1.1990327d-05, 1.2279323d-04,-3.2703147d-08 /
      data fpppp(21,14, 2,1),fpppp(21,14, 2,2),fpppp(21,14, 2,3)/
     x 5.5568291d-06, 5.4742175d-05,-4.4228615d-09 /
      data fpppp(21,14, 3,1),fpppp(21,14, 3,2),fpppp(21,14, 3,3)/
     x 2.1316645d-07,-8.8093449d-05, 5.6399715d-08 /
      data fpppp(21,14, 4,1),fpppp(21,14, 4,2),fpppp(21,14, 4,3)/
     x 2.1316645d-07,-9.3322575d-05, 5.6011277d-08 /
      data fpppp(21,14, 5,1),fpppp(21,14, 5,2),fpppp(21,14, 5,3)/
     x 5.5568291d-06, 7.5658680d-05,-2.8691123d-09 /
      data fpppp(21,14, 6,1),fpppp(21,14, 6,2),fpppp(21,14, 6,3)/
     x 1.1990327d-05, 4.4356339d-05,-3.8529706d-08 /
      data fpppp(21,14, 7,1),fpppp(21,14, 7,2),fpppp(21,14, 7,3)/
     x 1.7067135d-05, 2.4807195d-05,-3.6407636d-08 /
      data fpppp(21,14, 8,1),fpppp(21,14, 8,2),fpppp(21,14, 8,3)/
     x 1.3543954d-05, 2.9229334d-06,-1.7665982d-08 /
      data fpppp(21,14, 9,1),fpppp(21,14, 9,2),fpppp(21,14, 9,3)/
     x 7.8079701d-06,-3.7996239d-06,-3.1466802d-09 /
      data fpppp(21,14,10,1),fpppp(21,14,10,2),fpppp(21,14,10,3)/
     x 3.8856406d-06,-3.6097672d-06, 2.8112466d-09 /
      data fpppp(21,14,11,1),fpppp(21,14,11,2),fpppp(21,14,11,3)/
     x 1.7759669d-06,-1.7776971d-06, 4.3665757d-09 /
      data fpppp(21,14,12,1),fpppp(21,14,12,2),fpppp(21,14,12,3)/
     x 5.8846549d-07,-3.7867101d-07, 3.2816734d-09 /
      data fpppp(21,14,13,1),fpppp(21,14,13,2),fpppp(21,14,13,3)/
     x-6.7098663d-07, 2.1862195d-07, 1.5382751d-09 /
      data fpppp(21,14,14,1),fpppp(21,14,14,2),fpppp(21,14,14,3)/
     x-1.2899837d-06, 1.0413349d-06, 2.2387654d-10 /
      data fpppp(21,14,15,1),fpppp(21,14,15,2),fpppp(21,14,15,3)/
     x-1.3726268d-06, 4.1742938d-07,-3.6127228d-10 /
      data fpppp(21,14,16,1),fpppp(21,14,16,2),fpppp(21,14,16,3)/
     x-4.8597314d-07, 1.8440335d-06, 1.5132035d-09 /
      data fpppp(21,14,17,1),fpppp(21,14,17,2),fpppp(21,14,17,3)/
     x-1.6971810d-06,-3.5904203d-07,-8.5171022d-11 /
      data fpppp(21,14,18,1),fpppp(21,14,18,2),fpppp(21,14,18,3)/
     x-2.1929823d-06,-3.2317547d-07, 5.2085305d-10 /
      data fpppp(21,14,19,1),fpppp(21,14,19,2),fpppp(21,14,19,3)/
     x-2.0781722d-06,-7.7446765d-07, 8.0591785d-10 /
      data fpppp(21,14,20,1),fpppp(21,14,20,2),fpppp(21,14,20,3)/
     x-2.1072423d-06,-1.3335258d-06,-1.0244984d-10 /
      data fpppp(21,14,21,1),fpppp(21,14,21,2),fpppp(21,14,21,3)/
     x-2.1072423d-06,-1.3425637d-06,-6.8796219d-11 /
      data fpppp(21,14,22,1),fpppp(21,14,22,2),fpppp(21,14,22,3)/
     x-2.0781722d-06,-7.3831606d-07, 6.7130334d-10 /
      data fpppp(21,14,23,1),fpppp(21,14,23,2),fpppp(21,14,23,3)/
     x-2.1929823d-06,-4.5874394d-07, 1.0256574d-09 /
      data fpppp(21,15, 1,1),fpppp(21,15, 1,2),fpppp(21,15, 1,3)/
     x-9.4373295d-06, 9.7982609d-05, 4.9443392d-08 /
      data fpppp(21,15, 2,1),fpppp(21,15, 2,2),fpppp(21,15, 2,3)/
     x-5.8976390d-05, 4.2871566d-05, 3.0306360d-08 /
      data fpppp(21,15, 3,1),fpppp(21,15, 3,2),fpppp(21,15, 3,3)/
     x-1.1379997d-04,-7.2626506d-05,-9.4826912d-09 /
      data fpppp(21,15, 4,1),fpppp(21,15, 4,2),fpppp(21,15, 4,3)/
     x-1.1379997d-04,-7.7171295d-05,-1.1615720d-08 /
      data fpppp(21,15, 5,1),fpppp(21,15, 5,2),fpppp(21,15, 5,3)/
     x-5.8976390d-05, 6.1050722d-05, 3.8838475d-08 /
      data fpppp(21,15, 6,1),fpppp(21,15, 6,2),fpppp(21,15, 6,3)/
     x-9.4373295d-06, 2.9810772d-05, 1.7447962d-08 /
      data fpppp(21,15, 7,1),fpppp(21,15, 7,2),fpppp(21,15, 7,3)/
     x 1.9326331d-06, 2.0551733d-05,-6.8285248d-09 /
      data fpppp(21,15, 8,1),fpppp(21,15, 8,2),fpppp(21,15, 8,3)/
     x 5.8911962d-06, 5.5501621d-06,-1.7122800d-08 /
      data fpppp(21,15, 9,1),fpppp(21,15, 9,2),fpppp(21,15, 9,3)/
     x 7.2570843d-06,-5.3962997d-07,-1.3333066d-08 /
      data fpppp(21,15,10,1),fpppp(21,15,10,2),fpppp(21,15,10,3)/
     x 4.3020017d-06,-1.4674500d-06,-6.2316185d-09 /
      data fpppp(21,15,11,1),fpppp(21,15,11,2),fpppp(21,15,11,3)/
     x 2.9107104d-06,-7.1435978d-07,-1.0862986d-09 /
      data fpppp(21,15,12,1),fpppp(21,15,12,2),fpppp(21,15,12,3)/
     x 1.5215520d-06, 5.5425113d-08, 1.0374081d-09 /
      data fpppp(21,15,13,1),fpppp(21,15,13,2),fpppp(21,15,13,3)/
     x 8.2083889d-07, 2.4071542d-07, 1.1143462d-09 /
      data fpppp(21,15,14,1),fpppp(21,15,14,2),fpppp(21,15,14,3)/
     x 2.1027893d-07, 8.3062823d-07, 1.3306516d-09 /
      data fpppp(21,15,15,1),fpppp(21,15,15,2),fpppp(21,15,15,3)/
     x-5.0107164d-07, 3.5156767d-07, 7.5019275d-10 /
      data fpppp(21,15,16,1),fpppp(21,15,16,2),fpppp(21,15,16,3)/
     x-1.1458613d-06, 6.8570813d-07, 5.4535622d-11 /
      data fpppp(21,15,17,1),fpppp(21,15,17,2),fpppp(21,15,17,3)/
     x-7.0896886d-07,-1.5795012d-07, 7.6807923d-10 /
      data fpppp(21,15,18,1),fpppp(21,15,18,2),fpppp(21,15,18,3)/
     x-2.5095146d-07,-6.4357775d-08, 9.0812776d-10 /
      data fpppp(21,15,19,1),fpppp(21,15,19,2),fpppp(21,15,19,3)/
     x-3.7540038d-07,-6.6356266d-07,-2.3363839d-10 /
      data fpppp(21,15,20,1),fpppp(21,15,20,2),fpppp(21,15,20,3)/
     x-3.4610621d-07,-8.4665420d-07,-4.5656102d-10 /
      data fpppp(21,15,21,1),fpppp(21,15,21,2),fpppp(21,15,21,3)/
     x-3.4610621d-07,-8.7104164d-07,-5.0582062d-10 /
      data fpppp(21,15,22,1),fpppp(21,15,22,2),fpppp(21,15,22,3)/
     x-3.7540038d-07,-5.6601288d-07,-3.6599990d-11 /
      data fpppp(21,15,23,1),fpppp(21,15,23,2),fpppp(21,15,23,3)/
     x-2.5095146d-07,-4.3016944d-07, 1.6923374d-10 /
      data fpppp(21,16, 1,1),fpppp(21,16, 1,2),fpppp(21,16, 1,3)/
     x-3.0935143d-05, 4.9055806d-05, 5.5479386d-08 /
      data fpppp(21,16, 2,1),fpppp(21,16, 2,2),fpppp(21,16, 2,3)/
     x 2.3169771d-05, 2.2310277d-05, 2.4637807d-08 /
      data fpppp(21,16, 3,1),fpppp(21,16, 3,2),fpppp(21,16, 3,3)/
     x 6.2585944d-05,-3.3017649d-05,-4.0860303d-08 /
      data fpppp(21,16, 4,1),fpppp(21,16, 4,2),fpppp(21,16, 4,3)/
     x 6.2585944d-05,-3.6489510d-05,-4.1894531d-08 /
      data fpppp(21,16, 5,1),fpppp(21,16, 5,2),fpppp(21,16, 5,3)/
     x 2.3169771d-05, 3.6197720d-05, 2.8774719d-08 /
      data fpppp(21,16, 6,1),fpppp(21,16, 6,2),fpppp(21,16, 6,3)/
     x-3.0935143d-05,-3.0221047d-06, 3.9965969d-08 /
      data fpppp(21,16, 7,1),fpppp(21,16, 7,2),fpppp(21,16, 7,3)/
     x-1.9446598d-05, 1.1250926d-05, 2.2349790d-08 /
      data fpppp(21,16, 8,1),fpppp(21,16, 8,2),fpppp(21,16, 8,3)/
     x-1.0342733d-05, 6.0158091d-06, 4.1685462d-10 /
      data fpppp(21,16, 9,1),fpppp(21,16, 9,2),fpppp(21,16, 9,3)/
     x-5.6960073d-06,-6.2860529d-07,-9.9078004d-09 /
      data fpppp(21,16,10,1),fpppp(21,16,10,2),fpppp(21,16,10,3)/
     x 5.5373171d-07, 2.3651106d-06,-9.9974701d-09 /
      data fpppp(21,16,11,1),fpppp(21,16,11,2),fpppp(21,16,11,3)/
     x 1.6901801d-06,-1.0849631d-07,-6.7838468d-09 /
      data fpppp(21,16,12,1),fpppp(21,16,12,2),fpppp(21,16,12,3)/
     x 2.2214096d-06, 9.5465791d-07,-2.9887453d-09 /
      data fpppp(21,16,13,1),fpppp(21,16,13,2),fpppp(21,16,13,3)/
     x 1.6332741d-06, 4.2220138d-07,-4.4343660d-10 /
      data fpppp(21,16,14,1),fpppp(21,16,14,2),fpppp(21,16,14,3)/
     x 1.1366671d-06, 6.0981124d-07, 2.0206331d-10 /
      data fpppp(21,16,15,1),fpppp(21,16,15,2),fpppp(21,16,15,3)/
     x 8.0002566d-07, 4.5991208d-07, 1.2140928d-09 /
      data fpppp(21,16,16,1),fpppp(21,16,16,2),fpppp(21,16,16,3)/
     x 4.8922203d-07, 1.0204680d-07, 8.6574148d-10 /
      data fpppp(21,16,17,1),fpppp(21,16,17,2),fpppp(21,16,17,3)/
     x 5.5227584d-07, 1.7300365d-07, 4.1091263d-10 /
      data fpppp(21,16,18,1),fpppp(21,16,18,2),fpppp(21,16,18,3)/
     x 4.8678310d-07,-2.2829173d-07,-5.4268570d-10 /
      data fpppp(21,16,19,1),fpppp(21,16,19,2),fpppp(21,16,19,3)/
     x 7.9893972d-07,-3.3311748d-07,-7.9213632d-10 /
      data fpppp(21,16,20,1),fpppp(21,16,20,2),fpppp(21,16,20,3)/
     x 1.0200621d-06,-4.3513398d-07,-1.5889627d-10 /
      data fpppp(21,16,21,1),fpppp(21,16,21,2),fpppp(21,16,21,3)/
     x 1.0200621d-06,-4.3785003d-07,-1.8476475d-10 /
      data fpppp(21,16,22,1),fpppp(21,16,22,2),fpppp(21,16,22,3)/
     x 7.9893972d-07,-3.2225329d-07,-6.8866240d-10 /
      data fpppp(21,16,23,1),fpppp(21,16,23,2),fpppp(21,16,23,3)/
     x 4.8678310d-07,-2.6903243d-07,-9.3071290d-10 /
      data fpppp(21,17, 1,1),fpppp(21,17, 1,2),fpppp(21,17, 1,3)/
     x 4.1769015d-06, 1.5465884d-06, 1.4257897d-08 /
      data fpppp(21,17, 2,1),fpppp(21,17, 2,2),fpppp(21,17, 2,3)/
     x-1.5625557d-05,-1.5638929d-06, 9.7474308d-10 /
      data fpppp(21,17, 3,1),fpppp(21,17, 3,2),fpppp(21,17, 3,3)/
     x 1.3488480d-06,-8.8374667d-06,-2.7584261d-08 /
      data fpppp(21,17, 4,1),fpppp(21,17, 4,2),fpppp(21,17, 4,3)/
     x 1.3488480d-06,-7.7730176d-06,-2.7417830d-08 /
      data fpppp(21,17, 5,1),fpppp(21,17, 5,2),fpppp(21,17, 5,3)/
     x-1.5625557d-05,-5.8216894d-06, 3.0901858d-10 /
      data fpppp(21,17, 6,1),fpppp(21,17, 6,2),fpppp(21,17, 6,3)/
     x 4.1769015d-06, 1.7513325d-05, 1.6754363d-08 /
      data fpppp(21,17, 7,1),fpppp(21,17, 7,2),fpppp(21,17, 7,3)/
     x-1.5689378d-05,-9.8206972d-06, 2.1198194d-08 /
      data fpppp(21,17, 8,1),fpppp(21,17, 8,2),fpppp(21,17, 8,3)/
     x-1.3751989d-05, 5.0499629d-06, 1.3993866d-08 /
      data fpppp(21,17, 9,1),fpppp(21,17, 9,2),fpppp(21,17, 9,3)/
     x-7.5893254d-06, 5.8325279d-07, 5.0814998d-09 /
      data fpppp(21,17,10,1),fpppp(21,17,10,2),fpppp(21,17,10,3)/
     x-4.7705984d-06, 1.1729765d-06,-1.6259148d-09 /
      data fpppp(21,17,11,1),fpppp(21,17,11,2),fpppp(21,17,11,3)/
     x-1.3048756d-06, 1.0529373d-06,-3.9458909d-09 /
      data fpppp(21,17,12,1),fpppp(21,17,12,2),fpppp(21,17,12,3)/
     x 5.2855833d-07, 6.0527308d-07,-4.0847057d-09 /
      data fpppp(21,17,13,1),fpppp(21,17,13,2),fpppp(21,17,13,3)/
     x 1.9095921d-06, 8.0117297d-07,-2.9239075d-09 /
      data fpppp(21,17,14,1),fpppp(21,17,14,2),fpppp(21,17,14,3)/
     x 2.4610294d-06, 4.7434009d-07,-1.2433953d-09 /
      data fpppp(21,17,15,1),fpppp(21,17,15,2),fpppp(21,17,15,3)/
     x 2.8046299d-06, 3.6062231d-07,-5.6529479d-10 /
      data fpppp(21,17,16,1),fpppp(21,17,16,2),fpppp(21,17,16,3)/
     x 2.9939007d-06, 2.7915885d-07,-9.8088382d-11 /
      data fpppp(21,17,17,1),fpppp(21,17,17,2),fpppp(21,17,17,3)/
     x 3.0138823d-06, 7.6320809d-08, 1.0934833d-10 /
      data fpppp(21,17,18,1),fpppp(21,17,18,2),fpppp(21,17,18,3)/
     x 2.9649103d-06,-4.4674916d-09,-3.6111049d-10 /
      data fpppp(21,17,19,1),fpppp(21,17,19,2),fpppp(21,17,19,3)/
     x 3.0206322d-06,-9.3243444d-08,-5.4399231d-10 /
      data fpppp(21,17,20,1),fpppp(21,17,20,2),fpppp(21,17,20,3)/
     x 3.1932605d-06,-1.4257471d-07,-5.7942449d-10 /
      data fpppp(21,17,21,1),fpppp(21,17,21,2),fpppp(21,17,21,3)/
     x 3.1932605d-06,-1.4569598d-07,-5.8732070d-10 /
      data fpppp(21,17,22,1),fpppp(21,17,22,2),fpppp(21,17,22,3)/
     x 3.0206322d-06,-8.0758376d-08,-5.1240747d-10 /
      data fpppp(21,17,23,1),fpppp(21,17,23,2),fpppp(21,17,23,3)/
     x 2.9649103d-06,-5.1286499d-08,-4.7955362d-10 /
      data fpppp(21,18, 1,1),fpppp(21,18, 1,2),fpppp(21,18, 1,3)/
     x-4.6113191d-06,-7.6150141d-07, 1.9527853d-09 /
      data fpppp(21,18, 2,1),fpppp(21,18, 2,2),fpppp(21,18, 2,3)/
     x 1.0027921d-05,-8.1741236d-07,-2.5842952d-09 /
      data fpppp(21,18, 3,1),fpppp(21,18, 3,2),fpppp(21,18, 3,3)/
     x 1.9630832d-05,-9.5863095d-07,-1.2356350d-08 /
      data fpppp(21,18, 4,1),fpppp(21,18, 4,2),fpppp(21,18, 4,3)/
     x 1.9630832d-05,-9.2116446d-07,-1.2269306d-08 /
      data fpppp(21,18, 5,1),fpppp(21,18, 5,2),fpppp(21,18, 5,3)/
     x 1.0027921d-05,-9.6727834d-07,-2.9324677d-09 /
      data fpppp(21,18, 6,1),fpppp(21,18, 6,2),fpppp(21,18, 6,3)/
     x-4.6113191d-06,-1.9950397d-07, 3.2584323d-09 /
      data fpppp(21,18, 7,1),fpppp(21,18, 7,2),fpppp(21,18, 7,3)/
     x-1.7428406d-06,-3.4688104d-07, 6.2116914d-09 /
      data fpppp(21,18, 8,1),fpppp(21,18, 8,2),fpppp(21,18, 8,3)/
     x-3.6249314d-06, 2.3004471d-07, 6.7088010d-09 /
      data fpppp(21,18, 9,1),fpppp(21,18, 9,2),fpppp(21,18, 9,3)/
     x-4.4819029d-06, 1.3503786d-07, 5.4230590d-09 /
      data fpppp(21,18,10,1),fpppp(21,18,10,2),fpppp(21,18,10,3)/
     x-3.7859843d-06, 2.5536275d-07, 3.7949771d-09 /
      data fpppp(21,18,11,1),fpppp(21,18,11,2),fpppp(21,18,11,3)/
     x-2.8719824d-06, 4.6913783d-07, 2.1107611d-09 /
      data fpppp(21,18,12,1),fpppp(21,18,12,2),fpppp(21,18,12,3)/
     x-1.5911111d-06, 1.9479529d-07, 8.2031675d-10 /
      data fpppp(21,18,13,1),fpppp(21,18,13,2),fpppp(21,18,13,3)/
     x-1.5005729d-07, 4.0096613d-07, 6.4720768d-11 /
      data fpppp(21,18,14,1),fpppp(21,18,14,2),fpppp(21,18,14,3)/
     x 1.3697535d-06, 3.6857561d-07,-4.2384817d-10 /
      data fpppp(21,18,15,1),fpppp(21,18,15,2),fpppp(21,18,15,3)/
     x 2.7563677d-06, 1.1710547d-07,-6.5710429d-10 /
      data fpppp(21,18,16,1),fpppp(21,18,16,2),fpppp(21,18,16,3)/
     x 4.1162237d-06, 3.8523350d-07,-7.0125957d-10 /
      data fpppp(21,18,17,1),fpppp(21,18,17,2),fpppp(21,18,17,3)/
     x 5.2468455d-06,-1.2451860d-07,-1.1126289d-09 /
      data fpppp(21,18,18,1),fpppp(21,18,18,2),fpppp(21,18,18,3)/
     x 6.4037837d-06, 3.2897556d-07,-1.0477091d-09 /
      data fpppp(21,18,19,1),fpppp(21,18,19,2),fpppp(21,18,19,3)/
     x 7.0957458d-06, 1.4376068d-07,-1.1882244d-09 /
      data fpppp(21,18,20,1),fpppp(21,18,20,2),fpppp(21,18,20,3)/
     x 7.3628157d-06, 3.5449085d-09,-1.2632492d-09 /
      data fpppp(21,18,21,1),fpppp(21,18,21,2),fpppp(21,18,21,3)/
     x 7.3628157d-06,-2.1408915d-09,-1.2682573d-09 /
      data fpppp(21,18,22,1),fpppp(21,18,22,2),fpppp(21,18,22,3)/
     x 7.0957458d-06, 1.6650388d-07,-1.1681921d-09 /
      data fpppp(21,18,23,1),fpppp(21,18,23,2),fpppp(21,18,23,3)/
     x 6.4037837d-06, 2.4368855d-07,-1.1228304d-09 /
      data fpppp(21,19, 1,1),fpppp(21,19, 1,2),fpppp(21,19, 1,3)/
     x-8.5660671d-07, 7.4852110d-20,-1.8614148d-08 /
      data fpppp(21,19, 2,1),fpppp(21,19, 2,2),fpppp(21,19, 2,3)/
     x 1.7267454d-05, 9.3274053d-21,-1.1887341d-08 /
      data fpppp(21,19, 3,1),fpppp(21,19, 3,2),fpppp(21,19, 3,3)/
     x 1.5193079d-05,-2.1795731d-20, 2.3138848d-09 /
      data fpppp(21,19, 4,1),fpppp(21,19, 4,2),fpppp(21,19, 4,3)/
     x 1.5193079d-05,-8.4442340d-21, 2.6872676d-09 /
      data fpppp(21,19, 5,1),fpppp(21,19, 5,2),fpppp(21,19, 5,3)/
     x 1.7267454d-05, 1.3928602d-20,-1.3380872d-08 /
      data fpppp(21,19, 6,1),fpppp(21,19, 6,2),fpppp(21,19, 6,3)/
     x-8.5660671d-07,-1.9459597d-20,-1.3013406d-08 /
      data fpppp(21,19, 7,1),fpppp(21,19, 7,2),fpppp(21,19, 7,3)/
     x 9.2924634d-06, 3.1866893d-20,-4.8219807d-09 /
      data fpppp(21,19, 8,1),fpppp(21,19, 8,2),fpppp(21,19, 8,3)/
     x 2.6346080d-06,-2.5344083d-20, 5.3843291d-09 /
      data fpppp(21,19, 9,1),fpppp(21,19, 9,2),fpppp(21,19, 9,3)/
     x-2.8032634d-06, 3.7315531d-20, 9.9496870d-09 /
      data fpppp(21,19,10,1),fpppp(21,19,10,2),fpppp(21,19,10,3)/
     x-4.6039257d-06,-1.5150917d-20, 1.0058916d-08 /
      data fpppp(21,19,11,1),fpppp(21,19,11,2),fpppp(21,19,11,3)/
     x-4.8470746d-06,-2.8257065d-20, 7.2477856d-09 /
      data fpppp(21,19,12,1),fpppp(21,19,12,2),fpppp(21,19,12,3)/
     x-3.5888324d-06,-1.7415601d-23, 4.0107727d-09 /
      data fpppp(21,19,13,1),fpppp(21,19,13,2),fpppp(21,19,13,3)/
     x-1.5422874d-06,-2.9359321d-20, 1.4907493d-09 /
      data fpppp(21,19,14,1),fpppp(21,19,14,2),fpppp(21,19,14,3)/
     x 9.6865999d-07,-1.1161999d-20,-2.5144555d-10 /
      data fpppp(21,19,15,1),fpppp(21,19,15,2),fpppp(21,19,15,3)/
     x 3.2946387d-06, 1.9395699d-21,-1.2310790d-09 /
      data fpppp(21,19,16,1),fpppp(21,19,16,2),fpppp(21,19,16,3)/
     x 5.6335055d-06, 3.3425250d-20,-1.4074761d-09 /
      data fpppp(21,19,17,1),fpppp(21,19,17,2),fpppp(21,19,17,3)/
     x 7.5451353d-06, 3.5507607d-21,-2.0716309d-09 /
      data fpppp(21,19,18,1),fpppp(21,19,18,2),fpppp(21,19,18,3)/
     x 9.5681582d-06,-1.7796004d-20,-1.4862581d-09 /
      data fpppp(21,19,19,1),fpppp(21,19,19,2),fpppp(21,19,19,3)/
     x 1.0641311d-05, 1.7003569d-21,-1.5774919d-09 /
      data fpppp(21,19,20,1),fpppp(21,19,20,2),fpppp(21,19,20,3)/
     x 1.0961983d-05, 4.4346796d-21,-1.8718463d-09 /
      data fpppp(21,19,21,1),fpppp(21,19,21,2),fpppp(21,19,21,3)/
     x 1.0961983d-05, 1.2178588d-21,-1.8696565d-09 /
      data fpppp(21,19,22,1),fpppp(21,19,22,2),fpppp(21,19,22,3)/
     x 1.0641311d-05,-1.9735365d-20,-1.5862511d-09 /
      data fpppp(21,19,23,1),fpppp(21,19,23,2),fpppp(21,19,23,3)/
     x 9.5681582d-06, 2.2800149d-20,-1.4534112d-09 /
      data fpppp(22, 1, 1,1),fpppp(22, 1, 1,2),fpppp(22, 1, 1,3)/
     x-4.4950363d-04,-2.2915380d-18,-1.1780231d-08 /
      data fpppp(22, 1, 2,1),fpppp(22, 1, 2,2),fpppp(22, 1, 2,3)/
     x-1.3593619d-04,-1.4321481d-19,-8.8235828d-08 /
      data fpppp(22, 1, 3,1),fpppp(22, 1, 3,2),fpppp(22, 1, 3,3)/
     x 1.6311228d-04, 1.4909756d-18,-2.5300970d-07 /
      data fpppp(22, 1, 4,1),fpppp(22, 1, 4,2),fpppp(22, 1, 4,3)/
     x 1.6311228d-04, 1.1506808d-18,-2.5136391d-07 /
      data fpppp(22, 1, 5,1),fpppp(22, 1, 5,2),fpppp(22, 1, 5,3)/
     x-1.3593619d-04,-7.7436479d-19,-9.4818968d-08 /
      data fpppp(22, 1, 6,1),fpppp(22, 1, 6,2),fpppp(22, 1, 6,3)/
     x-4.4950363d-04, 1.5847927d-20, 1.2906544d-08 /
      data fpppp(22, 1, 7,1),fpppp(22, 1, 7,2),fpppp(22, 1, 7,3)/
     x-6.2793717d-04, 4.7336199d-19, 7.9435142d-08 /
      data fpppp(22, 1, 8,1),fpppp(22, 1, 8,2),fpppp(22, 1, 8,3)/
     x-6.3808538d-04,-9.6968331d-19, 9.9823554d-08 /
      data fpppp(22, 1, 9,1),fpppp(22, 1, 9,2),fpppp(22, 1, 9,3)/
     x-5.6833433d-04,-8.1727390d-19, 9.5758544d-08 /
      data fpppp(22, 1,10,1),fpppp(22, 1,10,2),fpppp(22, 1,10,3)/
     x-5.2776926d-04,-1.6233739d-18, 8.0341626d-08 /
      data fpppp(22, 1,11,1),fpppp(22, 1,11,2),fpppp(22, 1,11,3)/
     x-4.8425514d-04, 1.6790452d-18, 6.5100541d-08 /
      data fpppp(22, 1,12,1),fpppp(22, 1,12,2),fpppp(22, 1,12,3)/
     x-4.9821705d-04,-1.7588811d-19, 5.9352804d-08 /
      data fpppp(22, 1,13,1),fpppp(22, 1,13,2),fpppp(22, 1,13,3)/
     x-5.2193863d-04, 1.9369768d-18, 6.7011451d-08 /
      data fpppp(22, 1,14,1),fpppp(22, 1,14,2),fpppp(22, 1,14,3)/
     x-5.2617941d-04,-3.8677171d-19, 8.4229720d-08 /
      data fpppp(22, 1,15,1),fpppp(22, 1,15,2),fpppp(22, 1,15,3)/
     x-5.6867840d-04,-1.1432897d-18, 1.0133918d-07 /
      data fpppp(22, 1,16,1),fpppp(22, 1,16,2),fpppp(22, 1,16,3)/
     x-6.4500154d-04,-1.7865729d-18, 1.0718799d-07 /
      data fpppp(22, 1,17,1),fpppp(22, 1,17,2),fpppp(22, 1,17,3)/
     x-6.4901332d-04, 1.7259818d-18, 8.7722547d-08 /
      data fpppp(22, 1,18,1),fpppp(22, 1,18,2),fpppp(22, 1,18,3)/
     x-4.9442593d-04,-9.0979716d-19, 2.0274944d-08 /
      data fpppp(22, 1,19,1),fpppp(22, 1,19,2),fpppp(22, 1,19,3)/
     x-1.8047305d-05, 6.6012683d-19,-9.1812507d-08 /
      data fpppp(22, 1,20,1),fpppp(22, 1,20,2),fpppp(22, 1,20,3)/
     x 2.1112576d-04,-1.0674661d-18,-2.6383689d-07 /
      data fpppp(22, 1,21,1),fpppp(22, 1,21,2),fpppp(22, 1,21,3)/
     x 2.1112576d-04,-9.3794576d-19,-2.6534683d-07 /
      data fpppp(22, 1,22,1),fpppp(22, 1,22,2),fpppp(22, 1,22,3)/
     x-1.8047305d-05, 9.5793166d-19,-8.5772747d-08 /
      data fpppp(22, 1,23,1),fpppp(22, 1,23,2),fpppp(22, 1,23,3)/
     x-4.9442593d-04,-3.1085499d-18,-2.3741576d-09 /
      data fpppp(22, 2, 1,1),fpppp(22, 2, 1,2),fpppp(22, 2, 1,3)/
     x-2.3896971d-04,-2.3924737d-04, 5.7492241d-09 /
      data fpppp(22, 2, 2,1),fpppp(22, 2, 2,2),fpppp(22, 2, 2,3)/
     x-1.0628711d-04,-1.2893922d-04,-2.2935867d-08 /
      data fpppp(22, 2, 3,1),fpppp(22, 2, 3,2),fpppp(22, 2, 3,3)/
     x 4.7892763d-05, 9.8862724d-05,-8.4699268d-08 /
      data fpppp(22, 2, 4,1),fpppp(22, 2, 4,2),fpppp(22, 2, 4,3)/
     x 4.7892763d-05, 1.1386487d-04,-8.4182409d-08 /
      data fpppp(22, 2, 5,1),fpppp(22, 2, 5,2),fpppp(22, 2, 5,3)/
     x-1.0628711d-04,-1.8894780d-04,-2.5003304d-08 /
      data fpppp(22, 2, 6,1),fpppp(22, 2, 6,2),fpppp(22, 2, 6,3)/
     x-2.3896971d-04,-1.4215195d-05, 1.3502111d-08 /
      data fpppp(22, 2, 7,1),fpppp(22, 2, 7,2),fpppp(22, 2, 7,3)/
     x-3.0400755d-04,-1.3188354d-05, 3.4770160d-08 /
      data fpppp(22, 2, 8,1),fpppp(22, 2, 8,2),fpppp(22, 2, 8,3)/
     x-2.9400216d-04,-9.2549843d-06, 3.6595919d-08 /
      data fpppp(22, 2, 9,1),fpppp(22, 2, 9,2),fpppp(22, 2, 9,3)/
     x-2.4931741d-04, 3.0630662d-05, 2.8930363d-08 /
      data fpppp(22, 2,10,1),fpppp(22, 2,10,2),fpppp(22, 2,10,3)/
     x-2.2249339d-04, 3.2005799d-07, 1.8543916d-08 /
      data fpppp(22, 2,11,1),fpppp(22, 2,11,2),fpppp(22, 2,11,3)/
     x-1.9727233d-04, 3.0285871d-05, 1.0222794d-08 /
      data fpppp(22, 2,12,1),fpppp(22, 2,12,2),fpppp(22, 2,12,3)/
     x-2.0289458d-04, 9.6512596d-06, 7.3117171d-09 /
      data fpppp(22, 2,13,1),fpppp(22, 2,13,2),fpppp(22, 2,13,3)/
     x-2.1599324d-04, 1.1569931d-06, 1.1263917d-08 /
      data fpppp(22, 2,14,1),fpppp(22, 2,14,2),fpppp(22, 2,14,3)/
     x-2.2232670d-04, 2.0729716d-05, 2.0655956d-08 /
      data fpppp(22, 2,15,1),fpppp(22, 2,15,2),fpppp(22, 2,15,3)/
     x-2.5023723d-04, 2.7806155d-05, 3.2033238d-08 /
      data fpppp(22, 2,16,1),fpppp(22, 2,16,2),fpppp(22, 2,16,3)/
     x-2.9809381d-04,-1.4334992d-05, 4.0662219d-08 /
      data fpppp(22, 2,17,1),fpppp(22, 2,17,2),fpppp(22, 2,17,3)/
     x-3.1472441d-04, 1.9559112d-05, 3.9270474d-08 /
      data fpppp(22, 2,18,1),fpppp(22, 2,18,2),fpppp(22, 2,18,3)/
     x-2.6131908d-04,-1.2117816d-04, 1.7349636d-08 /
      data fpppp(22, 2,19,1),fpppp(22, 2,19,2),fpppp(22, 2,19,3)/
     x-4.8487560d-05,-3.5272136d-05,-2.3768648d-08 /
      data fpppp(22, 2,20,1),fpppp(22, 2,20,2),fpppp(22, 2,20,3)/
     x 6.3519912d-05, 5.9865618d-05,-9.0491092d-08 /
      data fpppp(22, 2,21,1),fpppp(22, 2,21,2),fpppp(22, 2,21,3)/
     x 6.3519912d-05, 6.1835954d-05,-9.0964880d-08 /
      data fpppp(22, 2,22,1),fpppp(22, 2,22,2),fpppp(22, 2,22,3)/
     x-4.8487560d-05,-4.3153478d-05,-2.1873494d-08 /
      data fpppp(22, 2,23,1),fpppp(22, 2,23,2),fpppp(22, 2,23,3)/
     x-2.6131908d-04,-9.1623124d-05, 1.0242809d-08 /
      data fpppp(22, 3, 1,1),fpppp(22, 3, 1,2),fpppp(22, 3, 1,3)/
     x 5.1417676d-05,-2.6809794d-04, 7.2844223d-08 /
      data fpppp(22, 3, 2,1),fpppp(22, 3, 2,2),fpppp(22, 3, 2,3)/
     x-1.0242885d-04,-1.6400215d-04, 9.4297521d-08 /
      data fpppp(22, 3, 3,1),fpppp(22, 3, 3,2),fpppp(22, 3, 3,3)/
     x 1.0817598d-04, 4.7744925d-05, 1.4127299d-07 /
      data fpppp(22, 3, 4,1),fpppp(22, 3, 4,2),fpppp(22, 3, 4,3)/
     x 1.0817598d-04, 6.7546763d-05, 1.3951578d-07 /
      data fpppp(22, 3, 5,1),fpppp(22, 3, 5,2),fpppp(22, 3, 5,3)/
     x-1.0242885d-04,-2.4320950d-04, 1.0132636d-07 /
      data fpppp(22, 3, 6,1),fpppp(22, 3, 6,2),fpppp(22, 3, 6,3)/
     x 5.1417676d-05, 2.8929619d-05, 4.6486059d-08 /
      data fpppp(22, 3, 7,1),fpppp(22, 3, 7,2),fpppp(22, 3, 7,3)/
     x 2.2879578d-04, 3.8741653d-05,-1.0174150d-08 /
      data fpppp(22, 3, 8,1),fpppp(22, 3, 8,2),fpppp(22, 3, 8,3)/
     x 2.9189136d-04, 1.7832326d-05,-4.8894800d-08 /
      data fpppp(22, 3, 9,1),fpppp(22, 3, 9,2),fpppp(22, 3, 9,3)/
     x 3.0798889d-04, 2.2392421d-05,-7.3271345d-08 /
      data fpppp(22, 3,10,1),fpppp(22, 3,10,2),fpppp(22, 3,10,3)/
     x 3.2192912d-04, 1.6987239d-05,-8.7104330d-08 /
      data fpppp(22, 3,11,1),fpppp(22, 3,11,2),fpppp(22, 3,11,3)/
     x 3.2105371d-04, 1.5773743d-05,-9.2292211d-08 /
      data fpppp(22, 3,12,1),fpppp(22, 3,12,2),fpppp(22, 3,12,3)/
     x 3.3392486d-04, 1.5044631d-05,-9.3090660d-08 /
      data fpppp(22, 3,13,1),fpppp(22, 3,13,2),fpppp(22, 3,13,3)/
     x 3.3808914d-04, 1.5771387d-05,-9.2322678d-08 /
      data fpppp(22, 3,14,1),fpppp(22, 3,14,2),fpppp(22, 3,14,3)/
     x 3.2019429d-04, 1.6370202d-05,-8.7260323d-08 /
      data fpppp(22, 3,15,1),fpppp(22, 3,15,2),fpppp(22, 3,15,3)/
     x 3.0687135d-04, 2.2517234d-05,-7.3309456d-08 /
      data fpppp(22, 3,16,1),fpppp(22, 3,16,2),fpppp(22, 3,16,3)/
     x 2.9376429d-04, 1.5407089d-05,-4.8880798d-08 /
      data fpppp(22, 3,17,1),fpppp(22, 3,17,2),fpppp(22, 3,17,3)/
     x 2.3535820d-04, 4.7821241d-05,-9.3114020d-09 /
      data fpppp(22, 3,18,1),fpppp(22, 3,18,2),fpppp(22, 3,18,3)/
     x 6.6360870d-05, 6.9062080d-06, 4.7718283d-08 /
      data fpppp(22, 3,19,1),fpppp(22, 3,19,2),fpppp(22, 3,19,3)/
     x-1.5830036d-04,-1.7246528d-04, 1.0382698d-07 /
      data fpppp(22, 3,20,1),fpppp(22, 3,20,2),fpppp(22, 3,20,3)/
     x 1.9249000d-05, 2.9861589d-05, 1.3736996d-07 /
      data fpppp(22, 3,21,1),fpppp(22, 3,21,2),fpppp(22, 3,21,3)/
     x 1.9249000d-05, 1.6865196d-05, 1.3929031d-07 /
      data fpppp(22, 3,22,1),fpppp(22, 3,22,2),fpppp(22, 3,22,3)/
     x-1.5830036d-04,-1.2047971d-04, 9.6145594d-08 /
      data fpppp(22, 3,23,1),fpppp(22, 3,23,2),fpppp(22, 3,23,3)/
     x 6.6360870d-05,-1.8803970d-04, 7.6523487d-08 /
      data fpppp(22, 4, 1,1),fpppp(22, 4, 1,2),fpppp(22, 4, 1,3)/
     x 6.2317909d-05, 6.1351064d-05,-3.3540181d-08 /
      data fpppp(22, 4, 2,1),fpppp(22, 4, 2,2),fpppp(22, 4, 2,3)/
     x-8.3026969d-06, 1.1838606d-05, 2.9763914d-08 /
      data fpppp(22, 4, 3,1),fpppp(22, 4, 3,2),fpppp(22, 4, 3,3)/
     x-4.4580036d-04,-9.2861516d-05, 1.6542885d-07 /
      data fpppp(22, 4, 4,1),fpppp(22, 4, 4,2),fpppp(22, 4, 4,3)/
     x-4.4580036d-04,-9.5308019d-05, 1.6540557d-07 /
      data fpppp(22, 4, 5,1),fpppp(22, 4, 5,2),fpppp(22, 4, 5,3)/
     x-8.3026969d-06, 2.1624618d-05, 2.9857020d-08 /
      data fpppp(22, 4, 6,1),fpppp(22, 4, 6,2),fpppp(22, 4, 6,3)/
     x 6.2317909d-05, 2.4653517d-05,-3.3889328d-08 /
      data fpppp(22, 4, 7,1),fpppp(22, 4, 7,2),fpppp(22, 4, 7,3)/
     x 3.0541107d-05, 2.0633165d-05,-5.4140812d-08 /
      data fpppp(22, 4, 8,1),fpppp(22, 4, 8,2),fpppp(22, 4, 8,3)/
     x 3.1448793d-05, 2.3092168d-05,-5.6464724d-08 /
      data fpppp(22, 4, 9,1),fpppp(22, 4, 9,2),fpppp(22, 4, 9,3)/
     x 3.1282355d-05, 1.7115584d-05,-5.1665705d-08 /
      data fpppp(22, 4,10,1),fpppp(22, 4,10,2),fpppp(22, 4,10,3)/
     x 2.9338413d-05, 1.5368824d-05,-3.9275700d-08 /
      data fpppp(22, 4,11,1),fpppp(22, 4,11,2),fpppp(22, 4,11,3)/
     x 2.9678474d-05, 1.2861102d-05,-2.8076814d-08 /
      data fpppp(22, 4,12,1),fpppp(22, 4,12,2),fpppp(22, 4,12,3)/
     x 2.5504929d-05, 1.1954953d-05,-2.4228522d-08 /
      data fpppp(22, 4,13,1),fpppp(22, 4,13,2),fpppp(22, 4,13,3)/
     x 2.3692059d-05, 1.2775293d-05,-2.8472562d-08 /
      data fpppp(22, 4,14,1),fpppp(22, 4,14,2),fpppp(22, 4,14,3)/
     x 2.7376322d-05, 1.4961524d-05,-3.9977798d-08 /
      data fpppp(22, 4,15,1),fpppp(22, 4,15,2),fpppp(22, 4,15,3)/
     x 2.8644000d-05, 1.7329390d-05,-5.2523517d-08 /
      data fpppp(22, 4,16,1),fpppp(22, 4,16,2),fpppp(22, 4,16,3)/
     x 2.8296111d-05, 2.1095959d-05,-5.7863474d-08 /
      data fpppp(22, 4,17,1),fpppp(22, 4,17,2),fpppp(22, 4,17,3)/
     x 3.0162854d-05, 2.4439606d-05,-5.7438967d-08 /
      data fpppp(22, 4,18,1),fpppp(22, 4,18,2),fpppp(22, 4,18,3)/
     x 6.3034964d-05, 2.4295185d-05,-3.8441915d-08 /
      data fpppp(22, 4,19,1),fpppp(22, 4,19,2),fpppp(22, 4,19,3)/
     x 9.6907484d-06, 3.5321147d-05, 2.2991413d-08 /
      data fpppp(22, 4,20,1),fpppp(22, 4,20,2),fpppp(22, 4,20,3)/
     x-3.8669419d-04,-1.0438772d-04, 1.7442763d-07 /
      data fpppp(22, 4,21,1),fpppp(22, 4,21,2),fpppp(22, 4,21,3)/
     x-3.8669419d-04,-1.0076952d-04, 1.7398917d-07 /
      data fpppp(22, 4,22,1),fpppp(22, 4,22,2),fpppp(22, 4,22,3)/
     x 9.6907484d-06, 2.0848344d-05, 2.4745256d-08 /
      data fpppp(22, 4,23,1),fpppp(22, 4,23,2),fpppp(22, 4,23,3)/
     x 6.3034964d-05, 7.8568198d-05,-4.5018825d-08 /
      data fpppp(22, 5, 1,1),fpppp(22, 5, 1,2),fpppp(22, 5, 1,3)/
     x 1.2661299d-05, 7.5860619d-06, 9.9500948d-09 /
      data fpppp(22, 5, 2,1),fpppp(22, 5, 2,2),fpppp(22, 5, 2,3)/
     x 4.8457903d-05,-8.4848602d-06, 4.4296376d-09 /
      data fpppp(22, 5, 3,1),fpppp(22, 5, 3,2),fpppp(22, 5, 3,3)/
     x 2.1003483d-04,-4.2873622d-05,-7.4332349d-09 /
      data fpppp(22, 5, 4,1),fpppp(22, 5, 4,2),fpppp(22, 5, 4,3)/
     x 2.1003483d-04,-4.2959247d-05,-7.3749223d-09 /
      data fpppp(22, 5, 5,1),fpppp(22, 5, 5,2),fpppp(22, 5, 5,3)/
     x 4.8457903d-05,-8.1423597d-06, 4.1963872d-09 /
      data fpppp(22, 5, 6,1),fpppp(22, 5, 6,2),fpppp(22, 5, 6,3)/
     x 1.2661299d-05, 6.3016851d-06, 1.0824784d-08 /
      data fpppp(22, 5, 7,1),fpppp(22, 5, 7,2),fpppp(22, 5, 7,3)/
     x 2.1823127d-05, 1.2329064d-05,-9.4755920d-10 /
      data fpppp(22, 5, 8,1),fpppp(22, 5, 8,2),fpppp(22, 5, 8,3)/
     x 2.4483131d-05, 1.3163795d-05,-3.1000012d-09 /
      data fpppp(22, 5, 9,1),fpppp(22, 5, 9,2),fpppp(22, 5, 9,3)/
     x 2.8760760d-05, 1.3110291d-05, 2.9939187d-09 /
      data fpppp(22, 5,10,1),fpppp(22, 5,10,2),fpppp(22, 5,10,3)/
     x 2.9796969d-05, 1.1343712d-05, 3.3418155d-09 /
      data fpppp(22, 5,11,1),fpppp(22, 5,11,2),fpppp(22, 5,11,3)/
     x 2.8051955d-05, 9.8428580d-06,-1.8390323d-09 /
      data fpppp(22, 5,12,1),fpppp(22, 5,12,2),fpppp(22, 5,12,3)/
     x 2.8287540d-05, 9.3671169d-06,-4.4559361d-09 /
      data fpppp(22, 5,13,1),fpppp(22, 5,13,2),fpppp(22, 5,13,3)/
     x 2.9897539d-05, 9.9876814d-06,-1.8258320d-09 /
      data fpppp(22, 5,14,1),fpppp(22, 5,14,2),fpppp(22, 5,14,3)/
     x 3.0936529d-05, 1.1575481d-05, 2.9872261d-09 /
      data fpppp(22, 5,15,1),fpppp(22, 5,15,2),fpppp(22, 5,15,3)/
     x 3.0799835d-05, 1.3572397d-05, 1.1794364d-09 /
      data fpppp(22, 5,16,1),fpppp(22, 5,16,2),fpppp(22, 5,16,3)/
     x 2.7897765d-05, 1.4027027d-05,-6.1846660d-09 /
      data fpppp(22, 5,17,1),fpppp(22, 5,17,2),fpppp(22, 5,17,3)/
     x 2.4987963d-05, 1.4210091d-05,-4.8312069d-09 /
      data fpppp(22, 5,18,1),fpppp(22, 5,18,2),fpppp(22, 5,18,3)/
     x 1.7211363d-05, 1.0396918d-05, 7.3626395d-09 /
      data fpppp(22, 5,19,1),fpppp(22, 5,19,2),fpppp(22, 5,19,3)/
     x 4.7683847d-05,-7.1756933d-06, 5.4527962d-09 /
      data fpppp(22, 5,20,1),fpppp(22, 5,20,2),fpppp(22, 5,20,3)/
     x 2.0798473d-04,-4.6340586d-05,-2.7354607d-09 /
      data fpppp(22, 5,21,1),fpppp(22, 5,21,2),fpppp(22, 5,21,3)/
     x 2.0798473d-04,-4.6307152d-05,-2.6447324d-09 /
      data fpppp(22, 5,22,1),fpppp(22, 5,22,2),fpppp(22, 5,22,3)/
     x 4.7683847d-05,-7.3094285d-06, 5.0898829d-09 /
      data fpppp(22, 5,23,1),fpppp(22, 5,23,2),fpppp(22, 5,23,3)/
     x 1.7211363d-05, 1.0898425d-05, 8.7235642d-09 /
      data fpppp(22, 6, 1,1),fpppp(22, 6, 1,2),fpppp(22, 6, 1,3)/
     x 1.5241105d-05,-2.2431123d-06, 3.3421541d-09 /
      data fpppp(22, 6, 2,1),fpppp(22, 6, 2,2),fpppp(22, 6, 2,3)/
     x 2.6185467d-05,-7.3888492d-06,-1.2837168d-08 /
      data fpppp(22, 6, 3,1),fpppp(22, 6, 3,2),fpppp(22, 6, 3,3)/
     x 4.9286263d-06,-1.8456442d-05,-4.7359445d-08 /
      data fpppp(22, 6, 4,1),fpppp(22, 6, 4,2),fpppp(22, 6, 4,3)/
     x 4.9286263d-06,-1.8384668d-05,-4.7617919d-08 /
      data fpppp(22, 6, 5,1),fpppp(22, 6, 5,2),fpppp(22, 6, 5,3)/
     x 2.6185467d-05,-7.6759473d-06,-1.1803272d-08 /
      data fpppp(22, 6, 6,1),fpppp(22, 6, 6,2),fpppp(22, 6, 6,3)/
     x 1.5241105d-05,-1.1664944d-06,-5.3495494d-10 /
      data fpppp(22, 6, 7,1),fpppp(22, 6, 7,2),fpppp(22, 6, 7,3)/
     x 6.2035931d-07, 4.0169030d-06, 1.4952346d-08 /
      data fpppp(22, 6, 8,1),fpppp(22, 6, 8,2),fpppp(22, 6, 8,3)/
     x-7.0587408d-06, 6.0028446d-06, 2.0224691d-08 /
      data fpppp(22, 6, 9,1),fpppp(22, 6, 9,2),fpppp(22, 6, 9,3)/
     x-1.2049520d-05, 6.1280645d-06, 1.6228887d-08 /
      data fpppp(22, 6,10,1),fpppp(22, 6,10,2),fpppp(22, 6,10,3)/
     x-1.2210858d-05, 6.5451663d-06, 1.2873049d-08 /
      data fpppp(22, 6,11,1),fpppp(22, 6,11,2),fpppp(22, 6,11,3)/
     x-9.1526523d-06, 7.2739344d-06, 1.4195642d-08 /
      data fpppp(22, 6,12,1),fpppp(22, 6,12,2),fpppp(22, 6,12,3)/
     x-7.4786836d-06, 7.7799886d-06, 1.5476860d-08 /
      data fpppp(22, 6,13,1),fpppp(22, 6,13,2),fpppp(22, 6,13,3)/
     x-8.7039417d-06, 7.7070166d-06, 1.3554820d-08 /
      data fpppp(22, 6,14,1),fpppp(22, 6,14,2),fpppp(22, 6,14,3)/
     x-1.0848971d-05, 7.4542675d-06, 1.1008581d-08 /
      data fpppp(22, 6,15,1),fpppp(22, 6,15,2),fpppp(22, 6,15,3)/
     x-1.0455425d-05, 7.6683972d-06, 1.3908091d-08 /
      data fpppp(22, 6,16,1),fpppp(22, 6,16,2),fpppp(22, 6,16,3)/
     x-5.6983952d-06, 7.9677055d-06, 1.7413170d-08 /
      data fpppp(22, 6,17,1),fpppp(22, 6,17,2),fpppp(22, 6,17,3)/
     x 1.5926980d-06, 6.8069113d-06, 1.3217343d-08 /
      data fpppp(22, 6,18,1),fpppp(22, 6,18,2),fpppp(22, 6,18,3)/
     x 1.4472028d-05, 1.3101041d-06,-6.7387009d-10 /
      data fpppp(22, 6,19,1),fpppp(22, 6,19,2),fpppp(22, 6,19,3)/
     x 2.5650843d-05,-6.6651835d-06,-1.0275236d-08 /
      data fpppp(22, 6,20,1),fpppp(22, 6,20,2),fpppp(22, 6,20,3)/
     x 3.3294463d-06,-2.2361642d-05,-4.5690005d-08 /
      data fpppp(22, 6,21,1),fpppp(22, 6,21,2),fpppp(22, 6,21,3)/
     x 3.3294463d-06,-2.2392510d-05,-4.5361261d-08 /
      data fpppp(22, 6,22,1),fpppp(22, 6,22,2),fpppp(22, 6,22,3)/
     x 2.5650843d-05,-6.5417139d-06,-1.1590210d-08 /
      data fpppp(22, 6,23,1),fpppp(22, 6,23,2),fpppp(22, 6,23,3)/
     x 1.4472028d-05, 8.4709279d-07, 4.2572795d-09 /
      data fpppp(22, 7, 1,1),fpppp(22, 7, 1,2),fpppp(22, 7, 1,3)/
     x 9.9499793d-06,-2.7792332d-06,-3.0874264d-09 /
      data fpppp(22, 7, 2,1),fpppp(22, 7, 2,2),fpppp(22, 7, 2,3)/
     x 2.2855843d-05,-3.9832883d-06,-1.3553534d-08 /
      data fpppp(22, 7, 3,1),fpppp(22, 7, 3,2),fpppp(22, 7, 3,3)/
     x 4.4766928d-05,-6.5897837d-06,-3.6149991d-08 /
      data fpppp(22, 7, 4,1),fpppp(22, 7, 4,2),fpppp(22, 7, 4,3)/
     x 4.4766928d-05,-6.5436235d-06,-3.5854096d-08 /
      data fpppp(22, 7, 5,1),fpppp(22, 7, 5,2),fpppp(22, 7, 5,3)/
     x 2.2855843d-05,-4.1679293d-06,-1.4737112d-08 /
      data fpppp(22, 7, 6,1),fpppp(22, 7, 6,2),fpppp(22, 7, 6,3)/
     x 9.9499793d-06,-2.0868294d-06, 1.3509896d-09 /
      data fpppp(22, 7, 7,1),fpppp(22, 7, 7,2),fpppp(22, 7, 7,3)/
     x-1.4659054d-07,-4.6604688d-07, 9.1481771d-09 /
      data fpppp(22, 7, 8,1),fpppp(22, 7, 8,2),fpppp(22, 7, 8,3)/
     x-7.4222340d-06, 1.0628890d-06, 1.2005282d-08 /
      data fpppp(22, 7, 9,1),fpppp(22, 7, 9,2),fpppp(22, 7, 9,3)/
     x-1.1104387d-05, 2.3970485d-06, 1.4624355d-08 /
      data fpppp(22, 7,10,1),fpppp(22, 7,10,2),fpppp(22, 7,10,3)/
     x-1.3743840d-05, 3.6398290d-06, 1.5186653d-08 /
      data fpppp(22, 7,11,1),fpppp(22, 7,11,2),fpppp(22, 7,11,3)/
     x-1.6210727d-05, 4.1504860d-06, 1.2999983d-08 /
      data fpppp(22, 7,12,1),fpppp(22, 7,12,2),fpppp(22, 7,12,3)/
     x-1.7067267d-05, 4.5717520d-06, 1.0793749d-08 /
      data fpppp(22, 7,13,1),fpppp(22, 7,13,2),fpppp(22, 7,13,3)/
     x-1.5451796d-05, 4.7148262d-06, 1.1682025d-08 /
      data fpppp(22, 7,14,1),fpppp(22, 7,14,2),fpppp(22, 7,14,3)/
     x-1.2359368d-05, 5.0271283d-06, 1.3631307d-08 /
      data fpppp(22, 7,15,1),fpppp(22, 7,15,2),fpppp(22, 7,15,3)/
     x-9.3246045d-06, 4.6205761d-06, 1.3061294d-08 /
      data fpppp(22, 7,16,1),fpppp(22, 7,16,2),fpppp(22, 7,16,3)/
     x-6.0090565d-06, 3.7589393d-06, 1.0746742d-08 /
      data fpppp(22, 7,17,1),fpppp(22, 7,17,2),fpppp(22, 7,17,3)/
     x 2.8793419d-07, 2.2552989d-06, 7.5097093d-09 /
      data fpppp(22, 7,18,1),fpppp(22, 7,18,2),fpppp(22, 7,18,3)/
     x 9.7106199d-06,-4.2169162d-07, 6.0658860d-10 /
      data fpppp(22, 7,19,1),fpppp(22, 7,19,2),fpppp(22, 7,19,3)/
     x 2.1818949d-05,-4.2936444d-06,-1.3994715d-08 /
      data fpppp(22, 7,20,1),fpppp(22, 7,20,2),fpppp(22, 7,20,3)/
     x 4.1340059d-05,-9.9414987d-06,-3.3766810d-08 /
      data fpppp(22, 7,21,1),fpppp(22, 7,21,2),fpppp(22, 7,21,3)/
     x 4.1340059d-05,-1.0000183d-05,-3.4021921d-08 /
      data fpppp(22, 7,22,1),fpppp(22, 7,22,2),fpppp(22, 7,22,3)/
     x 2.1818949d-05,-4.0589063d-06,-1.2974274d-08 /
      data fpppp(22, 7,23,1),fpppp(22, 7,23,2),fpppp(22, 7,23,3)/
     x 9.7106199d-06,-1.3019595d-06,-3.2200678d-09 /
      data fpppp(22, 8, 1,1),fpppp(22, 8, 1,2),fpppp(22, 8, 1,3)/
     x 3.8431438d-06, 1.7392947d-06,-1.9785118d-10 /
      data fpppp(22, 8, 2,1),fpppp(22, 8, 2,2),fpppp(22, 8, 2,3)/
     x 1.0941115d-05, 7.8940214d-08,-7.2678889d-09 /
      data fpppp(22, 8, 3,1),fpppp(22, 8, 3,2),fpppp(22, 8, 3,3)/
     x 1.3297586d-05,-3.3262625d-06,-2.2478411d-08 /
      data fpppp(22, 8, 4,1),fpppp(22, 8, 4,2),fpppp(22, 8, 4,3)/
     x 1.3297586d-05,-3.5934869d-06,-2.2372639d-08 /
      data fpppp(22, 8, 5,1),fpppp(22, 8, 5,2),fpppp(22, 8, 5,3)/
     x 1.0941115d-05, 1.1478378d-06,-7.6909806d-09 /
      data fpppp(22, 8, 6,1),fpppp(22, 8, 6,2),fpppp(22, 8, 6,3)/
     x 3.8431438d-06,-2.2690713d-06, 1.3887426d-09 /
      data fpppp(22, 8, 7,1),fpppp(22, 8, 7,2),fpppp(22, 8, 7,3)/
     x-2.1185109d-06,-1.0120085d-06, 6.5466616d-09 /
      data fpppp(22, 8, 8,1),fpppp(22, 8, 8,2),fpppp(22, 8, 8,3)/
     x-6.6896962d-06,-7.4729274d-07, 8.1295723d-09 /
      data fpppp(22, 8, 9,1),fpppp(22, 8, 9,2),fpppp(22, 8, 9,3)/
     x-1.0283922d-05, 2.4918917d-07, 8.0804155d-09 /
      data fpppp(22, 8,10,1),fpppp(22, 8,10,2),fpppp(22, 8,10,3)/
     x-1.2760302d-05, 1.3901803d-06, 7.6580577d-09 /
      data fpppp(22, 8,11,1),fpppp(22, 8,11,2),fpppp(22, 8,11,3)/
     x-1.3892051d-05, 2.0755613d-06, 7.2068259d-09 /
      data fpppp(22, 8,12,1),fpppp(22, 8,12,2),fpppp(22, 8,12,3)/
     x-1.3861144d-05, 2.7335437d-06, 7.1008149d-09 /
      data fpppp(22, 8,13,1),fpppp(22, 8,13,2),fpppp(22, 8,13,3)/
     x-1.3259057d-05, 2.7539924d-06, 6.8639882d-09 /
      data fpppp(22, 8,14,1),fpppp(22, 8,14,2),fpppp(22, 8,14,3)/
     x-1.1776620d-05, 2.9729432d-06, 7.2858794d-09 /
      data fpppp(22, 8,15,1),fpppp(22, 8,15,2),fpppp(22, 8,15,3)/
     x-9.0901944d-06, 2.5614857d-06, 7.4210708d-09 /
      data fpppp(22, 8,16,1),fpppp(22, 8,16,2),fpppp(22, 8,16,3)/
     x-5.0106643d-06, 2.1020222d-06, 7.0028233d-09 /
      data fpppp(22, 8,17,1),fpppp(22, 8,17,2),fpppp(22, 8,17,3)/
     x-6.3127764d-07, 1.2672497d-06, 3.7976401d-09 /
      data fpppp(22, 8,18,1),fpppp(22, 8,18,2),fpppp(22, 8,18,3)/
     x 3.9537539d-06,-6.6292851d-07,-2.4907249d-09 /
      data fpppp(22, 8,19,1),fpppp(22, 8,19,2),fpppp(22, 8,19,3)/
     x 8.6032885d-06,-2.3413411d-06,-9.8867601d-09 /
      data fpppp(22, 8,20,1),fpppp(22, 8,20,2),fpppp(22, 8,20,3)/
     x 9.8299635d-06,-4.6069198d-06,-1.6501084d-08 /
      data fpppp(22, 8,21,1),fpppp(22, 8,21,2),fpppp(22, 8,21,3)/
     x 9.8299635d-06,-4.6364044d-06,-1.6705641d-08 /
      data fpppp(22, 8,22,1),fpppp(22, 8,22,2),fpppp(22, 8,22,3)/
     x 8.6032885d-06,-2.2234026d-06,-9.0685289d-09 /
      data fpppp(22, 8,23,1),fpppp(22, 8,23,2),fpppp(22, 8,23,3)/
     x 3.9537539d-06,-1.1051977d-06,-5.5590918d-09 /
      data fpppp(22, 9, 1,1),fpppp(22, 9, 1,2),fpppp(22, 9, 1,3)/
     x 1.2771522d-06, 4.5106706d-06, 9.6171109d-09 /
      data fpppp(22, 9, 2,1),fpppp(22, 9, 2,2),fpppp(22, 9, 2,3)/
     x 6.4938589d-06, 1.8108360d-06, 6.9853048d-10 /
      data fpppp(22, 9, 3,1),fpppp(22, 9, 3,2),fpppp(22, 9, 3,3)/
     x 6.8600196d-06,-3.8055808d-06,-1.8328405d-08 /
      data fpppp(22, 9, 4,1),fpppp(22, 9, 4,2),fpppp(22, 9, 4,3)/
     x 6.8600196d-06,-4.1012314d-06,-1.8475944d-08 /
      data fpppp(22, 9, 5,1),fpppp(22, 9, 5,2),fpppp(22, 9, 5,3)/
     x 6.4938589d-06, 2.9934383d-06, 1.2886863d-09 /
      data fpppp(22, 9, 6,1),fpppp(22, 9, 6,2),fpppp(22, 9, 6,3)/
     x 1.2771522d-06, 7.5912036d-08, 7.4040266d-09 /
      data fpppp(22, 9, 7,1),fpppp(22, 9, 7,2),fpppp(22, 9, 7,3)/
     x-3.1800491d-06,-8.2640141d-08, 6.7175774d-09 /
      data fpppp(22, 9, 8,1),fpppp(22, 9, 8,2),fpppp(22, 9, 8,3)/
     x-5.9649922d-06,-9.3095694d-07, 2.9968386d-09 /
      data fpppp(22, 9, 9,1),fpppp(22, 9, 9,2),fpppp(22, 9, 9,3)/
     x-7.3628813d-06,-9.9168936d-07, 1.7199446d-09 /
      data fpppp(22, 9,10,1),fpppp(22, 9,10,2),fpppp(22, 9,10,3)/
     x-7.9557565d-06, 2.0518996d-07, 2.5168612d-09 /
      data fpppp(22, 9,11,1),fpppp(22, 9,11,2),fpppp(22, 9,11,3)/
     x-7.8667800d-06, 1.0679630d-06, 3.8037715d-09 /
      data fpppp(22, 9,12,1),fpppp(22, 9,12,2),fpppp(22, 9,12,3)/
     x-7.9193442d-06, 1.6808054d-06, 4.2630120d-09 /
      data fpppp(22, 9,13,1),fpppp(22, 9,13,2),fpppp(22, 9,13,3)/
     x-7.5618809d-06, 1.7507052d-06, 3.8308796d-09 /
      data fpppp(22, 9,14,1),fpppp(22, 9,14,2),fpppp(22, 9,14,3)/
     x-6.7771106d-06, 1.7287699d-06, 2.8897223d-09 /
      data fpppp(22, 9,15,1),fpppp(22, 9,15,2),fpppp(22, 9,15,3)/
     x-5.3997470d-06, 1.6556826d-06, 2.7073778d-09 /
      data fpppp(22, 9,16,1),fpppp(22, 9,16,2),fpppp(22, 9,16,3)/
     x-3.6435831d-06, 1.2539478d-06, 2.3255985d-09 /
      data fpppp(22, 9,17,1),fpppp(22, 9,17,2),fpppp(22, 9,17,3)/
     x-1.0250916d-06, 9.3373981d-07, 1.5122415d-09 /
      data fpppp(22, 9,18,1),fpppp(22, 9,18,2),fpppp(22, 9,18,3)/
     x 1.7830425d-06,-1.9324821d-07,-7.7736757d-10 /
      data fpppp(22, 9,19,1),fpppp(22, 9,19,2),fpppp(22, 9,19,3)/
     x 4.1732145d-06,-1.3615517d-06,-4.6560416d-09 /
      data fpppp(22, 9,20,1),fpppp(22, 9,20,2),fpppp(22, 9,20,3)/
     x 6.4535432d-06,-2.4817040d-06,-7.2239880d-09 /
      data fpppp(22, 9,21,1),fpppp(22, 9,21,2),fpppp(22, 9,21,3)/
     x 6.4535432d-06,-2.5123479d-06,-7.3512174d-09 /
      data fpppp(22, 9,22,1),fpppp(22, 9,22,2),fpppp(22, 9,22,3)/
     x 4.1732145d-06,-1.2389759d-06,-4.1471241d-09 /
      data fpppp(22, 9,23,1),fpppp(22, 9,23,2),fpppp(22, 9,23,3)/
     x 1.7830425d-06,-6.5290738d-07,-2.6858083d-09 /
      data fpppp(22,10, 1,1),fpppp(22,10, 1,2),fpppp(22,10, 1,3)/
     x-2.3433850d-06, 4.2764516d-06, 1.2754381d-08 /
      data fpppp(22,10, 2,1),fpppp(22,10, 2,2),fpppp(22,10, 2,3)/
     x 1.2902773d-06, 9.7588324d-07, 4.0038191d-09 /
      data fpppp(22,10, 3,1),fpppp(22,10, 3,2),fpppp(22,10, 3,3)/
     x 1.3964588d-05,-6.1149449d-06,-1.4553150d-08 /
      data fpppp(22,10, 4,1),fpppp(22,10, 4,2),fpppp(22,10, 4,3)/
     x 1.3964588d-05,-6.0831269d-06,-1.4893063d-08 /
      data fpppp(22,10, 5,1),fpppp(22,10, 5,2),fpppp(22,10, 5,3)/
     x 1.2902773d-06, 8.4861131d-07, 5.3634729d-09 /
      data fpppp(22,10, 6,1),fpppp(22,10, 6,2),fpppp(22,10, 6,3)/
     x-2.3433850d-06, 4.7537213d-06, 7.6556799d-09 /
      data fpppp(22,10, 7,1),fpppp(22,10, 7,2),fpppp(22,10, 7,3)/
     x-3.5266443d-06, 2.1305924d-06, 4.9536762d-09 /
      data fpppp(22,10, 8,1),fpppp(22,10, 8,2),fpppp(22,10, 8,3)/
     x-4.2128468d-06,-6.3448400d-09, 2.2999549d-09 /
      data fpppp(22,10, 9,1),fpppp(22,10, 9,2),fpppp(22,10, 9,3)/
     x-4.6917414d-06,-1.2170542d-06,-7.8366881d-11 /
      data fpppp(22,10,10,1),fpppp(22,10,10,2),fpppp(22,10,10,3)/
     x-4.0028875d-06,-6.4448169d-07, 5.0308528d-11 /
      data fpppp(22,10,11,1),fpppp(22,10,11,2),fpppp(22,10,11,3)/
     x-4.8268419d-06, 2.6280572d-07, 1.3930173d-09 /
      data fpppp(22,10,12,1),fpppp(22,10,12,2),fpppp(22,10,12,3)/
     x-4.6711273d-06, 1.0591468d-06, 2.1316088d-09 /
      data fpppp(22,10,13,1),fpppp(22,10,13,2),fpppp(22,10,13,3)/
     x-4.4156409d-06, 1.1317194d-06, 1.8596773d-09 /
      data fpppp(22,10,14,1),fpppp(22,10,14,2),fpppp(22,10,14,3)/
     x-3.9980679d-06, 1.2679770d-06, 1.2420234d-09 /
      data fpppp(22,10,15,1),fpppp(22,10,15,2),fpppp(22,10,15,3)/
     x-3.2055606d-06, 1.1813516d-06, 8.3506603d-10 /
      data fpppp(22,10,16,1),fpppp(22,10,16,2),fpppp(22,10,16,3)/
     x-2.0558770d-06, 1.1620862d-06, 6.6539923d-10 /
      data fpppp(22,10,17,1),fpppp(22,10,17,2),fpppp(22,10,17,3)/
     x-1.0877603d-06, 7.1150686d-07, 3.8527982d-10 /
      data fpppp(22,10,18,1),fpppp(22,10,18,2),fpppp(22,10,18,3)/
     x-1.9335102d-07,-3.4381213d-08,-4.5796504d-10 /
      data fpppp(22,10,19,1),fpppp(22,10,19,2),fpppp(22,10,19,3)/
     x 4.8460480d-07,-1.0735844d-06,-1.4083187d-09 /
      data fpppp(22,10,20,1),fpppp(22,10,20,2),fpppp(22,10,20,3)/
     x 7.1268091d-07,-1.5904999d-06,-3.1078236d-09 /
      data fpppp(22,10,21,1),fpppp(22,10,21,2),fpppp(22,10,21,3)/
     x 7.1268091d-07,-1.6283785d-06,-3.1152881d-09 /
      data fpppp(22,10,22,1),fpppp(22,10,22,2),fpppp(22,10,22,3)/
     x 4.8460480d-07,-9.2206996d-07,-1.3784608d-09 /
      data fpppp(22,10,23,1),fpppp(22,10,23,2),fpppp(22,10,23,3)/
     x-1.9335102d-07,-6.0256028d-07,-5.6993194d-10 /
      data fpppp(22,11, 1,1),fpppp(22,11, 1,2),fpppp(22,11, 1,3)/
     x-9.0978890d-07, 1.2530685d-05, 1.3983452d-10 /
      data fpppp(22,11, 2,1),fpppp(22,11, 2,2),fpppp(22,11, 2,3)/
     x 5.6089198d-07, 4.1201224d-06,-1.0127497d-09 /
      data fpppp(22,11, 3,1),fpppp(22,11, 3,2),fpppp(22,11, 3,3)/
     x-1.0277830d-05,-1.3826884d-05,-3.4776965d-09 /
      data fpppp(22,11, 4,1),fpppp(22,11, 4,2),fpppp(22,11, 4,3)/
     x-1.0277830d-05,-1.3959234d-05,-3.4862304d-09 /
      data fpppp(22,11, 5,1),fpppp(22,11, 5,2),fpppp(22,11, 5,3)/
     x 5.6089198d-07, 4.6495216d-06,-9.7861391d-10 /
      data fpppp(22,11, 6,1),fpppp(22,11, 6,2),fpppp(22,11, 6,3)/
     x-9.0978890d-07, 1.0545438d-05, 1.1825289d-11 /
      data fpppp(22,11, 7,1),fpppp(22,11, 7,2),fpppp(22,11, 7,3)/
     x-1.7866239d-06, 5.0974199d-06, 1.8694686d-09 /
      data fpppp(22,11, 8,1),fpppp(22,11, 8,2),fpppp(22,11, 8,3)/
     x-2.1629400d-06, 9.5098480d-07, 1.7577679d-09 /
      data fpppp(22,11, 9,1),fpppp(22,11, 9,2),fpppp(22,11, 9,3)/
     x-2.5637113d-06,-1.3505439d-07, 1.4940680d-09 /
      data fpppp(22,11,10,1),fpppp(22,11,10,2),fpppp(22,11,10,3)/
     x-4.3018565d-06,-2.6176949d-06, 5.2529854d-10 /
      data fpppp(22,11,11,1),fpppp(22,11,11,2),fpppp(22,11,11,3)/
     x-2.9124772d-06, 4.0259335d-07, 3.1003875d-10 /
      data fpppp(22,11,12,1),fpppp(22,11,12,2),fpppp(22,11,12,3)/
     x-2.7681543d-06, 3.1332868d-07, 3.0364042d-10 /
      data fpppp(22,11,13,1),fpppp(22,11,13,2),fpppp(22,11,13,3)/
     x-2.6981329d-06, 7.9924016d-07, 8.3218102d-10 /
      data fpppp(22,11,14,1),fpppp(22,11,14,2),fpppp(22,11,14,3)/
     x-2.3325021d-06, 1.1565799d-06, 8.4201633d-10 /
      data fpppp(22,11,15,1),fpppp(22,11,15,2),fpppp(22,11,15,3)/
     x-2.0011596d-06, 1.0809732d-06, 3.3125874d-10 /
      data fpppp(22,11,16,1),fpppp(22,11,16,2),fpppp(22,11,16,3)/
     x-1.6925567d-06, 1.0097844d-06,-3.2263015d-10 /
      data fpppp(22,11,17,1),fpppp(22,11,17,2),fpppp(22,11,17,3)/
     x-1.3594035d-06, 5.1769207d-07,-1.0522501d-11 /
      data fpppp(22,11,18,1),fpppp(22,11,18,2),fpppp(22,11,18,3)/
     x-1.1253259d-06,-1.3300928d-07, 5.3330942d-10 /
      data fpppp(22,11,19,1),fpppp(22,11,19,2),fpppp(22,11,19,3)/
     x-8.6759950d-07,-1.0441820d-06, 1.5101512d-09 /
      data fpppp(22,11,20,1),fpppp(22,11,20,2),fpppp(22,11,20,3)/
     x-4.1633613d-07,-1.1233660d-06,-2.5521392d-09 /
      data fpppp(22,11,21,1),fpppp(22,11,21,2),fpppp(22,11,21,3)/
     x-4.1633613d-07,-1.1648638d-06,-2.4157827d-09 /
      data fpppp(22,11,22,1),fpppp(22,11,22,2),fpppp(22,11,22,3)/
     x-8.6759950d-07,-8.7819085d-07, 9.6472513d-10 /
      data fpppp(22,11,23,1),fpppp(22,11,23,2),fpppp(22,11,23,3)/
     x-1.1253259d-06,-7.5547620d-07, 2.5786572d-09 /
      data fpppp(22,12, 1,1),fpppp(22,12, 1,2),fpppp(22,12, 1,3)/
     x 4.4482677d-06, 1.2325073d-05,-2.8708735d-08 /
      data fpppp(22,12, 2,1),fpppp(22,12, 2,2),fpppp(22,12, 2,3)/
     x 3.3097725d-06, 2.4347432d-06,-1.3562789d-08 /
      data fpppp(22,12, 3,1),fpppp(22,12, 3,2),fpppp(22,12, 3,3)/
     x 1.7118468d-05,-1.9010277d-05, 1.8378824d-08 /
      data fpppp(22,12, 4,1),fpppp(22,12, 4,2),fpppp(22,12, 4,3)/
     x 1.7118468d-05,-1.8570229d-05, 1.9278303d-08 /
      data fpppp(22,12, 5,1),fpppp(22,12, 5,2),fpppp(22,12, 5,3)/
     x 3.3097725d-06, 6.7455146d-07,-1.7160702d-08 /
      data fpppp(22,12, 6,1),fpppp(22,12, 6,2),fpppp(22,12, 6,3)/
     x 4.4482677d-06, 1.8925792d-05,-1.5216560d-08 /
      data fpppp(22,12, 7,1),fpppp(22,12, 7,2),fpppp(22,12, 7,3)/
     x 3.1098146d-06, 7.8344177d-06,-6.2655494d-09 /
      data fpppp(22,12, 8,1),fpppp(22,12, 8,2),fpppp(22,12, 8,3)/
     x 1.4727277d-06, 2.4394953d-06, 1.9585478d-09 /
      data fpppp(22,12, 9,1),fpppp(22,12, 9,2),fpppp(22,12, 9,3)/
     x-5.4141866d-09,-6.7951690d-07, 3.9777965d-09 /
      data fpppp(22,12,10,1),fpppp(22,12,10,2),fpppp(22,12,10,3)/
     x-5.3999838d-08,-1.3684299d-06, 2.4961173d-09 /
      data fpppp(22,12,11,1),fpppp(22,12,11,2),fpppp(22,12,11,3)/
     x-1.4117930d-06,-1.0329876d-06, 2.2064616d-10 /
      data fpppp(22,12,12,1),fpppp(22,12,12,2),fpppp(22,12,12,3)/
     x-1.4755736d-06,-6.0037556d-08, 3.9093550d-10 /
      data fpppp(22,12,13,1),fpppp(22,12,13,2),fpppp(22,12,13,3)/
     x-1.2565867d-06, 6.3765557d-07, 4.0935620d-10 /
      data fpppp(22,12,14,1),fpppp(22,12,14,2),fpppp(22,12,14,3)/
     x-1.3383935d-06, 1.0328829d-06, 5.8177478d-10 /
      data fpppp(22,12,15,1),fpppp(22,12,15,2),fpppp(22,12,15,3)/
     x-1.4822011d-06, 1.0346804d-06, 2.7468734d-10 /
      data fpppp(22,12,16,1),fpppp(22,12,16,2),fpppp(22,12,16,3)/
     x-1.6791228d-06, 8.6654451d-07, 9.4104595d-11 /
      data fpppp(22,12,17,1),fpppp(22,12,17,2),fpppp(22,12,17,3)/
     x-1.7772648d-06, 2.4895833d-07,-6.5391101d-10 /
      data fpppp(22,12,18,1),fpppp(22,12,18,2),fpppp(22,12,18,3)/
     x-1.7603278d-06,-2.9595432d-07, 9.8628927d-11 /
      data fpppp(22,12,19,1),fpppp(22,12,19,2),fpppp(22,12,19,3)/
     x-1.7913038d-06,-8.5236369d-07, 4.6282878d-10 /
      data fpppp(22,12,20,1),fpppp(22,12,20,2),fpppp(22,12,20,3)/
     x-1.8352576d-06,-9.3028900d-07,-1.9798090d-10 /
      data fpppp(22,12,21,1),fpppp(22,12,21,2),fpppp(22,12,21,3)/
     x-1.8352576d-06,-9.5497465d-07,-1.6605474d-10 /
      data fpppp(22,12,22,1),fpppp(22,12,22,2),fpppp(22,12,22,3)/
     x-1.7913038d-06,-7.5362112d-07, 3.3512415d-10 /
      data fpppp(22,12,23,1),fpppp(22,12,23,2),fpppp(22,12,23,3)/
     x-1.7603278d-06,-6.6623897d-07, 5.7752128d-10 /
      data fpppp(22,13, 1,1),fpppp(22,13, 1,2),fpppp(22,13, 1,3)/
     x 5.4615313d-06, 2.3188907d-05,-3.6853432d-08 /
      data fpppp(22,13, 2,1),fpppp(22,13, 2,2),fpppp(22,13, 2,3)/
     x-2.5145905d-06, 7.0492685d-06,-1.4449018d-08 /
      data fpppp(22,13, 3,1),fpppp(22,13, 3,2),fpppp(22,13, 3,3)/
     x-2.4935127d-05,-2.7427789d-05, 3.3122624d-08 /
      data fpppp(22,13, 4,1),fpppp(22,13, 4,2),fpppp(22,13, 4,3)/
     x-2.4935127d-05,-2.7616582d-05, 3.3888806d-08 /
      data fpppp(22,13, 5,1),fpppp(22,13, 5,2),fpppp(22,13, 5,3)/
     x-2.5145905d-06, 7.8044435d-06,-1.7513747d-08 /
      data fpppp(22,13, 6,1),fpppp(22,13, 6,2),fpppp(22,13, 6,3)/
     x 5.4615313d-06, 2.0357001d-05,-2.5360696d-08 /
      data fpppp(22,13, 7,1),fpppp(22,13, 7,2),fpppp(22,13, 7,3)/
     x 6.8724307d-06, 1.1383966d-05,-1.5691656d-08 /
      data fpppp(22,13, 8,1),fpppp(22,13, 8,2),fpppp(22,13, 8,3)/
     x 4.8534381d-06, 3.5030413d-06,-3.2793089d-09 /
      data fpppp(22,13, 9,1),fpppp(22,13, 9,2),fpppp(22,13, 9,3)/
     x 2.7860423d-06, 2.2624910d-07, 3.0685307d-09 /
      data fpppp(22,13,10,1),fpppp(22,13,10,2),fpppp(22,13,10,3)/
     x 7.7455748d-07,-1.0583525d-06, 3.5224441d-09 /
      data fpppp(22,13,11,1),fpppp(22,13,11,2),fpppp(22,13,11,3)/
     x-9.9312182d-08,-1.1337373d-06, 2.1247443d-09 /
      data fpppp(22,13,12,1),fpppp(22,13,12,2),fpppp(22,13,12,3)/
     x-5.0224251d-07,-4.3160878d-07, 7.1093495d-10 /
      data fpppp(22,13,13,1),fpppp(22,13,13,2),fpppp(22,13,13,3)/
     x-7.6975440d-07, 3.2624678d-07, 4.5975699d-10 /
      data fpppp(22,13,14,1),fpppp(22,13,14,2),fpppp(22,13,14,3)/
     x-7.7090147d-07, 8.6548713d-07, 5.3511592d-10 /
      data fpppp(22,13,15,1),fpppp(22,13,15,2),fpppp(22,13,15,3)/
     x-8.4757064d-07, 9.5519291d-07, 2.6370360d-10 /
      data fpppp(22,13,16,1),fpppp(22,13,16,2),fpppp(22,13,16,3)/
     x-9.0554263d-07, 6.8328312d-07,-9.2866340d-11 /
      data fpppp(22,13,17,1),fpppp(22,13,17,2),fpppp(22,13,17,3)/
     x-1.4079143d-06, 1.4877403d-07, 8.7673043d-12 /
      data fpppp(22,13,18,1),fpppp(22,13,18,2),fpppp(22,13,18,3)/
     x-1.6243801d-06,-4.4592965d-07,-8.5915010d-10 /
      data fpppp(22,13,19,1),fpppp(22,13,19,2),fpppp(22,13,19,3)/
     x-1.4883171d-06,-6.9644730d-07,-6.5876718d-10 /
      data fpppp(22,13,20,1),fpppp(22,13,20,2),fpppp(22,13,20,3)/
     x-1.6353614d-06,-7.4805597d-07, 1.4645913d-09 /
      data fpppp(22,13,21,1),fpppp(22,13,21,2),fpppp(22,13,21,3)/
     x-1.6353614d-06,-7.5880440d-07, 1.4270667d-09 /
      data fpppp(22,13,22,1),fpppp(22,13,22,2),fpppp(22,13,22,3)/
     x-1.4883171d-06,-6.5345358d-07,-5.0866889d-10 /
      data fpppp(22,13,23,1),fpppp(22,13,23,2),fpppp(22,13,23,3)/
     x-1.6243801d-06,-6.0715611d-07,-1.4220187d-09 /
      data fpppp(22,14, 1,1),fpppp(22,14, 1,2),fpppp(22,14, 1,3)/
     x-1.7356550d-06, 1.4300765d-05,-9.3720711d-09 /
      data fpppp(22,14, 2,1),fpppp(22,14, 2,2),fpppp(22,14, 2,3)/
     x-1.5453893d-05, 2.3101255d-06, 2.9792763d-10 /
      data fpppp(22,14, 3,1),fpppp(22,14, 3,2),fpppp(22,14, 3,3)/
     x-3.1138845d-05,-2.3475833d-05, 2.1148939d-08 /
      data fpppp(22,14, 4,1),fpppp(22,14, 4,2),fpppp(22,14, 4,3)/
     x-3.1138845d-05,-2.3315303d-05, 2.0922164d-08 /
      data fpppp(22,14, 5,1),fpppp(22,14, 5,2),fpppp(22,14, 5,3)/
     x-1.5453893d-05, 1.6680041d-06, 1.2050292d-09 /
      data fpppp(22,14, 6,1),fpppp(22,14, 6,2),fpppp(22,14, 6,3)/
     x-1.7356550d-06, 1.6708720d-05,-1.2773702d-08 /
      data fpppp(22,14, 7,1),fpppp(22,14, 7,2),fpppp(22,14, 7,3)/
     x 3.6871806d-06, 1.1484562d-05,-1.5184978d-08 /
      data fpppp(22,14, 8,1),fpppp(22,14, 8,2),fpppp(22,14, 8,3)/
     x 4.5953829d-06, 4.9090513d-06,-8.8996674d-09 /
      data fpppp(22,14, 9,1),fpppp(22,14, 9,2),fpppp(22,14, 9,3)/
     x 3.5675621d-06, 1.2404210d-06,-2.6413488d-09 /
      data fpppp(22,14,10,1),fpppp(22,14,10,2),fpppp(22,14,10,3)/
     x 2.2876829d-06,-1.2322077d-07, 1.2301793d-09 /
      data fpppp(22,14,11,1),fpppp(22,14,11,2),fpppp(22,14,11,3)/
     x 1.0355007d-06,-5.7415941d-07, 2.1655136d-09 /
      data fpppp(22,14,12,1),fpppp(22,14,12,2),fpppp(22,14,12,3)/
     x 6.0415434d-08,-6.1467747d-07, 1.2887042d-09 /
      data fpppp(22,14,13,1),fpppp(22,14,13,2),fpppp(22,14,13,3)/
     x-1.2577250d-07, 2.1383896d-07, 8.1296110d-10 /
      data fpppp(22,14,14,1),fpppp(22,14,14,2),fpppp(22,14,14,3)/
     x-2.7746130d-07, 5.1274975d-07,-5.0999030d-11 /
      data fpppp(22,14,15,1),fpppp(22,14,15,2),fpppp(22,14,15,3)/
     x-5.1920083d-07, 9.6393102d-07, 4.0419520d-10 /
      data fpppp(22,14,16,1),fpppp(22,14,16,2),fpppp(22,14,16,3)/
     x-9.8274405d-07, 1.3233213d-07, 3.9133357d-10 /
      data fpppp(22,14,17,1),fpppp(22,14,17,2),fpppp(22,14,17,3)/
     x-8.6252590d-07, 3.3606469d-07, 2.2925362d-10 /
      data fpppp(22,14,18,1),fpppp(22,14,18,2),fpppp(22,14,18,3)/
     x-9.2929120d-07,-3.0639619d-07, 1.0235136d-10 /
      data fpppp(22,14,19,1),fpppp(22,14,19,2),fpppp(22,14,19,3)/
     x-1.1550686d-06,-7.8285077d-07,-3.3569140d-10 /
      data fpppp(22,14,20,1),fpppp(22,14,20,2),fpppp(22,14,20,3)/
     x-8.3751399d-07,-4.8812740d-07, 4.0696137d-10 /
      data fpppp(22,14,21,1),fpppp(22,14,21,2),fpppp(22,14,21,3)/
     x-8.3751399d-07,-5.1727260d-07, 3.6971703d-10 /
      data fpppp(22,14,22,1),fpppp(22,14,22,2),fpppp(22,14,22,3)/
     x-1.1550686d-06,-6.6626998d-07,-1.8671405d-10 /
      data fpppp(22,14,23,1),fpppp(22,14,23,2),fpppp(22,14,23,3)/
     x-9.2929120d-07,-7.4357415d-07,-4.5631371d-10 /
      data fpppp(22,15, 1,1),fpppp(22,15, 1,2),fpppp(22,15, 1,3)/
     x-7.4177462d-06,-4.1928827d-06, 1.9650264d-08 /
      data fpppp(22,15, 2,1),fpppp(22,15, 2,2),fpppp(22,15, 2,3)/
     x 9.0625062d-07,-6.0372380d-06, 1.1850212d-08 /
      data fpppp(22,15, 3,1),fpppp(22,15, 3,2),fpppp(22,15, 3,3)/
     x 1.6561464d-05,-1.0465546d-05,-4.4785500d-09 /
      data fpppp(22,15, 4,1),fpppp(22,15, 4,2),fpppp(22,15, 4,3)/
     x 1.6561464d-05,-9.6323396d-06,-5.1534086d-09 /
      data fpppp(22,15, 5,1),fpppp(22,15, 5,2),fpppp(22,15, 5,3)/
     x 9.0625062d-07,-9.3700645d-06, 1.4549647d-08 /
      data fpppp(22,15, 6,1),fpppp(22,15, 6,2),fpppp(22,15, 6,3)/
     x-7.4177462d-06, 8.3052165d-06, 9.5273840d-09 /
      data fpppp(22,15, 7,1),fpppp(22,15, 7,2),fpppp(22,15, 7,3)/
     x-3.7730527d-06, 7.7295387d-06,-1.1519693d-09 /
      data fpppp(22,15, 8,1),fpppp(22,15, 8,2),fpppp(22,15, 8,3)/
     x-3.3530630d-07, 4.7973872d-06,-7.2197606d-09 /
      data fpppp(22,15, 9,1),fpppp(22,15, 9,2),fpppp(22,15, 9,3)/
     x 9.5215291d-07, 2.2381250d-06,-6.6486443d-09 /
      data fpppp(22,15,10,1),fpppp(22,15,10,2),fpppp(22,15,10,3)/
     x 1.6318395d-06, 8.3536148d-07,-3.3233870d-09 /
      data fpppp(22,15,11,1),fpppp(22,15,11,2),fpppp(22,15,11,3)/
     x 1.3260649d-06, 1.7102561d-07,-5.6038651d-10 /
      data fpppp(22,15,12,1),fpppp(22,15,12,2),fpppp(22,15,12,3)/
     x 9.1315061d-07,-9.1437494d-08, 6.6882541d-10 /
      data fpppp(22,15,13,1),fpppp(22,15,13,2),fpppp(22,15,13,3)/
     x 2.2655326d-07, 1.0791386d-07, 2.4367805d-10 /
      data fpppp(22,15,14,1),fpppp(22,15,14,2),fpppp(22,15,14,3)/
     x-6.9319348d-08, 2.2285897d-07, 7.1318528d-10 /
      data fpppp(22,15,15,1),fpppp(22,15,15,2),fpppp(22,15,15,3)/
     x-8.5150383d-08, 5.5911655d-07, 6.7015810d-11 /
      data fpppp(22,15,16,1),fpppp(22,15,16,2),fpppp(22,15,16,3)/
     x-1.5152023d-07, 2.5368846d-07, 4.9322610d-10 /
      data fpppp(22,15,17,1),fpppp(22,15,17,2),fpppp(22,15,17,3)/
     x-1.4611994d-07, 2.1009461d-07, 4.2394178d-10 /
      data fpppp(22,15,18,1),fpppp(22,15,18,2),fpppp(22,15,18,3)/
     x-3.1831740d-07,-2.2575280d-07, 6.4515637d-10 /
      data fpppp(22,15,19,1),fpppp(22,15,19,2),fpppp(22,15,19,3)/
     x-2.9267866d-07,-4.0611655d-07,-1.2983762d-10 /
      data fpppp(22,15,20,1),fpppp(22,15,20,2),fpppp(22,15,20,3)/
     x-5.4063454d-07,-4.0523353d-07,-5.2236686d-10 /
      data fpppp(22,15,21,1),fpppp(22,15,21,2),fpppp(22,15,21,3)/
     x-5.4063454d-07,-4.1381466d-07,-5.5045928d-10 /
      data fpppp(22,15,22,1),fpppp(22,15,22,2),fpppp(22,15,22,3)/
     x-2.9267866d-07,-3.7179203d-07,-1.7467935d-11 /
      data fpppp(22,15,23,1),fpppp(22,15,23,2),fpppp(22,15,23,3)/
     x-3.1831740d-07,-3.5446977d-07, 2.2377005d-10 /
      data fpppp(22,16, 1,1),fpppp(22,16, 1,2),fpppp(22,16, 1,3)/
     x-7.3713523d-06,-8.5491896d-06, 1.8985181d-08 /
      data fpppp(22,16, 2,1),fpppp(22,16, 2,2),fpppp(22,16, 2,3)/
     x-1.5386737d-05,-7.0202953d-06, 8.0428929d-09 /
      data fpppp(22,16, 3,1),fpppp(22,16, 3,2),fpppp(22,16, 3,3)/
     x-1.3983625d-05,-4.2731780d-06,-1.5255584d-08 /
      data fpppp(22,16, 4,1),fpppp(22,16, 4,2),fpppp(22,16, 4,3)/
     x-1.3983625d-05,-3.3472800d-06,-1.5516830d-08 /
      data fpppp(22,16, 5,1),fpppp(22,16, 5,2),fpppp(22,16, 5,3)/
     x-1.5386737d-05,-1.0723887d-05, 9.0878764d-09 /
      data fpppp(22,16, 6,1),fpppp(22,16, 6,2),fpppp(22,16, 6,3)/
     x-7.3713523d-06, 5.3392801d-06, 1.5066493d-08 /
      data fpppp(22,16, 7,1),fpppp(22,16, 7,2),fpppp(22,16, 7,3)/
     x-8.6191683d-06, 2.8561600d-06, 1.0372053d-08 /
      data fpppp(22,16, 8,1),fpppp(22,16, 8,2),fpppp(22,16, 8,3)/
     x-5.5972779d-06, 2.6488625d-06, 1.2195899d-09 /
      data fpppp(22,16, 9,1),fpppp(22,16, 9,2),fpppp(22,16, 9,3)/
     x-1.8073875d-06, 2.7324551d-06,-3.7467934d-09 /
      data fpppp(22,16,10,1),fpppp(22,16,10,2),fpppp(22,16,10,3)/
     x-3.3956540d-07, 8.3908278d-07,-4.4866343d-09 /
      data fpppp(22,16,11,1),fpppp(22,16,11,2),fpppp(22,16,11,3)/
     x 7.2602060d-07, 9.2264399d-07,-2.9812358d-09 /
      data fpppp(22,16,12,1),fpppp(22,16,12,2),fpppp(22,16,12,3)/
     x 8.2896757d-07, 2.4682930d-07,-1.4649298d-09 /
      data fpppp(22,16,13,1),fpppp(22,16,13,2),fpppp(22,16,13,3)/
     x 8.0897425d-07, 3.0667297d-07,-8.6709154d-11 /
      data fpppp(22,16,14,1),fpppp(22,16,14,2),fpppp(22,16,14,3)/
     x 4.8752080d-07, 1.9514249d-07,-2.2467477d-10 /
      data fpppp(22,16,15,1),fpppp(22,16,15,2),fpppp(22,16,15,3)/
     x 3.9957310d-07, 6.4541939d-08, 6.3850813d-10 /
      data fpppp(22,16,16,1),fpppp(22,16,16,2),fpppp(22,16,16,3)/
     x 8.0012658d-07, 5.3645327d-07, 2.5562842d-10 /
      data fpppp(22,16,17,1),fpppp(22,16,17,2),fpppp(22,16,17,3)/
     x 6.6619477d-07,-1.3539254d-07, 3.2474712d-10 /
      data fpppp(22,16,18,1),fpppp(22,16,18,2),fpppp(22,16,18,3)/
     x 9.1456782d-07, 5.6480755d-08,-2.6191475d-10 /
      data fpppp(22,16,19,1),fpppp(22,16,19,2),fpppp(22,16,19,3)/
     x 9.2392193d-07,-2.2291209d-07,-2.7897441d-10 /
      data fpppp(22,16,20,1),fpppp(22,16,20,2),fpppp(22,16,20,3)/
     x 1.0151930d-06,-2.1894038d-07,-1.6249086d-10 /
      data fpppp(22,16,21,1),fpppp(22,16,21,2),fpppp(22,16,21,3)/
     x 1.0151930d-06,-2.3229068d-07,-1.6588099d-10 /
      data fpppp(22,16,22,1),fpppp(22,16,22,2),fpppp(22,16,22,3)/
     x 9.2392193d-07,-1.6951090d-07,-2.6541391d-10 /
      data fpppp(22,16,23,1),fpppp(22,16,23,2),fpppp(22,16,23,3)/
     x 9.1456782d-07,-1.4377374d-07,-3.1276664d-10 /
      data fpppp(22,17, 1,1),fpppp(22,17, 1,2),fpppp(22,17, 1,3)/
     x-6.0721349d-06,-9.5126846d-07, 4.4863828d-09 /
      data fpppp(22,17, 2,1),fpppp(22,17, 2,2),fpppp(22,17, 2,3)/
     x 6.5160588d-06,-1.2215356d-06,-3.6652674d-10 /
      data fpppp(22,17, 3,1),fpppp(22,17, 3,2),fpppp(22,17, 3,3)/
     x 9.6065050d-06,-1.6548541d-06,-1.0837514d-08 /
      data fpppp(22,17, 4,1),fpppp(22,17, 4,2),fpppp(22,17, 4,3)/
     x 9.6065050d-06,-1.9100487d-06,-1.0711698d-08 /
      data fpppp(22,17, 5,1),fpppp(22,17, 5,2),fpppp(22,17, 5,3)/
     x 6.5160588d-06,-2.0075728d-07,-8.6979085d-10 /
      data fpppp(22,17, 6,1),fpppp(22,17, 6,2),fpppp(22,17, 6,3)/
     x-6.0721349d-06,-4.7791873d-06, 6.3736232d-09 /
      data fpppp(22,17, 7,1),fpppp(22,17, 7,2),fpppp(22,17, 7,3)/
     x-4.6555241d-06, 3.6366459d-06, 8.5244782d-09 /
      data fpppp(22,17, 8,1),fpppp(22,17, 8,2),fpppp(22,17, 8,3)/
     x-5.0634794d-06, 8.4723337d-08, 6.4915383d-09 /
      data fpppp(22,17, 9,1),fpppp(22,17, 9,2),fpppp(22,17, 9,3)/
     x-4.4178525d-06, 1.2106732d-06, 2.6145482d-09 /
      data fpppp(22,17,10,1),fpppp(22,17,10,2),fpppp(22,17,10,3)/
     x-2.3761103d-06, 8.2293611d-07,-3.9513381d-10 /
      data fpppp(22,17,11,1),fpppp(22,17,11,2),fpppp(22,17,11,3)/
     x-8.8965743d-07, 6.2015145d-07,-1.7131681d-09 /
      data fpppp(22,17,12,1),fpppp(22,17,12,2),fpppp(22,17,12,3)/
     x 2.9658953d-07, 5.6350601d-07,-1.6700571d-09 /
      data fpppp(22,17,13,1),fpppp(22,17,13,2),fpppp(22,17,13,3)/
     x 8.3889653d-07, 2.3651912d-07,-1.4545401d-09 /
      data fpppp(22,17,14,1),fpppp(22,17,14,2),fpppp(22,17,14,3)/
     x 1.2301716d-06, 2.9852029d-07,-4.0274081d-10 /
      data fpppp(22,17,15,1),fpppp(22,17,15,2),fpppp(22,17,15,3)/
     x 1.2444282d-06, 1.5154930d-07,-5.1033130d-10 /
      data fpppp(22,17,16,1),fpppp(22,17,16,2),fpppp(22,17,16,3)/
     x 1.1173402d-06, 1.2391717d-07,-1.0353334d-11 /
      data fpppp(22,17,17,1),fpppp(22,17,17,2),fpppp(22,17,17,3)/
     x 1.4295141d-06, 9.1832858d-08,-1.3519315d-10 /
      data fpppp(22,17,18,1),fpppp(22,17,18,2),fpppp(22,17,18,3)/
     x 1.6517391d-06, 4.8378645d-09,-2.5383232d-10 /
      data fpppp(22,17,19,1),fpppp(22,17,19,2),fpppp(22,17,19,3)/
     x 1.9128715d-06, 3.7534325d-09,-2.3666201d-10 /
      data fpppp(22,17,20,1),fpppp(22,17,20,2),fpppp(22,17,20,3)/
     x 1.9325011d-06,-6.0044909d-08,-1.6174569d-10 /
      data fpppp(22,17,21,1),fpppp(22,17,21,2),fpppp(22,17,21,3)/
     x 1.9325011d-06,-5.8683131d-08,-1.6259018d-10 /
      data fpppp(22,17,22,1),fpppp(22,17,22,2),fpppp(22,17,22,3)/
     x 1.9128715d-06,-1.6936803d-09,-2.3328404d-10 /
      data fpppp(22,17,23,1),fpppp(22,17,23,2),fpppp(22,17,23,3)/
     x 1.6517391d-06, 2.5264538d-08,-2.6649971d-10 /
      data fpppp(22,18, 1,1),fpppp(22,18, 1,2),fpppp(22,18, 1,3)/
     x 4.4592466d-06,-1.4655552d-07, 7.2835079d-10 /
      data fpppp(22,18, 2,1),fpppp(22,18, 2,2),fpppp(22,18, 2,3)/
     x 4.3254342d-06,-2.8888519d-07,-1.1349127d-09 /
      data fpppp(22,18, 3,1),fpppp(22,18, 3,2),fpppp(22,18, 3,3)/
     x 4.9607105d-06,-5.8229060d-07,-5.1409178d-09 /
      data fpppp(22,18, 4,1),fpppp(22,18, 4,2),fpppp(22,18, 4,3)/
     x 4.9607105d-06,-6.0256744d-07,-5.1176470d-09 /
      data fpppp(22,18, 5,1),fpppp(22,18, 5,2),fpppp(22,18, 5,3)/
     x 4.3254342d-06,-2.0777783d-07,-1.2279959d-09 /
      data fpppp(22,18, 6,1),fpppp(22,18, 6,2),fpppp(22,18, 6,3)/
     x 4.4592466d-06,-4.5070815d-07, 1.0774128d-09 /
      data fpppp(22,18, 7,1),fpppp(22,18, 7,2),fpppp(22,18, 7,3)/
     x 6.8601663d-07, 8.4711676d-09, 2.7557217d-09 /
      data fpppp(22,18, 8,1),fpppp(22,18, 8,2),fpppp(22,18, 8,3)/
     x-8.0717765d-07,-4.0241625d-08, 2.9131078d-09 /
      data fpppp(22,18, 9,1),fpppp(22,18, 9,2),fpppp(22,18, 9,3)/
     x-1.4626773d-06, 1.6087904d-07, 2.4275102d-09 /
      data fpppp(22,18,10,1),fpppp(22,18,10,2),fpppp(22,18,10,3)/
     x-1.6517096d-06, 2.0852410d-07, 1.6926809d-09 /
      data fpppp(22,18,11,1),fpppp(22,18,11,2),fpppp(22,18,11,3)/
     x-1.3087002d-06, 1.4738139d-07, 9.1295342d-10 /
      data fpppp(22,18,12,1),fpppp(22,18,12,2),fpppp(22,18,12,3)/
     x-6.8371201d-07, 2.7807406d-07, 3.2346641d-10 /
      data fpppp(22,18,13,1),fpppp(22,18,13,2),fpppp(22,18,13,3)/
     x 4.9053419d-08, 1.5415460d-07, 3.2591390d-11 /
      data fpppp(22,18,14,1),fpppp(22,18,14,2),fpppp(22,18,14,3)/
     x 7.4608864d-07, 1.1153145d-07,-3.3355822d-10 /
      data fpppp(22,18,15,1),fpppp(22,18,15,2),fpppp(22,18,15,3)/
     x 1.4934737d-06, 1.8801538d-07,-2.4812007d-10 /
      data fpppp(22,18,16,1),fpppp(22,18,16,2),fpppp(22,18,16,3)/
     x 2.1459332d-06, 3.2110166d-08,-4.4127025d-10 /
      data fpppp(22,18,17,1),fpppp(22,18,17,2),fpppp(22,18,17,3)/
     x 2.6796430d-06, 1.9049571d-07,-4.6481672d-10 /
      data fpppp(22,18,18,1),fpppp(22,18,18,2),fpppp(22,18,18,3)/
     x 3.0487334d-06, 4.6060922d-09,-4.5233194d-10 /
      data fpppp(22,18,19,1),fpppp(22,18,19,2),fpppp(22,18,19,3)/
     x 3.3486896d-06, 8.1333301d-10,-5.3523138d-10 /
      data fpppp(22,18,20,1),fpppp(22,18,20,2),fpppp(22,18,20,3)/
     x 3.6411219d-06, 7.4243696d-08,-4.9753509d-10 /
      data fpppp(22,18,21,1),fpppp(22,18,21,2),fpppp(22,18,21,3)/
     x 3.6411219d-06, 7.2437038d-08,-5.0230524d-10 /
      data fpppp(22,18,22,1),fpppp(22,18,22,2),fpppp(22,18,22,3)/
     x 3.3486896d-06, 8.0399650d-09,-5.1615080d-10 /
      data fpppp(22,18,23,1),fpppp(22,18,23,2),fpppp(22,18,23,3)/
     x 3.0487334d-06,-2.2493778d-08,-5.2388411d-10 /
      data fpppp(22,19, 1,1),fpppp(22,19, 1,2),fpppp(22,19, 1,3)/
     x 1.2352867d-05, 7.7879715d-21,-6.0984716d-09 /
      data fpppp(22,19, 2,1),fpppp(22,19, 2,2),fpppp(22,19, 2,3)/
     x 9.0186440d-06,-2.8538769d-21,-4.0864512d-09 /
      data fpppp(22,19, 3,1),fpppp(22,19, 3,2),fpppp(22,19, 3,3)/
     x 8.3823231d-06, 8.2227967d-21, 1.9038514d-10 /
      data fpppp(22,19, 4,1),fpppp(22,19, 4,2),fpppp(22,19, 4,3)/
     x 8.3823231d-06, 7.1613433d-21, 2.5099847d-10 /
      data fpppp(22,19, 5,1),fpppp(22,19, 5,2),fpppp(22,19, 5,3)/
     x 9.0186440d-06,-6.5208240d-21,-4.3289045d-09 /
      data fpppp(22,19, 6,1),fpppp(22,19, 6,2),fpppp(22,19, 6,3)/
     x 1.2352867d-05,-7.5611856d-21,-5.1892717d-09 /
      data fpppp(22,19, 7,1),fpppp(22,19, 7,2),fpppp(22,19, 7,3)/
     x 5.6338726d-06,-1.8940782d-20,-1.8926972d-09 /
      data fpppp(22,19, 8,1),fpppp(22,19, 8,2),fpppp(22,19, 8,3)/
     x 2.3855518d-06, 7.4121579d-21, 1.8633570d-09 /
      data fpppp(22,19, 9,1),fpppp(22,19, 9,2),fpppp(22,19, 9,3)/
     x-9.7684957d-08,-1.2253081d-20, 4.1114378d-09 /
      data fpppp(22,19,10,1),fpppp(22,19,10,2),fpppp(22,19,10,3)/
     x-1.7161506d-06, 7.0427374d-21, 4.3529773d-09 /
      data fpppp(22,19,11,1),fpppp(22,19,11,2),fpppp(22,19,11,3)/
     x-2.0696387d-06, 5.5757001d-21, 3.1510596d-09 /
      data fpppp(22,19,12,1),fpppp(22,19,12,2),fpppp(22,19,12,3)/
     x-1.5360354d-06, 2.7143183d-21, 1.6888040d-09 /
      data fpppp(22,19,13,1),fpppp(22,19,13,2),fpppp(22,19,13,3)/
     x-5.0657101d-07, 1.1216171d-20, 7.0401931d-10 /
      data fpppp(22,19,14,1),fpppp(22,19,14,2),fpppp(22,19,14,3)/
     x 6.1250103d-07, 1.3062748d-21,-3.3501809d-10 /
      data fpppp(22,19,15,1),fpppp(22,19,15,2),fpppp(22,19,15,3)/
     x 1.9127504d-06,-3.1958063d-21,-3.8906618d-10 /
      data fpppp(22,19,16,1),fpppp(22,19,16,2),fpppp(22,19,16,3)/
     x 2.9712749d-06,-8.6362589d-21,-8.2506283d-10 /
      data fpppp(22,19,17,1),fpppp(22,19,17,2),fpppp(22,19,17,3)/
     x 3.7906835d-06, 7.5937185d-21,-8.3167363d-10 /
      data fpppp(22,19,18,1),fpppp(22,19,18,2),fpppp(22,19,18,3)/
     x 4.2572069d-06,-6.1708459d-21,-5.9180812d-10 /
      data fpppp(22,19,19,1),fpppp(22,19,19,2),fpppp(22,19,19,3)/
     x 4.6568309d-06,-6.7572593d-21,-7.3640596d-10 /
      data fpppp(22,19,20,1),fpppp(22,19,20,2),fpppp(22,19,20,3)/
     x 5.1236534d-06,-1.4606753d-21,-7.3717176d-10 /
      data fpppp(22,19,21,1),fpppp(22,19,21,2),fpppp(22,19,21,3)/
     x 5.1236534d-06,-7.6339811d-21,-7.4401862d-10 /
      data fpppp(22,19,22,1),fpppp(22,19,22,2),fpppp(22,19,22,3)/
     x 4.6568309d-06, 6.8484237d-21,-7.0901853d-10 /
      data fpppp(22,19,23,1),fpppp(22,19,23,2),fpppp(22,19,23,3)/
     x 4.2572069d-06, 1.6370913d-20,-6.9451098d-10 /
      data fpppp(23, 1, 1,1),fpppp(23, 1, 1,2),fpppp(23, 1, 1,3)/
     x 2.6106157d-05, 1.1691064d-18,-3.6078028d-08 /
      data fpppp(23, 1, 2,1),fpppp(23, 1, 2,2),fpppp(23, 1, 2,3)/
     x 1.8401697d-05,-1.7740278d-19,-5.7061533d-08 /
      data fpppp(23, 1, 3,1),fpppp(23, 1, 3,2),fpppp(23, 1, 3,3)/
     x 1.0223408d-05,-6.1982079d-19,-1.0264687d-07 /
      data fpppp(23, 1, 4,1),fpppp(23, 1, 4,2),fpppp(23, 1, 4,3)/
     x 1.0223408d-05,-5.6745757d-19,-1.0156068d-07 /
      data fpppp(23, 1, 5,1),fpppp(23, 1, 5,2),fpppp(23, 1, 5,3)/
     x 1.8401697d-05, 1.8423492d-19,-6.1406299d-08 /
      data fpppp(23, 1, 6,1),fpppp(23, 1, 6,2),fpppp(23, 1, 6,3)/
     x 2.6106157d-05,-1.8864074d-19,-1.9785157d-08 /
      data fpppp(23, 1, 7,1),fpppp(23, 1, 7,2),fpppp(23, 1, 7,3)/
     x 1.9304381d-05,-4.7442276d-19, 1.8107574d-08 /
      data fpppp(23, 1, 8,1),fpppp(23, 1, 8,2),fpppp(23, 1, 8,3)/
     x-6.0092064d-06, 8.5390960d-20, 4.0506564d-08 /
      data fpppp(23, 1, 9,1),fpppp(23, 1, 9,2),fpppp(23, 1, 9,3)/
     x-3.3203820d-05, 5.5951942d-19, 4.9921237d-08 /
      data fpppp(23, 1,10,1),fpppp(23, 1,10,2),fpppp(23, 1,10,3)/
     x-4.2954497d-05, 7.4623946d-19, 4.9890250d-08 /
      data fpppp(23, 1,11,1),fpppp(23, 1,11,2),fpppp(23, 1,11,3)/
     x-5.0915867d-05,-5.1265205d-19, 4.7201693d-08 /
      data fpppp(23, 1,12,1),fpppp(23, 1,12,2),fpppp(23, 1,12,3)/
     x-4.6042223d-05, 6.1781493d-19, 4.6353409d-08 /
      data fpppp(23, 1,13,1),fpppp(23, 1,13,2),fpppp(23, 1,13,3)/
     x-4.2494614d-05,-3.1261631d-19, 4.8654184d-08 /
      data fpppp(23, 1,14,1),fpppp(23, 1,14,2),fpppp(23, 1,14,3)/
     x-4.6337421d-05,-9.2002876d-20, 5.3160840d-08 /
      data fpppp(23, 1,15,1),fpppp(23, 1,15,2),fpppp(23, 1,15,3)/
     x-3.8049972d-05, 4.0454530d-19, 5.3899832d-08 /
      data fpppp(23, 1,16,1),fpppp(23, 1,16,2),fpppp(23, 1,16,3)/
     x-1.1307677d-05, 6.0279492d-19, 4.4924672d-08 /
      data fpppp(23, 1,17,1),fpppp(23, 1,17,2),fpppp(23, 1,17,3)/
     x 1.5779628d-05,-3.7883069d-19, 2.1741838d-08 /
      data fpppp(23, 1,18,1),fpppp(23, 1,18,2),fpppp(23, 1,18,3)/
     x 2.8222342d-05,-1.5587392d-19,-1.8110906d-08 /
      data fpppp(23, 1,19,1),fpppp(23, 1,19,2),fpppp(23, 1,19,3)/
     x-2.0495140d-05,-4.9525391d-19,-6.2349120d-08 /
      data fpppp(23, 1,20,1),fpppp(23, 1,20,2),fpppp(23, 1,20,3)/
     x-6.9592788d-06, 4.3555394d-19,-1.0642199d-07 /
      data fpppp(23, 1,21,1),fpppp(23, 1,21,2),fpppp(23, 1,21,3)/
     x-6.9592788d-06, 2.8213546d-19,-1.0754561d-07 /
      data fpppp(23, 1,22,1),fpppp(23, 1,22,2),fpppp(23, 1,22,3)/
     x-2.0495140d-05,-3.1956246d-20,-5.7854651d-08 /
      data fpppp(23, 1,23,1),fpppp(23, 1,23,2),fpppp(23, 1,23,3)/
     x 2.8222342d-05, 1.0664712d-18,-3.4965167d-08 /
      data fpppp(23, 2, 1,1),fpppp(23, 2, 1,2),fpppp(23, 2, 1,3)/
     x 1.5431799d-05, 5.6562022d-05,-9.0896946d-09 /
      data fpppp(23, 2, 2,1),fpppp(23, 2, 2,2),fpppp(23, 2, 2,3)/
     x 2.3064870d-06, 2.4629632d-05,-1.7290434d-08 /
      data fpppp(23, 2, 3,1),fpppp(23, 2, 3,2),fpppp(23, 2, 3,3)/
     x-1.5858177d-05,-4.1621917d-05,-3.5066512d-08 /
      data fpppp(23, 2, 4,1),fpppp(23, 2, 4,2),fpppp(23, 2, 4,3)/
     x-1.5858177d-05,-4.5428169d-05,-3.4711149d-08 /
      data fpppp(23, 2, 5,1),fpppp(23, 2, 5,2),fpppp(23, 2, 5,3)/
     x 2.3064870d-06, 3.9854639d-05,-1.8711886d-08 /
      data fpppp(23, 2, 6,1),fpppp(23, 2, 6,2),fpppp(23, 2, 6,3)/
     x 1.5431799d-05,-5.3175346d-07,-3.7592503d-09 /
      data fpppp(23, 2, 7,1),fpppp(23, 2, 7,2),fpppp(23, 2, 7,3)/
     x 2.0333393d-05, 4.5545918d-06, 9.0475939d-09 /
      data fpppp(23, 2, 8,1),fpppp(23, 2, 8,2),fpppp(23, 2, 8,3)/
     x 1.5936342d-05, 7.2718324d-06, 1.5145467d-08 /
      data fpppp(23, 2, 9,1),fpppp(23, 2, 9,2),fpppp(23, 2, 9,3)/
     x 9.1577489d-06,-5.0111547d-07, 1.6260404d-08 /
      data fpppp(23, 2,10,1),fpppp(23, 2,10,2),fpppp(23, 2,10,3)/
     x 9.0298691d-06, 8.8419541d-06, 1.4169392d-08 /
      data fpppp(23, 2,11,1),fpppp(23, 2,11,2),fpppp(23, 2,11,3)/
     x 7.7662633d-06, 1.9080108d-06, 1.1754168d-08 /
      data fpppp(23, 2,12,1),fpppp(23, 2,12,2),fpppp(23, 2,12,3)/
     x 1.0929607d-05, 7.5153100d-06, 1.0953077d-08 /
      data fpppp(23, 2,13,1),fpppp(23, 2,13,2),fpppp(23, 2,13,3)/
     x 1.1765534d-05, 9.5330577d-06, 1.2494504d-08 /
      data fpppp(23, 2,14,1),fpppp(23, 2,14,2),fpppp(23, 2,14,3)/
     x 7.1775424d-06, 3.7068030d-06, 1.5846941d-08 /
      data fpppp(23, 2,15,1),fpppp(23, 2,15,2),fpppp(23, 2,15,3)/
     x 6.5130274d-06, 3.8517464d-07, 1.8402982d-08 /
      data fpppp(23, 2,16,1),fpppp(23, 2,16,2),fpppp(23, 2,16,3)/
     x 1.2997039d-05, 8.9094949d-06, 1.7571451d-08 /
      data fpppp(23, 2,17,1),fpppp(23, 2,17,2),fpppp(23, 2,17,3)/
     x 1.8168925d-05,-3.8063677d-06, 1.1130500d-08 /
      data fpppp(23, 2,18,1),fpppp(23, 2,18,2),fpppp(23, 2,18,3)/
     x 1.6014937d-05, 2.7646996d-05,-2.7356830d-09 /
      data fpppp(23, 2,19,1),fpppp(23, 2,19,2),fpppp(23, 2,19,3)/
     x-1.7356651d-05,-5.9826433d-07,-1.9185957d-08 /
      data fpppp(23, 2,20,1),fpppp(23, 2,20,2),fpppp(23, 2,20,3)/
     x-2.2933490d-05,-3.1733227d-05,-3.7381729d-08 /
      data fpppp(23, 2,21,1),fpppp(23, 2,21,2),fpppp(23, 2,21,3)/
     x-2.2933490d-05,-3.2384285d-05,-3.7759526d-08 /
      data fpppp(23, 2,22,1),fpppp(23, 2,22,2),fpppp(23, 2,22,3)/
     x-1.7356651d-05, 2.0059656d-06,-1.7674771d-08 /
      data fpppp(23, 2,23,1),fpppp(23, 2,23,2),fpppp(23, 2,23,3)/
     x 1.6014937d-05, 1.7881134d-05,-8.4026308d-09 /
      data fpppp(23, 3, 1,1),fpppp(23, 3, 1,2),fpppp(23, 3, 1,3)/
     x-5.5493296d-06, 7.0934842d-05, 3.7024168d-08 /
      data fpppp(23, 3, 2,1),fpppp(23, 3, 2,2),fpppp(23, 3, 2,3)/
     x-2.7603926d-05, 2.8793541d-05, 4.2758546d-08 /
      data fpppp(23, 3, 3,1),fpppp(23, 3, 3,2),fpppp(23, 3, 3,3)/
     x-1.2844627d-04,-5.8610733d-05, 5.5264448d-08 /
      data fpppp(23, 3, 4,1),fpppp(23, 3, 4,2),fpppp(23, 3, 4,3)/
     x-1.2844627d-04,-6.3683133d-05, 5.4883038d-08 /
      data fpppp(23, 3, 5,1),fpppp(23, 3, 5,2),fpppp(23, 3, 5,3)/
     x-2.7603926d-05, 4.9083141d-05, 4.4284183d-08 /
      data fpppp(23, 3, 6,1),fpppp(23, 3, 6,2),fpppp(23, 3, 6,3)/
     x-5.5493296d-06,-5.1511557d-06, 3.1303028d-08 /
      data fpppp(23, 3, 7,1),fpppp(23, 3, 7,2),fpppp(23, 3, 7,3)/
     x 9.5967717d-06, 1.7763125d-06, 8.9082291d-09 /
      data fpppp(23, 3, 8,1),fpppp(23, 3, 8,2),fpppp(23, 3, 8,3)/
     x 4.2884388d-05, 1.0397921d-05,-1.4154019d-08 /
      data fpppp(23, 3, 9,1),fpppp(23, 3, 9,2),fpppp(23, 3, 9,3)/
     x 7.4667840d-05, 1.0002257d-05,-3.3426684d-08 /
      data fpppp(23, 3,10,1),fpppp(23, 3,10,2),fpppp(23, 3,10,3)/
     x 9.5635626d-05, 1.1042825d-05,-4.5166899d-08 /
      data fpppp(23, 3,11,1),fpppp(23, 3,11,2),fpppp(23, 3,11,3)/
     x 1.1081080d-04, 1.0829660d-05,-4.9478201d-08 /
      data fpppp(23, 3,12,1),fpppp(23, 3,12,2),fpppp(23, 3,12,3)/
     x 1.1251566d-04, 1.0689643d-05,-5.0447292d-08 /
      data fpppp(23, 3,13,1),fpppp(23, 3,13,2),fpppp(23, 3,13,3)/
     x 1.0630470d-04, 1.0864864d-05,-4.9526056d-08 /
      data fpppp(23, 3,14,1),fpppp(23, 3,14,2),fpppp(23, 3,14,3)/
     x 9.5978651d-05, 1.1358411d-05,-4.5251601d-08 /
      data fpppp(23, 3,15,1),fpppp(23, 3,15,2),fpppp(23, 3,15,3)/
     x 7.4877788d-05, 1.0241729d-05,-3.3405922d-08 /
      data fpppp(23, 3,16,1),fpppp(23, 3,16,2),fpppp(23, 3,16,3)/
     x 4.2402764d-05, 1.1663460d-05,-1.3570836d-08 /
      data fpppp(23, 3,17,1),fpppp(23, 3,17,2),fpppp(23, 3,17,3)/
     x 7.7268364d-06, 4.3360685d-07, 1.0151763d-08 /
      data fpppp(23, 3,18,1),fpppp(23, 3,18,2),fpppp(23, 3,18,3)/
     x-1.0318988d-05, 1.9461710d-06, 3.2871596d-08 /
      data fpppp(23, 3,19,1),fpppp(23, 3,19,2),fpppp(23, 3,19,3)/
     x-1.4981100d-05, 3.1501527d-05, 4.4885513d-08 /
      data fpppp(23, 3,20,1),fpppp(23, 3,20,2),fpppp(23, 3,20,3)/
     x-1.0813805d-04,-5.5973354d-05, 5.2960691d-08 /
      data fpppp(23, 3,21,1),fpppp(23, 3,21,2),fpppp(23, 3,21,3)/
     x-1.0813805d-04,-5.2632675d-05, 5.3352091d-08 /
      data fpppp(23, 3,22,1),fpppp(23, 3,22,2),fpppp(23, 3,22,3)/
     x-1.4981100d-05, 1.8138811d-05, 4.3319911d-08 /
      data fpppp(23, 3,23,1),fpppp(23, 3,23,2),fpppp(23, 3,23,3)/
     x-1.0318988d-05, 5.2056353d-05, 3.8742601d-08 /
      data fpppp(23, 4, 1,1),fpppp(23, 4, 1,2),fpppp(23, 4, 1,3)/
     x 9.5432390d-06,-7.1197614d-06, 1.6198678d-08 /
      data fpppp(23, 4, 2,1),fpppp(23, 4, 2,2),fpppp(23, 4, 2,3)/
     x-9.1611287d-06,-1.3566618d-05, 3.1834943d-08 /
      data fpppp(23, 4, 3,1),fpppp(23, 4, 3,2),fpppp(23, 4, 3,3)/
     x 6.1738418d-05,-2.7662294d-05, 6.5968298d-08 /
      data fpppp(23, 4, 4,1),fpppp(23, 4, 4,2),fpppp(23, 4, 4,3)/
     x 6.1738418d-05,-2.7170573d-05, 6.4870920d-08 /
      data fpppp(23, 4, 5,1),fpppp(23, 4, 5,2),fpppp(23, 4, 5,3)/
     x-9.1611287d-06,-1.5533503d-05, 3.6224455d-08 /
      data fpppp(23, 4, 6,1),fpppp(23, 4, 6,2),fpppp(23, 4, 6,3)/
     x 9.5432390d-06, 2.5605747d-07,-2.6199391d-10 /
      data fpppp(23, 4, 7,1),fpppp(23, 4, 7,2),fpppp(23, 4, 7,3)/
     x 4.0039869d-05, 8.6712805d-06,-2.2453290d-08 /
      data fpppp(23, 4, 8,1),fpppp(23, 4, 8,2),fpppp(23, 4, 8,3)/
     x 5.2323692d-05, 9.8590130d-06,-2.9669142d-08 /
      data fpppp(23, 4, 9,1),fpppp(23, 4, 9,2),fpppp(23, 4, 9,3)/
     x 5.9158103d-05, 1.1644762d-05,-2.7021882d-08 /
      data fpppp(23, 4,10,1),fpppp(23, 4,10,2),fpppp(23, 4,10,3)/
     x 6.1066513d-05, 1.0814209d-05,-2.1849178d-08 /
      data fpppp(23, 4,11,1),fpppp(23, 4,11,2),fpppp(23, 4,11,3)/
     x 5.8586912d-05, 9.6359427d-06,-2.0463613d-08 /
      data fpppp(23, 4,12,1),fpppp(23, 4,12,2),fpppp(23, 4,12,3)/
     x 5.7951928d-05, 9.1452271d-06,-2.0847532d-08 /
      data fpppp(23, 4,13,1),fpppp(23, 4,13,2),fpppp(23, 4,13,3)/
     x 5.9867299d-05, 9.7466945d-06,-2.1033538d-08 /
      data fpppp(23, 4,14,1),fpppp(23, 4,14,2),fpppp(23, 4,14,3)/
     x 6.1278252d-05, 1.1139975d-05,-2.3103889d-08 /
      data fpppp(23, 4,15,1),fpppp(23, 4,15,2),fpppp(23, 4,15,3)/
     x 5.9936385d-05, 1.2099841d-05,-2.8122635d-08 /
      data fpppp(23, 4,16,1),fpppp(23, 4,16,2),fpppp(23, 4,16,3)/
     x 5.3954957d-05, 1.1293559d-05,-3.1451392d-08 /
      data fpppp(23, 4,17,1),fpppp(23, 4,17,2),fpppp(23, 4,17,3)/
     x 4.2194598d-05, 9.2728108d-06,-2.4541077d-08 /
      data fpppp(23, 4,18,1),fpppp(23, 4,18,2),fpppp(23, 4,18,3)/
     x 1.2789910d-05, 2.5225073d-06,-2.3333223d-09 /
      data fpppp(23, 4,19,1),fpppp(23, 4,19,2),fpppp(23, 4,19,3)/
     x-9.9352658d-06,-1.7109797d-05, 3.5777910d-08 /
      data fpppp(23, 4,20,1),fpppp(23, 4,20,2),fpppp(23, 4,20,3)/
     x 4.8963613d-05,-2.8206743d-05, 6.8745568d-08 /
      data fpppp(23, 4,21,1),fpppp(23, 4,21,2),fpppp(23, 4,21,3)/
     x 4.8963613d-05,-2.8892838d-05, 6.9824350d-08 /
      data fpppp(23, 4,22,1),fpppp(23, 4,22,2),fpppp(23, 4,22,3)/
     x-9.9352658d-06,-1.4365418d-05, 3.1462785d-08 /
      data fpppp(23, 4,23,1),fpppp(23, 4,23,2),fpppp(23, 4,23,3)/
     x 1.2789910d-05,-7.7689141d-06, 1.3848397d-08 /
      data fpppp(23, 5, 1,1),fpppp(23, 5, 1,2),fpppp(23, 5, 1,3)/
     x 1.6575844d-05,-1.7234448d-06,-1.1383917d-08 /
      data fpppp(23, 5, 2,1),fpppp(23, 5, 2,2),fpppp(23, 5, 2,3)/
     x 1.5699511d-05,-7.7108963d-06,-4.7682387d-09 /
      data fpppp(23, 5, 3,1),fpppp(23, 5, 3,2),fpppp(23, 5, 3,3)/
     x-1.2358412d-05,-2.0581984d-05, 9.1070871d-09 /
      data fpppp(23, 5, 4,1),fpppp(23, 5, 4,2),fpppp(23, 5, 4,3)/
     x-1.2358412d-05,-2.0510523d-05, 9.6340624d-09 /
      data fpppp(23, 5, 5,1),fpppp(23, 5, 5,2),fpppp(23, 5, 5,3)/
     x 1.5699511d-05,-7.9967402d-06,-6.8761398d-09 /
      data fpppp(23, 5, 6,1),fpppp(23, 5, 6,2),fpppp(23, 5, 6,3)/
     x 1.6575844d-05,-6.5153009d-07,-3.4792881d-09 /
      data fpppp(23, 5, 7,1),fpppp(23, 5, 7,2),fpppp(23, 5, 7,3)/
     x 1.3552849d-05, 5.0332701d-06,-2.9439918d-09 /
      data fpppp(23, 5, 8,1),fpppp(23, 5, 8,2),fpppp(23, 5, 8,3)/
     x 1.4769037d-05, 7.2962923d-06,-9.8948699d-10 /
      data fpppp(23, 5, 9,1),fpppp(23, 5, 9,2),fpppp(23, 5, 9,3)/
     x 1.4681597d-05, 7.3100503d-06,-3.6565336d-11 /
      data fpppp(23, 5,10,1),fpppp(23, 5,10,2),fpppp(23, 5,10,3)/
     x 1.5608769d-05, 7.0132173d-06,-4.5319795d-10 /
      data fpppp(23, 5,11,1),fpppp(23, 5,11,2),fpppp(23, 5,11,3)/
     x 1.8561707d-05, 7.3900576d-06, 7.1066275d-10 /
      data fpppp(23, 5,12,1),fpppp(23, 5,12,2),fpppp(23, 5,12,3)/
     x 2.0127746d-05, 7.9031115d-06, 2.0221834d-09 /
      data fpppp(23, 5,13,1),fpppp(23, 5,13,2),fpppp(23, 5,13,3)/
     x 1.8592129d-05, 7.6554353d-06, 6.2314233d-10 /
      data fpppp(23, 5,14,1),fpppp(23, 5,14,2),fpppp(23, 5,14,3)/
     x 1.6272027d-05, 7.5943529d-06,-8.0935062d-10 /
      data fpppp(23, 5,15,1),fpppp(23, 5,15,2),fpppp(23, 5,15,3)/
     x 1.5665619d-05, 8.1673870d-06,-1.6404378d-09 /
      data fpppp(23, 5,16,1),fpppp(23, 5,16,2),fpppp(23, 5,16,3)/
     x 1.6217983d-05, 8.6394736d-06,-2.8394798d-09 /
      data fpppp(23, 5,17,1),fpppp(23, 5,17,2),fpppp(23, 5,17,3)/
     x 1.5659914d-05, 6.6122598d-06,-4.8670175d-09 /
      data fpppp(23, 5,18,1),fpppp(23, 5,18,2),fpppp(23, 5,18,3)/
     x 1.8272132d-05, 6.0512249d-07,-4.4441797d-09 /
      data fpppp(23, 5,19,1),fpppp(23, 5,19,2),fpppp(23, 5,19,3)/
     x 1.8052422d-05,-6.9766476d-06,-6.2541038d-09 /
      data fpppp(23, 5,20,1),fpppp(23, 5,20,2),fpppp(23, 5,20,3)/
     x-1.0447938d-05,-2.3203574d-05, 1.2110706d-08 /
      data fpppp(23, 5,21,1),fpppp(23, 5,21,2),fpppp(23, 5,21,3)/
     x-1.0447938d-05,-2.3204011d-05, 1.1617976d-08 /
      data fpppp(23, 5,22,1),fpppp(23, 5,22,2),fpppp(23, 5,22,3)/
     x 1.8052422d-05,-6.9749000d-06,-4.2831857d-09 /
      data fpppp(23, 5,23,1),fpppp(23, 5,23,2),fpppp(23, 5,23,3)/
     x 1.8272132d-05, 5.9856877d-07,-1.1835123d-08 /
      data fpppp(23, 6, 1,1),fpppp(23, 6, 1,2),fpppp(23, 6, 1,3)/
     x 1.7215898d-05,-2.1169182d-06, 7.9316023d-10 /
      data fpppp(23, 6, 2,1),fpppp(23, 6, 2,2),fpppp(23, 6, 2,3)/
     x 2.6281501d-05,-4.6022064d-06,-6.3743247d-09 /
      data fpppp(23, 6, 3,1),fpppp(23, 6, 3,2),fpppp(23, 6, 3,3)/
     x 4.1230359d-05,-9.9629530d-06,-2.1643468d-08 /
      data fpppp(23, 6, 4,1),fpppp(23, 6, 4,2),fpppp(23, 6, 4,3)/
     x 4.1230359d-05,-9.9014773d-06,-2.1800535d-08 /
      data fpppp(23, 6, 5,1),fpppp(23, 6, 5,2),fpppp(23, 6, 5,3)/
     x 2.6281501d-05,-4.8481092d-06,-5.7460561d-09 /
      data fpppp(23, 6, 6,1),fpppp(23, 6, 6,2),fpppp(23, 6, 6,3)/
     x 1.7215898d-05,-1.1947828d-06,-1.5628468d-09 /
      data fpppp(23, 6, 7,1),fpppp(23, 6, 7,2),fpppp(23, 6, 7,3)/
     x 9.2679224d-06, 1.6386338d-06, 4.9433895d-09 /
      data fpppp(23, 6, 8,1),fpppp(23, 6, 8,2),fpppp(23, 6, 8,3)/
     x 1.9160036d-06, 2.7357209d-06, 7.3925538d-09 /
      data fpppp(23, 6, 9,1),fpppp(23, 6, 9,2),fpppp(23, 6, 9,3)/
     x-1.9443117d-06, 3.5510441d-06, 7.6721564d-09 /
      data fpppp(23, 6,10,1),fpppp(23, 6,10,2),fpppp(23, 6,10,3)/
     x-3.6267430d-06, 4.2175903d-06, 8.3604550d-09 /
      data fpppp(23, 6,11,1),fpppp(23, 6,11,2),fpppp(23, 6,11,3)/
     x-4.9497923d-06, 4.6214383d-06, 8.6830068d-09 /
      data fpppp(23, 6,12,1),fpppp(23, 6,12,2),fpppp(23, 6,12,3)/
     x-5.4819295d-06, 4.8345043d-06, 8.3721324d-09 /
      data fpppp(23, 6,13,1),fpppp(23, 6,13,2),fpppp(23, 6,13,3)/
     x-4.5181765d-06, 5.0324963d-06, 8.3055873d-09 /
      data fpppp(23, 6,14,1),fpppp(23, 6,14,2),fpppp(23, 6,14,3)/
     x-2.8170391d-06, 5.0969713d-06, 7.5894818d-09 /
      data fpppp(23, 6,15,1),fpppp(23, 6,15,2),fpppp(23, 6,15,3)/
     x-9.6996669d-07, 4.8215377d-06, 6.8870076d-09 /
      data fpppp(23, 6,16,1),fpppp(23, 6,16,2),fpppp(23, 6,16,3)/
     x 2.6048257d-06, 4.3139796d-06, 6.0706373d-09 /
      data fpppp(23, 6,17,1),fpppp(23, 6,17,2),fpppp(23, 6,17,3)/
     x 9.3973471d-06, 3.0478042d-06, 3.8412220d-09 /
      data fpppp(23, 6,18,1),fpppp(23, 6,18,2),fpppp(23, 6,18,3)/
     x 1.7124806d-05,-5.3482513d-08,-2.0795869d-09 /
      data fpppp(23, 6,19,1),fpppp(23, 6,19,2),fpppp(23, 6,19,3)/
     x 2.5583765d-05,-4.8914101d-06,-5.6750582d-09 /
      data fpppp(23, 6,20,1),fpppp(23, 6,20,2),fpppp(23, 6,20,3)/
     x 4.0790603d-05,-1.2018202d-05,-2.0304512d-08 /
      data fpppp(23, 6,21,1),fpppp(23, 6,21,2),fpppp(23, 6,21,3)/
     x 4.0790603d-05,-1.2089978d-05,-2.0151113d-08 /
      data fpppp(23, 6,22,1),fpppp(23, 6,22,2),fpppp(23, 6,22,3)/
     x 2.5583765d-05,-4.6043042d-06,-6.2886545d-09 /
      data fpppp(23, 6,23,1),fpppp(23, 6,23,2),fpppp(23, 6,23,3)/
     x 1.7124806d-05,-1.1301299d-06, 2.2139909d-10 /
      data fpppp(23, 7, 1,1),fpppp(23, 7, 1,2),fpppp(23, 7, 1,3)/
     x 7.5097492d-06,-1.9075064d-06,-4.0653079d-09 /
      data fpppp(23, 7, 2,1),fpppp(23, 7, 2,2),fpppp(23, 7, 2,3)/
     x 1.4273016d-05,-2.4308592d-06,-8.0312939d-09 /
      data fpppp(23, 7, 3,1),fpppp(23, 7, 3,2),fpppp(23, 7, 3,3)/
     x 1.7314166d-05,-3.5681236d-06,-1.6629305d-08 /
      data fpppp(23, 7, 4,1),fpppp(23, 7, 4,2),fpppp(23, 7, 4,3)/
     x 1.7314166d-05,-3.5404837d-06,-1.6455233d-08 /
      data fpppp(23, 7, 5,1),fpppp(23, 7, 5,2),fpppp(23, 7, 5,3)/
     x 1.4273016d-05,-2.5414188d-06,-8.7275816d-09 /
      data fpppp(23, 7, 6,1),fpppp(23, 7, 6,2),fpppp(23, 7, 6,3)/
     x 7.5097492d-06,-1.4929079d-06,-1.4542289d-09 /
      data fpppp(23, 7, 7,1),fpppp(23, 7, 7,2),fpppp(23, 7, 7,3)/
     x 1.7569538d-06,-3.1291823d-07, 3.1379967d-09 /
      data fpppp(23, 7, 8,1),fpppp(23, 7, 8,2),fpppp(23, 7, 8,3)/
     x-2.0791611d-06, 6.9777510d-07, 6.4139241d-09 /
      data fpppp(23, 7, 9,1),fpppp(23, 7, 9,2),fpppp(23, 7, 9,3)/
     x-5.3024999d-06, 1.5340125d-06, 8.8417667d-09 /
      data fpppp(23, 7,10,1),fpppp(23, 7,10,2),fpppp(23, 7,10,3)/
     x-8.1874329d-06, 1.9959942d-06, 8.4014172d-09 /
      data fpppp(23, 7,11,1),fpppp(23, 7,11,2),fpppp(23, 7,11,3)/
     x-1.0023989d-05, 2.3263898d-06, 6.4633264d-09 /
      data fpppp(23, 7,12,1),fpppp(23, 7,12,2),fpppp(23, 7,12,3)/
     x-1.0394302d-05, 2.5405763d-06, 5.3151829d-09 /
      data fpppp(23, 7,13,1),fpppp(23, 7,13,2),fpppp(23, 7,13,3)/
     x-9.5407728d-06, 2.9430163d-06, 6.1049090d-09 /
      data fpppp(23, 7,14,1),fpppp(23, 7,14,2),fpppp(23, 7,14,3)/
     x-7.6302008d-06, 2.9131715d-06, 7.7839260d-09 /
      data fpppp(23, 7,15,1),fpppp(23, 7,15,2),fpppp(23, 7,15,3)/
     x-4.7817162d-06, 2.9232482d-06, 8.0119962d-09 /
      data fpppp(23, 7,16,1),fpppp(23, 7,16,2),fpppp(23, 7,16,3)/
     x-1.6313752d-06, 2.2561736d-06, 6.0660719d-09 /
      data fpppp(23, 7,17,1),fpppp(23, 7,17,2),fpppp(23, 7,17,3)/
     x 1.8814373d-06, 1.0879912d-06, 2.1459755d-09 /
      data fpppp(23, 7,18,1),fpppp(23, 7,18,2),fpppp(23, 7,18,3)/
     x 7.1119338d-06,-7.7062434d-07,-2.3219983d-09 /
      data fpppp(23, 7,19,1),fpppp(23, 7,19,2),fpppp(23, 7,19,3)/
     x 1.3667852d-05,-2.7571770d-06,-8.6714067d-09 /
      data fpppp(23, 7,20,1),fpppp(23, 7,20,2),fpppp(23, 7,20,3)/
     x 1.7142505d-05,-5.3406715d-06,-1.5145160d-08 /
      data fpppp(23, 7,21,1),fpppp(23, 7,21,2),fpppp(23, 7,21,3)/
     x 1.7142505d-05,-5.3777406d-06,-1.5303150d-08 /
      data fpppp(23, 7,22,1),fpppp(23, 7,22,2),fpppp(23, 7,22,3)/
     x 1.3667852d-05,-2.6089007d-06,-8.0394465d-09 /
      data fpppp(23, 7,23,1),fpppp(23, 7,23,2),fpppp(23, 7,23,3)/
     x 7.1119338d-06,-1.3266605d-06,-4.6918488d-09 /
      data fpppp(23, 8, 1,1),fpppp(23, 8, 1,2),fpppp(23, 8, 1,3)/
     x 3.3432683d-06,-1.7783786d-06,-3.9094241d-10 /
      data fpppp(23, 8, 2,1),fpppp(23, 8, 2,2),fpppp(23, 8, 2,3)/
     x 6.4363972d-06,-1.4736183d-06,-3.8524723d-09 /
      data fpppp(23, 8, 3,1),fpppp(23, 8, 3,2),fpppp(23, 8, 3,3)/
     x 9.9056706d-06,-8.6564694d-07,-1.1332409d-08 /
      data fpppp(23, 8, 4,1),fpppp(23, 8, 4,2),fpppp(23, 8, 4,3)/
     x 9.9056706d-06,-7.8674594d-07,-1.1223257d-08 /
      data fpppp(23, 8, 5,1),fpppp(23, 8, 5,2),fpppp(23, 8, 5,3)/
     x 6.4363972d-06,-1.7892223d-06,-4.2890829d-09 /
      data fpppp(23, 8, 6,1),fpppp(23, 8, 6,2),fpppp(23, 8, 6,3)/
     x 3.3432683d-06,-5.9486358d-07, 1.2463475d-09 /
      data fpppp(23, 8, 7,1),fpppp(23, 8, 7,2),fpppp(23, 8, 7,3)/
     x-1.0248711d-07,-6.8776942d-07, 3.3837484d-09 /
      data fpppp(23, 8, 8,1),fpppp(23, 8, 8,2),fpppp(23, 8, 8,3)/
     x-3.2142015d-06,-2.4632328d-07, 4.0486664d-09 /
      data fpppp(23, 8, 9,1),fpppp(23, 8, 9,2),fpppp(23, 8, 9,3)/
     x-5.6221361d-06, 2.1137803d-07, 3.3339859d-09 /
      data fpppp(23, 8,10,1),fpppp(23, 8,10,2),fpppp(23, 8,10,3)/
     x-6.8220404d-06, 6.4250013d-07, 3.6441235d-09 /
      data fpppp(23, 8,11,1),fpppp(23, 8,11,2),fpppp(23, 8,11,3)/
     x-7.1875175d-06, 1.2518528d-06, 4.1294898d-09 /
      data fpppp(23, 8,12,1),fpppp(23, 8,12,2),fpppp(23, 8,12,3)/
     x-7.2935630d-06, 1.4118175d-06, 4.0936804d-09 /
      data fpppp(23, 8,13,1),fpppp(23, 8,13,2),fpppp(23, 8,13,3)/
     x-7.0698299d-06, 1.6933851d-06, 3.9427964d-09 /
      data fpppp(23, 8,14,1),fpppp(23, 8,14,2),fpppp(23, 8,14,3)/
     x-6.4451646d-06, 1.5712950d-06, 3.3561905d-09 /
      data fpppp(23, 8,15,1),fpppp(23, 8,15,2),fpppp(23, 8,15,3)/
     x-5.0001887d-06, 1.5353123d-06, 3.3914821d-09 /
      data fpppp(23, 8,16,1),fpppp(23, 8,16,2),fpppp(23, 8,16,3)/
     x-2.6922811d-06, 1.1131068d-06, 3.0778001d-09 /
      data fpppp(23, 8,17,1),fpppp(23, 8,17,2),fpppp(23, 8,17,3)/
     x 5.3368117d-07, 5.4453788d-07, 2.3975012d-09 /
      data fpppp(23, 8,18,1),fpppp(23, 8,18,2),fpppp(23, 8,18,3)/
     x 3.7291670d-06,-2.9274673d-07,-6.9564540d-10 /
      data fpppp(23, 8,19,1),fpppp(23, 8,19,2),fpppp(23, 8,19,3)/
     x 6.3069008d-06,-1.4039494d-06,-5.0490381d-09 /
      data fpppp(23, 8,20,1),fpppp(23, 8,20,2),fpppp(23, 8,20,3)/
     x 8.6997007d-06,-2.4962498d-06,-8.7327295d-09 /
      data fpppp(23, 8,21,1),fpppp(23, 8,21,2),fpppp(23, 8,21,3)/
     x 8.6997007d-06,-2.5248002d-06,-8.8577771d-09 /
      data fpppp(23, 8,22,1),fpppp(23, 8,22,2),fpppp(23, 8,22,3)/
     x 6.3069008d-06,-1.2897477d-06,-4.5488476d-09 /
      data fpppp(23, 8,23,1),fpppp(23, 8,23,2),fpppp(23, 8,23,3)/
     x 3.7291670d-06,-7.2100325d-07,-2.5713599d-09 /
      data fpppp(23, 9, 1,1),fpppp(23, 9, 1,2),fpppp(23, 9, 1,3)/
     x-1.6619261d-08,-2.8667440d-07, 3.8706354d-09 /
      data fpppp(23, 9, 2,1),fpppp(23, 9, 2,2),fpppp(23, 9, 2,3)/
     x 3.3797718d-06,-4.5391644d-07, 1.6806721d-10 /
      data fpppp(23, 9, 3,1),fpppp(23, 9, 3,2),fpppp(23, 9, 3,3)/
     x 7.9379746d-06,-8.3131638d-07,-7.7101536d-09 /
      data fpppp(23, 9, 4,1),fpppp(23, 9, 4,2),fpppp(23, 9, 4,3)/
     x 7.9379746d-06,-7.9802415d-07,-7.8078979d-09 /
      data fpppp(23, 9, 5,1),fpppp(23, 9, 5,2),fpppp(23, 9, 5,3)/
     x 3.3797718d-06,-5.8708536d-07, 5.5904417d-10 /
      data fpppp(23, 9, 6,1),fpppp(23, 9, 6,2),fpppp(23, 9, 6,3)/
     x-1.6619261d-08, 2.1270906d-07, 2.4044718d-09 /
      data fpppp(23, 9, 7,1),fpppp(23, 9, 7,2),fpppp(23, 9, 7,3)/
     x-2.0387057d-06,-1.7640543d-07, 2.9093474d-09 /
      data fpppp(23, 9, 8,1),fpppp(23, 9, 8,2),fpppp(23, 9, 8,3)/
     x-3.2656760d-06,-5.9684987d-07, 7.6642730d-10 /
      data fpppp(23, 9, 9,1),fpppp(23, 9, 9,2),fpppp(23, 9, 9,3)/
     x-3.7278343d-06,-1.7905147d-07, 1.1798844d-09 /
      data fpppp(23, 9,10,1),fpppp(23, 9,10,2),fpppp(23, 9,10,3)/
     x-4.2668435d-06, 6.0290208d-08, 1.3366926d-09 /
      data fpppp(23, 9,11,1),fpppp(23, 9,11,2),fpppp(23, 9,11,3)/
     x-4.7594327d-06, 5.9247965d-07, 1.8427040d-09 /
      data fpppp(23, 9,12,1),fpppp(23, 9,12,2),fpppp(23, 9,12,3)/
     x-4.8311531d-06, 7.7595764d-07, 2.2995337d-09 /
      data fpppp(23, 9,13,1),fpppp(23, 9,13,2),fpppp(23, 9,13,3)/
     x-4.6023043d-06, 9.0051985d-07, 1.7021635d-09 /
      data fpppp(23, 9,14,1),fpppp(23, 9,14,2),fpppp(23, 9,14,3)/
     x-3.9216179d-06, 1.0220649d-06, 1.6088417d-09 /
      data fpppp(23, 9,15,1),fpppp(23, 9,15,2),fpppp(23, 9,15,3)/
     x-3.1771737d-06, 8.0293758d-07, 1.0936980d-09 /
      data fpppp(23, 9,16,1),fpppp(23, 9,16,2),fpppp(23, 9,16,3)/
     x-1.9935460d-06, 7.4791538d-07, 1.3187075d-09 /
      data fpppp(23, 9,17,1),fpppp(23, 9,17,2),fpppp(23, 9,17,3)/
     x-7.3009562d-07, 3.4853498d-07, 5.6847859d-10 /
      data fpppp(23, 9,18,1),fpppp(23, 9,18,2),fpppp(23, 9,18,3)/
     x 8.7990301d-07,-4.0219714d-08,-4.4923563d-10 /
      data fpppp(23, 9,19,1),fpppp(23, 9,19,2),fpppp(23, 9,19,3)/
     x 2.4275872d-06,-7.0467141d-07,-2.2616378d-09 /
      data fpppp(23, 9,20,1),fpppp(23, 9,20,2),fpppp(23, 9,20,3)/
     x 3.2969846d-06,-1.3099655d-06,-3.4533186d-09 /
      data fpppp(23, 9,21,1),fpppp(23, 9,21,2),fpppp(23, 9,21,3)/
     x 3.2969846d-06,-1.3280975d-06,-3.5129524d-09 /
      data fpppp(23, 9,22,1),fpppp(23, 9,22,2),fpppp(23, 9,22,3)/
     x 2.4275872d-06,-6.3214335d-07,-2.0231028d-09 /
      data fpppp(23, 9,23,1),fpppp(23, 9,23,2),fpppp(23, 9,23,3)/
     x 8.7990301d-07,-3.1219993d-07,-1.3437420d-09 /
      data fpppp(23,10, 1,1),fpppp(23,10, 1,2),fpppp(23,10, 1,3)/
     x-2.9262992d-07, 3.8882442d-06, 4.3285739d-09 /
      data fpppp(23,10, 2,1),fpppp(23,10, 2,2),fpppp(23,10, 2,3)/
     x 1.6924825d-06, 1.4680089d-06, 1.1198572d-09 /
      data fpppp(23,10, 3,1),fpppp(23,10, 3,2),fpppp(23,10, 3,3)/
     x 2.0993143d-06,-3.6439835d-06,-5.7257646d-09 /
      data fpppp(23,10, 4,1),fpppp(23,10, 4,2),fpppp(23,10, 4,3)/
     x 2.0993143d-06,-3.7738792d-06,-5.7786140d-09 /
      data fpppp(23,10, 5,1),fpppp(23,10, 5,2),fpppp(23,10, 5,3)/
     x 1.6924825d-06, 1.9875915d-06, 1.3312550d-09 /
      data fpppp(23,10, 6,1),fpppp(23,10, 6,2),fpppp(23,10, 6,3)/
     x-2.9262992d-07, 1.9398095d-06, 3.5358324d-09 /
      data fpppp(23,10, 7,1),fpppp(23,10, 7,2),fpppp(23,10, 7,3)/
     x-1.7117250d-06, 9.9491641d-07, 1.9002450d-09 /
      data fpppp(23,10, 8,1),fpppp(23,10, 8,2),fpppp(23,10, 8,3)/
     x-2.2642375d-06,-1.2564701d-07, 1.1600260d-09 /
      data fpppp(23,10, 9,1),fpppp(23,10, 9,2),fpppp(23,10, 9,3)/
     x-2.6801456d-06,-6.1672456d-07,-4.7251256d-10 /
      data fpppp(23,10,10,1),fpppp(23,10,10,2),fpppp(23,10,10,3)/
     x-3.0373683d-06,-1.9536287d-07,-6.9339640d-11 /
      data fpppp(23,10,11,1),fpppp(23,10,11,2),fpppp(23,10,11,3)/
     x-2.8700682d-06, 2.1875275d-07, 1.0324658d-09 /
      data fpppp(23,10,12,1),fpppp(23,10,12,2),fpppp(23,10,12,3)/
     x-2.9479153d-06, 3.6871574d-07, 1.0955439d-09 /
      data fpppp(23,10,13,1),fpppp(23,10,13,2),fpppp(23,10,13,3)/
     x-2.8353412d-06, 6.3001315d-07, 8.8634220d-10 /
      data fpppp(23,10,14,1),fpppp(23,10,14,2),fpppp(23,10,14,3)/
     x-2.5270263d-06, 5.5880582d-07, 1.8991281d-10 /
      data fpppp(23,10,15,1),fpppp(23,10,15,2),fpppp(23,10,15,3)/
     x-1.8385922d-06, 6.5978117d-07, 4.3005244d-10 /
      data fpppp(23,10,16,1),fpppp(23,10,16,2),fpppp(23,10,16,3)/
     x-1.2127919d-06, 4.9691142d-07, 3.6059366d-10 /
      data fpppp(23,10,17,1),fpppp(23,10,17,2),fpppp(23,10,17,3)/
     x-4.7704307d-07, 4.5385810d-07, 5.1936378d-10 /
      data fpppp(23,10,18,1),fpppp(23,10,18,2),fpppp(23,10,18,3)/
     x 3.7282518d-08, 2.7109130d-08, 1.6246951d-11 /
      data fpppp(23,10,19,1),fpppp(23,10,19,2),fpppp(23,10,19,3)/
     x 4.5698956d-07,-5.2755502d-07,-6.2982624d-10 /
      data fpppp(23,10,20,1),fpppp(23,10,20,2),fpppp(23,10,20,3)/
     x 7.9333360d-07,-8.3128095d-07,-1.7559932d-09 /
      data fpppp(23,10,21,1),fpppp(23,10,21,2),fpppp(23,10,21,3)/
     x 7.9333360d-07,-8.5088184d-07,-1.7617145d-09 /
      data fpppp(23,10,22,1),fpppp(23,10,22,2),fpppp(23,10,22,3)/
     x 4.5698956d-07,-4.4915147d-07,-6.0694106d-10 /
      data fpppp(23,10,23,1),fpppp(23,10,23,2),fpppp(23,10,23,3)/
     x 3.7282518d-08,-2.6690419d-07,-6.9572479d-11 /
      data fpppp(23,11, 1,1),fpppp(23,11, 1,2),fpppp(23,11, 1,3)/
     x 1.5063911d-07, 8.3422089d-06,-5.3720788d-10 /
      data fpppp(23,11, 2,1),fpppp(23,11, 2,2),fpppp(23,11, 2,3)/
     x 9.3352170d-07, 3.1825448d-06,-7.6294254d-10 /
      data fpppp(23,11, 3,1),fpppp(23,11, 3,2),fpppp(23,11, 3,3)/
     x 5.0467141d-06,-7.7271403d-06,-1.2527256d-09 /
      data fpppp(23,11, 4,1),fpppp(23,11, 4,2),fpppp(23,11, 4,3)/
     x 5.0467141d-06,-7.9839316d-06,-1.2421102d-09 /
      data fpppp(23,11, 5,1),fpppp(23,11, 5,2),fpppp(23,11, 5,3)/
     x 9.3352170d-07, 4.2097100d-06,-8.0540386d-10 /
      data fpppp(23,11, 6,1),fpppp(23,11, 6,2),fpppp(23,11, 6,3)/
     x 1.5063911d-07, 4.4903396d-06,-3.7797793d-10 /
      data fpppp(23,11, 7,1),fpppp(23,11, 7,2),fpppp(23,11, 7,3)/
     x-5.1513868d-07, 2.9805571d-06, 1.0917181d-09 /
      data fpppp(23,11, 8,1),fpppp(23,11, 8,2),fpppp(23,11, 8,3)/
     x-1.1751001d-06, 5.3211418d-07, 7.7546372d-10 /
      data fpppp(23,11, 9,1),fpppp(23,11, 9,2),fpppp(23,11, 9,3)/
     x-1.5053830d-06,-9.7404208d-07, 3.8014112d-10 /
      data fpppp(23,11,10,1),fpppp(23,11,10,2),fpppp(23,11,10,3)/
     x-1.1300730d-06,-9.5512824d-08, 5.5876990d-10 /
      data fpppp(23,11,11,1),fpppp(23,11,11,2),fpppp(23,11,11,3)/
     x-1.5767351d-06,-3.3480304d-07, 1.2504181d-10 /
      data fpppp(23,11,12,1),fpppp(23,11,12,2),fpppp(23,11,12,3)/
     x-1.5361206d-06, 2.5284251d-07, 6.9751116d-11 /
      data fpppp(23,11,13,1),fpppp(23,11,13,2),fpppp(23,11,13,3)/
     x-1.4399259d-06, 4.9169558d-07, 5.2901715d-10 /
      data fpppp(23,11,14,1),fpppp(23,11,14,2),fpppp(23,11,14,3)/
     x-1.3960650d-06, 4.5788813d-07, 5.3384875d-10 /
      data fpppp(23,11,15,1),fpppp(23,11,15,2),fpppp(23,11,15,3)/
     x-1.3849118d-06, 4.8659705d-07,-3.9824027d-11 /
      data fpppp(23,11,16,1),fpppp(23,11,16,2),fpppp(23,11,16,3)/
     x-1.1443436d-06, 4.2174046d-07,-1.9975880d-10 /
      data fpppp(23,11,17,1),fpppp(23,11,17,2),fpppp(23,11,17,3)/
     x-9.1918894d-07, 3.9008011d-07, 1.7468941d-10 /
      data fpppp(23,11,18,1),fpppp(23,11,18,2),fpppp(23,11,18,3)/
     x-7.1094117d-07, 3.8957832d-08, 5.8043211d-10 /
      data fpppp(23,11,19,1),fpppp(23,11,19,2),fpppp(23,11,19,3)/
     x-6.1749340d-07,-5.1500552d-07, 8.1558251d-10 /
      data fpppp(23,11,20,1),fpppp(23,11,20,2),fpppp(23,11,20,3)/
     x-4.9672002d-07,-6.2326191d-07,-1.5774521d-09 /
      data fpppp(23,11,21,1),fpppp(23,11,21,2),fpppp(23,11,21,3)/
     x-4.9672002d-07,-6.4715956d-07,-1.5132796d-09 /
      data fpppp(23,11,22,1),fpppp(23,11,22,2),fpppp(23,11,22,3)/
     x-6.1749340d-07,-4.1941494d-07, 5.5889266d-10 /
      data fpppp(23,11,23,1),fpppp(23,11,23,2),fpppp(23,11,23,3)/
     x-7.1094117d-07,-3.1950683d-07, 1.5430190d-09 /
      data fpppp(23,12, 1,1),fpppp(23,12, 1,2),fpppp(23,12, 1,3)/
     x 1.9558512d-06, 1.4984252d-05,-1.1122607d-08 /
      data fpppp(23,12, 2,1),fpppp(23,12, 2,2),fpppp(23,12, 2,3)/
     x 3.2087992d-07, 5.9763890d-06,-5.1723586d-09 /
      data fpppp(23,12, 3,1),fpppp(23,12, 3,2),fpppp(23,12, 3,3)/
     x-7.7386642d-06,-1.2997223d-05, 7.4166173d-09 /
      data fpppp(23,12, 4,1),fpppp(23,12, 4,2),fpppp(23,12, 4,3)/
     x-7.7386642d-06,-1.3572889d-05, 7.6993394d-09 /
      data fpppp(23,12, 5,1),fpppp(23,12, 5,2),fpppp(23,12, 5,3)/
     x 3.2087992d-07, 8.2790533d-06,-6.3032471d-09 /
      data fpppp(23,12, 6,1),fpppp(23,12, 6,2),fpppp(23,12, 6,3)/
     x 1.9558512d-06, 6.3492609d-06,-6.8817748d-09 /
      data fpppp(23,12, 7,1),fpppp(23,12, 7,2),fpppp(23,12, 7,3)/
     x 1.8045132d-06, 5.1335350d-06,-3.1220933d-09 /
      data fpppp(23,12, 8,1),fpppp(23,12, 8,2),fpppp(23,12, 8,3)/
     x 8.7652315d-07, 1.3253312d-06, 9.7587729d-10 /
      data fpppp(23,12, 9,1),fpppp(23,12, 9,2),fpppp(23,12, 9,3)/
     x 9.5108463d-08,-4.3862684d-07, 2.2158916d-09 /
      data fpppp(23,12,10,1),fpppp(23,12,10,2),fpppp(23,12,10,3)/
     x-6.8359241d-07,-8.1827840d-07, 7.8072800d-10 /
      data fpppp(23,12,11,1),fpppp(23,12,11,2),fpppp(23,12,11,3)/
     x-5.1006588d-07,-3.0176756d-07,-2.2448350d-11 /
      data fpppp(23,12,12,1),fpppp(23,12,12,2),fpppp(23,12,12,3)/
     x-5.7324128d-07, 8.0477015d-08, 4.3824507d-10 /
      data fpppp(23,12,13,1),fpppp(23,12,13,2),fpppp(23,12,13,3)/
     x-6.7343426d-07, 3.6848071d-07, 1.1623081d-10 /
      data fpppp(23,12,14,1),fpppp(23,12,14,2),fpppp(23,12,14,3)/
     x-7.1970751d-07, 3.9337689d-07, 3.0733238d-10 /
      data fpppp(23,12,15,1),fpppp(23,12,15,2),fpppp(23,12,15,3)/
     x-6.9144931d-07, 4.7650417d-07, 4.8004133d-10 /
      data fpppp(23,12,16,1),fpppp(23,12,16,2),fpppp(23,12,16,3)/
     x-8.2606027d-07, 3.4995523d-07,-1.5738930d-10 /
      data fpppp(23,12,17,1),fpppp(23,12,17,2),fpppp(23,12,17,3)/
     x-8.9510972d-07, 2.6352392d-07,-3.0559576d-10 /
      data fpppp(23,12,18,1),fpppp(23,12,18,2),fpppp(23,12,18,3)/
     x-1.0180803d-06,-4.4438362d-08, 7.7528509d-12 /
      data fpppp(23,12,19,1),fpppp(23,12,19,2),fpppp(23,12,19,3)/
     x-9.8016857d-07,-4.5163453d-07, 3.9205761d-10 /
      data fpppp(23,12,20,1),fpppp(23,12,20,2),fpppp(23,12,20,3)/
     x-9.7252962d-07,-5.2761728d-07,-2.5817246d-10 /
      data fpppp(23,12,21,1),fpppp(23,12,21,2),fpppp(23,12,21,3)/
     x-9.7252962d-07,-5.4526305d-07,-2.2552631d-10 /
      data fpppp(23,12,22,1),fpppp(23,12,22,2),fpppp(23,12,22,3)/
     x-9.8016857d-07,-3.8105145d-07, 2.6147303d-10 /
      data fpppp(23,12,23,1),fpppp(23,12,23,2),fpppp(23,12,23,3)/
     x-1.0180803d-06,-3.0912491d-07, 4.9744503d-10 /
      data fpppp(23,13, 1,1),fpppp(23,13, 1,2),fpppp(23,13, 1,3)/
     x 1.7489806d-06, 1.3264034d-05,-1.4088818d-08 /
      data fpppp(23,13, 2,1),fpppp(23,13, 2,2),fpppp(23,13, 2,3)/
     x-2.1301062d-06, 4.5150262d-06,-5.3347188d-09 /
      data fpppp(23,13, 3,1),fpppp(23,13, 3,2),fpppp(23,13, 3,3)/
     x-4.7761734d-06,-1.4019178d-05, 1.3291092d-08 /
      data fpppp(23,13, 4,1),fpppp(23,13, 4,2),fpppp(23,13, 4,3)/
     x-4.7761734d-06,-1.4393099d-05, 1.3523794d-08 /
      data fpppp(23,13, 5,1),fpppp(23,13, 5,2),fpppp(23,13, 5,3)/
     x-2.1301062d-06, 6.0107111d-06,-6.2655273d-09 /
      data fpppp(23,13, 6,1),fpppp(23,13, 6,2),fpppp(23,13, 6,3)/
     x 1.7489806d-06, 7.6552156d-06,-1.0598286d-08 /
      data fpppp(23,13, 7,1),fpppp(23,13, 7,2),fpppp(23,13, 7,3)/
     x 2.9706734d-06, 6.1505383d-06,-7.1459723d-09 /
      data fpppp(23,13, 8,1),fpppp(23,13, 8,2),fpppp(23,13, 8,3)/
     x 2.5432456d-06, 2.4655012d-06,-1.4450998d-09 /
      data fpppp(23,13, 9,1),fpppp(23,13, 9,2),fpppp(23,13, 9,3)/
     x 1.4183631d-06, 6.3476401d-08, 1.4034279d-09 /
      data fpppp(23,13,10,1),fpppp(23,13,10,2),fpppp(23,13,10,3)/
     x 6.4886074d-07,-6.8292049d-07, 1.6159041d-09 /
      data fpppp(23,13,11,1),fpppp(23,13,11,2),fpppp(23,13,11,3)/
     x 3.9749965d-08,-5.2058502d-07, 8.8727248d-10 /
      data fpppp(23,13,12,1),fpppp(23,13,12,2),fpppp(23,13,12,3)/
     x-1.6892306d-07,-1.6935658d-09,-1.0400885d-11 /
      data fpppp(23,13,13,1),fpppp(23,13,13,2),fpppp(23,13,13,3)/
     x-1.9181013d-07, 2.2963502d-07, 5.5421674d-10 /
      data fpppp(23,13,14,1),fpppp(23,13,14,2),fpppp(23,13,14,3)/
     x-2.8130069d-07, 3.9793562d-07, 6.7186269d-10 /
      data fpppp(23,13,15,1),fpppp(23,13,15,2),fpppp(23,13,15,3)/
     x-4.8427401d-07, 3.5769747d-07,-2.0866232d-10 /
      data fpppp(23,13,16,1),fpppp(23,13,16,2),fpppp(23,13,16,3)/
     x-5.4735945d-07, 3.6178160d-07, 3.4755920d-10 /
      data fpppp(23,13,17,1),fpppp(23,13,17,2),fpppp(23,13,17,3)/
     x-6.9849665d-07, 7.0015978d-08,-4.9695811d-10 /
      data fpppp(23,13,18,1),fpppp(23,13,18,2),fpppp(23,13,18,3)/
     x-6.9754294d-07,-2.4139509d-08,-4.3107973d-10 /
      data fpppp(23,13,19,1),fpppp(23,13,19,2),fpppp(23,13,19,3)/
     x-8.9059053d-07,-4.0136430d-07,-4.8061632d-10 /
      data fpppp(23,13,20,1),fpppp(23,13,20,2),fpppp(23,13,20,3)/
     x-9.4735389d-07,-4.4074579d-07, 9.3699158d-10 /
      data fpppp(23,13,21,1),fpppp(23,13,21,2),fpppp(23,13,21,3)/
     x-9.4735389d-07,-4.5777965d-07, 9.0323745d-10 /
      data fpppp(23,13,22,1),fpppp(23,13,22,2),fpppp(23,13,22,3)/
     x-8.9059053d-07,-3.3322884d-07,-3.4559981d-10 /
      data fpppp(23,13,23,1),fpppp(23,13,23,2),fpppp(23,13,23,3)/
     x-6.9754294d-07,-2.7964749d-07,-9.3739164d-10 /
      data fpppp(23,14, 1,1),fpppp(23,14, 1,2),fpppp(23,14, 1,3)/
     x-1.0352232d-06, 9.8071872d-06,-3.6575202d-09 /
      data fpppp(23,14, 2,1),fpppp(23,14, 2,2),fpppp(23,14, 2,3)/
     x-3.7816871d-06, 2.6903651d-06, 1.5202945d-10 /
      data fpppp(23,14, 3,1),fpppp(23,14, 3,2),fpppp(23,14, 3,3)/
     x-5.6032106d-06,-1.2418866d-05, 8.3512303d-09 /
      data fpppp(23,14, 4,1),fpppp(23,14, 4,2),fpppp(23,14, 4,3)/
     x-5.6032106d-06,-1.2665795d-05, 8.2884399d-09 /
      data fpppp(23,14, 5,1),fpppp(23,14, 5,2),fpppp(23,14, 5,3)/
     x-3.7816871d-06, 3.6780792d-06, 4.0319099d-10 /
      data fpppp(23,14, 6,1),fpppp(23,14, 6,2),fpppp(23,14, 6,3)/
     x-1.0352232d-06, 6.1032593d-06,-4.5993759d-09 /
      data fpppp(23,14, 7,1),fpppp(23,14, 7,2),fpppp(23,14, 7,3)/
     x 1.2595195d-06, 5.7958690d-06,-6.2346724d-09 /
      data fpppp(23,14, 8,1),fpppp(23,14, 8,2),fpppp(23,14, 8,3)/
     x 1.9502644d-06, 2.9731400d-06,-4.1185638d-09 /
      data fpppp(23,14, 9,1),fpppp(23,14, 9,2),fpppp(23,14, 9,3)/
     x 1.7043904d-06, 8.8751483d-07,-1.1566047d-09 /
      data fpppp(23,14,10,1),fpppp(23,14,10,2),fpppp(23,14,10,3)/
     x 9.8512626d-07,-2.5192767d-07, 5.4674808d-10 /
      data fpppp(23,14,11,1),fpppp(23,14,11,2),fpppp(23,14,11,3)/
     x 4.8701742d-07,-4.2892845d-07, 7.5599087d-10 /
      data fpppp(23,14,12,1),fpppp(23,14,12,2),fpppp(23,14,12,3)/
     x 2.5026617d-07, 5.0115295d-09, 9.6173649d-10 /
      data fpppp(23,14,13,1),fpppp(23,14,13,2),fpppp(23,14,13,3)/
     x-4.6661084d-08, 7.0762817d-08, 1.9075776d-10 /
      data fpppp(23,14,14,1),fpppp(23,14,14,2),fpppp(23,14,14,3)/
     x-1.7974577d-07, 3.4507310d-07,-4.8583244d-11 /
      data fpppp(23,14,15,1),fpppp(23,14,15,2),fpppp(23,14,15,3)/
     x-1.4955505d-07, 2.7247811d-07, 8.0595280d-10 /
      data fpppp(23,14,16,1),fpppp(23,14,16,2),fpppp(23,14,16,3)/
     x-4.7002181d-07, 3.4270469d-07,-2.2442684d-10 /
      data fpppp(23,14,17,1),fpppp(23,14,17,2),fpppp(23,14,17,3)/
     x-4.4949227d-07, 2.0884611d-08, 3.2840066d-10 /
      data fpppp(23,14,18,1),fpppp(23,14,18,2),fpppp(23,14,18,3)/
     x-5.8467352d-07,-1.5171193d-07,-4.3174442d-10 /
      data fpppp(23,14,19,1),fpppp(23,14,19,2),fpppp(23,14,19,3)/
     x-4.3508824d-07,-2.3434201d-07,-1.5132274d-10 /
      data fpppp(23,14,20,1),fpppp(23,14,20,2),fpppp(23,14,20,3)/
     x-4.6799731d-07,-3.4064145d-07, 3.4543830d-10 /
      data fpppp(23,14,21,1),fpppp(23,14,21,2),fpppp(23,14,21,3)/
     x-4.6799731d-07,-3.4220903d-07, 3.4774525d-10 /
      data fpppp(23,14,22,1),fpppp(23,14,22,2),fpppp(23,14,22,3)/
     x-4.3508824d-07,-2.2807169d-07,-1.6055056d-10 /
      data fpppp(23,14,23,1),fpppp(23,14,23,2),fpppp(23,14,23,3)/
     x-5.8467352d-07,-1.7522562d-07,-3.9714009d-10 /
      data fpppp(23,15, 1,1),fpppp(23,15, 1,2),fpppp(23,15, 1,3)/
     x-4.5612185d-06, 6.7859789d-06, 7.8836381d-09 /
      data fpppp(23,15, 2,1),fpppp(23,15, 2,2),fpppp(23,15, 2,3)/
     x-8.2702651d-06, 1.6512718d-06, 4.6971218d-09 /
      data fpppp(23,15, 3,1),fpppp(23,15, 3,2),fpppp(23,15, 3,3)/
     x-1.1727537d-05,-9.2119079d-06,-1.9828361d-09 /
      data fpppp(23,15, 4,1),fpppp(23,15, 4,2),fpppp(23,15, 4,3)/
     x-1.1727537d-05,-9.4564951d-06,-2.2423458d-09 /
      data fpppp(23,15, 5,1),fpppp(23,15, 5,2),fpppp(23,15, 5,3)/
     x-8.2702651d-06, 2.6296207d-06, 5.7351608d-09 /
      data fpppp(23,15, 6,1),fpppp(23,15, 6,2),fpppp(23,15, 6,3)/
     x-4.5612185d-06, 3.1171706d-06, 3.9909919d-09 /
      data fpppp(23,15, 7,1),fpppp(23,15, 7,2),fpppp(23,15, 7,3)/
     x-2.3706533d-06, 3.9107959d-06,-1.8543994d-11 /
      data fpppp(23,15, 8,1),fpppp(23,15, 8,2),fpppp(23,15, 8,3)/
     x-4.9075474d-07, 2.6607480d-06,-2.9030229d-09 /
      data fpppp(23,15, 9,1),fpppp(23,15, 9,2),fpppp(23,15, 9,3)/
     x 5.8760502d-07, 1.2766110d-06,-3.0642906d-09 /
      data fpppp(23,15,10,1),fpppp(23,15,10,2),fpppp(23,15,10,3)/
     x 8.3290157d-07, 3.6762133d-07,-1.3913926d-09 /
      data fpppp(23,15,11,1),fpppp(23,15,11,2),fpppp(23,15,11,3)/
     x 6.4004721d-07,-4.9692530d-08,-6.9969521d-11 /
      data fpppp(23,15,12,1),fpppp(23,15,12,2),fpppp(23,15,12,3)/
     x 3.0098874d-07,-2.7492937d-08,-1.3114525d-11 /
      data fpppp(23,15,13,1),fpppp(23,15,13,2),fpppp(23,15,13,3)/
     x 2.7454907d-07, 3.8850214d-08, 4.2776360d-10 /
      data fpppp(23,15,14,1),fpppp(23,15,14,2),fpppp(23,15,14,3)/
     x 2.1463036d-07, 3.7886946d-07, 2.3899417d-10 /
      data fpppp(23,15,15,1),fpppp(23,15,15,2),fpppp(23,15,15,3)/
     x 6.4399260d-09, 1.0501081d-07,-6.6255808d-11 /
      data fpppp(23,15,16,1),fpppp(23,15,16,2),fpppp(23,15,16,3)/
     x 7.5345662d-07, 2.5842572d-07, 6.3805197d-10 /
      data fpppp(23,15,17,1),fpppp(23,15,17,2),fpppp(23,15,17,3)/
     x-6.9293493d-08, 2.0976135d-08, 2.0284718d-10 /
      data fpppp(23,15,18,1),fpppp(23,15,18,2),fpppp(23,15,18,3)/
     x-7.1454078d-08,-6.1136604d-08, 5.1218680d-10 /
      data fpppp(23,15,19,1),fpppp(23,15,19,2),fpppp(23,15,19,3)/
     x-2.3489917d-07,-2.0535334d-07,-5.5010192d-10 /
      data fpppp(23,15,20,1),fpppp(23,15,20,2),fpppp(23,15,20,3)/
     x-1.0847807d-07,-2.1037731d-07,-2.4883737d-10 /
      data fpppp(23,15,21,1),fpppp(23,15,21,2),fpppp(23,15,21,3)/
     x-1.0847807d-07,-2.1711175d-07,-3.0593605d-10 /
      data fpppp(23,15,22,1),fpppp(23,15,22,2),fpppp(23,15,22,3)/
     x-2.3489917d-07,-1.7841558d-07,-3.2170720d-10 /
      data fpppp(23,15,23,1),fpppp(23,15,23,2),fpppp(23,15,23,3)/
     x-7.1454078d-08,-1.6215321d-07,-3.4429339d-10 /
      data fpppp(23,16, 1,1),fpppp(23,16, 1,2),fpppp(23,16, 1,3)/
     x-4.2097996d-06, 3.0548909d-06, 7.3097482d-09 /
      data fpppp(23,16, 2,1),fpppp(23,16, 2,2),fpppp(23,16, 2,3)/
     x 3.9221740d-07, 6.1502673d-07, 3.0259227d-09 /
      data fpppp(23,16, 3,1),fpppp(23,16, 3,2),fpppp(23,16, 3,3)/
     x 3.8765885d-06,-4.4920691d-06,-6.1124236d-09 /
      data fpppp(23,16, 4,1),fpppp(23,16, 4,2),fpppp(23,16, 4,3)/
     x 3.8765885d-06,-4.7041418d-06,-6.1846636d-09 /
      data fpppp(23,16, 5,1),fpppp(23,16, 5,2),fpppp(23,16, 5,3)/
     x 3.9221740d-07, 1.4633176d-06, 3.3148826d-09 /
      data fpppp(23,16, 6,1),fpppp(23,16, 6,2),fpppp(23,16, 6,3)/
     x-4.2097996d-06,-1.2620009d-07, 6.2261483d-09 /
      data fpppp(23,16, 7,1),fpppp(23,16, 7,2),fpppp(23,16, 7,3)/
     x-3.7191826d-06, 1.7396820d-06, 4.3271715d-09 /
      data fpppp(23,16, 8,1),fpppp(23,16, 8,2),fpppp(23,16, 8,3)/
     x-2.5487701d-06, 1.5829321d-06, 6.6662336d-10 /
      data fpppp(23,16, 9,1),fpppp(23,16, 9,2),fpppp(23,16, 9,3)/
     x-1.3102554d-06, 9.3877218d-07,-1.3884269d-09 /
      data fpppp(23,16,10,1),fpppp(23,16,10,2),fpppp(23,16,10,3)/
     x-2.5001443d-07, 6.7641745d-07,-2.0683691d-09 /
      data fpppp(23,16,11,1),fpppp(23,16,11,2),fpppp(23,16,11,3)/
     x 2.3668126d-07, 1.9449630d-07,-1.2451523d-09 /
      data fpppp(23,16,12,1),fpppp(23,16,12,2),fpppp(23,16,12,3)/
     x 4.2575390d-07, 1.6986196d-07,-4.6592874d-10 /
      data fpppp(23,16,13,1),fpppp(23,16,13,2),fpppp(23,16,13,3)/
     x 2.9716266d-07, 9.5182597d-08,-3.8617125d-10 /
      data fpppp(23,16,14,1),fpppp(23,16,14,2),fpppp(23,16,14,3)/
     x 3.4229684d-07, 3.3478309d-08, 1.4669329d-10 /
      data fpppp(23,16,15,1),fpppp(23,16,15,2),fpppp(23,16,15,3)/
     x 3.6560011d-07, 9.1440621d-07, 2.0708266d-10 /
      data fpppp(23,16,16,1),fpppp(23,16,16,2),fpppp(23,16,16,3)/
     x-8.5681467d-07,-1.1296636d-06, 1.0608333d-10 /
      data fpppp(23,16,17,1),fpppp(23,16,17,2),fpppp(23,16,17,3)/
     x 4.8669039d-07, 8.8729530d-07, 2.5674091d-10 /
      data fpppp(23,16,18,1),fpppp(23,16,18,2),fpppp(23,16,18,3)/
     x 5.2446680d-07,-3.1074284d-07,-2.7698838d-10 /
      data fpppp(23,16,19,1),fpppp(23,16,19,2),fpppp(23,16,19,3)/
     x 6.9096400d-07, 8.6483241d-08, 2.7514247d-10 /
      data fpppp(23,16,20,1),fpppp(23,16,20,2),fpppp(23,16,20,3)/
     x 5.1295151d-07,-1.5886248d-07,-3.0375147d-10 /
      data fpppp(23,16,21,1),fpppp(23,16,21,2),fpppp(23,16,21,3)/
     x 5.1295151d-07,-1.3457194d-07,-2.6471913d-10 /
      data fpppp(23,16,22,1),fpppp(23,16,22,2),fpppp(23,16,22,3)/
     x 6.9096400d-07,-1.0678928d-08, 1.1901310d-10 /
      data fpppp(23,16,23,1),fpppp(23,16,23,2),fpppp(23,16,23,3)/
     x 5.2446680d-07, 5.3615288d-08, 3.0849677d-10 /
      data fpppp(23,17, 1,1),fpppp(23,17, 1,2),fpppp(23,17, 1,3)/
     x 7.5057880d-07,-2.2186721d-07, 1.6353471d-09 /
      data fpppp(23,17, 2,1),fpppp(23,17, 2,2),fpppp(23,17, 2,3)/
     x 7.8681073d-07,-5.8925929d-07,-2.0676855d-10 /
      data fpppp(23,17, 3,1),fpppp(23,17, 3,2),fpppp(23,17, 3,3)/
     x 3.1706623d-06,-1.4255854d-06,-4.1816231d-09 /
      data fpppp(23,17, 4,1),fpppp(23,17, 4,2),fpppp(23,17, 4,3)/
     x 3.1706623d-06,-1.3397350d-06,-4.1335613d-09 /
      data fpppp(23,17, 5,1),fpppp(23,17, 5,2),fpppp(23,17, 5,3)/
     x 7.8681073d-07,-9.3266080d-07,-3.9901611d-10 /
      data fpppp(23,17, 6,1),fpppp(23,17, 6,2),fpppp(23,17, 6,3)/
     x 7.5057880d-07, 1.0658885d-06, 2.3562754d-09 /
      data fpppp(23,17, 7,1),fpppp(23,17, 7,2),fpppp(23,17, 7,3)/
     x-1.6844800d-06,-4.9036577d-07, 3.6267401d-09 /
      data fpppp(23,17, 8,1),fpppp(23,17, 8,2),fpppp(23,17, 8,3)/
     x-2.1628507d-06, 6.7059567d-07, 2.6771410d-09 /
      data fpppp(23,17, 9,1),fpppp(23,17, 9,2),fpppp(23,17, 9,3)/
     x-1.7373152d-06, 3.7272577d-07, 9.7867034d-10 /
      data fpppp(23,17,10,1),fpppp(23,17,10,2),fpppp(23,17,10,3)/
     x-1.0890446d-06, 4.0914103d-07,-1.8431067d-11 /
      data fpppp(23,17,11,1),fpppp(23,17,11,2),fpppp(23,17,11,3)/
     x-4.1928721d-07, 2.6033764d-07,-7.7689262d-10 /
      data fpppp(23,17,12,1),fpppp(23,17,12,2),fpppp(23,17,12,3)/
     x 6.1805241d-08, 1.3131813d-07,-7.6998503d-10 /
      data fpppp(23,17,13,1),fpppp(23,17,13,2),fpppp(23,17,13,3)/
     x 4.3588578d-07, 2.0840880d-07,-4.6834920d-10 /
      data fpppp(23,17,14,1),fpppp(23,17,14,2),fpppp(23,17,14,3)/
     x 4.9846366d-07, 4.6330549d-08,-4.7787034d-10 /
      data fpppp(23,17,15,1),fpppp(23,17,15,2),fpppp(23,17,15,3)/
     x 7.1721773d-07, 1.5451505d-07,-2.0839223d-10 /
      data fpppp(23,17,16,1),fpppp(23,17,16,2),fpppp(23,17,16,3)/
     x 1.6435694d-06, 8.1082438d-08,-2.5012717d-11 /
      data fpppp(23,17,17,1),fpppp(23,17,17,2),fpppp(23,17,17,3)/
     x 9.9982218d-07, 5.1373296d-08,-1.7298377d-10 /
      data fpppp(23,17,18,1),fpppp(23,17,18,2),fpppp(23,17,18,3)/
     x 1.1377237d-06, 2.9103903d-08, 1.1085848d-11 /
      data fpppp(23,17,19,1),fpppp(23,17,19,2),fpppp(23,17,19,3)/
     x 1.1825302d-06,-1.6747301d-08,-3.4857151d-10 /
      data fpppp(23,17,20,1),fpppp(23,17,20,2),fpppp(23,17,20,3)/
     x 1.4307160d-06,-1.3254603d-09, 1.6093825d-10 /
      data fpppp(23,17,21,1),fpppp(23,17,21,2),fpppp(23,17,21,3)/
     x 1.4307160d-06,-3.8435645d-09, 1.3257930d-10 /
      data fpppp(23,17,22,1),fpppp(23,17,22,2),fpppp(23,17,22,3)/
     x 1.1825302d-06,-6.6748841d-09,-2.3513570d-10 /
      data fpppp(23,17,23,1),fpppp(23,17,23,2),fpppp(23,17,23,3)/
     x 1.1377237d-06,-8.6676610d-09,-4.1429843d-10 /
      data fpppp(23,18, 1,1),fpppp(23,18, 1,2),fpppp(23,18, 1,3)/
     x 9.7692103d-07,-1.9959184d-07, 3.2155370d-10 /
      data fpppp(23,18, 2,1),fpppp(23,18, 2,2),fpppp(23,18, 2,3)/
     x 2.7613455d-06,-2.1241624d-07,-4.2422901d-10 /
      data fpppp(23,18, 3,1),fpppp(23,18, 3,2),fpppp(23,18, 3,3)/
     x 4.0081748d-06,-2.4741385d-07,-2.0322519d-09 /
      data fpppp(23,18, 4,1),fpppp(23,18, 4,2),fpppp(23,18, 4,3)/
     x 4.0081748d-06,-2.3425951d-07,-2.0148971d-09 /
      data fpppp(23,18, 5,1),fpppp(23,18, 5,2),fpppp(23,18, 5,3)/
     x 2.7613455d-06,-2.6503359d-07,-4.9364820d-10 /
      data fpppp(23,18, 6,1),fpppp(23,18, 6,2),fpppp(23,18, 6,3)/
     x 9.7692103d-07,-2.2767730d-09, 5.8187566d-10 /
      data fpppp(23,18, 7,1),fpppp(23,18, 7,2),fpppp(23,18, 7,3)/
     x 3.2104688d-07,-1.1712702d-07, 1.0481954d-09 /
      data fpppp(23,18, 8,1),fpppp(23,18, 8,2),fpppp(23,18, 8,3)/
     x-3.9071295d-07, 5.6028716d-08, 1.2223780d-09 /
      data fpppp(23,18, 9,1),fpppp(23,18, 9,2),fpppp(23,18, 9,3)/
     x-7.8337367d-07, 1.5141688d-08, 1.0011570d-09 /
      data fpppp(23,18,10,1),fpppp(23,18,10,2),fpppp(23,18,10,3)/
     x-8.2429593d-07, 7.4651129d-08, 6.3488207d-10 /
      data fpppp(23,18,11,1),fpppp(23,18,11,2),fpppp(23,18,11,3)/
     x-6.4899043d-07, 1.1519983d-07, 3.7415657d-10 /
      data fpppp(23,18,12,1),fpppp(23,18,12,2),fpppp(23,18,12,3)/
     x-3.9196139d-07, 3.3345284d-08, 8.7344952d-11 /
      data fpppp(23,18,13,1),fpppp(23,18,13,2),fpppp(23,18,13,3)/
     x-8.0746094d-08, 7.8804927d-08,-8.7770111d-11 /
      data fpppp(23,18,14,1),fpppp(23,18,14,2),fpppp(23,18,14,3)/
     x 2.9612629d-07, 8.3303922d-08,-1.4733531d-10 /
      data fpppp(23,18,15,1),fpppp(23,18,15,2),fpppp(23,18,15,3)/
     x 5.8757758d-07, 5.8422219d-08,-1.7768213d-10 /
      data fpppp(23,18,16,1),fpppp(23,18,16,2),fpppp(23,18,16,3)/
     x 7.4380623d-07, 6.1963726d-08,-2.7723562d-10 /
      data fpppp(23,18,17,1),fpppp(23,18,17,2),fpppp(23,18,17,3)/
     x 1.1637937d-06, 2.0395017d-08,-1.9582488d-10 /
      data fpppp(23,18,18,1),fpppp(23,18,18,2),fpppp(23,18,18,3)/
     x 1.4293996d-06, 4.5525148d-08,-2.1207574d-10 /
      data fpppp(23,18,19,1),fpppp(23,18,19,2),fpppp(23,18,19,3)/
     x 1.6413106d-06, 7.1426443d-08,-7.0954462d-11 /
      data fpppp(23,18,20,1),fpppp(23,18,20,2),fpppp(23,18,20,3)/
     x 1.6869878d-06, 1.6793429d-08,-1.7488871d-10 /
      data fpppp(23,18,21,1),fpppp(23,18,21,2),fpppp(23,18,21,3)/
     x 1.6869878d-06, 1.9233145d-08,-1.6588758d-10 /
      data fpppp(23,18,22,1),fpppp(23,18,22,2),fpppp(23,18,22,3)/
     x 1.6413106d-06, 6.1667576d-08,-1.0695901d-10 /
      data fpppp(23,18,23,1),fpppp(23,18,23,2),fpppp(23,18,23,3)/
     x 1.4293996d-06, 8.2120901d-08,-7.7058703d-11 /
      data fpppp(23,19, 1,1),fpppp(23,19, 1,2),fpppp(23,19, 1,3)/
     x 2.5558450d-06,-1.8003992d-20,-2.2381276d-09 /
      data fpppp(23,19, 2,1),fpppp(23,19, 2,2),fpppp(23,19, 2,3)/
     x 4.2844685d-06, 1.3581908d-21,-1.5031840d-09 /
      data fpppp(23,19, 3,1),fpppp(23,19, 3,2),fpppp(23,19, 3,3)/
     x 4.4047048d-06,-1.0197989d-20, 5.4670609d-11 /
      data fpppp(23,19, 4,1),fpppp(23,19, 4,2),fpppp(23,19, 4,3)/
     x 4.4047048d-06,-2.8917164d-21, 8.4463735d-11 /
      data fpppp(23,19, 5,1),fpppp(23,19, 5,2),fpppp(23,19, 5,3)/
     x 4.2844685d-06, 5.6026605d-21,-1.6223565d-09 /
      data fpppp(23,19, 6,1),fpppp(23,19, 6,2),fpppp(23,19, 6,3)/
     x 2.5558450d-06, 2.4743998d-21,-1.7912307d-09 /
      data fpppp(23,19, 7,1),fpppp(23,19, 7,2),fpppp(23,19, 7,3)/
     x 2.3349097d-06, 7.2646670d-22,-9.9374552d-10 /
      data fpppp(23,19, 8,1),fpppp(23,19, 8,2),fpppp(23,19, 8,3)/
     x 9.8536244d-07,-1.1639230d-20, 7.5769521d-10 /
      data fpppp(23,19, 9,1),fpppp(23,19, 9,2),fpppp(23,19, 9,3)/
     x-2.2400393d-07,-3.4812690d-22, 1.6935324d-09 /
      data fpppp(23,19,10,1),fpppp(23,19,10,2),fpppp(23,19,10,3)/
     x-8.7491266d-07,-9.6156827d-23, 1.6872309d-09 /
      data fpppp(23,19,11,1),fpppp(23,19,11,2),fpppp(23,19,11,3)/
     x-1.0004837d-06,-2.0623351d-21, 1.3301230d-09 /
      data fpppp(23,19,12,1),fpppp(23,19,12,2),fpppp(23,19,12,3)/
     x-8.2006574d-07,-1.3779410d-21, 6.1285028d-10 /
      data fpppp(23,19,13,1),fpppp(23,19,13,2),fpppp(23,19,13,3)/
     x-4.1013369d-07, 6.3435861d-22, 1.6059268d-10 /
      data fpppp(23,19,14,1),fpppp(23,19,14,2),fpppp(23,19,14,3)/
     x 1.9621869d-07, 4.5061256d-21,-8.9685621d-11 /
      data fpppp(23,19,15,1),fpppp(23,19,15,2),fpppp(23,19,15,3)/
     x 5.9543965d-07,-2.7445866d-21,-2.7445345d-10 /
      data fpppp(23,19,16,1),fpppp(23,19,16,2),fpppp(23,19,16,3)/
     x 8.1551370d-07,-5.4571129d-21,-4.9485084d-10 /
      data fpppp(23,19,17,1),fpppp(23,19,17,2),fpppp(23,19,17,3)/
     x 1.4275253d-06, 1.1076333d-21,-3.3491844d-10 /
      data fpppp(23,19,18,1),fpppp(23,19,18,2),fpppp(23,19,18,3)/
     x 1.8129558d-06, 4.3004836d-21,-2.8916996d-10 /
      data fpppp(23,19,19,1),fpppp(23,19,19,2),fpppp(23,19,19,3)/
     x 2.1094584d-06, 2.1468984d-22,-5.0860566d-11 /
      data fpppp(23,19,20,1),fpppp(23,19,20,2),fpppp(23,19,20,3)/
     x 2.1322576d-06, 4.0820737d-21,-2.8199663d-10 /
      data fpppp(23,19,21,1),fpppp(23,19,21,2),fpppp(23,19,21,3)/
     x 2.1322576d-06, 5.0806669d-21,-2.6556437d-10 /
      data fpppp(23,19,22,1),fpppp(23,19,22,2),fpppp(23,19,22,3)/
     x 2.1094584d-06, 5.2988753d-21,-1.1658960d-10 /
      data fpppp(23,19,23,1),fpppp(23,19,23,2),fpppp(23,19,23,3)/
     x 1.8129558d-06,-1.4550313d-20,-4.2686099d-11 /
      data fpppp(24, 1, 1,1),fpppp(24, 1, 1,2),fpppp(24, 1, 1,3)/
     x-2.9771366d-05,-4.5628750d-19,-2.1152449d-08 /
      data fpppp(24, 1, 2,1),fpppp(24, 1, 2,2),fpppp(24, 1, 2,3)/
     x 2.6509350d-06, 1.4724771d-20,-2.8014854d-08 /
      data fpppp(24, 1, 3,1),fpppp(24, 1, 3,2),fpppp(24, 1, 3,3)/
     x 2.7486429d-05, 1.3425661d-19,-4.2999663d-08 /
      data fpppp(24, 1, 4,1),fpppp(24, 1, 4,2),fpppp(24, 1, 4,3)/
     x 2.7486429d-05, 1.9886049d-19,-4.2510269d-08 /
      data fpppp(24, 1, 5,1),fpppp(24, 1, 5,2),fpppp(24, 1, 5,3)/
     x 2.6509350d-06, 3.5153560d-20,-2.9972431d-08 /
      data fpppp(24, 1, 6,1),fpppp(24, 1, 6,2),fpppp(24, 1, 6,3)/
     x-2.9771366d-05, 4.8592105d-20,-1.3811536d-08 /
      data fpppp(24, 1, 7,1),fpppp(24, 1, 7,2),fpppp(24, 1, 7,3)/
     x-5.9797734d-05, 5.2305806d-20, 2.8597119d-09 /
      data fpppp(24, 1, 8,1),fpppp(24, 1, 8,2),fpppp(24, 1, 8,3)/
     x-8.1248903d-05,-4.2172640d-20, 1.5238676d-08 /
      data fpppp(24, 1, 9,1),fpppp(24, 1, 9,2),fpppp(24, 1, 9,3)/
     x-9.5012468d-05,-9.6970907d-20, 2.1964677d-08 /
      data fpppp(24, 1,10,1),fpppp(24, 1,10,2),fpppp(24, 1,10,3)/
     x-1.0479145d-04,-1.5319611d-19, 2.5302684d-08 /
      data fpppp(24, 1,11,1),fpppp(24, 1,11,2),fpppp(24, 1,11,3)/
     x-1.0930914d-04, 1.1463146d-19, 2.6385774d-08 /
      data fpppp(24, 1,12,1),fpppp(24, 1,12,2),fpppp(24, 1,12,3)/
     x-1.1240857d-04,-2.0179292d-19, 2.7364192d-08 /
      data fpppp(24, 1,13,1),fpppp(24, 1,13,2),fpppp(24, 1,13,3)/
     x-1.1230023d-04, 6.2082519d-20, 2.7533170d-08 /
      data fpppp(24, 1,14,1),fpppp(24, 1,14,2),fpppp(24, 1,14,3)/
     x-1.0697737d-04, 6.8401619d-20, 2.6970908d-08 /
      data fpppp(24, 1,15,1),fpppp(24, 1,15,2),fpppp(24, 1,15,3)/
     x-9.8095094d-05,-1.0500508d-19, 2.4264034d-08 /
      data fpppp(24, 1,16,1),fpppp(24, 1,16,2),fpppp(24, 1,16,3)/
     x-8.4998525d-05,-1.3271738d-19, 1.7091992d-08 /
      data fpppp(24, 1,17,1),fpppp(24, 1,17,2),fpppp(24, 1,17,3)/
     x-6.3970585d-05, 1.5807084d-19, 4.2919317d-09 /
      data fpppp(24, 1,18,1),fpppp(24, 1,18,2),fpppp(24, 1,18,3)/
     x-3.4413666d-05, 6.5274570d-20,-1.3676152d-08 /
      data fpppp(24, 1,19,1),fpppp(24, 1,19,2),fpppp(24, 1,19,3)/
     x 6.8103230d-06, 7.4103661d-20,-3.0655144d-08 /
      data fpppp(24, 1,20,1),fpppp(24, 1,20,2),fpppp(24, 1,20,3)/
     x 2.8644108d-05,-1.8242885d-20,-4.4706034d-08 /
      data fpppp(24, 1,21,1),fpppp(24, 1,21,2),fpppp(24, 1,21,3)/
     x 2.8644108d-05,-1.1637966d-19,-4.5200745d-08 /
      data fpppp(24, 1,22,1),fpppp(24, 1,22,2),fpppp(24, 1,22,3)/
     x 6.8103230d-06, 8.2151342d-20,-2.8676300d-08 /
      data fpppp(24, 1,23,1),fpppp(24, 1,23,2),fpppp(24, 1,23,3)/
     x-3.4413666d-05,-1.0044804d-19,-2.1096815d-08 /
      data fpppp(24, 2, 1,1),fpppp(24, 2, 1,2),fpppp(24, 2, 1,3)/
     x-2.0192750d-05,-1.3372359d-05,-5.9827180d-09 /
      data fpppp(24, 2, 2,1),fpppp(24, 2, 2,2),fpppp(24, 2, 2,3)/
     x-7.6938966d-06,-8.1080196d-06,-8.7500605d-09 /
      data fpppp(24, 2, 3,1),fpppp(24, 2, 3,2),fpppp(24, 2, 3,3)/
     x 3.5392693d-06, 2.7354494d-06,-1.4773982d-08 /
      data fpppp(24, 2, 4,1),fpppp(24, 2, 4,2),fpppp(24, 2, 4,3)/
     x 3.5392693d-06, 3.5006498d-06,-1.4609654d-08 /
      data fpppp(24, 2, 5,1),fpppp(24, 2, 5,2),fpppp(24, 2, 5,3)/
     x-7.6938966d-06,-1.1168821d-05,-9.4073701d-09 /
      data fpppp(24, 2, 6,1),fpppp(24, 2, 6,2),fpppp(24, 2, 6,3)/
     x-2.0192750d-05,-1.8943531d-06,-3.5178070d-09 /
      data fpppp(24, 2, 7,1),fpppp(24, 2, 7,2),fpppp(24, 2, 7,3)/
     x-3.0731249d-05,-1.1136950d-06, 2.0763217d-09 /
      data fpppp(24, 2, 8,1),fpppp(24, 2, 8,2),fpppp(24, 2, 8,3)/
     x-3.7280997d-05, 1.8944711d-08, 5.7805442d-09 /
      data fpppp(24, 2, 9,1),fpppp(24, 2, 9,2),fpppp(24, 2, 9,3)/
     x-4.0685425d-05, 2.6763213d-06, 7.2433157d-09 /
      data fpppp(24, 2,10,1),fpppp(24, 2,10,2),fpppp(24, 2,10,3)/
     x-4.3052696d-05, 1.8427488d-06, 7.5460540d-09 /
      data fpppp(24, 2,11,1),fpppp(24, 2,11,2),fpppp(24, 2,11,3)/
     x-4.3825236d-05, 3.5690710d-06, 7.2500925d-09 /
      data fpppp(24, 2,12,1),fpppp(24, 2,12,2),fpppp(24, 2,12,3)/
     x-4.4874821d-05, 2.7609372d-06, 7.4536334d-09 /
      data fpppp(24, 2,13,1),fpppp(24, 2,13,2),fpppp(24, 2,13,3)/
     x-4.5338255d-05, 2.1940440d-06, 7.8239514d-09 /
      data fpppp(24, 2,14,1),fpppp(24, 2,14,2),fpppp(24, 2,14,3)/
     x-4.4226534d-05, 2.8525629d-06, 8.3949980d-09 /
      data fpppp(24, 2,15,1),fpppp(24, 2,15,2),fpppp(24, 2,15,3)/
     x-4.2340125d-05, 2.6199127d-06, 8.4743802d-09 /
      data fpppp(24, 2,16,1),fpppp(24, 2,16,2),fpppp(24, 2,16,3)/
     x-3.9288810d-05,-2.3554608d-07, 6.8494058d-09 /
      data fpppp(24, 2,17,1),fpppp(24, 2,17,2),fpppp(24, 2,17,3)/
     x-3.2956508d-05, 5.3382506d-07, 2.9601309d-09 /
      data fpppp(24, 2,18,1),fpppp(24, 2,18,2),fpppp(24, 2,18,3)/
     x-2.2664211d-05,-7.1951328d-06,-3.3370631d-09 /
      data fpppp(24, 2,19,1),fpppp(24, 2,19,2),fpppp(24, 2,19,3)/
     x-5.8267501d-06,-3.6290483d-06,-9.7562402d-09 /
      data fpppp(24, 2,20,1),fpppp(24, 2,20,2),fpppp(24, 2,20,3)/
     x 3.5645420d-06, 7.6556328d-07,-1.5872455d-08 /
      data fpppp(24, 2,21,1),fpppp(24, 2,21,2),fpppp(24, 2,21,3)/
     x 3.5645420d-06, 8.3749046d-07,-1.6041677d-08 /
      data fpppp(24, 2,22,1),fpppp(24, 2,22,2),fpppp(24, 2,22,3)/
     x-5.8267501d-06,-3.9167570d-06,-9.0793522d-09 /
      data fpppp(24, 2,23,1),fpppp(24, 2,23,2),fpppp(24, 2,23,3)/
     x-2.2664211d-05,-6.1162252d-06,-5.8753930d-09 /
      data fpppp(24, 3, 1,1),fpppp(24, 3, 1,2),fpppp(24, 3, 1,3)/
     x-1.2308924d-05,-1.8242880d-05, 1.5551741d-08 /
      data fpppp(24, 3, 2,1),fpppp(24, 3, 2,2),fpppp(24, 3, 2,3)/
     x-2.7304738d-05,-1.3613116d-05, 1.8308255d-08 /
      data fpppp(24, 3, 3,1),fpppp(24, 3, 3,2),fpppp(24, 3, 3,3)/
     x-2.0520507d-05,-4.3121430d-06, 2.4254535d-08 /
      data fpppp(24, 3, 4,1),fpppp(24, 3, 4,2),fpppp(24, 3, 4,3)/
     x-2.0520507d-05,-3.2272306d-06, 2.4185470d-08 /
      data fpppp(24, 3, 5,1),fpppp(24, 3, 5,2),fpppp(24, 3, 5,3)/
     x-2.7304738d-05,-1.7952765d-05, 1.8584514d-08 /
      data fpppp(24, 3, 6,1),fpppp(24, 3, 6,2),fpppp(24, 3, 6,3)/
     x-1.2308924d-05,-1.9691946d-06, 1.4515771d-08 /
      data fpppp(24, 3, 7,1),fpppp(24, 3, 7,2),fpppp(24, 3, 7,3)/
     x 8.1074429d-06, 1.7675888d-06, 6.3603682d-09 /
      data fpppp(24, 3, 8,1),fpppp(24, 3, 8,2),fpppp(24, 3, 8,3)/
     x 2.5149363d-05, 3.3942193d-06,-4.0153285d-09 /
      data fpppp(24, 3, 9,1),fpppp(24, 3, 9,2),fpppp(24, 3, 9,3)/
     x 3.9181194d-05, 5.1911369d-06,-1.3605404d-08 /
      data fpppp(24, 3,10,1),fpppp(24, 3,10,2),fpppp(24, 3,10,3)/
     x 4.9789507d-05, 5.6848925d-06,-2.0642569d-08 /
      data fpppp(24, 3,11,1),fpppp(24, 3,11,2),fpppp(24, 3,11,3)/
     x 5.5284859d-05, 5.8293115d-06,-2.4736005d-08 /
      data fpppp(24, 3,12,1),fpppp(24, 3,12,2),fpppp(24, 3,12,3)/
     x 5.7618907d-05, 5.9065819d-06,-2.6343613d-08 /
      data fpppp(24, 3,13,1),fpppp(24, 3,13,2),fpppp(24, 3,13,3)/
     x 5.6162819d-05, 5.9203204d-06,-2.4899565d-08 /
      data fpppp(24, 3,14,1),fpppp(24, 3,14,2),fpppp(24, 3,14,3)/
     x 4.9849817d-05, 5.8497189d-06,-2.0463656d-08 /
      data fpppp(24, 3,15,1),fpppp(24, 3,15,2),fpppp(24, 3,15,3)/
     x 3.9283846d-05, 5.5344278d-06,-1.3399946d-08 /
      data fpppp(24, 3,16,1),fpppp(24, 3,16,2),fpppp(24, 3,16,3)/
     x 2.5241259d-05, 3.6031984d-06,-3.3432990d-09 /
      data fpppp(24, 3,17,1),fpppp(24, 3,17,2),fpppp(24, 3,17,3)/
     x 8.1967154d-06, 2.5292504d-06, 7.0806714d-09 /
      data fpppp(24, 3,18,1),fpppp(24, 3,18,2),fpppp(24, 3,18,3)/
     x-1.1904519d-05,-2.9986926d-06, 1.5425581d-08 /
      data fpppp(24, 3,19,1),fpppp(24, 3,19,2),fpppp(24, 3,19,3)/
     x-3.0234037d-05,-1.4666542d-05, 1.7982271d-08 /
      data fpppp(24, 3,20,1),fpppp(24, 3,20,2),fpppp(24, 3,20,3)/
     x-2.4607519d-05,-5.4455088d-06, 2.3466013d-08 /
      data fpppp(24, 3,21,1),fpppp(24, 3,21,2),fpppp(24, 3,21,3)/
     x-2.4607519d-05,-6.2036258d-06, 2.3465899d-08 /
      data fpppp(24, 3,22,1),fpppp(24, 3,22,2),fpppp(24, 3,22,3)/
     x-3.0234037d-05,-1.1634074d-05, 1.7982725d-08 /
      data fpppp(24, 3,23,1),fpppp(24, 3,23,2),fpppp(24, 3,23,3)/
     x-1.1904519d-05,-1.4370448d-05, 1.5423880d-08 /
      data fpppp(24, 4, 1,1),fpppp(24, 4, 1,2),fpppp(24, 4, 1,3)/
     x 1.5066689d-06,-2.0198653d-06, 1.4809651d-08 /
      data fpppp(24, 4, 2,1),fpppp(24, 4, 2,2),fpppp(24, 4, 2,3)/
     x-1.4484545d-05,-5.7524392d-06, 1.8089245d-08 /
      data fpppp(24, 4, 3,1),fpppp(24, 4, 3,2),fpppp(24, 4, 3,3)/
     x-4.4186124d-05,-1.3772239d-05, 2.5473129d-08 /
      data fpppp(24, 4, 4,1),fpppp(24, 4, 4,2),fpppp(24, 4, 4,3)/
     x-4.4186124d-05,-1.3734742d-05, 2.4849810d-08 /
      data fpppp(24, 4, 5,1),fpppp(24, 4, 5,2),fpppp(24, 4, 5,3)/
     x-1.4484545d-05,-5.9024283d-06, 2.0582518d-08 /
      data fpppp(24, 4, 6,1),fpppp(24, 4, 6,2),fpppp(24, 4, 6,3)/
     x 1.5066689d-06,-1.4574064d-06, 5.4598760d-09 /
      data fpppp(24, 4, 7,1),fpppp(24, 4, 7,2),fpppp(24, 4, 7,3)/
     x 1.2743414d-05, 2.3561735d-06,-7.0916136d-09 /
      data fpppp(24, 4, 8,1),fpppp(24, 4, 8,2),fpppp(24, 4, 8,3)/
     x 2.2961136d-05, 4.8255995d-06,-1.2629108d-08 /
      data fpppp(24, 4, 9,1),fpppp(24, 4, 9,2),fpppp(24, 4, 9,3)/
     x 2.9659297d-05, 5.3596318d-06,-1.3008370d-08 /
      data fpppp(24, 4,10,1),fpppp(24, 4,10,2),fpppp(24, 4,10,3)/
     x 3.3769624d-05, 5.6114663d-06,-1.2319217d-08 /
      data fpppp(24, 4,11,1),fpppp(24, 4,11,2),fpppp(24, 4,11,3)/
     x 3.6703275d-05, 6.0643585d-06,-1.1745647d-08 /
      data fpppp(24, 4,12,1),fpppp(24, 4,12,2),fpppp(24, 4,12,3)/
     x 3.7752697d-05, 6.2620852d-06,-1.1537451d-08 /
      data fpppp(24, 4,13,1),fpppp(24, 4,13,2),fpppp(24, 4,13,3)/
     x 3.6777065d-05, 6.2329090d-06,-1.2073040d-08 /
      data fpppp(24, 4,14,1),fpppp(24, 4,14,2),fpppp(24, 4,14,3)/
     x 3.4286874d-05, 5.9247080d-06,-1.3332708d-08 /
      data fpppp(24, 4,15,1),fpppp(24, 4,15,2),fpppp(24, 4,15,3)/
     x 3.0366309d-05, 5.8837381d-06,-1.3977921d-08 /
      data fpppp(24, 4,16,1),fpppp(24, 4,16,2),fpppp(24, 4,16,3)/
     x 2.3900087d-05, 5.3377107d-06,-1.3710588d-08 /
      data fpppp(24, 4,17,1),fpppp(24, 4,17,2),fpppp(24, 4,17,3)/
     x 1.3862929d-05, 3.2090343d-06,-7.8819826d-09 /
      data fpppp(24, 4,18,1),fpppp(24, 4,18,2),fpppp(24, 4,18,3)/
     x 2.3193395d-06,-1.2086557d-06, 4.7057811d-09 /
      data fpppp(24, 4,19,1),fpppp(24, 4,19,2),fpppp(24, 4,19,3)/
     x-1.3445576d-05,-5.3520756d-06, 2.1782155d-08 /
      data fpppp(24, 4,20,1),fpppp(24, 4,20,2),fpppp(24, 4,20,3)/
     x-4.1955847d-05,-1.5025403d-05, 2.6037367d-08 /
      data fpppp(24, 4,21,1),fpppp(24, 4,21,2),fpppp(24, 4,21,3)/
     x-4.1955847d-05,-1.5007802d-05, 2.6753694d-08 /
      data fpppp(24, 4,22,1),fpppp(24, 4,22,2),fpppp(24, 4,22,3)/
     x-1.3445576d-05,-5.4224806d-06, 1.8916850d-08 /
      data fpppp(24, 4,23,1),fpppp(24, 4,23,2),fpppp(24, 4,23,3)/
     x 2.3193395d-06,-9.4463706d-07, 1.5450676d-08 /
      data fpppp(24, 5, 1,1),fpppp(24, 5, 1,2),fpppp(24, 5, 1,3)/
     x 1.3813758d-05,-2.0902556d-06,-6.8133350d-09 /
      data fpppp(24, 5, 2,1),fpppp(24, 5, 2,2),fpppp(24, 5, 2,3)/
     x 1.4828377d-05,-4.3996087d-06,-2.3092515d-09 /
      data fpppp(24, 5, 3,1),fpppp(24, 5, 3,2),fpppp(24, 5, 3,3)/
     x 2.0427700d-05,-9.3842514d-06, 7.2120122d-09 /
      data fpppp(24, 5, 4,1),fpppp(24, 5, 4,2),fpppp(24, 5, 4,3)/
     x 2.0427700d-05,-9.3212011d-06, 7.4401137d-09 /
      data fpppp(24, 5, 5,1),fpppp(24, 5, 5,2),fpppp(24, 5, 5,3)/
     x 1.4828377d-05,-4.6518101d-06,-3.2216573d-09 /
      data fpppp(24, 5, 6,1),fpppp(24, 5, 6,2),fpppp(24, 5, 6,3)/
     x 1.3813758d-05,-1.1445003d-06,-3.3918135d-09 /
      data fpppp(24, 5, 7,1),fpppp(24, 5, 7,2),fpppp(24, 5, 7,3)/
     x 1.3539186d-05, 1.6827291d-06,-1.9806889d-09 /
      data fpppp(24, 5, 8,1),fpppp(24, 5, 8,2),fpppp(24, 5, 8,3)/
     x 1.2195652d-05, 2.9844783d-06,-1.6446029d-09 /
      data fpppp(24, 5, 9,1),fpppp(24, 5, 9,2),fpppp(24, 5, 9,3)/
     x 1.1591156d-05, 3.5308639d-06,-2.1088931d-09 /
      data fpppp(24, 5,10,1),fpppp(24, 5,10,2),fpppp(24, 5,10,3)/
     x 1.2010474d-05, 4.0485528d-06,-7.1308878d-10 /
      data fpppp(24, 5,11,1),fpppp(24, 5,11,2),fpppp(24, 5,11,3)/
     x 1.2449860d-05, 4.4550212d-06, 1.5164706d-09 /
      data fpppp(24, 5,12,1),fpppp(24, 5,12,2),fpppp(24, 5,12,3)/
     x 1.2629718d-05, 4.5268649d-06, 2.3744282d-09 /
      data fpppp(24, 5,13,1),fpppp(24, 5,13,2),fpppp(24, 5,13,3)/
     x 1.2605909d-05, 4.6587562d-06, 1.2298045d-09 /
      data fpppp(24, 5,14,1),fpppp(24, 5,14,2),fpppp(24, 5,14,3)/
     x 1.2351829d-05, 4.4919647d-06,-9.5884657d-10 /
      data fpppp(24, 5,15,1),fpppp(24, 5,15,2),fpppp(24, 5,15,3)/
     x 1.2151942d-05, 4.2304457d-06,-2.8731186d-09 /
      data fpppp(24, 5,16,1),fpppp(24, 5,16,2),fpppp(24, 5,16,3)/
     x 1.2773588d-05, 3.7526575d-06,-2.7620307d-09 /
      data fpppp(24, 5,17,1),fpppp(24, 5,17,2),fpppp(24, 5,17,3)/
     x 1.4005416d-05, 2.4941644d-06,-3.0172730d-09 /
      data fpppp(24, 5,18,1),fpppp(24, 5,18,2),fpppp(24, 5,18,3)/
     x 1.4239934d-05,-6.0016482d-07,-3.4828968d-09 /
      data fpppp(24, 5,19,1),fpppp(24, 5,19,2),fpppp(24, 5,19,3)/
     x 1.4692825d-05,-4.8119830d-06,-3.0695942d-09 /
      data fpppp(24, 5,20,1),fpppp(24, 5,20,2),fpppp(24, 5,20,3)/
     x 2.0084071d-05,-1.0413293d-05, 8.7335191d-09 /
      data fpppp(24, 5,21,1),fpppp(24, 5,21,2),fpppp(24, 5,21,3)/
     x 2.0084071d-05,-1.0489141d-05, 8.4916766d-09 /
      data fpppp(24, 5,22,1),fpppp(24, 5,22,2),fpppp(24, 5,22,3)/
     x 1.4692825d-05,-4.5085893d-06,-2.1022239d-09 /
      data fpppp(24, 5,23,1),fpppp(24, 5,23,2),fpppp(24, 5,23,3)/
     x 1.4239934d-05,-1.7378913d-06,-7.1105355d-09 /
      data fpppp(24, 6, 1,1),fpppp(24, 6, 1,2),fpppp(24, 6, 1,3)/
     x 9.4240428d-06,-1.7795076d-06,-1.3518110d-09 /
      data fpppp(24, 6, 2,1),fpppp(24, 6, 2,2),fpppp(24, 6, 2,3)/
     x 1.4038986d-05,-2.6217401d-06,-3.5812377d-09 /
      data fpppp(24, 6, 3,1),fpppp(24, 6, 3,2),fpppp(24, 6, 3,3)/
     x 1.6651235d-05,-4.4517939d-06,-8.3296807d-09 /
      data fpppp(24, 6, 4,1),fpppp(24, 6, 4,2),fpppp(24, 6, 4,3)/
     x 1.6651235d-05,-4.4075718d-06,-8.3802556d-09 /
      data fpppp(24, 6, 5,1),fpppp(24, 6, 5,2),fpppp(24, 6, 5,3)/
     x 1.4038986d-05,-2.7986284d-06,-3.3789380d-09 /
      data fpppp(24, 6, 6,1),fpppp(24, 6, 6,2),fpppp(24, 6, 6,3)/
     x 9.4240428d-06,-1.1161764d-06,-2.1104352d-09 /
      data fpppp(24, 6, 7,1),fpppp(24, 6, 7,2),fpppp(24, 6, 7,3)/
     x 5.2251147d-06, 1.6678189d-07,-2.7132814d-10 /
      data fpppp(24, 6, 8,1),fpppp(24, 6, 8,2),fpppp(24, 6, 8,3)/
     x 2.8302993d-06, 1.3071931d-06, 2.7281220d-09 /
      data fpppp(24, 6, 9,1),fpppp(24, 6, 9,2),fpppp(24, 6, 9,3)/
     x 1.1554933d-06, 2.0458541d-06, 5.0872287d-09 /
      data fpppp(24, 6,10,1),fpppp(24, 6,10,2),fpppp(24, 6,10,3)/
     x-6.6633688d-07, 2.3071707d-06, 5.2778247d-09 /
      data fpppp(24, 6,11,1),fpppp(24, 6,11,2),fpppp(24, 6,11,3)/
     x-2.1321369d-06, 2.4754247d-06, 4.0114673d-09 /
      data fpppp(24, 6,12,1),fpppp(24, 6,12,2),fpppp(24, 6,12,3)/
     x-2.5719016d-06, 2.5548473d-06, 3.4866746d-09 /
      data fpppp(24, 6,13,1),fpppp(24, 6,13,2),fpppp(24, 6,13,3)/
     x-1.7855226d-06, 2.7884732d-06, 4.1143748d-09 /
      data fpppp(24, 6,14,1),fpppp(24, 6,14,2),fpppp(24, 6,14,3)/
     x-1.8094506d-07, 2.8630936d-06, 4.8389459d-09 /
      data fpppp(24, 6,15,1),fpppp(24, 6,15,2),fpppp(24, 6,15,3)/
     x 1.7464319d-06, 2.7669907d-06, 4.7464350d-09 /
      data fpppp(24, 6,16,1),fpppp(24, 6,16,2),fpppp(24, 6,16,3)/
     x 3.4899260d-06, 2.1609746d-06, 2.2636986d-09 /
      data fpppp(24, 6,17,1),fpppp(24, 6,17,2),fpppp(24, 6,17,3)/
     x 5.7535888d-06, 1.0059394d-06,-7.4491760d-10 /
      data fpppp(24, 6,18,1),fpppp(24, 6,18,2),fpppp(24, 6,18,3)/
     x 9.6195074d-06,-7.8504239d-07,-2.8552131d-09 /
      data fpppp(24, 6,19,1),fpppp(24, 6,19,2),fpppp(24, 6,19,3)/
     x 1.4220549d-05,-2.9377698d-06,-3.4837089d-09 /
      data fpppp(24, 6,20,1),fpppp(24, 6,20,2),fpppp(24, 6,20,3)/
     x 1.6715522d-05,-5.4423061d-06,-7.4507021d-09 /
      data fpppp(24, 6,21,1),fpppp(24, 6,21,2),fpppp(24, 6,21,3)/
     x 1.6715522d-05,-5.4890123d-06,-7.3926593d-09 /
      data fpppp(24, 6,22,1),fpppp(24, 6,22,2),fpppp(24, 6,22,3)/
     x 1.4220549d-05,-2.7509450d-06,-3.7158800d-09 /
      data fpppp(24, 6,23,1),fpppp(24, 6,23,2),fpppp(24, 6,23,3)/
     x 9.6195074d-06,-1.4856353d-06,-1.9845716d-09 /
      data fpppp(24, 7, 1,1),fpppp(24, 7, 1,2),fpppp(24, 7, 1,3)/
     x 5.3256335d-06,-1.0526613d-06,-2.2621441d-09 /
      data fpppp(24, 7, 2,1),fpppp(24, 7, 2,2),fpppp(24, 7, 2,3)/
     x 7.8779402d-06,-1.2774350d-06,-4.1703511d-09 /
      data fpppp(24, 7, 3,1),fpppp(24, 7, 3,2),fpppp(24, 7, 3,3)/
     x 1.0286336d-05,-1.7711625d-06,-8.3123520d-09 /
      data fpppp(24, 7, 4,1),fpppp(24, 7, 4,2),fpppp(24, 7, 4,3)/
     x 1.0286336d-05,-1.7500405d-06,-8.2196268d-09 /
      data fpppp(24, 7, 5,1),fpppp(24, 7, 5,2),fpppp(24, 7, 5,3)/
     x 7.8779402d-06,-1.3619230d-06,-4.5412518d-09 /
      data fpppp(24, 7, 6,1),fpppp(24, 7, 6,2),fpppp(24, 7, 6,3)/
     x 5.3256335d-06,-7.3583102d-07,-8.7126655d-10 /
      data fpppp(24, 7, 7,1),fpppp(24, 7, 7,2),fpppp(24, 7, 7,3)/
     x 2.5964102d-06,-1.1358534d-07, 2.0839460d-09 /
      data fpppp(24, 7, 8,1),fpppp(24, 7, 8,2),fpppp(24, 7, 8,3)/
     x-3.0234531d-07, 3.1352305d-07, 3.4051578d-09 /
      data fpppp(24, 7, 9,1),fpppp(24, 7, 9,2),fpppp(24, 7, 9,3)/
     x-2.7348232d-06, 6.7615685d-07, 4.0498623d-09 /
      data fpppp(24, 7,10,1),fpppp(24, 7,10,2),fpppp(24, 7,10,3)/
     x-4.0842822d-06, 9.3965968d-07, 3.7692113d-09 /
      data fpppp(24, 7,11,1),fpppp(24, 7,11,2),fpppp(24, 7,11,3)/
     x-4.5221234d-06, 1.2408371d-06, 3.5180908d-09 /
      data fpppp(24, 7,12,1),fpppp(24, 7,12,2),fpppp(24, 7,12,3)/
     x-4.5665539d-06, 1.4669478d-06, 2.9897297d-09 /
      data fpppp(24, 7,13,1),fpppp(24, 7,13,2),fpppp(24, 7,13,3)/
     x-4.4483943d-06, 1.5002065d-06, 3.1488400d-09 /
      data fpppp(24, 7,14,1),fpppp(24, 7,14,2),fpppp(24, 7,14,3)/
     x-3.8080072d-06, 1.5867900d-06, 3.8676324d-09 /
      data fpppp(24, 7,15,1),fpppp(24, 7,15,2),fpppp(24, 7,15,3)/
     x-2.4713438d-06, 1.3529166d-06, 3.5929577d-09 /
      data fpppp(24, 7,16,1),fpppp(24, 7,16,2),fpppp(24, 7,16,3)/
     x-1.4006157d-07, 1.0998203d-06, 3.1403500d-09 /
      data fpppp(24, 7,17,1),fpppp(24, 7,17,2),fpppp(24, 7,17,3)/
     x 2.6985787d-06, 5.4443556d-07, 1.4789090d-09 /
      data fpppp(24, 7,18,1),fpppp(24, 7,18,2),fpppp(24, 7,18,3)/
     x 5.3387783d-06,-3.9406169d-07,-1.2972268d-09 /
      data fpppp(24, 7,19,1),fpppp(24, 7,19,2),fpppp(24, 7,19,3)/
     x 7.6334769d-06,-1.5803442d-06,-4.7536307d-09 /
      data fpppp(24, 7,20,1),fpppp(24, 7,20,2),fpppp(24, 7,20,3)/
     x 9.7993503d-06,-2.5947780d-06,-7.4574919d-09 /
      data fpppp(24, 7,21,1),fpppp(24, 7,21,2),fpppp(24, 7,21,3)/
     x 9.7993503d-06,-2.6286173d-06,-7.5616661d-09 /
      data fpppp(24, 7,22,1),fpppp(24, 7,22,2),fpppp(24, 7,22,3)/
     x 7.6334769d-06,-1.4449872d-06,-4.3369341d-09 /
      data fpppp(24, 7,23,1),fpppp(24, 7,23,2),fpppp(24, 7,23,3)/
     x 5.3387783d-06,-9.0165032d-07,-2.8598390d-09 /
      data fpppp(24, 8, 1,1),fpppp(24, 8, 1,2),fpppp(24, 8, 1,3)/
     x 2.0446045d-06,-2.1137665d-07, 7.6408328d-12 /
      data fpppp(24, 8, 2,1),fpppp(24, 8, 2,2),fpppp(24, 8, 2,3)/
     x 4.0674569d-06,-3.7727441d-07,-1.7318648d-09 /
      data fpppp(24, 8, 3,1),fpppp(24, 8, 3,2),fpppp(24, 8, 3,3)/
     x 5.3707135d-06,-7.2632351d-07,-5.4901371d-09 /
      data fpppp(24, 8, 4,1),fpppp(24, 8, 4,2),fpppp(24, 8, 4,3)/
     x 5.3707135d-06,-7.3760420d-07,-5.4363066d-09 /
      data fpppp(24, 8, 5,1),fpppp(24, 8, 5,2),fpppp(24, 8, 5,3)/
     x 4.0674569d-06,-3.3215165d-07,-1.9471868d-09 /
      data fpppp(24, 8, 6,1),fpppp(24, 8, 6,2),fpppp(24, 8, 6,3)/
     x 2.0446045d-06,-3.8058701d-07, 8.1509855d-10 /
      data fpppp(24, 8, 7,1),fpppp(24, 8, 7,2),fpppp(24, 8, 7,3)/
     x 3.6756527d-08,-1.6326026d-07, 1.7882876d-09 /
      data fpppp(24, 8, 8,1),fpppp(24, 8, 8,2),fpppp(24, 8, 8,3)/
     x-1.6601763d-06,-1.4091582d-07, 1.5806762d-09 /
      data fpppp(24, 8, 9,1),fpppp(24, 8, 9,2),fpppp(24, 8, 9,3)/
     x-2.7594199d-06, 1.0165191d-07, 1.5428607d-09 /
      data fpppp(24, 8,10,1),fpppp(24, 8,10,2),fpppp(24, 8,10,3)/
     x-3.5679550d-06, 3.2790809d-07, 1.7977458d-09 /
      data fpppp(24, 8,11,1),fpppp(24, 8,11,2),fpppp(24, 8,11,3)/
     x-4.0786921d-06, 4.8831852d-07, 1.8769674d-09 /
      data fpppp(24, 8,12,1),fpppp(24, 8,12,2),fpppp(24, 8,12,3)/
     x-4.2061866d-06, 6.7793326d-07, 2.0787988d-09 /
      data fpppp(24, 8,13,1),fpppp(24, 8,13,2),fpppp(24, 8,13,3)/
     x-3.9343270d-06, 8.1018896d-07, 1.9518978d-09 /
      data fpppp(24, 8,14,1),fpppp(24, 8,14,2),fpppp(24, 8,14,3)/
     x-3.3759367d-06, 8.1224378d-07, 1.6396020d-09 /
      data fpppp(24, 8,15,1),fpppp(24, 8,15,2),fpppp(24, 8,15,3)/
     x-2.5329392d-06, 7.2607597d-07, 1.5037922d-09 /
      data fpppp(24, 8,16,1),fpppp(24, 8,16,2),fpppp(24, 8,16,3)/
     x-1.3485689d-06, 5.2394011d-07, 1.3375913d-09 /
      data fpppp(24, 8,17,1),fpppp(24, 8,17,2),fpppp(24, 8,17,3)/
     x 2.1582915d-07, 2.8423042d-07, 9.9646375d-10 /
      data fpppp(24, 8,18,1),fpppp(24, 8,18,2),fpppp(24, 8,18,3)/
     x 2.1182835d-06,-1.4700058d-07,-2.7297769d-11 /
      data fpppp(24, 8,19,1),fpppp(24, 8,19,2),fpppp(24, 8,19,3)/
     x 3.8513281d-06,-6.6482895d-07,-2.1432773d-09 /
      data fpppp(24, 8,20,1),fpppp(24, 8,20,2),fpppp(24, 8,20,3)/
     x 4.8301372d-06,-1.2112949d-06,-4.4018757d-09 /
      data fpppp(24, 8,21,1),fpppp(24, 8,21,2),fpppp(24, 8,21,3)/
     x 4.8301372d-06,-1.2237701d-06,-4.4522855d-09 /
      data fpppp(24, 8,22,1),fpppp(24, 8,22,2),fpppp(24, 8,22,3)/
     x 3.8513281d-06,-6.1492814d-07,-1.9416380d-09 /
      data fpppp(24, 8,23,1),fpppp(24, 8,23,2),fpppp(24, 8,23,3)/
     x 2.1182835d-06,-3.3412863d-07,-7.8344516d-10 /
      data fpppp(24, 9, 1,1),fpppp(24, 9, 1,2),fpppp(24, 9, 1,3)/
     x 1.2742865d-07, 3.4842844d-07, 1.5306015d-09 /
      data fpppp(24, 9, 2,1),fpppp(24, 9, 2,2),fpppp(24, 9, 2,3)/
     x 1.1605669d-06, 2.0026812d-08, 1.9768669d-11 /
      data fpppp(24, 9, 3,1),fpppp(24, 9, 3,2),fpppp(24, 9, 3,3)/
     x 1.9302236d-06,-6.7434322d-07,-3.1939543d-09 /
      data fpppp(24, 9, 4,1),fpppp(24, 9, 4,2),fpppp(24, 9, 4,3)/
     x 1.9302236d-06,-6.9070176d-07,-3.2355623d-09 /
      data fpppp(24, 9, 5,1),fpppp(24, 9, 5,2),fpppp(24, 9, 5,3)/
     x 1.1605669d-06, 8.5460989d-08, 1.8620078d-10 /
      data fpppp(24, 9, 6,1),fpppp(24, 9, 6,2),fpppp(24, 9, 6,3)/
     x 1.2742865d-07, 1.0305028d-07, 9.0648109d-10 /
      data fpppp(24, 9, 7,1),fpppp(24, 9, 7,2),fpppp(24, 9, 7,3)/
     x-7.0395136d-07,-2.9490199d-08, 8.8426693d-10 /
      data fpppp(24, 9, 8,1),fpppp(24, 9, 8,2),fpppp(24, 9, 8,3)/
     x-1.2083657d-06,-5.6433925d-08, 8.5107550d-10 /
      data fpppp(24, 9, 9,1),fpppp(24, 9, 9,2),fpppp(24, 9, 9,3)/
     x-1.8610250d-06,-1.0319126d-07, 3.4157963d-10 /
      data fpppp(24, 9,10,1),fpppp(24, 9,10,2),fpppp(24, 9,10,3)/
     x-2.3653402d-06, 9.2785509d-08, 6.4932802d-10 /
      data fpppp(24, 9,11,1),fpppp(24, 9,11,2),fpppp(24, 9,11,3)/
     x-2.7274277d-06, 1.0465971d-07, 7.3306403d-10 /
      data fpppp(24, 9,12,1),fpppp(24, 9,12,2),fpppp(24, 9,12,3)/
     x-2.8186845d-06, 2.3406258d-07, 9.6945494d-10 /
      data fpppp(24, 9,13,1),fpppp(24, 9,13,2),fpppp(24, 9,13,3)/
     x-2.6348043d-06, 4.0588000d-07, 9.0702444d-10 /
      data fpppp(24, 9,14,1),fpppp(24, 9,14,2),fpppp(24, 9,14,3)/
     x-2.2673799d-06, 4.0161389d-07, 4.0575683d-10 /
      data fpppp(24, 9,15,1),fpppp(24, 9,15,2),fpppp(24, 9,15,3)/
     x-1.5931918d-06, 4.9932986d-07, 7.2122968d-10 /
      data fpppp(24, 9,16,1),fpppp(24, 9,16,2),fpppp(24, 9,16,3)/
     x-9.3818278d-07, 3.2469652d-07, 5.6006281d-10 /
      data fpppp(24, 9,17,1),fpppp(24, 9,17,2),fpppp(24, 9,17,3)/
     x-1.9589282d-07, 2.3213416d-07, 5.6276706d-10 /
      data fpppp(24, 9,18,1),fpppp(24, 9,18,2),fpppp(24, 9,18,3)/
     x 4.4539010d-07,-5.6234263d-08,-4.3448443d-10 /
      data fpppp(24, 9,19,1),fpppp(24, 9,19,2),fpppp(24, 9,19,3)/
     x 1.1037250d-06,-3.3833123d-07,-1.1771816d-09 /
      data fpppp(24, 9,20,1),fpppp(24, 9,20,2),fpppp(24, 9,20,3)/
     x 1.6454752d-06,-5.7779832d-07,-1.4784162d-09 /
      data fpppp(24, 9,21,1),fpppp(24, 9,21,2),fpppp(24, 9,21,3)/
     x 1.6454752d-06,-5.8588435d-07,-1.5069979d-09 /
      data fpppp(24, 9,22,1),fpppp(24, 9,22,2),fpppp(24, 9,22,3)/
     x 1.1037250d-06,-3.0598712d-07,-1.0628548d-09 /
      data fpppp(24, 9,23,1),fpppp(24, 9,23,2),fpppp(24, 9,23,3)/
     x 4.4539010d-07,-1.7752468d-07,-8.6320982d-10 /
      data fpppp(24,10, 1,1),fpppp(24,10, 1,2),fpppp(24,10, 1,3)/
     x-3.6333228d-07, 9.9726204d-07, 1.2260536d-09 /
      data fpppp(24,10, 2,1),fpppp(24,10, 2,2),fpppp(24,10, 2,3)/
     x 5.5558035d-07, 2.5469996d-07, 2.0058898d-10 /
      data fpppp(24,10, 3,1),fpppp(24,10, 3,2),fpppp(24,10, 3,3)/
     x 1.9786071d-06,-1.3302872d-06,-2.0013419d-09 /
      data fpppp(24,10, 4,1),fpppp(24,10, 4,2),fpppp(24,10, 4,3)/
     x 1.9786071d-06,-1.3411675d-06,-1.9934554d-09 /
      data fpppp(24,10, 5,1),fpppp(24,10, 5,2),fpppp(24,10, 5,3)/
     x 5.5558035d-07, 2.9822110d-07, 1.6904304d-10 /
      data fpppp(24,10, 6,1),fpppp(24,10, 6,2),fpppp(24,10, 6,3)/
     x-3.6333228d-07, 8.3405773d-07, 1.3443509d-09 /
      data fpppp(24,10, 7,1),fpppp(24,10, 7,2),fpppp(24,10, 7,3)/
     x-8.9945896d-07, 5.2447511d-07, 1.0064900d-09 /
      data fpppp(24,10, 8,1),fpppp(24,10, 8,2),fpppp(24,10, 8,3)/
     x-1.2192770d-06,-6.5016884d-08,-9.7733277d-11 /
      data fpppp(24,10, 9,1),fpppp(24,10, 9,2),fpppp(24,10, 9,3)/
     x-1.2668163d-06,-7.8981715d-08, 9.9959570d-12 /
      data fpppp(24,10,10,1),fpppp(24,10,10,2),fpppp(24,10,10,3)/
     x-1.3173376d-06,-8.4380497d-08,-7.9003541d-11 /
      data fpppp(24,10,11,1),fpppp(24,10,11,2),fpppp(24,10,11,3)/
     x-1.4683177d-06, 2.6372144d-08, 5.6738385d-10 /
      data fpppp(24,10,12,1),fpppp(24,10,12,2),fpppp(24,10,12,3)/
     x-1.5170648d-06, 7.9548472d-08, 6.2089766d-10 /
      data fpppp(24,10,13,1),fpppp(24,10,13,2),fpppp(24,10,13,3)/
     x-1.4666816d-06, 1.3780613d-07, 1.7333207d-10 /
      data fpppp(24,10,14,1),fpppp(24,10,14,2),fpppp(24,10,14,3)/
     x-1.2687635d-06, 3.2492907d-07, 2.6654381d-10 /
      data fpppp(24,10,15,1),fpppp(24,10,15,2),fpppp(24,10,15,3)/
     x-1.1216478d-06, 2.6142818d-07,-1.3873088d-10 /
      data fpppp(24,10,16,1),fpppp(24,10,16,2),fpppp(24,10,16,3)/
     x-7.6479794d-07, 3.1052096d-07, 3.7306415d-10 /
      data fpppp(24,10,17,1),fpppp(24,10,17,2),fpppp(24,10,17,3)/
     x-4.4587598d-07, 1.4214489d-07, 9.8861002d-11 /
      data fpppp(24,10,18,1),fpppp(24,10,18,2),fpppp(24,10,18,3)/
     x-1.6662914d-08, 4.5355294d-08, 2.6875685d-10 /
      data fpppp(24,10,19,1),fpppp(24,10,19,2),fpppp(24,10,19,3)/
     x 2.8006341d-07,-2.5092209d-07,-2.2847467d-10 /
      data fpppp(24,10,20,1),fpppp(24,10,20,2),fpppp(24,10,20,3)/
     x 4.6725349d-07,-3.2888075d-07,-9.0606719d-10 /
      data fpppp(24,10,21,1),fpppp(24,10,21,2),fpppp(24,10,21,3)/
     x 4.6725349d-07,-3.4121762d-07,-9.1465999d-10 /
      data fpppp(24,10,22,1),fpppp(24,10,22,2),fpppp(24,10,22,3)/
     x 2.8006341d-07,-2.0157462d-07,-1.9410347d-10 /
      data fpppp(24,10,23,1),fpppp(24,10,23,2),fpppp(24,10,23,3)/
     x-1.6662914d-08,-1.3969772d-07, 1.3986483d-10 /
      data fpppp(24,11, 1,1),fpppp(24,11, 1,2),fpppp(24,11, 1,3)/
     x-6.5923589d-08, 2.3784491d-06,-7.1364971d-11 /
      data fpppp(24,11, 2,1),fpppp(24,11, 2,2),fpppp(24,11, 2,3)/
     x 2.6035708d-07, 7.3775818d-07,-2.5902682d-10 /
      data fpppp(24,11, 3,1),fpppp(24,11, 3,2),fpppp(24,11, 3,3)/
     x-2.1297691d-07,-2.7587645d-06,-6.5652046d-10 /
      data fpppp(24,11, 4,1),fpppp(24,11, 4,2),fpppp(24,11, 4,3)/
     x-2.1297691d-07,-2.7924406d-06,-6.6463854d-10 /
      data fpppp(24,11, 5,1),fpppp(24,11, 5,2),fpppp(24,11, 5,3)/
     x 2.6035708d-07, 8.7246241d-07,-2.2655452d-10 /
      data fpppp(24,11, 6,1),fpppp(24,11, 6,2),fpppp(24,11, 6,3)/
     x-6.5923589d-08, 1.8733082d-06,-1.9313610d-10 /
      data fpppp(24,11, 7,1),fpppp(24,11, 7,2),fpppp(24,11, 7,3)/
     x-3.6598457d-07, 1.2431089d-06, 3.3095991d-10 /
      data fpppp(24,11, 8,1),fpppp(24,11, 8,2),fpppp(24,11, 8,3)/
     x-6.2430348d-07, 1.9342552d-07, 5.6436162d-10 /
      data fpppp(24,11, 9,1),fpppp(24,11, 9,2),fpppp(24,11, 9,3)/
     x-6.4295277d-07,-1.0700248d-07,-7.6629853d-13 /
      data fpppp(24,11,10,1),fpppp(24,11,10,2),fpppp(24,11,10,3)/
     x-7.5858749d-07,-2.8022012d-07, 3.5899351d-10 /
      data fpppp(24,11,11,1),fpppp(24,11,11,2),fpppp(24,11,11,3)/
     x-6.3891489d-07, 5.0709289d-08, 3.2737395d-10 /
      data fpppp(24,11,12,1),fpppp(24,11,12,2),fpppp(24,11,12,3)/
     x-7.0530817d-07, 2.6905632d-08,-1.8524647d-10 /
      data fpppp(24,11,13,1),fpppp(24,11,13,2),fpppp(24,11,13,3)/
     x-7.4551313d-07, 5.7469632d-08, 3.5847741d-10 /
      data fpppp(24,11,14,1),fpppp(24,11,14,2),fpppp(24,11,14,3)/
     x-7.4852989d-07, 2.0629481d-07, 2.4948239d-11 /
      data fpppp(24,11,15,1),fpppp(24,11,15,2),fpppp(24,11,15,3)/
     x-6.2325076d-07, 2.3543739d-07, 1.6734251d-10 /
      data fpppp(24,11,16,1),fpppp(24,11,16,2),fpppp(24,11,16,3)/
     x-5.9874909d-07, 2.0963111d-07,-2.0379436d-10 /
      data fpppp(24,11,17,1),fpppp(24,11,17,2),fpppp(24,11,17,3)/
     x-5.2723959d-07, 1.6967914d-07, 3.1404003d-10 /
      data fpppp(24,11,18,1),fpppp(24,11,18,2),fpppp(24,11,18,3)/
     x-5.2741854d-07, 3.2033955d-08, 3.4192759d-10 /
      data fpppp(24,11,19,1),fpppp(24,11,19,2),fpppp(24,11,19,3)/
     x-4.2022116d-07,-2.2691157d-07, 4.8894691d-10 /
      data fpppp(24,11,20,1),fpppp(24,11,20,2),fpppp(24,11,20,3)/
     x-2.9681595d-07,-2.4997958d-07,-9.9125210d-10 /
      data fpppp(24,11,21,1),fpppp(24,11,21,2),fpppp(24,11,21,3)/
     x-2.9681595d-07,-2.6176030d-07,-9.5148411d-10 /
      data fpppp(24,11,22,1),fpppp(24,11,22,2),fpppp(24,11,22,3)/
     x-4.2022116d-07,-1.7978870d-07, 3.2987498d-10 /
      data fpppp(24,11,23,1),fpppp(24,11,23,2),fpppp(24,11,23,3)/
     x-5.2741854d-07,-1.4467682d-07, 9.3844735d-10 /
      data fpppp(24,12, 1,1),fpppp(24,12, 1,2),fpppp(24,12, 1,3)/
     x 8.7418846d-07, 3.0843758d-06,-4.3882859d-09 /
      data fpppp(24,12, 2,1),fpppp(24,12, 2,2),fpppp(24,12, 2,3)/
     x 2.4957659d-07, 8.0678552d-07,-2.0790973d-09 /
      data fpppp(24,12, 3,1),fpppp(24,12, 3,2),fpppp(24,12, 3,3)/
     x 1.0353968d-07,-4.0716275d-06, 2.8135784d-09 /
      data fpppp(24,12, 4,1),fpppp(24,12, 4,2),fpppp(24,12, 4,3)/
     x 1.0353968d-07,-4.0753682d-06, 2.9108533d-09 /
      data fpppp(24,12, 5,1),fpppp(24,12, 5,2),fpppp(24,12, 5,3)/
     x 2.4957659d-07, 8.2174811d-07,-2.4681971d-09 /
      data fpppp(24,12, 6,1),fpppp(24,12, 6,2),fpppp(24,12, 6,3)/
     x 8.7418846d-07, 3.0282661d-06,-2.9291618d-09 /
      data fpppp(24,12, 7,1),fpppp(24,12, 7,2),fpppp(24,12, 7,3)/
     x 8.0578885d-07, 1.9185219d-06,-1.2155363d-09 /
      data fpppp(24,12, 8,1),fpppp(24,12, 8,2),fpppp(24,12, 8,3)/
     x 5.8082830d-07, 7.3575969d-07, 4.1846880d-10 /
      data fpppp(24,12, 9,1),fpppp(24,12, 9,2),fpppp(24,12, 9,3)/
     x 8.0905370d-08,-2.7137467d-07, 1.1655480d-09 /
      data fpppp(24,12,10,1),fpppp(24,12,10,2),fpppp(24,12,10,3)/
     x-2.6988639d-08,-2.1344060d-07, 3.7493260d-10 /
      data fpppp(24,12,11,1),fpppp(24,12,11,2),fpppp(24,12,11,3)/
     x-2.5118121d-07,-1.1460681d-07,-2.5697082d-10 /
      data fpppp(24,12,12,1),fpppp(24,12,12,2),fpppp(24,12,12,3)/
     x-2.5982759d-07, 4.3772234d-08, 5.4854987d-10 /
      data fpppp(24,12,13,1),fpppp(24,12,13,2),fpppp(24,12,13,3)/
     x-3.3259099d-07, 2.8515297d-08,-2.6099716d-10 /
      data fpppp(24,12,14,1),fpppp(24,12,14,2),fpppp(24,12,14,3)/
     x-3.2267239d-07, 1.9159202d-07, 3.0022332d-10 /
      data fpppp(24,12,15,1),fpppp(24,12,15,2),fpppp(24,12,15,3)/
     x-3.7419420d-07, 1.4327941d-07, 1.3687593d-10 /
      data fpppp(24,12,16,1),fpppp(24,12,16,2),fpppp(24,12,16,3)/
     x-3.3407263d-07, 1.6774621d-07,-1.4507183d-11 /
      data fpppp(24,12,17,1),fpppp(24,12,17,2),fpppp(24,12,17,3)/
     x-3.3889236d-07, 1.3252287d-07,-1.9605430d-10 /
      data fpppp(24,12,18,1),fpppp(24,12,18,2),fpppp(24,12,18,3)/
     x-3.1243058d-07, 7.3288516d-08, 3.0428602d-10 /
      data fpppp(24,12,19,1),fpppp(24,12,19,2),fpppp(24,12,19,3)/
     x-4.2547136d-07,-1.9899808d-07, 1.5070722d-10 /
      data fpppp(24,12,20,1),fpppp(24,12,20,2),fpppp(24,12,20,3)/
     x-4.9976405d-07,-2.4722302d-07,-2.6175842d-10 /
      data fpppp(24,12,21,1),fpppp(24,12,21,2),fpppp(24,12,21,3)/
     x-4.9976405d-07,-2.5907974d-07,-2.5991165d-10 /
      data fpppp(24,12,22,1),fpppp(24,12,22,2),fpppp(24,12,22,3)/
     x-4.2547136d-07,-1.5157119d-07, 1.4332016d-10 /
      data fpppp(24,12,23,1),fpppp(24,12,23,2),fpppp(24,12,23,3)/
     x-3.1243058d-07,-1.0456233d-07, 3.3198748d-10 /
      data fpppp(24,13, 1,1),fpppp(24,13, 1,2),fpppp(24,13, 1,3)/
     x 8.5225806d-07, 3.5841166d-06,-5.5243218d-09 /
      data fpppp(24,13, 2,1),fpppp(24,13, 2,2),fpppp(24,13, 2,3)/
     x-7.9579526d-07, 8.7230872d-07,-2.0969229d-09 /
      data fpppp(24,13, 3,1),fpppp(24,13, 3,2),fpppp(24,13, 3,3)/
     x-3.3176310d-06,-4.9233854d-06, 5.2003934d-09 /
      data fpppp(24,13, 4,1),fpppp(24,13, 4,2),fpppp(24,13, 4,3)/
     x-3.3176310d-06,-4.9502004d-06, 5.2828355d-09 /
      data fpppp(24,13, 5,1),fpppp(24,13, 5,2),fpppp(24,13, 5,3)/
     x-7.9579526d-07, 9.7956852d-07,-2.4266913d-09 /
      data fpppp(24,13, 6,1),fpppp(24,13, 6,2),fpppp(24,13, 6,3)/
     x 8.5225806d-07, 3.1818924d-06,-4.2876904d-09 /
      data fpppp(24,13, 7,1),fpppp(24,13, 7,2),fpppp(24,13, 7,3)/
     x 1.4034141d-06, 2.5480029d-06,-3.1128853d-09 /
      data fpppp(24,13, 8,1),fpppp(24,13, 8,2),fpppp(24,13, 8,3)/
     x 1.0386289d-06, 9.6271059d-07,-4.6448032d-10 /
      data fpppp(24,13, 9,1),fpppp(24,13, 9,2),fpppp(24,13, 9,3)/
     x 6.7300151d-07, 1.0696077d-08, 5.6761912d-10 /
      data fpppp(24,13,10,1),fpppp(24,13,10,2),fpppp(24,13,10,3)/
     x 1.9216791d-07,-2.6112552d-07, 6.5134091d-10 /
      data fpppp(24,13,11,1),fpppp(24,13,11,2),fpppp(24,13,11,3)/
     x 1.3159557d-07,-7.8133712d-08, 5.5120536d-10 /
      data fpppp(24,13,12,1),fpppp(24,13,12,2),fpppp(24,13,12,3)/
     x-1.8654918d-08,-4.5612817d-08,-3.2180186d-10 /
      data fpppp(24,13,13,1),fpppp(24,13,13,2),fpppp(24,13,13,3)/
     x-6.3996374d-08, 9.7407612d-08, 5.6621059d-10 /
      data fpppp(24,13,14,1),fpppp(24,13,14,2),fpppp(24,13,14,3)/
     x-2.2302004d-07, 1.4598833d-07, 4.4420981d-10 /
      data fpppp(24,13,15,1),fpppp(24,13,15,2),fpppp(24,13,15,3)/
     x-2.2650543d-07, 1.1495095d-07,-7.5750959d-11 /
      data fpppp(24,13,16,1),fpppp(24,13,16,2),fpppp(24,13,16,3)/
     x-3.0259341d-07, 9.4637605d-08,-4.6093979d-12 /
      data fpppp(24,13,17,1),fpppp(24,13,17,2),fpppp(24,13,17,3)/
     x-2.8031622d-07, 1.2203977d-07,-1.8318813d-10 /
      data fpppp(24,13,18,1),fpppp(24,13,18,2),fpppp(24,13,18,3)/
     x-3.4862101d-07, 1.9296743d-09,-4.7917791d-10 /
      data fpppp(24,13,19,1),fpppp(24,13,19,2),fpppp(24,13,19,3)/
     x-3.3772891d-07,-1.1874115d-07,-7.7985534d-11 /
      data fpppp(24,13,20,1),fpppp(24,13,20,2),fpppp(24,13,20,3)/
     x-3.8263035d-07,-2.2582019d-07, 5.0323100d-10 /
      data fpppp(24,13,21,1),fpppp(24,13,21,2),fpppp(24,13,21,3)/
     x-3.8263035d-07,-2.2917623d-07, 5.0939989d-10 /
      data fpppp(24,13,22,1),fpppp(24,13,22,2),fpppp(24,13,22,3)/
     x-3.3772891d-07,-1.0531699d-07,-1.0266110d-10 /
      data fpppp(24,13,23,1),fpppp(24,13,23,2),fpppp(24,13,23,3)/
     x-3.4862101d-07,-4.8410949d-08,-3.8664453d-10 /
      data fpppp(24,14, 1,1),fpppp(24,14, 1,2),fpppp(24,14, 1,3)/
     x-6.0415953d-07, 2.3031836d-06,-1.4885960d-09 /
      data fpppp(24,14, 2,1),fpppp(24,14, 2,2),fpppp(24,14, 2,3)/
     x-2.2509849d-06, 2.3101980d-07, 2.5126980d-11 /
      data fpppp(24,14, 3,1),fpppp(24,14, 3,2),fpppp(24,14, 3,3)/
     x-3.9258570d-06,-4.2118225d-06, 3.2856651d-09 /
      data fpppp(24,14, 4,1),fpppp(24,14, 4,2),fpppp(24,14, 4,3)/
     x-3.9258570d-06,-4.2074628d-06, 3.2561848d-09 /
      data fpppp(24,14, 5,1),fpppp(24,14, 5,2),fpppp(24,14, 5,3)/
     x-2.2509849d-06, 2.1358102d-07, 1.4304824d-10 /
      data fpppp(24,14, 6,1),fpppp(24,14, 6,2),fpppp(24,14, 6,3)/
     x-6.0415953d-07, 2.3685791d-06,-1.9308008d-09 /
      data fpppp(24,14, 7,1),fpppp(24,14, 7,2),fpppp(24,14, 7,3)/
     x 4.5093170d-07, 2.2967152d-06,-2.5381113d-09 /
      data fpppp(24,14, 8,1),fpppp(24,14, 8,2),fpppp(24,14, 8,3)/
     x 8.7171349d-07, 1.2250409d-06,-1.7290680d-09 /
      data fpppp(24,14, 9,1),fpppp(24,14, 9,2),fpppp(24,14, 9,3)/
     x 7.2496687d-07, 1.8615803d-07,-4.7675358d-10 /
      data fpppp(24,14,10,1),fpppp(24,14,10,2),fpppp(24,14,10,3)/
     x 6.2649674d-07, 6.1725944d-08, 2.3114081d-10 /
      data fpppp(24,14,11,1),fpppp(24,14,11,2),fpppp(24,14,11,3)/
     x 2.4253439d-07,-1.3794307d-07, 2.4713030d-10 /
      data fpppp(24,14,12,1),fpppp(24,14,12,2),fpppp(24,14,12,3)/
     x 1.2124487d-07,-8.9798338d-10, 6.2729693d-10 /
      data fpppp(24,14,13,1),fpppp(24,14,13,2),fpppp(24,14,13,3)/
     x 5.5296816d-08, 1.3704340d-07, 2.0661650d-10 /
      data fpppp(24,14,14,1),fpppp(24,14,14,2),fpppp(24,14,14,3)/
     x 3.3283742d-07, 5.4752685d-08,-7.5487114d-12 /
      data fpppp(24,14,15,1),fpppp(24,14,15,2),fpppp(24,14,15,3)/
     x-7.1697934d-08, 1.7704355d-07, 1.1761077d-10 /
      data fpppp(24,14,16,1),fpppp(24,14,16,2),fpppp(24,14,16,3)/
     x 2.6563162d-08, 9.5061630d-09, 6.7749943d-10 /
      data fpppp(24,14,17,1),fpppp(24,14,17,2),fpppp(24,14,17,3)/
     x-2.1004048d-07, 8.2881575d-08,-5.2089467d-10 /
      data fpppp(24,14,18,1),fpppp(24,14,18,2),fpppp(24,14,18,3)/
     x-1.9024377d-07,-1.7351989d-08,-7.3323113d-11 /
      data fpppp(24,14,19,1),fpppp(24,14,19,2),fpppp(24,14,19,3)/
     x-2.2949648d-07,-9.9882271d-08,-2.8606863d-10 /
      data fpppp(24,14,20,1),fpppp(24,14,20,2),fpppp(24,14,20,3)/
     x-2.3572739d-07,-1.6230658d-07, 2.8379736d-10 /
      data fpppp(24,14,21,1),fpppp(24,14,21,2),fpppp(24,14,21,3)/
     x-2.3572739d-07,-1.6484134d-07, 2.6107507d-10 /
      data fpppp(24,14,22,1),fpppp(24,14,22,2),fpppp(24,14,22,3)/
     x-2.2949648d-07,-8.9743233d-08,-1.9517946d-10 /
      data fpppp(24,14,23,1),fpppp(24,14,23,2),fpppp(24,14,23,3)/
     x-1.9024377d-07,-5.5373384d-08,-4.1415751d-10 /
      data fpppp(24,15, 1,1),fpppp(24,15, 1,2),fpppp(24,15, 1,3)/
     x-1.6122621d-06, 3.0298351d-07, 3.0440905d-09 /
      data fpppp(24,15, 2,1),fpppp(24,15, 2,2),fpppp(24,15, 2,3)/
     x-1.3558761d-06,-5.6388199d-07, 1.7956458d-09 /
      data fpppp(24,15, 3,1),fpppp(24,15, 3,2),fpppp(24,15, 3,3)/
     x-3.9968705d-07,-2.4527072d-06,-8.2536158d-10 /
      data fpppp(24,15, 4,1),fpppp(24,15, 4,2),fpppp(24,15, 4,3)/
     x-3.9968705d-07,-2.3980087d-06,-9.2026612d-10 /
      data fpppp(24,15, 5,1),fpppp(24,15, 5,2),fpppp(24,15, 5,3)/
     x-1.3558761d-06,-7.8267576d-07, 2.1752640d-09 /
      data fpppp(24,15, 6,1),fpppp(24,15, 6,2),fpppp(24,15, 6,3)/
     x-1.6122621d-06, 1.1234601d-06, 1.6205224d-09 /
      data fpppp(24,15, 7,1),fpppp(24,15, 7,2),fpppp(24,15, 7,3)/
     x-9.8363378d-07, 1.4240999d-06, 1.4604922d-10 /
      data fpppp(24,15, 8,1),fpppp(24,15, 8,2),fpppp(24,15, 8,3)/
     x-3.1134032d-07, 9.9497374d-07,-1.3917512d-09 /
      data fpppp(24,15, 9,1),fpppp(24,15, 9,2),fpppp(24,15, 9,3)/
     x 1.4856846d-07, 4.6919685d-07,-1.2113090d-09 /
      data fpppp(24,15,10,1),fpppp(24,15,10,2),fpppp(24,15,10,3)/
     x 1.9964694d-07, 1.1573687d-07,-6.0058393d-10 /
      data fpppp(24,15,11,1),fpppp(24,15,11,2),fpppp(24,15,11,3)/
     x 2.9804416d-07, 9.5643994d-08,-1.0303344d-11 /
      data fpppp(24,15,12,1),fpppp(24,15,12,2),fpppp(24,15,12,3)/
     x 2.5258415d-07,-4.3772379d-08, 7.9601125d-11 /
      data fpppp(24,15,13,1),fpppp(24,15,13,2),fpppp(24,15,13,3)/
     x 1.5272184d-07, 5.0551228d-07, 2.4995230d-10 /
      data fpppp(24,15,14,1),fpppp(24,15,14,2),fpppp(24,15,14,3)/
     x-4.7964995d-07,-5.3646317d-07,-2.5151747d-10 /
      data fpppp(24,15,15,1),fpppp(24,15,15,2),fpppp(24,15,15,3)/
     x 5.1038573d-08, 5.0051861d-07, 2.3526890d-09 /
      data fpppp(24,15,16,1),fpppp(24,15,16,2),fpppp(24,15,16,3)/
     x-7.9165980d-07,-5.5978569d-08,-3.4174103d-09 /
      data fpppp(24,15,17,1),fpppp(24,15,17,2),fpppp(24,15,17,3)/
     x-2.8347143d-08, 6.8671303d-08, 2.7274735d-09 /
      data fpppp(24,15,18,1),fpppp(24,15,18,2),fpppp(24,15,18,3)/
     x-9.5777293d-08,-5.1795400d-08,-7.1833462d-10 /
      data fpppp(24,15,19,1),fpppp(24,15,19,2),fpppp(24,15,19,3)/
     x-3.1644413d-08,-7.0762108d-08,-1.1522676d-10 /
      data fpppp(24,15,20,1),fpppp(24,15,20,2),fpppp(24,15,20,3)/
     x-1.3123438d-08,-9.3994576d-08,-1.9766821d-10 /
      data fpppp(24,15,21,1),fpppp(24,15,21,2),fpppp(24,15,21,3)/
     x-1.3123438d-08,-9.4380251d-08,-1.6721344d-10 /
      data fpppp(24,15,22,1),fpppp(24,15,22,2),fpppp(24,15,22,3)/
     x-3.1644413d-08,-6.9219407d-08,-2.3704585d-10 /
      data fpppp(24,15,23,1),fpppp(24,15,23,2),fpppp(24,15,23,3)/
     x-9.5777293d-08,-5.7580527d-08,-2.6151304d-10 /
      data fpppp(24,16, 1,1),fpppp(24,16, 1,2),fpppp(24,16, 1,3)/
     x-1.4732130d-06,-4.9503707d-07, 2.7216325d-09 /
      data fpppp(24,16, 2,1),fpppp(24,16, 2,2),fpppp(24,16, 2,3)/
     x-1.3877635d-06,-6.8648517d-07, 1.1034929d-09 /
      data fpppp(24,16, 3,1),fpppp(24,16, 3,2),fpppp(24,16, 3,3)/
     x-6.1970139d-07,-1.1311880d-06,-2.3584298d-09 /
      data fpppp(24,16, 4,1),fpppp(24,16, 4,2),fpppp(24,16, 4,3)/
     x-6.1970139d-07,-1.0708884d-06,-2.3680886d-09 /
      data fpppp(24,16, 5,1),fpppp(24,16, 5,2),fpppp(24,16, 5,3)/
     x-1.3877635d-06,-9.2768339d-07, 1.1421280d-09 /
      data fpppp(24,16, 6,1),fpppp(24,16, 6,2),fpppp(24,16, 6,3)/
     x-1.4732130d-06, 4.0945627d-07, 2.5767507d-09 /
      data fpppp(24,16, 7,1),fpppp(24,16, 7,2),fpppp(24,16, 7,3)/
     x-1.5870932d-06, 4.9566782d-07, 1.6155242d-09 /
      data fpppp(24,16, 8,1),fpppp(24,16, 8,2),fpppp(24,16, 8,3)/
     x-1.1491333d-06, 5.4924967d-07, 4.4159412d-10 /
      data fpppp(24,16, 9,1),fpppp(24,16, 9,2),fpppp(24,16, 9,3)/
     x-5.8624747d-07, 3.7853878d-07,-7.6170610d-10 /
      data fpppp(24,16,10,1),fpppp(24,16,10,2),fpppp(24,16,10,3)/
     x-1.0343268d-07, 2.1307655d-07,-8.3954453d-10 /
      data fpppp(24,16,11,1),fpppp(24,16,11,2),fpppp(24,16,11,3)/
     x 1.0795799d-07, 1.6197165d-07,-4.3926373d-10 /
      data fpppp(24,16,12,1),fpppp(24,16,12,2),fpppp(24,16,12,3)/
     x 1.9853300d-07, 1.0549032d-07,-2.4157479d-10 /
      data fpppp(24,16,13,1),fpppp(24,16,13,2),fpppp(24,16,13,3)/
     x 2.6960957d-07, 9.0926032d-08,-1.8958548d-10 /
      data fpppp(24,16,14,1),fpppp(24,16,14,2),fpppp(24,16,14,3)/
     x 5.9269023d-07, 2.7785927d-07, 9.2213100d-10 /
      data fpppp(24,16,15,1),fpppp(24,16,15,2),fpppp(24,16,15,3)/
     x 2.2455382d-07,-7.3615614d-07,-3.6992566d-09 /
      data fpppp(24,16,16,1),fpppp(24,16,16,2),fpppp(24,16,16,3)/
     x 1.5008145d-06, 1.3672436d-06, 6.3271890d-09 /
      data fpppp(24,16,17,1),fpppp(24,16,17,2),fpppp(24,16,17,3)/
     x 1.9214333d-07,-8.3596934d-07,-3.9582989d-09 /
      data fpppp(24,16,18,1),fpppp(24,16,18,2),fpppp(24,16,18,3)/
     x 2.2143802d-07, 2.5817075d-07, 1.1688119d-09 /
      data fpppp(24,16,19,1),fpppp(24,16,19,2),fpppp(24,16,19,3)/
     x 1.7281912d-07,-1.3956070d-07,-3.7232614d-10 /
      data fpppp(24,16,20,1),fpppp(24,16,20,2),fpppp(24,16,20,3)/
     x 2.2891264d-07,-2.3130484d-08,-7.8067573d-11 /
      data fpppp(24,16,21,1),fpppp(24,16,21,2),fpppp(24,16,21,3)/
     x 2.2891264d-07,-4.4589292d-08,-1.5774125d-10 /
      data fpppp(24,16,22,1),fpppp(24,16,22,2),fpppp(24,16,22,3)/
     x 1.7281912d-07,-5.3725472d-08,-5.3631451d-11 /
      data fpppp(24,16,23,1),fpppp(24,16,23,2),fpppp(24,16,23,3)/
     x 2.2143802d-07,-6.3711372d-08,-2.6293192d-11 /
      data fpppp(24,17, 1,1),fpppp(24,17, 1,2),fpppp(24,17, 1,3)/
     x-5.5224403d-07,-1.5131942d-07, 7.9117984d-10 /
      data fpppp(24,17, 2,1),fpppp(24,17, 2,2),fpppp(24,17, 2,3)/
     x 5.9390650d-07,-2.4131379d-07, 1.6782459d-11 /
      data fpppp(24,17, 3,1),fpppp(24,17, 3,2),fpppp(24,17, 3,3)/
     x 1.1031077d-06,-4.2920136d-07,-1.6483181d-09 /
      data fpppp(24,17, 4,1),fpppp(24,17, 4,2),fpppp(24,17, 4,3)/
     x 1.1031077d-06,-4.3787698d-07,-1.6383823d-09 /
      data fpppp(24,17, 5,1),fpppp(24,17, 5,2),fpppp(24,17, 5,3)/
     x 5.9390650d-07,-2.0661129d-07,-2.2960533d-11 /
      data fpppp(24,17, 6,1),fpppp(24,17, 6,2),fpppp(24,17, 6,3)/
     x-5.5224403d-07,-2.8145378d-07, 9.4021606d-10 /
      data fpppp(24,17, 7,1),fpppp(24,17, 7,2),fpppp(24,17, 7,3)/
     x-8.9928900d-07, 1.7917757d-07, 1.4400738d-09 /
      data fpppp(24,17, 8,1),fpppp(24,17, 8,2),fpppp(24,17, 8,3)/
     x-1.0134852d-06, 1.1653934d-07, 1.0047545d-09 /
      data fpppp(24,17, 9,1),fpppp(24,17, 9,2),fpppp(24,17, 9,3)/
     x-8.5740218d-07, 1.8148184d-07, 4.1239434d-10 /
      data fpppp(24,17,10,1),fpppp(24,17,10,2),fpppp(24,17,10,3)/
     x-5.7858100d-07, 1.1662178d-07,-3.7661709d-11 /
      data fpppp(24,17,11,1),fpppp(24,17,11,2),fpppp(24,17,11,3)/
     x-2.4430624d-07, 1.2695180d-07,-3.6120767d-10 /
      data fpppp(24,17,12,1),fpppp(24,17,12,2),fpppp(24,17,12,3)/
     x-1.1564841d-08, 1.2528420d-07,-2.8261455d-10 /
      data fpppp(24,17,13,1),fpppp(24,17,13,2),fpppp(24,17,13,3)/
     x 1.1915106d-07, 6.1141008d-08,-2.4579419d-10 /
      data fpppp(24,17,14,1),fpppp(24,17,14,2),fpppp(24,17,14,3)/
     x 2.0482802d-07, 1.1291354d-07,-6.9095870d-10 /
      data fpppp(24,17,15,1),fpppp(24,17,15,2),fpppp(24,17,15,3)/
     x 3.6494349d-07, 3.2071091d-08, 2.2143300d-09 /
      data fpppp(24,17,16,1),fpppp(24,17,16,2),fpppp(24,17,16,3)/
     x-3.6099386d-07, 6.8274720d-08,-3.8773634d-09 /
      data fpppp(24,17,17,1),fpppp(24,17,17,2),fpppp(24,17,17,3)/
     x 5.0643958d-07, 2.9068025d-09, 2.3998005d-09 /
      data fpppp(24,17,18,1),fpppp(24,17,18,2),fpppp(24,17,18,3)/
     x 5.6978500d-07, 3.3293499d-08,-7.4720943d-10 /
      data fpppp(24,17,19,1),fpppp(24,17,19,2),fpppp(24,17,19,3)/
     x 6.3453928d-07, 8.8150310d-09, 1.9163881d-10 /
      data fpppp(24,17,20,1),fpppp(24,17,20,2),fpppp(24,17,20,3)/
     x 5.9665885d-07,-1.5517261d-08, 7.1805013d-11 /
      data fpppp(24,17,21,1),fpppp(24,17,21,2),fpppp(24,17,21,3)/
     x 5.9665885d-07,-1.6140207d-08, 1.1902514d-10 /
      data fpppp(24,17,22,1),fpppp(24,17,22,2),fpppp(24,17,22,3)/
     x 6.3453928d-07, 1.1306815d-08, 2.7583034d-12 /
      data fpppp(24,17,23,1),fpppp(24,17,23,2),fpppp(24,17,23,3)/
     x 5.6978500d-07, 2.3949307d-08,-3.8907520d-11 /
      data fpppp(24,18, 1,1),fpppp(24,18, 1,2),fpppp(24,18, 1,3)/
     x 4.1308750d-07,-8.9389751d-08, 1.0280936d-10 /
      data fpppp(24,18, 2,1),fpppp(24,18, 2,2),fpppp(24,18, 2,3)/
     x 7.0998128d-07,-9.2824604d-08,-1.5894506d-10 /
      data fpppp(24,18, 3,1),fpppp(24,18, 3,2),fpppp(24,18, 3,3)/
     x 1.0305155d-06,-1.0024240d-07,-7.2416960d-10 /
      data fpppp(24,18, 4,1),fpppp(24,18, 4,2),fpppp(24,18, 4,3)/
     x 1.0305155d-06,-1.0014196d-07,-7.1660573d-10 /
      data fpppp(24,18, 5,1),fpppp(24,18, 5,2),fpppp(24,18, 5,3)/
     x 7.0998128d-07,-9.3226354d-08,-1.8920056d-10 /
      data fpppp(24,18, 6,1),fpppp(24,18, 6,2),fpppp(24,18, 6,3)/
     x 4.1308750d-07,-8.7883188d-08, 2.1626749d-10 /
      data fpppp(24,18, 7,1),fpppp(24,18, 7,2),fpppp(24,18, 7,3)/
     x-4.2804542d-09,-2.0030836d-08, 4.6756560d-10 /
      data fpppp(24,18, 8,1),fpppp(24,18, 8,2),fpppp(24,18, 8,3)/
     x-2.5500837d-07,-1.9903809d-08, 4.5196561d-10 /
      data fpppp(24,18, 9,1),fpppp(24,18, 9,2),fpppp(24,18, 9,3)/
     x-3.5910935d-07, 3.4744241d-08, 4.1843309d-10 /
      data fpppp(24,18,10,1),fpppp(24,18,10,2),fpppp(24,18,10,3)/
     x-3.6457246d-07, 3.2141833d-08, 2.1239628d-10 /
      data fpppp(24,18,11,1),fpppp(24,18,11,2),fpppp(24,18,11,3)/
     x-3.1159167d-07, 2.5474801d-09, 8.8970423d-11 /
      data fpppp(24,18,12,1),fpppp(24,18,12,2),fpppp(24,18,12,3)/
     x-1.5994120d-07, 6.2361623d-08,-2.9675984d-11 /
      data fpppp(24,18,13,1),fpppp(24,18,13,2),fpppp(24,18,13,3)/
     x 1.6333610d-08, 4.8630221d-08,-6.5277898d-11 /
      data fpppp(24,18,14,1),fpppp(24,18,14,2),fpppp(24,18,14,3)/
     x 1.9259068d-07, 3.3417921d-08,-8.4426711d-11 /
      data fpppp(24,18,15,1),fpppp(24,18,15,2),fpppp(24,18,15,3)/
     x 3.4871812d-07, 2.7630985d-08,-5.3550127d-10 /
      data fpppp(24,18,16,1),fpppp(24,18,16,2),fpppp(24,18,16,3)/
     x 6.6666364d-07, 3.6528921d-08, 5.3814666d-10 /
      data fpppp(24,18,17,1),fpppp(24,18,17,2),fpppp(24,18,17,3)/
     x 6.7911303d-07, 2.8613020d-08,-5.2699304d-10 /
      data fpppp(24,18,18,1),fpppp(24,18,18,2),fpppp(24,18,18,3)/
     x 7.9811992d-07, 2.2044126d-08, 8.8502835d-11 /
      data fpppp(24,18,19,1),fpppp(24,18,19,2),fpppp(24,18,19,3)/
     x 8.9134459d-07, 1.7788850d-08,-2.2047336d-11 /
      data fpppp(24,18,20,1),fpppp(24,18,20,2),fpppp(24,18,20,3)/
     x 9.7091989d-07, 1.6599956d-08, 3.3643412d-11 /
      data fpppp(24,18,21,1),fpppp(24,18,21,2),fpppp(24,18,21,3)/
     x 9.7091989d-07, 1.6424301d-08, 2.7162122d-11 /
      data fpppp(24,18,22,1),fpppp(24,18,22,2),fpppp(24,18,22,3)/
     x 8.9134459d-07, 1.8491469d-08, 3.8778263d-12 /
      data fpppp(24,18,23,1),fpppp(24,18,23,2),fpppp(24,18,23,3)/
     x 7.9811992d-07, 1.9409306d-08,-8.7165222d-12 /
      data fpppp(24,19, 1,1),fpppp(24,19, 1,2),fpppp(24,19, 1,3)/
     x 1.3657440d-06, 6.3976639d-21,-9.4044172d-10 /
      data fpppp(24,19, 2,1),fpppp(24,19, 2,2),fpppp(24,19, 2,3)/
     x 1.3590833d-06, 2.4795729d-22,-5.9495339d-10 /
      data fpppp(24,19, 3,1),fpppp(24,19, 3,2),fpppp(24,19, 3,3)/
     x 1.4708952d-06, 3.5097450d-21, 1.3882553d-10 /
      data fpppp(24,19, 4,1),fpppp(24,19, 4,2),fpppp(24,19, 4,3)/
     x 1.4708952d-06, 5.1131105d-22, 1.5029364d-10 /
      data fpppp(24,19, 5,1),fpppp(24,19, 5,2),fpppp(24,19, 5,3)/
     x 1.3590833d-06,-6.9668918d-22,-6.4082586d-10 /
      data fpppp(24,19, 6,1),fpppp(24,19, 6,2),fpppp(24,19, 6,3)/
     x 1.3657440d-06, 1.3837445d-21,-7.6841996d-10 /
      data fpppp(24,19, 7,1),fpppp(24,19, 7,2),fpppp(24,19, 7,3)/
     x 8.3152686d-07,-1.1184797d-21,-2.7721179d-10 /
      data fpppp(24,19, 8,1),fpppp(24,19, 8,2),fpppp(24,19, 8,3)/
     x 3.2551739d-07, 6.9531990d-21, 2.1801937d-10 /
      data fpppp(24,19, 9,1),fpppp(24,19, 9,2),fpppp(24,19, 9,3)/
     x-8.0658679d-08, 2.7055238d-21, 7.5820375d-10 /
      data fpppp(24,19,10,1),fpppp(24,19,10,2),fpppp(24,19,10,3)/
     x-3.4746588d-07, 3.3855893d-21, 6.2011850d-10 /
      data fpppp(24,19,11,1),fpppp(24,19,11,2),fpppp(24,19,11,3)/
     x-4.6029961d-07, 1.3699799d-21, 4.3282793d-10 /
      data fpppp(24,19,12,1),fpppp(24,19,12,2),fpppp(24,19,12,3)/
     x-3.2595227d-07, 1.3317331d-21, 1.3926877d-10 /
      data fpppp(24,19,13,1),fpppp(24,19,13,2),fpppp(24,19,13,3)/
     x-1.0009557d-07, 4.6504177d-22, 4.7602679d-11 /
      data fpppp(24,19,14,1),fpppp(24,19,14,2),fpppp(24,19,14,3)/
     x 7.3031944d-08,-3.8524673d-21,-1.1207235d-10 /
      data fpppp(24,19,15,1),fpppp(24,19,15,2),fpppp(24,19,15,3)/
     x 3.7723991d-07, 3.0622756d-21,-8.1007028d-10 /
      data fpppp(24,19,16,1),fpppp(24,19,16,2),fpppp(24,19,16,3)/
     x 8.6875947d-07, 3.6069333d-21, 7.7649604d-10 /
      data fpppp(24,19,17,1),fpppp(24,19,17,2),fpppp(24,19,17,3)/
     x 8.9225014d-07, 2.4867892d-23,-8.0096005d-10 /
      data fpppp(24,19,18,1),fpppp(24,19,18,2),fpppp(24,19,18,3)/
     x 1.0607440d-06,-5.4118085d-21, 1.3800551d-10 /
      data fpppp(24,19,19,1),fpppp(24,19,19,2),fpppp(24,19,19,3)/
     x 1.2066970d-06, 8.3841946d-22,-1.3547456d-11 /
      data fpppp(24,19,20,1),fpppp(24,19,20,2),fpppp(24,19,20,3)/
     x 1.3433195d-06, 4.2575575d-22, 4.9205865d-11 /
      data fpppp(24,19,21,1),fpppp(24,19,21,2),fpppp(24,19,21,3)/
     x 1.3433195d-06,-3.4292009d-21, 4.0621790d-11 /
      data fpppp(24,19,22,1),fpppp(24,19,22,2),fpppp(24,19,22,3)/
     x 1.2066970d-06,-9.1104477d-22, 2.0788844d-11 /
      data fpppp(24,19,23,1),fpppp(24,19,23,2),fpppp(24,19,23,3)/
     x 1.0607440d-06, 9.3875019d-21, 9.2443826d-12 /
      data fpppp(25, 1, 1,1),fpppp(25, 1, 1,2),fpppp(25, 1, 1,3)/
     x 4.8857846d-06, 1.8199025d-19,-4.8150339d-09 /
      data fpppp(25, 1, 2,1),fpppp(25, 1, 2,2),fpppp(25, 1, 2,3)/
     x 4.9809855d-06, 1.8643490d-20,-5.3659166d-09 /
      data fpppp(25, 1, 3,1),fpppp(25, 1, 3,2),fpppp(25, 1, 3,3)/
     x 4.2566101d-06,-5.6991885d-20,-6.5829507d-09 /
      data fpppp(25, 1, 4,1),fpppp(25, 1, 4,2),fpppp(25, 1, 4,3)/
     x 4.2566101d-06,-5.2728490d-20,-6.5189513d-09 /
      data fpppp(25, 1, 5,1),fpppp(25, 1, 5,2),fpppp(25, 1, 5,3)/
     x 4.9809855d-06,-1.9072009d-20,-5.6219142d-09 /
      data fpppp(25, 1, 6,1),fpppp(25, 1, 6,2),fpppp(25, 1, 6,3)/
     x 4.8857846d-06,-1.4090899d-20,-3.8550429d-09 /
      data fpppp(25, 1, 7,1),fpppp(25, 1, 7,2),fpppp(25, 1, 7,3)/
     x 2.8865887d-06,-3.5208322d-20,-8.4896252d-10 /
      data fpppp(25, 1, 8,1),fpppp(25, 1, 8,2),fpppp(25, 1, 8,3)/
     x-1.3337468d-06,-9.9399698d-21, 2.0310000d-09 /
      data fpppp(25, 1, 9,1),fpppp(25, 1, 9,2),fpppp(25, 1, 9,3)/
     x-6.2740389d-06, 3.1294842d-20, 3.9755102d-09 /
      data fpppp(25, 1,10,1),fpppp(25, 1,10,2),fpppp(25, 1,10,3)/
     x-1.0075107d-05, 8.9452499d-20, 5.2532096d-09 /
      data fpppp(25, 1,11,1),fpppp(25, 1,11,2),fpppp(25, 1,11,3)/
     x-1.3021729d-05,-7.5844149d-20, 5.6569073d-09 /
      data fpppp(25, 1,12,1),fpppp(25, 1,12,2),fpppp(25, 1,12,3)/
     x-1.3718372d-05, 8.7623007d-20, 5.8709284d-09 /
      data fpppp(25, 1,13,1),fpppp(25, 1,13,2),fpppp(25, 1,13,3)/
     x-1.2626709d-05,-1.9869810d-20, 5.9332494d-09 /
      data fpppp(25, 1,14,1),fpppp(25, 1,14,2),fpppp(25, 1,14,3)/
     x-1.0481337d-05,-2.4205933d-20, 5.5583265d-09 /
      data fpppp(25, 1,15,1),fpppp(25, 1,15,2),fpppp(25, 1,15,3)/
     x-6.6604956d-06, 3.8662921d-20, 4.6697319d-09 /
      data fpppp(25, 1,16,1),fpppp(25, 1,16,2),fpppp(25, 1,16,3)/
     x-1.6406066d-06, 2.9671035d-21, 2.4435702d-09 /
      data fpppp(25, 1,17,1),fpppp(25, 1,17,2),fpppp(25, 1,17,3)/
     x 2.7903879d-06,-4.2196330d-20,-5.7570747d-10 /
      data fpppp(25, 1,18,1),fpppp(25, 1,18,2),fpppp(25, 1,18,3)/
     x 5.1478467d-06,-4.5639920d-20,-4.0411816d-09 /
      data fpppp(25, 1,19,1),fpppp(25, 1,19,2),fpppp(25, 1,19,3)/
     x 2.5462363d-06,-4.3817146d-20,-5.7408124d-09 /
      data fpppp(25, 1,20,1),fpppp(25, 1,20,2),fpppp(25, 1,20,3)/
     x 3.0768470d-06, 1.1936318d-20,-7.2622626d-09 /
      data fpppp(25, 1,21,1),fpppp(25, 1,21,2),fpppp(25, 1,21,3)/
     x 3.0768470d-06, 2.1234942d-20,-7.3092383d-09 /
      data fpppp(25, 1,22,1),fpppp(25, 1,22,2),fpppp(25, 1,22,3)/
     x 2.5462363d-06,-1.3169694d-20,-5.5529097d-09 /
      data fpppp(25, 1,23,1),fpppp(25, 1,23,2),fpppp(25, 1,23,3)/
     x 5.1478467d-06, 1.3892619d-19,-4.7458166d-09 /
      data fpppp(25, 2, 1,1),fpppp(25, 2, 1,2),fpppp(25, 2, 1,3)/
     x 1.3088171d-06, 3.5959386d-06,-1.4196381d-09 /
      data fpppp(25, 2, 2,1),fpppp(25, 2, 2,2),fpppp(25, 2, 2,3)/
     x 7.6516817d-07, 1.5494954d-06,-1.6837550d-09 /
      data fpppp(25, 2, 3,1),fpppp(25, 2, 3,2),fpppp(25, 2, 3,3)/
     x-4.3991910d-07,-2.6922733d-06,-2.2620399d-09 /
      data fpppp(25, 2, 4,1),fpppp(25, 2, 4,2),fpppp(25, 2, 4,3)/
     x-4.3991910d-07,-2.9433402d-06,-2.2404798d-09 /
      data fpppp(25, 2, 5,1),fpppp(25, 2, 5,2),fpppp(25, 2, 5,3)/
     x 7.6516817d-07, 2.5537630d-06,-1.7699951d-09 /
      data fpppp(25, 2, 6,1),fpppp(25, 2, 6,2),fpppp(25, 2, 6,3)/
     x 1.3088171d-06,-1.7006491d-07,-1.0962376d-09 /
      data fpppp(25, 2, 7,1),fpppp(25, 2, 7,2),fpppp(25, 2, 7,3)/
     x 9.4389697d-07, 2.0517362d-07,-4.2957883d-11 /
      data fpppp(25, 2, 8,1),fpppp(25, 2, 8,2),fpppp(25, 2, 8,3)/
     x-4.4106376d-07, 3.8871206d-07, 7.8785496d-10 /
      data fpppp(25, 2, 9,1),fpppp(25, 2, 9,2),fpppp(25, 2, 9,3)/
     x-2.1878928d-06,-2.5640397d-08, 1.2704423d-09 /
      data fpppp(25, 2,10,1),fpppp(25, 2,10,2),fpppp(25, 2,10,3)/
     x-3.4454661d-06, 6.4225114d-07, 1.5778748d-09 /
      data fpppp(25, 2,11,1),fpppp(25, 2,11,2),fpppp(25, 2,11,3)/
     x-4.4632775d-06, 3.2011705d-07, 1.6275465d-09 /
      data fpppp(25, 2,12,1),fpppp(25, 2,12,2),fpppp(25, 2,12,3)/
     x-4.6579718d-06, 6.1471662d-07, 1.6884048d-09 /
      data fpppp(25, 2,13,1),fpppp(25, 2,13,2),fpppp(25, 2,13,3)/
     x-4.2885640d-06, 8.2127028d-07, 1.7510938d-09 /
      data fpppp(25, 2,14,1),fpppp(25, 2,14,2),fpppp(25, 2,14,3)/
     x-3.6768334d-06, 2.9000194d-07, 1.7427153d-09 /
      data fpppp(25, 2,15,1),fpppp(25, 2,15,2),fpppp(25, 2,15,3)/
     x-2.4226134d-06, 4.5375061d-08, 1.6254703d-09 /
      data fpppp(25, 2,16,1),fpppp(25, 2,16,2),fpppp(25, 2,16,3)/
     x-6.4605037d-07, 4.9999649d-07, 1.0337546d-09 /
      data fpppp(25, 2,17,1),fpppp(25, 2,17,2),fpppp(25, 2,17,3)/
     x 8.4416842d-07,-3.4441454d-07, 1.0290065d-10 /
      data fpppp(25, 2,18,1),fpppp(25, 2,18,2),fpppp(25, 2,18,3)/
     x 1.4131245d-06, 1.6342876d-06,-1.1444747d-09 /
      data fpppp(25, 2,19,1),fpppp(25, 2,19,2),fpppp(25, 2,19,3)/
     x-4.3469452d-07,-5.3148941d-08,-1.8625094d-09 /
      data fpppp(25, 2,20,1),fpppp(25, 2,20,2),fpppp(25, 2,20,3)/
     x-8.6394584d-07,-2.0527599d-06,-2.6121005d-09 /
      data fpppp(25, 2,21,1),fpppp(25, 2,21,2),fpppp(25, 2,21,3)/
     x-8.6394584d-07,-2.0885646d-06,-2.6295795d-09 /
      data fpppp(25, 2,22,1),fpppp(25, 2,22,2),fpppp(25, 2,22,3)/
     x-4.3469452d-07, 9.0069682d-08,-1.7925931d-09 /
      data fpppp(25, 2,23,1),fpppp(25, 2,23,2),fpppp(25, 2,23,3)/
     x 1.4131245d-06, 1.0972178d-06,-1.4066606d-09 /
      data fpppp(25, 3, 1,1),fpppp(25, 3, 1,2),fpppp(25, 3, 1,3)/
     x-5.9891991d-06, 3.8083088d-06, 2.9975511d-09 /
      data fpppp(25, 3, 2,1),fpppp(25, 3, 2,2),fpppp(25, 3, 2,3)/
     x-7.4013498d-06, 1.3623971d-06, 3.3030069d-09 /
      data fpppp(25, 3, 3,1),fpppp(25, 3, 3,2),fpppp(25, 3, 3,3)/
     x-1.3990141d-05,-3.6965736d-06, 3.9588641d-09 /
      data fpppp(25, 3, 4,1),fpppp(25, 3, 4,2),fpppp(25, 3, 4,3)/
     x-1.3990141d-05,-4.0155441d-06, 3.9565733d-09 /
      data fpppp(25, 3, 5,1),fpppp(25, 3, 5,2),fpppp(25, 3, 5,3)/
     x-7.4013498d-06, 2.6382792d-06, 3.3121703d-09 /
      data fpppp(25, 3, 6,1),fpppp(25, 3, 6,2),fpppp(25, 3, 6,3)/
     x-5.9891991d-06,-9.7624916d-07, 2.9631886d-09 /
      data fpppp(25, 3, 7,1),fpppp(25, 3, 7,2),fpppp(25, 3, 7,3)/
     x-4.9256816d-06,-4.6283344d-07, 1.6377374d-09 /
      data fpppp(25, 3, 8,1),fpppp(25, 3, 8,2),fpppp(25, 3, 8,3)/
     x-2.1056937d-06, 3.6143474d-07,-2.1338875d-10 /
      data fpppp(25, 3, 9,1),fpppp(25, 3, 9,2),fpppp(25, 3, 9,3)/
     x 1.1210246d-06, 7.2515811d-07,-2.1903473d-09 /
      data fpppp(25, 3,10,1),fpppp(25, 3,10,2),fpppp(25, 3,10,3)/
     x 3.8428278d-06, 1.1860676d-06,-4.0414683d-09 /
      data fpppp(25, 3,11,1),fpppp(25, 3,11,2),fpppp(25, 3,11,3)/
     x 6.0385109d-06, 1.5449081d-06,-4.8469879d-09 /
      data fpppp(25, 3,12,1),fpppp(25, 3,12,2),fpppp(25, 3,12,3)/
     x 6.6331596d-06, 1.6505839d-06,-5.5082100d-09 /
      data fpppp(25, 3,13,1),fpppp(25, 3,13,2),fpppp(25, 3,13,3)/
     x 5.7321571d-06, 1.6023289d-06,-4.8030803d-09 /
      data fpppp(25, 3,14,1),fpppp(25, 3,14,2),fpppp(25, 3,14,3)/
     x 3.7540531d-06, 1.2655979d-06,-3.9437026d-09 /
      data fpppp(25, 3,15,1),fpppp(25, 3,15,2),fpppp(25, 3,15,3)/
     x 9.0622688d-07, 7.6428966d-07,-2.1680984d-09 /
      data fpppp(25, 3,16,1),fpppp(25, 3,16,2),fpppp(25, 3,16,3)/
     x-2.3592956d-06, 4.9096518d-07,-5.8133304d-11 /
      data fpppp(25, 3,17,1),fpppp(25, 3,17,2),fpppp(25, 3,17,3)/
     x-5.1784418d-06,-6.1415274d-07, 1.7987681d-09 /
      data fpppp(25, 3,18,1),fpppp(25, 3,18,2),fpppp(25, 3,18,3)/
     x-6.2568042d-06,-5.3890515d-07, 3.1199718d-09 /
      data fpppp(25, 3,19,1),fpppp(25, 3,19,2),fpppp(25, 3,19,3)/
     x-6.3438927d-06, 1.4140515d-06, 2.9526209d-09 /
      data fpppp(25, 3,20,1),fpppp(25, 3,20,2),fpppp(25, 3,20,3)/
     x-1.2325689d-05,-3.4676527d-06, 4.0426888d-09 /
      data fpppp(25, 3,21,1),fpppp(25, 3,21,2),fpppp(25, 3,21,3)/
     x-1.2325689d-05,-3.2668100d-06, 4.0105978d-09 /
      data fpppp(25, 3,22,1),fpppp(25, 3,22,2),fpppp(25, 3,22,3)/
     x-6.3438927d-06, 6.1068088d-07, 3.0809847d-09 /
      data fpppp(25, 3,23,1),fpppp(25, 3,23,2),fpppp(25, 3,23,3)/
     x-6.2568042d-06, 2.4737347d-06, 2.6386076d-09 /
      data fpppp(25, 4, 1,1),fpppp(25, 4, 1,2),fpppp(25, 4, 1,3)/
     x-2.6354492d-07,-1.8743527d-06, 3.8384635d-09 /
      data fpppp(25, 4, 2,1),fpppp(25, 4, 2,2),fpppp(25, 4, 2,3)/
     x-1.7404156d-06,-1.7907149d-06, 3.7236677d-09 /
      data fpppp(25, 4, 3,1),fpppp(25, 4, 3,2),fpppp(25, 4, 3,3)/
     x 3.4475622d-06,-1.6449405d-06, 3.5297919d-09 /
      data fpppp(25, 4, 4,1),fpppp(25, 4, 4,2),fpppp(25, 4, 4,3)/
     x 3.4475622d-06,-1.5864040d-06, 3.4385905d-09 /
      data fpppp(25, 4, 5,1),fpppp(25, 4, 5,2),fpppp(25, 4, 5,3)/
     x-1.7404156d-06,-2.0248606d-06, 4.0884736d-09 /
      data fpppp(25, 4, 6,1),fpppp(25, 4, 6,2),fpppp(25, 4, 6,3)/
     x-2.6354492d-07,-9.9630653d-07, 2.4704416d-09 /
      data fpppp(25, 4, 7,1),fpppp(25, 4, 7,2),fpppp(25, 4, 7,3)/
     x 2.9488438d-06,-9.5276274d-08, 2.5701535d-10 /
      data fpppp(25, 4, 8,1),fpppp(25, 4, 8,2),fpppp(25, 4, 8,3)/
     x 5.1802717d-06, 4.3065353d-07,-2.0612872d-09 /
      data fpppp(25, 4, 9,1),fpppp(25, 4, 9,2),fpppp(25, 4, 9,3)/
     x 7.1502426d-06, 1.0580047d-06,-3.0061110d-09 /
      data fpppp(25, 4,10,1),fpppp(25, 4,10,2),fpppp(25, 4,10,3)/
     x 8.8258365d-06, 1.4804137d-06,-2.8567823d-09 /
      data fpppp(25, 4,11,1),fpppp(25, 4,11,2),fpppp(25, 4,11,3)/
     x 9.7386202d-06, 1.5580036d-06,-2.7634145d-09 /
      data fpppp(25, 4,12,1),fpppp(25, 4,12,2),fpppp(25, 4,12,3)/
     x 1.0116733d-05, 1.6670120d-06,-2.1555059d-09 /
      data fpppp(25, 4,13,1),fpppp(25, 4,13,2),fpppp(25, 4,13,3)/
     x 9.8638604d-06, 1.6233510d-06,-3.0551894d-09 /
      data fpppp(25, 4,14,1),fpppp(25, 4,14,2),fpppp(25, 4,14,3)/
     x 8.9925981d-06, 1.6163069d-06,-3.0822967d-09 /
      data fpppp(25, 4,15,1),fpppp(25, 4,15,2),fpppp(25, 4,15,3)/
     x 7.4167138d-06, 1.2017665d-06,-3.3390921d-09 /
      data fpppp(25, 4,16,1),fpppp(25, 4,16,2),fpppp(25, 4,16,3)/
     x 5.4047643d-06, 6.4806493d-07,-2.2627678d-09 /
      data fpppp(25, 4,17,1),fpppp(25, 4,17,2),fpppp(25, 4,17,3)/
     x 3.0663156d-06,-9.4316372d-08,-6.5772165d-11 /
      data fpppp(25, 4,18,1),fpppp(25, 4,18,2),fpppp(25, 4,18,3)/
     x-1.5351012d-07,-8.7603133d-07, 2.5973299d-09 /
      data fpppp(25, 4,19,1),fpppp(25, 4,19,2),fpppp(25, 4,19,3)/
     x-2.0041550d-06,-2.3350876d-06, 4.4888557d-09 /
      data fpppp(25, 4,20,1),fpppp(25, 4,20,2),fpppp(25, 4,20,3)/
     x 2.5358935d-06,-1.6228229d-06, 3.6812831d-09 /
      data fpppp(25, 4,21,1),fpppp(25, 4,21,2),fpppp(25, 4,21,3)/
     x 2.5358935d-06,-1.7078599d-06, 3.7889600d-09 /
      data fpppp(25, 4,22,1),fpppp(25, 4,22,2),fpppp(25, 4,22,3)/
     x-2.0041550d-06,-1.9949396d-06, 4.0581481d-09 /
      data fpppp(25, 4,23,1),fpppp(25, 4,23,2),fpppp(25, 4,23,3)/
     x-1.5351012d-07,-2.1515866d-06, 4.2124831d-09 /
      data fpppp(25, 5, 1,1),fpppp(25, 5, 1,2),fpppp(25, 5, 1,3)/
     x 3.1571154d-06,-1.0598807d-06,-1.8665133d-09 /
      data fpppp(25, 5, 2,1),fpppp(25, 5, 2,2),fpppp(25, 5, 2,3)/
     x 2.7411054d-06,-1.1809860d-06,-3.1746146d-10 /
      data fpppp(25, 5, 3,1),fpppp(25, 5, 3,2),fpppp(25, 5, 3,3)/
     x 5.2930393d-07,-1.4548422d-06, 2.9962108d-09 /
      data fpppp(25, 5, 4,1),fpppp(25, 5, 4,2),fpppp(25, 5, 4,3)/
     x 5.2930393d-07,-1.4297389d-06, 3.0062287d-09 /
      data fpppp(25, 5, 5,1),fpppp(25, 5, 5,2),fpppp(25, 5, 5,3)/
     x 2.7411054d-06,-1.2813991d-06,-3.5753309d-10 /
      data fpppp(25, 5, 6,1),fpppp(25, 5, 6,2),fpppp(25, 5, 6,3)/
     x 3.1571154d-06,-6.8333170d-07,-1.7162446d-09 /
      data fpppp(25, 5, 7,1),fpppp(25, 5, 7,2),fpppp(25, 5, 7,3)/
     x 3.2589040d-06,-1.8723185d-07,-2.0491711d-09 /
      data fpppp(25, 5, 8,1),fpppp(25, 5, 8,2),fpppp(25, 5, 8,3)/
     x 4.0138289d-06, 4.9065427d-07,-8.1668345d-10 /
      data fpppp(25, 5, 9,1),fpppp(25, 5, 9,2),fpppp(25, 5, 9,3)/
     x 4.4784659d-06, 9.5785118d-07,-6.0951702d-11 /
      data fpppp(25, 5,10,1),fpppp(25, 5,10,2),fpppp(25, 5,10,3)/
     x 4.1911730d-06, 1.0816249d-06, 1.2679077d-10 /
      data fpppp(25, 5,11,1),fpppp(25, 5,11,2),fpppp(25, 5,11,3)/
     x 3.7274728d-06, 1.0228714d-06, 4.6361642d-10 /
      data fpppp(25, 5,12,1),fpppp(25, 5,12,2),fpppp(25, 5,12,3)/
     x 3.5121057d-06, 1.0781026d-06, 1.4015873d-10 /
      data fpppp(25, 5,13,1),fpppp(25, 5,13,2),fpppp(25, 5,13,3)/
     x 3.8304214d-06, 1.1280378d-06, 5.8116626d-10 /
      data fpppp(25, 5,14,1),fpppp(25, 5,14,2),fpppp(25, 5,14,3)/
     x 4.3102812d-06, 1.2485807d-06,-8.6348691d-11 /
      data fpppp(25, 5,15,1),fpppp(25, 5,15,2),fpppp(25, 5,15,3)/
     x 4.5713730d-06, 1.1223405d-06,-1.5590841d-10 /
      data fpppp(25, 5,16,1),fpppp(25, 5,16,2),fpppp(25, 5,16,3)/
     x 4.1303650d-06, 7.2715505d-07,-1.0900568d-09 /
      data fpppp(25, 5,17,1),fpppp(25, 5,17,2),fpppp(25, 5,17,3)/
     x 3.2770651d-06,-1.7451328d-08,-1.9382585d-09 /
      data fpppp(25, 5,18,1),fpppp(25, 5,18,2),fpppp(25, 5,18,3)/
     x 2.8841336d-06,-6.8761803d-07,-2.0597140d-09 /
      data fpppp(25, 5,19,1),fpppp(25, 5,19,2),fpppp(25, 5,19,3)/
     x 2.4539248d-06,-1.3126939d-06,-6.3774256d-11 /
      data fpppp(25, 5,20,1),fpppp(25, 5,20,2),fpppp(25, 5,20,3)/
     x 6.0397540d-08,-1.6849162d-06, 3.0455242d-09 /
      data fpppp(25, 5,21,1),fpppp(25, 5,21,2),fpppp(25, 5,21,3)/
     x 6.0397540d-08,-1.7063421d-06, 3.0713913d-09 /
      data fpppp(25, 5,22,1),fpppp(25, 5,22,2),fpppp(25, 5,22,3)/
     x 2.4539248d-06,-1.2269903d-06,-1.6724269d-10 /
      data fpppp(25, 5,23,1),fpppp(25, 5,23,2),fpppp(25, 5,23,3)/
     x 2.8841336d-06,-1.0090064d-06,-1.6717073d-09 /
      data fpppp(25, 6, 1,1),fpppp(25, 6, 1,2),fpppp(25, 6, 1,3)/
     x 2.6465938d-06,-5.1556517d-07,-8.8761425d-10 /
      data fpppp(25, 6, 2,1),fpppp(25, 6, 2,2),fpppp(25, 6, 2,3)/
     x 2.9569403d-06,-6.3258247d-07,-1.0134142d-09 /
      data fpppp(25, 6, 3,1),fpppp(25, 6, 3,2),fpppp(25, 6, 3,3)/
     x 3.6439192d-06,-8.9097073d-07,-1.2810621d-09 /
      data fpppp(25, 6, 4,1),fpppp(25, 6, 4,2),fpppp(25, 6, 4,3)/
     x 3.6439192d-06,-8.7760614d-07,-1.2844279d-09 /
      data fpppp(25, 6, 5,1),fpppp(25, 6, 5,2),fpppp(25, 6, 5,3)/
     x 2.9569403d-06,-6.8604083d-07,-9.9995105d-10 /
      data fpppp(25, 6, 6,1),fpppp(25, 6, 6,2),fpppp(25, 6, 6,3)/
     x 2.6465938d-06,-3.1509631d-07,-9.3810093d-10 /
      data fpppp(25, 6, 7,1),fpppp(25, 6, 7,2),fpppp(25, 6, 7,3)/
     x 2.2601277d-06, 5.0385876d-08,-1.0816944d-10 /
      data fpppp(25, 6, 8,1),fpppp(25, 6, 8,2),fpppp(25, 6, 8,3)/
     x 1.3243592d-06, 2.5938345d-07, 3.7201273d-10 /
      data fpppp(25, 6, 9,1),fpppp(25, 6, 9,2),fpppp(25, 6, 9,3)/
     x 4.2756340d-07, 3.0957471d-07, 8.8178945d-10 /
      data fpppp(25, 6,10,1),fpppp(25, 6,10,2),fpppp(25, 6,10,3)/
     x 1.8449789d-07, 5.1823304d-07, 1.2981410d-09 /
      data fpppp(25, 6,11,1),fpppp(25, 6,11,2),fpppp(25, 6,11,3)/
     x 2.9778359d-07, 5.8218624d-07, 1.0029904d-09 /
      data fpppp(25, 6,12,1),fpppp(25, 6,12,2),fpppp(25, 6,12,3)/
     x 4.3734802d-07, 7.6094831d-07, 1.1901829d-09 /
      data fpppp(25, 6,13,1),fpppp(25, 6,13,2),fpppp(25, 6,13,3)/
     x 2.8209452d-07, 6.6018379d-07, 8.1523474d-10 /
      data fpppp(25, 6,14,1),fpppp(25, 6,14,2),fpppp(25, 6,14,3)/
     x 2.8387590d-07, 6.8408460d-07, 1.3335381d-09 /
      data fpppp(25, 6,15,1),fpppp(25, 6,15,2),fpppp(25, 6,15,3)/
     x 5.7781949d-07, 5.1500259d-07, 7.3462891d-10 /
      data fpppp(25, 6,16,1),fpppp(25, 6,16,2),fpppp(25, 6,16,3)/
     x 1.4408255d-06, 4.3926103d-07, 3.8953570d-10 /
      data fpppp(25, 6,17,1),fpppp(25, 6,17,2),fpppp(25, 6,17,3)/
     x 2.4110740d-06, 1.8683744d-07,-3.7925932d-10 /
      data fpppp(25, 6,18,1),fpppp(25, 6,18,2),fpppp(25, 6,18,3)/
     x 2.8676040d-06,-1.9553709d-07,-6.9275328d-10 /
      data fpppp(25, 6,19,1),fpppp(25, 6,19,2),fpppp(25, 6,19,3)/
     x 2.9725359d-06,-7.6392118d-07,-1.2985765d-09 /
      data fpppp(25, 6,20,1),fpppp(25, 6,20,2),fpppp(25, 6,20,3)/
     x 3.5774082d-06,-1.1188326d-06,-1.1098294d-09 /
      data fpppp(25, 6,21,1),fpppp(25, 6,21,2),fpppp(25, 6,21,3)/
     x 3.5774082d-06,-1.1379509d-06,-1.1427679d-09 /
      data fpppp(25, 6,22,1),fpppp(25, 6,22,2),fpppp(25, 6,22,3)/
     x 2.9725359d-06,-6.8744800d-07,-1.1668223d-09 /
      data fpppp(25, 6,23,1),fpppp(25, 6,23,2),fpppp(25, 6,23,3)/
     x 2.8676040d-06,-4.8231154d-07,-1.1868313d-09 /
      data fpppp(25, 7, 1,1),fpppp(25, 7, 1,2),fpppp(25, 7, 1,3)/
     x 1.5112280d-06,-1.3834151d-07, 3.4842468d-10 /
      data fpppp(25, 7, 2,1),fpppp(25, 7, 2,2),fpppp(25, 7, 2,3)/
     x 2.2350859d-06,-2.2210829d-07,-5.2179067d-10 /
      data fpppp(25, 7, 3,1),fpppp(25, 7, 3,2),fpppp(25, 7, 3,3)/
     x 2.4514944d-06,-4.0500129d-07,-2.3917815d-09 /
      data fpppp(25, 7, 4,1),fpppp(25, 7, 4,2),fpppp(25, 7, 4,3)/
     x 2.4514944d-06,-3.9906396d-07,-2.3826051d-09 /
      data fpppp(25, 7, 5,1),fpppp(25, 7, 5,2),fpppp(25, 7, 5,3)/
     x 2.2350859d-06,-2.4585762d-07,-5.5849618d-10 /
      data fpppp(25, 7, 6,1),fpppp(25, 7, 6,2),fpppp(25, 7, 6,3)/
     x 1.5112280d-06,-4.9281513d-08, 4.8607033d-10 /
      data fpppp(25, 7, 7,1),fpppp(25, 7, 7,2),fpppp(25, 7, 7,3)/
     x 5.2167401d-07,-3.1534762d-08, 6.8799442d-10 /
      data fpppp(25, 7, 8,1),fpppp(25, 7, 8,2),fpppp(25, 7, 8,3)/
     x-2.8372222d-07, 4.8771420d-08, 6.8662826d-10 /
      data fpppp(25, 7, 9,1),fpppp(25, 7, 9,2),fpppp(25, 7, 9,3)/
     x-7.6856204d-07, 8.4360642d-08, 8.1566541d-10 /
      data fpppp(25, 7,10,1),fpppp(25, 7,10,2),fpppp(25, 7,10,3)/
     x-1.1848801d-06, 1.7344584d-07, 6.7516369d-10 /
      data fpppp(25, 7,11,1),fpppp(25, 7,11,2),fpppp(25, 7,11,3)/
     x-1.4454473d-06, 2.4876851d-07, 7.4447728d-10 /
      data fpppp(25, 7,12,1),fpppp(25, 7,12,2),fpppp(25, 7,12,3)/
     x-1.5630341d-06, 2.9254820d-07, 2.6436939d-10 /
      data fpppp(25, 7,13,1),fpppp(25, 7,13,2),fpppp(25, 7,13,3)/
     x-1.3343984d-06, 3.9067928d-07, 8.7679968d-10 /
      data fpppp(25, 7,14,1),fpppp(25, 7,14,2),fpppp(25, 7,14,3)/
     x-1.0967457d-06, 2.7613711d-07, 5.9131672d-10 /
      data fpppp(25, 7,15,1),fpppp(25, 7,15,2),fpppp(25, 7,15,3)/
     x-6.2364734d-07, 2.6844728d-07, 8.2200588d-10 /
      data fpppp(25, 7,16,1),fpppp(25, 7,16,2),fpppp(25, 7,16,3)/
     x-8.0312880d-08, 1.9607424d-07, 5.1434107d-10 /
      data fpppp(25, 7,17,1),fpppp(25, 7,17,2),fpppp(25, 7,17,3)/
     x 7.0221806d-07, 1.0738879d-07, 6.0097445d-10 /
      data fpppp(25, 7,18,1),fpppp(25, 7,18,2),fpppp(25, 7,18,3)/
     x 1.6655788d-06,-2.6888994d-08, 1.4558523d-10 /
      data fpppp(25, 7,19,1),fpppp(25, 7,19,2),fpppp(25, 7,19,3)/
     x 2.4467641d-06,-2.6352514d-07,-5.0703120d-10 /
      data fpppp(25, 7,20,1),fpppp(25, 7,20,2),fpppp(25, 7,20,3)/
     x 2.6489565d-06,-5.7835915d-07,-2.1806197d-09 /
      data fpppp(25, 7,21,1),fpppp(25, 7,21,2),fpppp(25, 7,21,3)/
     x 2.6489565d-06,-5.8261771d-07,-2.1745251d-09 /
      data fpppp(25, 7,22,1),fpppp(25, 7,22,2),fpppp(25, 7,22,3)/
     x 2.4467641d-06,-2.4649091d-07,-5.3140934d-10 /
      data fpppp(25, 7,23,1),fpppp(25, 7,23,2),fpppp(25, 7,23,3)/
     x 1.6655788d-06,-9.0767350d-08, 2.3700323d-10 /
      data fpppp(25, 8, 1,1),fpppp(25, 8, 1,2),fpppp(25, 8, 1,3)/
     x 3.1986819d-07,-8.4748247d-08,-1.7086812d-10 /
      data fpppp(25, 8, 2,1),fpppp(25, 8, 2,2),fpppp(25, 8, 2,3)/
     x 6.9512467d-07,-9.6232670d-08,-4.1985581d-10 /
      data fpppp(25, 8, 3,1),fpppp(25, 8, 3,2),fpppp(25, 8, 3,3)/
     x 1.0558759d-06,-1.2467830d-07,-9.6529758d-10 /
      data fpppp(25, 8, 4,1),fpppp(25, 8, 4,2),fpppp(25, 8, 4,3)/
     x 1.0558759d-06,-1.1796503d-07,-9.4447829d-10 /
      data fpppp(25, 8, 5,1),fpppp(25, 8, 5,2),fpppp(25, 8, 5,3)/
     x 6.9512467d-07,-1.2308575d-07,-5.0313297d-10 /
      data fpppp(25, 8, 6,1),fpppp(25, 8, 6,2),fpppp(25, 8, 6,3)/
     x 3.1986819d-07, 1.5950818d-08, 1.4142123d-10 /
      data fpppp(25, 8, 7,1),fpppp(25, 8, 7,2),fpppp(25, 8, 7,3)/
     x 1.4014880d-08,-6.3214653d-08, 4.6285398d-10 /
      data fpppp(25, 8, 8,1),fpppp(25, 8, 8,2),fpppp(25, 8, 8,3)/
     x-2.3227429d-07, 8.4671636d-08, 5.8722375d-10 /
      data fpppp(25, 8, 9,1),fpppp(25, 8, 9,2),fpppp(25, 8, 9,3)/
     x-6.3143330d-07,-8.8147309d-09, 2.4588862d-10 /
      data fpppp(25, 8,10,1),fpppp(25, 8,10,2),fpppp(25, 8,10,3)/
     x-9.7945825d-07, 3.2943118d-08, 2.9409597d-10 /
      data fpppp(25, 8,11,1),fpppp(25, 8,11,2),fpppp(25, 8,11,3)/
     x-1.2693936d-06, 3.6182626d-09, 1.7194014d-11 /
      data fpppp(25, 8,12,1),fpppp(25, 8,12,2),fpppp(25, 8,12,3)/
     x-1.3159497d-06, 1.0837311d-07, 5.0707345d-10 /
      data fpppp(25, 8,13,1),fpppp(25, 8,13,2),fpppp(25, 8,13,3)/
     x-1.2646715d-06, 8.3913886d-08, 1.0053711d-10 /
      data fpppp(25, 8,14,1),fpppp(25, 8,14,2),fpppp(25, 8,14,3)/
     x-9.6265789d-07, 1.7684637d-07, 3.3457872d-10 /
      data fpppp(25, 8,15,1),fpppp(25, 8,15,2),fpppp(25, 8,15,3)/
     x-6.0707275d-07, 1.1204190d-07, 2.6084206d-10 /
      data fpppp(25, 8,16,1),fpppp(25, 8,16,2),fpppp(25, 8,16,3)/
     x-2.1642834d-07, 1.6869729d-07, 5.0573835d-10 /
      data fpppp(25, 8,17,1),fpppp(25, 8,17,2),fpppp(25, 8,17,3)/
     x 9.2466736d-08, 5.6829861d-08, 2.4131364d-10 /
      data fpppp(25, 8,18,1),fpppp(25, 8,18,2),fpppp(25, 8,18,3)/
     x 3.5251444d-07,-2.8856150d-08,-2.6034416d-11 /
      data fpppp(25, 8,19,1),fpppp(25, 8,19,2),fpppp(25, 8,19,3)/
     x 6.7801621d-07,-1.2440353d-07,-5.5346368d-10 /
      data fpppp(25, 8,20,1),fpppp(25, 8,20,2),fpppp(25, 8,20,3)/
     x 1.0314232d-06,-2.1029904d-07,-7.9058542d-10 /
      data fpppp(25, 8,21,1),fpppp(25, 8,21,2),fpppp(25, 8,21,3)/
     x 1.0314232d-06,-2.1293177d-07,-8.1036893d-10 /
      data fpppp(25, 8,22,1),fpppp(25, 8,22,2),fpppp(25, 8,22,3)/
     x 6.7801621d-07,-1.1387261d-07,-4.7432967d-10 /
      data fpppp(25, 8,23,1),fpppp(25, 8,23,2),fpppp(25, 8,23,3)/
     x 3.5251444d-07,-6.8347071d-08,-3.2278695d-10 /
      data fpppp(25, 9, 1,1),fpppp(25, 9, 1,2),fpppp(25, 9, 1,3)/
     x 9.7757071d-08,-1.4496933d-08, 2.8406926d-10 /
      data fpppp(25, 9, 2,1),fpppp(25, 9, 2,2),fpppp(25, 9, 2,3)/
     x 3.5622313d-07,-3.6024580d-08, 8.3171040d-11 /
      data fpppp(25, 9, 3,1),fpppp(25, 9, 3,2),fpppp(25, 9, 3,3)/
     x 6.9334922d-07,-8.5153883d-08,-3.4387813d-10 /
      data fpppp(25, 9, 4,1),fpppp(25, 9, 4,2),fpppp(25, 9, 4,3)/
     x 6.9334922d-07,-7.9906279d-08,-3.4991040d-10 /
      data fpppp(25, 9, 5,1),fpppp(25, 9, 5,2),fpppp(25, 9, 5,3)/
     x 3.5622313d-07,-5.7014997d-08, 1.0730010d-10 /
      data fpppp(25, 9, 6,1),fpppp(25, 9, 6,2),fpppp(25, 9, 6,3)/
     x 9.7757071d-08, 6.4217132d-08, 1.9358527d-10 /
      data fpppp(25, 9, 7,1),fpppp(25, 9, 7,2),fpppp(25, 9, 7,3)/
     x-1.5833821d-07, 4.3958048d-08,-1.7044461d-11 /
      data fpppp(25, 9, 8,1),fpppp(25, 9, 8,2),fpppp(25, 9, 8,3)/
     x-4.0411005d-07, 1.4865266d-08, 2.9672739d-11 /
      data fpppp(25, 9, 9,1),fpppp(25, 9, 9,2),fpppp(25, 9, 9,3)/
     x-5.3768201d-07, 3.2605657d-09,-2.2369809d-11 /
      data fpppp(25, 9,10,1),fpppp(25, 9,10,2),fpppp(25, 9,10,3)/
     x-5.9374069d-07,-7.2284399d-08,-1.4414396d-10 /
      data fpppp(25, 9,11,1),fpppp(25, 9,11,2),fpppp(25, 9,11,3)/
     x-5.5727395d-07,-7.2489272d-09, 3.0028207d-10 /
      data fpppp(25, 9,12,1),fpppp(25, 9,12,2),fpppp(25, 9,12,3)/
     x-5.8335929d-07, 5.7361470d-09, 1.8579155d-10 /
      data fpppp(25, 9,13,1),fpppp(25, 9,13,2),fpppp(25, 9,13,3)/
     x-5.5819769d-07, 5.5192784d-09, 2.9369755d-10 /
      data fpppp(25, 9,14,1),fpppp(25, 9,14,2),fpppp(25, 9,14,3)/
     x-5.2098298d-07, 1.0654645d-07, 1.0133104d-10 /
      data fpppp(25, 9,15,1),fpppp(25, 9,15,2),fpppp(25, 9,15,3)/
     x-4.9936202d-07, 4.5440290d-08,-4.1870416d-11 /
      data fpppp(25, 9,16,1),fpppp(25, 9,16,2),fpppp(25, 9,16,3)/
     x-3.3939118d-07, 1.0193753d-07, 1.7728001d-11 /
      data fpppp(25, 9,17,1),fpppp(25, 9,17,2),fpppp(25, 9,17,3)/
     x-1.4112566d-07, 2.4492190d-08, 7.0177308d-11 /
      data fpppp(25, 9,18,1),fpppp(25, 9,18,2),fpppp(25, 9,18,3)/
     x 1.1820428d-07,-1.7820806d-08,-1.4209535d-10 /
      data fpppp(25, 9,19,1),fpppp(25, 9,19,2),fpppp(25, 9,19,3)/
     x 2.8410758d-07,-6.9298968d-08,-3.1292926d-10 /
      data fpppp(25, 9,20,1),fpppp(25, 9,20,2),fpppp(25, 9,20,3)/
     x 3.9008087d-07,-4.6475416d-08,-6.1130124d-11 /
      data fpppp(25, 9,21,1),fpppp(25, 9,21,2),fpppp(25, 9,21,3)/
     x 3.9008087d-07,-4.9424584d-08,-7.4817158d-11 /
      data fpppp(25, 9,22,1),fpppp(25, 9,22,2),fpppp(25, 9,22,3)/
     x 2.8410758d-07,-5.7502293d-08,-2.5818113d-10 /
      data fpppp(25, 9,23,1),fpppp(25, 9,23,2),fpppp(25, 9,23,3)/
     x 1.1820428d-07,-6.2058335d-08,-3.4740086d-10 /
      data fpppp(25,10, 1,1),fpppp(25,10, 1,2),fpppp(25,10, 1,3)/
     x-2.0793759d-07, 2.2164008d-07, 8.3313114d-12 /
      data fpppp(25,10, 2,1),fpppp(25,10, 2,2),fpppp(25,10, 2,3)/
     x-1.3191525d-07, 6.9799056d-08,-6.0308777d-11 /
      data fpppp(25,10, 3,1),fpppp(25,10, 3,2),fpppp(25,10, 3,3)/
     x-2.1435890d-07,-2.5230850d-07,-2.0300840d-10 /
      data fpppp(25,10, 4,1),fpppp(25,10, 4,2),fpppp(25,10, 4,3)/
     x-2.1435890d-07,-2.5802413d-07,-2.1068439d-10 /
      data fpppp(25,10, 5,1),fpppp(25,10, 5,2),fpppp(25,10, 5,3)/
     x-1.3191525d-07, 9.2661559d-08,-2.9604801d-11 /
      data fpppp(25,10, 6,1),fpppp(25,10, 6,2),fpppp(25,10, 6,3)/
     x-2.0793759d-07, 1.3590570d-07,-1.0680860d-10 /
      data fpppp(25,10, 7,1),fpppp(25,10, 7,2),fpppp(25,10, 7,3)/
     x-2.0862083d-07, 1.2806131d-07, 4.3304637d-10 /
      data fpppp(25,10, 8,1),fpppp(25,10, 8,2),fpppp(25,10, 8,3)/
     x-2.6596518d-07, 5.8111200d-08,-1.4575844d-10 /
      data fpppp(25,10, 9,1),fpppp(25,10, 9,2),fpppp(25,10, 9,3)/
     x-1.9602089d-07, 9.4144183d-09, 1.5243021d-11 /
      data fpppp(25,10,10,1),fpppp(25,10,10,2),fpppp(25,10,10,3)/
     x-2.6222739d-07,-4.1842086d-08, 1.1571396d-10 /
      data fpppp(25,10,11,1),fpppp(25,10,11,2),fpppp(25,10,11,3)/
     x-2.6369092d-07,-6.1939749d-08,-2.9110643d-12 /
      data fpppp(25,10,12,1),fpppp(25,10,12,2),fpppp(25,10,12,3)/
     x-2.3359985d-07,-3.2550505d-08, 1.7488133d-10 /
      data fpppp(25,10,13,1),fpppp(25,10,13,2),fpppp(25,10,13,3)/
     x-2.2466689d-07,-4.7891444d-09, 8.8777513d-11 /
      data fpppp(25,10,14,1),fpppp(25,10,14,2),fpppp(25,10,14,3)/
     x-2.1741953d-07,-3.1861341d-09,-6.1443109d-11 /
      data fpppp(25,10,15,1),fpppp(25,10,15,2),fpppp(25,10,15,3)/
     x-1.6367860d-07, 1.0617318d-07, 1.4869575d-10 /
      data fpppp(25,10,16,1),fpppp(25,10,16,2),fpppp(25,10,16,3)/
     x-2.3208463d-07, 3.1584229d-08,-6.3334700d-11 /
      data fpppp(25,10,17,1),fpppp(25,10,17,2),fpppp(25,10,17,3)/
     x-2.0323759d-07, 4.7876655d-08, 6.2658345d-11 /
      data fpppp(25,10,18,1),fpppp(25,10,18,2),fpppp(25,10,18,3)/
     x-2.0590520d-07,-6.2184758d-08,-9.7624738d-11 /
      data fpppp(25,10,19,1),fpppp(25,10,19,2),fpppp(25,10,19,3)/
     x-8.6440265d-08,-3.4439334d-08, 2.8661670d-11 /
      data fpppp(25,10,20,1),fpppp(25,10,20,2),fpppp(25,10,20,3)/
     x 1.8918424d-09, 1.0779553d-08,-1.6677727d-10 /
      data fpppp(25,10,21,1),fpppp(25,10,21,2),fpppp(25,10,21,3)/
     x 1.8918424d-09, 1.1094898d-08,-1.5645332d-10 /
      data fpppp(25,10,22,1),fpppp(25,10,22,2),fpppp(25,10,22,3)/
     x-8.6440265d-08,-3.5700716d-08,-1.2634137d-11 /
      data fpppp(25,10,23,1),fpppp(25,10,23,2),fpppp(25,10,23,3)/
     x-2.0590520d-07,-5.7454577d-08, 5.7234537d-11 /
      data fpppp(25,11, 1,1),fpppp(25,11, 1,2),fpppp(25,11, 1,3)/
     x-4.4284664d-08, 3.7798810d-07, 4.5455322d-11 /
      data fpppp(25,11, 2,1),fpppp(25,11, 2,2),fpppp(25,11, 2,3)/
     x-9.9910171d-08, 1.1757360d-07,-8.7635580d-11 /
      data fpppp(25,11, 3,1),fpppp(25,11, 3,2),fpppp(25,11, 3,3)/
     x 7.0087848d-08,-4.3705821d-07,-3.8413950d-10 /
      data fpppp(25,11, 4,1),fpppp(25,11, 4,2),fpppp(25,11, 4,3)/
     x 7.0087848d-08,-4.4300691d-07,-3.6434852d-10 /
      data fpppp(25,11, 5,1),fpppp(25,11, 5,2),fpppp(25,11, 5,3)/
     x-9.9910171d-08, 1.4136839d-07,-1.6679950d-10 /
      data fpppp(25,11, 6,1),fpppp(25,11, 6,2),fpppp(25,11, 6,3)/
     x-4.4284664d-08, 2.8875764d-07, 3.4232002d-10 /
      data fpppp(25,11, 7,1),fpppp(25,11, 7,2),fpppp(25,11, 7,3)/
     x-6.7490960d-08, 2.1337619d-07,-1.7190600d-10 /
      data fpppp(25,11, 8,1),fpppp(25,11, 8,2),fpppp(25,11, 8,3)/
     x 2.3016503d-07, 1.1988855d-07, 3.9175001d-10 /
      data fpppp(25,11, 9,1),fpppp(25,11, 9,2),fpppp(25,11, 9,3)/
     x-6.3606216d-08,-2.9841790d-08, 1.4460670d-10 /
      data fpppp(25,11,10,1),fpppp(25,11,10,2),fpppp(25,11,10,3)/
     x-8.3210314d-09, 3.3675614d-08, 1.9006319d-10 /
      data fpppp(25,11,11,1),fpppp(25,11,11,2),fpppp(25,11,11,3)/
     x-1.3690249d-07,-8.3891415d-08, 1.3052868d-11 /
      data fpppp(25,11,12,1),fpppp(25,11,12,2),fpppp(25,11,12,3)/
     x-1.5401782d-07,-7.1736719d-08,-8.0854700d-11 /
      data fpppp(25,11,13,1),fpppp(25,11,13,2),fpppp(25,11,13,3)/
     x-1.2620650d-07,-3.2697345d-08,-2.0834704d-10 /
      data fpppp(25,11,14,1),fpppp(25,11,14,2),fpppp(25,11,14,3)/
     x-1.0355317d-07,-4.1467275d-08, 9.8136967d-11 /
      data fpppp(25,11,15,1),fpppp(25,11,15,2),fpppp(25,11,15,3)/
     x-1.0259533d-07, 4.7385100d-08,-8.8155407d-11 /
      data fpppp(25,11,16,1),fpppp(25,11,16,2),fpppp(25,11,16,3)/
     x-2.9370863d-08, 8.9892045d-08, 2.2288657d-10 /
      data fpppp(25,11,17,1),fpppp(25,11,17,2),fpppp(25,11,17,3)/
     x-4.3286624d-08, 1.6304364d-08,-1.4670947d-11 /
      data fpppp(25,11,18,1),fpppp(25,11,18,2),fpppp(25,11,18,3)/
     x 2.0410854d-08,-2.7637364d-09, 4.0075956d-10 /
      data fpppp(25,11,19,1),fpppp(25,11,19,2),fpppp(25,11,19,3)/
     x-4.6448923d-09,-5.3412533d-08, 5.9481799d-11 /
      data fpppp(25,11,20,1),fpppp(25,11,20,2),fpppp(25,11,20,3)/
     x-5.4674700d-09, 1.9352723d-08,-3.8472290d-10 /
      data fpppp(25,11,21,1),fpppp(25,11,21,2),fpppp(25,11,21,3)/
     x-5.4674700d-09, 1.5336620d-08,-3.9108281d-10 /
      data fpppp(25,11,22,1),fpppp(25,11,22,2),fpppp(25,11,22,3)/
     x-4.6448923d-09,-3.7348119d-08, 8.4921464d-11 /
      data fpppp(25,11,23,1),fpppp(25,11,23,2),fpppp(25,11,23,3)/
     x 2.0410854d-08,-6.3005291d-08, 3.0536082d-10 /
      data fpppp(25,12, 1,1),fpppp(25,12, 1,2),fpppp(25,12, 1,3)/
     x 1.3070189d-07, 6.6643120d-07,-6.4396591d-10 /
      data fpppp(25,12, 2,1),fpppp(25,12, 2,2),fpppp(25,12, 2,3)/
     x 2.0755157d-09, 2.4407972d-07,-3.6152229d-10 /
      data fpppp(25,12, 3,1),fpppp(25,12, 3,2),fpppp(25,12, 3,3)/
     x-4.4646321d-07,-6.4471359d-07, 2.4287327d-10 /
      data fpppp(25,12, 4,1),fpppp(25,12, 4,2),fpppp(25,12, 4,3)/
     x-4.4646321d-07,-6.7314333d-07, 2.4434458d-10 /
      data fpppp(25,12, 5,1),fpppp(25,12, 5,2),fpppp(25,12, 5,3)/
     x 2.0755157d-09, 3.5779870d-07,-3.6740752d-10 /
      data fpppp(25,12, 6,1),fpppp(25,12, 6,2),fpppp(25,12, 6,3)/
     x 1.3070189d-07, 2.3998502d-07,-6.2189629d-10 /
      data fpppp(25,12, 7,1),fpppp(25,12, 7,2),fpppp(25,12, 7,3)/
     x 1.9529308d-07, 6.3344258d-07, 1.9648724d-10 /
      data fpppp(25,12, 8,1),fpppp(25,12, 8,2),fpppp(25,12, 8,3)/
     x-3.3564982d-07,-3.2446166d-07,-2.9455280d-11 /
      data fpppp(25,12, 9,1),fpppp(25,12, 9,2),fpppp(25,12, 9,3)/
     x 4.2896306d-08, 2.9172952d-07, 3.7727525d-10 /
      data fpppp(25,12,10,1),fpppp(25,12,10,2),fpppp(25,12,10,3)/
     x-1.2383367d-07,-1.1319035d-07,-3.1533400d-11 /
      data fpppp(25,12,11,1),fpppp(25,12,11,2),fpppp(25,12,11,3)/
     x-2.3686598d-08, 1.9017485d-08, 2.8202123d-10 /
      data fpppp(25,12,12,1),fpppp(25,12,12,2),fpppp(25,12,12,3)/
     x-1.0713403d-07,-9.4156927d-08,-2.2118243d-10 /
      data fpppp(25,12,13,1),fpppp(25,12,13,2),fpppp(25,12,13,3)/
     x-1.6429248d-07,-6.7692640d-08, 9.2168574d-11 /
      data fpppp(25,12,14,1),fpppp(25,12,14,2),fpppp(25,12,14,3)/
     x-2.0420454d-07,-7.3237226d-08,-2.3161655d-10 /
      data fpppp(25,12,15,1),fpppp(25,12,15,2),fpppp(25,12,15,3)/
     x-1.2856061d-07, 4.4906913d-08, 9.8415118d-11 /
      data fpppp(25,12,16,1),fpppp(25,12,16,2),fpppp(25,12,16,3)/
     x-8.0717800d-08, 5.5567555d-08,-1.4565674d-10 /
      data fpppp(25,12,17,1),fpppp(25,12,17,2),fpppp(25,12,17,3)/
     x-9.9815730d-09, 7.0536962d-08, 2.5131682d-10 /
      data fpppp(25,12,18,1),fpppp(25,12,18,2),fpppp(25,12,18,3)/
     x-4.3154009d-08,-1.8900330d-08, 3.0866161d-11 /
      data fpppp(25,12,19,1),fpppp(25,12,19,2),fpppp(25,12,19,3)/
     x-1.1526095d-08,-2.4040162d-08, 1.7300112d-10 /
      data fpppp(25,12,20,1),fpppp(25,12,20,2),fpppp(25,12,20,3)/
     x 4.6339143d-08, 2.1384015d-09,-1.4897077d-10 /
      data fpppp(25,12,21,1),fpppp(25,12,21,2),fpppp(25,12,21,3)/
     x 4.6339143d-08, 1.3145172d-09,-1.3509156d-10 /
      data fpppp(25,12,22,1),fpppp(25,12,22,2),fpppp(25,12,22,3)/
     x-1.1526095d-08,-2.0744625d-08, 1.1748432d-10 /
      data fpppp(25,12,23,1),fpppp(25,12,23,2),fpppp(25,12,23,3)/
     x-4.3154009d-08,-3.1258594d-08, 2.3905418d-10 /
      data fpppp(25,13, 1,1),fpppp(25,13, 1,2),fpppp(25,13, 1,3)/
     x 2.0669992d-07, 5.4479616d-07,-7.8084419d-10 /
      data fpppp(25,13, 2,1),fpppp(25,13, 2,2),fpppp(25,13, 2,3)/
     x 9.9536024d-08, 1.6923475d-07,-3.0377026d-10 /
      data fpppp(25,13, 3,1),fpppp(25,13, 3,2),fpppp(25,13, 3,3)/
     x 5.5170873d-08,-6.2811359d-07, 7.1387895d-10 /
      data fpppp(25,13, 4,1),fpppp(25,13, 4,2),fpppp(25,13, 4,3)/
     x 5.5170873d-08,-6.4110929d-07, 7.2202007d-10 /
      data fpppp(25,13, 5,1),fpppp(25,13, 5,2),fpppp(25,13, 5,3)/
     x 9.9536024d-08, 2.2121756d-07,-3.3633475d-10 /
      data fpppp(25,13, 6,1),fpppp(25,13, 6,2),fpppp(25,13, 6,3)/
     x 2.0669992d-07, 3.4986062d-07,-6.5872737d-10 /
      data fpppp(25,13, 7,1),fpppp(25,13, 7,2),fpppp(25,13, 7,3)/
     x 2.0777021d-07, 3.3086146d-07,-7.4530857d-10 /
      data fpppp(25,13, 8,1),fpppp(25,13, 8,2),fpppp(25,13, 8,3)/
     x 4.7039930d-07, 1.6341462d-07, 1.7512606d-10 /
      data fpppp(25,13, 9,1),fpppp(25,13, 9,2),fpppp(25,13, 9,3)/
     x 8.8303394d-08, 8.8462179d-09,-7.8661893d-11 /
      data fpppp(25,13,10,1),fpppp(25,13,10,2),fpppp(25,13,10,3)/
     x 3.1856907d-07, 5.8492189d-09, 3.8683215d-10 /
      data fpppp(25,13,11,1),fpppp(25,13,11,2),fpppp(25,13,11,3)/
     x-3.1594339d-08,-3.4028666d-08,-1.9923059d-10 /
      data fpppp(25,13,12,1),fpppp(25,13,12,2),fpppp(25,13,12,3)/
     x-4.8621363d-08,-4.8437938d-08, 3.4719382d-10 /
      data fpppp(25,13,13,1),fpppp(25,13,13,2),fpppp(25,13,13,3)/
     x-6.6266605d-08,-6.9825345d-08,-4.2867213d-10 /
      data fpppp(25,13,14,1),fpppp(25,13,14,2),fpppp(25,13,14,3)/
     x 8.5187653d-08,-7.1669628d-08, 7.2009930d-10 /
      data fpppp(25,13,15,1),fpppp(25,13,15,2),fpppp(25,13,15,3)/
     x-3.4071712d-08, 4.6030741d-08,-3.2424050d-10 /
      data fpppp(25,13,16,1),fpppp(25,13,16,2),fpppp(25,13,16,3)/
     x-4.8886767d-08, 3.9003965d-08, 1.8291207d-10 /
      data fpppp(25,13,17,1),fpppp(25,13,17,2),fpppp(25,13,17,3)/
     x-8.0349139d-08, 3.7910052d-08,-2.6454757d-10 /
      data fpppp(25,13,18,1),fpppp(25,13,18,2),fpppp(25,13,18,3)/
     x-5.4106594d-08, 1.4323716d-08,-1.1590889d-11 /
      data fpppp(25,13,19,1),fpppp(25,13,19,2),fpppp(25,13,19,3)/
     x-7.9365076d-08, 1.3696311d-08, 7.1931699d-11 /
      data fpppp(25,13,20,1),fpppp(25,13,20,2),fpppp(25,13,20,3)/
     x-1.6928538d-07,-3.3372328d-08, 5.4300675d-11 /
      data fpppp(25,13,21,1),fpppp(25,13,21,2),fpppp(25,13,21,3)/
     x-1.6928538d-07,-3.2359450d-08, 5.8655916d-11 /
      data fpppp(25,13,22,1),fpppp(25,13,22,2),fpppp(25,13,22,3)/
     x-7.9365076d-08, 9.6447996d-09, 5.4510737d-11 /
      data fpppp(25,13,23,1),fpppp(25,13,23,2),fpppp(25,13,23,3)/
     x-5.4106594d-08, 2.9516884d-08, 5.3737718d-11 /
      data fpppp(25,14, 1,1),fpppp(25,14, 1,2),fpppp(25,14, 1,3)/
     x 1.0303976d-07, 3.8409026d-07,-3.7843494d-10 /
      data fpppp(25,14, 2,1),fpppp(25,14, 2,2),fpppp(25,14, 2,3)/
     x 4.8164557d-08, 9.0288504d-08,-9.1841425d-11 /
      data fpppp(25,14, 3,1),fpppp(25,14, 3,2),fpppp(25,14, 3,3)/
     x 8.3588426d-08,-5.3445599d-07, 5.2116759d-10 /
      data fpppp(25,14, 4,1),fpppp(25,14, 4,2),fpppp(25,14, 4,3)/
     x 8.3588426d-08,-5.4290970d-07, 5.2312749d-10 /
      data fpppp(25,14, 5,1),fpppp(25,14, 5,2),fpppp(25,14, 5,3)/
     x 4.8164557d-08, 1.2410336d-07,-9.9680994d-11 /
      data fpppp(25,14, 6,1),fpppp(25,14, 6,2),fpppp(25,14, 6,3)/
     x 1.0303976d-07, 2.5728454d-07,-3.4903656d-10 /
      data fpppp(25,14, 7,1),fpppp(25,14, 7,2),fpppp(25,14, 7,3)/
     x 1.5713252d-07, 3.0942806d-07,-4.1945619d-10 /
      data fpppp(25,14, 8,1),fpppp(25,14, 8,2),fpppp(25,14, 8,3)/
     x 8.0995269d-08, 4.9622799d-08,-4.4839367d-10 /
      data fpppp(25,14, 9,1),fpppp(25,14, 9,2),fpppp(25,14, 9,3)/
     x 1.6977970d-07, 3.4699834d-07, 9.0954485d-11 /
      data fpppp(25,14,10,1),fpppp(25,14,10,2),fpppp(25,14,10,3)/
     x-2.9547019d-07,-4.0744888d-07,-1.9277915d-10 /
      data fpppp(25,14,11,1),fpppp(25,14,11,2),fpppp(25,14,11,3)/
     x 1.1288191d-07, 2.4000312d-07, 4.6925474d-10 /
      data fpppp(25,14,12,1),fpppp(25,14,12,2),fpppp(25,14,12,3)/
     x 7.2560317d-08,-7.8415690d-08,-5.0802330d-10 /
      data fpppp(25,14,13,1),fpppp(25,14,13,2),fpppp(25,14,13,3)/
     x 3.6865856d-08,-6.7805791d-08, 2.2698881d-09 /
      data fpppp(25,14,14,1),fpppp(25,14,14,2),fpppp(25,14,14,3)/
     x-6.5447265d-07, 2.6986030d-08,-3.0178231d-09 /
      data fpppp(25,14,15,1),fpppp(25,14,15,2),fpppp(25,14,15,3)/
     x-8.6360758d-08,-5.3198056d-08, 2.0273483d-09 /
      data fpppp(25,14,16,1),fpppp(25,14,16,2),fpppp(25,14,16,3)/
     x-1.5932587d-07, 7.5661950d-08,-6.5215464d-10 /
      data fpppp(25,14,17,1),fpppp(25,14,17,2),fpppp(25,14,17,3)/
     x-7.6734413d-08, 4.6101814d-09, 2.4272447d-10 /
      data fpppp(25,14,18,1),fpppp(25,14,18,2),fpppp(25,14,18,3)/
     x-9.6481692d-08, 2.1590294d-08,-1.8174354d-10 /
      data fpppp(25,14,19,1),fpppp(25,14,19,2),fpppp(25,14,19,3)/
     x-1.2855368d-07, 2.4071583d-09,-1.8761520d-10 /
      data fpppp(25,14,20,1),fpppp(25,14,20,2),fpppp(25,14,20,3)/
     x-1.0818786d-07,-2.6795249d-08, 1.1655812d-10 /
      data fpppp(25,14,21,1),fpppp(25,14,21,2),fpppp(25,14,21,3)/
     x-1.0818786d-07,-2.7058952d-08, 1.0954138d-10 /
      data fpppp(25,14,22,1),fpppp(25,14,22,2),fpppp(25,14,22,3)/
     x-1.2855368d-07, 3.4619709d-09,-1.5954826d-10 /
      data fpppp(25,14,23,1),fpppp(25,14,23,2),fpppp(25,14,23,3)/
     x-9.6481692d-08, 1.7634747d-08,-2.8699456d-10 /
      data fpppp(25,15, 1,1),fpppp(25,15, 1,2),fpppp(25,15, 1,3)/
     x-2.1236708d-07, 3.3508434d-07, 3.7843623d-10 /
      data fpppp(25,15, 2,1),fpppp(25,15, 2,2),fpppp(25,15, 2,3)/
     x-4.2980144d-07, 8.7961437d-08, 2.1343139d-10 /
      data fpppp(25,15, 3,1),fpppp(25,15, 3,2),fpppp(25,15, 3,3)/
     x-6.4501012d-07,-4.3275436d-07,-1.3158332d-10 /
      data fpppp(25,15, 4,1),fpppp(25,15, 4,2),fpppp(25,15, 4,3)/
     x-6.4501012d-07,-4.4821258d-07,-1.4657574d-10 /
      data fpppp(25,15, 5,1),fpppp(25,15, 5,2),fpppp(25,15, 5,3)/
     x-4.2980144d-07, 1.4979431d-07, 2.7340107d-10 /
      data fpppp(25,15, 6,1),fpppp(25,15, 6,2),fpppp(25,15, 6,3)/
     x-2.1236708d-07, 1.0321105d-07, 1.5354992d-10 /
      data fpppp(25,15, 7,1),fpppp(25,15, 7,2),fpppp(25,15, 7,3)/
     x-1.0187055d-07, 1.9501798d-07, 5.0085698d-11 /
      data fpppp(25,15, 8,1),fpppp(25,15, 8,2),fpppp(25,15, 8,3)/
     x-3.5822966d-09, 9.7665597d-08,-3.0803708d-10 /
      data fpppp(25,15, 9,1),fpppp(25,15, 9,2),fpppp(25,15, 9,3)/
     x 3.6500597d-08, 8.7545022d-08,-2.8616551d-10 /
      data fpppp(25,15,10,1),fpppp(25,15,10,2),fpppp(25,15,10,3)/
     x 3.3077259d-07, 5.8253562d-08, 1.5480802d-10 /
      data fpppp(25,15,11,1),fpppp(25,15,11,2),fpppp(25,15,11,3)/
     x 4.2801371d-08,-7.2626176d-08,-3.9887316d-10 /
      data fpppp(25,15,12,1),fpppp(25,15,12,2),fpppp(25,15,12,3)/
     x 5.9088755d-08, 2.0195060d-07, 1.1187150d-09 /
      data fpppp(25,15,13,1),fpppp(25,15,13,2),fpppp(25,15,13,3)/
     x 4.9017676d-08,-7.2896948d-07,-3.3450582d-09 /
      data fpppp(25,15,14,1),fpppp(25,15,14,2),fpppp(25,15,14,3)/
     x 1.1114905d-06, 1.0870979d-06, 5.4540880d-09 /
      data fpppp(25,15,15,1),fpppp(25,15,15,2),fpppp(25,15,15,3)/
     x 7.2317666d-08,-6.6962625d-07,-3.1825553d-09 /
      data fpppp(25,15,16,1),fpppp(25,15,16,2),fpppp(25,15,16,3)/
     x 4.5518697d-07, 1.8183977d-07, 1.0724224d-09 /
      data fpppp(25,15,17,1),fpppp(25,15,17,2),fpppp(25,15,17,3)/
     x 4.6423039d-09,-1.7404667d-08,-2.5581110d-10 /
      data fpppp(25,15,18,1),fpppp(25,15,18,2),fpppp(25,15,18,3)/
     x-6.0009538d-09, 2.4483342d-09,-7.0307707d-11 /
      data fpppp(25,15,19,1),fpppp(25,15,19,2),fpppp(25,15,19,3)/
     x 2.0578854d-08, 2.1890353d-08,-1.3651914d-10 /
      data fpppp(25,15,20,1),fpppp(25,15,20,2),fpppp(25,15,20,3)/
     x-2.0625811d-09,-2.1030891d-08,-5.1467437d-11 /
      data fpppp(25,15,21,1),fpppp(25,15,21,2),fpppp(25,15,21,3)/
     x-2.0625811d-09,-1.9157223d-08,-5.6494442d-11 /
      data fpppp(25,15,22,1),fpppp(25,15,22,2),fpppp(25,15,22,3)/
     x 2.0578854d-08, 1.4395683d-08,-1.1641112d-10 /
      data fpppp(25,15,23,1),fpppp(25,15,23,2),fpppp(25,15,23,3)/
     x-6.0009538d-09, 3.0553350d-08,-1.4571277d-10 /
      data fpppp(25,16, 1,1),fpppp(25,16, 1,2),fpppp(25,16, 1,3)/
     x-3.4136000d-07, 2.0825433d-07, 4.5707144d-10 /
      data fpppp(25,16, 2,1),fpppp(25,16, 2,2),fpppp(25,16, 2,3)/
     x-6.6935644d-08, 6.2765054d-08, 1.9335300d-10 /
      data fpppp(25,16, 3,1),fpppp(25,16, 3,2),fpppp(25,16, 3,3)/
     x 3.1756662d-08,-2.3828169d-07,-3.6816426d-10 /
      data fpppp(25,16, 4,1),fpppp(25,16, 4,2),fpppp(25,16, 4,3)/
     x 3.1756662d-08,-2.5703468d-07,-3.7445320d-10 /
      data fpppp(25,16, 5,1),fpppp(25,16, 5,2),fpppp(25,16, 5,3)/
     x-6.6935644d-08, 1.3777701d-07, 2.1850876d-10 /
      data fpppp(25,16, 6,1),fpppp(25,16, 6,2),fpppp(25,16, 6,3)/
     x-3.4136000d-07,-7.3040496d-08, 3.6273734d-10 /
      data fpppp(25,16, 7,1),fpppp(25,16, 7,2),fpppp(25,16, 7,3)/
     x-3.1042218d-07, 8.3856756d-08, 9.5079538d-11 /
      data fpppp(25,16, 8,1),fpppp(25,16, 8,2),fpppp(25,16, 8,3)/
     x-1.9356053d-07, 6.1751763d-08, 1.0877702d-10 /
      data fpppp(25,16, 9,1),fpppp(25,16, 9,2),fpppp(25,16, 9,3)/
     x-1.0703938d-07, 6.2429108d-08,-9.5198630d-11 /
      data fpppp(25,16,10,1),fpppp(25,16,10,2),fpppp(25,16,10,3)/
     x-1.1393462d-07, 3.9868685d-08,-3.7906324d-10 /
      data fpppp(25,16,11,1),fpppp(25,16,11,2),fpppp(25,16,11,3)/
     x 3.3961738d-08, 1.6177168d-08, 2.8558531d-10 /
      data fpppp(25,16,12,1),fpppp(25,16,12,2),fpppp(25,16,12,3)/
     x 5.2753694d-08,-7.0051212d-11,-6.5161604d-10 /
      data fpppp(25,16,13,1),fpppp(25,16,13,2),fpppp(25,16,13,3)/
     x 6.5333241d-08, 3.0962838d-08, 2.2901144d-09 /
      data fpppp(25,16,14,1),fpppp(25,16,14,2),fpppp(25,16,14,3)/
     x-6.0280934d-07,-1.0097777d-07,-3.3928297d-09 /
      data fpppp(25,16,15,1),fpppp(25,16,15,2),fpppp(25,16,15,3)/
     x 4.5157175d-08, 4.5457631d-07, 2.1803054d-09 /
      data fpppp(25,16,16,1),fpppp(25,16,16,2),fpppp(25,16,16,3)/
     x-6.4713239d-07,-7.1948226d-07,-4.3296408d-10 /
      data fpppp(25,16,17,1),fpppp(25,16,17,2),fpppp(25,16,17,3)/
     x 6.8010317d-08, 4.7928212d-07, 8.4804574d-11 /
      data fpppp(25,16,18,1),fpppp(25,16,18,2),fpppp(25,16,18,3)/
     x 8.9241791d-08,-1.2064465d-07, 4.1265097d-11 /
      data fpppp(25,16,19,1),fpppp(25,16,19,2),fpppp(25,16,19,3)/
     x 7.3863770d-08, 3.8434071d-08,-1.2375581d-10 /
      data fpppp(25,16,20,1),fpppp(25,16,20,2),fpppp(25,16,20,3)/
     x 9.2842722d-08,-9.6477946d-09,-1.9188827d-11 /
      data fpppp(25,16,21,1),fpppp(25,16,21,2),fpppp(25,16,21,3)/
     x 9.2842722d-08,-1.0314849d-09,-2.9338455d-11 /
      data fpppp(25,16,22,1),fpppp(25,16,22,2),fpppp(25,16,22,3)/
     x 7.3863770d-08, 3.9688319d-09,-8.3157297d-11 /
      data fpppp(25,16,23,1),fpppp(25,16,23,2),fpppp(25,16,23,3)/
     x 8.9241791d-08, 8.5999956d-09,-1.1097932d-10 /
      data fpppp(25,17, 1,1),fpppp(25,17, 1,2),fpppp(25,17, 1,3)/
     x-1.4119999d-07,-2.3972869d-08,-8.7452796d-11 /
      data fpppp(25,17, 2,1),fpppp(25,17, 2,2),fpppp(25,17, 2,3)/
     x-2.3009328d-07,-4.1699513d-08,-9.5381758d-11 /
      data fpppp(25,17, 3,1),fpppp(25,17, 3,2),fpppp(25,17, 3,3)/
     x-7.8601342d-08,-8.1656394d-08,-1.2087533d-10 /
      data fpppp(25,17, 4,1),fpppp(25,17, 4,2),fpppp(25,17, 4,3)/
     x-7.8601342d-08,-7.8206765d-08,-1.0599519d-10 /
      data fpppp(25,17, 5,1),fpppp(25,17, 5,2),fpppp(25,17, 5,3)/
     x-2.3009328d-07,-5.5498031d-08,-1.5490234d-10 /
      data fpppp(25,17, 6,1),fpppp(25,17, 6,2),fpppp(25,17, 6,3)/
     x-1.4119999d-07, 2.7771573d-08, 1.3574937d-10 /
      data fpppp(25,17, 7,1),fpppp(25,17, 7,2),fpppp(25,17, 7,3)/
     x-2.0862179d-07, 3.8946441d-09, 2.5606779d-10 /
      data fpppp(25,17, 8,1),fpppp(25,17, 8,2),fpppp(25,17, 8,3)/
     x-2.3375670d-07,-2.2482340d-09, 6.6793811d-11 /
      data fpppp(25,17, 9,1),fpppp(25,17, 9,2),fpppp(25,17, 9,3)/
     x-1.7550636d-07, 2.2276647d-08,-7.4970832d-11 /
      data fpppp(25,17,10,1),fpppp(25,17,10,2),fpppp(25,17,10,3)/
     x-7.2939352d-08, 3.4556340d-08, 1.7530356d-10 /
      data fpppp(25,17,11,1),fpppp(25,17,11,2),fpppp(25,17,11,3)/
     x-5.9100549d-08, 1.5921939d-08,-2.9697172d-10 /
      data fpppp(25,17,12,1),fpppp(25,17,12,2),fpppp(25,17,12,3)/
     x 1.9537771d-08,-6.2884522d-09, 1.6790510d-10 /
      data fpppp(25,17,13,1),fpppp(25,17,13,2),fpppp(25,17,13,3)/
     x 8.9173051d-08, 3.6533584d-08,-6.2251981d-10 /
      data fpppp(25,17,14,1),fpppp(25,17,14,2),fpppp(25,17,14,3)/
     x 2.7078917d-07,-5.7731259d-09, 9.0555550d-10 /
      data fpppp(25,17,15,1),fpppp(25,17,15,2),fpppp(25,17,15,3)/
     x 1.1143255d-07, 2.1837132d-08,-6.0484474d-10 /
      data fpppp(25,17,16,1),fpppp(25,17,16,2),fpppp(25,17,16,3)/
     x 5.5264585d-07,-1.4729859d-08, 1.5823735d-11 /
      data fpppp(25,17,17,1),fpppp(25,17,17,2),fpppp(25,17,17,3)/
     x 1.2467408d-07, 3.5742938d-08, 7.7212292d-11 /
      data fpppp(25,17,18,1),fpppp(25,17,18,2),fpppp(25,17,18,3)/
     x 1.0768608d-07,-1.3667943d-08,-9.3620411d-11 /
      data fpppp(25,17,19,1),fpppp(25,17,19,2),fpppp(25,17,19,3)/
     x 1.3770853d-07, 1.2720544d-08, 1.0639381d-10 /
      data fpppp(25,17,20,1),fpppp(25,17,20,2),fpppp(25,17,20,3)/
     x 1.4211182d-07, 3.2820628d-09, 6.7684739d-11 /
      data fpppp(25,17,21,1),fpppp(25,17,21,2),fpppp(25,17,21,3)/
     x 1.4211182d-07, 4.7437611d-09, 7.8036565d-11 /
      data fpppp(25,17,22,1),fpppp(25,17,22,2),fpppp(25,17,22,3)/
     x 1.3770853d-07, 6.8737506d-09, 6.4986509d-11 /
      data fpppp(25,17,23,1),fpppp(25,17,23,2),fpppp(25,17,23,3)/
     x 1.0768608d-07, 8.2575319d-09, 6.1656969d-11 /
      data fpppp(25,18, 1,1),fpppp(25,18, 1,2),fpppp(25,18, 1,3)/
     x-7.2536697d-09, 5.1057512d-09, 1.6942872d-10 /
      data fpppp(25,18, 2,1),fpppp(25,18, 2,2),fpppp(25,18, 2,3)/
     x 8.7374363d-08,-5.5992243d-09, 8.4796098d-11 /
      data fpppp(25,18, 3,1),fpppp(25,18, 3,2),fpppp(25,18, 3,3)/
     x 1.1720804d-07,-2.7581844d-08,-9.1511632d-11 /
      data fpppp(25,18, 4,1),fpppp(25,18, 4,2),fpppp(25,18, 4,3)/
     x 1.1720804d-07,-2.9255917d-08,-1.0034542d-10 /
      data fpppp(25,18, 5,1),fpppp(25,18, 5,2),fpppp(25,18, 5,3)/
     x 8.7374363d-08, 1.0970667d-09, 1.2013126d-10 /
      data fpppp(25,18, 6,1),fpppp(25,18, 6,2),fpppp(25,18, 6,3)/
     x-7.2536697d-09,-2.0005340d-08, 3.6921858d-11 /
      data fpppp(25,18, 7,1),fpppp(25,18, 7,2),fpppp(25,18, 7,3)/
     x-3.7473861d-08, 1.2927967d-08, 7.0991897d-11 /
      data fpppp(25,18, 8,1),fpppp(25,18, 8,2),fpppp(25,18, 8,3)/
     x-6.5721898d-08,-1.6597439d-08, 4.0020747d-11 /
      data fpppp(25,18, 9,1),fpppp(25,18, 9,2),fpppp(25,18, 9,3)/
     x-8.4593528d-08, 7.1025189d-09, 6.0847344d-11 /
      data fpppp(25,18,10,1),fpppp(25,18,10,2),fpppp(25,18,10,3)/
     x-8.8076179d-08,-2.1080902d-08,-1.2118557d-10 /
      data fpppp(25,18,11,1),fpppp(25,18,11,2),fpppp(25,18,11,3)/
     x-3.4254677d-08, 4.9170913d-08, 7.2674436d-11 /
      data fpppp(25,18,12,1),fpppp(25,18,12,2),fpppp(25,18,12,3)/
     x-3.2408813d-08,-1.8080741d-08,-1.4246126d-10 /
      data fpppp(25,18,13,1),fpppp(25,18,13,2),fpppp(25,18,13,3)/
     x-1.7647531d-08, 1.5865255d-09, 7.9419492d-11 /
      data fpppp(25,18,14,1),fpppp(25,18,14,2),fpppp(25,18,14,3)/
     x-2.2265197d-08, 4.8988991d-09,-3.4475424d-10 /
      data fpppp(25,18,15,1),fpppp(25,18,15,2),fpppp(25,18,15,3)/
     x 6.6950583d-08, 1.3797789d-08, 1.0106679d-10 /
      data fpppp(25,18,16,1),fpppp(25,18,16,2),fpppp(25,18,16,3)/
     x 1.9406251d-08, 1.0193332d-09,-4.2941564d-11 /
      data fpppp(25,18,17,1),fpppp(25,18,17,2),fpppp(25,18,17,3)/
     x 1.2136295d-07, 3.7097382d-09,-4.5204104d-11 /
      data fpppp(25,18,18,1),fpppp(25,18,18,2),fpppp(25,18,18,3)/
     x 1.5553960d-07, 1.8531864d-08, 7.2028696d-11 /
      data fpppp(25,18,19,1),fpppp(25,18,19,2),fpppp(25,18,19,3)/
     x 1.5714193d-07,-6.5333422d-09, 3.4482333d-11 /
      data fpppp(25,18,20,1),fpppp(25,18,20,2),fpppp(25,18,20,3)/
     x 1.6990459d-07, 8.1908838d-09, 1.0443067d-10 /
      data fpppp(25,18,21,1),fpppp(25,18,21,2),fpppp(25,18,21,3)/
     x 1.6990459d-07, 6.6749101d-09, 1.0109892d-10 /
      data fpppp(25,18,22,1),fpppp(25,18,22,2),fpppp(25,18,22,3)/
     x 1.5714193d-07,-4.6944756d-10, 4.7809343d-11 /
      data fpppp(25,18,23,1),fpppp(25,18,23,2),fpppp(25,18,23,3)/
     x 1.5553960d-07,-4.2077408d-09, 2.2052408d-11 /
      data fpppp(25,19, 1,1),fpppp(25,19, 1,2),fpppp(25,19, 1,3)/
     x 1.4561085d-07, 1.0315852d-21, 1.9733716d-10 /
      data fpppp(25,19, 2,1),fpppp(25,19, 2,2),fpppp(25,19, 2,3)/
     x 2.6752050d-07,-1.0575990d-21, 1.3099892d-10 /
      data fpppp(25,19, 3,1),fpppp(25,19, 3,2),fpppp(25,19, 3,3)/
     x 2.2554102d-07, 1.9165575d-22, 1.1641971d-13 /
      data fpppp(25,19, 4,1),fpppp(25,19, 4,2),fpppp(25,19, 4,3)/
     x 2.2554102d-07, 1.7291538d-21,-1.9607586d-11 /
      data fpppp(25,19, 5,1),fpppp(25,19, 5,2),fpppp(25,19, 5,3)/
     x 2.6752050d-07,-2.0720050d-21, 2.0989494d-10 /
      data fpppp(25,19, 6,1),fpppp(25,19, 6,2),fpppp(25,19, 6,3)/
     x 1.4561085d-07,-1.4705393d-21,-9.8522929d-11 /
      data fpppp(25,19, 7,1),fpppp(25,19, 7,2),fpppp(25,19, 7,3)/
     x 1.1386048d-07, 2.0040402d-21,-1.5208524d-11 /
      data fpppp(25,19, 8,1),fpppp(25,19, 8,2),fpppp(25,19, 8,3)/
     x 4.2818342d-08,-3.1828810d-21, 8.9019278d-12 /
      data fpppp(25,19, 9,1),fpppp(25,19, 9,2),fpppp(25,19, 9,3)/
     x-3.9217786d-08,-4.2111634d-22, 1.6363970d-10 /
      data fpppp(25,19,10,1),fpppp(25,19,10,2),fpppp(25,19,10,3)/
     x-8.7175264d-08,-1.9338935d-21,-1.7457300d-10 /
      data fpppp(25,19,11,1),fpppp(25,19,11,2),fpppp(25,19,11,3)/
     x-4.3096851d-08,-2.4405660d-21, 1.7026254d-10 /
      data fpppp(25,19,12,1),fpppp(25,19,12,2),fpppp(25,19,12,3)/
     x-7.9003779d-08,-1.8290478d-22,-1.3000262d-10 /
      data fpppp(25,19,13,1),fpppp(25,19,13,2),fpppp(25,19,13,3)/
     x-8.7136572d-08,-4.6051060d-22,-2.5137651d-10 /
      data fpppp(25,19,14,1),fpppp(25,19,14,2),fpppp(25,19,14,3)/
     x 1.8009829d-08, 3.4616221d-21,-9.7225719d-12 /
      data fpppp(25,19,15,1),fpppp(25,19,15,2),fpppp(25,19,15,3)/
     x 5.4113573d-08,-8.7994339d-22,-1.9046785d-10 /
      data fpppp(25,19,16,1),fpppp(25,19,16,2),fpppp(25,19,16,3)/
     x-1.8685395d-08,-2.8432438d-21, 4.3308312d-11 /
      data fpppp(25,19,17,1),fpppp(25,19,17,2),fpppp(25,19,17,3)/
     x 1.3518751d-07,-6.5423022d-22,-1.3481361d-10 /
      data fpppp(25,19,18,1),fpppp(25,19,18,2),fpppp(25,19,18,3)/
     x 1.9499048d-07, 3.9641507d-21, 1.5181077d-10 /
      data fpppp(25,19,19,1),fpppp(25,19,19,2),fpppp(25,19,19,3)/
     x 1.8926429d-07,-2.0211741d-21, 4.8874026d-11 /
      data fpppp(25,19,20,1),fpppp(25,19,20,2),fpppp(25,19,20,3)/
     x 2.0383346d-07,-2.1116948d-21, 1.5549878d-10 /
      data fpppp(25,19,21,1),fpppp(25,19,21,2),fpppp(25,19,21,3)/
     x 2.0383346d-07, 2.3439958d-21, 1.4825060d-10 /
      data fpppp(25,19,22,1),fpppp(25,19,22,2),fpppp(25,19,22,3)/
     x 1.8926429d-07,-2.2936442d-21, 7.7866740d-11 /
      data fpppp(25,19,23,1),fpppp(25,19,23,2),fpppp(25,19,23,3)/
     x 1.9499048d-07,-2.1215934d-21, 4.3088090d-11 /
      data fpppp(26, 1, 1,1),fpppp(26, 1, 1,2),fpppp(26, 1, 1,3)/
     x-1.7960208d-06,-2.6327963d-20,-2.1952060d-09 /
      data fpppp(26, 1, 2,1),fpppp(26, 1, 2,2),fpppp(26, 1, 2,3)/
     x 9.5482334d-07,-1.2835251d-20,-2.1908239d-09 /
      data fpppp(26, 1, 3,1),fpppp(26, 1, 3,2),fpppp(26, 1, 3,3)/
     x 3.0040533d-06, 5.7840088d-21,-2.2099264d-09 /
      data fpppp(26, 1, 4,1),fpppp(26, 1, 4,2),fpppp(26, 1, 4,3)/
     x 3.0040533d-06, 1.2060707d-20,-2.1600641d-09 /
      data fpppp(26, 1, 5,1),fpppp(26, 1, 5,2),fpppp(26, 1, 5,3)/
     x 9.5482334d-07, 1.9717699d-21,-2.3902730d-09 /
      data fpppp(26, 1, 6,1),fpppp(26, 1, 6,2),fpppp(26, 1, 6,3)/
     x-1.7960208d-06,-3.7158076d-21,-1.4472719d-09 /
      data fpppp(26, 1, 7,1),fpppp(26, 1, 7,2),fpppp(26, 1, 7,3)/
     x-4.8023446d-06, 1.1057281d-21,-6.9674594d-10 /
      data fpppp(26, 1, 8,1),fpppp(26, 1, 8,2),fpppp(26, 1, 8,3)/
     x-7.3897378d-06, 2.9596651d-21, 5.7765664d-10 /
      data fpppp(26, 1, 9,1),fpppp(26, 1, 9,2),fpppp(26, 1, 9,3)/
     x-9.3781818d-06,-8.4722655d-21, 1.5084343d-09 /
      data fpppp(26, 1,10,1),fpppp(26, 1,10,2),fpppp(26, 1,10,3)/
     x-1.0923293d-05,-1.5559144d-20, 2.0875802d-09 /
      data fpppp(26, 1,11,1),fpppp(26, 1,11,2),fpppp(26, 1,11,3)/
     x-1.1766617d-05, 1.3160491d-20, 2.2061230d-09 /
      data fpppp(26, 1,12,1),fpppp(26, 1,12,2),fpppp(26, 1,12,3)/
     x-1.2131427d-05,-1.1029283d-20, 2.6478622d-09 /
      data fpppp(26, 1,13,1),fpppp(26, 1,13,2),fpppp(26, 1,13,3)/
     x-1.1971924d-05, 7.1432345d-21, 2.2995821d-09 /
      data fpppp(26, 1,14,1),fpppp(26, 1,14,2),fpppp(26, 1,14,3)/
     x-1.1057538d-05, 5.8856981d-21, 2.4287711d-09 /
      data fpppp(26, 1,15,1),fpppp(26, 1,15,2),fpppp(26, 1,15,3)/
     x-9.6168603d-06,-9.4684824d-21, 1.6442019d-09 /
      data fpppp(26, 1,16,1),fpppp(26, 1,16,2),fpppp(26, 1,16,3)/
     x-7.6065441d-06, 6.3838474d-22, 9.3740171d-10 /
      data fpppp(26, 1,17,1),fpppp(26, 1,17,2),fpppp(26, 1,17,3)/
     x-5.0114654d-06, 1.2459449d-20,-7.6797453d-10 /
      data fpppp(26, 1,18,1),fpppp(26, 1,18,2),fpppp(26, 1,18,3)/
     x-1.9524732d-06, 6.0102317d-21,-1.3063012d-09 /
      data fpppp(26, 1,19,1),fpppp(26, 1,19,2),fpppp(26, 1,19,3)/
     x 1.3498498d-06, 2.3488457d-21,-2.6371463d-09 /
      data fpppp(26, 1,20,1),fpppp(26, 1,20,2),fpppp(26, 1,20,3)/
     x 3.2398487d-06, 4.2119848d-21,-2.5422835d-09 /
      data fpppp(26, 1,21,1),fpppp(26, 1,21,2),fpppp(26, 1,21,3)/
     x 3.2398487d-06,-8.8039308d-21,-2.6075579d-09 /
      data fpppp(26, 1,22,1),fpppp(26, 1,22,2),fpppp(26, 1,22,3)/
     x 1.3498498d-06, 2.0672523d-21,-2.3760487d-09 /
      data fpppp(26, 1,23,1),fpppp(26, 1,23,2),fpppp(26, 1,23,3)/
     x-1.9524732d-06,-1.7137075d-20,-2.2854175d-09 /
      data fpppp(26, 2, 1,1),fpppp(26, 2, 1,2),fpppp(26, 2, 1,3)/
     x-1.7473150d-06,-9.7621586d-07,-7.1254112d-10 /
      data fpppp(26, 2, 2,1),fpppp(26, 2, 2,2),fpppp(26, 2, 2,3)/
     x-7.3242892d-07,-6.5033019d-07,-7.1744606d-10 /
      data fpppp(26, 2, 3,1),fpppp(26, 2, 3,2),fpppp(26, 2, 3,3)/
     x 1.5183391d-07, 1.7630570d-08,-7.4081880d-10 /
      data fpppp(26, 2, 4,1),fpppp(26, 2, 4,2),fpppp(26, 2, 4,3)/
     x 1.5183391d-07, 7.0770537d-08,-7.1831004d-10 /
      data fpppp(26, 2, 5,1),fpppp(26, 2, 5,2),fpppp(26, 2, 5,3)/
     x-7.3242892d-07,-8.6289005d-07,-8.0748109d-10 /
      data fpppp(26, 2, 6,1),fpppp(26, 2, 6,2),fpppp(26, 2, 6,3)/
     x-1.7473150d-06,-1.7911636d-07,-3.7490978d-10 /
      data fpppp(26, 2, 7,1),fpppp(26, 2, 7,2),fpppp(26, 2, 7,3)/
     x-2.7803224d-06,-1.1684939d-07,-1.6066705d-10 /
      data fpppp(26, 2, 8,1),fpppp(26, 2, 8,2),fpppp(26, 2, 8,3)/
     x-3.5835758d-06, 1.4840639d-08, 2.3077592d-10 /
      data fpppp(26, 2, 9,1),fpppp(26, 2, 9,2),fpppp(26, 2, 9,3)/
     x-4.1430903d-06, 2.7038768d-07, 4.9293348d-10 /
      data fpppp(26, 2,10,1),fpppp(26, 2,10,2),fpppp(26, 2,10,3)/
     x-4.5921613d-06, 2.3924162d-07, 6.1954186d-10 /
      data fpppp(26, 2,11,1),fpppp(26, 2,11,2),fpppp(26, 2,11,3)/
     x-4.8233348d-06, 3.6698343d-07, 6.1914259d-10 /
      data fpppp(26, 2,12,1),fpppp(26, 2,12,2),fpppp(26, 2,12,3)/
     x-4.9449365d-06, 3.8826877d-07, 8.0401890d-10 /
      data fpppp(26, 2,13,1),fpppp(26, 2,13,2),fpppp(26, 2,13,3)/
     x-4.9308177d-06, 2.4869074d-07, 6.5047369d-10 /
      data fpppp(26, 2,14,1),fpppp(26, 2,14,2),fpppp(26, 2,14,3)/
     x-4.6693225d-06, 3.5481782d-07, 8.0416285d-10 /
      data fpppp(26, 2,15,1),fpppp(26, 2,15,2),fpppp(26, 2,15,3)/
     x-4.2760270d-06, 2.3570282d-07, 5.5513850d-10 /
      data fpppp(26, 2,16,1),fpppp(26, 2,16,2),fpppp(26, 2,16,3)/
     x-3.7036106d-06, 1.6043435d-08, 4.2932256d-10 /
      data fpppp(26, 2,17,1),fpppp(26, 2,17,2),fpppp(26, 2,17,3)/
     x-2.8913783d-06,-2.4662267d-08,-1.8409712d-10 /
      data fpppp(26, 2,18,1),fpppp(26, 2,18,2),fpppp(26, 2,18,3)/
     x-1.8288755d-06,-4.9039265d-07,-3.1133888d-10 /
      data fpppp(26, 2,19,1),fpppp(26, 2,19,2),fpppp(26, 2,19,3)/
     x-5.2615972d-07,-4.0378000d-07,-9.2989601d-10 /
      data fpppp(26, 2,20,1),fpppp(26, 2,20,2),fpppp(26, 2,20,3)/
     x 2.6429609d-07,-9.6553752d-08,-8.9473702d-10 /
      data fpppp(26, 2,21,1),fpppp(26, 2,21,2),fpppp(26, 2,21,3)/
     x 2.6429609d-07,-9.9248036d-08,-9.2487774d-10 /
      data fpppp(26, 2,22,1),fpppp(26, 2,22,2),fpppp(26, 2,22,3)/
     x-5.2615972d-07,-3.9300286d-07,-8.0933310d-10 /
      data fpppp(26, 2,23,1),fpppp(26, 2,23,2),fpppp(26, 2,23,3)/
     x-1.8288755d-06,-5.3080692d-07,-7.6344979d-10 /
      data fpppp(26, 3, 1,1),fpppp(26, 3, 1,2),fpppp(26, 3, 1,3)/
     x-2.5752668d-06,-1.4679085d-06, 1.5340760d-09 /
      data fpppp(26, 3, 2,1),fpppp(26, 3, 2,2),fpppp(26, 3, 2,3)/
     x-3.9761793d-06,-1.2005195d-06, 1.4331970d-09 /
      data fpppp(26, 3, 3,1),fpppp(26, 3, 3,2),fpppp(26, 3, 3,3)/
     x-3.9701398d-06,-6.6698052d-07, 1.2341405d-09 /
      data fpppp(26, 3, 4,1),fpppp(26, 3, 4,2),fpppp(26, 3, 4,3)/
     x-3.9701398d-06,-5.9796480d-07, 1.2041933d-09 /
      data fpppp(26, 3, 5,1),fpppp(26, 3, 5,2),fpppp(26, 3, 5,3)/
     x-3.9761793d-06,-1.4765824d-06, 1.5529858d-09 /
      data fpppp(26, 3, 6,1),fpppp(26, 3, 6,2),fpppp(26, 3, 6,3)/
     x-2.5752668d-06,-4.3267273d-07, 1.0848682d-09 /
      data fpppp(26, 3, 7,1),fpppp(26, 3, 7,2),fpppp(26, 3, 7,3)/
     x-6.5676441d-07, 4.4881808d-09, 9.7479675d-10 /
      data fpppp(26, 3, 8,1),fpppp(26, 3, 8,2),fpppp(26, 3, 8,3)/
     x 1.0812669d-06, 3.0884888d-07, 1.9751962d-11 /
      data fpppp(26, 3, 9,1),fpppp(26, 3, 9,2),fpppp(26, 3, 9,3)/
     x 2.6360037d-06, 5.7652852d-07,-9.1759998d-10 /
      data fpppp(26, 3,10,1),fpppp(26, 3,10,2),fpppp(26, 3,10,3)/
     x 3.9702395d-06, 7.2090944d-07,-1.5765330d-09 /
      data fpppp(26, 3,11,1),fpppp(26, 3,11,2),fpppp(26, 3,11,3)/
     x 4.7683676d-06, 7.6577764d-07,-1.9221205d-09 /
      data fpppp(26, 3,12,1),fpppp(26, 3,12,2),fpppp(26, 3,12,3)/
     x 5.0636625d-06, 8.2083609d-07,-2.2554441d-09 /
      data fpppp(26, 3,13,1),fpppp(26, 3,13,2),fpppp(26, 3,13,3)/
     x 4.7689085d-06, 7.6552294d-07,-1.9360249d-09 /
      data fpppp(26, 3,14,1),fpppp(26, 3,14,2),fpppp(26, 3,14,3)/
     x 3.8979179d-06, 7.6092264d-07,-1.6757242d-09 /
      data fpppp(26, 3,15,1),fpppp(26, 3,15,2),fpppp(26, 3,15,3)/
     x 2.6127964d-06, 6.3747879d-07,-7.4900090d-10 /
      data fpppp(26, 3,16,1),fpppp(26, 3,16,2),fpppp(26, 3,16,3)/
     x 1.0386209d-06, 3.1357516d-07,-7.4101682d-12 /
      data fpppp(26, 3,17,1),fpppp(26, 3,17,2),fpppp(26, 3,17,3)/
     x-6.5093859d-07, 8.7291445d-08, 1.1194809d-09 /
      data fpppp(26, 3,18,1),fpppp(26, 3,18,2),fpppp(26, 3,18,3)/
     x-2.5232062d-06,-5.2644992d-07, 1.0839033d-09 /
      data fpppp(26, 3,19,1),fpppp(26, 3,19,2),fpppp(26, 3,19,3)/
     x-4.1091748d-06,-1.2710362d-06, 1.4526261d-09 /
      data fpppp(26, 3,20,1),fpppp(26, 3,20,2),fpppp(26, 3,20,3)/
     x-4.1867961d-06,-7.4655459d-07, 1.2854022d-09 /
      data fpppp(26, 3,21,1),fpppp(26, 3,21,2),fpppp(26, 3,21,3)/
     x-4.1867961d-06,-7.9351714d-07, 1.3066092d-09 /
      data fpppp(26, 3,22,1),fpppp(26, 3,22,2),fpppp(26, 3,22,3)/
     x-4.1091748d-06,-1.0831860d-06, 1.3677981d-09 /
      data fpppp(26, 3,23,1),fpppp(26, 3,23,2),fpppp(26, 3,23,3)/
     x-2.5232062d-06,-1.2308882d-06, 1.4020081d-09 /
      data fpppp(26, 4, 1,1),fpppp(26, 4, 1,2),fpppp(26, 4, 1,3)/
     x-3.3491659d-07,-6.0287166d-07, 1.1068602d-09 /
      data fpppp(26, 4, 2,1),fpppp(26, 4, 2,2),fpppp(26, 4, 2,3)/
     x-1.7721862d-06,-8.3139514d-07, 1.2134117d-09 /
      data fpppp(26, 4, 3,1),fpppp(26, 4, 3,2),fpppp(26, 4, 3,3)/
     x-3.6479735d-06,-1.3269085d-06, 1.4386189d-09 /
      data fpppp(26, 4, 4,1),fpppp(26, 4, 4,2),fpppp(26, 4, 4,3)/
     x-3.6479735d-06,-1.3167232d-06, 1.4440743d-09 /
      data fpppp(26, 4, 5,1),fpppp(26, 4, 5,2),fpppp(26, 4, 5,3)/
     x-1.7721862d-06,-8.7213630d-07, 1.1915902d-09 /
      data fpppp(26, 4, 6,1),fpppp(26, 4, 6,2),fpppp(26, 4, 6,3)/
     x-3.3491659d-07,-4.5009230d-07, 1.1886905d-09 /
      data fpppp(26, 4, 7,1),fpppp(26, 4, 7,2),fpppp(26, 4, 7,3)/
     x 1.1114185d-06, 2.4443722d-08, 1.2413377d-11 /
      data fpppp(26, 4, 8,1),fpppp(26, 4, 8,2),fpppp(26, 4, 8,3)/
     x 2.7407270d-06, 4.6309135d-07,-6.6677067d-10 /
      data fpppp(26, 4, 9,1),fpppp(26, 4, 9,2),fpppp(26, 4, 9,3)/
     x 4.0110888d-06, 6.9472880d-07,-9.4551929d-10 /
      data fpppp(26, 4,10,1),fpppp(26, 4,10,2),fpppp(26, 4,10,3)/
     x 4.7231969d-06, 7.6429143d-07,-1.2244802d-09 /
      data fpppp(26, 4,11,1),fpppp(26, 4,11,2),fpppp(26, 4,11,3)/
     x 5.0905984d-06, 8.3441566d-07,-1.1233942d-09 /
      data fpppp(26, 4,12,1),fpppp(26, 4,12,2),fpppp(26, 4,12,3)/
     x 5.1948809d-06, 8.4743368d-07,-1.0602383d-09 /
      data fpppp(26, 4,13,1),fpppp(26, 4,13,2),fpppp(26, 4,13,3)/
     x 5.1634647d-06, 8.7621681d-07,-1.2416580d-09 /
      data fpppp(26, 4,14,1),fpppp(26, 4,14,2),fpppp(26, 4,14,3)/
     x 4.8385720d-06, 8.4650378d-07,-1.1621353d-09 /
      data fpppp(26, 4,15,1),fpppp(26, 4,15,2),fpppp(26, 4,15,3)/
     x 4.0836545d-06, 7.7273976d-07,-1.3003742d-09 /
      data fpppp(26, 4,16,1),fpppp(26, 4,16,2),fpppp(26, 4,16,3)/
     x 2.8433092d-06, 5.3516761d-07,-6.9385538d-10 /
      data fpppp(26, 4,17,1),fpppp(26, 4,17,2),fpppp(26, 4,17,3)/
     x 1.1682669d-06, 1.1310002d-07,-9.5893263d-11 /
      data fpppp(26, 4,18,1),fpppp(26, 4,18,2),fpppp(26, 4,18,3)/
     x-3.5478725d-07,-4.7056108d-07, 1.0781659d-09 /
      data fpppp(26, 4,19,1),fpppp(26, 4,19,2),fpppp(26, 4,19,3)/
     x-1.7176703d-06,-8.7435162d-07, 1.4716970d-09 /
      data fpppp(26, 4,20,1),fpppp(26, 4,20,2),fpppp(26, 4,20,3)/
     x-3.4734996d-06,-1.4160817d-06, 1.6014669d-09 /
      data fpppp(26, 4,21,1),fpppp(26, 4,21,2),fpppp(26, 4,21,3)/
     x-3.4734996d-06,-1.4232486d-06, 1.6172725d-09 /
      data fpppp(26, 4,22,1),fpppp(26, 4,22,2),fpppp(26, 4,22,3)/
     x-1.7176703d-06,-8.4568393d-07, 1.4084745d-09 /
      data fpppp(26, 4,23,1),fpppp(26, 4,23,2),fpppp(26, 4,23,3)/
     x-3.5478725d-07,-5.7806494d-07, 1.3152503d-09 /
      data fpppp(26, 5, 1,1),fpppp(26, 5, 1,2),fpppp(26, 5, 1,3)/
     x 1.7294941d-06,-3.4797922d-07,-7.5806630d-10 /
      data fpppp(26, 5, 2,1),fpppp(26, 5, 2,2),fpppp(26, 5, 2,3)/
     x 1.5214516d-06,-5.7131712d-07,-1.3744657d-11 /
      data fpppp(26, 5, 3,1),fpppp(26, 5, 3,2),fpppp(26, 5, 3,3)/
     x 1.5481683d-06,-1.0528662d-06, 1.5955372d-09 /
      data fpppp(26, 5, 4,1),fpppp(26, 5, 4,2),fpppp(26, 5, 4,3)/
     x 1.5481683d-06,-1.0476724d-06, 1.5705001d-09 /
      data fpppp(26, 5, 5,1),fpppp(26, 5, 5,2),fpppp(26, 5, 5,3)/
     x 1.5214516d-06,-5.9209241d-07, 8.6403942d-11 /
      data fpppp(26, 5, 6,1),fpppp(26, 5, 6,2),fpppp(26, 5, 6,3)/
     x 1.7294941d-06,-2.7007190d-07,-1.1336236d-09 /
      data fpppp(26, 5, 7,1),fpppp(26, 5, 7,2),fpppp(26, 5, 7,3)/
     x 1.9509346d-06, 1.4629128d-07,-1.0542278d-09 /
      data fpppp(26, 5, 8,1),fpppp(26, 5, 8,2),fpppp(26, 5, 8,3)/
     x 1.8973735d-06, 2.8874682d-07,-4.9956571d-10 /
      data fpppp(26, 5, 9,1),fpppp(26, 5, 9,2),fpppp(26, 5, 9,3)/
     x 1.8497993d-06, 4.1229050d-07,-3.2295964d-10 /
      data fpppp(26, 5,10,1),fpppp(26, 5,10,2),fpppp(26, 5,10,3)/
     x 2.0279396d-06, 5.1101399d-07, 1.9189716d-10 /
      data fpppp(26, 5,11,1),fpppp(26, 5,11,2),fpppp(26, 5,11,3)/
     x 2.2508126d-06, 6.2012777d-07, 2.0856019d-10 /
      data fpppp(26, 5,12,1),fpppp(26, 5,12,2),fpppp(26, 5,12,3)/
     x 2.3967925d-06, 6.7019232d-07, 5.2750253d-10 /
      data fpppp(26, 5,13,1),fpppp(26, 5,13,2),fpppp(26, 5,13,3)/
     x 2.2671348d-06, 6.7671119d-07, 2.6537367d-10 /
      data fpppp(26, 5,14,1),fpppp(26, 5,14,2),fpppp(26, 5,14,3)/
     x 2.0891460d-06, 5.7824822d-07,-3.7706943d-11 /
      data fpppp(26, 5,15,1),fpppp(26, 5,15,2),fpppp(26, 5,15,3)/
     x 1.9678087d-06, 5.5596844d-07,-1.2432904d-10 /
      data fpppp(26, 5,16,1),fpppp(26, 5,16,2),fpppp(26, 5,16,3)/
     x 1.9369927d-06, 3.7848188d-07,-7.5588829d-10 /
      data fpppp(26, 5,17,1),fpppp(26, 5,17,2),fpppp(26, 5,17,3)/
     x 1.9748629d-06, 2.1856800d-07,-1.0262011d-09 /
      data fpppp(26, 5,18,1),fpppp(26, 5,18,2),fpppp(26, 5,18,3)/
     x 1.7570759d-06,-1.8544450d-07,-1.0566739d-09 /
      data fpppp(26, 5,19,1),fpppp(26, 5,19,2),fpppp(26, 5,19,3)/
     x 1.3944124d-06,-6.9213027d-07, 7.1306898d-11 /
      data fpppp(26, 5,20,1),fpppp(26, 5,20,2),fpppp(26, 5,20,3)/
     x 1.3927741d-06,-1.1593963d-06, 1.5259527d-09 /
      data fpppp(26, 5,21,1),fpppp(26, 5,21,2),fpppp(26, 5,21,3)/
     x 1.3927741d-06,-1.1730971d-06, 1.5472729d-09 /
      data fpppp(26, 5,22,1),fpppp(26, 5,22,2),fpppp(26, 5,22,3)/
     x 1.3944124d-06,-6.3732743d-07,-1.3974008d-11 /
      data fpppp(26, 5,23,1),fpppp(26, 5,23,2),fpppp(26, 5,23,3)/
     x 1.7570759d-06,-3.9095513d-07,-7.3687052d-10 /
      data fpppp(26, 6, 1,1),fpppp(26, 6, 1,2),fpppp(26, 6, 1,3)/
     x 1.7363879d-06,-1.3663256d-07,-2.0517052d-10 /
      data fpppp(26, 6, 2,1),fpppp(26, 6, 2,2),fpppp(26, 6, 2,3)/
     x 2.1448063d-06,-2.7894750d-07,-3.4728195d-10 /
      data fpppp(26, 6, 3,1),fpppp(26, 6, 3,2),fpppp(26, 6, 3,3)/
     x 2.3312914d-06,-5.8585894d-07,-6.5479670d-10 /
      data fpppp(26, 6, 4,1),fpppp(26, 6, 4,2),fpppp(26, 6, 4,3)/
     x 2.3312914d-06,-5.8244495d-07,-6.4956377d-10 /
      data fpppp(26, 6, 5,1),fpppp(26, 6, 5,2),fpppp(26, 6, 5,3)/
     x 2.1448063d-06,-2.9260346d-07,-3.6821366d-10 /
      data fpppp(26, 6, 6,1),fpppp(26, 6, 6,2),fpppp(26, 6, 6,3)/
     x 1.7363879d-06,-8.5422703d-08,-1.2667659d-10 /
      data fpppp(26, 6, 7,1),fpppp(26, 6, 7,2),fpppp(26, 6, 7,3)/
     x 1.1027731d-06, 6.7639790d-08, 5.4267226d-12 /
      data fpppp(26, 6, 8,1),fpppp(26, 6, 8,2),fpppp(26, 6, 8,3)/
     x 5.7801296d-07, 1.0359120d-07,-1.0620131d-10 /
      data fpppp(26, 6, 9,1),fpppp(26, 6, 9,2),fpppp(26, 6, 9,3)/
     x 2.4086900d-07, 2.2621237d-07, 6.0136840d-10 /
      data fpppp(26, 6,10,1),fpppp(26, 6,10,2),fpppp(26, 6,10,3)/
     x-8.7480301d-08, 2.3650672d-07, 4.1208416d-10 /
      data fpppp(26, 6,11,1),fpppp(26, 6,11,2),fpppp(26, 6,11,3)/
     x-3.0477346d-07, 3.3967855d-07, 6.6437238d-10 /
      data fpppp(26, 6,12,1),fpppp(26, 6,12,2),fpppp(26, 6,12,3)/
     x-4.3641390d-07, 2.9378788d-07, 1.4159939d-11 /
      data fpppp(26, 6,13,1),fpppp(26, 6,13,2),fpppp(26, 6,13,3)/
     x-2.6020834d-07, 4.0961639d-07, 5.8921762d-10 /
      data fpppp(26, 6,14,1),fpppp(26, 6,14,2),fpppp(26, 6,14,3)/
     x-6.3243351d-08, 3.1347039d-07, 4.1281414d-10 /
      data fpppp(26, 6,15,1),fpppp(26, 6,15,2),fpppp(26, 6,15,3)/
     x 2.6794085d-07, 3.2367627d-07, 3.0923198d-10 /
      data fpppp(26, 6,16,1),fpppp(26, 6,16,2),fpppp(26, 6,16,3)/
     x 6.8569286d-07, 2.4362650d-07, 1.3139121d-10 /
      data fpppp(26, 6,17,1),fpppp(26, 6,17,2),fpppp(26, 6,17,3)/
     x 1.1660168d-06, 1.5485554d-07,-1.2677450d-10 /
      data fpppp(26, 6,18,1),fpppp(26, 6,18,2),fpppp(26, 6,18,3)/
     x 1.7215474d-06,-4.0870578d-08,-7.5563737d-11 /
      data fpppp(26, 6,19,1),fpppp(26, 6,19,2),fpppp(26, 6,19,3)/
     x 2.1349904d-06,-3.3998066d-07,-3.7307832d-10 /
      data fpppp(26, 6,20,1),fpppp(26, 6,20,2),fpppp(26, 6,20,3)/
     x 2.2211351d-06,-7.1802499d-07,-6.5656949d-10 /
      data fpppp(26, 6,21,1),fpppp(26, 6,21,2),fpppp(26, 6,21,3)/
     x 2.2211351d-06,-7.2384886d-07,-6.6441215d-10 /
      data fpppp(26, 6,22,1),fpppp(26, 6,22,2),fpppp(26, 6,22,3)/
     x 2.1349904d-06,-3.1668521d-07,-3.4170768d-10 /
      data fpppp(26, 6,23,1),fpppp(26, 6,23,2),fpppp(26, 6,23,3)/
     x 1.7215474d-06,-1.2822854d-07,-1.9320364d-10 /
      data fpppp(26, 7, 1,1),fpppp(26, 7, 1,2),fpppp(26, 7, 1,3)/
     x 6.1351700d-07,-5.6326353d-08, 4.6380365d-10 /
      data fpppp(26, 7, 2,1),fpppp(26, 7, 2,2),fpppp(26, 7, 2,3)/
     x 9.9108662d-07,-1.1308431d-07,-8.7238099d-11 /
      data fpppp(26, 7, 3,1),fpppp(26, 7, 3,2),fpppp(26, 7, 3,3)/
     x 1.2698617d-06,-2.3355354d-07,-1.2609635d-09 /
      data fpppp(26, 7, 4,1),fpppp(26, 7, 4,2),fpppp(26, 7, 4,3)/
     x 1.2698617d-06,-2.3557470d-07,-1.2733506d-09 /
      data fpppp(26, 7, 5,1),fpppp(26, 7, 5,2),fpppp(26, 7, 5,3)/
     x 9.9108662d-07,-1.0499967d-07,-3.7689445d-11 /
      data fpppp(26, 7, 6,1),fpppp(26, 7, 6,2),fpppp(26, 7, 6,3)/
     x 6.1351700d-07,-8.6643721d-08, 2.7799620d-10 /
      data fpppp(26, 7, 7,1),fpppp(26, 7, 7,2),fpppp(26, 7, 7,3)/
     x 3.1933113d-07, 4.0350046d-08, 3.4599599d-10 /
      data fpppp(26, 7, 8,1),fpppp(26, 7, 8,2),fpppp(26, 7, 8,3)/
     x 2.8306316d-08, 6.2437068d-08, 7.1280447d-10 /
      data fpppp(26, 7, 9,1),fpppp(26, 7, 9,2),fpppp(26, 7, 9,3)/
     x-3.7083168d-07, 6.1104947d-08, 1.7027697d-10 /
      data fpppp(26, 7,10,1),fpppp(26, 7,10,2),fpppp(26, 7,10,3)/
     x-6.8141413d-07, 8.3563899d-08, 5.2016904d-10 /
      data fpppp(26, 7,11,1),fpppp(26, 7,11,2),fpppp(26, 7,11,3)/
     x-9.4105543d-07, 9.1899103d-08,-1.6045203d-10 /
      data fpppp(26, 7,12,1),fpppp(26, 7,12,2),fpppp(26, 7,12,3)/
     x-9.6903462d-07, 1.6251979d-07, 2.7306410d-10 /
      data fpppp(26, 7,13,1),fpppp(26, 7,13,2),fpppp(26, 7,13,3)/
     x-9.5555765d-07, 1.2650901d-07,-1.1666737d-10 /
      data fpppp(26, 7,14,1),fpppp(26, 7,14,2),fpppp(26, 7,14,3)/
     x-6.5849147d-07, 1.8590224d-07, 4.6693682d-10 /
      data fpppp(26, 7,15,1),fpppp(26, 7,15,2),fpppp(26, 7,15,3)/
     x-3.4224617d-07, 1.7126557d-07, 2.9987856d-10 /
      data fpppp(26, 7,16,1),fpppp(26, 7,16,2),fpppp(26, 7,16,3)/
     x 3.7649942d-08, 1.5247883d-07, 4.1992727d-10 /
      data fpppp(26, 7,17,1),fpppp(26, 7,17,2),fpppp(26, 7,17,3)/
     x 3.7489523d-07, 1.1275406d-07, 4.4240634d-10 /
      data fpppp(26, 7,18,1),fpppp(26, 7,18,2),fpppp(26, 7,18,3)/
     x 6.6647995d-07,-2.6939360d-08, 1.3289621d-10 /
      data fpppp(26, 7,19,1),fpppp(26, 7,19,2),fpppp(26, 7,19,3)/
     x 9.7563116d-07,-1.8253198d-07,-1.4397019d-10 /
      data fpppp(26, 7,20,1),fpppp(26, 7,20,2),fpppp(26, 7,20,3)/
     x 1.2697497d-06,-3.3040767d-07,-1.1337358d-09 /
      data fpppp(26, 7,21,1),fpppp(26, 7,21,2),fpppp(26, 7,21,3)/
     x 1.2697497d-06,-3.3451767d-07,-1.1249530d-09 /
      data fpppp(26, 7,22,1),fpppp(26, 7,22,2),fpppp(26, 7,22,3)/
     x 9.7563116d-07,-1.6609199d-07,-1.7910137d-10 /
      data fpppp(26, 7,23,1),fpppp(26, 7,23,2),fpppp(26, 7,23,3)/
     x 6.6647995d-07,-8.8589335d-08, 2.6463812d-10 /
      data fpppp(26, 8, 1,1),fpppp(26, 8, 1,2),fpppp(26, 8, 1,3)/
     x 1.8293768d-07,-2.9688566d-08,-3.6728134d-10 /
      data fpppp(26, 8, 2,1),fpppp(26, 8, 2,2),fpppp(26, 8, 2,3)/
     x 3.9598732d-07,-4.0192483d-08,-3.0929116d-10 /
      data fpppp(26, 8, 3,1),fpppp(26, 8, 3,2),fpppp(26, 8, 3,3)/
     x 6.2004010d-07,-6.1802556d-08,-2.0201014d-10 /
      data fpppp(26, 8, 4,1),fpppp(26, 8, 4,2),fpppp(26, 8, 4,3)/
     x 6.2004010d-07,-6.3374621d-08,-1.7228874d-10 /
      data fpppp(26, 8, 5,1),fpppp(26, 8, 5,2),fpppp(26, 8, 5,3)/
     x 3.9598732d-07,-3.3904222d-08,-4.2817678d-10 /
      data fpppp(26, 8, 6,1),fpppp(26, 8, 6,2),fpppp(26, 8, 6,3)/
     x 1.8293768d-07,-5.3269548d-08, 7.8539721d-11 /
      data fpppp(26, 8, 7,1),fpppp(26, 8, 7,2),fpppp(26, 8, 7,3)/
     x-8.0153215d-08, 4.9485116d-08, 3.4234579d-10 /
      data fpppp(26, 8, 8,1),fpppp(26, 8, 8,2),fpppp(26, 8, 8,3)/
     x-3.5589776d-07,-5.0166259d-08, 6.4109544d-11 /
      data fpppp(26, 8, 9,1),fpppp(26, 8, 9,2),fpppp(26, 8, 9,3)/
     x-5.1439506d-07, 1.7780225d-08, 1.4926272d-10 /
      data fpppp(26, 8,10,1),fpppp(26, 8,10,2),fpppp(26, 8,10,3)/
     x-5.9713804d-07,-4.6289415d-08,-2.2884245d-10 /
      data fpppp(26, 8,11,1),fpppp(26, 8,11,2),fpppp(26, 8,11,3)/
     x-5.5596486d-07, 6.8715876d-08, 2.9002521d-10 /
      data fpppp(26, 8,12,1),fpppp(26, 8,12,2),fpppp(26, 8,12,3)/
     x-5.9041077d-07, 4.6459378d-08, 5.9307894d-11 /
      data fpppp(26, 8,13,1),fpppp(26, 8,13,2),fpppp(26, 8,13,3)/
     x-5.3768406d-07, 1.1881804d-07, 3.0196548d-10 /
      data fpppp(26, 8,14,1),fpppp(26, 8,14,2),fpppp(26, 8,14,3)/
     x-5.3838178d-07, 4.3152579d-08,-1.0434017d-10 /
      data fpppp(26, 8,15,1),fpppp(26, 8,15,2),fpppp(26, 8,15,3)/
     x-4.2813566d-07, 1.2604404d-07, 1.6185507d-10 /
      data fpppp(26, 8,16,1),fpppp(26, 8,16,2),fpppp(26, 8,16,3)/
     x-2.7338837d-07, 3.3428217d-08, 1.3027324d-10 /
      data fpppp(26, 8,17,1),fpppp(26, 8,17,2),fpppp(26, 8,17,3)/
     x-2.7541019d-08, 5.8143883d-08, 8.1053677d-11 /
      data fpppp(26, 8,18,1),fpppp(26, 8,18,2),fpppp(26, 8,18,3)/
     x 2.3612271d-07,-2.4689688d-08, 6.6987218d-11 /
      data fpppp(26, 8,19,1),fpppp(26, 8,19,2),fpppp(26, 8,19,3)/
     x 4.4526265d-07,-9.2193862d-08,-3.4697873d-10 /
      data fpppp(26, 8,20,1),fpppp(26, 8,20,2),fpppp(26, 8,20,3)/
     x 5.9380158d-07,-1.1069665d-07,-2.2774446d-10 /
      data fpppp(26, 8,21,1),fpppp(26, 8,21,2),fpppp(26, 8,21,3)/
     x 5.9380158d-07,-1.1349109d-07,-2.5003601d-10 /
      data fpppp(26, 8,22,1),fpppp(26, 8,22,2),fpppp(26, 8,22,3)/
     x 4.4526265d-07,-8.1016101d-08,-2.5781254d-10 /
      data fpppp(26, 8,23,1),fpppp(26, 8,23,2),fpppp(26, 8,23,3)/
     x 2.3612271d-07,-6.6606292d-08,-2.6738600d-10 /
      data fpppp(26, 9, 1,1),fpppp(26, 9, 1,2),fpppp(26, 9, 1,3)/
     x-1.4697498d-07, 5.0573131d-08, 2.5587612d-10 /
      data fpppp(26, 9, 2,1),fpppp(26, 9, 2,2),fpppp(26, 9, 2,3)/
     x 4.1448179d-08, 1.9197035d-08, 1.5329392d-10 /
      data fpppp(26, 9, 3,1),fpppp(26, 9, 3,2),fpppp(26, 9, 3,3)/
     x 1.2906825d-07,-4.5251399d-08,-5.7115087d-11 /
      data fpppp(26, 9, 4,1),fpppp(26, 9, 4,2),fpppp(26, 9, 4,3)/
     x 1.2906825d-07,-5.0127000d-08,-7.3582582d-11 /
      data fpppp(26, 9, 5,1),fpppp(26, 9, 5,2),fpppp(26, 9, 5,3)/
     x 4.1448179d-08, 3.8699440d-08, 2.1916390d-10 /
      data fpppp(26, 9, 6,1),fpppp(26, 9, 6,2),fpppp(26, 9, 6,3)/
     x-1.4697498d-07,-2.2560890d-08, 8.8636978d-12 /
      data fpppp(26, 9, 7,1),fpppp(26, 9, 7,2),fpppp(26, 9, 7,3)/
     x-2.5806008d-07, 2.8330846d-08,-6.8221625d-11 /
      data fpppp(26, 9, 8,1),fpppp(26, 9, 8,2),fpppp(26, 9, 8,3)/
     x-3.2030606d-07,-3.7561152d-08,-2.3889152d-10 /
      data fpppp(26, 9, 9,1),fpppp(26, 9, 9,2),fpppp(26, 9, 9,3)/
     x-2.6466897d-07,-1.7329975d-08, 6.4110101d-11 /
      data fpppp(26, 9,10,1),fpppp(26, 9,10,2),fpppp(26, 9,10,3)/
     x-2.9242621d-07,-2.6030811d-08,-6.0902211d-11 /
      data fpppp(26, 9,11,1),fpppp(26, 9,11,2),fpppp(26, 9,11,3)/
     x-3.2067171d-07,-1.7011990d-08,-6.6749594d-12 /
      data fpppp(26, 9,12,1),fpppp(26, 9,12,2),fpppp(26, 9,12,3)/
     x-2.6819985d-07, 4.0368714d-08, 2.9391182d-10 /
      data fpppp(26, 9,13,1),fpppp(26, 9,13,2),fpppp(26, 9,13,3)/
     x-2.6499987d-07, 7.4667473d-08, 9.9001601d-11 /
      data fpppp(26, 9,14,1),fpppp(26, 9,14,2),fpppp(26, 9,14,3)/
     x-2.4355267d-07, 2.4410253d-08, 1.4543177d-10 /
      data fpppp(26, 9,15,1),fpppp(26, 9,15,2),fpppp(26, 9,15,3)/
     x-2.2882413d-07, 7.7488598d-08,-3.7526707d-11 /
      data fpppp(26, 9,16,1),fpppp(26, 9,16,2),fpppp(26, 9,16,3)/
     x-2.4655220d-07, 1.2904787d-08,-9.5116726d-11 /
      data fpppp(26, 9,17,1),fpppp(26, 9,17,2),fpppp(26, 9,17,3)/
     x-1.9849221d-07, 2.9631509d-10,-2.0007186d-11 /
      data fpppp(26, 9,18,1),fpppp(26, 9,18,2),fpppp(26, 9,18,3)/
     x-1.1262035d-07,-4.4600797d-08,-2.7320402d-10 /
      data fpppp(26, 9,19,1),fpppp(26, 9,19,2),fpppp(26, 9,19,3)/
     x 3.6670534d-08,-4.7084877d-08,-8.5292993d-11 /
      data fpppp(26, 9,20,1),fpppp(26, 9,20,2),fpppp(26, 9,20,3)/
     x 1.2391434d-07,-7.3921591d-09, 1.0578494d-10 /
      data fpppp(26, 9,21,1),fpppp(26, 9,21,2),fpppp(26, 9,21,3)/
     x 1.2391434d-07,-8.3893434d-09, 1.1047203d-10 /
      data fpppp(26, 9,22,1),fpppp(26, 9,22,2),fpppp(26, 9,22,3)/
     x 3.6670534d-08,-4.3096140d-08,-1.0404135d-10 /
      data fpppp(26, 9,23,1),fpppp(26, 9,23,2),fpppp(26, 9,23,3)/
     x-1.1262035d-07,-5.9558561d-08,-2.0289770d-10 /
      data fpppp(26,10, 1,1),fpppp(26,10, 1,2),fpppp(26,10, 1,3)/
     x-8.2764681d-08, 8.9167004d-08,-4.4404535d-11 /
      data fpppp(26,10, 2,1),fpppp(26,10, 2,2),fpppp(26,10, 2,3)/
     x-6.1001434d-08, 2.6742592d-08,-5.7521695d-11 /
      data fpppp(26,10, 3,1),fpppp(26,10, 3,2),fpppp(26,10, 3,3)/
     x 2.5774108d-08,-1.0685352d-07,-8.6799350d-11 /
      data fpppp(26,10, 4,1),fpppp(26,10, 4,2),fpppp(26,10, 4,3)/
     x 2.5774108d-08,-1.0715187d-07,-8.4752805d-11 /
      data fpppp(26,10, 5,1),fpppp(26,10, 5,2),fpppp(26,10, 5,3)/
     x-6.1001434d-08, 2.7935998d-08,-6.5707876d-11 /
      data fpppp(26,10, 6,1),fpppp(26,10, 6,2),fpppp(26,10, 6,3)/
     x-8.2764681d-08, 8.4691733d-08,-1.3706357d-11 /
      data fpppp(26,10, 7,1),fpppp(26,10, 7,2),fpppp(26,10, 7,3)/
     x-9.8837894d-08, 4.9368851d-08,-1.3338284d-10 /
      data fpppp(26,10, 8,1),fpppp(26,10, 8,2),fpppp(26,10, 8,3)/
     x 1.5032655d-08, 4.2377461d-08, 6.8686257d-10 /
      data fpppp(26,10, 9,1),fpppp(26,10, 9,2),fpppp(26,10, 9,3)/
     x-1.6916342d-07,-7.3253585d-08,-6.0340373d-10 /
      data fpppp(26,10,10,1),fpppp(26,10,10,2),fpppp(26,10,10,3)/
     x-1.1195980d-07,-6.2753598d-09, 3.8784768d-10 /
      data fpppp(26,10,11,1),fpppp(26,10,11,2),fpppp(26,10,11,3)/
     x-1.3082528d-07,-3.4019812d-08,-8.7210314d-11 /
      data fpppp(26,10,12,1),fpppp(26,10,12,2),fpppp(26,10,12,3)/
     x-1.5489108d-07, 1.9510344d-09,-5.4811824d-11 /
      data fpppp(26,10,13,1),fpppp(26,10,13,2),fpppp(26,10,13,3)/
     x-1.3309008d-07, 2.7056850d-08, 1.6533959d-10 /
      data fpppp(26,10,14,1),fpppp(26,10,14,2),fpppp(26,10,14,3)/
     x-1.4691190d-07, 3.5776782d-08,-7.0776170d-11 /
      data fpppp(26,10,15,1),fpppp(26,10,15,2),fpppp(26,10,15,3)/
     x-1.5266284d-07, 4.0978744d-09, 1.8497360d-11 /
      data fpppp(26,10,16,1),fpppp(26,10,16,2),fpppp(26,10,16,3)/
     x-7.5740889d-08, 5.8961285d-08, 8.2600519d-11 /
      data fpppp(26,10,17,1),fpppp(26,10,17,2),fpppp(26,10,17,3)/
     x-8.3612878d-08,-2.9577383d-08,-8.0897954d-11 /
      data fpppp(26,10,18,1),fpppp(26,10,18,2),fpppp(26,10,18,3)/
     x-3.6561407d-08,-1.8999933d-08, 7.2914099d-11 /
      data fpppp(26,10,19,1),fpppp(26,10,19,2),fpppp(26,10,19,3)/
     x-4.4565114d-08,-6.7900555d-08,-1.0031721d-10 /
      data fpppp(26,10,20,1),fpppp(26,10,20,2),fpppp(26,10,20,3)/
     x-1.7873417d-08, 4.0005085d-08,-4.8608897d-11 /
      data fpppp(26,10,21,1),fpppp(26,10,21,2),fpppp(26,10,21,3)/
     x-1.7873417d-08, 3.5293538d-08,-5.7977339d-11 /
      data fpppp(26,10,22,1),fpppp(26,10,22,2),fpppp(26,10,22,3)/
     x-4.4565114d-08,-4.9054368d-08,-6.2843437d-11 /
      data fpppp(26,10,23,1),fpppp(26,10,23,2),fpppp(26,10,23,3)/
     x-3.6561407d-08,-8.9673136d-08,-6.7612534d-11 /
      data fpppp(26,11, 1,1),fpppp(26,11, 1,2),fpppp(26,11, 1,3)/
     x 1.1349534d-08, 2.0091050d-07,-6.7902657d-11 /
      data fpppp(26,11, 2,1),fpppp(26,11, 2,2),fpppp(26,11, 2,3)/
     x 1.6154896d-08, 6.5567629d-08,-1.2391778d-10 /
      data fpppp(26,11, 3,1),fpppp(26,11, 3,2),fpppp(26,11, 3,3)/
     x 4.4761526d-09,-2.2396120d-07,-2.4320026d-10 /
      data fpppp(26,11, 4,1),fpppp(26,11, 4,2),fpppp(26,11, 4,3)/
     x 4.4761526d-09,-2.2482154d-07,-2.4451262d-10 /
      data fpppp(26,11, 5,1),fpppp(26,11, 5,2),fpppp(26,11, 5,3)/
     x 1.6154896d-08, 6.9009002d-08,-1.1866834d-10 /
      data fpppp(26,11, 6,1),fpppp(26,11, 6,2),fpppp(26,11, 6,3)/
     x 1.1349534d-08, 1.8800535d-07,-8.7588039d-11 /
      data fpppp(26,11, 7,1),fpppp(26,11, 7,2),fpppp(26,11, 7,3)/
     x 6.8300818d-09, 1.3471052d-07, 1.2982880d-09 /
      data fpppp(26,11, 8,1),fpppp(26,11, 8,2),fpppp(26,11, 8,3)/
     x-4.2143584d-07, 1.3908095d-08,-1.9211491d-09 /
      data fpppp(26,11, 9,1),fpppp(26,11, 9,2),fpppp(26,11, 9,3)/
     x-1.1960963d-08, 3.5083958d-09, 1.8233313d-09 /
      data fpppp(26,11,10,1),fpppp(26,11,10,2),fpppp(26,11,10,3)/
     x-1.4335100d-07,-6.7514712d-08,-6.9320387d-10 /
      data fpppp(26,11,11,1),fpppp(26,11,11,2),fpppp(26,11,11,3)/
     x-1.3516005d-07,-2.4917697d-08, 2.1255126d-10 /
      data fpppp(26,11,12,1),fpppp(26,11,12,2),fpppp(26,11,12,3)/
     x-1.3707279d-07,-1.0099230d-08, 5.9910644d-11 /
      data fpppp(26,11,13,1),fpppp(26,11,13,2),fpppp(26,11,13,3)/
     x-1.5412198d-07,-3.3074460d-08,-4.3569571d-10 /
      data fpppp(26,11,14,1),fpppp(26,11,14,2),fpppp(26,11,14,3)/
     x-8.5586362d-08, 3.2199380d-08, 1.4444068d-10 /
      data fpppp(26,11,15,1),fpppp(26,11,15,2),fpppp(26,11,15,3)/
     x-3.0426650d-08, 1.5192509d-08,-2.8198059d-11 /
      data fpppp(26,11,16,1),fpppp(26,11,16,2),fpppp(26,11,16,3)/
     x-4.3633557d-08, 1.1888619d-08, 8.4888194d-11 /
      data fpppp(26,11,17,1),fpppp(26,11,17,2),fpppp(26,11,17,3)/
     x 1.0392276d-08, 2.2425245d-08, 1.3464016d-10 /
      data fpppp(26,11,18,1),fpppp(26,11,18,2),fpppp(26,11,18,3)/
     x-1.3739835d-08,-4.8427426d-08, 1.3720946d-10 /
      data fpppp(26,11,19,1),fpppp(26,11,19,2),fpppp(26,11,19,3)/
     x 2.7865259d-08,-4.1543621d-08, 7.2873315d-11 /
      data fpppp(26,11,20,1),fpppp(26,11,20,2),fpppp(26,11,20,3)/
     x 8.7148208d-08, 4.8152627d-08,-2.1225718d-10 /
      data fpppp(26,11,21,1),fpppp(26,11,21,2),fpppp(26,11,21,3)/
     x 8.7148208d-08, 4.6492448d-08,-2.0899493d-10 /
      data fpppp(26,11,22,1),fpppp(26,11,22,2),fpppp(26,11,22,3)/
     x 2.7865259d-08,-3.4902904d-08, 5.9824311d-11 /
      data fpppp(26,11,23,1),fpppp(26,11,23,2),fpppp(26,11,23,3)/
     x-1.3739835d-08,-7.3330115d-08, 1.8614322d-10 /
      data fpppp(26,12, 1,1),fpppp(26,12, 1,2),fpppp(26,12, 1,3)/
     x 1.3328906d-07, 2.9457174d-07,-8.0939534d-11 /
      data fpppp(26,12, 2,1),fpppp(26,12, 2,2),fpppp(26,12, 2,3)/
     x 1.2809383d-07, 9.4129626d-08,-6.2897792d-11 /
      data fpppp(26,12, 3,1),fpppp(26,12, 3,2),fpppp(26,12, 3,3)/
     x 6.6667295d-08,-3.3908988d-07,-3.9082485d-11 /
      data fpppp(26,12, 4,1),fpppp(26,12, 4,2),fpppp(26,12, 4,3)/
     x 6.6667295d-08,-3.3261369d-07,-1.3102739d-11 /
      data fpppp(26,12, 5,1),fpppp(26,12, 5,2),fpppp(26,12, 5,3)/
     x 1.2809383d-07, 6.8224846d-08,-1.6681677d-10 /
      data fpppp(26,12, 6,1),fpppp(26,12, 6,2),fpppp(26,12, 6,3)/
     x 1.3328906d-07, 3.9171467d-07, 3.0875665d-10 /
      data fpppp(26,12, 7,1),fpppp(26,12, 7,2),fpppp(26,12, 7,3)/
     x 6.2483835d-08,-2.0884020d-07,-1.9713637d-09 /
      data fpppp(26,12, 8,1),fpppp(26,12, 8,2),fpppp(26,12, 8,3)/
     x 6.2776527d-07, 6.7165715d-07, 3.3394138d-09 /
      data fpppp(26,12, 9,1),fpppp(26,12, 9,2),fpppp(26,12, 9,3)/
     x-4.6252070d-08,-4.2211314d-07,-2.3450463d-09 /
      data fpppp(26,12,10,1),fpppp(26,12,10,2),fpppp(26,12,10,3)/
     x 7.8787220d-08, 7.1558261d-08, 1.2637879d-09 /
      data fpppp(26,12,11,1),fpppp(26,12,11,2),fpppp(26,12,11,3)/
     x-2.4292783d-08,-6.0545847d-08,-2.6315009d-10 /
      data fpppp(26,12,12,1),fpppp(26,12,12,2),fpppp(26,12,12,3)/
     x-5.5736569d-08,-1.7519628d-08,-3.4302945d-10 /
      data fpppp(26,12,13,1),fpppp(26,12,13,2),fpppp(26,12,13,3)/
     x-2.1059699d-08,-1.5553297d-08, 2.7039340d-10 /
      data fpppp(26,12,14,1),fpppp(26,12,14,2),fpppp(26,12,14,3)/
     x-1.2611274d-08,-6.1298049d-09,-1.6058849d-10 /
      data fpppp(26,12,15,1),fpppp(26,12,15,2),fpppp(26,12,15,3)/
     x-6.0217212d-08,-1.3845315d-08, 1.5752497d-11 /
      data fpppp(26,12,16,1),fpppp(26,12,16,2),fpppp(26,12,16,3)/
     x-4.4275706d-08, 3.2851436d-08,-9.4381838d-11 /
      data fpppp(26,12,17,1),fpppp(26,12,17,2),fpppp(26,12,17,3)/
     x-6.0308889d-08,-5.4192698d-09, 1.0979387d-10 /
      data fpppp(26,12,18,1),fpppp(26,12,18,2),fpppp(26,12,18,3)/
     x-2.4491595d-09,-1.0317232d-08, 2.0650415d-11 /
      data fpppp(26,12,19,1),fpppp(26,12,19,2),fpppp(26,12,19,3)/
     x 3.6964831d-08,-1.6042383d-08, 2.7175798d-10 /
      data fpppp(26,12,20,1),fpppp(26,12,20,2),fpppp(26,12,20,3)/
     x 6.6626504d-09, 2.7875923d-08,-1.5650088d-10 /
      data fpppp(26,12,21,1),fpppp(26,12,21,2),fpppp(26,12,21,3)/
     x 6.6626504d-09, 2.6631286d-08,-1.3509447d-10 /
      data fpppp(26,12,22,1),fpppp(26,12,22,2),fpppp(26,12,22,3)/
     x 3.6964831d-08,-1.1063833d-08, 1.8613234d-10 /
      data fpppp(26,12,23,1),fpppp(26,12,23,2),fpppp(26,12,23,3)/
     x-2.4491595d-09,-2.8986792d-08, 3.4174657d-10 /
      data fpppp(26,13, 1,1),fpppp(26,13, 1,2),fpppp(26,13, 1,3)/
     x 9.7980871d-08, 2.9519448d-07,-4.1550044d-10 /
      data fpppp(26,13, 2,1),fpppp(26,13, 2,2),fpppp(26,13, 2,3)/
     x-6.1834035d-08, 7.5564691d-08,-2.0016859d-10 /
      data fpppp(26,13, 3,1),fpppp(26,13, 3,2),fpppp(26,13, 3,3)/
     x-2.0268202d-07,-3.9511473d-07, 2.6940159d-10 /
      data fpppp(26,13, 4,1),fpppp(26,13, 4,2),fpppp(26,13, 4,3)/
     x-2.0268202d-07,-3.9503747d-07, 2.5514819d-10 /
      data fpppp(26,13, 5,1),fpppp(26,13, 5,2),fpppp(26,13, 5,3)/
     x-6.1834035d-08, 7.5255652d-08,-1.4315500d-10 /
      data fpppp(26,13, 6,1),fpppp(26,13, 6,2),fpppp(26,13, 6,3)/
     x 9.7980871d-08, 2.9635338d-07,-6.2930140d-10 /
      data fpppp(26,13, 7,1),fpppp(26,13, 7,2),fpppp(26,13, 7,3)/
     x 1.6535528d-07, 2.3992014d-07, 1.1237087d-09 /
      data fpppp(26,13, 8,1),fpppp(26,13, 8,2),fpppp(26,13, 8,3)/
     x-2.5669283d-07, 9.0410254d-08,-2.3408107d-09 /
      data fpppp(26,13, 9,1),fpppp(26,13, 9,2),fpppp(26,13, 9,3)/
     x 1.1193440d-07,-1.2840875d-08, 2.5575304d-09 /
      data fpppp(26,13,10,1),fpppp(26,13,10,2),fpppp(26,13,10,3)/
     x-3.0452978d-07,-1.9677782d-08,-2.1003494d-09 /
      data fpppp(26,13,11,1),fpppp(26,13,11,2),fpppp(26,13,11,3)/
     x 1.1878816d-08,-4.9855140d-08, 1.1129793d-09 /
      data fpppp(26,13,12,1),fpppp(26,13,12,2),fpppp(26,13,12,3)/
     x 4.1617678d-08, 9.8650066d-09, 1.1888800d-10 /
      data fpppp(26,13,13,1),fpppp(26,13,13,2),fpppp(26,13,13,3)/
     x-3.2034087d-08,-3.7615574d-08,-1.0553140d-10 /
      data fpppp(26,13,14,1),fpppp(26,13,14,2),fpppp(26,13,14,3)/
     x-1.9238758d-07,-2.6960956d-08,-1.1015352d-10 /
      data fpppp(26,13,15,1),fpppp(26,13,15,2),fpppp(26,13,15,3)/
     x-5.8181530d-08,-1.6325657d-08, 5.7108798d-11 /
      data fpppp(26,13,16,1),fpppp(26,13,16,2),fpppp(26,13,16,3)/
     x-2.5224587d-08, 1.4660339d-08, 1.7302305d-10 /
      data fpppp(26,13,17,1),fpppp(26,13,17,2),fpppp(26,13,17,3)/
     x-5.5339161d-09, 2.2862095d-08,-1.8727194d-10 /
      data fpppp(26,13,18,1),fpppp(26,13,18,2),fpppp(26,13,18,3)/
     x-3.1069101d-08, 1.4631208d-08, 1.5363017d-10 /
      data fpppp(26,13,19,1),fpppp(26,13,19,2),fpppp(26,13,19,3)/
     x-9.1367455d-08,-3.6828933d-08,-1.6021410d-10 /
      data fpppp(26,13,20,1),fpppp(26,13,20,2),fpppp(26,13,20,3)/
     x-7.6416125d-08, 1.9974985d-08, 6.6054837d-11 /
      data fpppp(26,13,21,1),fpppp(26,13,21,2),fpppp(26,13,21,3)/
     x-7.6416125d-08, 1.6273942d-08, 4.6144879d-11 /
      data fpppp(26,13,22,1),fpppp(26,13,22,2),fpppp(26,13,22,3)/
     x-9.1367455d-08,-2.2024762d-08,-8.0574269d-11 /
      data fpppp(26,13,23,1),fpppp(26,13,23,2),fpppp(26,13,23,3)/
     x-3.1069101d-08,-4.0884435d-08,-1.4501919d-10 /
      data fpppp(26,14, 1,1),fpppp(26,14, 1,2),fpppp(26,14, 1,3)/
     x 9.4171797d-09, 2.2990113d-07,-1.4286301d-10 /
      data fpppp(26,14, 2,1),fpppp(26,14, 2,2),fpppp(26,14, 2,3)/
     x-1.2188395d-07, 4.4609472d-08,-4.4819249d-11 /
      data fpppp(26,14, 3,1),fpppp(26,14, 3,2),fpppp(26,14, 3,3)/
     x-2.8910851d-07,-3.5194940d-07, 1.6084608d-10 /
      data fpppp(26,14, 4,1),fpppp(26,14, 4,2),fpppp(26,14, 4,3)/
     x-2.8910851d-07,-3.5281510d-07, 1.6859585d-10 /
      data fpppp(26,14, 5,1),fpppp(26,14, 5,2),fpppp(26,14, 5,3)/
     x-1.2188395d-07, 4.8072263d-08,-7.5818336d-11 /
      data fpppp(26,14, 6,1),fpppp(26,14, 6,2),fpppp(26,14, 6,3)/
     x 9.4171797d-09, 2.1691567d-07,-2.6616433d-11 /
      data fpppp(26,14, 7,1),fpppp(26,14, 7,2),fpppp(26,14, 7,3)/
     x 1.0630279d-07, 1.7902240d-07,-6.8795427d-10 /
      data fpppp(26,14, 8,1),fpppp(26,14, 8,2),fpppp(26,14, 8,3)/
     x 2.3123514d-07, 2.3831541d-07, 9.1682762d-10 /
      data fpppp(26,14, 9,1),fpppp(26,14, 9,2),fpppp(26,14, 9,3)/
     x 7.9420379d-08,-3.6386328d-07,-2.2525869d-09 /
      data fpppp(26,14,10,1),fpppp(26,14,10,2),fpppp(26,14,10,3)/
     x 6.1713792d-07, 5.4933607d-07, 3.0346569d-09 /
      data fpppp(26,14,11,1),fpppp(26,14,11,2),fpppp(26,14,11,3)/
     x 2.8398890d-08,-3.4295411d-07,-1.6894446d-09 /
      data fpppp(26,14,12,1),fpppp(26,14,12,2),fpppp(26,14,12,3)/
     x-3.7974394d-08, 3.9481499d-08, 4.5314008d-10 /
      data fpppp(26,14,13,1),fpppp(26,14,13,2),fpppp(26,14,13,3)/
     x-2.9286341d-08,-3.7196115d-08,-1.0240737d-11 /
      data fpppp(26,14,14,1),fpppp(26,14,14,2),fpppp(26,14,14,3)/
     x 4.6955128d-07,-2.2836689d-08, 3.0343175d-10 /
      data fpppp(26,14,15,1),fpppp(26,14,15,2),fpppp(26,14,15,3)/
     x-7.9796237d-09, 4.7058528d-09, 2.8868505d-11 /
      data fpppp(26,14,16,1),fpppp(26,14,16,2),fpppp(26,14,16,3)/
     x-3.7515312d-08,-1.5987335d-08,-3.1216433d-10 /
      data fpppp(26,14,17,1),fpppp(26,14,17,2),fpppp(26,14,17,3)/
     x-3.2484756d-08, 2.6984383d-08, 3.0405355d-10 /
      data fpppp(26,14,18,1),fpppp(26,14,18,2),fpppp(26,14,18,3)/
     x-6.2585189d-08, 6.5310308d-09,-2.9975579d-10 /
      data fpppp(26,14,19,1),fpppp(26,14,19,2),fpppp(26,14,19,3)/
     x-4.2487579d-08,-8.5623051d-09, 8.2677567d-11 /
      data fpppp(26,14,20,1),fpppp(26,14,20,2),fpppp(26,14,20,3)/
     x-9.5031052d-08, 7.5514304d-09,-1.7450379d-11 /
      data fpppp(26,14,21,1),fpppp(26,14,21,2),fpppp(26,14,21,3)/
     x-9.5031052d-08, 6.4780248d-09, 2.9211271d-12 /
      data fpppp(26,14,22,1),fpppp(26,14,22,2),fpppp(26,14,22,3)/
     x-4.2487579d-08,-4.2686825d-09, 1.1915428d-12 /
      data fpppp(26,14,23,1),fpppp(26,14,23,2),fpppp(26,14,23,3)/
     x-6.2585189d-08,-9.5700541d-09, 5.8168051d-12 /
      data fpppp(26,15, 1,1),fpppp(26,15, 1,2),fpppp(26,15, 1,3)/
     x-1.0931650d-07, 7.3710149d-08, 1.8195857d-10 /
      data fpppp(26,15, 2,1),fpppp(26,15, 2,2),fpppp(26,15, 2,3)/
     x-7.3765063d-08,-1.6371013d-08, 9.9433389d-11 /
      data fpppp(26,15, 3,1),fpppp(26,15, 3,2),fpppp(26,15, 3,3)/
     x-2.6478659d-08,-2.1077723d-07,-6.7743200d-11 /
      data fpppp(26,15, 4,1),fpppp(26,15, 4,2),fpppp(26,15, 4,3)/
     x-2.6478659d-08,-2.0837071d-07,-8.4653594d-11 /
      data fpppp(26,15, 5,1),fpppp(26,15, 5,2),fpppp(26,15, 5,3)/
     x-7.3765063d-08,-2.5997104d-08, 1.6707497d-10 /
      data fpppp(26,15, 6,1),fpppp(26,15, 6,2),fpppp(26,15, 6,3)/
     x-1.0931650d-07, 1.0980799d-07,-7.1697349d-11 /
      data fpppp(26,15, 7,1),fpppp(26,15, 7,2),fpppp(26,15, 7,3)/
     x-8.4158955d-08, 1.0629689d-07, 9.7319729d-11 /
      data fpppp(26,15, 8,1),fpppp(26,15, 8,2),fpppp(26,15, 8,3)/
     x-1.7321354d-08, 1.2564615d-07,-5.1588054d-10 /
      data fpppp(26,15, 9,1),fpppp(26,15, 9,2),fpppp(26,15, 9,3)/
     x 4.7972376d-08, 2.1382741d-08, 1.1411289d-09 /
      data fpppp(26,15,10,1),fpppp(26,15,10,2),fpppp(26,15,10,3)/
     x-3.0039099d-07,-6.7686602d-09,-1.8421441d-09 /
      data fpppp(26,15,11,1),fpppp(26,15,11,2),fpppp(26,15,11,3)/
     x 5.8563018d-08, 6.2516667d-08, 1.2119506d-09 /
      data fpppp(26,15,12,1),fpppp(26,15,12,2),fpppp(26,15,12,3)/
     x 3.6210505d-08,-1.7857570d-07,-3.1618806d-10 /
      data fpppp(26,15,13,1),fpppp(26,15,13,2),fpppp(26,15,13,3)/
     x 4.4067014d-08, 4.8241209d-07, 2.7830203d-10 /
      data fpppp(26,15,14,1),fpppp(26,15,14,2),fpppp(26,15,14,3)/
     x-7.5190257d-07,-7.7772323d-07,-6.0644172d-12 /
      data fpppp(26,15,15,1),fpppp(26,15,15,2),fpppp(26,15,15,3)/
     x-2.2200314d-08, 4.5734911d-07,-1.4426710d-11 /
      data fpppp(26,15,16,1),fpppp(26,15,16,2),fpppp(26,15,16,3)/
     x-6.2693409d-08,-9.3534770d-08, 4.2550076d-10 /
      data fpppp(26,15,17,1),fpppp(26,15,17,2),fpppp(26,15,17,3)/
     x-2.3009526d-08,-7.7303540d-09,-3.8656440d-10 /
      data fpppp(26,15,18,1),fpppp(26,15,18,2),fpppp(26,15,18,3)/
     x 4.0362517d-08, 3.8617061d-08, 2.0601507d-10 /
      data fpppp(26,15,19,1),fpppp(26,15,19,2),fpppp(26,15,19,3)/
     x 1.0041814d-08,-2.9867222d-08,-3.3536236d-10 /
      data fpppp(26,15,20,1),fpppp(26,15,20,2),fpppp(26,15,20,3)/
     x 6.2463412d-08, 2.0655500d-08, 6.2589357d-11 /
      data fpppp(26,15,21,1),fpppp(26,15,21,2),fpppp(26,15,21,3)/
     x 6.2463412d-08, 1.6285489d-08, 2.8075675d-11 /
      data fpppp(26,15,22,1),fpppp(26,15,22,2),fpppp(26,15,22,3)/
     x 1.0041814d-08,-1.2387180d-08,-1.9730763d-10 /
      data fpppp(26,15,23,1),fpppp(26,15,23,2),fpppp(26,15,23,3)/
     x 4.0362517d-08,-2.6933096d-08,-3.1169016d-10 /
      data fpppp(26,16, 1,1),fpppp(26,16, 1,2),fpppp(26,16, 1,3)/
     x-1.1257774d-07,-4.4875498d-08, 3.6451487d-11 /
      data fpppp(26,16, 2,1),fpppp(26,16, 2,2),fpppp(26,16, 2,3)/
     x-1.1868939d-07,-5.6772667d-08,-5.7598153d-12 /
      data fpppp(26,16, 3,1),fpppp(26,16, 3,2),fpppp(26,16, 3,3)/
     x-3.2191298d-08,-8.5899532d-08,-9.9913999d-11 /
      data fpppp(26,16, 4,1),fpppp(26,16, 4,2),fpppp(26,16, 4,3)/
     x-3.2191298d-08,-7.9541901d-08,-9.3436560d-11 /
      data fpppp(26,16, 5,1),fpppp(26,16, 5,2),fpppp(26,16, 5,3)/
     x-1.1868939d-07,-8.2203191d-08,-3.1669572d-11 /
      data fpppp(26,16, 6,1),fpppp(26,16, 6,2),fpppp(26,16, 6,3)/
     x-1.1257774d-07, 5.0488965d-08, 1.3361307d-10 /
      data fpppp(26,16, 7,1),fpppp(26,16, 7,2),fpppp(26,16, 7,3)/
     x-8.7642369d-08, 5.1797603d-08, 9.7034413d-11 /
      data fpppp(26,16, 8,1),fpppp(26,16, 8,2),fpppp(26,16, 8,3)/
     x-9.9020897d-08, 5.0736415d-08,-2.6948938d-11 /
      data fpppp(26,16, 9,1),fpppp(26,16, 9,2),fpppp(26,16, 9,3)/
     x-3.7752629d-08, 2.7088659d-08,-2.9571379d-10 /
      data fpppp(26,16,10,1),fpppp(26,16,10,2),fpppp(26,16,10,3)/
     x 9.1009201d-08, 1.9924999d-08, 3.2270344d-10 /
      data fpppp(26,16,11,1),fpppp(26,16,11,2),fpppp(26,16,11,3)/
     x-2.8382755d-10,-9.0798119d-10,-2.8970910d-10 /
      data fpppp(26,16,12,1),fpppp(26,16,12,2),fpppp(26,16,12,3)/
     x 3.0889213d-08, 1.5756176d-08, 1.8823373d-10 /
      data fpppp(26,16,13,1),fpppp(26,16,13,2),fpppp(26,16,13,3)/
     x 7.8119729d-09,-3.6993418d-08,-3.8102208d-11 /
      data fpppp(26,16,14,1),fpppp(26,16,14,2),fpppp(26,16,14,3)/
     x 5.1212240d-07, 1.3288865d-08, 4.4743696d-11 /
      data fpppp(26,16,15,1),fpppp(26,16,15,2),fpppp(26,16,15,3)/
     x 5.4358037d-08,-7.0344481d-08, 1.8830207d-10 /
      data fpppp(26,16,16,1),fpppp(26,16,16,2),fpppp(26,16,16,3)/
     x 1.4507431d-07, 1.2006102d-07,-1.9161145d-10 /
      data fpppp(26,16,17,1),fpppp(26,16,17,2),fpppp(26,16,17,3)/
     x 4.0023605d-08,-6.7173953d-08, 2.4983125d-10 /
      data fpppp(26,16,18,1),fpppp(26,16,18,2),fpppp(26,16,18,3)/
     x 4.2727022d-10, 3.5513347d-09,-2.7304049d-10 /
      data fpppp(26,16,19,1),fpppp(26,16,19,2),fpppp(26,16,19,3)/
     x 5.9077297d-08, 1.5837176d-08, 1.6608875d-10 /
      data fpppp(26,16,20,1),fpppp(26,16,20,2),fpppp(26,16,20,3)/
     x 3.3367179d-08, 6.8420392d-09,-7.3438536d-11 /
      data fpppp(26,16,21,1),fpppp(26,16,21,2),fpppp(26,16,21,3)/
     x 3.3367179d-08, 7.6244872d-09,-4.7287809d-11 /
      data fpppp(26,16,22,1),fpppp(26,16,22,2),fpppp(26,16,22,3)/
     x 5.9077297d-08, 1.2707384d-08, 6.1485846d-11 /
      data fpppp(26,16,23,1),fpppp(26,16,23,2),fpppp(26,16,23,3)/
     x 4.2727022d-10, 1.5288055d-08, 1.1922041d-10 /
      data fpppp(26,17, 1,1),fpppp(26,17, 1,2),fpppp(26,17, 1,3)/
     x-8.3614108d-08,-3.0885263d-08,-5.0587860d-11 /
      data fpppp(26,17, 2,1),fpppp(26,17, 2,2),fpppp(26,17, 2,3)/
     x 2.0393256d-08,-2.8452702d-08,-3.0747437d-11 /
      data fpppp(26,17, 3,1),fpppp(26,17, 3,2),fpppp(26,17, 3,3)/
     x 8.5522678d-08,-2.5188169d-08, 7.6357797d-12 /
      data fpppp(26,17, 4,1),fpppp(26,17, 4,2),fpppp(26,17, 4,3)/
     x 8.5522678d-08,-2.1778999d-08, 1.4866735d-11 /
      data fpppp(26,17, 5,1),fpppp(26,17, 5,2),fpppp(26,17, 5,3)/
     x 2.0393256d-08,-4.2089382d-08,-5.9671260d-11 /
      data fpppp(26,17, 6,1),fpppp(26,17, 6,2),fpppp(26,17, 6,3)/
     x-8.3614108d-08, 2.0252289d-08, 5.7876474d-11 /
      data fpppp(26,17, 7,1),fpppp(26,17, 7,2),fpppp(26,17, 7,3)/
     x-1.4159382d-07,-3.3319485d-08,-2.8708481d-11 /
      data fpppp(26,17, 8,1),fpppp(26,17, 8,2),fpppp(26,17, 8,3)/
     x-1.0639108d-07, 5.8822461d-08, 7.6049275d-11 /
      data fpppp(26,17, 9,1),fpppp(26,17, 9,2),fpppp(26,17, 9,3)/
     x-1.0633492d-07,-1.4674033d-08,-2.4514545d-11 /
      data fpppp(26,17,10,1),fpppp(26,17,10,2),fpppp(26,17,10,3)/
     x-9.8884678d-08, 1.7208554d-08,-7.6079375d-11 /
      data fpppp(26,17,11,1),fpppp(26,17,11,2),fpppp(26,17,11,3)/
     x-1.7854160d-08, 1.4546131d-09, 2.7652699d-12 /
      data fpppp(26,17,12,1),fpppp(26,17,12,2),fpppp(26,17,12,3)/
     x-7.9177728d-09, 1.3812813d-08,-3.2854990d-11 /
      data fpppp(26,17,13,1),fpppp(26,17,13,2),fpppp(26,17,13,3)/
     x 1.0920584d-08,-1.4975355d-08, 2.6598713d-12 /
      data fpppp(26,17,14,1),fpppp(26,17,14,2),fpppp(26,17,14,3)/
     x-1.0671905d-07, 4.1285229d-09,-1.1014501d-11 /
      data fpppp(26,17,15,1),fpppp(26,17,15,2),fpppp(26,17,15,3)/
     x 3.0100009d-08,-6.9405232d-09,-7.4918120d-11 /
      data fpppp(26,17,16,1),fpppp(26,17,16,2),fpppp(26,17,16,3)/
     x-1.4632118d-08, 1.1615060d-08, 4.3595296d-11 /
      data fpppp(26,17,17,1),fpppp(26,17,17,2),fpppp(26,17,17,3)/
     x 7.3437726d-08, 3.6292509d-10,-8.7225090d-11 /
      data fpppp(26,17,18,1),fpppp(26,17,18,2),fpppp(26,17,18,3)/
     x 1.0249516d-07, 9.0986708d-09, 1.6135463d-10 /
      data fpppp(26,17,19,1),fpppp(26,17,19,2),fpppp(26,17,19,3)/
     x 5.8851499d-08,-1.2995362d-09,-1.1535903d-10 /
      data fpppp(26,17,20,1),fpppp(26,17,20,2),fpppp(26,17,20,3)/
     x 7.3175146d-08, 7.0489776d-09, 1.0142259d-10 /
      data fpppp(26,17,21,1),fpppp(26,17,21,2),fpppp(26,17,21,3)/
     x 7.3175146d-08, 6.3704564d-09, 8.3485326d-11 /
      data fpppp(26,17,22,1),fpppp(26,17,22,2),fpppp(26,17,22,3)/
     x 5.8851499d-08, 1.4145486d-09,-4.3609967d-11 /
      data fpppp(26,17,23,1),fpppp(26,17,23,2),fpppp(26,17,23,3)/
     x 1.0249516d-07,-1.0791473d-09,-1.0770438d-10 /
      data fpppp(26,18, 1,1),fpppp(26,18, 1,2),fpppp(26,18, 1,3)/
     x 9.7190502d-09,-8.2231717d-09, 1.1867986d-10 /
      data fpppp(26,18, 2,1),fpppp(26,18, 2,2),fpppp(26,18, 2,3)/
     x 2.5035089d-08,-8.0191126d-09, 7.3189752d-11 /
      data fpppp(26,18, 3,1),fpppp(26,18, 3,2),fpppp(26,18, 3,3)/
     x 3.6254994d-08,-8.6013083d-09,-2.1169775d-11 /
      data fpppp(26,18, 4,1),fpppp(26,18, 4,2),fpppp(26,18, 4,3)/
     x 3.6254994d-08,-6.8172440d-09,-2.6628509d-11 /
      data fpppp(26,18, 5,1),fpppp(26,18, 5,2),fpppp(26,18, 5,3)/
     x 2.5035089d-08,-1.5155370d-08, 9.5024686d-11 /
      data fpppp(26,18, 6,1),fpppp(26,18, 6,2),fpppp(26,18, 6,3)/
     x 9.7190502d-09, 1.8537793d-08, 3.6798857d-11 /
      data fpppp(26,18, 7,1),fpppp(26,18, 7,2),fpppp(26,18, 7,3)/
     x-1.8623761d-08,-2.9437962d-08, 2.5458125d-11 /
      data fpppp(26,18, 8,1),fpppp(26,18, 8,2),fpppp(26,18, 8,3)/
     x-4.1394223d-08, 2.4380199d-08, 1.0199548d-11 /
      data fpppp(26,18, 9,1),fpppp(26,18, 9,2),fpppp(26,18, 9,3)/
     x-4.1026576d-08,-2.0123554d-08,-4.3677481d-11 /
      data fpppp(26,18,10,1),fpppp(26,18,10,2),fpppp(26,18,10,3)/
     x-2.4202919d-08, 2.5293630d-08, 3.9641704d-12 /
      data fpppp(26,18,11,1),fpppp(26,18,11,2),fpppp(26,18,11,3)/
     x-3.4411479d-08,-2.8468007d-08,-9.3302979d-11 /
      data fpppp(26,18,12,1),fpppp(26,18,12,2),fpppp(26,18,12,3)/
     x 1.1412269d-09, 1.4059597d-08,-3.1359888d-11 /
      data fpppp(26,18,13,1),fpppp(26,18,13,2),fpppp(26,18,13,3)/
     x 2.9143391d-08, 4.3743888d-09,-6.2401807d-11 /
      data fpppp(26,18,14,1),fpppp(26,18,14,2),fpppp(26,18,14,3)/
     x 7.7074969d-08, 4.8564328d-09,-2.6681455d-11 /
      data fpppp(26,18,15,1),fpppp(26,18,15,2),fpppp(26,18,15,3)/
     x 4.4122463d-08,-5.5453680d-09,-5.4782017d-11 /
      data fpppp(26,18,16,1),fpppp(26,18,16,2),fpppp(26,18,16,3)/
     x 5.7305133d-08, 9.7271371d-09,-1.2164283d-11 /
      data fpppp(26,18,17,1),fpppp(26,18,17,2),fpppp(26,18,17,3)/
     x 3.9778709d-08, 8.4082785d-09, 2.2799729d-11 /
      data fpppp(26,18,18,1),fpppp(26,18,18,2),fpppp(26,18,18,3)/
     x 2.7042098d-08,-1.9751404d-08,-3.7905935d-11 /
      data fpppp(26,18,19,1),fpppp(26,18,19,2),fpppp(26,18,19,3)/
     x 4.9836030d-08, 2.1617473d-08, 1.1372847d-10 /
      data fpppp(26,18,20,1),fpppp(26,18,20,2),fpppp(26,18,20,3)/
     x 4.1828720d-08,-1.8537279d-09, 5.9751732d-11 /
      data fpppp(26,18,21,1),fpppp(26,18,21,2),fpppp(26,18,21,3)/
     x 4.1828720d-08, 6.2991628d-10, 6.8145256d-11 /
      data fpppp(26,18,22,1),fpppp(26,18,22,2),fpppp(26,18,22,3)/
     x 4.9836030d-08, 1.1682897d-08, 8.0154381d-11 /
      data fpppp(26,18,23,1),fpppp(26,18,23,2),fpppp(26,18,23,3)/
     x 2.7042098d-08, 1.7503259d-08, 8.7996912d-11 /
      data fpppp(26,19, 1,1),fpppp(26,19, 1,2),fpppp(26,19, 1,3)/
     x 8.4660915d-08,-2.0854195d-21, 2.1471699d-10 /
      data fpppp(26,19, 2,1),fpppp(26,19, 2,2),fpppp(26,19, 2,3)/
     x 6.8088585d-08, 2.0599028d-22, 1.4029128d-10 /
      data fpppp(26,19, 3,1),fpppp(26,19, 3,2),fpppp(26,19, 3,3)/
     x 3.4696356d-08,-1.5843795d-21,-1.1016664d-11 /
      data fpppp(26,19, 4,1),fpppp(26,19, 4,2),fpppp(26,19, 4,3)/
     x 3.4696356d-08,-2.0848422d-21,-2.5324170d-11 /
      data fpppp(26,19, 5,1),fpppp(26,19, 5,2),fpppp(26,19, 5,3)/
     x 6.8088585d-08, 2.5369562d-21, 1.9752131d-10 /
      data fpppp(26,19, 6,1),fpppp(26,19, 6,2),fpppp(26,19, 6,3)/
     x 8.4660915d-08, 3.9209669d-22, 1.0438835d-13 /
      data fpppp(26,19, 7,1),fpppp(26,19, 7,2),fpppp(26,19, 7,3)/
     x 5.3797297d-08,-1.9015172d-21, 2.8222017d-11 /
      data fpppp(26,19, 8,1),fpppp(26,19, 8,2),fpppp(26,19, 8,3)/
     x 2.9263359d-09, 8.4780582d-22,-7.4079107d-12 /
      data fpppp(26,19, 9,1),fpppp(26,19, 9,2),fpppp(26,19, 9,3)/
     x-1.3972700d-08,-1.6398013d-21, 2.0120208d-11 /
      data fpppp(26,19,10,1),fpppp(26,19,10,2),fpppp(26,19,10,3)/
     x-2.5114199d-08,-1.6933480d-22,-5.2799817d-11 /
      data fpppp(26,19,11,1),fpppp(26,19,11,2),fpppp(26,19,11,3)/
     x-5.1258230d-08, 1.2136870d-21,-7.8359051d-11 /
      data fpppp(26,19,12,1),fpppp(26,19,12,2),fpppp(26,19,12,3)/
     x-3.4757694d-09,-6.2403095d-22,-9.3460164d-11 /
      data fpppp(26,19,13,1),fpppp(26,19,13,2),fpppp(26,19,13,3)/
     x 4.3047857d-08,-6.0164811d-22,-9.7228125d-11 /
      data fpppp(26,19,14,1),fpppp(26,19,14,2),fpppp(26,19,14,3)/
     x 3.1544568d-08,-3.2294496d-21,-5.3803050d-11 /
      data fpppp(26,19,15,1),fpppp(26,19,15,2),fpppp(26,19,15,3)/
     x 4.7207636d-08,-1.3763577d-21,-1.1560486d-10 /
      data fpppp(26,19,16,1),fpppp(26,19,16,2),fpppp(26,19,16,3)/
     x 6.3058475d-08, 3.1577239d-21, 1.5209373d-11 /
      data fpppp(26,19,17,1),fpppp(26,19,17,2),fpppp(26,19,17,3)/
     x 2.5283445d-08, 7.2873802d-22, 5.0870733d-12 /
      data fpppp(26,19,18,1),fpppp(26,19,18,2),fpppp(26,19,18,3)/
     x 2.3093099d-09,-1.9445439d-21,-5.6122015d-11 /
      data fpppp(26,19,19,1),fpppp(26,19,19,2),fpppp(26,19,19,3)/
     x 4.3331895d-08, 3.1046832d-21, 1.9694875d-10 /
      data fpppp(26,19,20,1),fpppp(26,19,20,2),fpppp(26,19,20,3)/
     x 3.0812121d-08, 1.8009128d-21, 7.9947154d-11 /
      data fpppp(26,19,21,1),fpppp(26,19,21,2),fpppp(26,19,21,3)/
     x 3.0812121d-08,-1.2670108d-21, 9.4551815d-11 /
      data fpppp(26,19,22,1),fpppp(26,19,22,2),fpppp(26,19,22,3)/
     x 4.3331895d-08, 2.3480658d-21, 1.3853011d-10 /
      data fpppp(26,19,23,1),fpppp(26,19,23,2),fpppp(26,19,23,3)/
     x 2.3093099d-09,-4.4938226d-22, 1.6294789d-10 /
      data fpppp(27, 1, 1,1),fpppp(27, 1, 1,2),fpppp(27, 1, 1,3)/
     x 5.3735855d-07, 6.3074146d-21,-3.0096854d-11 /
      data fpppp(27, 1, 2,1),fpppp(27, 1, 2,2),fpppp(27, 1, 2,3)/
     x 5.8891143d-07, 5.9860841d-21,-4.1975308d-11 /
      data fpppp(27, 1, 3,1),fpppp(27, 1, 3,2),fpppp(27, 1, 3,3)/
     x 5.0746881d-07,-3.2889388d-21,-6.0245507d-11 /
      data fpppp(27, 1, 4,1),fpppp(27, 1, 4,2),fpppp(27, 1, 4,3)/
     x 5.0746881d-07,-1.7693546d-21,-7.2816858d-11 /
      data fpppp(27, 1, 5,1),fpppp(27, 1, 5,2),fpppp(27, 1, 5,3)/
     x 5.8891143d-07, 1.7105436d-23, 8.3100966d-12 /
      data fpppp(27, 1, 6,1),fpppp(27, 1, 6,2),fpppp(27, 1, 6,3)/
     x 5.3735855d-07, 1.1491224d-21,-2.1866712d-10 /
      data fpppp(27, 1, 7,1),fpppp(27, 1, 7,2),fpppp(27, 1, 7,3)/
     x 3.8534981d-07,-5.3977056d-21,-1.6878672d-10 /
      data fpppp(27, 1, 8,1),fpppp(27, 1, 8,2),fpppp(27, 1, 8,3)/
     x 6.2776250d-08,-2.4651177d-21, 1.2037571d-10 /
      data fpppp(27, 1, 9,1),fpppp(27, 1, 9,2),fpppp(27, 1, 9,3)/
     x-3.6276034d-07, 3.1391897d-21,-1.0780492d-10 /
      data fpppp(27, 1,10,1),fpppp(27, 1,10,2),fpppp(27, 1,10,3)/
     x-6.6897667d-07, 6.8865764d-21, 2.2458484d-10 /
      data fpppp(27, 1,11,1),fpppp(27, 1,11,2),fpppp(27, 1,11,3)/
     x-9.1400662d-07,-3.9407408d-21, 5.1281263d-11 /
      data fpppp(27, 1,12,1),fpppp(27, 1,12,2),fpppp(27, 1,12,3)/
     x-9.6449373d-07, 5.5122503d-21, 2.9730320d-10 /
      data fpppp(27, 1,13,1),fpppp(27, 1,13,2),fpppp(27, 1,13,3)/
     x-8.5384300d-07,-3.1545280d-22, 1.8553178d-10 /
      data fpppp(27, 1,14,1),fpppp(27, 1,14,2),fpppp(27, 1,14,3)/
     x-6.5965184d-07,-3.2290939d-21, 2.1137549d-10 /
      data fpppp(27, 1,15,1),fpppp(27, 1,15,2),fpppp(27, 1,15,3)/
     x-3.0549675d-07, 2.8145862d-21, 3.8748747d-11 /
      data fpppp(27, 1,16,1),fpppp(27, 1,16,2),fpppp(27, 1,16,3)/
     x 1.3687454d-07,-4.9280304d-22, 6.7473501d-11 /
      data fpppp(27, 1,17,1),fpppp(27, 1,17,2),fpppp(27, 1,17,3)/
     x 5.1918776d-07,-2.5922963d-21,-1.6992800d-10 /
      data fpppp(27, 1,18,1),fpppp(27, 1,18,2),fpppp(27, 1,18,3)/
     x 7.2547953d-07,-1.7978155d-21,-1.1975977d-10 /
      data fpppp(27, 1,19,1),fpppp(27, 1,19,2),fpppp(27, 1,19,3)/
     x 6.9253140d-07,-1.7697880d-22,-1.6733978d-10 /
      data fpppp(27, 1,20,1),fpppp(27, 1,20,2),fpppp(27, 1,20,3)/
     x 7.0758561d-07,-1.3043235d-21,-9.7597095d-11 /
      data fpppp(27, 1,21,1),fpppp(27, 1,21,2),fpppp(27, 1,21,3)/
     x 7.0758561d-07, 2.3146951d-21,-1.0140057d-10 /
      data fpppp(27, 1,22,1),fpppp(27, 1,22,2),fpppp(27, 1,22,3)/
     x 6.9253140d-07, 2.2655277d-21,-1.5212587d-10 /
      data fpppp(27, 1,23,1),fpppp(27, 1,23,2),fpppp(27, 1,23,3)/
     x 7.2547953d-07, 8.9481151d-21,-1.7681194d-10 /
      data fpppp(27, 2, 1,1),fpppp(27, 2, 1,2),fpppp(27, 2, 1,3)/
     x 1.4515954d-07, 1.8066791d-07,-2.0166570d-11 /
      data fpppp(27, 2, 2,1),fpppp(27, 2, 2,2),fpppp(27, 2, 2,3)/
     x 1.3895421d-07, 7.3263622d-08,-1.5328828d-11 /
      data fpppp(27, 2, 3,1),fpppp(27, 2, 3,2),fpppp(27, 2, 3,3)/
     x 6.0590019d-08,-1.4882774d-07,-2.0309359d-12 /
      data fpppp(27, 2, 4,1),fpppp(27, 2, 4,2),fpppp(27, 2, 4,3)/
     x 6.0590019d-08,-1.6293394d-07,-7.1607137d-12 /
      data fpppp(27, 2, 5,1),fpppp(27, 2, 5,2),fpppp(27, 2, 5,3)/
     x 1.3895421d-07, 1.2968843d-07, 5.1902836d-12 /
      data fpppp(27, 2, 6,1),fpppp(27, 2, 6,2),fpppp(27, 2, 6,3)/
     x 1.4515954d-07,-3.0925136d-08,-9.7113237d-11 /
      data fpppp(27, 2, 7,1),fpppp(27, 2, 7,2),fpppp(27, 2, 7,3)/
     x 1.1579813d-07, 1.1288283d-08,-6.6447128d-11 /
      data fpppp(27, 2, 8,1),fpppp(27, 2, 8,2),fpppp(27, 2, 8,3)/
     x 1.5880509d-08, 2.9121007d-08, 4.9778325d-11 /
      data fpppp(27, 2, 9,1),fpppp(27, 2, 9,2),fpppp(27, 2, 9,3)/
     x-1.2813227d-07,-1.3665584d-08,-6.2488567d-11 /
      data fpppp(27, 2,10,1),fpppp(27, 2,10,2),fpppp(27, 2,10,3)/
     x-2.1796742d-07, 5.4441604d-08, 7.2694212d-11 /
      data fpppp(27, 2,11,1),fpppp(27, 2,11,2),fpppp(27, 2,11,3)/
     x-2.9291451d-07, 2.5145803d-08, 8.0803447d-12 /
      data fpppp(27, 2,12,1),fpppp(27, 2,12,2),fpppp(27, 2,12,3)/
     x-3.0028421d-07, 2.9924889d-08, 1.2095823d-10 /
      data fpppp(27, 2,13,1),fpppp(27, 2,13,2),fpppp(27, 2,13,3)/
     x-2.5932756d-07, 8.0779973d-08, 7.6035048d-11 /
      data fpppp(27, 2,14,1),fpppp(27, 2,14,2),fpppp(27, 2,14,3)/
     x-2.0774634d-07, 6.5066699d-09, 7.3289964d-11 /
      data fpppp(27, 2,15,1),fpppp(27, 2,15,2),fpppp(27, 2,15,3)/
     x-9.1961131d-08, 8.8722667d-09, 1.1240148d-11 /
      data fpppp(27, 2,16,1),fpppp(27, 2,16,2),fpppp(27, 2,16,3)/
     x 5.9979508d-08, 3.1237271d-08, 3.4061492d-11 /
      data fpppp(27, 2,17,1),fpppp(27, 2,17,2),fpppp(27, 2,17,3)/
     x 1.9007988d-07,-9.9374721d-09,-6.4915611d-11 /
      data fpppp(27, 2,18,1),fpppp(27, 2,18,2),fpppp(27, 2,18,3)/
     x 2.4809759d-07, 5.3194512d-08,-5.0402485d-11 /
      data fpppp(27, 2,19,1),fpppp(27, 2,19,2),fpppp(27, 2,19,3)/
     x 1.9942869d-07, 9.4045765d-09,-8.0860700d-11 /
      data fpppp(27, 2,20,1),fpppp(27, 2,20,2),fpppp(27, 2,20,3)/
     x 1.7597439d-07,-1.1707955d-07,-1.2722743d-11 /
      data fpppp(27, 2,21,1),fpppp(27, 2,21,2),fpppp(27, 2,21,3)/
     x 1.7597439d-07,-1.1635633d-07,-1.5677929d-11 /
      data fpppp(27, 2,22,1),fpppp(27, 2,22,2),fpppp(27, 2,22,3)/
     x 1.9942869d-07, 6.5116666d-09,-6.9039954d-11 /
      data fpppp(27, 2,23,1),fpppp(27, 2,23,2),fpppp(27, 2,23,3)/
     x 2.4809759d-07, 6.4042924d-08,-9.4730282d-11 /
      data fpppp(27, 3, 1,1),fpppp(27, 3, 1,2),fpppp(27, 3, 1,3)/
     x-6.0228132d-07, 1.4181996d-07,-8.3544331d-12 /
      data fpppp(27, 3, 2,1),fpppp(27, 3, 2,2),fpppp(27, 3, 2,3)/
     x-7.4766738d-07, 3.0862356d-08,-1.8474248d-11 /
      data fpppp(27, 3, 3,1),fpppp(27, 3, 3,2),fpppp(27, 3, 3,3)/
     x-1.0549725d-06,-1.9903008d-07,-4.5453715d-11 /
      data fpppp(27, 3, 4,1),fpppp(27, 3, 4,2),fpppp(27, 3, 4,3)/
     x-1.0549725d-06,-2.1280935d-07,-3.6188956d-11 /
      data fpppp(27, 3, 5,1),fpppp(27, 3, 5,2),fpppp(27, 3, 5,3)/
     x-7.4766738d-07, 8.5979415d-08,-5.5533285d-11 /
      data fpppp(27, 3, 6,1),fpppp(27, 3, 6,2),fpppp(27, 3, 6,3)/
     x-6.0228132d-07,-6.4869005d-08, 1.3061695d-10 /
      data fpppp(27, 3, 7,1),fpppp(27, 3, 7,2),fpppp(27, 3, 7,3)/
     x-4.6759407d-07,-4.5372617d-08, 2.0704975d-10 /
      data fpppp(27, 3, 8,1),fpppp(27, 3, 8,2),fpppp(27, 3, 8,3)/
     x-2.1612762d-07,-2.9530605d-09,-1.2883951d-11 /
      data fpppp(27, 3, 9,1),fpppp(27, 3, 9,2),fpppp(27, 3, 9,3)/
     x 8.3200527d-08, 5.3916347d-08, 7.8864440d-11 /
      data fpppp(27, 3,10,1),fpppp(27, 3,10,2),fpppp(27, 3,10,3)/
     x 2.8501271d-07, 8.3603071d-08,-6.6387751d-11 /
      data fpppp(27, 3,11,1),fpppp(27, 3,11,2),fpppp(27, 3,11,3)/
     x 4.2659306d-07, 1.3067139d-07,-1.6060362d-10 /
      data fpppp(27, 3,12,1),fpppp(27, 3,12,2),fpppp(27, 3,12,3)/
     x 4.5471139d-07, 1.1500118d-07,-2.0210613d-10 /
      data fpppp(27, 3,13,1),fpppp(27, 3,13,2),fpppp(27, 3,13,3)/
     x 4.1041470d-07, 1.4260280d-07,-2.0879097d-10 /
      data fpppp(27, 3,14,1),fpppp(27, 3,14,2),fpppp(27, 3,14,3)/
     x 2.9467628d-07, 8.8287496d-08,-4.7089355d-11 /
      data fpppp(27, 3,15,1),fpppp(27, 3,15,2),fpppp(27, 3,15,3)/
     x 8.0218259d-08, 5.3665319d-08,-3.4374293d-11 /
      data fpppp(27, 3,16,1),fpppp(27, 3,16,2),fpppp(27, 3,16,3)/
     x-1.8564344d-07, 2.4951505d-08, 2.2149436d-10 /
      data fpppp(27, 3,17,1),fpppp(27, 3,17,2),fpppp(27, 3,17,3)/
     x-4.5406521d-07,-5.5682806d-08, 1.1940008d-10 /
      data fpppp(27, 3,18,1),fpppp(27, 3,18,2),fpppp(27, 3,18,3)/
     x-5.8409630d-07,-3.8817880d-08, 5.6917335d-11 /
      data fpppp(27, 3,19,1),fpppp(27, 3,19,2),fpppp(27, 3,19,3)/
     x-6.5413707d-07, 2.9448560d-08, 5.8782460d-11 /
      data fpppp(27, 3,20,1),fpppp(27, 3,20,2),fpppp(27, 3,20,3)/
     x-9.3388127d-07,-1.9235248d-07,-1.9059082d-11 /
      data fpppp(27, 3,21,1),fpppp(27, 3,21,2),fpppp(27, 3,21,3)/
     x-9.3388127d-07,-1.8419867d-07,-1.7246210d-11 /
      data fpppp(27, 3,22,1),fpppp(27, 3,22,2),fpppp(27, 3,22,3)/
     x-6.5413707d-07,-3.1666786d-09, 5.1530971d-11 /
      data fpppp(27, 3,23,1),fpppp(27, 3,23,2),fpppp(27, 3,23,3)/
     x-5.8409630d-07, 8.3489265d-08, 8.4110421d-11 /
      data fpppp(27, 4, 1,1),fpppp(27, 4, 1,2),fpppp(27, 4, 1,3)/
     x-1.0637572d-07,-1.0275300d-07,-3.1287786d-12 /
      data fpppp(27, 4, 2,1),fpppp(27, 4, 2,2),fpppp(27, 4, 2,3)/
     x-1.0596369d-07,-1.0536848d-07, 8.2651983d-11 /
      data fpppp(27, 4, 3,1),fpppp(27, 4, 3,2),fpppp(27, 4, 3,3)/
     x 1.6985804d-07,-1.1261461d-07, 2.6685423d-10 /
      data fpppp(27, 4, 4,1),fpppp(27, 4, 4,2),fpppp(27, 4, 4,3)/
     x 1.6985804d-07,-1.0974192d-07, 2.6617815d-10 /
      data fpppp(27, 4, 5,1),fpppp(27, 4, 5,2),fpppp(27, 4, 5,3)/
     x-1.0596369d-07,-1.1685923d-07, 8.5356290d-11 /
      data fpppp(27, 4, 6,1),fpppp(27, 4, 6,2),fpppp(27, 4, 6,3)/
     x-1.0637572d-07,-5.9662672d-08,-1.3269930d-11 /
      data fpppp(27, 4, 7,1),fpppp(27, 4, 7,2),fpppp(27, 4, 7,3)/
     x 4.7455558d-08,-2.3623298d-08,-1.1850387d-10 /
      data fpppp(27, 4, 8,1),fpppp(27, 4, 8,2),fpppp(27, 4, 8,3)/
     x 1.9975761d-07, 7.2130992d-09,-1.0331910d-10 /
      data fpppp(27, 4, 9,1),fpppp(27, 4, 9,2),fpppp(27, 4, 9,3)/
     x 3.7606678d-07, 4.5485898d-08,-1.1591084d-10 /
      data fpppp(27, 4,10,1),fpppp(27, 4,10,2),fpppp(27, 4,10,3)/
     x 6.0609474d-07, 9.2406420d-08,-2.5030003d-10 /
      data fpppp(27, 4,11,1),fpppp(27, 4,11,2),fpppp(27, 4,11,3)/
     x 8.0164652d-07, 1.3312635d-07, 1.0990308d-10 /
      data fpppp(27, 4,12,1),fpppp(27, 4,12,2),fpppp(27, 4,12,3)/
     x 8.9195568d-07, 1.4120484d-07,-1.1652607d-11 /
      data fpppp(27, 4,13,1),fpppp(27, 4,13,2),fpppp(27, 4,13,3)/
     x 8.1686312d-07, 1.3625128d-07, 1.2003552d-10 /
      data fpppp(27, 4,14,1),fpppp(27, 4,14,2),fpppp(27, 4,14,3)/
     x 6.2028901d-07, 1.0501443d-07,-2.2944039d-10 /
      data fpppp(27, 4,15,1),fpppp(27, 4,15,2),fpppp(27, 4,15,3)/
     x 3.9714445d-07, 6.9603393d-08,-1.6618290d-11 /
      data fpppp(27, 4,16,1),fpppp(27, 4,16,2),fpppp(27, 4,16,3)/
     x 1.5928131d-07, 1.4961720d-08,-3.6402984d-10 /
      data fpppp(27, 4,17,1),fpppp(27, 4,17,2),fpppp(27, 4,17,3)/
     x 4.4199260d-09,-6.8358952d-09, 2.6154214d-11 /
      data fpppp(27, 4,18,1),fpppp(27, 4,18,2),fpppp(27, 4,18,3)/
     x-1.7444834d-07,-4.8022047d-08, 3.1368291d-11 /
      data fpppp(27, 4,19,1),fpppp(27, 4,19,2),fpppp(27, 4,19,3)/
     x-2.4608219d-07,-1.3582354d-07, 1.2351341d-11 /
      data fpppp(27, 4,20,1),fpppp(27, 4,20,2),fpppp(27, 4,20,3)/
     x-1.9881374d-08,-1.2493375d-07, 2.9384200d-10 /
      data fpppp(27, 4,21,1),fpppp(27, 4,21,2),fpppp(27, 4,21,3)/
     x-1.9881374d-08,-1.2934277d-07, 2.8670374d-10 /
      data fpppp(27, 4,22,1),fpppp(27, 4,22,2),fpppp(27, 4,22,3)/
     x-2.4608219d-07,-1.1818745d-07, 4.0904364d-11 /
      data fpppp(27, 4,23,1),fpppp(27, 4,23,2),fpppp(27, 4,23,3)/
     x-1.7444834d-07,-1.1415737d-07,-7.5705547d-11 /
      data fpppp(27, 5, 1,1),fpppp(27, 5, 1,2),fpppp(27, 5, 1,3)/
     x 3.4723318d-07,-4.4512062d-08,-1.2908898d-10 /
      data fpppp(27, 5, 2,1),fpppp(27, 5, 2,2),fpppp(27, 5, 2,3)/
     x 2.2489342d-07,-6.8775458d-08, 1.7783376d-11 /
      data fpppp(27, 5, 3,1),fpppp(27, 5, 3,2),fpppp(27, 5, 3,3)/
     x 6.0431720d-08,-1.2271071d-07, 3.2832708d-10 /
      data fpppp(27, 5, 4,1),fpppp(27, 5, 4,2),fpppp(27, 5, 4,3)/
     x 6.0431720d-08,-1.1931175d-07, 3.3564695d-10 /
      data fpppp(27, 5, 5,1),fpppp(27, 5, 5,2),fpppp(27, 5, 5,3)/
     x 2.2489342d-07,-8.2371299d-08,-1.1496116d-11 /
      data fpppp(27, 5, 6,1),fpppp(27, 5, 6,2),fpppp(27, 5, 6,3)/
     x 3.4723318d-07, 6.4723392d-09,-1.9290887d-11 /
      data fpppp(27, 5, 7,1),fpppp(27, 5, 7,2),fpppp(27, 5, 7,3)/
     x 3.4994080d-07, 3.7270609d-09,-2.4041539d-10 /
      data fpppp(27, 5, 8,1),fpppp(27, 5, 8,2),fpppp(27, 5, 8,3)/
     x 3.4984150d-07, 4.1901763d-08,-1.2256141d-10 /
      data fpppp(27, 5, 9,1),fpppp(27, 5, 9,2),fpppp(27, 5, 9,3)/
     x 3.2582811d-07, 5.3340466d-08,-1.5295283d-10 /
      data fpppp(27, 5,10,1),fpppp(27, 5,10,2),fpppp(27, 5,10,3)/
     x 2.3703428d-07, 6.4125997d-08, 1.6723664d-10 /
      data fpppp(27, 5,11,1),fpppp(27, 5,11,2),fpppp(27, 5,11,3)/
     x 1.2986748d-07, 5.1121798d-08,-9.9872029d-11 /
      data fpppp(27, 5,12,1),fpppp(27, 5,12,2),fpppp(27, 5,12,3)/
     x 7.1431011d-08, 5.6628150d-08, 7.2521085d-11 /
      data fpppp(27, 5,13,1),fpppp(27, 5,13,2),fpppp(27, 5,13,3)/
     x 1.2741675d-07, 3.7881045d-08,-1.0570586d-10 /
      data fpppp(27, 5,14,1),fpppp(27, 5,14,2),fpppp(27, 5,14,3)/
     x 2.3474845d-07, 9.4574593d-08, 1.1846545d-10 /
      data fpppp(27, 5,15,1),fpppp(27, 5,15,2),fpppp(27, 5,15,3)/
     x 3.0930683d-07, 4.8452529d-08,-2.7925597d-10 /
      data fpppp(27, 5,16,1),fpppp(27, 5,16,2),fpppp(27, 5,16,3)/
     x 3.9090366d-07, 7.7254903d-08, 1.4241348d-12 /
      data fpppp(27, 5,17,1),fpppp(27, 5,17,2),fpppp(27, 5,17,3)/
     x 3.7546679d-07, 2.2381348d-08,-3.1111003d-10 /
      data fpppp(27, 5,18,1),fpppp(27, 5,18,2),fpppp(27, 5,18,3)/
     x 3.6308306d-07,-5.5742422d-09,-4.0817247d-11 /
      data fpppp(27, 5,19,1),fpppp(27, 5,19,2),fpppp(27, 5,19,3)/
     x 2.7609029d-07,-7.3754893d-08, 1.3261226d-10 /
      data fpppp(27, 5,20,1),fpppp(27, 5,20,2),fpppp(27, 5,20,3)/
     x 8.2326668d-08,-1.4366557d-07, 2.5891748d-10 /
      data fpppp(27, 5,21,1),fpppp(27, 5,21,2),fpppp(27, 5,21,3)/
     x 8.2326668d-08,-1.4535334d-07, 2.6435200d-10 /
      data fpppp(27, 5,22,1),fpppp(27, 5,22,2),fpppp(27, 5,22,3)/
     x 2.7609029d-07,-6.7003817d-08, 1.1087421d-10 /
      data fpppp(27, 5,23,1),fpppp(27, 5,23,2),fpppp(27, 5,23,3)/
     x 3.6308306d-07,-3.0890780d-08, 4.0700449d-11 /
      data fpppp(27, 6, 1,1),fpppp(27, 6, 1,2),fpppp(27, 6, 1,3)/
     x 2.3734471d-07,-1.2113067d-09, 3.5160829d-10 /
      data fpppp(27, 6, 2,1),fpppp(27, 6, 2,2),fpppp(27, 6, 2,3)/
     x 2.3663746d-07,-2.6083101d-08, 1.2196735d-10 /
      data fpppp(27, 6, 3,1),fpppp(27, 6, 3,2),fpppp(27, 6, 3,3)/
     x 1.9209342d-07,-7.9178880d-08,-3.5529747d-10 /
      data fpppp(27, 6, 4,1),fpppp(27, 6, 4,2),fpppp(27, 6, 4,3)/
     x 1.9209342d-07,-7.9530496d-08,-3.8123758d-10 /
      data fpppp(27, 6, 5,1),fpppp(27, 6, 5,2),fpppp(27, 6, 5,3)/
     x 2.3663746d-07,-2.4676639d-08, 2.2572780d-10 /
      data fpppp(27, 6, 6,1),fpppp(27, 6, 6,2),fpppp(27, 6, 6,3)/
     x 2.3734471d-07,-6.4855401d-09,-3.7493390d-11 /
      data fpppp(27, 6, 7,1),fpppp(27, 6, 7,2),fpppp(27, 6, 7,3)/
     x 2.7269725d-07, 3.4602352d-08, 2.4677329d-10 /
      data fpppp(27, 6, 8,1),fpppp(27, 6, 8,2),fpppp(27, 6, 8,3)/
     x 2.2420095d-07, 4.4977829d-08, 9.5060220d-11 /
      data fpppp(27, 6, 9,1),fpppp(27, 6, 9,2),fpppp(27, 6, 9,3)/
     x 8.5321643d-08, 2.2088213d-08, 3.1513242d-10 /
      data fpppp(27, 6,10,1),fpppp(27, 6,10,2),fpppp(27, 6,10,3)/
     x-5.2170698d-08, 1.9869482d-08,-6.9783064d-11 /
      data fpppp(27, 6,11,1),fpppp(27, 6,11,2),fpppp(27, 6,11,3)/
     x-1.5348948d-07, 3.3391240d-10, 2.6720939d-11 /
      data fpppp(27, 6,12,1),fpppp(27, 6,12,2),fpppp(27, 6,12,3)/
     x-1.7584252d-07, 3.1805354d-08,-2.9583881d-10 /
      data fpppp(27, 6,13,1),fpppp(27, 6,13,2),fpppp(27, 6,13,3)/
     x-1.7573755d-07,-1.5976303d-08,-8.4719658d-11 /
      data fpppp(27, 6,14,1),fpppp(27, 6,14,2),fpppp(27, 6,14,3)/
     x-6.9819828d-08, 3.6044284d-08,-1.1698402d-10 /
      data fpppp(27, 6,15,1),fpppp(27, 6,15,2),fpppp(27, 6,15,3)/
     x 7.3124967d-08, 5.4514080d-08, 2.9140014d-10 /
      data fpppp(27, 6,16,1),fpppp(27, 6,16,2),fpppp(27, 6,16,3)/
     x 1.7466108d-07, 5.0815443d-08,-1.3603276d-13 /
      data fpppp(27, 6,17,1),fpppp(27, 6,17,2),fpppp(27, 6,17,3)/
     x 2.5968209d-07, 5.7668578d-08, 2.5440528d-10 /
      data fpppp(27, 6,18,1),fpppp(27, 6,18,2),fpppp(27, 6,18,3)/
     x 2.5161025d-07,-3.5609038d-09, 2.5892604d-11 /
      data fpppp(27, 6,19,1),fpppp(27, 6,19,2),fpppp(27, 6,19,3)/
     x 2.4477191d-07,-4.5986612d-08, 1.2511262d-10 /
      data fpppp(27, 6,20,1),fpppp(27, 6,20,2),fpppp(27, 6,20,3)/
     x 2.6093301d-07,-9.1010770d-08,-2.9515590d-10 /
      data fpppp(27, 6,21,1),fpppp(27, 6,21,2),fpppp(27, 6,21,3)/
     x 2.6093301d-07,-9.2027278d-08,-2.8113634d-10 /
      data fpppp(27, 6,22,1),fpppp(27, 6,22,2),fpppp(27, 6,22,3)/
     x 2.4477191d-07,-4.1920580d-08, 6.9034393d-11 /
      data fpppp(27, 6,23,1),fpppp(27, 6,23,2),fpppp(27, 6,23,3)/
     x 2.5161025d-07,-1.8808523d-08, 2.3618595d-10 /
      data fpppp(27, 7, 1,1),fpppp(27, 7, 1,2),fpppp(27, 7, 1,3)/
     x 3.8340166d-08,-3.1555330d-08, 1.1792264d-11 /
      data fpppp(27, 7, 2,1),fpppp(27, 7, 2,2),fpppp(27, 7, 2,3)/
     x 9.9290635d-08,-2.1282653d-08,-5.3925664d-11 /
      data fpppp(27, 7, 3,1),fpppp(27, 7, 3,2),fpppp(27, 7, 3,3)/
     x 1.8737011d-07,-7.7472211d-10,-2.0318208d-10 /
      data fpppp(27, 7, 4,1),fpppp(27, 7, 4,2),fpppp(27, 7, 4,3)/
     x 1.8737011d-07, 1.8589385d-09,-1.8842558d-10 /
      data fpppp(27, 7, 5,1),fpppp(27, 7, 5,2),fpppp(27, 7, 5,3)/
     x 9.9290635d-08,-3.1817295d-08,-1.1295166d-10 /
      data fpppp(27, 7, 6,1),fpppp(27, 7, 6,2),fpppp(27, 7, 6,3)/
     x 3.8340166d-08, 7.9495792d-09, 2.3313974d-10 /
      data fpppp(27, 7, 7,1),fpppp(27, 7, 7,2),fpppp(27, 7, 7,3)/
     x-6.7348570d-08,-5.0482640d-09, 1.9357636d-11 /
      data fpppp(27, 7, 8,1),fpppp(27, 7, 8,2),fpppp(27, 7, 8,3)/
     x-1.4961208d-07,-1.2012548d-08, 2.1430360d-10 /
      data fpppp(27, 7, 9,1),fpppp(27, 7, 9,2),fpppp(27, 7, 9,3)/
     x-1.5652420d-07,-8.4671246d-09,-1.6154453d-10 /
      data fpppp(27, 7,10,1),fpppp(27, 7,10,2),fpppp(27, 7,10,3)/
     x-1.3830665d-07,-1.2111347d-09, 1.7578333d-10 /
      data fpppp(27, 7,11,1),fpppp(27, 7,11,2),fpppp(27, 7,11,3)/
     x-8.4479441d-08, 1.8076464d-08,-1.2859488d-10 /
      data fpppp(27, 7,12,1),fpppp(27, 7,12,2),fpppp(27, 7,12,3)/
     x-8.3599490d-08, 2.1330921d-08, 9.3279069d-11 /
      data fpppp(27, 7,13,1),fpppp(27, 7,13,2),fpppp(27, 7,13,3)/
     x-6.8898594d-08, 2.2317691d-08,-4.3611968d-11 /
      data fpppp(27, 7,14,1),fpppp(27, 7,14,2),fpppp(27, 7,14,3)/
     x-1.1903199d-07, 4.3228959d-09, 7.9811569d-11 /
      data fpppp(27, 7,15,1),fpppp(27, 7,15,2),fpppp(27, 7,15,3)/
     x-1.2328636d-07, 2.2402613d-08,-3.9511868d-11 /
      data fpppp(27, 7,16,1),fpppp(27, 7,16,2),fpppp(27, 7,16,3)/
     x-9.6467247d-08, 2.2736343d-08, 1.2144817d-10 /
      data fpppp(27, 7,17,1),fpppp(27, 7,17,2),fpppp(27, 7,17,3)/
     x-3.5460761d-08, 8.7806389d-09, 1.1734350d-10 /
      data fpppp(27, 7,18,1),fpppp(27, 7,18,2),fpppp(27, 7,18,3)/
     x 5.9174981d-08, 1.1037449d-09, 1.1950031d-10 /
      data fpppp(27, 7,19,1),fpppp(27, 7,19,2),fpppp(27, 7,19,3)/
     x 1.3539080d-07,-3.2743383d-08,-2.5931224d-11 /
      data fpppp(27, 7,20,1),fpppp(27, 7,20,2),fpppp(27, 7,20,3)/
     x 1.8325571d-07,-2.6031028d-08,-2.4907342d-10 /
      data fpppp(27, 7,21,1),fpppp(27, 7,21,2),fpppp(27, 7,21,3)/
     x 1.8325571d-07,-2.7786387d-08,-2.5103380d-10 /
      data fpppp(27, 7,22,1),fpppp(27, 7,22,2),fpppp(27, 7,22,3)/
     x 1.3539080d-07,-2.5721948d-08,-1.8089736d-11 /
      data fpppp(27, 7,23,1),fpppp(27, 7,23,2),fpppp(27, 7,23,3)/
     x 5.9174981d-08,-2.5226639d-08, 9.0094727d-11 /
      data fpppp(27, 8, 1,1),fpppp(27, 8, 1,2),fpppp(27, 8, 1,3)/
     x-1.2457319d-07,-2.6344267d-08,-9.3575575d-11 /
      data fpppp(27, 8, 2,1),fpppp(27, 8, 2,2),fpppp(27, 8, 2,3)/
     x-2.1424617d-08,-7.7380390d-09,-6.6682369d-12 /
      data fpppp(27, 8, 3,1),fpppp(27, 8, 3,2),fpppp(27, 8, 3,3)/
     x 4.1205211d-08, 3.1258203d-08, 1.8443818d-10 /
      data fpppp(27, 8, 4,1),fpppp(27, 8, 4,2),fpppp(27, 8, 4,3)/
     x 4.1205211d-08, 3.2788136d-08, 1.7590447d-10 /
      data fpppp(27, 8, 5,1),fpppp(27, 8, 5,2),fpppp(27, 8, 5,3)/
     x-2.1424617d-08,-1.3857770d-08, 2.7466635d-11 /
      data fpppp(27, 8, 6,1),fpppp(27, 8, 6,2),fpppp(27, 8, 6,3)/
     x-1.2457319d-07,-3.3952763d-09,-2.2158134d-10 /
      data fpppp(27, 8, 7,1),fpppp(27, 8, 7,2),fpppp(27, 8, 7,3)/
     x-1.5555549d-07,-3.8820672d-08, 6.0471422d-11 /
      data fpppp(27, 8, 8,1),fpppp(27, 8, 8,2),fpppp(27, 8, 8,3)/
     x-1.4237201d-07,-1.2717935d-08,-2.8445989d-10 /
      data fpppp(27, 8, 9,1),fpppp(27, 8, 9,2),fpppp(27, 8, 9,3)/
     x-1.0960753d-07,-3.9437081d-08, 1.5511149d-10 /
      data fpppp(27, 8,10,1),fpppp(27, 8,10,2),fpppp(27, 8,10,3)/
     x-7.6537753d-08, 2.5292670d-08,-2.3742815d-10 /
      data fpppp(27, 8,11,1),fpppp(27, 8,11,2),fpppp(27, 8,11,3)/
     x-7.7013069d-08,-9.0369259d-09, 1.5990435d-10 /
      data fpppp(27, 8,12,1),fpppp(27, 8,12,2),fpppp(27, 8,12,3)/
     x-4.3500917d-08, 4.3859989d-08, 1.1781738d-10 /
      data fpppp(27, 8,13,1),fpppp(27, 8,13,2),fpppp(27, 8,13,3)/
     x-6.0213795d-08, 9.7038639d-10, 1.6654240d-10 /
      data fpppp(27, 8,14,1),fpppp(27, 8,14,2),fpppp(27, 8,14,3)/
     x-6.6396852d-08, 3.5168594d-08,-2.6856564d-11 /
      data fpppp(27, 8,15,1),fpppp(27, 8,15,2),fpppp(27, 8,15,3)/
     x-1.0251976d-07,-9.7325685d-09,-2.2350288d-11 /
      data fpppp(27, 8,16,1),fpppp(27, 8,16,2),fpppp(27, 8,16,3)/
     x-1.2907772d-07, 2.4635225d-08,-2.5071845d-11 /
      data fpppp(27, 8,17,1),fpppp(27, 8,17,2),fpppp(27, 8,17,3)/
     x-1.4021571d-07,-2.4341162d-08,-1.5712086d-10 /
      data fpppp(27, 8,18,1),fpppp(27, 8,18,2),fpppp(27, 8,18,3)/
     x-1.1229678d-07,-6.7930512d-09, 8.8876212d-12 /
      data fpppp(27, 8,19,1),fpppp(27, 8,19,2),fpppp(27, 8,19,3)/
     x-6.1472432d-08,-3.4561303d-08,-1.1917197d-10 /
      data fpppp(27, 8,20,1),fpppp(27, 8,20,2),fpppp(27, 8,20,3)/
     x-2.2090423d-08, 9.9082589d-09, 8.9805114d-11 /
      data fpppp(27, 8,21,1),fpppp(27, 8,21,2),fpppp(27, 8,21,3)/
     x-2.2090423d-08, 7.6050605d-09, 7.9097097d-11 /
      data fpppp(27, 8,22,1),fpppp(27, 8,22,2),fpppp(27, 8,22,3)/
     x-6.1472432d-08,-2.5348509d-08,-7.6339898d-11 /
      data fpppp(27, 8,23,1),fpppp(27, 8,23,2),fpppp(27, 8,23,3)/
     x-1.1229678d-07,-4.1341028d-08,-1.5173263d-10 /
      data fpppp(27, 9, 1,1),fpppp(27, 9, 1,2),fpppp(27, 9, 1,3)/
     x-4.3154570d-08,-1.9193533d-08,-7.2465342d-11 /
      data fpppp(27, 9, 2,1),fpppp(27, 9, 2,2),fpppp(27, 9, 2,3)/
     x-1.0894835d-07,-5.1336014d-09,-3.9450634d-11 /
      data fpppp(27, 9, 3,1),fpppp(27, 9, 3,2),fpppp(27, 9, 3,3)/
     x-1.2163543d-07, 2.3272893d-08, 2.0601705d-11 /
      data fpppp(27, 9, 4,1),fpppp(27, 9, 4,2),fpppp(27, 9, 4,3)/
     x-1.2163543d-07, 2.6286272d-08, 3.9315270d-11 /
      data fpppp(27, 9, 5,1),fpppp(27, 9, 5,2),fpppp(27, 9, 5,3)/
     x-1.0894835d-07,-1.7187116d-08,-1.1430489d-10 /
      data fpppp(27, 9, 6,1),fpppp(27, 9, 6,2),fpppp(27, 9, 6,3)/
     x-4.3154570d-08, 2.6007146d-08, 2.0823814d-10 /
      data fpppp(27, 9, 7,1),fpppp(27, 9, 7,2),fpppp(27, 9, 7,3)/
     x-3.8101714d-08,-3.1107439d-08,-1.6406334d-10 /
      data fpppp(27, 9, 8,1),fpppp(27, 9, 8,2),fpppp(27, 9, 8,3)/
     x-2.1662770d-08,-8.6387133d-09, 2.5976352d-10 /
      data fpppp(27, 9, 9,1),fpppp(27, 9, 9,2),fpppp(27, 9, 9,3)/
     x-6.5814441d-08,-3.7946335d-08,-4.2099170d-10 /
      data fpppp(27, 9,10,1),fpppp(27, 9,10,2),fpppp(27, 9,10,3)/
     x-4.8137921d-08, 5.3480800d-09, 2.0606274d-10 /
      data fpppp(27, 9,11,1),fpppp(27, 9,11,2),fpppp(27, 9,11,3)/
     x-4.6560638d-08, 2.5126273d-09,-7.7466212d-11 /
      data fpppp(27, 9,12,1),fpppp(27, 9,12,2),fpppp(27, 9,12,3)/
     x-7.2668083d-08, 1.3503565d-08, 6.9092713d-11 /
      data fpppp(27, 9,13,1),fpppp(27, 9,13,2),fpppp(27, 9,13,3)/
     x-6.8723830d-08,-4.5253752d-09, 9.3208732d-12 /
      data fpppp(27, 9,14,1),fpppp(27, 9,14,2),fpppp(27, 9,14,3)/
     x-6.2486675d-08, 3.5071502d-08, 1.0645939d-10 /
      data fpppp(27, 9,15,1),fpppp(27, 9,15,2),fpppp(27, 9,15,3)/
     x-5.6145579d-08,-7.7245592d-09,-9.8344300d-11 /
      data fpppp(27, 9,16,1),fpppp(27, 9,16,2),fpppp(27, 9,16,3)/
     x-2.1145995d-08, 1.8895871d-08, 8.9023780d-11 /
      data fpppp(27, 9,17,1),fpppp(27, 9,17,2),fpppp(27, 9,17,3)/
     x-3.1872895d-08,-1.0912416d-08,-6.2341033d-11 /
      data fpppp(27, 9,18,1),fpppp(27, 9,18,2),fpppp(27, 9,18,3)/
     x-4.9959624d-08,-1.0756702d-08,-1.3131151d-10 /
      data fpppp(27, 9,19,1),fpppp(27, 9,19,2),fpppp(27, 9,19,3)/
     x-8.3026285d-08,-4.0440522d-08,-9.8857058d-11 /
      data fpppp(27, 9,20,1),fpppp(27, 9,20,2),fpppp(27, 9,20,3)/
     x-7.9870043d-08, 2.0262230d-08, 1.1201828d-10 /
      data fpppp(27, 9,21,1),fpppp(27, 9,21,2),fpppp(27, 9,21,3)/
     x-7.9870043d-08, 1.7508507d-08, 1.0888755d-10 /
      data fpppp(27, 9,22,1),fpppp(27, 9,22,2),fpppp(27, 9,22,3)/
     x-8.3026285d-08,-2.9425629d-08,-8.6334140d-11 /
      data fpppp(27, 9,23,1),fpppp(27, 9,23,2),fpppp(27, 9,23,3)/
     x-4.9959624d-08,-5.2062552d-08,-1.7827246d-10 /
      data fpppp(27,10, 1,1),fpppp(27,10, 1,2),fpppp(27,10, 1,3)/
     x-3.1072196d-09, 1.9756271d-08, 1.6879679d-10 /
      data fpppp(27,10, 2,1),fpppp(27,10, 2,2),fpppp(27,10, 2,3)/
     x 1.2831206d-08, 1.8718046d-08, 8.3751072d-11 /
      data fpppp(27,10, 3,1),fpppp(27,10, 3,2),fpppp(27,10, 3,3)/
     x-2.4381988d-08, 1.7256074d-08,-8.9326054d-11 /
      data fpppp(27,10, 4,1),fpppp(27,10, 4,2),fpppp(27,10, 4,3)/
     x-2.4381988d-08, 1.5921184d-08,-1.0536254d-10 /
      data fpppp(27,10, 5,1),fpppp(27,10, 5,2),fpppp(27,10, 5,3)/
     x 1.2831206d-08, 2.4057606d-08, 1.4789700d-10 /
      data fpppp(27,10, 6,1),fpppp(27,10, 6,2),fpppp(27,10, 6,3)/
     x-3.1072196d-09,-2.6707880d-10,-7.1750420d-11 /
      data fpppp(27,10, 7,1),fpppp(27,10, 7,2),fpppp(27,10, 7,3)/
     x-3.6401554d-10, 2.6225319d-09, 1.5915475d-10 /
      data fpppp(27,10, 8,1),fpppp(27,10, 8,2),fpppp(27,10, 8,3)/
     x-7.5369069d-08,-4.0987915d-08,-2.6770617d-10 /
      data fpppp(27,10, 9,1),fpppp(27,10, 9,2),fpppp(27,10, 9,3)/
     x-3.3404922d-09, 7.4935359d-09, 3.7793039d-10 /
      data fpppp(27,10,10,1),fpppp(27,10,10,2),fpppp(27,10,10,3)/
     x-6.2178294d-08,-3.7212903d-08,-7.0011180d-11 /
      data fpppp(27,10,11,1),fpppp(27,10,11,2),fpppp(27,10,11,3)/
     x-8.3223259d-08, 4.2942255d-10,-4.6361187d-11 /
      data fpppp(27,10,12,1),fpppp(27,10,12,2),fpppp(27,10,12,3)/
     x-8.2029623d-08, 5.7817299d-09,-1.2571314d-10 /
      data fpppp(27,10,13,1),fpppp(27,10,13,2),fpppp(27,10,13,3)/
     x-6.3505426d-08, 3.8558941d-10,-1.4045690d-12 /
      data fpppp(27,10,14,1),fpppp(27,10,14,2),fpppp(27,10,14,3)/
     x-2.1138704d-08, 1.4256870d-08,-3.7141390d-11 /
      data fpppp(27,10,15,1),fpppp(27,10,15,2),fpppp(27,10,15,3)/
     x 7.4868383d-09, 2.3481620d-08, 2.0594768d-10 /
      data fpppp(27,10,16,1),fpppp(27,10,16,2),fpppp(27,10,16,3)/
     x-2.5285343d-08,-2.0117461d-08,-2.1374368d-10 /
      data fpppp(27,10,17,1),fpppp(27,10,17,2),fpppp(27,10,17,3)/
     x 8.7123086d-09, 5.6979461d-09, 1.4714642d-10 /
      data fpppp(27,10,18,1),fpppp(27,10,18,2),fpppp(27,10,18,3)/
     x-8.1763653d-10,-2.8082832d-08,-3.5668743d-12 /
      data fpppp(27,10,19,1),fpppp(27,10,19,2),fpppp(27,10,19,3)/
     x 1.1435414d-08,-1.1282749d-08,-2.6359994d-11 /
      data fpppp(27,10,20,1),fpppp(27,10,20,2),fpppp(27,10,20,3)/
     x 5.9947871d-09, 1.9586305d-08,-1.4112153d-11 /
      data fpppp(27,10,21,1),fpppp(27,10,21,2),fpppp(27,10,21,3)/
     x 5.9947871d-09, 1.9699969d-08,-1.5465417d-11 /
      data fpppp(27,10,22,1),fpppp(27,10,22,2),fpppp(27,10,22,3)/
     x 1.1435414d-08,-1.1737405d-08,-2.0946935d-11 /
      data fpppp(27,10,23,1),fpppp(27,10,23,2),fpppp(27,10,23,3)/
     x-8.1763653d-10,-2.6377870d-08,-2.3865847d-11 /
      data fpppp(27,11, 1,1),fpppp(27,11, 1,2),fpppp(27,11, 1,3)/
     x 8.7749371d-09, 4.2624551d-09,-4.6247881d-11 /
      data fpppp(27,11, 2,1),fpppp(27,11, 2,2),fpppp(27,11, 2,3)/
     x 3.2505518d-08, 1.2534277d-08,-5.8501553d-11 /
      data fpppp(27,11, 3,1),fpppp(27,11, 3,2),fpppp(27,11, 3,3)/
     x 6.0240167d-08, 3.0328825d-08,-8.7979845d-11 /
      data fpppp(27,11, 4,1),fpppp(27,11, 4,2),fpppp(27,11, 4,3)/
     x 6.0240167d-08, 3.0207700d-08,-8.2344108d-11 /
      data fpppp(27,11, 5,1),fpppp(27,11, 5,2),fpppp(27,11, 5,3)/
     x 3.2505518d-08, 1.3018776d-08,-8.1044500d-11 /
      data fpppp(27,11, 6,1),fpppp(27,11, 6,2),fpppp(27,11, 6,3)/
     x 8.7749371d-09, 2.4455843d-09, 3.8288169d-11 /
      data fpppp(27,11, 7,1),fpppp(27,11, 7,2),fpppp(27,11, 7,3)/
     x-1.0541270d-08,-8.9115267d-09, 1.3107241d-11 /
      data fpppp(27,11, 8,1),fpppp(27,11, 8,2),fpppp(27,11, 8,3)/
     x 1.7887575d-07,-1.2141603d-08, 3.4888494d-10 /
      data fpppp(27,11, 9,1),fpppp(27,11, 9,2),fpppp(27,11, 9,3)/
     x-4.0286790d-08,-2.7620270d-08,-8.7687837d-11 /
      data fpppp(27,11,10,1),fpppp(27,11,10,2),fpppp(27,11,10,3)/
     x-6.8140341d-09,-2.7756719d-08,-2.3600983d-10 /
      data fpppp(27,11,11,1),fpppp(27,11,11,2),fpppp(27,11,11,3)/
     x 1.5322358d-08,-5.4330292d-09, 1.3983618d-10 /
      data fpppp(27,11,12,1),fpppp(27,11,12,2),fpppp(27,11,12,3)/
     x 2.7185766d-08, 1.2156410d-08, 1.5605080d-10 /
      data fpppp(27,11,13,1),fpppp(27,11,13,2),fpppp(27,11,13,3)/
     x 8.7279332d-09, 2.1742436d-08,-2.0979160d-10 /
      data fpppp(27,11,14,1),fpppp(27,11,14,2),fpppp(27,11,14,3)/
     x-2.7491496d-08,-6.5363962d-09, 6.4171240d-11 /
      data fpppp(27,11,15,1),fpppp(27,11,15,2),fpppp(27,11,15,3)/
     x-4.7759492d-08,-7.5288540d-10,-2.4761773d-10 /
      data fpppp(27,11,16,1),fpppp(27,11,16,2),fpppp(27,11,16,3)/
     x-5.7144213d-09, 7.9912435d-09, 2.7257106d-10 /
      data fpppp(27,11,17,1),fpppp(27,11,17,2),fpppp(27,11,17,3)/
     x-2.4640657d-08,-3.0357605d-08,-1.1055380d-10 /
      data fpppp(27,11,18,1),fpppp(27,11,18,2),fpppp(27,11,18,3)/
     x 2.5550441d-08,-1.4220229d-08, 5.6195499d-11 /
      data fpppp(27,11,19,1),fpppp(27,11,19,2),fpppp(27,11,19,3)/
     x 5.1607800d-08,-6.1956840d-09, 1.4614023d-10 /
      data fpppp(27,11,20,1),fpppp(27,11,20,2),fpppp(27,11,20,3)/
     x 5.3093867d-08, 2.4881382d-08,-9.3558951d-11 /
      data fpppp(27,11,21,1),fpppp(27,11,21,2),fpppp(27,11,21,3)/
     x 5.3093867d-08, 2.4573878d-08,-8.3979630d-11 /
      data fpppp(27,11,22,1),fpppp(27,11,22,2),fpppp(27,11,22,3)/
     x 5.1607800d-08,-4.9656676d-09, 1.0782295d-10 /
      data fpppp(27,11,23,1),fpppp(27,11,23,2),fpppp(27,11,23,3)/
     x 2.5550441d-08,-1.8832790d-08, 1.9988531d-10 /
      data fpppp(27,12, 1,1),fpppp(27,12, 1,2),fpppp(27,12, 1,3)/
     x-1.2572879d-08,-4.8666359d-09,-8.5387915d-11 /
      data fpppp(27,12, 2,1),fpppp(27,12, 2,2),fpppp(27,12, 2,3)/
     x-2.1248992d-08, 6.4428668d-09,-6.6579570d-11 /
      data fpppp(27,12, 3,1),fpppp(27,12, 3,2),fpppp(27,12, 3,3)/
     x 2.6186432d-09, 3.2075820d-08,-2.9833079d-11 /
      data fpppp(27,12, 4,1),fpppp(27,12, 4,2),fpppp(27,12, 4,3)/
     x 2.6186432d-09, 2.9628787d-08,-2.3608144d-11 /
      data fpppp(27,12, 5,1),fpppp(27,12, 5,2),fpppp(27,12, 5,3)/
     x-2.1248992d-08, 1.6230996d-08,-9.1479309d-11 /
      data fpppp(27,12, 6,1),fpppp(27,12, 6,2),fpppp(27,12, 6,3)/
     x-1.2572879d-08,-4.1572120d-08, 7.9861070d-12 /
      data fpppp(27,12, 7,1),fpppp(27,12, 7,2),fpppp(27,12, 7,3)/
     x-4.7239194d-09, 1.8773681d-07, 5.8623145d-11 /
      data fpppp(27,12, 8,1),fpppp(27,12, 8,2),fpppp(27,12, 8,3)/
     x-2.9882017d-07,-3.1405506d-07,-1.3804937d-10 /
      data fpppp(27,12, 9,1),fpppp(27,12, 9,2),fpppp(27,12, 9,3)/
     x 6.0404169d-09, 1.6379486d-07, 6.3477313d-11 /
      data fpppp(27,12,10,1),fpppp(27,12,10,2),fpppp(27,12,10,3)/
     x-4.1163279d-08,-6.6046005d-08, 3.8164090d-10 /
      data fpppp(27,12,11,1),fpppp(27,12,11,2),fpppp(27,12,11,3)/
     x-2.9297656d-08, 4.6741697d-09,-2.3400144d-10 /
      data fpppp(27,12,12,1),fpppp(27,12,12,2),fpppp(27,12,12,3)/
     x-7.5543979d-09,-6.5777448d-09,-2.6200875d-10 /
      data fpppp(27,12,13,1),fpppp(27,12,13,2),fpppp(27,12,13,3)/
     x 1.5399498d-08, 2.4821209d-08, 3.3566362d-10 /
      data fpppp(27,12,14,1),fpppp(27,12,14,2),fpppp(27,12,14,3)/
     x 2.6289198d-09,-1.2036873d-08,-2.3639547d-10 /
      data fpppp(27,12,15,1),fpppp(27,12,15,2),fpppp(27,12,15,3)/
     x 2.6621357d-08, 1.8947094d-08, 2.7683818d-10 /
      data fpppp(27,12,16,1),fpppp(27,12,16,2),fpppp(27,12,16,3)/
     x-5.0615648d-09,-2.2751602d-08,-2.6894843d-10 /
      data fpppp(27,12,17,1),fpppp(27,12,17,2),fpppp(27,12,17,3)/
     x 1.4091138d-08,-1.2212093d-09, 1.7238529d-10 /
      data fpppp(27,12,18,1),fpppp(27,12,18,2),fpppp(27,12,18,3)/
     x-2.3766506d-08,-2.6342471d-08, 2.1926685d-11 /
      data fpppp(27,12,19,1),fpppp(27,12,19,2),fpppp(27,12,19,3)/
     x-3.9175908d-08,-1.4664902d-08, 3.1915320d-11 /
      data fpppp(27,12,20,1),fpppp(27,12,20,2),fpppp(27,12,20,3)/
     x-1.9697013d-08, 2.9295884d-08,-5.5258886d-11 /
      data fpppp(27,12,21,1),fpppp(27,12,21,2),fpppp(27,12,21,3)/
     x-1.9697013d-08, 2.8876385d-08,-5.2853668d-11 /
      data fpppp(27,12,22,1),fpppp(27,12,22,2),fpppp(27,12,22,3)/
     x-3.9175908d-08,-1.2986902d-08, 2.2294447d-11 /
      data fpppp(27,12,23,1),fpppp(27,12,23,2),fpppp(27,12,23,3)/
     x-2.3766506d-08,-3.2634969d-08, 5.8004959d-11 /
      data fpppp(27,13, 1,1),fpppp(27,13, 1,2),fpppp(27,13, 1,3)/
     x 3.9445288d-08, 1.5819458d-08, 4.5426967d-11 /
      data fpppp(27,13, 2,1),fpppp(27,13, 2,2),fpppp(27,13, 2,3)/
     x 5.2438000d-08, 1.7086576d-08, 1.9564976d-11 /
      data fpppp(27,13, 3,1),fpppp(27,13, 3,2),fpppp(27,13, 3,3)/
     x 1.4192396d-08, 2.0007896d-08,-2.9295843d-11 /
      data fpppp(27,13, 4,1),fpppp(27,13, 4,2),fpppp(27,13, 4,3)/
     x 1.4192396d-08, 1.9647275d-08,-4.0771880d-11 /
      data fpppp(27,13, 5,1),fpppp(27,13, 5,2),fpppp(27,13, 5,3)/
     x 5.2438000d-08, 1.8529062d-08, 6.5469124d-11 /
      data fpppp(27,13, 6,1),fpppp(27,13, 6,2),fpppp(27,13, 6,3)/
     x 3.9445288d-08, 1.0410135d-08,-1.2671359d-10 /
      data fpppp(27,13, 7,1),fpppp(27,13, 7,2),fpppp(27,13, 7,3)/
     x 3.0349060d-08, 6.3017046d-09,-1.8323826d-13 /
      data fpppp(27,13, 8,1),fpppp(27,13, 8,2),fpppp(27,13, 8,3)/
     x 1.9462515d-07,-2.5310051d-08,-9.8727750d-12 /
      data fpppp(27,13, 9,1),fpppp(27,13, 9,2),fpppp(27,13, 9,3)/
     x-6.9115513d-09,-7.9054261d-09, 7.9103355d-11 /
      data fpppp(27,13,10,1),fpppp(27,13,10,2),fpppp(27,13,10,3)/
     x 1.5820616d-07,-3.1499521d-08,-2.5866749d-10 /
      data fpppp(27,13,11,1),fpppp(27,13,11,2),fpppp(27,13,11,3)/
     x 3.0846972d-08, 1.9017718d-08, 3.8329978d-10 /
      data fpppp(27,13,12,1),fpppp(27,13,12,2),fpppp(27,13,12,3)/
     x-2.2176359d-08,-1.1519658d-08, 7.1577221d-11 /
      data fpppp(27,13,13,1),fpppp(27,13,13,2),fpppp(27,13,13,3)/
     x-2.2319809d-08,-4.1041432d-09,-3.1836517d-10 /
      data fpppp(27,13,14,1),fpppp(27,13,14,2),fpppp(27,13,14,3)/
     x 5.1824757d-08, 1.0315441d-08, 2.4382671d-10 /
      data fpppp(27,13,15,1),fpppp(27,13,15,2),fpppp(27,13,15,3)/
     x-4.8400995d-09,-8.5658940d-09,-2.0389701d-10 /
      data fpppp(27,13,16,1),fpppp(27,13,16,2),fpppp(27,13,16,3)/
     x-7.5920019d-09, 1.0292164d-09, 2.5745472d-10 /
      data fpppp(27,13,17,1),fpppp(27,13,17,2),fpppp(27,13,17,3)/
     x-3.2811276d-08,-2.3062681d-08,-1.3175359d-10 /
      data fpppp(27,13,18,1),fpppp(27,13,18,2),fpppp(27,13,18,3)/
     x-2.3511805d-08,-1.3482216d-08, 5.2930576d-11 /
      data fpppp(27,13,19,1),fpppp(27,13,19,2),fpppp(27,13,19,3)/
     x-1.0918374d-08,-3.1330541d-09,-6.8366560d-11 /
      data fpppp(27,13,20,1),fpppp(27,13,20,2),fpppp(27,13,20,3)/
     x-1.9755731d-08, 2.2274737d-08, 1.6021862d-11 /
      data fpppp(27,13,21,1),fpppp(27,13,21,2),fpppp(27,13,21,3)/
     x-1.9755731d-08, 2.2203164d-08, 8.3947224d-12 /
      data fpppp(27,13,22,1),fpppp(27,13,22,2),fpppp(27,13,22,3)/
     x-1.0918374d-08,-2.8467615d-09,-3.7858003d-11 /
      data fpppp(27,13,23,1),fpppp(27,13,23,2),fpppp(27,13,23,3)/
     x-2.3511805d-08,-1.4555813d-08,-6.1476512d-11 /
      data fpppp(27,14, 1,1),fpppp(27,14, 1,2),fpppp(27,14, 1,3)/
     x 2.4631908d-08,-1.1355924d-08,-1.1362940d-10 /
      data fpppp(27,14, 2,1),fpppp(27,14, 2,2),fpppp(27,14, 2,3)/
     x 2.2683692d-08, 2.4213165d-10,-6.7061444d-11 /
      data fpppp(27,14, 3,1),fpppp(27,14, 3,2),fpppp(27,14, 3,3)/
     x 5.1215328d-08, 2.3824397d-08, 2.5850340d-11 /
      data fpppp(27,14, 4,1),fpppp(27,14, 4,2),fpppp(27,14, 4,3)/
     x 5.1215328d-08, 2.6048139d-08, 3.7884545d-11 /
      data fpppp(27,14, 5,1),fpppp(27,14, 5,2),fpppp(27,14, 5,3)/
     x 2.2683692d-08,-8.6528363d-09,-1.1519826d-10 /
      data fpppp(27,14, 6,1),fpppp(27,14, 6,2),fpppp(27,14, 6,3)/
     x 2.4631908d-08, 2.2000206d-08, 6.6883673d-11 /
      data fpppp(27,14, 7,1),fpppp(27,14, 7,2),fpppp(27,14, 7,3)/
     x 4.9512829d-09, 9.0452394d-09,-1.8515080d-10 /
      data fpppp(27,14, 8,1),fpppp(27,14, 8,2),fpppp(27,14, 8,3)/
     x-3.3839003d-08,-6.0453005d-08, 3.8567480d-11 /
      data fpppp(27,14, 9,1),fpppp(27,14, 9,2),fpppp(27,14, 9,3)/
     x 2.3943243d-08, 1.6404572d-07,-5.6738148d-11 /
      data fpppp(27,14,10,1),fpppp(27,14,10,2),fpppp(27,14,10,3)/
     x-2.4456564d-07,-2.5940859d-07, 2.1939171d-10 /
      data fpppp(27,14,11,1),fpppp(27,14,11,2),fpppp(27,14,11,3)/
     x-1.4363326d-08, 1.2740498d-07,-2.4780088d-10 /
      data fpppp(27,14,12,1),fpppp(27,14,12,2),fpppp(27,14,12,3)/
     x 2.8510167d-08,-1.0288624d-08, 1.6375009d-10 /
      data fpppp(27,14,13,1),fpppp(27,14,13,2),fpppp(27,14,13,3)/
     x 1.3573426d-08, 3.1549271d-09, 2.1419939d-10 /
      data fpppp(27,14,14,1),fpppp(27,14,14,2),fpppp(27,14,14,3)/
     x-1.6513375d-07,-2.0585724d-08,-1.9257092d-10 /
      data fpppp(27,14,15,1),fpppp(27,14,15,2),fpppp(27,14,15,3)/
     x-8.8879757d-09,-1.0771119d-08, 1.5698571d-10 /
      data fpppp(27,14,16,1),fpppp(27,14,16,2),fpppp(27,14,16,3)/
     x 9.2930392d-09,-1.2558381d-09,-1.4015432d-10 /
      data fpppp(27,14,17,1),fpppp(27,14,17,2),fpppp(27,14,17,3)/
     x 1.7998166d-08,-1.4458174d-08, 5.3528757d-11 /
      data fpppp(27,14,18,1),fpppp(27,14,18,2),fpppp(27,14,18,3)/
     x 3.5777029d-08,-6.2016345d-09,-9.9638739d-12 /
      data fpppp(27,14,19,1),fpppp(27,14,19,2),fpppp(27,14,19,3)/
     x 2.0597151d-08, 2.9368507d-09, 7.9107649d-12 /
      data fpppp(27,14,20,1),fpppp(27,14,20,2),fpppp(27,14,20,3)/
     x 3.0313762d-08, 1.6742670d-08,-1.7953060d-11 /
      data fpppp(27,14,21,1),fpppp(27,14,21,2),fpppp(27,14,21,3)/
     x 3.0313762d-08, 1.6870634d-08,-1.6531647d-11 /
      data fpppp(27,14,22,1),fpppp(27,14,22,2),fpppp(27,14,22,3)/
     x 2.0597151d-08, 2.4249957d-09, 2.2251148d-12 /
      data fpppp(27,14,23,1),fpppp(27,14,23,2),fpppp(27,14,23,3)/
     x 3.5777029d-08,-4.2821783d-09, 1.1357314d-11 /
      data fpppp(27,15, 1,1),fpppp(27,15, 1,2),fpppp(27,15, 1,3)/
     x 1.1781869d-08,-6.9693022d-09,-2.6404630d-11 /
      data fpppp(27,15, 2,1),fpppp(27,15, 2,2),fpppp(27,15, 2,3)/
     x-4.9645079d-09, 7.2569392d-10,-2.0328686d-11 /
      data fpppp(27,15, 3,1),fpppp(27,15, 3,2),fpppp(27,15, 3,3)/
     x-2.5267785d-09, 1.6632071d-08,-2.5723151d-12 /
      data fpppp(27,15, 4,1),fpppp(27,15, 4,2),fpppp(27,15, 4,3)/
     x-2.5267785d-09, 1.7652147d-08,-1.0861170d-11 /
      data fpppp(27,15, 5,1),fpppp(27,15, 5,2),fpppp(27,15, 5,3)/
     x-4.9645079d-09,-3.3546109d-09, 1.2826735d-11 /
      data fpppp(27,15, 6,1),fpppp(27,15, 6,2),fpppp(27,15, 6,3)/
     x 1.1781869d-08, 8.3318407d-09,-1.5073746d-10 /
      data fpppp(27,15, 7,1),fpppp(27,15, 7,2),fpppp(27,15, 7,3)/
     x 4.3408515d-08, 1.2603788d-08, 8.2949050d-11 /
      data fpppp(27,15, 8,1),fpppp(27,15, 8,2),fpppp(27,15, 8,3)/
     x 4.0552688d-08,-1.1146378d-08,-2.3131262d-11 /
      data fpppp(27,15, 9,1),fpppp(27,15, 9,2),fpppp(27,15, 9,3)/
     x 2.0412296d-08, 5.7631135d-10,-3.9376914d-11 /
      data fpppp(27,15,10,1),fpppp(27,15,10,2),fpppp(27,15,10,3)/
     x 1.7543318d-07, 6.5661444d-09, 8.7393601d-12 /
      data fpppp(27,15,11,1),fpppp(27,15,11,2),fpppp(27,15,11,3)/
     x-8.7318484d-10,-3.3281736d-08, 8.4575002d-11 /
      data fpppp(27,15,12,1),fpppp(27,15,12,2),fpppp(27,15,12,3)/
     x-2.0010460d-08, 5.5544138d-08, 1.9098721d-11 /
      data fpppp(27,15,13,1),fpppp(27,15,13,2),fpppp(27,15,13,3)/
     x-3.3743832d-08,-1.5187609d-07,-1.1780881d-10 /
      data fpppp(27,15,14,1),fpppp(27,15,14,2),fpppp(27,15,14,3)/
     x 2.0957148d-07, 2.0932669d-07, 2.5828638d-10 /
      data fpppp(27,15,15,1),fpppp(27,15,15,2),fpppp(27,15,15,3)/
     x-9.1084417d-09,-1.4693340d-07,-1.3198712d-10 /
      data fpppp(27,15,16,1),fpppp(27,15,16,2),fpppp(27,15,16,3)/
     x 7.8592153d-09, 8.7752596d-09, 1.2309825d-10 /
      data fpppp(27,15,17,1),fpppp(27,15,17,2),fpppp(27,15,17,3)/
     x 1.5588257d-08, 9.2292427d-09,-1.4162873d-11 /
      data fpppp(27,15,18,1),fpppp(27,15,18,2),fpppp(27,15,18,3)/
     x-1.4371275d-09,-2.5509577d-08,-1.0580503d-10 /
      data fpppp(27,15,19,1),fpppp(27,15,19,2),fpppp(27,15,19,3)/
     x 3.2858099d-08, 2.3057549d-08,-2.0555276d-11 /
      data fpppp(27,15,20,1),fpppp(27,15,20,2),fpppp(27,15,20,3)/
     x 1.4781143d-08, 7.3789345d-09, 1.7635429d-11 /
      data fpppp(27,15,21,1),fpppp(27,15,21,2),fpppp(27,15,21,3)/
     x 1.4781143d-08, 1.0031647d-08, 2.0836098d-11 /
      data fpppp(27,15,22,1),fpppp(27,15,22,2),fpppp(27,15,22,3)/
     x 3.2858099d-08, 1.2446698d-08,-3.3357951d-11 /
      data fpppp(27,15,23,1),fpppp(27,15,23,2),fpppp(27,15,23,3)/
     x-1.4371275d-09, 1.4281112d-08,-5.7794995d-11 /
      data fpppp(27,16, 1,1),fpppp(27,16, 1,2),fpppp(27,16, 1,3)/
     x 5.4145617d-09, 2.5089554d-08,-8.5484717d-11 /
      data fpppp(27,16, 2,1),fpppp(27,16, 2,2),fpppp(27,16, 2,3)/
     x 2.5063536d-08, 1.7755027d-08,-5.2158539d-11 /
      data fpppp(27,16, 3,1),fpppp(27,16, 3,2),fpppp(27,16, 3,3)/
     x 2.4882813d-08, 2.9710057d-09, 1.1310460d-11 /
      data fpppp(27,16, 4,1),fpppp(27,16, 4,2),fpppp(27,16, 4,3)/
     x 2.4882813d-08, 1.3385687d-09, 2.5212880d-11 /
      data fpppp(27,16, 5,1),fpppp(27,16, 5,2),fpppp(27,16, 5,3)/
     x 2.5063536d-08, 2.4284775d-08,-1.0776822d-10 /
      data fpppp(27,16, 6,1),fpppp(27,16, 6,2),fpppp(27,16, 6,3)/
     x 5.4145617d-09, 6.0299800d-10, 1.2305158d-10 /
      data fpppp(27,16, 7,1),fpppp(27,16, 7,2),fpppp(27,16, 7,3)/
     x-2.4273205d-08,-2.0834709d-09,-1.2292754d-10 /
      data fpppp(27,16, 8,1),fpppp(27,16, 8,2),fpppp(27,16, 8,3)/
     x-1.7110072d-09, 4.1436342d-10, 1.2100689d-11 /
      data fpppp(27,16, 9,1),fpppp(27,16, 9,2),fpppp(27,16, 9,3)/
     x-1.0635543d-08, 2.2837918d-09,-2.0445385d-12 /
      data fpppp(27,16,10,1),fpppp(27,16,10,2),fpppp(27,16,10,3)/
     x-4.5759355d-08,-2.2661219d-09,-6.7330900d-11 /
      data fpppp(27,16,11,1),fpppp(27,16,11,2),fpppp(27,16,11,3)/
     x 7.7300934d-09, 2.0981621d-09, 9.7718204d-11 /
      data fpppp(27,16,12,1),fpppp(27,16,12,2),fpppp(27,16,12,3)/
     x-2.5733661d-09,-1.0527930d-08,-1.0003254d-10 /
      data fpppp(27,16,13,1),fpppp(27,16,13,2),fpppp(27,16,13,3)/
     x 1.1885943d-08, 1.3213746d-08, 2.2836877d-10 /
      data fpppp(27,16,14,1),fpppp(27,16,14,2),fpppp(27,16,14,3)/
     x-1.4968248d-07,-2.0942926d-08,-1.4601879d-10 /
      data fpppp(27,16,15,1),fpppp(27,16,15,2),fpppp(27,16,15,3)/
     x-2.3443273d-08, 1.2291232d-08, 1.4140649d-10 /
      data fpppp(27,16,16,1),fpppp(27,16,16,2),fpppp(27,16,16,3)/
     x-4.6230800d-08,-4.7060492d-08,-1.2856943d-10 /
      data fpppp(27,16,17,1),fpppp(27,16,17,2),fpppp(27,16,17,3)/
     x-1.1775991d-08, 1.1809122d-08, 5.8001979d-11 /
      data fpppp(27,16,18,1),fpppp(27,16,18,2),fpppp(27,16,18,3)/
     x 1.1716896d-08, 4.5735901d-09,-1.0002249d-11 /
      data fpppp(27,16,19,1),fpppp(27,16,19,2),fpppp(27,16,19,3)/
     x-1.2113233d-08,-8.2779647d-09,-7.8239667d-12 /
      data fpppp(27,16,20,1),fpppp(27,16,20,2),fpppp(27,16,20,3)/
     x 5.7900671d-09, 1.1590120d-08,-8.6520159d-13 /
      data fpppp(27,16,21,1),fpppp(27,16,21,2),fpppp(27,16,21,3)/
     x 5.7900671d-09, 1.0539962d-08,-9.1595200d-13 /
      data fpppp(27,16,22,1),fpppp(27,16,22,2),fpppp(27,16,22,3)/
     x-1.2113233d-08,-4.0773329d-09,-7.6209651d-12 /
      data fpppp(27,16,23,1),fpppp(27,16,23,2),fpppp(27,16,23,3)/
     x 1.1716896d-08,-1.1178779d-08,-1.0763505d-11 /
      data fpppp(27,17, 1,1),fpppp(27,17, 1,2),fpppp(27,17, 1,3)/
     x 1.9788109d-08, 3.2380470d-08, 1.6394623d-10 /
      data fpppp(27,17, 2,1),fpppp(27,17, 2,2),fpppp(27,17, 2,3)/
     x 8.9171507d-09, 1.9731367d-08, 9.7757385d-11 /
      data fpppp(27,17, 3,1),fpppp(27,17, 3,2),fpppp(27,17, 3,3)/
     x-2.1548546d-08,-5.4395642d-09,-3.3450427d-11 /
      data fpppp(27,17, 4,1),fpppp(27,17, 4,2),fpppp(27,17, 4,3)/
     x-2.1548546d-08,-8.8245694d-09,-5.2044910d-11 /
      data fpppp(27,17, 5,1),fpppp(27,17, 5,2),fpppp(27,17, 5,3)/
     x 8.9171507d-09, 3.3271388d-08, 1.7213532d-10 /
      data fpppp(27,17, 6,1),fpppp(27,17, 6,2),fpppp(27,17, 6,3)/
     x 1.9788109d-08,-1.8394607d-08,-1.1497102d-10 /
      data fpppp(27,17, 7,1),fpppp(27,17, 7,2),fpppp(27,17, 7,3)/
     x 3.8741593d-08, 2.9764719d-08, 1.0888055d-10 /
      data fpppp(27,17, 8,1),fpppp(27,17, 8,2),fpppp(27,17, 8,3)/
     x 1.5469955d-08,-3.0605660d-08,-1.3224712d-10 /
      data fpppp(27,17, 9,1),fpppp(27,17, 9,2),fpppp(27,17, 9,3)/
     x 3.3830695d-08, 2.6179760d-08, 5.5338132d-11 /
      data fpppp(27,17,10,1),fpppp(27,17,10,2),fpppp(27,17,10,3)/
     x 3.2273459d-08,-6.8253812d-09,-2.3572387d-11 /
      data fpppp(27,17,11,1),fpppp(27,17,11,2),fpppp(27,17,11,3)/
     x 7.4582796d-09,-1.9345981d-09,-6.6604371d-11 /
      data fpppp(27,17,12,1),fpppp(27,17,12,2),fpppp(27,17,12,3)/
     x 5.9345159d-09, 2.0664960d-09, 1.0981427d-10 /
      data fpppp(27,17,13,1),fpppp(27,17,13,2),fpppp(27,17,13,3)/
     x-4.2682537d-09,-1.1737676d-09,-1.1964108d-10 /
      data fpppp(27,17,14,1),fpppp(27,17,14,2),fpppp(27,17,14,3)/
     x 3.4033318d-08,-1.0527553d-08, 5.2905201d-11 /
      data fpppp(27,17,15,1),fpppp(27,17,15,2),fpppp(27,17,15,3)/
     x 6.9654879d-10, 5.8502322d-09,-1.8129749d-11 /
      data fpppp(27,17,16,1),fpppp(27,17,16,2),fpppp(27,17,16,3)/
     x-1.5027845d-09,-1.0240619d-08, 8.2026716d-11 /
      data fpppp(27,17,17,1),fpppp(27,17,17,2),fpppp(27,17,17,3)/
     x-4.4730982d-08,-1.1866001d-08,-1.1674308d-10 /
      data fpppp(27,17,18,1),fpppp(27,17,18,2),fpppp(27,17,18,3)/
     x-6.0456863d-08, 5.9213532d-09, 5.0558927d-11 /
      data fpppp(27,17,19,1),fpppp(27,17,19,2),fpppp(27,17,19,3)/
     x-4.6883912d-08,-7.0894847d-09,-2.8230441d-11 /
      data fpppp(27,17,20,1),fpppp(27,17,20,2),fpppp(27,17,20,3)/
     x-5.6973303d-08, 5.3399267d-09, 4.1406809d-11 /
      data fpppp(27,17,21,1),fpppp(27,17,21,2),fpppp(27,17,21,3)/
     x-5.6973303d-08, 4.4469886d-09, 3.6124210d-11 /
      data fpppp(27,17,22,1),fpppp(27,17,22,2),fpppp(27,17,22,3)/
     x-4.6883912d-08,-3.5177322d-09,-7.1000455d-12 /
      data fpppp(27,17,23,1),fpppp(27,17,23,2),fpppp(27,17,23,3)/
     x-6.0456863d-08,-7.4727187d-09,-2.8680058d-11 /
      data fpppp(27,18, 1,1),fpppp(27,18, 1,2),fpppp(27,18, 1,3)/
     x-7.9148279d-09, 6.3247852d-09,-3.2119662d-11 /
      data fpppp(27,18, 2,1),fpppp(27,18, 2,2),fpppp(27,18, 2,3)/
     x-6.5211010d-09, 4.4406585d-09,-5.2320576d-12 /
      data fpppp(27,18, 3,1),fpppp(27,18, 3,2),fpppp(27,18, 3,3)/
     x 5.5684801d-09, 1.0518671d-09, 4.9754938d-11 /
      data fpppp(27,18, 4,1),fpppp(27,18, 4,2),fpppp(27,18, 4,3)/
     x 5.5684801d-09,-8.3223373d-11, 5.4356214d-11 /
      data fpppp(27,18, 5,1),fpppp(27,18, 5,2),fpppp(27,18, 5,3)/
     x-6.5211010d-09, 8.9810205d-09,-2.3637163d-11 /
      data fpppp(27,18, 6,1),fpppp(27,18, 6,2),fpppp(27,18, 6,3)/
     x-7.9148279d-09,-1.0701573d-08, 3.6899483d-11 /
      data fpppp(27,18, 7,1),fpppp(27,18, 7,2),fpppp(27,18, 7,3)/
     x-5.5772781d-09, 1.4149912d-08,-2.9998418d-11 /
      data fpppp(27,18, 8,1),fpppp(27,18, 8,2),fpppp(27,18, 8,3)/
     x 2.9240813d-09,-8.9510535d-09, 4.6435891d-11 /
      data fpppp(27,18, 9,1),fpppp(27,18, 9,2),fpppp(27,18, 9,3)/
     x-1.5014413d-09, 8.9560995d-09,-6.0096632d-11 /
      data fpppp(27,18,10,1),fpppp(27,18,10,2),fpppp(27,18,10,3)/
     x-2.2530819d-09,-1.7780543d-09,-4.7730820d-12 /
      data fpppp(27,18,11,1),fpppp(27,18,11,2),fpppp(27,18,11,3)/
     x 3.1201963d-09,-1.5676680d-09,-4.4937958d-11 /
      data fpppp(27,18,12,1),fpppp(27,18,12,2),fpppp(27,18,12,3)/
     x 5.0927344d-10, 8.8441279d-09,-3.8282058d-11 /
      data fpppp(27,18,13,1),fpppp(27,18,13,2),fpppp(27,18,13,3)/
     x-6.9149874d-09,-1.1460386d-08,-1.9937130d-11 /
      data fpppp(27,18,14,1),fpppp(27,18,14,2),fpppp(27,18,14,3)/
     x-1.8455382d-08, 3.1745325d-09,-6.0137487d-12 /
      data fpppp(27,18,15,1),fpppp(27,18,15,2),fpppp(27,18,15,3)/
     x-1.4903493d-08,-1.4919558d-09,-3.7107867d-11 /
      data fpppp(27,18,16,1),fpppp(27,18,16,2),fpppp(27,18,16,3)/
     x-1.8739605d-08,-4.9676980d-09,-2.6244188d-11 /
      data fpppp(27,18,17,1),fpppp(27,18,17,2),fpppp(27,18,17,3)/
     x-1.3994525d-08,-6.7440594d-09, 4.4017753d-11 /
      data fpppp(27,18,18,1),fpppp(27,18,18,2),fpppp(27,18,18,3)/
     x-1.6002279d-08, 1.5922319d-08, 1.4283656d-11 /
      data fpppp(27,18,19,1),fpppp(27,18,19,2),fpppp(27,18,19,3)/
     x-3.6229012d-08,-1.7657551d-08, 1.9629856d-11 /
      data fpppp(27,18,20,1),fpppp(27,18,20,2),fpppp(27,18,20,3)/
     x-3.7183614d-08, 3.8189121d-09, 3.3184359d-11 /
      data fpppp(27,18,21,1),fpppp(27,18,21,2),fpppp(27,18,21,3)/
     x-3.7183614d-08, 1.7491865d-09, 3.3137876d-11 /
      data fpppp(27,18,22,1),fpppp(27,18,22,2),fpppp(27,18,22,3)/
     x-3.6229012d-08,-9.3786487d-09, 1.9815786d-11 /
      data fpppp(27,18,23,1),fpppp(27,18,23,2),fpppp(27,18,23,3)/
     x-1.6002279d-08,-1.5123565d-08, 1.3586416d-11 /
      data fpppp(27,19, 1,1),fpppp(27,19, 1,2),fpppp(27,19, 1,3)/
     x-2.3595912d-08, 2.0024037d-22,-1.0090074d-10 /
      data fpppp(27,19, 2,1),fpppp(27,19, 2,2),fpppp(27,19, 2,3)/
     x-2.2161677d-08, 6.0670308d-22,-3.5962824d-11 /
      data fpppp(27,19, 3,1),fpppp(27,19, 3,2),fpppp(27,19, 3,3)/
     x 1.1671682d-08, 8.1841178d-22, 9.6398516d-11 /
      data fpppp(27,19, 4,1),fpppp(27,19, 4,2),fpppp(27,19, 4,3)/
     x 1.1671682d-08, 6.5783032d-22, 1.0828336d-10 /
      data fpppp(27,19, 5,1),fpppp(27,19, 5,2),fpppp(27,19, 5,3)/
     x-2.2161677d-08,-1.2245168d-21,-8.3502211d-11 /
      data fpppp(27,19, 6,1),fpppp(27,19, 6,2),fpppp(27,19, 6,3)/
     x-2.3595912d-08, 1.8891738d-22, 7.7371958d-11 /
      data fpppp(27,19, 7,1),fpppp(27,19, 7,2),fpppp(27,19, 7,3)/
     x-1.9229387d-08, 8.2862716d-22,-6.2966798d-11 /
      data fpppp(27,19, 8,1),fpppp(27,19, 8,2),fpppp(27,19, 8,3)/
     x-1.1284108d-09,-1.2510991d-22, 1.3282438d-10 /
      data fpppp(27,19, 9,1),fpppp(27,19, 9,2),fpppp(27,19, 9,3)/
     x-1.4034042d-08, 7.9562331d-22,-1.2615499d-10 /
      data fpppp(27,19,10,1),fpppp(27,19,10,2),fpppp(27,19,10,3)/
     x-4.6198071d-09,-1.1862459d-23, 2.1157425d-11 /
      data fpppp(27,19,11,1),fpppp(27,19,11,2),fpppp(27,19,11,3)/
     x-5.6095673d-11,-1.0947168d-22,-7.6411255d-11 /
      data fpppp(27,19,12,1),fpppp(27,19,12,2),fpppp(27,19,12,3)/
     x-9.3507631d-10, 5.6917346d-22,-8.4108919d-11 /
      data fpppp(27,19,13,1),fpppp(27,19,13,2),fpppp(27,19,13,3)/
     x-1.3420996d-08, 4.7322632d-22,-4.8151407d-11 /
      data fpppp(27,19,14,1),fpppp(27,19,14,2),fpppp(27,19,14,3)/
     x-3.4570824d-09, 1.6456803d-21, 8.7367128d-12 /
      data fpppp(27,19,15,1),fpppp(27,19,15,2),fpppp(27,19,15,3)/
     x-1.9149288d-08, 8.1357080d-22,-9.6245448d-11 /
      data fpppp(27,19,16,1),fpppp(27,19,16,2),fpppp(27,19,16,3)/
     x-1.8272187d-08,-1.8751305d-21,-4.3410220d-11 /
      data fpppp(27,19,17,1),fpppp(27,19,17,2),fpppp(27,19,17,3)/
     x-1.4556248d-09,-6.5497967d-22, 1.0891976d-10 /
      data fpppp(27,19,18,1),fpppp(27,19,18,2),fpppp(27,19,18,3)/
     x-4.8700794d-09, 1.2818571d-21, 5.6759409d-12 /
      data fpppp(27,19,19,1),fpppp(27,19,19,2),fpppp(27,19,19,3)/
     x-3.8552849d-08,-1.7751988d-21, 4.7985361d-11 /
      data fpppp(27,19,20,1),fpppp(27,19,20,2),fpppp(27,19,20,3)/
     x-4.0980514d-08,-6.1031888d-22, 3.9388898d-11 /
      data fpppp(27,19,21,1),fpppp(27,19,21,2),fpppp(27,19,21,3)/
     x-4.0980514d-08, 8.9987771d-22, 4.1587685d-11 /
      data fpppp(27,19,22,1),fpppp(27,19,22,2),fpppp(27,19,22,3)/
     x-3.8552849d-08,-9.6883584d-22, 3.9190215d-11 /
      data fpppp(27,19,23,1),fpppp(27,19,23,2),fpppp(27,19,23,3)/
     x-4.8700794d-09,-4.1085930d-22, 3.8657738d-11 /
      data fpppp(28, 1, 1,1),fpppp(28, 1, 1,2),fpppp(28, 1, 1,3)/
     x-2.2215382d-07,-8.3473276d-22, 6.7049688d-11 /
      data fpppp(28, 1, 2,1),fpppp(28, 1, 2,2),fpppp(28, 1, 2,3)/
     x-1.7229789d-07,-3.7814956d-21, 7.4266991d-11 /
      data fpppp(28, 1, 3,1),fpppp(28, 1, 3,2),fpppp(28, 1, 3,3)/
     x-1.0848772d-07, 1.6252605d-21, 9.1404004d-11 /
      data fpppp(28, 1, 4,1),fpppp(28, 1, 4,2),fpppp(28, 1, 4,3)/
     x-1.0848772d-07, 4.9808262d-23, 8.8479120d-11 /
      data fpppp(28, 1, 5,1),fpppp(28, 1, 5,2),fpppp(28, 1, 5,3)/
     x-1.7229789d-07,-6.6130413d-22, 8.5966528d-11 /
      data fpppp(28, 1, 6,1),fpppp(28, 1, 6,2),fpppp(28, 1, 6,3)/
     x-2.2215382d-07,-8.6589052d-22, 2.3176426d-11 /
      data fpppp(28, 1, 7,1),fpppp(28, 1, 7,2),fpppp(28, 1, 7,3)/
     x-2.7838452d-07, 2.9790158d-21,-9.6342433d-12 /
      data fpppp(28, 1, 8,1),fpppp(28, 1, 8,2),fpppp(28, 1, 8,3)/
     x-2.9535429d-07, 1.1010837d-21,-1.1559470d-10 /
      data fpppp(28, 1, 9,1),fpppp(28, 1, 9,2),fpppp(28, 1, 9,3)/
     x-2.6777923d-07,-1.0553455d-21, 7.5939502d-11 /
      data fpppp(28, 1,10,1),fpppp(28, 1,10,2),fpppp(28, 1,10,3)/
     x-2.7420335d-07,-2.5483024d-21,-1.9350432d-10 /
      data fpppp(28, 1,11,1),fpppp(28, 1,11,2),fpppp(28, 1,11,3)/
     x-2.5221361d-07, 1.0861152d-21, 6.6290044d-11 /
      data fpppp(28, 1,12,1),fpppp(28, 1,12,2),fpppp(28, 1,12,3)/
     x-2.7628175d-07,-1.8670241d-21,-7.1287517d-11 /
      data fpppp(28, 1,13,1),fpppp(28, 1,13,2),fpppp(28, 1,13,3)/
     x-2.8096626d-07, 1.5903148d-22,-1.4376342d-10 /
      data fpppp(28, 1,14,1),fpppp(28, 1,14,2),fpppp(28, 1,14,3)/
     x-2.6016228d-07, 1.8048328d-21, 1.8320211d-11 /
      data fpppp(28, 1,15,1),fpppp(28, 1,15,2),fpppp(28, 1,15,3)/
     x-2.5798177d-07,-6.3516359d-22, 2.6424627d-11 /
      data fpppp(28, 1,16,1),fpppp(28, 1,16,2),fpppp(28, 1,16,3)/
     x-2.7134394d-07,-3.2135896d-22,-1.2970669d-10 /
      data fpppp(28, 1,17,1),fpppp(28, 1,17,2),fpppp(28, 1,17,3)/
     x-2.4565231d-07, 6.0129183d-23,-2.0162337d-11 /
      data fpppp(28, 1,18,1),fpppp(28, 1,18,2),fpppp(28, 1,18,3)/
     x-1.9089432d-07,-4.7218558d-22, 7.6097855d-11 /
      data fpppp(28, 1,19,1),fpppp(28, 1,19,2),fpppp(28, 1,19,3)/
     x-9.6169076d-08,-1.0593554d-21,-2.3132903d-11 /
      data fpppp(28, 1,20,1),fpppp(28, 1,20,2),fpppp(28, 1,20,3)/
     x-3.1571555d-08, 1.2286612d-21, 1.3574704d-10 /
      data fpppp(28, 1,21,1),fpppp(28, 1,21,2),fpppp(28, 1,21,3)/
     x-3.1571555d-08,-9.0857268d-22, 1.2751723d-10 /
      data fpppp(28, 1,22,1),fpppp(28, 1,22,2),fpppp(28, 1,22,3)/
     x-9.6169076d-08,-1.3992871d-21, 9.7863502d-12 /
      data fpppp(28, 1,23,1),fpppp(28, 1,23,2),fpppp(28, 1,23,3)/
     x-1.9089432d-07,-3.5101655d-21,-4.7349343d-11 /
      data fpppp(28, 2, 1,1),fpppp(28, 2, 1,2),fpppp(28, 2, 1,3)/
     x-1.0384229d-07,-6.5606168d-08,-3.2229356d-12 /
      data fpppp(28, 2, 2,1),fpppp(28, 2, 2,2),fpppp(28, 2, 2,3)/
     x-8.1730250d-08,-3.6423518d-08, 1.4713139d-11 /
      data fpppp(28, 2, 3,1),fpppp(28, 2, 3,2),fpppp(28, 2, 3,3)/
     x-4.5075754d-08, 2.3627630d-08, 5.3327068d-11 /
      data fpppp(28, 2, 4,1),fpppp(28, 2, 4,2),fpppp(28, 2, 4,3)/
     x-4.5075754d-08, 2.7973057d-08, 5.3012971d-11 /
      data fpppp(28, 2, 5,1),fpppp(28, 2, 5,2),fpppp(28, 2, 5,3)/
     x-8.1730250d-08,-5.3805228d-08, 1.5969524d-11 /
      data fpppp(28, 2, 6,1),fpppp(28, 2, 6,2),fpppp(28, 2, 6,3)/
     x-1.0384229d-07,-4.2475823d-10,-7.9343802d-12 /
      data fpppp(28, 2, 7,1),fpppp(28, 2, 7,2),fpppp(28, 2, 7,3)/
     x-1.2621037d-07,-9.3955440d-09,-2.2307978d-11 /
      data fpppp(28, 2, 8,1),fpppp(28, 2, 8,2),fpppp(28, 2, 8,3)/
     x-1.2797201d-07,-7.7158065d-09,-6.0923209d-11 /
      data fpppp(28, 2, 9,1),fpppp(28, 2, 9,2),fpppp(28, 2, 9,3)/
     x-1.0837577d-07, 1.8931021d-08, 3.8147910d-11 /
      data fpppp(28, 2,10,1),fpppp(28, 2,10,2),fpppp(28, 2,10,3)/
     x-1.0716391d-07,-7.2423499d-09,-8.0986415d-11 /
      data fpppp(28, 2,11,1),fpppp(28, 2,11,2),fpppp(28, 2,11,3)/
     x-9.5293561d-08, 1.8714254d-08, 4.9373182d-11 /
      data fpppp(28, 2,12,1),fpppp(28, 2,12,2),fpppp(28, 2,12,3)/
     x-1.0655986d-07, 1.3142412d-08, 2.7570028d-12 /
      data fpppp(28, 2,13,1),fpppp(28, 2,13,2),fpppp(28, 2,13,3)/
     x-1.1134795d-07,-1.0534489d-08,-5.5154303d-11 /
      data fpppp(28, 2,14,1),fpppp(28, 2,14,2),fpppp(28, 2,14,3)/
     x-1.0307644d-07, 2.0940165d-08, 3.3902182d-11 /
      data fpppp(28, 2,15,1),fpppp(28, 2,15,2),fpppp(28, 2,15,3)/
     x-1.0847025d-07, 8.3933112d-09, 7.6614696d-12 /
      data fpppp(28, 2,16,1),fpppp(28, 2,16,2),fpppp(28, 2,16,3)/
     x-1.2152754d-07,-5.1179913d-09,-5.3172125d-11 /
      data fpppp(28, 2,17,1),fpppp(28, 2,17,2),fpppp(28, 2,17,3)/
     x-1.1820778d-07,-2.6711543d-09,-2.9844043d-11 /
      data fpppp(28, 2,18,1),fpppp(28, 2,18,2),fpppp(28, 2,18,3)/
     x-9.8616083d-08,-2.1926684d-08, 2.1064662d-11 /
      data fpppp(28, 2,19,1),fpppp(28, 2,19,2),fpppp(28, 2,19,3)/
     x-5.7167636d-08,-2.4589849d-08,-3.6606965d-11 /
      data fpppp(28, 2,20,1),fpppp(28, 2,20,2),fpppp(28, 2,20,3)/
     x-2.5432749d-08, 1.5419431d-08, 6.6736627d-11 /
      data fpppp(28, 2,21,1),fpppp(28, 2,21,2),fpppp(28, 2,21,3)/
     x-2.5432749d-08, 1.4406734d-08, 6.1709793d-11 /
      data fpppp(28, 2,22,1),fpppp(28, 2,22,2),fpppp(28, 2,22,3)/
     x-5.7167636d-08,-2.0539059d-08,-1.6499629d-11 /
      data fpppp(28, 2,23,1),fpppp(28, 2,23,2),fpppp(28, 2,23,3)/
     x-9.8616083d-08,-3.7117148d-08,-5.4337849d-11 /
      data fpppp(28, 3, 1,1),fpppp(28, 3, 1,2),fpppp(28, 3, 1,3)/
     x-7.9102933d-10,-7.1481485d-08,-1.1919235d-10 /
      data fpppp(28, 3, 2,1),fpppp(28, 3, 2,2),fpppp(28, 3, 2,3)/
     x 2.0470664d-09,-4.4709625d-08,-9.3050744d-11 /
      data fpppp(28, 3, 3,1),fpppp(28, 3, 3,2),fpppp(28, 3, 3,3)/
     x 6.8116077d-08, 1.0329766d-08,-3.9953083d-11 /
      data fpppp(28, 3, 4,1),fpppp(28, 3, 4,2),fpppp(28, 3, 4,3)/
     x 6.8116077d-08, 1.4405303d-08,-3.4842983d-11 /
      data fpppp(28, 3, 5,1),fpppp(28, 3, 5,2),fpppp(28, 3, 5,3)/
     x 2.0470664d-09,-6.1011774d-08,-1.1349114d-10 /
      data fpppp(28, 3, 6,1),fpppp(28, 3, 6,2),fpppp(28, 3, 6,3)/
     x-7.9102933d-10,-1.0348426d-08,-4.2540843d-11 /
      data fpppp(28, 3, 7,1),fpppp(28, 3, 7,2),fpppp(28, 3, 7,3)/
     x 3.5831451d-08, 4.6674770d-09,-9.3079570d-11 /
      data fpppp(28, 3, 8,1),fpppp(28, 3, 8,2),fpppp(28, 3, 8,3)/
     x 6.5333944d-08, 1.4799777d-08, 9.8172378d-11 /
      data fpppp(28, 3, 9,1),fpppp(28, 3, 9,2),fpppp(28, 3, 9,3)/
     x 7.6177443d-08, 4.7952282d-09,-7.2124783d-11 /
      data fpppp(28, 3,10,1),fpppp(28, 3,10,2),fpppp(28, 3,10,3)/
     x 1.2389173d-07, 1.6885307d-08, 1.5293969d-10 /
      data fpppp(28, 3,11,1),fpppp(28, 3,11,2),fpppp(28, 3,11,3)/
     x 1.5326248d-07,-2.2804611d-09,-4.2147999d-11 /
      data fpppp(28, 3,12,1),fpppp(28, 3,12,2),fpppp(28, 3,12,3)/
     x 1.9370819d-07, 2.6221186d-08, 2.5823070d-10 /
      data fpppp(28, 3,13,1),fpppp(28, 3,13,2),fpppp(28, 3,13,3)/
     x 1.6759807d-07,-2.3647957d-09, 7.0861072d-11 /
      data fpppp(28, 3,14,1),fpppp(28, 3,14,2),fpppp(28, 3,14,3)/
     x 1.1722188d-07, 2.0588030d-08, 1.0217810d-10 /
      data fpppp(28, 3,15,1),fpppp(28, 3,15,2),fpppp(28, 3,15,3)/
     x 6.4526747d-08, 7.6479694d-09,-6.7979111d-11 /
      data fpppp(28, 3,16,1),fpppp(28, 3,16,2),fpppp(28, 3,16,3)/
     x 2.7223348d-08, 1.6806020d-08, 1.2992257d-10 /
      data fpppp(28, 3,17,1),fpppp(28, 3,17,2),fpppp(28, 3,17,3)/
     x-7.3675216d-09, 2.9029318d-09,-7.9662404d-11 /
      data fpppp(28, 3,18,1),fpppp(28, 3,18,2),fpppp(28, 3,18,3)/
     x-4.2554481d-08,-1.0318371d-08,-1.5108023d-10 /
      data fpppp(28, 3,19,1),fpppp(28, 3,19,2),fpppp(28, 3,19,3)/
     x-6.3632741d-08,-5.0061947d-08,-8.3434054d-12 /
      data fpppp(28, 3,20,1),fpppp(28, 3,20,2),fpppp(28, 3,20,3)/
     x-1.5341944d-08, 1.2199500d-09,-6.0353142d-11 /
      data fpppp(28, 3,21,1),fpppp(28, 3,21,2),fpppp(28, 3,21,3)/
     x-1.5341944d-08,-1.8026035d-09,-5.2425546d-11 /
      data fpppp(28, 3,22,1),fpppp(28, 3,22,2),fpppp(28, 3,22,3)/
     x-6.3632741d-08,-3.7971733d-08,-4.0053792d-11 /
      data fpppp(28, 3,23,1),fpppp(28, 3,23,2),fpppp(28, 3,23,3)/
     x-4.2554481d-08,-5.5656674d-08,-3.2166282d-11 /
      data fpppp(28, 4, 1,1),fpppp(28, 4, 1,2),fpppp(28, 4, 1,3)/
     x 1.5567119d-07,-2.3028659d-09,-7.5223001d-11 /
      data fpppp(28, 4, 2,1),fpppp(28, 4, 2,2),fpppp(28, 4, 2,3)/
     x 1.0959053d-07,-1.1757904d-08,-3.2079520d-11 /
      data fpppp(28, 4, 3,1),fpppp(28, 4, 3,2),fpppp(28, 4, 3,3)/
     x 7.0783674d-09,-3.1938721d-08, 5.9978016d-11 /
      data fpppp(28, 4, 4,1),fpppp(28, 4, 4,2),fpppp(28, 4, 4,3)/
     x 7.0783674d-09,-3.2078684d-08, 6.0665382d-11 /
      data fpppp(28, 4, 5,1),fpppp(28, 4, 5,2),fpppp(28, 4, 5,3)/
     x 1.0959053d-07,-1.1198055d-08,-3.4828985d-11 /
      data fpppp(28, 4, 6,1),fpppp(28, 4, 6,2),fpppp(28, 4, 6,3)/
     x 1.5567119d-07,-4.4023000d-09,-6.4912507d-11 /
      data fpppp(28, 4, 7,1),fpppp(28, 4, 7,2),fpppp(28, 4, 7,3)/
     x 1.6333643d-07, 1.7401891d-08, 3.9491338d-11 /
      data fpppp(28, 4, 8,1),fpppp(28, 4, 8,2),fpppp(28, 4, 8,3)/
     x 1.6790704d-07, 1.5791853d-08,-1.0821636d-10 /
      data fpppp(28, 4, 9,1),fpppp(28, 4, 9,2),fpppp(28, 4, 9,3)/
     x 1.7270648d-07, 2.5032796d-08, 7.1286377d-11 /
      data fpppp(28, 4,10,1),fpppp(28, 4,10,2),fpppp(28, 4,10,3)/
     x 1.3089066d-07, 7.5265522d-09,-3.8062928d-11 /
      data fpppp(28, 4,11,1),fpppp(28, 4,11,2),fpppp(28, 4,11,3)/
     x 8.1092560d-08, 5.5991347d-09, 1.2744593d-10 /
      data fpppp(28, 4,12,1),fpppp(28, 4,12,2),fpppp(28, 4,12,3)/
     x 3.7064680d-08,-1.5777419d-08,-1.2129773d-10 /
      data fpppp(28, 4,13,1),fpppp(28, 4,13,2),fpppp(28, 4,13,3)/
     x 6.3897143d-08, 8.3553202d-09, 6.5954544d-11 /
      data fpppp(28, 4,14,1),fpppp(28, 4,14,2),fpppp(28, 4,14,3)/
     x 1.1627648d-07, 6.6537927d-09,-1.3974796d-11 /
      data fpppp(28, 4,15,1),fpppp(28, 4,15,2),fpppp(28, 4,15,3)/
     x 1.5532461d-07, 2.2408291d-08, 5.5451288d-11 /
      data fpppp(28, 4,16,1),fpppp(28, 4,16,2),fpppp(28, 4,16,3)/
     x 1.7970352d-07, 2.9523717d-08,-5.9943193d-11 /
      data fpppp(28, 4,17,1),fpppp(28, 4,17,2),fpppp(28, 4,17,3)/
     x 1.6158773d-07, 1.4529101d-08, 1.0997532d-11 /
      data fpppp(28, 4,18,1),fpppp(28, 4,18,2),fpppp(28, 4,18,3)/
     x 1.4026535d-07,-3.0311065d-09, 8.6665831d-11 /
      data fpppp(28, 4,19,1),fpppp(28, 4,19,2),fpppp(28, 4,19,3)/
     x 8.9035062d-08,-1.5918294d-08,-1.2616153d-10 /
      data fpppp(28, 4,20,1),fpppp(28, 4,20,2),fpppp(28, 4,20,3)/
     x-1.9083135d-08,-3.6246732d-08, 1.5834831d-11 /
      data fpppp(28, 4,21,1),fpppp(28, 4,21,2),fpppp(28, 4,21,3)/
     x-1.9083135d-08,-3.6408152d-08, 2.5867780d-12 /
      data fpppp(28, 4,22,1),fpppp(28, 4,22,2),fpppp(28, 4,22,3)/
     x 8.9035062d-08,-1.5272614d-08,-7.3169312d-11 /
      data fpppp(28, 4,23,1),fpppp(28, 4,23,2),fpppp(28, 4,23,3)/
     x 1.4026535d-07,-5.4524081d-09,-1.1205497d-10 /
      data fpppp(28, 5, 1,1),fpppp(28, 5, 1,2),fpppp(28, 5, 1,3)/
     x 3.7749537d-08,-9.7850410d-09, 1.6122061d-10 /
      data fpppp(28, 5, 2,1),fpppp(28, 5, 2,2),fpppp(28, 5, 2,3)/
     x 1.5782984d-09,-1.3956027d-08, 7.9096306d-11 /
      data fpppp(28, 5, 3,1),fpppp(28, 5, 3,2),fpppp(28, 5, 3,3)/
     x-3.8129299d-08,-2.2978453d-08,-9.2005170d-11 /
      data fpppp(28, 5, 4,1),fpppp(28, 5, 4,2),fpppp(28, 5, 4,3)/
     x-3.8129299d-08,-2.2830404d-08,-1.0054372d-10 /
      data fpppp(28, 5, 5,1),fpppp(28, 5, 5,2),fpppp(28, 5, 5,3)/
     x 1.5782984d-09,-1.4548225d-08, 1.1325052d-10 /
      data fpppp(28, 5, 6,1),fpppp(28, 5, 6,2),fpppp(28, 5, 6,3)/
     x 3.7749537d-08,-7.5642968d-09, 3.3142318d-11 /
      data fpppp(28, 5, 7,1),fpppp(28, 5, 7,2),fpppp(28, 5, 7,3)/
     x 8.6302879d-08, 1.7913682d-08, 7.0864994d-11 /
      data fpppp(28, 5, 8,1),fpppp(28, 5, 8,2),fpppp(28, 5, 8,3)/
     x 9.4512358d-08, 1.4940161d-08, 6.0738528d-11 /
      data fpppp(28, 5, 9,1),fpppp(28, 5, 9,2),fpppp(28, 5, 9,3)/
     x 6.5655732d-08, 1.0058285d-08, 2.7046694d-11 /
      data fpppp(28, 5,10,1),fpppp(28, 5,10,2),fpppp(28, 5,10,3)/
     x 4.3874897d-08,-1.6546025d-09, 3.2996888d-11 /
      data fpppp(28, 5,11,1),fpppp(28, 5,11,2),fpppp(28, 5,11,3)/
     x 3.6607167d-08, 1.2220900d-08,-1.2244264d-10 /
      data fpppp(28, 5,12,1),fpppp(28, 5,12,2),fpppp(28, 5,12,3)/
     x 4.2194161d-08,-5.9117458d-09,-1.0749706d-10 /
      data fpppp(28, 5,13,1),fpppp(28, 5,13,2),fpppp(28, 5,13,3)/
     x 4.5775535d-08, 2.7756068d-08,-6.2043267d-11 /
      data fpppp(28, 5,14,1),fpppp(28, 5,14,2),fpppp(28, 5,14,3)/
     x 4.9997207d-08,-1.5305527d-08,-8.2365577d-11 /
      data fpppp(28, 5,15,1),fpppp(28, 5,15,2),fpppp(28, 5,15,3)/
     x 7.8540072d-08, 2.9265732d-08, 7.7884619d-11 /
      data fpppp(28, 5,16,1),fpppp(28, 5,16,2),fpppp(28, 5,16,3)/
     x 7.5570373d-08, 7.0803003d-09,-6.0905777d-11 /
      data fpppp(28, 5,17,1),fpppp(28, 5,17,2),fpppp(28, 5,17,3)/
     x 8.7699473d-08, 2.2535159d-08, 1.2698554d-10 /
      data fpppp(28, 5,18,1),fpppp(28, 5,18,2),fpppp(28, 5,18,3)/
     x 4.9998790d-08,-9.3545117d-09,-3.0080148d-11 /
      data fpppp(28, 5,19,1),fpppp(28, 5,19,2),fpppp(28, 5,19,3)/
     x 1.8438133d-08,-2.3094779d-08, 1.1966448d-10 /
      data fpppp(28, 5,20,1),fpppp(28, 5,20,2),fpppp(28, 5,20,3)/
     x 2.0015310d-08,-1.9866934d-08,-3.5189007d-11 /
      data fpppp(28, 5,21,1),fpppp(28, 5,21,2),fpppp(28, 5,21,3)/
     x 2.0015310d-08,-2.0590664d-08,-2.4650578d-11 /
      data fpppp(28, 5,22,1),fpppp(28, 5,22,2),fpppp(28, 5,22,3)/
     x 1.8438133d-08,-2.0199856d-08, 7.7510759d-11 /
      data fpppp(28, 5,23,1),fpppp(28, 5,23,2),fpppp(28, 5,23,3)/
     x 4.9998790d-08,-2.0210473d-08, 1.2799630d-10 /
      data fpppp(28, 6, 1,1),fpppp(28, 6, 1,2),fpppp(28, 6, 1,3)/
     x-5.3723779d-08,-4.0637905d-08,-4.1608735d-11 /
      data fpppp(28, 6, 2,1),fpppp(28, 6, 2,2),fpppp(28, 6, 2,3)/
     x-3.9320059d-08,-2.3488704d-08,-5.0407108d-11 /
      data fpppp(28, 6, 3,1),fpppp(28, 6, 3,2),fpppp(28, 6, 3,3)/
     x 1.8734462d-08, 1.1764596d-08,-7.5602428d-11 /
      data fpppp(28, 6, 4,1),fpppp(28, 6, 4,2),fpppp(28, 6, 4,3)/
     x 1.8734462d-08, 1.4380822d-08,-6.4504516d-11 /
      data fpppp(28, 6, 5,1),fpppp(28, 6, 5,2),fpppp(28, 6, 5,3)/
     x-3.9320059d-08,-3.3953606d-08,-9.4798756d-11 /
      data fpppp(28, 6, 6,1),fpppp(28, 6, 6,2),fpppp(28, 6, 6,3)/
     x-5.3723779d-08,-1.3945231d-09, 1.2485995d-10 /
      data fpppp(28, 6, 7,1),fpppp(28, 6, 7,2),fpppp(28, 6, 7,3)/
     x-9.0142115d-08,-1.3748025d-08, 2.3607505d-11 /
      data fpppp(28, 6, 8,1),fpppp(28, 6, 8,2),fpppp(28, 6, 8,3)/
     x-9.9488866d-08,-3.9478175d-09, 8.6510263d-11 /
      data fpppp(28, 6, 9,1),fpppp(28, 6, 9,2),fpppp(28, 6, 9,3)/
     x-6.5287633d-08,-5.0851934d-09, 2.8975991d-11 /
      data fpppp(28, 6,10,1),fpppp(28, 6,10,2),fpppp(28, 6,10,3)/
     x-1.8110146d-08, 2.5405485d-09,-6.8969207d-11 /
      data fpppp(28, 6,11,1),fpppp(28, 6,11,2),fpppp(28, 6,11,3)/
     x 3.2895764d-08, 1.9404985d-08, 5.4053818d-11 /
      data fpppp(28, 6,12,1),fpppp(28, 6,12,2),fpppp(28, 6,12,3)/
     x 5.3173004d-08, 1.4788786d-08,-4.0586207d-11 /
      data fpppp(28, 6,13,1),fpppp(28, 6,13,2),fpppp(28, 6,13,3)/
     x 4.2034645d-08, 3.4677326d-08,-2.2021924d-11 /
      data fpppp(28, 6,14,1),fpppp(28, 6,14,2),fpppp(28, 6,14,3)/
     x-2.0296764d-09,-2.9996412d-09,-4.7728918d-11 /
      data fpppp(28, 6,15,1),fpppp(28, 6,15,2),fpppp(28, 6,15,3)/
     x-4.6302046d-08,-4.7126384d-09,-3.8085229d-11 /
      data fpppp(28, 6,16,1),fpppp(28, 6,16,2),fpppp(28, 6,16,3)/
     x-5.3185837d-08, 1.0384023d-08, 9.9114177d-11 /
      data fpppp(28, 6,17,1),fpppp(28, 6,17,2),fpppp(28, 6,17,3)/
     x-6.1997606d-08,-1.5639005d-08,-3.0035721d-11 /
      data fpppp(28, 6,18,1),fpppp(28, 6,18,2),fpppp(28, 6,18,3)/
     x-2.1300989d-08,-9.7215044d-09, 8.2491052d-11 /
      data fpppp(28, 6,19,1),fpppp(28, 6,19,2),fpppp(28, 6,19,3)/
     x 1.4039178d-08,-1.8620949d-08, 4.3254490d-11 /
      data fpppp(28, 6,20,1),fpppp(28, 6,20,2),fpppp(28, 6,20,3)/
     x 3.4856733d-08, 5.0960112d-09,-6.6918590d-11 /
      data fpppp(28, 6,21,1),fpppp(28, 6,21,2),fpppp(28, 6,21,3)/
     x 3.4856733d-08, 4.1481935d-09,-6.6340542d-11 /
      data fpppp(28, 6,22,1),fpppp(28, 6,22,2),fpppp(28, 6,22,3)/
     x 1.4039178d-08,-1.4829678d-08, 4.0942299d-11 /
      data fpppp(28, 6,23,1),fpppp(28, 6,23,2),fpppp(28, 6,23,3)/
     x-2.1300989d-08,-2.3938770d-08, 9.1161771d-11 /
      data fpppp(28, 7, 1,1),fpppp(28, 7, 1,2),fpppp(28, 7, 1,3)/
     x-5.1225989d-08,-1.3415528d-08, 2.2988751d-11 /
      data fpppp(28, 7, 2,1),fpppp(28, 7, 2,2),fpppp(28, 7, 2,3)/
     x 1.0031281d-09,-3.8586820d-09, 2.6983282d-11 /
      data fpppp(28, 7, 3,1),fpppp(28, 7, 3,2),fpppp(28, 7, 3,3)/
     x 2.7293819d-08, 1.6910029d-08, 3.8835833d-11 /
      data fpppp(28, 7, 4,1),fpppp(28, 7, 4,2),fpppp(28, 7, 4,3)/
     x 2.7293819d-08, 1.6402959d-08, 3.3073358d-11 /
      data fpppp(28, 7, 5,1),fpppp(28, 7, 5,2),fpppp(28, 7, 5,3)/
     x 1.0031281d-09,-1.8304006d-09, 5.0033184d-11 /
      data fpppp(28, 7, 6,1),fpppp(28, 7, 6,2),fpppp(28, 7, 6,3)/
     x-5.1225989d-08,-2.1021584d-08,-6.3448380d-11 /
      data fpppp(28, 7, 7,1),fpppp(28, 7, 7,2),fpppp(28, 7, 7,3)/
     x-5.6617542d-08,-2.2589782d-08,-2.5918582d-11 /
      data fpppp(28, 7, 8,1),fpppp(28, 7, 8,2),fpppp(28, 7, 8,3)/
     x-4.2421536d-08,-7.8872198d-10, 6.5809736d-12 /
      data fpppp(28, 7, 9,1),fpppp(28, 7, 9,2),fpppp(28, 7, 9,3)/
     x-4.1310724d-08,-7.1962794d-09,-1.3576930d-10 /
      data fpppp(28, 7,10,1),fpppp(28, 7,10,2),fpppp(28, 7,10,3)/
     x-2.4217972d-08, 7.5218067d-09, 1.6079394d-10 /
      data fpppp(28, 7,11,1),fpppp(28, 7,11,2),fpppp(28, 7,11,3)/
     x-3.6574058d-08, 1.0790205d-08,-1.3261000d-10 /
      data fpppp(28, 7,12,1),fpppp(28, 7,12,2),fpppp(28, 7,12,3)/
     x-2.6834150d-08, 9.9347082d-09, 1.4727737d-10 /
      data fpppp(28, 7,13,1),fpppp(28, 7,13,2),fpppp(28, 7,13,3)/
     x-3.0929784d-08, 1.8112325d-08,-4.0773578d-11 /
      data fpppp(28, 7,14,1),fpppp(28, 7,14,2),fpppp(28, 7,14,3)/
     x-2.5308158d-08, 7.4596016d-09, 7.9463933d-11 /
      data fpppp(28, 7,15,1),fpppp(28, 7,15,2),fpppp(28, 7,15,3)/
     x-4.0739174d-08,-5.3818220d-09,-3.9369901d-11 /
      data fpppp(28, 7,16,1),fpppp(28, 7,16,2),fpppp(28, 7,16,3)/
     x-5.6564017d-08,-5.4433338d-11,-4.6428823d-11 /
      data fpppp(28, 7,17,1),fpppp(28, 7,17,2),fpppp(28, 7,17,3)/
     x-5.6471993d-08,-8.8498866d-09, 3.0495107d-11 /
      data fpppp(28, 7,18,1),fpppp(28, 7,18,2),fpppp(28, 7,18,3)/
     x-4.9336584d-08,-2.0952308d-08,-1.8357209d-11 /
      data fpppp(28, 7,19,1),fpppp(28, 7,19,2),fpppp(28, 7,19,3)/
     x-2.2874708d-08,-1.1614464d-08,-1.6127603d-11 /
      data fpppp(28, 7,20,1),fpppp(28, 7,20,2),fpppp(28, 7,20,3)/
     x 1.2236009d-08, 1.4488377d-08,-4.8828291d-12 /
      data fpppp(28, 7,21,1),fpppp(28, 7,21,2),fpppp(28, 7,21,3)/
     x 1.2236009d-08, 1.4353402d-08,-5.0260865d-12 /
      data fpppp(28, 7,22,1),fpppp(28, 7,22,2),fpppp(28, 7,22,3)/
     x-2.2874708d-08,-1.1074563d-08,-1.5554573d-11 /
      data fpppp(28, 7,23,1),fpppp(28, 7,23,2),fpppp(28, 7,23,3)/
     x-4.9336584d-08,-2.2976939d-08,-2.0506069d-11 /
      data fpppp(28, 8, 1,1),fpppp(28, 8, 1,2),fpppp(28, 8, 1,3)/
     x 4.7053657d-09, 4.5451464d-09, 7.0196702d-11 /
      data fpppp(28, 8, 2,1),fpppp(28, 8, 2,2),fpppp(28, 8, 2,3)/
     x-2.7334052d-08, 5.1856163d-09, 6.1388037d-11 /
      data fpppp(28, 8, 3,1),fpppp(28, 8, 3,2),fpppp(28, 8, 3,3)/
     x-6.5804302d-08, 7.1263259d-09, 4.4059897d-11 /
      data fpppp(28, 8, 4,1),fpppp(28, 8, 4,2),fpppp(28, 8, 4,3)/
     x-6.5804302d-08, 6.1318459d-09, 4.1351648d-11 /
      data fpppp(28, 8, 5,1),fpppp(28, 8, 5,2),fpppp(28, 8, 5,3)/
     x-2.7334052d-08, 9.1635360d-09, 7.2221034d-11 /
      data fpppp(28, 8, 6,1),fpppp(28, 8, 6,2),fpppp(28, 8, 6,3)/
     x 4.7053657d-09,-1.0372052d-08, 2.9572963d-11 /
      data fpppp(28, 8, 7,1),fpppp(28, 8, 7,2),fpppp(28, 8, 7,3)/
     x-6.3220633d-09,-9.1398440d-09,-6.0045739d-11 /
      data fpppp(28, 8, 8,1),fpppp(28, 8, 8,2),fpppp(28, 8, 8,3)/
     x-1.5687954d-08,-9.9896381d-09,-1.7302329d-10 /
      data fpppp(28, 8, 9,1),fpppp(28, 8, 9,2),fpppp(28, 8, 9,3)/
     x-1.9085974d-08, 1.5016065d-08, 1.7497028d-10 /
      data fpppp(28, 8,10,1),fpppp(28, 8,10,2),fpppp(28, 8,10,3)/
     x-4.7002850d-08,-2.0045487d-08,-2.3749379d-10 /
      data fpppp(28, 8,11,1),fpppp(28, 8,11,2),fpppp(28, 8,11,3)/
     x-4.3958253d-08, 2.5040747d-08, 1.8866601d-10 /
      data fpppp(28, 8,12,1),fpppp(28, 8,12,2),fpppp(28, 8,12,3)/
     x-6.3907641d-08,-1.9170790d-08,-9.4355324d-11 /
      data fpppp(28, 8,13,1),fpppp(28, 8,13,2),fpppp(28, 8,13,3)/
     x-5.6009621d-08, 1.6777326d-08, 9.6164618d-11 /
      data fpppp(28, 8,14,1),fpppp(28, 8,14,2),fpppp(28, 8,14,3)/
     x-4.3768082d-08,-8.4631475d-09,-8.4882904d-12 /
      data fpppp(28, 8,15,1),fpppp(28, 8,15,2),fpppp(28, 8,15,3)/
     x-2.3400793d-08, 7.9540933d-09,-4.2037647d-11 /
      data fpppp(28, 8,16,1),fpppp(28, 8,16,2),fpppp(28, 8,16,3)/
     x-2.3198295d-09,-3.6043474d-09, 5.5372511d-11 /
      data fpppp(28, 8,17,1),fpppp(28, 8,17,2),fpppp(28, 8,17,3)/
     x 7.3355093d-09, 6.6938325d-09,-8.9427817d-11 /
      data fpppp(28, 8,18,1),fpppp(28, 8,18,2),fpppp(28, 8,18,3)/
     x-4.9961566d-09,-1.8395139d-08, 1.2098829d-11 /
      data fpppp(28, 8,19,1),fpppp(28, 8,19,2),fpppp(28, 8,19,3)/
     x-1.6768635d-08, 3.9941373d-09,-6.5905145d-11 /
      data fpppp(28, 8,20,1),fpppp(28, 8,20,2),fpppp(28, 8,20,3)/
     x-2.1197781d-08, 3.1003907d-09, 5.3933126d-11 /
      data fpppp(28, 8,21,1),fpppp(28, 8,21,2),fpppp(28, 8,21,3)/
     x-2.1197781d-08, 4.1829710d-09, 4.7575761d-11 /
      data fpppp(28, 8,22,1),fpppp(28, 8,22,2),fpppp(28, 8,22,3)/
     x-1.6768635d-08,-3.3618379d-10,-4.0475683d-11 /
      data fpppp(28, 8,23,1),fpppp(28, 8,23,2),fpppp(28, 8,23,3)/
     x-4.9961566d-09,-2.1564346d-09,-8.3261654d-11 /
      data fpppp(28, 9, 1,1),fpppp(28, 9, 1,2),fpppp(28, 9, 1,3)/
     x-1.7459615d-08,-2.7558887d-09,-6.3071861d-11 /
      data fpppp(28, 9, 2,1),fpppp(28, 9, 2,2),fpppp(28, 9, 2,3)/
     x-2.7263136d-09, 2.2511510d-09,-3.3942823d-11 /
      data fpppp(28, 9, 3,1),fpppp(28, 9, 3,2),fpppp(28, 9, 3,3)/
     x 6.6109508d-09, 1.3461596d-08, 2.9850456d-11 /
      data fpppp(28, 9, 4,1),fpppp(28, 9, 4,2),fpppp(28, 9, 4,3)/
     x 6.6109508d-09, 1.2619716d-08, 2.7446113d-11 /
      data fpppp(28, 9, 5,1),fpppp(28, 9, 5,2),fpppp(28, 9, 5,3)/
     x-2.7263136d-09, 5.6186724d-09,-2.4325451d-11 /
      data fpppp(28, 9, 6,1),fpppp(28, 9, 6,2),fpppp(28, 9, 6,3)/
     x-1.7459615d-08,-1.5384094d-08,-9.9137008d-11 /
      data fpppp(28, 9, 7,1),fpppp(28, 9, 7,2),fpppp(28, 9, 7,3)/
     x 1.1936579d-08, 1.9485501d-10, 1.2868381d-10 /
      data fpppp(28, 9, 8,1),fpppp(28, 9, 8,2),fpppp(28, 9, 8,3)/
     x-4.1842977d-09,-6.3513827d-09, 1.9947662d-10 /
      data fpppp(28, 9, 9,1),fpppp(28, 9, 9,2),fpppp(28, 9, 9,3)/
     x-1.8189504d-08, 2.8889185d-09,-2.8255188d-10 /
      data fpppp(28, 9,10,1),fpppp(28, 9,10,2),fpppp(28, 9,10,3)/
     x-3.4995775d-08,-7.9885386d-09, 1.4897695d-10 /
      data fpppp(28, 9,11,1),fpppp(28, 9,11,2),fpppp(28, 9,11,3)/
     x-5.3636919d-08, 7.6959966d-09,-1.4279693d-10 /
      data fpppp(28, 9,12,1),fpppp(28, 9,12,2),fpppp(28, 9,12,3)/
     x-5.3572762d-08,-1.2694008d-08, 3.3319714d-11 /
      data fpppp(28, 9,13,1),fpppp(28, 9,13,2),fpppp(28, 9,13,3)/
     x-4.3827554d-08, 1.1943642d-08,-3.5845172d-11 /
      data fpppp(28, 9,14,1),fpppp(28, 9,14,2),fpppp(28, 9,14,3)/
     x-3.1623933d-08,-1.6423686d-08,-8.4544565d-13 /
      data fpppp(28, 9,15,1),fpppp(28, 9,15,2),fpppp(28, 9,15,3)/
     x-1.2000800d-08, 1.1809724d-08, 8.0819463d-11 /
      data fpppp(28, 9,16,1),fpppp(28, 9,16,2),fpppp(28, 9,16,3)/
     x-2.0004388d-08,-2.3611840d-09,-7.2922448d-11 /
      data fpppp(28, 9,17,1),fpppp(28, 9,17,2),fpppp(28, 9,17,3)/
     x-1.0322952d-08, 4.4492047d-10, 4.5362087d-11 /
      data fpppp(28, 9,18,1),fpppp(28, 9,18,2),fpppp(28, 9,18,3)/
     x 6.8578726d-09,-6.8657692d-09,-8.4760593d-11 /
      data fpppp(28, 9,19,1),fpppp(28, 9,19,2),fpppp(28, 9,19,3)/
     x 1.4697803d-08, 1.7728890d-08, 6.0492202d-11 /
      data fpppp(28, 9,20,1),fpppp(28, 9,20,2),fpppp(28, 9,20,3)/
     x-1.2411121d-08,-6.6910863d-09, 8.9673560d-13 /
      data fpppp(28, 9,21,1),fpppp(28, 9,21,2),fpppp(28, 9,21,3)/
     x-1.2411121d-08,-4.9826695d-09, 9.1117995d-12 /
      data fpppp(28, 9,22,1),fpppp(28, 9,22,2),fpppp(28, 9,22,3)/
     x 1.4697803d-08, 1.0895223d-08, 2.7631946d-11 /
      data fpppp(28, 9,23,1),fpppp(28, 9,23,2),fpppp(28, 9,23,3)/
     x 6.8578726d-09, 1.8760484d-08, 3.8465365d-11 /
      data fpppp(28,10, 1,1),fpppp(28,10, 1,2),fpppp(28,10, 1,3)/
     x-9.9452495d-09,-9.9871886d-09,-3.0262430d-12 /
      data fpppp(28,10, 2,1),fpppp(28,10, 2,2),fpppp(28,10, 2,3)/
     x-1.6992127d-08,-1.0245758d-09,-5.3827710d-12 /
      data fpppp(28,10, 3,1),fpppp(28,10, 3,2),fpppp(28,10, 3,3)/
     x 1.4730874d-10, 1.7263514d-08,-1.9280631d-11 /
      data fpppp(28,10, 4,1),fpppp(28,10, 4,2),fpppp(28,10, 4,3)/
     x 1.4730874d-10, 1.8869155d-08,-3.7963563d-12 /
      data fpppp(28,10, 5,1),fpppp(28,10, 5,2),fpppp(28,10, 5,3)/
     x-1.6992127d-08,-7.4471400d-09,-6.7319868d-11 /
      data fpppp(28,10, 6,1),fpppp(28,10, 6,2),fpppp(28,10, 6,3)/
     x-9.9452495d-09, 1.4097427d-08, 2.2923787d-10 /
      data fpppp(28,10, 7,1),fpppp(28,10, 7,2),fpppp(28,10, 7,3)/
     x-4.4887398d-08,-2.7461643d-08,-1.7134009d-10 /
      data fpppp(28,10, 8,1),fpppp(28,10, 8,2),fpppp(28,10, 8,3)/
     x-7.9168943d-09, 2.2640090d-09,-1.8054369d-10 /
      data fpppp(28,10, 9,1),fpppp(28,10, 9,2),fpppp(28,10, 9,3)/
     x-9.0985057d-09,-1.5877140d-08, 3.3452975d-10 /
      data fpppp(28,10,10,1),fpppp(28,10,10,2),fpppp(28,10,10,3)/
     x 6.8595594d-09, 7.0634853d-09,-1.1992358d-10 /
      data fpppp(28,10,11,1),fpppp(28,10,11,2),fpppp(28,10,11,3)/
     x 1.3898437d-08,-2.8735148d-10, 4.9267430d-11 /
      data fpppp(28,10,12,1),fpppp(28,10,12,2),fpppp(28,10,12,3)/
     x 1.7111437d-08, 1.3434262d-09,-2.4396844d-11 /
      data fpppp(28,10,13,1),fpppp(28,10,13,2),fpppp(28,10,13,3)/
     x-7.4483832d-09, 6.3047445d-09,-3.7636398d-11 /
      data fpppp(28,10,14,1),fpppp(28,10,14,2),fpppp(28,10,14,3)/
     x-2.4302801d-08,-6.8414534d-09,-2.3246736d-11 /
      data fpppp(28,10,15,1),fpppp(28,10,15,2),fpppp(28,10,15,3)/
     x-3.4040045d-08,-8.7795507d-09,-5.5920497d-11 /
      data fpppp(28,10,16,1),fpppp(28,10,16,2),fpppp(28,10,16,3)/
     x-2.5363843d-09, 1.0566524d-08, 9.0155264d-11 /
      data fpppp(28,10,17,1),fpppp(28,10,17,2),fpppp(28,10,17,3)/
     x-4.9410051d-09,-2.6910749d-09,-9.2692172d-11 /
      data fpppp(28,10,18,1),fpppp(28,10,18,2),fpppp(28,10,18,3)/
     x 4.2964248d-09, 1.7998732d-10, 1.1579211d-10 /
      data fpppp(28,10,19,1),fpppp(28,10,19,2),fpppp(28,10,19,3)/
     x 3.1663846d-09,-8.8668042d-10,-5.0786307d-11 /
      data fpppp(28,10,20,1),fpppp(28,10,20,2),fpppp(28,10,20,3)/
     x 1.7559973d-08, 4.7388999d-10, 1.2521940d-11 /
      data fpppp(28,10,21,1),fpppp(28,10,21,2),fpppp(28,10,21,3)/
     x 1.7559973d-08, 3.9311781d-10, 3.2123384d-12 /
      data fpppp(28,10,22,1),fpppp(28,10,22,2),fpppp(28,10,22,3)/
     x 3.1663846d-09,-5.6359170d-10,-1.3547902d-11 /
      data fpppp(28,10,23,1),fpppp(28,10,23,2),fpppp(28,10,23,3)/
     x 4.2964248d-09,-1.0315954d-09,-2.3851907d-11 /
      data fpppp(28,11, 1,1),fpppp(28,11, 1,2),fpppp(28,11, 1,3)/
     x-8.8411746d-09, 1.2353985d-08, 2.7245640d-11 /
      data fpppp(28,11, 2,1),fpppp(28,11, 2,2),fpppp(28,11, 2,3)/
     x-2.4304963d-09, 1.1666640d-08, 1.3362952d-12 /
      data fpppp(28,11, 3,1),fpppp(28,11, 3,2),fpppp(28,11, 3,3)/
     x-4.1481495d-09, 1.0846072d-08,-4.8246292d-11 /
      data fpppp(28,11, 4,1),fpppp(28,11, 4,2),fpppp(28,11, 4,3)/
     x-4.1481495d-09, 9.7045221d-09,-5.8636806d-11 /
      data fpppp(28,11, 5,1),fpppp(28,11, 5,2),fpppp(28,11, 5,3)/
     x-2.4304963d-09, 1.6232840d-08, 4.2898353d-11 /
      data fpppp(28,11, 6,1),fpppp(28,11, 6,2),fpppp(28,11, 6,3)/
     x-8.8411746d-09,-4.7692651d-09,-1.2861208d-10 /
      data fpppp(28,11, 7,1),fpppp(28,11, 7,2),fpppp(28,11, 7,3)/
     x 6.5907638d-09,-4.5507277d-10, 2.1057352d-10 /
      data fpppp(28,11, 8,1),fpppp(28,11, 8,2),fpppp(28,11, 8,3)/
     x-7.3483668d-08,-1.2797491d-08, 1.3790785d-10 /
      data fpppp(28,11, 9,1),fpppp(28,11, 9,2),fpppp(28,11, 9,3)/
     x-2.6280041d-08,-1.7813428d-08,-2.5030301d-10 /
      data fpppp(28,11,10,1),fpppp(28,11,10,2),fpppp(28,11,10,3)/
     x-1.8165529d-08, 5.1418475d-09, 1.4451175d-11 /
      data fpppp(28,11,11,1),fpppp(28,11,11,2),fpppp(28,11,11,3)/
     x-1.4298685d-08, 1.0348831d-09, 4.5527912d-11 /
      data fpppp(28,11,12,1),fpppp(28,11,12,2),fpppp(28,11,12,3)/
     x-1.5632775d-08,-6.6669493d-09,-1.8668929d-11 /
      data fpppp(28,11,13,1),fpppp(28,11,13,2),fpppp(28,11,13,3)/
     x 1.3173663d-08, 8.2818020d-09, 5.8336431d-11 /
      data fpppp(28,11,14,1),fpppp(28,11,14,2),fpppp(28,11,14,3)/
     x 1.5753711d-08, 1.3784047d-09,-3.1013683d-11 /
      data fpppp(28,11,15,1),fpppp(28,11,15,2),fpppp(28,11,15,3)/
     x 1.7893986d-08, 3.9131482d-09, 5.0301155d-11 /
      data fpppp(28,11,16,1),fpppp(28,11,16,2),fpppp(28,11,16,3)/
     x-1.6693609d-08,-7.6622571d-09,-1.5260705d-10 /
      data fpppp(28,11,17,1),fpppp(28,11,17,2),fpppp(28,11,17,3)/
     x-8.7043048d-09, 1.0145714d-08, 2.3760173d-10 /
      data fpppp(28,11,18,1),fpppp(28,11,18,2),fpppp(28,11,18,3)/
     x-3.6718842d-08,-7.4451550d-09,-1.6227993d-10 /
      data fpppp(28,11,19,1),fpppp(28,11,19,2),fpppp(28,11,19,3)/
     x-4.2931366d-08,-5.8002016d-09, 8.5946194d-11 /
      data fpppp(28,11,20,1),fpppp(28,11,20,2),fpppp(28,11,20,3)/
     x-4.2209543d-08, 1.5815726d-09,-4.0285093d-11 /
      data fpppp(28,11,21,1),fpppp(28,11,21,2),fpppp(28,11,21,3)/
     x-4.2209543d-08, 1.4961355d-09,-2.5705944d-11 /
      data fpppp(28,11,22,1),fpppp(28,11,22,2),fpppp(28,11,22,3)/
     x-4.2931366d-08,-5.4584532d-09, 2.7629600d-11 /
      data fpppp(28,11,23,1),fpppp(28,11,23,2),fpppp(28,11,23,3)/
     x-3.6718842d-08,-8.7267112d-09, 5.6407294d-11 /
      data fpppp(28,12, 1,1),fpppp(28,12, 1,2),fpppp(28,12, 1,3)/
     x 1.5708839d-08, 2.4716701d-08, 6.1814888d-11 /
      data fpppp(28,12, 2,1),fpppp(28,12, 2,2),fpppp(28,12, 2,3)/
     x 2.0584998d-08, 1.8455103d-08, 2.4495184d-11 /
      data fpppp(28,12, 3,1),fpppp(28,12, 3,2),fpppp(28,12, 3,3)/
     x 1.3099853d-09, 5.5399190d-09,-5.3335779d-11 /
      data fpppp(28,12, 4,1),fpppp(28,12, 4,2),fpppp(28,12, 4,3)/
     x 1.3099853d-09, 4.6604952d-09,-5.7080484d-11 /
      data fpppp(28,12, 5,1),fpppp(28,12, 5,2),fpppp(28,12, 5,3)/
     x 2.0584998d-08, 2.1972798d-08, 3.9474004d-11 /
      data fpppp(28,12, 6,1),fpppp(28,12, 6,2),fpppp(28,12, 6,3)/
     x 1.5708839d-08, 1.1525344d-08, 5.6443133d-12 /
      data fpppp(28,12, 7,1),fpppp(28,12, 7,2),fpppp(28,12, 7,3)/
     x 5.7012570d-10,-6.1034799d-08,-5.6437013d-11 /
      data fpppp(28,12, 8,1),fpppp(28,12, 8,2),fpppp(28,12, 8,3)/
     x 8.7541991d-08, 7.9322642d-08,-2.9589406d-11 /
      data fpppp(28,12, 9,1),fpppp(28,12, 9,2),fpppp(28,12, 9,3)/
     x 3.2669513d-09,-6.1176737d-08, 1.2617215d-10 /
      data fpppp(28,12,10,1),fpppp(28,12,10,2),fpppp(28,12,10,3)/
     x 6.7699593d-09, 1.0307926d-08, 8.2661178d-11 /
      data fpppp(28,12,11,1),fpppp(28,12,11,2),fpppp(28,12,11,3)/
     x 7.9804893d-09,-1.2769072d-08,-1.3303811d-10 /
      data fpppp(28,12,12,1),fpppp(28,12,12,2),fpppp(28,12,12,3)/
     x 7.7023110d-09, 1.2621400d-08, 4.5166406d-11 /
      data fpppp(28,12,13,1),fpppp(28,12,13,2),fpppp(28,12,13,3)/
     x-1.3831777d-08,-1.2276471d-08,-7.8425676d-11 /
      data fpppp(28,12,14,1),fpppp(28,12,14,2),fpppp(28,12,14,3)/
     x 5.0596551d-09, 1.5666227d-08, 9.2073024d-11 /
      data fpppp(28,12,15,1),fpppp(28,12,15,2),fpppp(28,12,15,3)/
     x-1.1230159d-08,-1.4953848d-08,-4.1653992d-11 /
      data fpppp(28,12,16,1),fpppp(28,12,16,2),fpppp(28,12,16,3)/
     x 6.8001482d-10, 1.6809189d-08, 1.6098085d-10 /
      data fpppp(28,12,17,1),fpppp(28,12,17,2),fpppp(28,12,17,3)/
     x-2.2852388d-08,-1.5301973d-08,-2.4417659d-10 /
      data fpppp(28,12,18,1),fpppp(28,12,18,2),fpppp(28,12,18,3)/
     x-1.9216380d-09, 7.4572192d-09, 2.3846708d-10 /
      data fpppp(28,12,19,1),fpppp(28,12,19,2),fpppp(28,12,19,3)/
     x-2.0645058d-09,-6.7723452d-09,-8.7094468d-11 /
      data fpppp(28,12,20,1),fpppp(28,12,20,2),fpppp(28,12,20,3)/
     x-8.7968426d-09, 1.0677719d-09,-2.0137042d-11 /
      data fpppp(28,12,21,1),fpppp(28,12,21,2),fpppp(28,12,21,3)/
     x-8.7968426d-09, 2.1864438d-10,-3.7074147d-11 /
      data fpppp(28,12,22,1),fpppp(28,12,22,2),fpppp(28,12,22,3)/
     x-2.0645058d-09,-3.3758353d-09,-1.9346047d-11 /
      data fpppp(28,12,23,1),fpppp(28,12,23,2),fpppp(28,12,23,3)/
     x-1.9216380d-09,-5.2796931d-09,-1.5589494d-11 /
      data fpppp(28,13, 1,1),fpppp(28,13, 1,2),fpppp(28,13, 1,3)/
     x-4.1956452d-09, 1.2561446d-08,-1.3504641d-10 /
      data fpppp(28,13, 2,1),fpppp(28,13, 2,2),fpppp(28,13, 2,3)/
     x-6.3958598d-09, 1.1021481d-08,-7.8234589d-11 /
      data fpppp(28,13, 3,1),fpppp(28,13, 3,2),fpppp(28,13, 3,3)/
     x 2.2816353d-08, 8.3194798d-09, 3.7800862d-11 /
      data fpppp(28,13, 4,1),fpppp(28,13, 4,2),fpppp(28,13, 4,3)/
     x 2.2816353d-08, 7.2731145d-09, 4.7783164d-11 /
      data fpppp(28,13, 5,1),fpppp(28,13, 5,2),fpppp(28,13, 5,3)/
     x-6.3958598d-09, 1.5206942d-08,-1.1816379d-10 /
      data fpppp(28,13, 6,1),fpppp(28,13, 6,2),fpppp(28,13, 6,3)/
     x-4.1956452d-09,-3.1340339d-09, 1.4688111d-11 /
      data fpppp(28,13, 7,1),fpppp(28,13, 7,2),fpppp(28,13, 7,3)/
     x-2.6404160d-09,-5.1453459d-09,-6.2069181d-11 /
      data fpppp(28,13, 8,1),fpppp(28,13, 8,2),fpppp(28,13, 8,3)/
     x-4.6497551d-08, 4.0436231d-09, 2.0771367d-11 /
      data fpppp(28,13, 9,1),fpppp(28,13, 9,2),fpppp(28,13, 9,3)/
     x 1.0393771d-08,-8.3737260d-09, 2.1571771d-11 /
      data fpppp(28,13,10,1),fpppp(28,13,10,2),fpppp(28,13,10,3)/
     x-3.9138451d-08, 3.8074126d-09,-4.9246921d-11 /
      data fpppp(28,13,11,1),fpppp(28,13,11,2),fpppp(28,13,11,3)/
     x-1.7085736d-08,-1.7905619d-08, 1.0727131d-10 /
      data fpppp(28,13,12,1),fpppp(28,13,12,2),fpppp(28,13,12,3)/
     x 8.0576588d-09, 8.4162194d-10,-2.0432737d-11 /
      data fpppp(28,13,13,1),fpppp(28,13,13,2),fpppp(28,13,13,3)/
     x 1.2523856d-08, 7.2100458d-09, 6.8463670d-11 /
      data fpppp(28,13,14,1),fpppp(28,13,14,2),fpppp(28,13,14,3)/
     x-2.6969056d-08,-7.6403996d-09,-9.1231963d-11 /
      data fpppp(28,13,15,1),fpppp(28,13,15,2),fpppp(28,13,15,3)/
     x-3.0396693d-09,-1.2302962d-09, 3.9031617d-11 /
      data fpppp(28,13,16,1),fpppp(28,13,16,2),fpppp(28,13,16,3)/
     x-1.8547528d-09, 1.8405033d-09,-6.8230010d-11 /
      data fpppp(28,13,17,1),fpppp(28,13,17,2),fpppp(28,13,17,3)/
     x 1.6840577d-08, 2.7373275d-09, 2.0404245d-10 /
      data fpppp(28,13,18,1),fpppp(28,13,18,2),fpppp(28,13,18,3)/
     x 3.1205147d-09,-2.7148454d-09,-1.5442607d-10 /
      data fpppp(28,13,19,1),fpppp(28,13,19,2),fpppp(28,13,19,3)/
     x-1.1109179d-09,-3.9375508d-09, 4.8844531d-11 /
      data fpppp(28,13,20,1),fpppp(28,13,20,2),fpppp(28,13,20,3)/
     x 5.8138918d-09, 2.1333693d-09,-2.1980486d-11 /
      data fpppp(28,13,21,1),fpppp(28,13,21,2),fpppp(28,13,21,3)/
     x 5.8138918d-09, 1.9408471d-09,-1.0762656d-11 /
      data fpppp(28,13,22,1),fpppp(28,13,22,2),fpppp(28,13,22,3)/
     x-1.1109179d-09,-3.1674619d-09, 3.9732117d-12 /
      data fpppp(28,13,23,1),fpppp(28,13,23,2),fpppp(28,13,23,3)/
     x 3.1205147d-09,-5.6026787d-09, 1.3841371d-11 /
      data fpppp(28,14, 1,1),fpppp(28,14, 1,2),fpppp(28,14, 1,3)/
     x 1.1083295d-08, 2.9101868d-08, 4.2892990d-11 /
      data fpppp(28,14, 2,1),fpppp(28,14, 2,2),fpppp(28,14, 2,3)/
     x 1.3377899d-08, 1.9263391d-08, 1.9398715d-11 /
      data fpppp(28,14, 3,1),fpppp(28,14, 3,2),fpppp(28,14, 3,3)/
     x-5.8203214d-09,-2.9305047d-10,-2.6212073d-11 /
      data fpppp(28,14, 4,1),fpppp(28,14, 4,2),fpppp(28,14, 4,3)/
     x-5.8203214d-09,-2.9635671d-09,-3.4496728d-11 /
      data fpppp(28,14, 5,1),fpppp(28,14, 5,2),fpppp(28,14, 5,3)/
     x 1.3377899d-08, 2.9945457d-08, 5.2537333d-11 /
      data fpppp(28,14, 6,1),fpppp(28,14, 6,2),fpppp(28,14, 6,3)/
     x 1.1083295d-08,-1.0955882d-08,-8.1376828d-11 /
      data fpppp(28,14, 7,1),fpppp(28,14, 7,2),fpppp(28,14, 7,3)/
     x 2.5289402d-08, 5.5478314d-09, 3.3277863d-11 /
      data fpppp(28,14, 8,1),fpppp(28,14, 8,2),fpppp(28,14, 8,3)/
     x 3.0853442d-08, 1.4531235d-08,-3.0772490d-11 /
      data fpppp(28,14, 9,1),fpppp(28,14, 9,2),fpppp(28,14, 9,3)/
     x 4.9022269d-09,-5.3209297d-08,-3.1917643d-11 /
      data fpppp(28,14,10,1),fpppp(28,14,10,2),fpppp(28,14,10,3)/
     x 7.5594959d-08, 6.0822416d-08, 8.9436565d-11 /
      data fpppp(28,14,11,1),fpppp(28,14,11,2),fpppp(28,14,11,3)/
     x 1.3833459d-08,-2.7872615d-08,-1.7028955d-11 /
      data fpppp(28,14,12,1),fpppp(28,14,12,2),fpppp(28,14,12,3)/
     x-2.1694033d-08,-1.8023858d-08, 2.5381832d-11 /
      data fpppp(28,14,13,1),fpppp(28,14,13,2),fpppp(28,14,13,3)/
     x-1.2556004d-08, 5.7064177d-10,-6.9716329d-11 /
      data fpppp(28,14,14,1),fpppp(28,14,14,2),fpppp(28,14,14,3)/
     x 5.6250078d-08, 4.8994975d-09, 1.4118684d-10 /
      data fpppp(28,14,15,1),fpppp(28,14,15,2),fpppp(28,14,15,3)/
     x 6.8198599d-09,-4.4952691d-09,-7.3513183d-11 /
      data fpppp(28,14,16,1),fpppp(28,14,16,2),fpppp(28,14,16,3)/
     x 5.9744950d-09, 4.7863493d-09, 7.9770007d-11 /
      data fpppp(28,14,17,1),fpppp(28,14,17,2),fpppp(28,14,17,3)/
     x-9.5741331d-10,-5.3804404d-09,-1.2427577d-10 /
      data fpppp(28,14,18,1),fpppp(28,14,18,2),fpppp(28,14,18,3)/
     x 2.8971204d-09,-5.8514423d-10, 6.0536656d-11 /
      data fpppp(28,14,19,1),fpppp(28,14,19,2),fpppp(28,14,19,3)/
     x 1.4509763d-08, 4.8626122d-10,-1.1988552d-12 /
      data fpppp(28,14,20,1),fpppp(28,14,20,2),fpppp(28,14,20,3)/
     x 5.1988813d-09, 1.6531054d-09,-1.5796553d-12 /
      data fpppp(28,14,21,1),fpppp(28,14,21,2),fpppp(28,14,21,3)/
     x 5.1988813d-09, 1.6781154d-09,-4.5017030d-12 /
      data fpppp(28,14,22,1),fpppp(28,14,22,2),fpppp(28,14,22,3)/
     x 1.4509763d-08, 3.8622106d-10, 1.0489336d-11 /
      data fpppp(28,14,23,1),fpppp(28,14,23,2),fpppp(28,14,23,3)/
     x 2.8971204d-09,-2.0999363d-10, 1.6705941d-11 /
      data fpppp(28,15, 1,1),fpppp(28,15, 1,2),fpppp(28,15, 1,3)/
     x 1.8510222d-08, 2.2533727d-08, 1.9896031d-11 /
      data fpppp(28,15, 2,1),fpppp(28,15, 2,2),fpppp(28,15, 2,3)/
     x 2.3186118d-08, 1.4734902d-08, 7.7965690d-12 /
      data fpppp(28,15, 3,1),fpppp(28,15, 3,2),fpppp(28,15, 3,3)/
     x 1.5951931d-08,-1.1843784d-09,-1.8001507d-11 /
      data fpppp(28,15, 4,1),fpppp(28,15, 4,2),fpppp(28,15, 4,3)/
     x 1.5951931d-08,-2.5712296d-09,-1.8227857d-11 /
      data fpppp(28,15, 5,1),fpppp(28,15, 5,2),fpppp(28,15, 5,3)/
     x 2.3186118d-08, 2.0282308d-08, 8.7019716d-12 /
      data fpppp(28,15, 6,1),fpppp(28,15, 6,2),fpppp(28,15, 6,3)/
     x 1.8510222d-08, 1.7309581d-09, 1.6500771d-11 /
      data fpppp(28,15, 7,1),fpppp(28,15, 7,2),fpppp(28,15, 7,3)/
     x-7.1754938d-09, 2.9559597d-09,-7.4456065d-11 /
      data fpppp(28,15, 8,1),fpppp(28,15, 8,2),fpppp(28,15, 8,3)/
     x-1.1129893d-08,-5.9895670d-10, 5.0292197d-11 /
      data fpppp(28,15, 9,1),fpppp(28,15, 9,2),fpppp(28,15, 9,3)/
     x-8.6858450d-09,-1.2027259d-09,-4.2381828d-11 /
      data fpppp(28,15,10,1),fpppp(28,15,10,2),fpppp(28,15,10,3)/
     x-5.2379343d-08,-9.8986427d-09,-2.2550440d-11 /
      data fpppp(28,15,11,1),fpppp(28,15,11,2),fpppp(28,15,11,3)/
     x-4.3674262d-09, 9.7359170d-09, 4.5529533d-11 /
      data fpppp(28,15,12,1),fpppp(28,15,12,2),fpppp(28,15,12,3)/
     x 9.3724731d-09,-2.5700694d-08, 1.4216425d-11 /
      data fpppp(28,15,13,1),fpppp(28,15,13,2),fpppp(28,15,13,3)/
     x 5.8923426d-09, 4.2365988d-08, 1.0447256d-10 /
      data fpppp(28,15,14,1),fpppp(28,15,14,2),fpppp(28,15,14,3)/
     x-7.5391176d-08,-7.0578542d-08,-1.4511006d-10 /
      data fpppp(28,15,15,1),fpppp(28,15,15,2),fpppp(28,15,15,3)/
     x-1.9376551d-09, 4.1090892d-08, 1.2732892d-10 /
      data fpppp(28,15,16,1),fpppp(28,15,16,2),fpppp(28,15,16,3)/
     x-5.8214636d-09,-5.3967909d-09,-6.8486549d-11 /
      data fpppp(28,15,17,1),fpppp(28,15,17,2),fpppp(28,15,17,3)/
     x-1.6070314d-09,-8.5709162d-09, 5.1298952d-11 /
      data fpppp(28,15,18,1),fpppp(28,15,18,2),fpppp(28,15,18,3)/
     x 5.7016163d-09, 8.7889658d-09,-2.3037292d-11 /
      data fpppp(28,15,19,1),fpppp(28,15,19,2),fpppp(28,15,19,3)/
     x-6.9655015d-09,-8.4495529d-09,-6.1020460d-11 /
      data fpppp(28,15,20,1),fpppp(28,15,20,2),fpppp(28,15,20,3)/
     x 1.0345664d-08, 4.8073620d-09, 3.1501249d-11 /
      data fpppp(28,15,21,1),fpppp(28,15,21,2),fpppp(28,15,21,3)/
     x 1.0345664d-08, 3.6954120d-09, 2.7648719d-11 /
      data fpppp(28,15,22,1),fpppp(28,15,22,2),fpppp(28,15,22,3)/
     x-6.9655015d-09,-4.0017531d-09,-4.5610340d-11 /
      data fpppp(28,15,23,1),fpppp(28,15,23,2),fpppp(28,15,23,3)/
     x 5.7016163d-09,-7.8902834d-09,-8.0825242d-11 /
      data fpppp(28,16, 1,1),fpppp(28,16, 1,2),fpppp(28,16, 1,3)/
     x 2.6065934d-09,-3.6574166d-09,-6.6652439d-11 /
      data fpppp(28,16, 2,1),fpppp(28,16, 2,2),fpppp(28,16, 2,3)/
     x-6.0455604d-09,-8.9804182d-10,-4.2234342d-11 /
      data fpppp(28,16, 3,1),fpppp(28,16, 3,2),fpppp(28,16, 3,3)/
     x-2.7370694d-09, 4.7926101d-09, 8.9908295d-12 /
      data fpppp(28,16, 4,1),fpppp(28,16, 4,2),fpppp(28,16, 4,3)/
     x-2.7370694d-09, 5.1816246d-09, 1.0914646d-11 /
      data fpppp(28,16, 5,1),fpppp(28,16, 5,2),fpppp(28,16, 5,3)/
     x-6.0455604d-09,-2.4540998d-09,-4.9929606d-11 /
      data fpppp(28,16, 6,1),fpppp(28,16, 6,2),fpppp(28,16, 6,3)/
     x 2.6065934d-09, 2.1778009d-09,-3.7795199d-11 /
      data fpppp(28,16, 7,1),fpppp(28,16, 7,2),fpppp(28,16, 7,3)/
     x 2.8139418d-08, 1.1739439d-08, 7.9806550d-11 /
      data fpppp(28,16, 8,1),fpppp(28,16, 8,2),fpppp(28,16, 8,3)/
     x 2.0094337d-08,-4.2852620d-09,-9.8267973d-11 /
      data fpppp(28,16, 9,1),fpppp(28,16, 9,2),fpppp(28,16, 9,3)/
     x 2.8456363d-08, 4.1385872d-09, 9.7671492d-11 /
      data fpppp(28,16,10,1),fpppp(28,16,10,2),fpppp(28,16,10,3)/
     x 2.5708408d-08,-4.4187733d-09,-1.6269292d-11 /
      data fpppp(28,16,11,1),fpppp(28,16,11,2),fpppp(28,16,11,3)/
     x-2.2270015d-09,-1.6140352d-09, 6.8222247d-12 /
      data fpppp(28,16,12,1),fpppp(28,16,12,2),fpppp(28,16,12,3)/
     x-9.1325495d-09,-3.5687207d-09,-3.2858649d-11 /
      data fpppp(28,16,13,1),fpppp(28,16,13,2),fpppp(28,16,13,3)/
     x-1.5743217d-08,-1.0035130d-08, 2.3591463d-12 /
      data fpppp(28,16,14,1),fpppp(28,16,14,2),fpppp(28,16,14,3)/
     x 3.3372511d-08, 5.1013686d-09, 6.7732249d-11 /
      data fpppp(28,16,15,1),fpppp(28,16,15,2),fpppp(28,16,15,3)/
     x-5.5863357d-09,-1.1120995d-08,-2.0250949d-11 /
      data fpppp(28,16,16,1),fpppp(28,16,16,2),fpppp(28,16,16,3)/
     x 2.5295930d-09, 1.0764620d-08,-1.6508819d-11 /
      data fpppp(28,16,17,1),fpppp(28,16,17,2),fpppp(28,16,17,3)/
     x-2.4160134d-09,-6.0966642d-09,-1.3731543d-11 /
      data fpppp(28,16,18,1),fpppp(28,16,18,2),fpppp(28,16,18,3)/
     x-3.9773935d-09,-4.2928559d-09,-2.6456465d-11 /
      data fpppp(28,16,19,1),fpppp(28,16,19,2),fpppp(28,16,19,3)/
     x 8.9300002d-09, 9.0974529d-09, 5.0368099d-11 /
      data fpppp(28,16,20,1),fpppp(28,16,20,2),fpppp(28,16,20,3)/
     x-3.6849204d-09,-2.0464372d-09,-6.7059828d-12 /
      data fpppp(28,16,21,1),fpppp(28,16,21,2),fpppp(28,16,21,3)/
     x-3.6849204d-09,-1.1639630d-09,-1.7949479d-12 /
      data fpppp(28,16,22,1),fpppp(28,16,22,2),fpppp(28,16,22,3)/
     x 8.9300002d-09, 5.5675559d-09, 3.0723959d-11 /
      data fpppp(28,16,23,1),fpppp(28,16,23,2),fpppp(28,16,23,3)/
     x-3.9773935d-09, 8.9442579d-09, 4.7209059d-11 /
      data fpppp(28,17, 1,1),fpppp(28,17, 1,2),fpppp(28,17, 1,3)/
     x 5.3920663d-09,-1.5115304d-08, 4.3116323d-11 /
      data fpppp(28,17, 2,1),fpppp(28,17, 2,2),fpppp(28,17, 2,3)/
     x 4.2983596d-09,-7.5153910d-09, 2.8335605d-11 /
      data fpppp(28,17, 3,1),fpppp(28,17, 3,2),fpppp(28,17, 3,3)/
     x 1.4893805d-08, 7.5956111d-09,-3.1436353d-12 /
      data fpppp(28,17, 4,1),fpppp(28,17, 4,2),fpppp(28,17, 4,3)/
     x 1.4893805d-08, 9.6510326d-09,-3.4826560d-12 /
      data fpppp(28,17, 5,1),fpppp(28,17, 5,2),fpppp(28,17, 5,3)/
     x 4.2983596d-09,-1.5737077d-08, 2.9691688d-11 /
      data fpppp(28,17, 6,1),fpppp(28,17, 6,2),fpppp(28,17, 6,3)/
     x 5.3920663d-09, 1.5716018d-08, 3.8031012d-11 /
      data fpppp(28,17, 7,1),fpppp(28,17, 7,2),fpppp(28,17, 7,3)/
     x-9.2890716d-09,-1.0557991d-08,-5.6849315d-11 /
      data fpppp(28,17, 8,1),fpppp(28,17, 8,2),fpppp(28,17, 8,3)/
     x 1.8341069d-09, 1.6484707d-08, 4.7745433d-11 /
      data fpppp(28,17, 9,1),fpppp(28,17, 9,2),fpppp(28,17, 9,3)/
     x-1.4569821d-08,-1.2764514d-08,-7.6087918d-11 /
      data fpppp(28,17,10,1),fpppp(28,17,10,2),fpppp(28,17,10,3)/
     x-5.8922851d-09, 8.6469879d-11, 1.3796972d-11 /
      data fpppp(28,17,11,1),fpppp(28,17,11,2),fpppp(28,17,11,3)/
     x 3.6800104d-09, 5.0292889d-09,-4.9712119d-11 /
      data fpppp(28,17,12,1),fpppp(28,17,12,2),fpppp(28,17,12,3)/
     x 8.7857710d-09,-7.0543331d-09, 9.8623555d-11 /
      data fpppp(28,17,13,1),fpppp(28,17,13,2),fpppp(28,17,13,3)/
     x 4.7182885d-09,-3.1729370d-09,-6.2637001d-11 /
      data fpppp(28,17,14,1),fpppp(28,17,14,2),fpppp(28,17,14,3)/
     x-7.4663342d-09, 6.3306744d-09, 4.7687090d-11 /
      data fpppp(28,17,15,1),fpppp(28,17,15,2),fpppp(28,17,15,3)/
     x-8.3089063d-09,-1.1012986d-08,-7.1621372d-11 /
      data fpppp(28,17,16,1),fpppp(28,17,16,2),fpppp(28,17,16,3)/
     x-9.0015490d-09, 3.2087538d-09, 6.2200806d-11 /
      data fpppp(28,17,17,1),fpppp(28,17,17,2),fpppp(28,17,17,3)/
     x-2.2647756d-09, 2.2083152d-09,-4.1792451d-11 /
      data fpppp(28,17,18,1),fpppp(28,17,18,2),fpppp(28,17,18,3)/
     x-2.2531772d-09,-7.0743641d-09, 2.2862851d-11 /
      data fpppp(28,17,19,1),fpppp(28,17,19,2),fpppp(28,17,19,3)/
     x-1.2042026d-08, 7.7113603d-09,-3.1031065d-11 /
      data fpppp(28,17,20,1),fpppp(28,17,20,2),fpppp(28,17,20,3)/
     x-8.5856903d-09,-2.3339459d-09, 2.3639499d-11 /
      data fpppp(28,17,21,1),fpppp(28,17,21,2),fpppp(28,17,21,3)/
     x-8.5856903d-09,-1.4095693d-09, 1.9870187d-11 /
      data fpppp(28,17,22,1),fpppp(28,17,22,2),fpppp(28,17,22,3)/
     x-1.2042026d-08, 4.0138539d-09,-1.5953816d-11 /
      data fpppp(28,17,23,1),fpppp(28,17,23,2),fpppp(28,17,23,3)/
     x-2.2531772d-09, 6.7912851d-09,-3.3676833d-11 /
      data fpppp(28,18, 1,1),fpppp(28,18, 1,2),fpppp(28,18, 1,3)/
     x-1.4684233d-09,-6.8372372d-09,-3.2017628d-11 /
      data fpppp(28,18, 2,1),fpppp(28,18, 2,2),fpppp(28,18, 2,3)/
     x 8.9252335d-11,-3.2209852d-09,-8.6985300d-12 /
      data fpppp(28,18, 3,1),fpppp(28,18, 3,2),fpppp(28,18, 3,3)/
     x-2.1000044d-11, 4.0649635d-09, 4.0150288d-11 /
      data fpppp(28,18, 4,1),fpppp(28,18, 4,2),fpppp(28,18, 4,3)/
     x-2.1000044d-11, 4.8754983d-09, 4.2111475d-11 /
      data fpppp(28,18, 5,1),fpppp(28,18, 5,2),fpppp(28,18, 5,3)/
     x 8.9252335d-11,-6.4631246d-09,-1.6543276d-11 /
      data fpppp(28,18, 6,1),fpppp(28,18, 6,2),fpppp(28,18, 6,3)/
     x-1.4684233d-09, 5.3207856d-09,-2.5998317d-12 /
      data fpppp(28,18, 7,1),fpppp(28,18, 7,2),fpppp(28,18, 7,3)/
     x 1.1947373d-09,-1.6764247d-09, 8.3807678d-12 /
      data fpppp(28,18, 8,1),fpppp(28,18, 8,2),fpppp(28,18, 8,3)/
     x-1.8229169d-09, 4.3068802d-10,-7.6030065d-12 /
      data fpppp(28,18, 9,1),fpppp(28,18, 9,2),fpppp(28,18, 9,3)/
     x 5.1986149d-09, 2.7872054d-09, 5.4471161d-12 /
      data fpppp(28,18,10,1),fpppp(28,18,10,2),fpppp(28,18,10,3)/
     x 2.2675687d-09,-9.1402851d-09,-3.9097096d-11 /
      data fpppp(28,18,11,1),fpppp(28,18,11,2),fpppp(28,18,11,3)/
     x 2.8852738d-09, 1.6086119d-08, 3.3973311d-11 /
      data fpppp(28,18,12,1),fpppp(28,18,12,2),fpppp(28,18,12,3)/
     x-5.0657668d-09,-1.9866997d-08,-8.9245304d-11 /
      data fpppp(28,18,13,1),fpppp(28,18,13,2),fpppp(28,18,13,3)/
     x 6.4059887d-10, 1.3843268d-08, 3.6680733d-11 /
      data fpppp(28,18,14,1),fpppp(28,18,14,2),fpppp(28,18,14,3)/
     x-1.8099802d-09,-8.6281273d-09,-4.4838385d-11 /
      data fpppp(28,18,15,1),fpppp(28,18,15,2),fpppp(28,18,15,3)/
     x-1.8162909d-09, 3.4313359d-09, 2.3675667d-11 /
      data fpppp(28,18,16,1),fpppp(28,18,16,2),fpppp(28,18,16,3)/
     x-6.4481961d-09,-2.4553592d-09,-3.3693542d-11 /
      data fpppp(28,18,17,1),fpppp(28,18,17,2),fpppp(28,18,17,3)/
     x-1.1300329d-08, 5.0458709d-09, 2.9558674d-11 /
      data fpppp(28,18,18,1),fpppp(28,18,18,2),fpppp(28,18,18,3)/
     x-1.6008561d-08,-1.3250504d-08,-1.8225113d-11 /
      data fpppp(28,18,19,1),fpppp(28,18,19,2),fpppp(28,18,19,3)/
     x-9.5696445d-09, 1.1785353d-08, 3.8019522d-11 /
      data fpppp(28,18,20,1),fpppp(28,18,20,2),fpppp(28,18,20,3)/
     x-1.2721760d-08,-3.1997736d-09, 8.3247111d-12 /
      data fpppp(28,18,21,1),fpppp(28,18,21,2),fpppp(28,18,21,3)/
     x-1.2721760d-08,-1.6794137d-09, 1.1652348d-11 /
      data fpppp(28,18,22,1),fpppp(28,18,22,2),fpppp(28,18,22,3)/
     x-9.5696445d-09, 5.7039130d-09, 2.4708976d-11 /
      data fpppp(28,18,23,1),fpppp(28,18,23,2),fpppp(28,18,23,3)/
     x-1.6008561d-08, 9.5548948d-09, 3.1689438d-11 /
      data fpppp(28,19, 1,1),fpppp(28,19, 1,2),fpppp(28,19, 1,3)/
     x-5.5729236d-09,-6.1898683d-24,-5.4322233d-11 /
      data fpppp(28,19, 2,1),fpppp(28,19, 2,2),fpppp(28,19, 2,3)/
     x 3.8152871d-11,-7.0180854d-22,-1.4988642d-11 /
      data fpppp(28,19, 3,1),fpppp(28,19, 3,2),fpppp(28,19, 3,3)/
     x-5.6370396d-09,-2.1629008d-22, 6.7607529d-11 /
      data fpppp(28,19, 4,1),fpppp(28,19, 4,2),fpppp(28,19, 4,3)/
     x-5.6370396d-09,-2.9329886d-22, 7.0565196d-11 /
      data fpppp(28,19, 5,1),fpppp(28,19, 5,2),fpppp(28,19, 5,3)/
     x 3.8152871d-11, 6.9422766d-22,-2.6819309d-11 /
      data fpppp(28,19, 6,1),fpppp(28,19, 6,2),fpppp(28,19, 6,3)/
     x-5.5729236d-09,-7.8148076d-23,-9.9572313d-12 /
      data fpppp(28,19, 7,1),fpppp(28,19, 7,2),fpppp(28,19, 7,3)/
     x-2.0106819d-09, 2.5134902d-24, 1.5929151d-11 /
      data fpppp(28,19, 8,1),fpppp(28,19, 8,2),fpppp(28,19, 8,3)/
     x-9.6522853d-09,-1.2287467d-22,-5.4194901d-12 /
      data fpppp(28,19, 9,1),fpppp(28,19, 9,2),fpppp(28,19, 9,3)/
     x 7.0257309d-09,-2.7412928d-22, 1.4040880d-11 /
      data fpppp(28,19,10,1),fpppp(28,19,10,2),fpppp(28,19,10,3)/
     x-9.3273384d-10,-4.3121202d-23,-6.8288212d-11 /
      data fpppp(28,19,11,1),fpppp(28,19,11,2),fpppp(28,19,11,3)/
     x 4.0053225d-09, 1.0293773d-22, 7.7595948d-11 /
      data fpppp(28,19,12,1),fpppp(28,19,12,2),fpppp(28,19,12,3)/
     x-9.8402023d-09,-4.8153185d-22,-1.8587100d-10 /
      data fpppp(28,19,13,1),fpppp(28,19,13,2),fpppp(28,19,13,3)/
     x 3.5741080d-09,-2.9212897d-22, 8.9051644d-11 /
      data fpppp(28,19,14,1),fpppp(28,19,14,2),fpppp(28,19,14,3)/
     x-9.4379688d-09,-5.0720611d-22,-1.1665520d-10 /
      data fpppp(28,19,15,1),fpppp(28,19,15,2),fpppp(28,19,15,3)/
     x 2.0434143d-09,-1.8342659d-22, 7.7067717d-11 /
      data fpppp(28,19,16,1),fpppp(28,19,16,2),fpppp(28,19,16,3)/
     x-7.9189846d-09, 8.3495551d-22,-7.9701041d-11 /
      data fpppp(28,19,17,1),fpppp(28,19,17,2),fpppp(28,19,17,3)/
     x-1.7711085d-08, 2.9471375d-22, 7.2506361d-11 /
      data fpppp(28,19,18,1),fpppp(28,19,18,2),fpppp(28,19,18,3)/
     x-2.5341202d-08,-5.6321453d-22,-3.3482425d-11 /
      data fpppp(28,19,19,1),fpppp(28,19,19,2),fpppp(28,19,19,3)/
     x-1.3795665d-08, 6.8025502d-22, 6.4084467d-11 /
      data fpppp(28,19,20,1),fpppp(28,19,20,2),fpppp(28,19,20,3)/
     x-1.7076316d-08, 8.0382314d-23, 6.0557146d-12 /
      data fpppp(28,19,21,1),fpppp(28,19,21,2),fpppp(28,19,21,3)/
     x-1.7076316d-08,-5.3433834d-22, 1.1972501d-11 /
      data fpppp(28,19,22,1),fpppp(28,19,22,2),fpppp(28,19,22,3)/
     x-1.3795665d-08, 5.2919186d-23, 4.0417319d-11 /
      data fpppp(28,19,23,1),fpppp(28,19,23,2),fpppp(28,19,23,3)/
     x-2.5341202d-08, 3.2397232d-22, 5.5269377d-11 /
      data fpppp(29, 1, 1,1),fpppp(29, 1, 1,2),fpppp(29, 1, 1,3)/
     x-2.1103350d-08, 3.3114642d-22, 5.7142410d-11 /
      data fpppp(29, 1, 2,1),fpppp(29, 1, 2,2),fpppp(29, 1, 2,3)/
     x-6.2507935d-09,-6.5844102d-23, 5.0586538d-11 /
      data fpppp(29, 1, 3,1),fpppp(29, 1, 3,2),fpppp(29, 1, 3,3)/
     x-1.1738127d-09, 4.2571001d-24, 4.0257662d-11 /
      data fpppp(29, 1, 4,1),fpppp(29, 1, 4,2),fpppp(29, 1, 4,3)/
     x-1.1738127d-09,-1.5352951d-22, 3.3748676d-11 /
      data fpppp(29, 1, 5,1),fpppp(29, 1, 5,2),fpppp(29, 1, 5,3)/
     x-6.2507935d-09,-4.3491756d-23, 7.6622484d-11 /
      data fpppp(29, 1, 6,1),fpppp(29, 1, 6,2),fpppp(29, 1, 6,3)/
     x-2.1103350d-08,-2.2081724d-23,-4.0492387d-11 /
      data fpppp(29, 1, 7,1),fpppp(29, 1, 7,2),fpppp(29, 1, 7,3)/
     x-4.6031470d-08, 1.7123440d-22, 9.8262793d-11 /
      data fpppp(29, 1, 8,1),fpppp(29, 1, 8,2),fpppp(29, 1, 8,3)/
     x-8.2354614d-08, 6.0817276d-23,-9.0191876d-11 /
      data fpppp(29, 1, 9,1),fpppp(29, 1, 9,2),fpppp(29, 1, 9,3)/
     x-1.1867266d-07, 9.0051870d-23, 1.7659978d-11 /
      data fpppp(29, 1,10,1),fpppp(29, 1,10,2),fpppp(29, 1,10,3)/
     x-1.5039832d-07, 8.6495669d-23,-2.5711440d-11 /
      data fpppp(29, 1,11,1),fpppp(29, 1,11,2),fpppp(29, 1,11,3)/
     x-1.7134998d-07,-1.3197635d-22,-1.6404742d-10 /
      data fpppp(29, 1,12,1),fpppp(29, 1,12,2),fpppp(29, 1,12,3)/
     x-1.7988452d-07, 3.9828936d-23, 1.8290924d-10 /
      data fpppp(29, 1,13,1),fpppp(29, 1,13,2),fpppp(29, 1,13,3)/
     x-1.7253871d-07,-1.0904120d-22,-1.7333524d-10 /
      data fpppp(29, 1,14,1),fpppp(29, 1,14,2),fpppp(29, 1,14,3)/
     x-1.5042998d-07, 4.5958889d-23, 6.1574564d-12 /
      data fpppp(29, 1,15,1),fpppp(29, 1,15,2),fpppp(29, 1,15,3)/
     x-1.1562449d-07, 1.3154425d-22,-2.7525436d-11 /
      data fpppp(29, 1,16,1),fpppp(29, 1,16,2),fpppp(29, 1,16,3)/
     x-7.4758409d-08,-4.4917034d-23,-2.0214668d-11 /
      data fpppp(29, 1,17,1),fpppp(29, 1,17,2),fpppp(29, 1,17,3)/
     x-3.2391287d-08,-1.3551338d-22,-7.8877838d-11 /
      data fpppp(29, 1,18,1),fpppp(29, 1,18,2),fpppp(29, 1,18,3)/
     x-6.0592745d-11,-1.4099354d-22, 1.0128359d-10 /
      data fpppp(29, 1,19,1),fpppp(29, 1,19,2),fpppp(29, 1,19,3)/
     x 1.6423713d-08,-1.2223245d-22, 6.0070095d-11 /
      data fpppp(29, 1,20,1),fpppp(29, 1,20,2),fpppp(29, 1,20,3)/
     x 2.8703362d-08, 2.2244043d-23, 1.6646306d-11 /
      data fpppp(29, 1,21,1),fpppp(29, 1,21,2),fpppp(29, 1,21,3)/
     x 2.8703362d-08, 7.3086336d-23, 1.5651888d-11 /
      data fpppp(29, 1,22,1),fpppp(29, 1,22,2),fpppp(29, 1,22,3)/
     x 1.6423713d-08,-1.4934588d-22, 6.4047766d-11 /
      data fpppp(29, 1,23,1),fpppp(29, 1,23,2),fpppp(29, 1,23,3)/
     x-6.0592745d-11, 1.8216495d-22, 8.6367330d-11 /
      data fpppp(29, 2, 1,1),fpppp(29, 2, 1,2),fpppp(29, 2, 1,3)/
     x-1.1070235d-08, 4.0964389d-09, 1.5549700d-11 /
      data fpppp(29, 2, 2,1),fpppp(29, 2, 2,2),fpppp(29, 2, 2,3)/
     x-6.9713303d-09,-2.4890015d-10, 1.9157883d-11 /
      data fpppp(29, 2, 3,1),fpppp(29, 2, 3,2),fpppp(29, 2, 3,3)/
     x-6.9752687d-09,-9.3050518d-09, 2.8326316d-11 /
      data fpppp(29, 2, 4,1),fpppp(29, 2, 4,2),fpppp(29, 2, 4,3)/
     x-6.9752687d-09,-9.7518079d-09, 2.5812246d-11 /
      data fpppp(29, 2, 5,1),fpppp(29, 2, 5,2),fpppp(29, 2, 5,3)/
     x-6.9713303d-09, 1.5381244d-09, 2.9214166d-11 /
      data fpppp(29, 2, 6,1),fpppp(29, 2, 6,2),fpppp(29, 2, 6,3)/
     x-1.1070235d-08,-2.6049032d-09,-2.2161358d-11 /
      data fpppp(29, 2, 7,1),fpppp(29, 2, 7,2),fpppp(29, 2, 7,3)/
     x-1.8517150d-08,-7.9546489d-10, 3.3599811d-11 /
      data fpppp(29, 2, 8,1),fpppp(29, 2, 8,2),fpppp(29, 2, 8,3)/
     x-3.0001451d-08, 1.3287228d-09,-3.6971704d-11 /
      data fpppp(29, 2, 9,1),fpppp(29, 2, 9,2),fpppp(29, 2, 9,3)/
     x-4.1264789d-08, 2.6848426d-09, 3.9764676d-12 /
      data fpppp(29, 2,10,1),fpppp(29, 2,10,2),fpppp(29, 2,10,3)/
     x-5.1000184d-08, 3.9679177d-09,-8.4073619d-12 /
      data fpppp(29, 2,11,1),fpppp(29, 2,11,2),fpppp(29, 2,11,3)/
     x-5.7489155d-08, 5.4933519d-09,-7.1880612d-11 /
      data fpppp(29, 2,12,1),fpppp(29, 2,12,2),fpppp(29, 2,12,3)/
     x-6.0465822d-08, 6.0806628d-09, 9.3913579d-11 /
      data fpppp(29, 2,13,1),fpppp(29, 2,13,2),fpppp(29, 2,13,3)/
     x-5.8787118d-08, 5.5610102d-09,-7.2282327d-11 /
      data fpppp(29, 2,14,1),fpppp(29, 2,14,2),fpppp(29, 2,14,3)/
     x-5.2486034d-08, 4.3453545d-09, 3.7642402d-12 /
      data fpppp(29, 2,15,1),fpppp(29, 2,15,2),fpppp(29, 2,15,3)/
     x-4.2061211d-08, 2.9007284d-09,-1.0312936d-11 /
      data fpppp(29, 2,16,1),fpppp(29, 2,16,2),fpppp(29, 2,16,3)/
     x-2.9350038d-08, 1.2370520d-09,-1.4194585d-11 /
      data fpppp(29, 2,17,1),fpppp(29, 2,17,2),fpppp(29, 2,17,3)/
     x-1.5623210d-08,-7.3358146d-10,-3.8384827d-11 /
      data fpppp(29, 2,18,1),fpppp(29, 2,18,2),fpppp(29, 2,18,3)/
     x-5.3165485d-09,-6.7450405d-11, 3.6618747d-11 /
      data fpppp(29, 2,19,1),fpppp(29, 2,19,2),fpppp(29, 2,19,3)/
     x-1.3157668d-09,-3.3708108d-09, 1.9256569d-11 /
      data fpppp(29, 2,20,1),fpppp(29, 2,20,2),fpppp(29, 2,20,3)/
     x 1.7510996d-09,-8.7159758d-09, 9.9344151d-12 /
      data fpppp(29, 2,21,1),fpppp(29, 2,21,2),fpppp(29, 2,21,3)/
     x 1.7510996d-09,-8.7543753d-09, 9.3167645d-12 /
      data fpppp(29, 2,22,1),fpppp(29, 2,22,2),fpppp(29, 2,22,3)/
     x-1.3157668d-09,-3.2172127d-09, 2.1727172d-11 /
      data fpppp(29, 2,23,1),fpppp(29, 2,23,2),fpppp(29, 2,23,3)/
     x-5.3165485d-09,-6.4344335d-10, 2.7353988d-11 /
      data fpppp(29, 3, 1,1),fpppp(29, 3, 1,2),fpppp(29, 3, 1,3)/
     x-2.1075097d-08,-8.6068345d-10,-2.6752530d-11 /
      data fpppp(29, 3, 2,1),fpppp(29, 3, 2,2),fpppp(29, 3, 2,3)/
     x-3.0237450d-08,-6.0905417d-09,-1.2395431d-11 /
      data fpppp(29, 3, 3,1),fpppp(29, 3, 3,2),fpppp(29, 3, 3,3)/
     x-4.3082857d-08,-1.7055578d-08, 1.4557829d-11 /
      data fpppp(29, 3, 4,1),fpppp(29, 3, 4,2),fpppp(29, 3, 4,3)/
     x-4.3082857d-08,-1.7478733d-08, 2.1228749d-11 /
      data fpppp(29, 3, 5,1),fpppp(29, 3, 5,2),fpppp(29, 3, 5,3)/
     x-3.0237450d-08,-4.3979200d-09,-3.9079109d-11 /
      data fpppp(29, 3, 6,1),fpppp(29, 3, 6,2),fpppp(29, 3, 6,3)/
     x-2.1075097d-08,-7.2080146d-09, 7.3311263d-11 /
      data fpppp(29, 3, 7,1),fpppp(29, 3, 7,2),fpppp(29, 3, 7,3)/
     x-7.2699979d-09,-4.9487905d-09,-1.6375584d-10 /
      data fpppp(29, 3, 8,1),fpppp(29, 3, 8,2),fpppp(29, 3, 8,3)/
     x 1.9823247d-08, 3.8306752d-09, 1.8280473d-11 /
      data fpppp(29, 3, 9,1),fpppp(29, 3, 9,2),fpppp(29, 3, 9,3)/
     x 4.8240263d-08, 6.2473490d-09, 5.6720833d-11 /
      data fpppp(29, 3,10,1),fpppp(29, 3,10,2),fpppp(29, 3,10,3)/
     x 7.4101714d-08, 1.1400545d-08,-8.2007619d-11 /
      data fpppp(29, 3,11,1),fpppp(29, 3,11,2),fpppp(29, 3,11,3)/
     x 9.2879733d-08, 1.2926474d-08, 2.0667721d-10 /
      data fpppp(29, 3,12,1),fpppp(29, 3,12,2),fpppp(29, 3,12,3)/
     x 9.9919041d-08, 1.5665153d-08,-1.5764444d-10 /
      data fpppp(29, 3,13,1),fpppp(29, 3,13,2),fpppp(29, 3,13,3)/
     x 9.1465643d-08, 1.4176070d-08, 1.8368071d-10 /
      data fpppp(29, 3,14,1),fpppp(29, 3,14,2),fpppp(29, 3,14,3)/
     x 6.9319683d-08, 1.2530563d-08,-2.6998190d-11 /
      data fpppp(29, 3,15,1),fpppp(29, 3,15,2),fpppp(29, 3,15,3)/
     x 3.8336411d-08, 7.7424011d-09, 1.0696107d-11 /
      data fpppp(29, 3,16,1),fpppp(29, 3,16,2),fpppp(29, 3,16,3)/
     x 5.9325266d-09, 4.6558433d-09,-4.4898931d-11 /
      data fpppp(29, 3,17,1),fpppp(29, 3,17,2),fpppp(29, 3,17,3)/
     x-2.3154192d-08,-3.2542328d-09, 5.8065981d-11 /
      data fpppp(29, 3,18,1),fpppp(29, 3,18,2),fpppp(29, 3,18,3)/
     x-4.0794269d-08,-7.4388159d-09,-1.4846198d-10 /
      data fpppp(29, 3,19,1),fpppp(29, 3,19,2),fpppp(29, 3,19,3)/
     x-4.9380283d-08,-7.7547341d-09, 6.8380400d-14 /
      data fpppp(29, 3,20,1),fpppp(29, 3,20,2),fpppp(29, 3,20,3)/
     x-6.2731685d-08,-1.8781292d-08, 1.5660420d-11 /
      data fpppp(29, 3,21,1),fpppp(29, 3,21,2),fpppp(29, 3,21,3)/
     x-6.2731685d-08,-1.8552029d-08, 2.2365519d-11 /
      data fpppp(29, 3,22,1),fpppp(29, 3,22,2),fpppp(29, 3,22,3)/
     x-4.9380283d-08,-8.6717865d-09,-2.6752013d-11 /
      data fpppp(29, 3,23,1),fpppp(29, 3,23,2),fpppp(29, 3,23,3)/
     x-4.0794269d-08,-3.9998697d-09,-4.7885502d-11 /
      data fpppp(29, 4, 1,1),fpppp(29, 4, 1,2),fpppp(29, 4, 1,3)/
     x 3.9052963d-08,-1.0739956d-08,-6.6571439d-11 /
      data fpppp(29, 4, 2,1),fpppp(29, 4, 2,2),fpppp(29, 4, 2,3)/
     x 2.5405970d-08,-1.3191067d-08,-4.3512438d-11 /
      data fpppp(29, 4, 3,1),fpppp(29, 4, 3,2),fpppp(29, 4, 3,3)/
     x 2.6881018d-08,-1.8561436d-08, 7.2193372d-12 /
      data fpppp(29, 4, 4,1),fpppp(29, 4, 4,2),fpppp(29, 4, 4,3)/
     x 2.6881018d-08,-1.8354958d-08, 4.9099872d-12 /
      data fpppp(29, 4, 5,1),fpppp(29, 4, 5,2),fpppp(29, 4, 5,3)/
     x 2.5405970d-08,-1.4016979d-08,-3.4275037d-11 /
      data fpppp(29, 4, 6,1),fpppp(29, 4, 6,2),fpppp(29, 4, 6,3)/
     x 3.9052963d-08,-7.6427883d-09,-1.0121169d-10 /
      data fpppp(29, 4, 7,1),fpppp(29, 4, 7,2),fpppp(29, 4, 7,3)/
     x 6.0912239d-08, 1.3428032d-09, 1.0331285d-10 /
      data fpppp(29, 4, 8,1),fpppp(29, 4, 8,2),fpppp(29, 4, 8,3)/
     x 7.8497571d-08, 5.2258650d-09, 6.6420633d-11 /
      data fpppp(29, 4, 9,1),fpppp(29, 4, 9,2),fpppp(29, 4, 9,3)/
     x 9.5405201d-08, 8.6303368d-09,-1.2303237d-10 /
      data fpppp(29, 4,10,1),fpppp(29, 4,10,2),fpppp(29, 4,10,3)/
     x 1.0924046d-07, 1.2891312d-08, 1.6255730d-10 /
      data fpppp(29, 4,11,1),fpppp(29, 4,11,2),fpppp(29, 4,11,3)/
     x 1.1547039d-07, 1.2613931d-08,-1.6713352d-10 /
      data fpppp(29, 4,12,1),fpppp(29, 4,12,2),fpppp(29, 4,12,3)/
     x 1.1692234d-07, 1.3953631d-08, 1.5976578d-10 /
      data fpppp(29, 4,13,1),fpppp(29, 4,13,2),fpppp(29, 4,13,3)/
     x 1.1396432d-07, 1.3995424d-08,-1.0254169d-10 /
      data fpppp(29, 4,14,1),fpppp(29, 4,14,2),fpppp(29, 4,14,3)/
     x 1.0760922d-07, 1.3649648d-08, 4.1531629d-11 /
      data fpppp(29, 4,15,1),fpppp(29, 4,15,2),fpppp(29, 4,15,3)/
     x 9.4813821d-08, 1.1978480d-08, 1.8417253d-11 /
      data fpppp(29, 4,16,1),fpppp(29, 4,16,2),fpppp(29, 4,16,3)/
     x 7.6655414d-08, 8.8040195d-09, 5.2932225d-11 /
      data fpppp(29, 4,17,1),fpppp(29, 4,17,2),fpppp(29, 4,17,3)/
     x 5.4361535d-08, 2.0620167d-09,-4.1335500d-11 /
      data fpppp(29, 4,18,1),fpppp(29, 4,18,2),fpppp(29, 4,18,3)/
     x 2.9504187d-08,-7.0842427d-09, 8.7912865d-11 /
      data fpppp(29, 4,19,1),fpppp(29, 4,19,2),fpppp(29, 4,19,3)/
     x 8.6928280d-09,-1.6922951d-08,-9.4808487d-11 /
      data fpppp(29, 4,20,1),fpppp(29, 4,20,2),fpppp(29, 4,20,3)/
     x 4.1423557d-09,-2.1169952d-08,-2.2146210d-11 /
      data fpppp(29, 4,21,1),fpppp(29, 4,21,2),fpppp(29, 4,21,3)/
     x 4.1423557d-09,-2.1542900d-08,-3.2429299d-11 /
      data fpppp(29, 4,22,1),fpppp(29, 4,22,2),fpppp(29, 4,22,3)/
     x 8.6928280d-09,-1.5431158d-08,-5.3676130d-11 /
      data fpppp(29, 4,23,1),fpppp(29, 4,23,2),fpppp(29, 4,23,3)/
     x 2.9504187d-08,-1.2678465d-08,-6.6333475d-11 /
      data fpppp(29, 5, 1,1),fpppp(29, 5, 1,2),fpppp(29, 5, 1,3)/
     x 3.0841202d-08,-7.7301650d-09, 1.5867248d-11 /
      data fpppp(29, 5, 2,1),fpppp(29, 5, 2,2),fpppp(29, 5, 2,3)/
     x 7.2924212d-09,-1.0635653d-08,-9.2127376d-12 /
      data fpppp(29, 5, 3,1),fpppp(29, 5, 3,2),fpppp(29, 5, 3,3)/
     x-1.8533561d-08,-1.7052206d-08,-6.3632460d-11 /
      data fpppp(29, 5, 4,1),fpppp(29, 5, 4,2),fpppp(29, 5, 4,3)/
     x-1.8533561d-08,-1.6718820d-08,-6.2447891d-11 /
      data fpppp(29, 5, 5,1),fpppp(29, 5, 5,2),fpppp(29, 5, 5,3)/
     x 7.2924212d-09,-1.1969197d-08,-1.3951013d-11 /
      data fpppp(29, 5, 6,1),fpppp(29, 5, 6,2),fpppp(29, 5, 6,3)/
     x 3.0841202d-08,-2.7293744d-09, 3.3635779d-11 /
      data fpppp(29, 5, 7,1),fpppp(29, 5, 7,2),fpppp(29, 5, 7,3)/
     x 4.5531801d-08, 3.2084997d-09, 5.2233575d-11 /
      data fpppp(29, 5, 8,1),fpppp(29, 5, 8,2),fpppp(29, 5, 8,3)/
     x 5.1544243d-08, 6.4906693d-09,-1.1297989d-10 /
      data fpppp(29, 5, 9,1),fpppp(29, 5, 9,2),fpppp(29, 5, 9,3)/
     x 5.0206762d-08, 7.2238062d-09, 1.6974702d-10 /
      data fpppp(29, 5,10,1),fpppp(29, 5,10,2),fpppp(29, 5,10,3)/
     x 4.1193503d-08, 7.1496908d-09,-3.6558225d-11 /
      data fpppp(29, 5,11,1),fpppp(29, 5,11,2),fpppp(29, 5,11,3)/
     x 3.3232564d-08, 8.5680804d-09, 4.0865071d-11 /
      data fpppp(29, 5,12,1),fpppp(29, 5,12,2),fpppp(29, 5,12,3)/
     x 2.9782217d-08, 8.0676409d-09,-4.9114908d-11 /
      data fpppp(29, 5,13,1),fpppp(29, 5,13,2),fpppp(29, 5,13,3)/
     x 3.5544438d-08, 1.0325974d-08,-1.7372333d-12 /
      data fpppp(29, 5,14,1),fpppp(29, 5,14,2),fpppp(29, 5,14,3)/
     x 4.4362685d-08, 8.6735420d-09,-1.8538985d-11 /
      data fpppp(29, 5,15,1),fpppp(29, 5,15,2),fpppp(29, 5,15,3)/
     x 5.4844422d-08, 1.1149137d-08, 2.1500789d-11 /
      data fpppp(29, 5,16,1),fpppp(29, 5,16,2),fpppp(29, 5,16,3)/
     x 5.8629234d-08, 9.7394965d-09, 9.1170574d-12 /
      data fpppp(29, 5,17,1),fpppp(29, 5,17,2),fpppp(29, 5,17,3)/
     x 5.5895304d-08, 5.5510169d-09, 1.7622009d-11 /
      data fpppp(29, 5,18,1),fpppp(29, 5,18,2),fpppp(29, 5,18,3)/
     x 4.3561257d-08,-4.6153222d-09,-2.0520463d-11 /
      data fpppp(29, 5,19,1),fpppp(29, 5,19,2),fpppp(29, 5,19,3)/
     x 2.5201949d-08,-1.3508549d-08, 9.8143500d-11 /
      data fpppp(29, 5,20,1),fpppp(29, 5,20,2),fpppp(29, 5,20,3)/
     x 3.8790577d-09,-1.8688858d-08,-6.5656322d-11 /
      data fpppp(29, 5,21,1),fpppp(29, 5,21,2),fpppp(29, 5,21,3)/
     x 3.8790577d-09,-1.8996251d-08,-5.6395062d-11 /
      data fpppp(29, 5,22,1),fpppp(29, 5,22,2),fpppp(29, 5,22,3)/
     x 2.5201949d-08,-1.2278976d-08, 6.1098459d-11 /
      data fpppp(29, 5,23,1),fpppp(29, 5,23,2),fpppp(29, 5,23,3)/
     x 4.3561257d-08,-9.2262194d-09, 1.1839844d-10 /
      data fpppp(29, 6, 1,1),fpppp(29, 6, 1,2),fpppp(29, 6, 1,3)/
     x 5.8982980d-09,-9.4054756d-09, 9.5999869d-11 /
      data fpppp(29, 6, 2,1),fpppp(29, 6, 2,2),fpppp(29, 6, 2,3)/
     x 1.2842244d-08,-7.6252774d-09, 4.4568546d-11 /
      data fpppp(29, 6, 3,1),fpppp(29, 6, 3,2),fpppp(29, 6, 3,3)/
     x 2.2392360d-08,-4.0583185d-09,-6.2407548d-11 /
      data fpppp(29, 6, 4,1),fpppp(29, 6, 4,2),fpppp(29, 6, 4,3)/
     x 2.2392360d-08,-3.6247533d-09,-6.8066845d-11 /
      data fpppp(29, 6, 5,1),fpppp(29, 6, 5,2),fpppp(29, 6, 5,3)/
     x 1.2842244d-08,-9.3595384d-09, 6.7205731d-11 /
      data fpppp(29, 6, 6,1),fpppp(29, 6, 6,2),fpppp(29, 6, 6,3)/
     x 5.8982980d-09,-2.9019969d-09, 1.1110423d-11 /
      data fpppp(29, 6, 7,1),fpppp(29, 6, 7,2),fpppp(29, 6, 7,3)/
     x-5.7880242d-10,-1.8971319d-09,-1.0714120d-10 /
      data fpppp(29, 6, 8,1),fpppp(29, 6, 8,2),fpppp(29, 6, 8,3)/
     x-5.8695607d-09, 2.9265922d-09, 2.4063323d-10 /
      data fpppp(29, 6, 9,1),fpppp(29, 6, 9,2),fpppp(29, 6, 9,3)/
     x-1.3100216d-08, 8.6838182d-11,-1.8159896d-10 /
      data fpppp(29, 6,10,1),fpppp(29, 6,10,2),fpppp(29, 6,10,3)/
     x-1.3196020d-08, 2.5180616d-09, 7.1114224d-11 /
      data fpppp(29, 6,11,1),fpppp(29, 6,11,2),fpppp(29, 6,11,3)/
     x-9.6955685d-09, 6.0129176d-09,-4.3801803d-13 /
      data fpppp(29, 6,12,1),fpppp(29, 6,12,2),fpppp(29, 6,12,3)/
     x-5.9457156d-09, 8.6226874d-09,-3.4299764d-11 /
      data fpppp(29, 6,13,1),fpppp(29, 6,13,2),fpppp(29, 6,13,3)/
     x-7.0703671d-09, 6.9674940d-09, 3.7576342d-11 /
      data fpppp(29, 6,14,1),fpppp(29, 6,14,2),fpppp(29, 6,14,3)/
     x-7.4654374d-09, 5.5691138d-09, 3.1275043d-11 /
      data fpppp(29, 6,15,1),fpppp(29, 6,15,2),fpppp(29, 6,15,3)/
     x-6.4196381d-09, 4.1766472d-09,-2.7109065d-11 /
      data fpppp(29, 6,16,1),fpppp(29, 6,16,2),fpppp(29, 6,16,3)/
     x 7.3930905d-11, 6.6729392d-09,-3.7296562d-11 /
      data fpppp(29, 6,17,1),fpppp(29, 6,17,2),fpppp(29, 6,17,3)/
     x 6.5360156d-09, 9.4937309d-10, 4.5120552d-11 /
      data fpppp(29, 6,18,1),fpppp(29, 6,18,2),fpppp(29, 6,18,3)/
     x 1.4918549d-08,-4.8252775d-09, 4.9727421d-12 /
      data fpppp(29, 6,19,1),fpppp(29, 6,19,2),fpppp(29, 6,19,3)/
     x 2.4141410d-08,-1.0502729d-08,-5.5253626d-11 /
      data fpppp(29, 6,20,1),fpppp(29, 6,20,2),fpppp(29, 6,20,3)/
     x 3.4643746d-08,-6.2085319d-09, 2.3920199d-11 /
      data fpppp(29, 6,21,1),fpppp(29, 6,21,2),fpppp(29, 6,21,3)/
     x 3.4643746d-08,-6.5731558d-09, 1.9307502d-11 /
      data fpppp(29, 6,22,1),fpppp(29, 6,22,2),fpppp(29, 6,22,3)/
     x 2.4141410d-08,-9.0442333d-09,-3.6802837d-11 /
      data fpppp(29, 6,23,1),fpppp(29, 6,23,2),fpppp(29, 6,23,3)/
     x 1.4918549d-08,-1.0294636d-08,-6.4217715d-11 /
      data fpppp(29, 7, 1,1),fpppp(29, 7, 1,2),fpppp(29, 7, 1,3)/
     x-7.9003062d-09,-7.3110101d-09,-2.9194730d-11 /
      data fpppp(29, 7, 2,1),fpppp(29, 7, 2,2),fpppp(29, 7, 2,3)/
     x 9.3999594d-09,-3.2257123d-09,-1.0405434d-11 /
      data fpppp(29, 7, 3,1),fpppp(29, 7, 3,2),fpppp(29, 7, 3,3)/
     x 2.4379143d-08, 5.4354326d-09, 2.7966612d-11 /
      data fpppp(29, 7, 4,1),fpppp(29, 7, 4,2),fpppp(29, 7, 4,3)/
     x 2.4379143d-08, 5.5982961d-09, 3.1275389d-11 /
      data fpppp(29, 7, 5,1),fpppp(29, 7, 5,2),fpppp(29, 7, 5,3)/
     x 9.3999594d-09,-3.8771664d-09,-2.3640541d-11 /
      data fpppp(29, 7, 6,1),fpppp(29, 7, 6,2),fpppp(29, 7, 6,3)/
     x-7.9003062d-09,-4.8680572d-09, 2.0436919d-11 /
      data fpppp(29, 7, 7,1),fpppp(29, 7, 7,2),fpppp(29, 7, 7,3)/
     x-2.1065342d-08,-5.5572946d-09, 1.1104227d-10 /
      data fpppp(29, 7, 8,1),fpppp(29, 7, 8,2),fpppp(29, 7, 8,3)/
     x-2.9640671d-08,-3.9690055d-09,-2.4691168d-10 /
      data fpppp(29, 7, 9,1),fpppp(29, 7, 9,2),fpppp(29, 7, 9,3)/
     x-2.9174281d-08,-1.2373067d-09, 2.1137230d-10 /
      data fpppp(29, 7,10,1),fpppp(29, 7,10,2),fpppp(29, 7,10,3)/
     x-2.7319629d-08, 2.1854512d-10,-1.8943400d-10 /
      data fpppp(29, 7,11,1),fpppp(29, 7,11,2),fpppp(29, 7,11,3)/
     x-2.4345084d-08, 4.8737182d-09, 7.2304817d-11 /
      data fpppp(29, 7,12,1),fpppp(29, 7,12,2),fpppp(29, 7,12,3)/
     x-2.2668897d-08, 5.3916075d-09, 4.2178028d-11 /
      data fpppp(29, 7,13,1),fpppp(29, 7,13,2),fpppp(29, 7,13,3)/
     x-2.2768251d-08, 5.2765651d-09,-4.3442213d-11 /
      data fpppp(29, 7,14,1),fpppp(29, 7,14,2),fpppp(29, 7,14,3)/
     x-2.5219450d-08, 3.2031151d-09,-2.2928941d-11 /
      data fpppp(29, 7,15,1),fpppp(29, 7,15,2),fpppp(29, 7,15,3)/
     x-2.6057056d-08, 1.6234499d-09, 7.2805581d-12 /
      data fpppp(29, 7,16,1),fpppp(29, 7,16,2),fpppp(29, 7,16,3)/
     x-2.5057728d-08, 2.1218729d-09, 1.5056598d-11 /
      data fpppp(29, 7,17,1),fpppp(29, 7,17,2),fpppp(29, 7,17,3)/
     x-1.7721991d-08,-2.4417966d-09, 2.1601075d-11 /
      data fpppp(29, 7,18,1),fpppp(29, 7,18,2),fpppp(29, 7,18,3)/
     x-5.7674924d-09,-5.6921807d-09,-3.3179074d-11 /
      data fpppp(29, 7,19,1),fpppp(29, 7,19,2),fpppp(29, 7,19,3)/
     x 8.7831597d-09,-6.1473912d-09, 3.8399984d-11 /
      data fpppp(29, 7,20,1),fpppp(29, 7,20,2),fpppp(29, 7,20,3)/
     x 2.1518535d-08, 1.8697128d-09,-1.8331830d-11 /
      data fpppp(29, 7,21,1),fpppp(29, 7,21,2),fpppp(29, 7,21,3)/
     x 2.1518535d-08, 1.6705107d-09,-1.3677372d-11 /
      data fpppp(29, 7,22,1),fpppp(29, 7,22,2),fpppp(29, 7,22,3)/
     x 8.7831597d-09,-5.3505825d-09, 1.9782154d-11 /
      data fpppp(29, 7,23,1),fpppp(29, 7,23,2),fpppp(29, 7,23,3)/
     x-5.7674924d-09,-8.6802132d-09, 3.6637788d-11 /
      data fpppp(29, 8, 1,1),fpppp(29, 8, 1,2),fpppp(29, 8, 1,3)/
     x-1.6739786d-08,-2.9110617d-09,-3.5199161d-11 /
      data fpppp(29, 8, 2,1),fpppp(29, 8, 2,2),fpppp(29, 8, 2,3)/
     x-1.6251066d-08, 1.4506040d-10,-1.0990388d-11 /
      data fpppp(29, 8, 3,1),fpppp(29, 8, 3,2),fpppp(29, 8, 3,3)/
     x-1.9109768d-08, 6.7132912d-09, 3.8693626d-11 /
      data fpppp(29, 8, 4,1),fpppp(29, 8, 4,2),fpppp(29, 8, 4,3)/
     x-1.9109768d-08, 6.6793450d-09, 4.2529502d-11 /
      data fpppp(29, 8, 5,1),fpppp(29, 8, 5,2),fpppp(29, 8, 5,3)/
     x-1.6251066d-08, 2.8084525d-10,-2.6333893d-11 /
      data fpppp(29, 8, 6,1),fpppp(29, 8, 6,2),fpppp(29, 8, 6,3)/
     x-1.6739786d-08,-3.4202549d-09, 2.2338983d-11 /
      data fpppp(29, 8, 7,1),fpppp(29, 8, 7,2),fpppp(29, 8, 7,3)/
     x-1.9169932d-08,-6.4822077d-09,-2.4125902d-11 /
      data fpppp(29, 8, 8,1),fpppp(29, 8, 8,2),fpppp(29, 8, 8,3)/
     x-1.9496531d-08,-3.5707502d-09, 1.0020845d-10 /
      data fpppp(29, 8, 9,1),fpppp(29, 8, 9,2),fpppp(29, 8, 9,3)/
     x-2.1353969d-08,-1.7759712d-09,-1.8957204d-10 /
      data fpppp(29, 8,10,1),fpppp(29, 8,10,2),fpppp(29, 8,10,3)/
     x-2.3650865d-08,-2.6830869d-10, 1.5615399d-10 /
      data fpppp(29, 8,11,1),fpppp(29, 8,11,2),fpppp(29, 8,11,3)/
     x-2.7068906d-08, 2.6530729d-09,-8.1228328d-11 /
      data fpppp(29, 8,12,1),fpppp(29, 8,12,2),fpppp(29, 8,12,3)/
     x-2.9352353d-08, 8.6421544d-10,-7.4156248d-11 /
      data fpppp(29, 8,13,1),fpppp(29, 8,13,2),fpppp(29, 8,13,3)/
     x-2.7534458d-08, 1.9770020d-09, 4.7615186d-11 /
      data fpppp(29, 8,14,1),fpppp(29, 8,14,2),fpppp(29, 8,14,3)/
     x-2.3190549d-08, 2.4161819d-09,-5.5060800d-12 /
      data fpppp(29, 8,15,1),fpppp(29, 8,15,2),fpppp(29, 8,15,3)/
     x-2.0173748d-08, 9.3075834d-10,-9.6486455d-12 /
      data fpppp(29, 8,16,1),fpppp(29, 8,16,2),fpppp(29, 8,16,3)/
     x-1.6510444d-08, 1.9917266d-09, 7.3558882d-11 /
      data fpppp(29, 8,17,1),fpppp(29, 8,17,2),fpppp(29, 8,17,3)/
     x-1.5071120d-08,-2.2869779d-09,-1.4984422d-10 /
      data fpppp(29, 8,18,1),fpppp(29, 8,18,2),fpppp(29, 8,18,3)/
     x-1.3288044d-08,-4.4247142d-09, 1.0453231d-10 /
      data fpppp(29, 8,19,1),fpppp(29, 8,19,2),fpppp(29, 8,19,3)/
     x-1.1223542d-08,-2.3691522d-09, 1.2818025d-11 /
      data fpppp(29, 8,20,1),fpppp(29, 8,20,2),fpppp(29, 8,20,3)/
     x-1.0995270d-08, 2.3041228d-09,-1.2038981d-11 /
      data fpppp(29, 8,21,1),fpppp(29, 8,21,2),fpppp(29, 8,21,3)/
     x-1.0995270d-08, 2.2981751d-09,-1.5841878d-11 /
      data fpppp(29, 8,22,1),fpppp(29, 8,22,2),fpppp(29, 8,22,3)/
     x-1.1223542d-08,-2.3453611d-09, 2.8029611d-11 /
      data fpppp(29, 8,23,1),fpppp(29, 8,23,2),fpppp(29, 8,23,3)/
     x-1.3288044d-08,-4.5139307d-09, 4.7488866d-11 /
      data fpppp(29, 9, 1,1),fpppp(29, 9, 1,2),fpppp(29, 9, 1,3)/
     x-1.4576838d-08,-2.2140386d-09, 5.8273210d-11 /
      data fpppp(29, 9, 2,1),fpppp(29, 9, 2,2),fpppp(29, 9, 2,3)/
     x-1.6801942d-08, 9.9125057d-10, 3.7803317d-11 /
      data fpppp(29, 9, 3,1),fpppp(29, 9, 3,2),fpppp(29, 9, 3,3)/
     x-1.7245850d-08, 7.8628345d-09,-4.7682744d-12 /
      data fpppp(29, 9, 4,1),fpppp(29, 9, 4,2),fpppp(29, 9, 4,3)/
     x-1.7245850d-08, 7.8573971d-09,-7.0300897d-12 /
      data fpppp(29, 9, 5,1),fpppp(29, 9, 5,2),fpppp(29, 9, 5,3)/
     x-1.6801942d-08, 1.0130001d-09, 4.6850578d-11 /
      data fpppp(29, 9, 6,1),fpppp(29, 9, 6,2),fpppp(29, 9, 6,3)/
     x-1.4576838d-08,-2.2955993d-09, 2.4345980d-11 /
      data fpppp(29, 9, 7,1),fpppp(29, 9, 7,2),fpppp(29, 9, 7,3)/
     x-1.0705820d-08,-4.6732417d-09,-1.0896846d-10 /
      data fpppp(29, 9, 8,1),fpppp(29, 9, 8,2),fpppp(29, 9, 8,3)/
     x-1.0179720d-08,-4.1258868d-09, 8.9658233d-11 /
      data fpppp(29, 9, 9,1),fpppp(29, 9, 9,2),fpppp(29, 9, 9,3)/
     x-1.3264593d-08,-1.9275562d-09, 2.7024249d-11 /
      data fpppp(29, 9,10,1),fpppp(29, 9,10,2),fpppp(29, 9,10,3)/
     x-1.6580732d-08,-1.9509272d-09,-3.9195926d-11 /
      data fpppp(29, 9,11,1),fpppp(29, 9,11,2),fpppp(29, 9,11,3)/
     x-2.0110986d-08, 1.2496096d-09,-9.1444042d-11 /
      data fpppp(29, 9,12,1),fpppp(29, 9,12,2),fpppp(29, 9,12,3)/
     x-2.1500542d-08,-3.5542502d-10, 1.5467108d-10 /
      data fpppp(29, 9,13,1),fpppp(29, 9,13,2),fpppp(29, 9,13,3)/
     x-2.1433021d-08, 7.1615102d-10,-1.2386246d-10 /
      data fpppp(29, 9,14,1),fpppp(29, 9,14,2),fpppp(29, 9,14,3)/
     x-1.8894597d-08, 3.8976359d-10, 5.2104871d-11 /
      data fpppp(29, 9,15,1),fpppp(29, 9,15,2),fpppp(29, 9,15,3)/
     x-1.4364392d-08, 1.4542376d-09,-2.0448485d-11 /
      data fpppp(29, 9,16,1),fpppp(29, 9,16,2),fpppp(29, 9,16,3)/
     x-1.1585463d-08, 9.0805165d-10,-1.0939370d-10 /
      data fpppp(29, 9,17,1),fpppp(29, 9,17,2),fpppp(29, 9,17,3)/
     x-7.9853909d-09,-1.2725838d-09, 1.8994460d-10 /
      data fpppp(29, 9,18,1),fpppp(29, 9,18,2),fpppp(29, 9,18,3)/
     x-7.2552023d-09,-2.5181361d-09,-1.1352381d-10 /
      data fpppp(29, 9,19,1),fpppp(29, 9,19,2),fpppp(29, 9,19,3)/
     x-9.3579990d-09,-1.1180614d-09,-6.7546329d-11 /
      data fpppp(29, 9,20,1),fpppp(29, 9,20,2),fpppp(29, 9,20,3)/
     x-1.2696497d-08, 1.8121195d-09, 6.6558367d-11 /
      data fpppp(29, 9,21,1),fpppp(29, 9,21,2),fpppp(29, 9,21,3)/
     x-1.2696497d-08, 1.8136697d-09, 6.5770169d-11 /
      data fpppp(29, 9,22,1),fpppp(29, 9,22,2),fpppp(29, 9,22,3)/
     x-9.3579990d-09,-1.1242621d-09,-6.4393535d-11 /
      data fpppp(29, 9,23,1),fpppp(29, 9,23,2),fpppp(29, 9,23,3)/
     x-7.2552023d-09,-2.4948836d-09,-1.2534678d-10 /
      data fpppp(29,10, 1,1),fpppp(29,10, 1,2),fpppp(29,10, 1,3)/
     x-8.3408118d-09,-4.4094067d-10,-2.1946642d-11 /
      data fpppp(29,10, 2,1),fpppp(29,10, 2,2),fpppp(29,10, 2,3)/
     x-7.2286360d-09, 2.6471049d-09,-1.2116952d-11 /
      data fpppp(29,10, 3,1),fpppp(29,10, 3,2),fpppp(29,10, 3,3)/
     x-5.3355734d-09, 9.2559024d-09, 1.2008729d-11 /
      data fpppp(29,10, 4,1),fpppp(29,10, 4,2),fpppp(29,10, 4,3)/
     x-5.3355734d-09, 9.2706776d-09, 6.6501212d-12 /
      data fpppp(29,10, 5,1),fpppp(29,10, 5,2),fpppp(29,10, 5,3)/
     x-7.2286360d-09, 2.5880042d-09, 9.3174788d-12 /
      data fpppp(29,10, 6,1),fpppp(29,10, 6,2),fpppp(29,10, 6,3)/
     x-8.3408118d-09,-2.1931316d-10,-1.0232576d-10 /
      data fpppp(29,10, 7,1),fpppp(29,10, 7,2),fpppp(29,10, 7,3)/
     x-1.1827842d-08,-5.2462787d-09, 2.2002526d-10 /
      data fpppp(29,10, 8,1),fpppp(29,10, 8,2),fpppp(29,10, 8,3)/
     x-1.4024274d-08,-6.0901669d-09,-2.3634059d-10 /
      data fpppp(29,10, 9,1),fpppp(29,10, 9,2),fpppp(29,10, 9,3)/
     x-9.6118902d-09,-3.4264775d-09, 1.5144637d-10 /
      data fpppp(29,10,10,1),fpppp(29,10,10,2),fpppp(29,10,10,3)/
     x-1.0252914d-08,-3.2529900d-09,-1.4175639d-10 /
      data fpppp(29,10,11,1),fpppp(29,10,11,2),fpppp(29,10,11,3)/
     x-7.5783054d-09, 1.0092914d-09, 2.2657759d-10 /
      data fpppp(29,10,12,1),fpppp(29,10,12,2),fpppp(29,10,12,3)/
     x-8.0935937d-09,-1.0071498d-10,-2.4043434d-10 /
      data fpppp(29,10,13,1),fpppp(29,10,13,2),fpppp(29,10,13,3)/
     x-9.0460405d-09, 1.8872458d-09, 1.7188661d-10 /
      data fpppp(29,10,14,1),fpppp(29,10,14,2),fpppp(29,10,14,3)/
     x-9.4823544d-09, 8.6970224d-11,-1.2321493d-10 /
      data fpppp(29,10,15,1),fpppp(29,10,15,2),fpppp(29,10,15,3)/
     x-8.9772942d-09, 2.3266101d-10, 4.8596757d-11 /
      data fpppp(29,10,16,1),fpppp(29,10,16,2),fpppp(29,10,16,3)/
     x-6.7055851d-09, 4.8902141d-10, 9.5700765d-11 /
      data fpppp(29,10,17,1),fpppp(29,10,17,2),fpppp(29,10,17,3)/
     x-6.4031160d-09,-2.0803577d-09,-2.1382773d-10 /
      data fpppp(29,10,18,1),fpppp(29,10,18,2),fpppp(29,10,18,3)/
     x-3.6652633d-09,-2.6879310d-09, 1.1345232d-10 /
      data fpppp(29,10,19,1),fpppp(29,10,19,2),fpppp(29,10,19,3)/
     x-1.9581481d-09,-1.8205637d-09, 8.5703237d-11 /
      data fpppp(29,10,20,1),fpppp(29,10,20,2),fpppp(29,10,20,3)/
     x-1.5137754d-09, 3.1690850d-09,-5.1427684d-11 /
      data fpppp(29,10,21,1),fpppp(29,10,21,2),fpppp(29,10,21,3)/
     x-1.5137754d-09, 3.0997273d-09,-4.9707177d-11 /
      data fpppp(29,10,22,1),fpppp(29,10,22,2),fpppp(29,10,22,3)/
     x-1.9581481d-09,-1.5431329d-09, 7.8821210d-11 /
      data fpppp(29,10,23,1),fpppp(29,10,23,2),fpppp(29,10,23,3)/
     x-3.6652633d-09,-3.7282964d-09, 1.3925993d-10 /
      data fpppp(29,11, 1,1),fpppp(29,11, 1,2),fpppp(29,11, 1,3)/
     x-9.2425576d-10, 2.7815386d-09, 3.0133589d-11 /
      data fpppp(29,11, 2,1),fpppp(29,11, 2,2),fpppp(29,11, 2,3)/
     x 3.3357661d-09, 4.8792904d-09, 9.4240272d-12 /
      data fpppp(29,11, 3,1),fpppp(29,11, 3,2),fpppp(29,11, 3,3)/
     x 5.3032145d-09, 9.5064356d-09,-3.8925012d-11 /
      data fpppp(29,11, 4,1),fpppp(29,11, 4,2),fpppp(29,11, 4,3)/
     x 5.3032145d-09, 9.2755007d-09,-3.1975051d-11 /
      data fpppp(29,11, 5,1),fpppp(29,11, 5,2),fpppp(29,11, 5,3)/
     x 3.3357661d-09, 5.8030298d-09,-1.8375816d-11 /
      data fpppp(29,11, 6,1),fpppp(29,11, 6,2),fpppp(29,11, 6,3)/
     x-9.2425576d-10,-6.8248438d-10, 1.3438300d-10 /
      data fpppp(29,11, 7,1),fpppp(29,11, 7,2),fpppp(29,11, 7,3)/
     x-3.7947756d-09,-3.7655088d-09,-1.9458107d-10 /
      data fpppp(29,11, 8,1),fpppp(29,11, 8,2),fpppp(29,11, 8,3)/
     x-1.1771509d-10,-5.3651653d-09, 2.4007209d-10 /
      data fpppp(29,11, 9,1),fpppp(29,11, 9,2),fpppp(29,11, 9,3)/
     x-9.3703743d-09,-7.8417583d-09,-1.8683305d-10 /
      data fpppp(29,11,10,1),fpppp(29,11,10,2),fpppp(29,11,10,3)/
     x-3.8502161d-09,-1.2509775d-09, 1.5794684d-10 /
      data fpppp(29,11,11,1),fpppp(29,11,11,2),fpppp(29,11,11,3)/
     x-4.0770450d-09,-2.2295385d-09,-1.8774440d-10 /
      data fpppp(29,11,12,1),fpppp(29,11,12,2),fpppp(29,11,12,3)/
     x-1.4851152d-09, 1.0438345d-09, 1.8685330d-10 /
      data fpppp(29,11,13,1),fpppp(29,11,13,2),fpppp(29,11,13,3)/
     x 1.4244788d-09, 2.5236024d-09,-1.4995400d-10 /
      data fpppp(29,11,14,1),fpppp(29,11,14,2),fpppp(29,11,14,3)/
     x-3.1730519d-10, 9.1734604d-10, 1.2604800d-10 /
      data fpppp(29,11,15,1),fpppp(29,11,15,2),fpppp(29,11,15,3)/
     x-2.7007401d-09, 1.2877204d-10,-4.8841035d-11 /
      data fpppp(29,11,16,1),fpppp(29,11,16,2),fpppp(29,11,16,3)/
     x-6.2162677d-09,-1.3507020d-09,-9.9092516d-11 /
      data fpppp(29,11,17,1),fpppp(29,11,17,2),fpppp(29,11,17,3)/
     x-5.5727178d-09,-1.2197848d-09, 2.0300147d-10 /
      data fpppp(29,11,18,1),fpppp(29,11,18,2),fpppp(29,11,18,3)/
     x-7.7029337d-09,-4.0125349d-09,-1.0514283d-10 /
      data fpppp(29,11,19,1),fpppp(29,11,19,2),fpppp(29,11,19,3)/
     x-6.8604816d-09,-3.5554439d-09,-3.3472367d-11 /
      data fpppp(29,11,20,1),fpppp(29,11,20,2),fpppp(29,11,20,3)/
     x-4.9282827d-09, 4.6134471d-09, 1.6832699d-11 /
      data fpppp(29,11,21,1),fpppp(29,11,21,2),fpppp(29,11,21,3)/
     x-4.9282827d-09, 4.4541880d-09, 1.9120426d-11 /
      data fpppp(29,11,22,1),fpppp(29,11,22,2),fpppp(29,11,22,3)/
     x-6.8604816d-09,-2.9184075d-09,-4.2623271d-11 /
      data fpppp(29,11,23,1),fpppp(29,11,23,2),fpppp(29,11,23,3)/
     x-7.7029337d-09,-6.4014212d-09,-7.0826937d-11 /
      data fpppp(29,12, 1,1),fpppp(29,12, 1,2),fpppp(29,12, 1,3)/
     x 3.0226208d-09, 4.1231945d-09,-1.5761976d-11 /
      data fpppp(29,12, 2,1),fpppp(29,12, 2,2),fpppp(29,12, 2,3)/
     x 4.7977429d-09, 5.4899948d-09,-1.1230635d-11 /
      data fpppp(29,12, 3,1),fpppp(29,12, 3,2),fpppp(29,12, 3,3)/
     x 5.4666081d-09, 8.6280525d-09, 3.4714950d-12 /
      data fpppp(29,12, 4,1),fpppp(29,12, 4,2),fpppp(29,12, 4,3)/
     x 5.4666081d-09, 8.2619524d-09,-5.2647057d-12 /
      data fpppp(29,12, 5,1),fpppp(29,12, 5,2),fpppp(29,12, 5,3)/
     x 4.7977429d-09, 6.9543952d-09, 2.3714168d-11 /
      data fpppp(29,12, 6,1),fpppp(29,12, 6,2),fpppp(29,12, 6,3)/
     x 3.0226208d-09,-1.3683072d-09,-1.4680499d-10 /
      data fpppp(29,12, 7,1),fpppp(29,12, 7,2),fpppp(29,12, 7,3)/
     x 2.0768233d-09, 4.6820065d-09, 1.6516557d-10 /
      data fpppp(29,12, 8,1),fpppp(29,12, 8,2),fpppp(29,12, 8,3)/
     x-9.5803154d-09,-1.5514917d-08,-1.5981527d-10 /
      data fpppp(29,12, 9,1),fpppp(29,12, 9,2),fpppp(29,12, 9,3)/
     x 1.3474981d-09, 1.7501193d-09, 1.7248933d-10 /
      data fpppp(29,12,10,1),fpppp(29,12,10,2),fpppp(29,12,10,3)/
     x-3.6181296d-09,-6.2584249d-09,-8.0577415d-11 /
      data fpppp(29,12,11,1),fpppp(29,12,11,2),fpppp(29,12,11,3)/
     x 3.8122604d-10,-2.1450194d-09, 2.9982292d-11 /
      data fpppp(29,12,12,1),fpppp(29,12,12,2),fpppp(29,12,12,3)/
     x 1.7444164d-09, 1.3534195d-09,-1.8761502d-11 /
      data fpppp(29,12,13,1),fpppp(29,12,13,2),fpppp(29,12,13,3)/
     x-1.1156426d-09,-2.1328266d-10, 4.9477703d-11 /
      data fpppp(29,12,14,1),fpppp(29,12,14,2),fpppp(29,12,14,3)/
     x 1.4054435d-10, 2.1025199d-09,-7.5387605d-11 /
      data fpppp(29,12,15,1),fpppp(29,12,15,2),fpppp(29,12,15,3)/
     x-5.1293615d-10,-1.5559646d-09, 2.2861289d-11 /
      data fpppp(29,12,16,1),fpppp(29,12,16,2),fpppp(29,12,16,3)/
     x-7.0152784d-10, 4.8133468d-10, 1.3070423d-10 /
      data fpppp(29,12,17,1),fpppp(29,12,17,2),fpppp(29,12,17,3)/
     x-5.1043800d-09,-3.0125950d-09,-1.5441176d-10 /
      data fpppp(29,12,18,1),fpppp(29,12,18,2),fpppp(29,12,18,3)/
     x-5.1382971d-09,-2.6861110d-09, 1.4201859d-10 /
      data fpppp(29,12,19,1),fpppp(29,12,19,2),fpppp(29,12,19,3)/
     x-6.7962970d-09,-4.0052008d-09,-9.5178515d-11 /
      data fpppp(29,12,20,1),fpppp(29,12,20,2),fpppp(29,12,20,3)/
     x-5.1461640d-09, 4.6706665d-09, 2.6562722d-12 /
      data fpppp(29,12,21,1),fpppp(29,12,21,2),fpppp(29,12,21,3)/
     x-5.1461640d-09, 4.4158645d-09,-1.0770310d-11 /
      data fpppp(29,12,22,1),fpppp(29,12,22,2),fpppp(29,12,22,3)/
     x-6.7962970d-09,-2.9859930d-09,-4.1472185d-11 /
      data fpppp(29,12,23,1),fpppp(29,12,23,2),fpppp(29,12,23,3)/
     x-5.1382971d-09,-6.5081403d-09,-5.9380149d-11 /
      data fpppp(29,13, 1,1),fpppp(29,13, 1,2),fpppp(29,13, 1,3)/
     x 7.7109208d-09, 4.2736779d-09,-4.0274297d-11 /
      data fpppp(29,13, 2,1),fpppp(29,13, 2,2),fpppp(29,13, 2,3)/
     x 7.4711642d-09, 5.1496640d-09,-2.8124264d-11 /
      data fpppp(29,13, 3,1),fpppp(29,13, 3,2),fpppp(29,13, 3,3)/
     x 8.2906383d-09, 7.0866126d-09,-7.2812459d-12 /
      data fpppp(29,13, 4,1),fpppp(29,13, 4,2),fpppp(29,13, 4,3)/
     x 8.2906383d-09, 6.9819004d-09, 1.8060964d-12 /
      data fpppp(29,13, 5,1),fpppp(29,13, 5,2),fpppp(29,13, 5,3)/
     x 7.4711642d-09, 5.5685127d-09,-6.4473634d-11 /
      data fpppp(29,13, 6,1),fpppp(29,13, 6,2),fpppp(29,13, 6,3)/
     x 7.7109208d-09, 2.7029950d-09, 9.6035838d-11 /
      data fpppp(29,13, 7,1),fpppp(29,13, 7,2),fpppp(29,13, 7,3)/
     x 5.6519670d-09,-9.5364068d-10,-1.3088399d-10 /
      data fpppp(29,13, 8,1),fpppp(29,13, 8,2),fpppp(29,13, 8,3)/
     x 1.1471785d-08,-2.5081562d-09, 1.3520129d-10 /
      data fpppp(29,13, 9,1),fpppp(29,13, 9,2),fpppp(29,13, 9,3)/
     x 2.2909148d-09,-4.7914914d-09,-1.4237061d-10 /
      data fpppp(29,13,10,1),fpppp(29,13,10,2),fpppp(29,13,10,3)/
     x 8.4802951d-09,-3.3191291d-09, 6.5335918d-11 /
      data fpppp(29,13,11,1),fpppp(29,13,11,2),fpppp(29,13,11,3)/
     x-5.7671091d-10,-2.8474238d-09, 1.0316918d-10 /
      data fpppp(29,13,12,1),fpppp(29,13,12,2),fpppp(29,13,12,3)/
     x-1.2208779d-09,-2.4491080d-09,-1.5419618d-10 /
      data fpppp(29,13,13,1),fpppp(29,13,13,2),fpppp(29,13,13,3)/
     x 1.5503362d-09, 1.1252534d-09, 8.6244796d-11 /
      data fpppp(29,13,14,1),fpppp(29,13,14,2),fpppp(29,13,14,3)/
     x 8.1308538d-10,-5.9673729d-10, 4.1084892d-11 /
      data fpppp(29,13,15,1),fpppp(29,13,15,2),fpppp(29,13,15,3)/
     x-8.6808179d-10,-1.0026352d-09, 8.6439402d-13 /
      data fpppp(29,13,16,1),fpppp(29,13,16,2),fpppp(29,13,16,3)/
     x-2.1117282d-09,-1.5894786d-09,-1.0318094d-10 /
      data fpppp(29,13,17,1),fpppp(29,13,17,2),fpppp(29,13,17,3)/
     x 1.7074264d-10,-6.0391863d-10, 1.6900315d-10 /
      data fpppp(29,13,18,1),fpppp(29,13,18,2),fpppp(29,13,18,3)/
     x-1.5769733d-09,-3.5909958d-09,-1.6090534d-10 /
      data fpppp(29,13,19,1),fpppp(29,13,19,2),fpppp(29,13,19,3)/
     x-7.3889857d-10,-6.6908217d-10, 1.7172411d-10 /
      data fpppp(29,13,20,1),fpppp(29,13,20,2),fpppp(29,13,20,3)/
     x-2.7050581d-09, 3.3337366d-09,-7.9634710d-11 /
      data fpppp(29,13,21,1),fpppp(29,13,21,2),fpppp(29,13,21,3)/
     x-2.7050581d-09, 3.3837650d-09,-5.8277262d-11 /
      data fpppp(29,13,22,1),fpppp(29,13,22,2),fpppp(29,13,22,3)/
     x-7.3889857d-10,-8.6919574d-10, 8.6294320d-11 /
      data fpppp(29,13,23,1),fpppp(29,13,23,2),fpppp(29,13,23,3)/
     x-1.5769733d-09,-2.8405699d-09, 1.5945638d-10 /
      data fpppp(29,14, 1,1),fpppp(29,14, 1,2),fpppp(29,14, 1,3)/
     x 8.2553033d-09, 5.2136415d-09, 3.2022383d-13 /
      data fpppp(29,14, 2,1),fpppp(29,14, 2,2),fpppp(29,14, 2,3)/
     x 8.6130685d-09, 5.1739284d-09,-3.1944263d-12 /
      data fpppp(29,14, 3,1),fpppp(29,14, 3,2),fpppp(29,14, 3,3)/
     x 7.7469809d-09, 5.2041248d-09,-1.0119098d-11 /
      data fpppp(29,14, 4,1),fpppp(29,14, 4,2),fpppp(29,14, 4,3)/
     x 7.7469809d-09, 5.0023574d-09,-1.1180861d-11 /
      data fpppp(29,14, 5,1),fpppp(29,14, 5,2),fpppp(29,14, 5,3)/
     x 8.6130685d-09, 5.9809980d-09, 1.0526243d-12 /
      data fpppp(29,14, 6,1),fpppp(29,14, 6,2),fpppp(29,14, 6,3)/
     x 8.2553033d-09, 2.1871305d-09,-1.5606216d-11 /
      data fpppp(29,14, 7,1),fpppp(29,14, 7,2),fpppp(29,14, 7,3)/
     x 8.5002529d-09, 2.1982089d-09, 6.4569551d-11 /
      data fpppp(29,14, 8,1),fpppp(29,14, 8,2),fpppp(29,14, 8,3)/
     x 4.2308322d-09,-3.7748399d-09,-1.4751863d-10 /
      data fpppp(29,14, 9,1),fpppp(29,14, 9,2),fpppp(29,14, 9,3)/
     x 4.1743408d-09, 3.7683083d-09, 1.1690891d-10 /
      data fpppp(29,14,10,1),fpppp(29,14,10,2),fpppp(29,14,10,3)/
     x-8.6432221d-09,-1.3685542d-08,-1.3900731d-11 /
      data fpppp(29,14,11,1),fpppp(29,14,11,2),fpppp(29,14,11,3)/
     x 3.1469383d-10, 4.3265118d-09,-1.1003692d-10 /
      data fpppp(29,14,12,1),fpppp(29,14,12,2),fpppp(29,14,12,3)/
     x-2.0668915d-09,-4.7755978d-09, 2.1819233d-10 /
      data fpppp(29,14,13,1),fpppp(29,14,13,2),fpppp(29,14,13,3)/
     x-3.6099545d-09,-1.0399042d-09,-1.3766340d-10 /
      data fpppp(29,14,14,1),fpppp(29,14,14,2),fpppp(29,14,14,3)/
     x-5.9211179d-09,-1.4429710d-09, 2.1227995d-11 /
      data fpppp(29,14,15,1),fpppp(29,14,15,2),fpppp(29,14,15,3)/
     x-1.1181735d-10,-1.9225754d-09,-3.8321798d-12 /
      data fpppp(29,14,16,1),fpppp(29,14,16,2),fpppp(29,14,16,3)/
     x 2.3429795d-09,-7.5976884d-10, 8.1892824d-11 /
      data fpppp(29,14,17,1),fpppp(29,14,17,2),fpppp(29,14,17,3)/
     x 1.3671775d-09,-1.8644550d-09,-1.0358075d-10 /
      data fpppp(29,14,18,1),fpppp(29,14,18,2),fpppp(29,14,18,3)/
     x 3.6527224d-09,-1.2100179d-09, 1.0964904d-10 /
      data fpppp(29,14,19,1),fpppp(29,14,19,2),fpppp(29,14,19,3)/
     x 3.9978011d-09,-2.8587939d-11,-1.6192314d-10 /
      data fpppp(29,14,20,1),fpppp(29,14,20,2),fpppp(29,14,20,3)/
     x 5.7421493d-09, 2.9839072d-09, 6.8657136d-11 /
      data fpppp(29,14,21,1),fpppp(29,14,21,2),fpppp(29,14,21,3)/
     x 5.7421493d-09, 2.9732552d-09, 5.0658260d-11 /
      data fpppp(29,14,22,1),fpppp(29,14,22,2),fpppp(29,14,22,3)/
     x 3.9978011d-09, 1.4019867d-11,-8.9927640d-11 /
      data fpppp(29,14,23,1),fpppp(29,14,23,2),fpppp(29,14,23,3)/
     x 3.6527224d-09,-1.3697971d-09,-1.6033409d-10 /
      data fpppp(29,15, 1,1),fpppp(29,15, 1,2),fpppp(29,15, 1,3)/
     x 6.9220576d-09, 4.7854425d-09,-3.5072281d-11 /
      data fpppp(29,15, 2,1),fpppp(29,15, 2,2),fpppp(29,15, 2,3)/
     x 6.6608923d-09, 4.4325986d-09,-2.0966665d-11 /
      data fpppp(29,15, 3,1),fpppp(29,15, 3,2),fpppp(29,15, 3,3)/
     x 6.2465154d-09, 3.7627848d-09, 9.2978578d-12 /
      data fpppp(29,15, 4,1),fpppp(29,15, 4,2),fpppp(29,15, 4,3)/
     x 6.2465154d-09, 3.6117946d-09, 9.2310041d-12 /
      data fpppp(29,15, 5,1),fpppp(29,15, 5,2),fpppp(29,15, 5,3)/
     x 6.6608923d-09, 5.0365595d-09,-2.0699250d-11 /
      data fpppp(29,15, 6,1),fpppp(29,15, 6,2),fpppp(29,15, 6,3)/
     x 6.9220576d-09, 2.5205892d-09,-3.6075086d-11 /
      data fpppp(29,15, 7,1),fpppp(29,15, 7,2),fpppp(29,15, 7,3)/
     x 5.4175297d-09, 1.6561451d-09,-3.6575375d-11 /
      data fpppp(29,15, 8,1),fpppp(29,15, 8,2),fpppp(29,15, 8,3)/
     x 4.6377593d-09,-5.6914526d-10, 9.4062015d-11 /
      data fpppp(29,15, 9,1),fpppp(29,15, 9,2),fpppp(29,15, 9,3)/
     x 2.4706706d-09,-1.4037806d-09,-5.2838929d-11 /
      data fpppp(29,15,10,1),fpppp(29,15,10,2),fpppp(29,15,10,3)/
     x 7.2676637d-09,-2.3067320d-09,-1.8626128d-11 /
      data fpppp(29,15,11,1),fpppp(29,15,11,2),fpppp(29,15,11,3)/
     x-7.2524509d-10,-2.6829254d-09, 1.0012494d-10 /
      data fpppp(29,15,12,1),fpppp(29,15,12,2),fpppp(29,15,12,3)/
     x-9.8140201d-10,-1.3222328d-09,-1.2226577d-10 /
      data fpppp(29,15,13,1),fpppp(29,15,13,2),fpppp(29,15,13,3)/
     x-2.1093155d-09,-6.2433944d-09, 1.1603291d-10 /
      data fpppp(29,15,14,1),fpppp(29,15,14,2),fpppp(29,15,14,3)/
     x 3.4498355d-09, 4.1904690d-09,-4.8800614d-11 /
      data fpppp(29,15,15,1),fpppp(29,15,15,2),fpppp(29,15,15,3)/
     x-2.3926666d-09,-5.5865916d-09, 5.4055203d-11 /
      data fpppp(29,15,16,1),fpppp(29,15,16,2),fpppp(29,15,16,3)/
     x-1.5866149d-09,-1.7653694d-09,-9.9950127d-11 /
      data fpppp(29,15,17,1),fpppp(29,15,17,2),fpppp(29,15,17,3)/
     x 1.9753332d-09,-4.8005572d-10, 6.7968062d-11 /
      data fpppp(29,15,18,1),fpppp(29,15,18,2),fpppp(29,15,18,3)/
     x 3.1644508d-09,-9.3110156d-10,-5.2723859d-11 /
      data fpppp(29,15,19,1),fpppp(29,15,19,2),fpppp(29,15,19,3)/
     x 4.5688274d-09, 1.4144014d-09, 1.1345237d-10 /
      data fpppp(29,15,20,1),fpppp(29,15,20,2),fpppp(29,15,20,3)/
     x 3.6356792d-09, 1.9814782d-09,-4.9896460d-11 /
      data fpppp(29,15,21,1),fpppp(29,15,21,2),fpppp(29,15,21,3)/
     x 3.6356792d-09, 2.0802536d-09,-3.8389861d-11 /
      data fpppp(29,15,22,1),fpppp(29,15,22,2),fpppp(29,15,22,3)/
     x 4.5688274d-09, 1.0193000d-09, 6.7425976d-11 /
      data fpppp(29,15,23,1),fpppp(29,15,23,2),fpppp(29,15,23,3)/
     x 3.1644508d-09, 5.5052845d-10, 1.1987513d-10 /
      data fpppp(29,16, 1,1),fpppp(29,16, 1,2),fpppp(29,16, 1,3)/
     x 3.9594242d-09, 3.3807192d-09, 3.8387862d-11 /
      data fpppp(29,16, 2,1),fpppp(29,16, 2,2),fpppp(29,16, 2,3)/
     x 4.5469302d-09, 3.1559271d-09, 2.0223161d-11 /
      data fpppp(29,16, 3,1),fpppp(29,16, 3,2),fpppp(29,16, 3,3)/
     x 4.2745986d-09, 2.7427993d-09,-1.8139597d-11 /
      data fpppp(29,16, 4,1),fpppp(29,16, 4,2),fpppp(29,16, 4,3)/
     x 4.2745986d-09, 2.6228026d-09,-1.9122401d-11 /
      data fpppp(29,16, 5,1),fpppp(29,16, 5,2),fpppp(29,16, 5,3)/
     x 4.5469302d-09, 3.6359137d-09, 2.4154375d-11 /
      data fpppp(29,16, 6,1),fpppp(29,16, 6,2),fpppp(29,16, 6,3)/
     x 3.9594242d-09, 1.5807693d-09, 2.3645808d-11 /
      data fpppp(29,16, 7,1),fpppp(29,16, 7,2),fpppp(29,16, 7,3)/
     x 4.6101139d-09, 1.4415408d-09,-3.5635038d-11 /
      data fpppp(29,16, 8,1),fpppp(29,16, 8,2),fpppp(29,16, 8,3)/
     x 4.8445603d-09, 5.6840640d-10, 1.6999280d-11 /
      data fpppp(29,16, 9,1),fpppp(29,16, 9,2),fpppp(29,16, 9,3)/
     x 4.5252520d-09,-5.2085548d-10,-5.1101026d-11 /
      data fpppp(29,16,10,1),fpppp(29,16,10,2),fpppp(29,16,10,3)/
     x 1.0208758d-09,-1.1696481d-09, 6.4867872d-11 /
      data fpppp(29,16,11,1),fpppp(29,16,11,2),fpppp(29,16,11,3)/
     x 1.6524766d-10,-1.5158533d-09,-5.0765500d-11 /
      data fpppp(29,16,12,1),fpppp(29,16,12,2),fpppp(29,16,12,3)/
     x-2.5557019d-09,-2.5909948d-09, 5.5618829d-11 /
      data fpppp(29,16,13,1),fpppp(29,16,13,2),fpppp(29,16,13,3)/
     x-3.5174219d-09,-1.6241601d-09,-6.5157900d-11 /
      data fpppp(29,16,14,1),fpppp(29,16,14,2),fpppp(29,16,14,3)/
     x-7.5794373d-09,-1.8649997d-09, 6.3984965d-11 /
      data fpppp(29,16,15,1),fpppp(29,16,15,2),fpppp(29,16,15,3)/
     x-3.4841170d-09,-1.6465102d-09,-3.3741002d-11 /
      data fpppp(29,16,16,1),fpppp(29,16,16,2),fpppp(29,16,16,3)/
     x-3.3685560d-09,-2.2384992d-09, 7.3306653d-11 /
      data fpppp(29,16,17,1),fpppp(29,16,17,2),fpppp(29,16,17,3)/
     x-2.6375023d-09,-6.2115744d-10,-8.8535010d-11 /
      data fpppp(29,16,18,1),fpppp(29,16,18,2),fpppp(29,16,18,3)/
     x-9.6070903d-10,-3.6688751d-10, 2.6821480d-11 /
      data fpppp(29,16,19,1),fpppp(29,16,19,2),fpppp(29,16,19,3)/
     x-5.0045807d-10, 9.4572819d-10,-7.3943177d-11 /
      data fpppp(29,16,20,1),fpppp(29,16,20,2),fpppp(29,16,20,3)/
     x 9.0027000d-10, 1.3300488d-09, 5.3580935d-11 /
      data fpppp(29,16,21,1),fpppp(29,16,21,2),fpppp(29,16,21,3)/
     x 9.0027000d-10, 1.3838431d-09, 4.5972901d-11 /
      data fpppp(29,16,22,1),fpppp(29,16,22,2),fpppp(29,16,22,3)/
     x-5.0045807d-10, 7.3055109d-10,-4.3511042d-11 /
      data fpppp(29,16,23,1),fpppp(29,16,23,2),fpppp(29,16,23,3)/
     x-9.6070903d-10, 4.4002663d-10,-8.7299025d-11 /
      data fpppp(29,17, 1,1),fpppp(29,17, 1,2),fpppp(29,17, 1,3)/
     x 2.6973747d-09, 1.0671377d-09, 1.1285555d-11 /
      data fpppp(29,17, 2,1),fpppp(29,17, 2,2),fpppp(29,17, 2,3)/
     x 1.7356583d-09, 1.3574168d-09, 1.0544574d-11 /
      data fpppp(29,17, 3,1),fpppp(29,17, 3,2),fpppp(29,17, 3,3)/
     x 1.6093273d-09, 1.9618499d-09, 1.1613596d-11 /
      data fpppp(29,17, 4,1),fpppp(29,17, 4,2),fpppp(29,17, 4,3)/
     x 1.6093273d-09, 1.9926389d-09, 6.9641293d-12 /
      data fpppp(29,17, 5,1),fpppp(29,17, 5,2),fpppp(29,17, 5,3)/
     x 1.7356583d-09, 1.2342608d-09, 2.9142440d-11 /
      data fpppp(29,17, 6,1),fpppp(29,17, 6,2),fpppp(29,17, 6,3)/
     x 2.6973747d-09, 1.5289727d-09,-5.8456440d-11 /
      data fpppp(29,17, 7,1),fpppp(29,17, 7,2),fpppp(29,17, 7,3)/
     x 2.7123062d-09, 9.1615530d-10, 7.3848015d-11 /
      data fpppp(29,17, 8,1),fpppp(29,17, 8,2),fpppp(29,17, 8,3)/
     x 2.4791442d-09, 8.7275034d-10,-1.0104079d-10 /
      data fpppp(29,17, 9,1),fpppp(29,17, 9,2),fpppp(29,17, 9,3)/
     x 1.4483541d-09,-3.9428315d-10, 1.1843719d-10 /
      data fpppp(29,17,10,1),fpppp(29,17,10,2),fpppp(29,17,10,3)/
     x 1.7316018d-09,-6.3609780d-10,-1.0664031d-10 /
      data fpppp(29,17,11,1),fpppp(29,17,11,2),fpppp(29,17,11,3)/
     x 9.4047321d-10,-4.4758017d-10, 6.4922725d-11 /
      data fpppp(29,17,12,1),fpppp(29,17,12,2),fpppp(29,17,12,3)/
     x 1.0614334d-09,-1.6734726d-09,-8.2357240d-11 /
      data fpppp(29,17,13,1),fpppp(29,17,13,2),fpppp(29,17,13,3)/
     x 9.6270516d-11,-5.7222452d-10, 1.1120380d-10 /
      data fpppp(29,17,14,1),fpppp(29,17,14,2),fpppp(29,17,14,3)/
     x-5.3709167d-10,-1.2198744d-09,-9.1411997d-11 /
      data fpppp(29,17,15,1),fpppp(29,17,15,2),fpppp(29,17,15,3)/
     x-3.1182649d-09,-1.6616279d-09, 1.1394704d-11 /
      data fpppp(29,17,16,1),fpppp(29,17,16,2),fpppp(29,17,16,3)/
     x-3.5538318d-09,-7.1630371d-10,-3.0947329d-11 /
      data fpppp(29,17,17,1),fpppp(29,17,17,2),fpppp(29,17,17,3)/
     x-5.0351916d-09,-6.1628710d-10, 6.6369452d-11 /
      data fpppp(29,17,18,1),fpppp(29,17,18,2),fpppp(29,17,18,3)/
     x-6.4506709d-09,-9.0587871d-10,-5.7681120d-11 /
      data fpppp(29,17,19,1),fpppp(29,17,19,2),fpppp(29,17,19,3)/
     x-6.9381449d-09, 1.0209990d-09, 5.4599099d-11 /
      data fpppp(29,17,20,1),fpppp(29,17,20,2),fpppp(29,17,20,3)/
     x-8.2860349d-09, 1.7001624d-10,-1.0423273d-11 /
      data fpppp(29,17,21,1),fpppp(29,17,21,2),fpppp(29,17,21,3)/
     x-8.2860349d-09, 2.8033284d-10,-3.6531468d-12 /
      data fpppp(29,17,22,1),fpppp(29,17,22,2),fpppp(29,17,22,3)/
     x-6.9381449d-09, 5.7973263d-10, 2.7518594d-11 /
      data fpppp(29,17,23,1),fpppp(29,17,23,2),fpppp(29,17,23,3)/
     x-6.4506709d-09, 7.4887029d-10, 4.3870773d-11 /
      data fpppp(29,18, 1,1),fpppp(29,18, 1,2),fpppp(29,18, 1,3)/
     x-2.2268361d-09,-3.3413494d-10,-9.0248792d-12 /
      data fpppp(29,18, 2,1),fpppp(29,18, 2,2),fpppp(29,18, 2,3)/
     x-2.6491218d-09, 1.5987904d-10,-1.4118658d-12 /
      data fpppp(29,18, 3,1),fpppp(29,18, 3,2),fpppp(29,18, 3,3)/
     x-2.2376234d-09, 1.1801902d-09, 1.3221643d-11 /
      data fpppp(29,18, 4,1),fpppp(29,18, 4,2),fpppp(29,18, 4,3)/
     x-2.2376234d-09, 1.2471981d-09, 1.6161803d-11 /
      data fpppp(29,18, 5,1),fpppp(29,18, 5,2),fpppp(29,18, 5,3)/
     x-2.6491218d-09,-1.0815244d-10,-1.3172506d-11 /
      data fpppp(29,18, 6,1),fpppp(29,18, 6,2),fpppp(29,18, 6,3)/
     x-2.2268361d-09, 6.7098312d-10, 3.5077521d-11 /
      data fpppp(29,18, 7,1),fpppp(29,18, 7,2),fpppp(29,18, 7,3)/
     x-1.2867033d-09, 5.2520563d-10,-4.6898918d-11 /
      data fpppp(29,18, 8,1),fpppp(29,18, 8,2),fpppp(29,18, 8,3)/
     x-2.8542132d-10, 9.8075153d-11, 7.0833916d-11 /
      data fpppp(29,18, 9,1),fpppp(29,18, 9,2),fpppp(29,18, 9,3)/
     x 9.9276340d-10, 4.4656564d-10,-9.0185896d-11 /
      data fpppp(29,18,10,1),fpppp(29,18,10,2),fpppp(29,18,10,3)/
     x 1.3439729d-09,-7.3652608d-10, 6.8176056d-11 /
      data fpppp(29,18,11,1),fpppp(29,18,11,2),fpppp(29,18,11,3)/
     x 1.8761958d-09, 9.7458727d-10,-8.7317946d-11 /
      data fpppp(29,18,12,1),fpppp(29,18,12,2),fpppp(29,18,12,3)/
     x 8.5692730d-10,-1.3060069d-09, 8.0897627d-11 /
      data fpppp(29,18,13,1),fpppp(29,18,13,2),fpppp(29,18,13,3)/
     x 1.5225746d-10, 5.5378756d-11,-8.9614724d-11 /
      data fpppp(29,18,14,1),fpppp(29,18,14,2),fpppp(29,18,14,3)/
     x-1.0563797d-09,-6.0442344d-10, 5.4405284d-11 /
      data fpppp(29,18,15,1),fpppp(29,18,15,2),fpppp(29,18,15,3)/
     x-1.9292463d-09,-4.3185348d-10,-3.2849416d-11 /
      data fpppp(29,18,16,1),fpppp(29,18,16,2),fpppp(29,18,16,3)/
     x-3.7353784d-09,-4.7460220d-10, 2.1786810d-11 /
      data fpppp(29,18,17,1),fpppp(29,18,17,2),fpppp(29,18,17,3)/
     x-5.4255089d-09,-1.8601000d-10,-4.1147777d-11 /
      data fpppp(29,18,18,1),fpppp(29,18,18,2),fpppp(29,18,18,3)/
     x-7.1291208d-09,-6.7022246d-10, 4.9418768d-11 /
      data fpppp(29,18,19,1),fpppp(29,18,19,2),fpppp(29,18,19,3)/
     x-8.6380781d-09, 2.6240640d-10,-2.2311316d-11 /
      data fpppp(29,18,20,1),fpppp(29,18,20,2),fpppp(29,18,20,3)/
     x-9.4716009d-09,-2.5496209d-10, 1.4028779d-11 /
      data fpppp(29,18,21,1),fpppp(29,18,21,2),fpppp(29,18,21,3)/
     x-9.4716009d-09,-1.9923104d-10, 9.8188680d-12 /
      data fpppp(29,18,22,1),fpppp(29,18,22,2),fpppp(29,18,22,3)/
     x-8.6380781d-09, 3.9482194d-11,-5.4716710d-12 /
      data fpppp(29,18,23,1),fpppp(29,18,23,2),fpppp(29,18,23,3)/
     x-7.1291208d-09, 1.6574332d-10,-1.3729899d-11 /
      data fpppp(29,19, 1,1),fpppp(29,19, 1,2),fpppp(29,19, 1,3)/
     x-6.1047150d-09,-1.9698390d-23,-3.1275849d-11 /
      data fpppp(29,19, 2,1),fpppp(29,19, 2,2),fpppp(29,19, 2,3)/
     x-6.5843282d-09,-3.5210809d-23,-1.2717491d-11 /
      data fpppp(29,19, 3,1),fpppp(29,19, 3,2),fpppp(29,19, 3,3)/
     x-5.7469514d-09, 3.0793152d-23, 2.2871160d-11 /
      data fpppp(29,19, 4,1),fpppp(29,19, 4,2),fpppp(29,19, 4,3)/
     x-5.7469514d-09, 1.7467956d-23, 3.0184864d-11 /
      data fpppp(29,19, 5,1),fpppp(29,19, 5,2),fpppp(29,19, 5,3)/
     x-6.5843282d-09,-2.2563120d-23,-4.1972306d-11 /
      data fpppp(29,19, 6,1),fpppp(29,19, 6,2),fpppp(29,19, 6,3)/
     x-6.1047150d-09,-1.4426180d-24, 7.8429708d-11 /
      data fpppp(29,19, 7,1),fpppp(29,19, 7,2),fpppp(29,19, 7,3)/
     x-4.6853694d-09, 8.2276238d-23,-1.0186586d-10 /
      data fpppp(29,19, 8,1),fpppp(29,19, 8,2),fpppp(29,19, 8,3)/
     x-2.9359441d-09,-2.6422321d-24, 1.5987583d-10 /
      data fpppp(29,19, 9,1),fpppp(29,19, 9,2),fpppp(29,19, 9,3)/
     x-2.1177221d-10, 2.9224499d-23,-1.9076289d-10 /
      data fpppp(29,19,10,1),fpppp(29,19,10,2),fpppp(29,19,10,3)/
     x 1.2701596d-09,-2.5375381d-23, 1.4404255d-10 /
      data fpppp(29,19,11,1),fpppp(29,19,11,2),fpppp(29,19,11,3)/
     x 2.7660622d-09, 2.9309772d-23,-1.6300750d-10 /
      data fpppp(29,19,12,1),fpppp(29,19,12,2),fpppp(29,19,12,3)/
     x 1.7443188d-09,-4.9627672d-23, 1.5808651d-10 /
      data fpppp(29,19,13,1),fpppp(29,19,13,2),fpppp(29,19,13,3)/
     x 1.2247317d-09,-2.2001398d-23,-1.8266747d-10 /
      data fpppp(29,19,14,1),fpppp(29,19,14,2),fpppp(29,19,14,3)/
     x 5.8479894d-10, 1.0356206d-23, 1.1416135d-10 /
      data fpppp(29,19,15,1),fpppp(29,19,15,2),fpppp(29,19,15,3)/
     x-9.7541819d-10, 2.6550584d-23,-5.1556442d-11 /
      data fpppp(29,19,16,1),fpppp(29,19,16,2),fpppp(29,19,16,3)/
     x-3.9179904d-09, 2.6026744d-24, 2.9667200d-11 /
      data fpppp(29,19,17,1),fpppp(29,19,17,2),fpppp(29,19,17,3)/
     x-6.3893610d-09,-1.5901775d-23,-7.3687381d-11 /
      data fpppp(29,19,18,1),fpppp(29,19,18,2),fpppp(29,19,18,3)/
     x-9.1822884d-09, 2.0721527d-23, 1.0177509d-10 /
      data fpppp(29,19,19,1),fpppp(29,19,19,2),fpppp(29,19,19,3)/
     x-1.1691655d-08, 1.7638362d-24,-4.0520961d-11 /
      data fpppp(29,19,20,1),fpppp(29,19,20,2),fpppp(29,19,20,3)/
     x-1.2943092d-08,-6.0748522d-23, 1.3207614d-11 /
      data fpppp(29,19,21,1),fpppp(29,19,21,2),fpppp(29,19,21,3)/
     x-1.2943092d-08,-4.4880674d-25, 5.2628648d-12 /
      data fpppp(29,19,22,1),fpppp(29,19,22,2),fpppp(29,19,22,3)/
     x-1.1691655d-08,-6.8044572d-23,-8.7419641d-12 /
      data fpppp(29,19,23,1),fpppp(29,19,23,2),fpppp(29,19,23,3)/
     x-9.1822884d-09,-7.6991859d-23,-1.7396151d-11 /
      data fpppp(30, 1, 1,1),fpppp(30, 1, 1,2),fpppp(30, 1, 1,3)/
     x-9.0675352d-09,-1.2838478d-21, 1.8953541d-11 /
      data fpppp(30, 1, 2,1),fpppp(30, 1, 2,2),fpppp(30, 1, 2,3)/
     x-7.8728831d-08, 2.7837374d-21, 1.3710494d-11 /
      data fpppp(30, 1, 3,1),fpppp(30, 1, 3,2),fpppp(30, 1, 3,3)/
     x-1.2432160d-07,-8.3708982d-22,-2.7187284d-12 /
      data fpppp(30, 1, 4,1),fpppp(30, 1, 4,2),fpppp(30, 1, 4,3)/
     x-1.2432160d-07, 4.8107294d-22, 6.3709846d-12 /
      data fpppp(30, 1, 5,1),fpppp(30, 1, 5,2),fpppp(30, 1, 5,3)/
     x-7.8728831d-08, 1.0122703d-21,-2.2648358d-11 /
      data fpppp(30, 1, 6,1),fpppp(30, 1, 6,2),fpppp(30, 1, 6,3)/
     x-9.0675352d-09, 7.5006977d-22, 1.5529924d-10 /
      data fpppp(30, 1, 7,1),fpppp(30, 1, 7,2),fpppp(30, 1, 7,3)/
     x 9.9589298d-08,-1.3693388d-21,-1.5377975d-10 /
      data fpppp(30, 1, 8,1),fpppp(30, 1, 8,2),fpppp(30, 1, 8,3)/
     x 2.0517966d-07,-2.2523247d-22, 6.9193054d-11 /
      data fpppp(30, 1, 9,1),fpppp(30, 1, 9,2),fpppp(30, 1, 9,3)/
     x 2.9533906d-07, 2.4013167d-22, 3.4629388d-11 /
      data fpppp(30, 1,10,1),fpppp(30, 1,10,2),fpppp(30, 1,10,3)/
     x 3.8776647d-07, 5.6339650d-22,-8.6420751d-11 /
      data fpppp(30, 1,11,1),fpppp(30, 1,11,2),fpppp(30, 1,11,3)/
     x 4.2873592d-07, 5.6793630d-23, 1.6444257d-11 /
      data fpppp(30, 1,12,1),fpppp(30, 1,12,2),fpppp(30, 1,12,3)/
     x 4.7350086d-07, 4.5848101d-23,-3.6465948d-11 /
      data fpppp(30, 1,13,1),fpppp(30, 1,13,2),fpppp(30, 1,13,3)/
     x 4.3855883d-07,-4.5630110d-22, 1.3474785d-11 /
      data fpppp(30, 1,14,1),fpppp(30, 1,14,2),fpppp(30, 1,14,3)/
     x 3.5707906d-07,-1.0504779d-21,-3.1108113d-11 /
      data fpppp(30, 1,15,1),fpppp(30, 1,15,2),fpppp(30, 1,15,3)/
     x 2.5308288d-07,-1.6307538d-22, 2.4989202d-13 /
      data fpppp(30, 1,16,1),fpppp(30, 1,16,2),fpppp(30, 1,16,3)/
     x 1.4281111d-07, 7.1979469d-22,-2.6006439d-11 /
      data fpppp(30, 1,17,1),fpppp(30, 1,17,2),fpppp(30, 1,17,3)/
     x 5.4834237d-09, 1.0302162d-21,-1.0746189d-11 /
      data fpppp(30, 1,18,1),fpppp(30, 1,18,2),fpppp(30, 1,18,3)/
     x-1.0891791d-07, 1.4645444d-21, 6.0615345d-11 /
      data fpppp(30, 1,19,1),fpppp(30, 1,19,2),fpppp(30, 1,19,3)/
     x-2.0043993d-07, 1.5694444d-21,-1.4673864d-11 /
      data fpppp(30, 1,20,1),fpppp(30, 1,20,2),fpppp(30, 1,20,3)/
     x-2.8243009d-07,-1.2958370d-21, 1.7899122d-11 /
      data fpppp(30, 1,21,1),fpppp(30, 1,21,2),fpppp(30, 1,21,3)/
     x-2.8243009d-07, 4.3041612d-22, 1.3603714d-11 /
      data fpppp(30, 1,22,1),fpppp(30, 1,22,2),fpppp(30, 1,22,3)/
     x-2.0043993d-07, 5.7601260d-22, 2.5077698d-12 /
      data fpppp(30, 1,23,1),fpppp(30, 1,23,2),fpppp(30, 1,23,3)/
     x-1.0891791d-07, 1.3203188d-21,-3.8157797d-12 /
      data fpppp(30, 2, 1,1),fpppp(30, 2, 1,2),fpppp(30, 2, 1,3)/
     x 5.6923538d-08, 1.8757069d-08, 7.4772049d-12 /
      data fpppp(30, 2, 2,1),fpppp(30, 2, 2,2),fpppp(30, 2, 2,3)/
     x 3.5494120d-08, 1.8513872d-08, 6.8104361d-12 /
      data fpppp(30, 2, 3,1),fpppp(30, 2, 3,2),fpppp(30, 2, 3,3)/
     x 1.8854644d-08, 1.8289548d-08, 3.1274705d-12 /
      data fpppp(30, 2, 4,1),fpppp(30, 2, 4,2),fpppp(30, 2, 4,3)/
     x 1.8854644d-08, 1.7770127d-08, 7.0722775d-12 /
      data fpppp(30, 2, 5,1),fpppp(30, 2, 5,2),fpppp(30, 2, 5,3)/
     x 3.5494120d-08, 2.0591557d-08,-8.9687920d-12 /
      data fpppp(30, 2, 6,1),fpppp(30, 2, 6,2),fpppp(30, 2, 6,3)/
     x 5.6923538d-08, 1.0965753d-08, 6.6649310d-11 /
      data fpppp(30, 2, 7,1),fpppp(30, 2, 7,2),fpppp(30, 2, 7,3)/
     x 8.9361449d-08, 6.9839071d-09,-6.7166127d-11 /
      data fpppp(30, 2, 8,1),fpppp(30, 2, 8,2),fpppp(30, 2, 8,3)/
     x 1.1509602d-07, 2.2763850d-10, 2.3268619d-11 /
      data fpppp(30, 2, 9,1),fpppp(30, 2, 9,2),fpppp(30, 2, 9,3)/
     x 1.3092695d-07,-1.5996596d-08, 1.8847944d-11 /
      data fpppp(30, 2,10,1),fpppp(30, 2,10,2),fpppp(30, 2,10,3)/
     x 1.5111548d-07,-7.2592617d-09,-4.1240106d-11 /
      data fpppp(30, 2,11,1),fpppp(30, 2,11,2),fpppp(30, 2,11,3)/
     x 1.5427271d-07,-2.9991290d-08, 1.5331201d-11 /
      data fpppp(30, 2,12,1),fpppp(30, 2,12,2),fpppp(30, 2,12,3)/
     x 1.6866572d-07,-2.1086571d-08,-2.5865356d-11 /
      data fpppp(30, 2,13,1),fpppp(30, 2,13,2),fpppp(30, 2,13,3)/
     x 1.5761462d-07,-1.2250931d-08, 2.0019720d-11 /
      data fpppp(30, 2,14,1),fpppp(30, 2,14,2),fpppp(30, 2,14,3)/
     x 1.3256488d-07,-2.6344734d-08,-2.6863682d-11 /
      data fpppp(30, 2,15,1),fpppp(30, 2,15,2),fpppp(30, 2,15,3)/
     x 1.0613934d-07,-1.0491711d-08, 8.8505571d-12 /
      data fpppp(30, 2,16,1),fpppp(30, 2,16,2),fpppp(30, 2,16,3)/
     x 7.8761215d-08,-5.9810829d-09,-1.6308578d-11 /
      data fpppp(30, 2,17,1),fpppp(30, 2,17,2),fpppp(30, 2,17,3)/
     x 3.9286045d-08, 8.3583647d-09,-1.4572136d-11 /
      data fpppp(30, 2,18,1),fpppp(30, 2,18,2),fpppp(30, 2,18,3)/
     x 3.8046948d-09, 5.8299862d-09, 3.1348822d-11 /
      data fpppp(30, 2,19,1),fpppp(30, 2,19,2),fpppp(30, 2,19,3)/
     x-2.6035969d-08, 2.6308787d-08,-4.9058084d-12 /
      data fpppp(30, 2,20,1),fpppp(30, 2,20,2),fpppp(30, 2,20,3)/
     x-5.7368733d-08, 1.5268199d-08, 8.6363847d-12 /
      data fpppp(30, 2,21,1),fpppp(30, 2,21,2),fpppp(30, 2,21,3)/
     x-5.7368733d-08, 1.6484864d-08, 6.6154518d-12 /
      data fpppp(30, 2,22,1),fpppp(30, 2,22,2),fpppp(30, 2,22,3)/
     x-2.6035969d-08, 2.1442127d-08, 3.1779233d-12 /
      data fpppp(30, 2,23,1),fpppp(30, 2,23,2),fpppp(30, 2,23,3)/
     x 3.8046948d-09, 2.4079961d-08, 1.0348279d-12 /
      data fpppp(30, 3, 1,1),fpppp(30, 3, 1,2),fpppp(30, 3, 1,3)/
     x 3.0070308d-07, 3.6280335d-08, 2.4624057d-11 /
      data fpppp(30, 3, 2,1),fpppp(30, 3, 2,2),fpppp(30, 3, 2,3)/
     x 3.5413913d-07, 3.9495285d-08, 2.2074926d-11 /
      data fpppp(30, 3, 3,1),fpppp(30, 3, 3,2),fpppp(30, 3, 3,3)/
     x 3.8288189d-07, 4.6477741d-08, 2.4613768d-11 /
      data fpppp(30, 3, 4,1),fpppp(30, 3, 4,2),fpppp(30, 3, 4,3)/
     x 3.8288189d-07, 4.6314504d-08, 1.0611557d-11 /
      data fpppp(30, 3, 5,1),fpppp(30, 3, 5,2),fpppp(30, 3, 5,3)/
     x 3.5413913d-07, 4.0148231d-08, 7.8083774d-11 /
      data fpppp(30, 3, 6,1),fpppp(30, 3, 6,2),fpppp(30, 3, 6,3)/
     x 3.0070308d-07, 3.3831785d-08,-1.8540912d-10 /
      data fpppp(30, 3, 7,1),fpppp(30, 3, 7,2),fpppp(30, 3, 7,3)/
     x 1.9974994d-07, 2.9140141d-09, 1.7693459d-10 /
      data fpppp(30, 3, 8,1),fpppp(30, 3, 8,2),fpppp(30, 3, 8,3)/
     x 8.4504853d-08,-1.1401590d-08,-1.3671620d-10 /
      data fpppp(30, 3, 9,1),fpppp(30, 3, 9,2),fpppp(30, 3, 9,3)/
     x-2.2701065d-08,-2.0518282d-08, 3.3283186d-11 /
      data fpppp(30, 3,10,1),fpppp(30, 3,10,2),fpppp(30, 3,10,3)/
     x-1.4377970d-07,-4.2735590d-08, 1.2612438d-11 /
      data fpppp(30, 3,11,1),fpppp(30, 3,11,2),fpppp(30, 3,11,3)/
     x-2.1931332d-07,-3.2627360d-08, 1.4001539d-11 /
      data fpppp(30, 3,12,1),fpppp(30, 3,12,2),fpppp(30, 3,12,3)/
     x-2.8434936d-07,-6.4140765d-08, 1.1613712d-11 /
      data fpppp(30, 3,13,1),fpppp(30, 3,13,2),fpppp(30, 3,13,3)/
     x-2.3950653d-07,-3.5591157d-08,-3.2069630d-11 /
      data fpppp(30, 3,14,1),fpppp(30, 3,14,2),fpppp(30, 3,14,3)/
     x-1.5411135d-07,-4.8344605d-08, 2.0940365d-11 /
      data fpppp(30, 3,15,1),fpppp(30, 3,15,2),fpppp(30, 3,15,3)/
     x-3.3773781d-08,-2.0350785d-08, 1.3353755d-11 /
      data fpppp(30, 3,16,1),fpppp(30, 3,16,2),fpppp(30, 3,16,3)/
     x 8.6157051d-08,-2.9330261d-08, 1.2839730d-11 /
      data fpppp(30, 3,17,1),fpppp(30, 3,17,2),fpppp(30, 3,17,3)/
     x 2.1409156d-07, 1.8116059d-08,-2.6367051d-11 /
      data fpppp(30, 3,18,1),fpppp(30, 3,18,2),fpppp(30, 3,18,3)/
     x 2.9665966d-07, 1.6965976d-08,-8.6002473d-11 /
      data fpppp(30, 3,19,1),fpppp(30, 3,19,2),fpppp(30, 3,19,3)/
     x 3.4799363d-07, 4.4202154d-08, 8.9666243d-11 /
      data fpppp(30, 3,20,1),fpppp(30, 3,20,2),fpppp(30, 3,20,3)/
     x 3.8951698d-07, 5.2644932d-08,-1.3929406d-11 /
      data fpppp(30, 3,21,1),fpppp(30, 3,21,2),fpppp(30, 3,21,3)/
     x 3.8951698d-07, 5.3750765d-08,-3.2958606d-12 /
      data fpppp(30, 3,22,1),fpppp(30, 3,22,2),fpppp(30, 3,22,3)/
     x 3.4799363d-07, 3.9778822d-08, 4.7132062d-11 /
      data fpppp(30, 3,23,1),fpppp(30, 3,23,2),fpppp(30, 3,23,3)/
     x 2.9665966d-07, 3.3553471d-08, 7.3500705d-11 /
      data fpppp(30, 4, 1,1),fpppp(30, 4, 1,2),fpppp(30, 4, 1,3)/
     x-7.7777016d-08, 3.0956296d-08,-5.8410250d-11 /
      data fpppp(30, 4, 2,1),fpppp(30, 4, 2,2),fpppp(30, 4, 2,3)/
     x-4.2693068d-08, 4.0997897d-08,-4.0236503d-11 /
      data fpppp(30, 4, 3,1),fpppp(30, 4, 3,2),fpppp(30, 4, 3,3)/
     x-2.6069381d-08, 6.2984947d-08,-8.6402803d-12 /
      data fpppp(30, 4, 4,1),fpppp(30, 4, 4,2),fpppp(30, 4, 4,3)/
     x-2.6069381d-08, 6.2163612d-08, 4.2178841d-12 /
      data fpppp(30, 4, 5,1),fpppp(30, 4, 5,2),fpppp(30, 4, 5,3)/
     x-4.2693068d-08, 4.4283236d-08,-9.1669160d-11 /
      data fpppp(30, 4, 6,1),fpppp(30, 4, 6,2),fpppp(30, 4, 6,3)/
     x-7.7777016d-08, 1.8636276d-08, 1.3446222d-10 /
      data fpppp(30, 4, 7,1),fpppp(30, 4, 7,2),fpppp(30, 4, 7,3)/
     x-1.1201877d-07,-1.1705675d-08,-1.3016952d-10 /
      data fpppp(30, 4, 8,1),fpppp(30, 4, 8,2),fpppp(30, 4, 8,3)/
     x-1.5430998d-07,-1.4690720d-08, 1.0251032d-10 /
      data fpppp(30, 4, 9,1),fpppp(30, 4, 9,2),fpppp(30, 4, 9,3)/
     x-2.1407342d-07,-4.3069745d-08,-5.8039971d-11 /
      data fpppp(30, 4,10,1),fpppp(30, 4,10,2),fpppp(30, 4,10,3)/
     x-2.3482023d-07,-2.6549563d-08, 3.6113335d-11 /
      data fpppp(30, 4,11,1),fpppp(30, 4,11,2),fpppp(30, 4,11,3)/
     x-2.4596952d-07,-4.9136763d-08, 1.3429994d-11 /
      data fpppp(30, 4,12,1),fpppp(30, 4,12,2),fpppp(30, 4,12,3)/
     x-2.1873464d-07,-1.1753718d-08,-4.4981883d-11 /
      data fpppp(30, 4,13,1),fpppp(30, 4,13,2),fpppp(30, 4,13,3)/
     x-2.3000840d-07,-5.1260305d-08, 1.2106102d-10 /
      data fpppp(30, 4,14,1),fpppp(30, 4,14,2),fpppp(30, 4,14,3)/
     x-2.2322043d-07,-3.0197549d-08,-8.3714248d-11 /
      data fpppp(30, 4,15,1),fpppp(30, 4,15,2),fpppp(30, 4,15,3)/
     x-1.9829334d-07,-4.1935746d-08, 3.2198088d-11 /
      data fpppp(30, 4,16,1),fpppp(30, 4,16,2),fpppp(30, 4,16,3)/
     x-1.5650716d-07,-3.1643262d-08,-2.6088527d-11 /
      data fpppp(30, 4,17,1),fpppp(30, 4,17,2),fpppp(30, 4,17,3)/
     x-1.0461305d-07,-1.4519495d-08,-1.0270578d-11 /
      data fpppp(30, 4,18,1),fpppp(30, 4,18,2),fpppp(30, 4,18,3)/
     x-4.0948627d-08, 1.0937319d-08, 1.0494293d-10 /
      data fpppp(30, 4,19,1),fpppp(30, 4,19,2),fpppp(30, 4,19,3)/
     x 2.3333502d-08, 5.4469171d-08,-1.1257569d-10 /
      data fpppp(30, 4,20,1),fpppp(30, 4,20,2),fpppp(30, 4,20,3)/
     x 6.0017442d-08, 6.9358996d-08, 1.0065489d-11 /
      data fpppp(30, 4,21,1),fpppp(30, 4,21,2),fpppp(30, 4,21,3)/
     x 6.0017442d-08, 7.1095543d-08,-2.9764970d-12 /
      data fpppp(30, 4,22,1),fpppp(30, 4,22,2),fpppp(30, 4,22,3)/
     x 2.3333502d-08, 4.7522981d-08,-6.0407748d-11 /
      data fpppp(30, 4,23,1),fpppp(30, 4,23,2),fpppp(30, 4,23,3)/
     x-4.0948627d-08, 3.6985531d-08,-9.0686861d-11 /
      data fpppp(30, 5, 1,1),fpppp(30, 5, 1,2),fpppp(30, 5, 1,3)/
     x-1.7608399d-07, 1.8540398d-08, 3.2208058d-11 /
      data fpppp(30, 5, 2,1),fpppp(30, 5, 2,2),fpppp(30, 5, 2,3)/
     x-1.1650629d-07, 3.1017195d-08, 1.2488859d-11 /
      data fpppp(30, 5, 3,1),fpppp(30, 5, 3,2),fpppp(30, 5, 3,3)/
     x-3.2458197d-08, 5.8453313d-08,-2.7714858d-11 /
      data fpppp(30, 5, 4,1),fpppp(30, 5, 4,2),fpppp(30, 5, 4,3)/
     x-3.2458197d-08, 5.7228095d-08,-3.1305348d-11 /
      data fpppp(30, 5, 5,1),fpppp(30, 5, 5,2),fpppp(30, 5, 5,3)/
     x-1.1650629d-07, 3.5918068d-08, 2.6850821d-11 /
      data fpppp(30, 5, 6,1),fpppp(30, 5, 6,2),fpppp(30, 5, 6,3)/
     x-1.7608399d-07, 1.6212622d-10,-2.1649299d-11 /
      data fpppp(30, 5, 7,1),fpppp(30, 5, 7,2),fpppp(30, 5, 7,3)/
     x-2.1393026d-07,-2.3127475d-08, 2.3237725d-12 /
      data fpppp(30, 5, 8,1),fpppp(30, 5, 8,2),fpppp(30, 5, 8,3)/
     x-2.0804381d-07,-3.0249873d-08, 4.1563325d-11 /
      data fpppp(30, 5, 9,1),fpppp(30, 5, 9,2),fpppp(30, 5, 9,3)/
     x-1.4673917d-07,-2.6170524d-08, 7.4276380d-13 /
      data fpppp(30, 5,10,1),fpppp(30, 5,10,2),fpppp(30, 5,10,3)/
     x-8.4067904d-08,-1.2335824d-08,-3.9418449d-11 /
      data fpppp(30, 5,11,1),fpppp(30, 5,11,2),fpppp(30, 5,11,3)/
     x-3.2205528d-08,-2.4081504d-08, 1.9823104d-11 /
      data fpppp(30, 5,12,1),fpppp(30, 5,12,2),fpppp(30, 5,12,3)/
     x-1.7807404d-08, 2.9170120d-09, 6.0488010d-11 /
      data fpppp(30, 5,13,1),fpppp(30, 5,13,2),fpppp(30, 5,13,3)/
     x-3.9093543d-08,-3.7468853d-08,-1.0841581d-10 /
      data fpppp(30, 5,14,1),fpppp(30, 5,14,2),fpppp(30, 5,14,3)/
     x-8.2766553d-08,-1.7641377d-09, 1.2670793d-10 /
      data fpppp(30, 5,15,1),fpppp(30, 5,15,2),fpppp(30, 5,15,3)/
     x-1.4367090d-07,-4.3859235d-08,-9.7069960d-11 /
      data fpppp(30, 5,16,1),fpppp(30, 5,16,2),fpppp(30, 5,16,3)/
     x-1.7582012d-07,-2.7103714d-08, 9.8418479d-11 /
      data fpppp(30, 5,17,1),fpppp(30, 5,17,2),fpppp(30, 5,17,3)/
     x-1.9703299d-07,-3.4854977d-08,-5.2431844d-12 /
      data fpppp(30, 5,18,1),fpppp(30, 5,18,2),fpppp(30, 5,18,3)/
     x-1.6445702d-07, 4.3595024d-09,-4.9903172d-11 /
      data fpppp(30, 5,19,1),fpppp(30, 5,19,2),fpppp(30, 5,19,3)/
     x-1.1722412d-07, 4.0526378d-08, 1.7864733d-11 /
      data fpppp(30, 5,20,1),fpppp(30, 5,20,2),fpppp(30, 5,20,3)/
     x-7.2945150d-08, 6.0304174d-08,-1.9111458d-11 /
      data fpppp(30, 5,21,1),fpppp(30, 5,21,2),fpppp(30, 5,21,3)/
     x-7.2945150d-08, 6.1582840d-08,-1.5075534d-11 /
      data fpppp(30, 5,22,1),fpppp(30, 5,22,2),fpppp(30, 5,22,3)/
     x-1.1722412d-07, 3.5411713d-08, 1.7210382d-12 /
      data fpppp(30, 5,23,1),fpppp(30, 5,23,2),fpppp(30, 5,23,3)/
     x-1.6445702d-07, 2.3539497d-08, 1.0635685d-11 /
      data fpppp(30, 6, 1,1),fpppp(30, 6, 1,2),fpppp(30, 6, 1,3)/
     x-3.1045050d-08, 4.0809334d-08, 1.3105590d-11 /
      data fpppp(30, 6, 2,1),fpppp(30, 6, 2,2),fpppp(30, 6, 2,3)/
     x-3.2590736d-08, 3.1799447d-08, 3.2259217d-12 /
      data fpppp(30, 6, 3,1),fpppp(30, 6, 3,2),fpppp(30, 6, 3,3)/
     x-7.5567396d-08, 1.4175332d-08,-1.5807285d-11 /
      data fpppp(30, 6, 4,1),fpppp(30, 6, 4,2),fpppp(30, 6, 4,3)/
     x-7.5567396d-08, 1.1230455d-08,-1.9547928d-11 /
      data fpppp(30, 6, 5,1),fpppp(30, 6, 5,2),fpppp(30, 6, 5,3)/
     x-3.2590736d-08, 4.3578951d-08, 1.8188496d-11 /
      data fpppp(30, 6, 6,1),fpppp(30, 6, 6,2),fpppp(30, 6, 6,3)/
     x-3.1045050d-08,-3.3638086d-09,-4.3004064d-11 /
      data fpppp(30, 6, 7,1),fpppp(30, 6, 7,2),fpppp(30, 6, 7,3)/
     x-1.0290514d-08,-3.3913877d-09, 6.7507985d-11 /
      data fpppp(30, 6, 8,1),fpppp(30, 6, 8,2),fpppp(30, 6, 8,3)/
     x 1.8182740d-08,-1.0788674d-08,-6.0158804d-11 /
      data fpppp(30, 6, 9,1),fpppp(30, 6, 9,2),fpppp(30, 6, 9,3)/
     x 1.8664072d-08,-4.3019521d-09,-5.9839123d-12 /
      data fpppp(30, 6,10,1),fpppp(30, 6,10,2),fpppp(30, 6,10,3)/
     x 1.9482619d-08,-8.1995204d-09, 1.5716696d-10 /
      data fpppp(30, 6,11,1),fpppp(30, 6,11,2),fpppp(30, 6,11,3)/
     x 3.4390940d-09,-1.4185967d-08,-1.7409557d-10 /
      data fpppp(30, 6,12,1),fpppp(30, 6,12,2),fpppp(30, 6,12,3)/
     x-5.9884927d-09,-1.6552820d-08, 9.2915965d-11 /
      data fpppp(30, 6,13,1),fpppp(30, 6,13,2),fpppp(30, 6,13,3)/
     x 9.8467240d-09,-2.7938334d-08,-4.5569125d-11 /
      data fpppp(30, 6,14,1),fpppp(30, 6,14,2),fpppp(30, 6,14,3)/
     x 2.1289380d-08, 1.9752682d-09,-3.1825248d-13 /
      data fpppp(30, 6,15,1),fpppp(30, 6,15,2),fpppp(30, 6,15,3)/
     x 1.5191019d-08,-1.1073037d-08, 1.0305616d-10 /
      data fpppp(30, 6,16,1),fpppp(30, 6,16,2),fpppp(30, 6,16,3)/
     x-1.3135495d-08,-2.7057442d-08,-1.3828225d-10 /
      data fpppp(30, 6,17,1),fpppp(30, 6,17,2),fpppp(30, 6,17,3)/
     x-2.7994394d-08,-4.6060841d-09, 8.7056349d-11 /
      data fpppp(30, 6,18,1),fpppp(30, 6,18,2),fpppp(30, 6,18,3)/
     x-6.6657161d-08, 3.0592014d-09, 2.1144798d-12 /
      data fpppp(30, 6,19,1),fpppp(30, 6,19,2),fpppp(30, 6,19,3)/
     x-9.3758023d-08, 2.5696511d-08,-4.4751736d-12 /
      data fpppp(30, 6,20,1),fpppp(30, 6,20,2),fpppp(30, 6,20,3)/
     x-1.0498801d-07, 2.5977116d-08,-1.8696651d-11 /
      data fpppp(30, 6,21,1),fpppp(30, 6,21,2),fpppp(30, 6,21,3)/
     x-1.0498801d-07, 2.7045456d-08,-1.8694419d-11 /
      data fpppp(30, 6,22,1),fpppp(30, 6,22,2),fpppp(30, 6,22,3)/
     x-9.3758023d-08, 2.1423152d-08,-4.4841045d-12 /
      data fpppp(30, 6,23,1),fpppp(30, 6,23,2),fpppp(30, 6,23,3)/
     x-6.6657161d-08, 1.9084300d-08, 2.1479708d-12 /
      data fpppp(30, 7, 1,1),fpppp(30, 7, 1,2),fpppp(30, 7, 1,3)/
     x 4.0297149d-08, 1.8408873d-08,-2.8507933d-11 /
      data fpppp(30, 7, 2,1),fpppp(30, 7, 2,2),fpppp(30, 7, 2,3)/
     x-3.1061447d-08, 9.0061207d-09,-1.7637513d-11 /
      data fpppp(30, 7, 3,1),fpppp(30, 7, 3,2),fpppp(30, 7, 3,3)/
     x-8.1079728d-08,-1.1044142d-08, 3.8013812d-12 /
      data fpppp(30, 7, 4,1),fpppp(30, 7, 4,2),fpppp(30, 7, 4,3)/
     x-8.1079728d-08,-1.1216502d-08, 7.0473909d-12 /
      data fpppp(30, 7, 5,1),fpppp(30, 7, 5,2),fpppp(30, 7, 5,3)/
     x-3.1061447d-08, 9.6955581d-09,-3.0621552d-11 /
      data fpppp(30, 7, 6,1),fpppp(30, 7, 6,2),fpppp(30, 7, 6,3)/
     x 4.0297149d-08, 1.5823483d-08, 2.0182212d-11 /
      data fpppp(30, 7, 7,1),fpppp(30, 7, 7,2),fpppp(30, 7, 7,3)/
     x 7.0316692d-08, 2.4263857d-08,-7.4055991d-12 /
      data fpppp(30, 7, 8,1),fpppp(30, 7, 8,2),fpppp(30, 7, 8,3)/
     x 6.6800188d-08,-4.6457887d-09, 3.2754783d-11 /
      data fpppp(30, 7, 9,1),fpppp(30, 7, 9,2),fpppp(30, 7, 9,3)/
     x 7.0667069d-08, 1.3754610d-08, 6.3511211d-11 /
      data fpppp(30, 7,10,1),fpppp(30, 7,10,2),fpppp(30, 7,10,3)/
     x 3.5492530d-08,-1.1822807d-08,-2.2420557d-10 /
      data fpppp(30, 7,11,1),fpppp(30, 7,11,2),fpppp(30, 7,11,3)/
     x 3.4296549d-08,-1.3718678d-08, 2.5606560d-10 /
      data fpppp(30, 7,12,1),fpppp(30, 7,12,2),fpppp(30, 7,12,3)/
     x 2.2196146d-08,-1.2454994d-08,-1.9522144d-10 /
      data fpppp(30, 7,13,1),fpppp(30, 7,13,2),fpppp(30, 7,13,3)/
     x 2.0059288d-08,-2.7919702d-08, 1.2346416d-10 /
      data fpppp(30, 7,14,1),fpppp(30, 7,14,2),fpppp(30, 7,14,3)/
     x 3.2668291d-08,-5.0166876d-09,-5.3452749d-11 /
      data fpppp(30, 7,15,1),fpppp(30, 7,15,2),fpppp(30, 7,15,3)/
     x 5.9752419d-08, 1.2302151d-09,-7.5855222d-11 /
      data fpppp(30, 7,16,1),fpppp(30, 7,16,2),fpppp(30, 7,16,3)/
     x 7.4628487d-08,-6.7135667d-09, 1.4553054d-10 /
      data fpppp(30, 7,17,1),fpppp(30, 7,17,2),fpppp(30, 7,17,3)/
     x 6.1751872d-08, 1.9894792d-09,-6.5561742d-11 /
      data fpppp(30, 7,18,1),fpppp(30, 7,18,2),fpppp(30, 7,18,3)/
     x 3.1351686d-08, 1.7124397d-08,-3.9056648d-11 /
      data fpppp(30, 7,19,1),fpppp(30, 7,19,2),fpppp(30, 7,19,3)/
     x-1.3119157d-08, 1.9891887d-08, 4.4623093d-11 /
      data fpppp(30, 7,20,1),fpppp(30, 7,20,2),fpppp(30, 7,20,3)/
     x-6.1589103d-08,-3.2859303d-09,-3.9485653d-12 /
      data fpppp(30, 7,21,1),fpppp(30, 7,21,2),fpppp(30, 7,21,3)/
     x-6.1589103d-08,-2.6411295d-09, 1.0995287d-12 /
      data fpppp(30, 7,22,1),fpppp(30, 7,22,2),fpppp(30, 7,22,3)/
     x-1.3119157d-08, 1.7312684d-08, 2.4430717d-11 /
      data fpppp(30, 7,23,1),fpppp(30, 7,23,2),fpppp(30, 7,23,3)/
     x 3.1351686d-08, 2.6796410d-08, 3.6664763d-11 /
      data fpppp(30, 8, 1,1),fpppp(30, 8, 1,2),fpppp(30, 8, 1,3)/
     x 1.1677809d-08,-1.6823803d-09,-1.3220228d-12 /
      data fpppp(30, 8, 2,1),fpppp(30, 8, 2,2),fpppp(30, 8, 2,3)/
     x 6.5410175d-09,-3.9217080d-09, 1.8204629d-12 /
      data fpppp(30, 8, 3,1),fpppp(30, 8, 3,2),fpppp(30, 8, 3,3)/
     x 2.6386728d-08,-9.1220233d-09, 4.8645985d-12 /
      data fpppp(30, 8, 4,1),fpppp(30, 8, 4,2),fpppp(30, 8, 4,3)/
     x 2.6386728d-08,-8.4189507d-09, 1.1321683d-11 /
      data fpppp(30, 8, 5,1),fpppp(30, 8, 5,2),fpppp(30, 8, 5,3)/
     x 6.5410175d-09,-6.7339982d-09,-2.4007875d-11 /
      data fpppp(30, 8, 6,1),fpppp(30, 8, 6,2),fpppp(30, 8, 6,3)/
     x 1.1677809d-08, 8.8637079d-09, 9.5534243d-11 /
      data fpppp(30, 8, 7,1),fpppp(30, 8, 7,2),fpppp(30, 8, 7,3)/
     x 4.2028798d-08, 1.8120357d-08,-8.2616113d-11 /
      data fpppp(30, 8, 8,1),fpppp(30, 8, 8,2),fpppp(30, 8, 8,3)/
     x 4.9380896d-08, 1.3414781d-08,-2.5197255d-11 /
      data fpppp(30, 8, 9,1),fpppp(30, 8, 9,2),fpppp(30, 8, 9,3)/
     x 2.8943307d-08,-8.3088897d-09,-2.5982692d-11 /
      data fpppp(30, 8,10,1),fpppp(30, 8,10,2),fpppp(30, 8,10,3)/
     x 5.0209962d-08, 1.8992250d-08, 1.6567931d-10 /
      data fpppp(30, 8,11,1),fpppp(30, 8,11,2),fpppp(30, 8,11,3)/
     x 3.3547116d-08,-2.9762044d-08,-2.1634097d-10 /
      data fpppp(30, 8,12,1),fpppp(30, 8,12,2),fpppp(30, 8,12,3)/
     x 4.0490736d-08, 9.8518267d-09, 1.6664236d-10 /
      data fpppp(30, 8,13,1),fpppp(30, 8,13,2),fpppp(30, 8,13,3)/
     x 4.2955038d-08,-2.3588731d-08,-7.6803555d-11 /
      data fpppp(30, 8,14,1),fpppp(30, 8,14,2),fpppp(30, 8,14,3)/
     x 3.9804350d-08, 1.5088955d-09,-3.0479067d-11 /
      data fpppp(30, 8,15,1),fpppp(30, 8,15,2),fpppp(30, 8,15,3)/
     x 3.6210108d-08,-4.9330947d-09, 8.7314044d-11 /
      data fpppp(30, 8,16,1),fpppp(30, 8,16,2),fpppp(30, 8,16,3)/
     x 2.7655258d-08,-2.0419877d-09,-1.0702886d-10 /
      data fpppp(30, 8,17,1),fpppp(30, 8,17,2),fpppp(30, 8,17,3)/
     x 2.2298440d-08,-4.6042980d-09, 2.0997098d-11 /
      data fpppp(30, 8,18,1),fpppp(30, 8,18,2),fpppp(30, 8,18,3)/
     x 3.2970148d-08, 2.1749629d-08, 7.4075147d-11 /
      data fpppp(30, 8,19,1),fpppp(30, 8,19,2),fpppp(30, 8,19,3)/
     x 2.9509399d-08, 6.1832745d-09,-5.9675818d-11 /
      data fpppp(30, 8,20,1),fpppp(30, 8,20,2),fpppp(30, 8,20,3)/
     x 1.3883112d-08,-3.7841271d-09, 1.7162350d-11 /
      data fpppp(30, 8,21,1),fpppp(30, 8,21,2),fpppp(30, 8,21,3)/
     x 1.3883112d-08,-4.3022395d-09, 9.1113006d-12 /
      data fpppp(30, 8,22,1),fpppp(30, 8,22,2),fpppp(30, 8,22,3)/
     x 2.9509399d-08, 8.2557240d-09,-2.7471620d-11 /
      data fpppp(30, 8,23,1),fpppp(30, 8,23,2),fpppp(30, 8,23,3)/
     x 3.2970148d-08, 1.3977944d-08,-4.6690596d-11 /
      data fpppp(30, 9, 1,1),fpppp(30, 9, 1,2),fpppp(30, 9, 1,3)/
     x 8.1097570d-09, 9.1935389d-09, 5.3043661d-12 /
      data fpppp(30, 9, 2,1),fpppp(30, 9, 2,2),fpppp(30, 9, 2,3)/
     x 1.5000501d-08, 2.5313356d-09, 7.3389781d-12 /
      data fpppp(30, 9, 3,1),fpppp(30, 9, 3,2),fpppp(30, 9, 3,3)/
     x 4.7857072d-09,-1.1525780d-08, 1.7298616d-11 /
      data fpppp(30, 9, 4,1),fpppp(30, 9, 4,2),fpppp(30, 9, 4,3)/
     x 4.7857072d-09,-1.1909090d-08, 7.4990446d-12 /
      data fpppp(30, 9, 5,1),fpppp(30, 9, 5,2),fpppp(30, 9, 5,3)/
     x 1.5000501d-08, 4.0645743d-09, 4.6537265d-11 /
      data fpppp(30, 9, 6,1),fpppp(30, 9, 6,2),fpppp(30, 9, 6,3)/
     x 8.1097570d-09, 3.4438938d-09,-1.4168921d-10 /
      data fpppp(30, 9, 7,1),fpppp(30, 9, 7,2),fpppp(30, 9, 7,3)/
     x-3.3906438d-08, 2.9811699d-09, 9.5465947d-11 /
      data fpppp(30, 9, 8,1),fpppp(30, 9, 8,2),fpppp(30, 9, 8,3)/
     x-1.3720514d-08, 2.5886530d-09, 5.7020690d-11 /
      data fpppp(30, 9, 9,1),fpppp(30, 9, 9,2),fpppp(30, 9, 9,3)/
     x 2.7787079d-08, 1.1716391d-08,-3.3122146d-11 /
      data fpppp(30, 9,10,1),fpppp(30, 9,10,2),fpppp(30, 9,10,3)/
     x 3.5419536d-08, 4.2393038d-09,-1.3333129d-10 /
      data fpppp(30, 9,11,1),fpppp(30, 9,11,2),fpppp(30, 9,11,3)/
     x 5.5480835d-08,-1.0932778d-08, 1.8211855d-10 /
      data fpppp(30, 9,12,1),fpppp(30, 9,12,2),fpppp(30, 9,12,3)/
     x 6.6730334d-08, 1.2945766d-08,-1.4780942d-10 /
      data fpppp(30, 9,13,1),fpppp(30, 9,13,2),fpppp(30, 9,13,3)/
     x 4.7290112d-08,-1.5922316d-08, 3.6775465d-11 /
      data fpppp(30, 9,14,1),fpppp(30, 9,14,2),fpppp(30, 9,14,3)/
     x 3.0452431d-08, 8.7940279d-09, 7.9728826d-11 /
      data fpppp(30, 9,15,1),fpppp(30, 9,15,2),fpppp(30, 9,15,3)/
     x 7.1653688d-09,-1.1218517d-08,-1.0386559d-10 /
      data fpppp(30, 9,16,1),fpppp(30, 9,16,2),fpppp(30, 9,16,3)/
     x 9.1929622d-09,-4.3773431d-09, 6.0083633d-11 /
      data fpppp(30, 9,17,1),fpppp(30, 9,17,2),fpppp(30, 9,17,3)/
     x 1.0850297d-08, 1.6209591d-09,-1.7957009d-11 /
      data fpppp(30, 9,18,1),fpppp(30, 9,18,2),fpppp(30, 9,18,3)/
     x-5.9448444d-09, 1.0243717d-08,-3.6621246d-11 /
      data fpppp(30, 9,19,1),fpppp(30, 9,19,2),fpppp(30, 9,19,3)/
     x-6.5839336d-09,-1.0264231d-08, 3.1119769d-11 /
      data fpppp(30, 9,20,1),fpppp(30, 9,20,2),fpppp(30, 9,20,3)/
     x 2.8136174d-08, 5.5023387d-09, 6.5181101d-12 /
      data fpppp(30, 9,21,1),fpppp(30, 9,21,2),fpppp(30, 9,21,3)/
     x 2.8136174d-08, 4.1796007d-09, 1.0278638d-11 /
      data fpppp(30, 9,22,1),fpppp(30, 9,22,2),fpppp(30, 9,22,3)/
     x-6.5839336d-09,-4.9732791d-09, 1.6077657d-11 /
      data fpppp(30, 9,23,1),fpppp(30, 9,23,2),fpppp(30, 9,23,3)/
     x-5.9448444d-09,-9.5973531d-09, 1.9786673d-11 /
      data fpppp(30,10, 1,1),fpppp(30,10, 1,2),fpppp(30,10, 1,3)/
     x-8.7228633d-09, 4.0195216d-09, 5.5099427d-11 /
      data fpppp(30,10, 2,1),fpppp(30,10, 2,2),fpppp(30,10, 2,3)/
     x-2.2992848d-09,-7.4665488d-10, 2.8833887d-11 /
      data fpppp(30,10, 3,1),fpppp(30,10, 3,2),fpppp(30,10, 3,3)/
     x-3.3151865d-09,-9.8345927d-09,-2.9094981d-11 /
      data fpppp(30,10, 4,1),fpppp(30,10, 4,2),fpppp(30,10, 4,3)/
     x-3.3151865d-09,-1.1803863d-08,-2.6215241d-11 /
      data fpppp(30,10, 5,1),fpppp(30,10, 5,2),fpppp(30,10, 5,3)/
     x-2.2992848d-09, 7.1304273d-09, 1.7314925d-11 /
      data fpppp(30,10, 6,1),fpppp(30,10, 6,2),fpppp(30,10, 6,3)/
     x-8.7228633d-09,-2.5519536d-08, 9.8295532d-11 /
      data fpppp(30,10, 7,1),fpppp(30,10, 7,2),fpppp(30,10, 7,3)/
     x 3.9607480d-08, 2.9215482d-08,-6.6995512d-11 /
      data fpppp(30,10, 8,1),fpppp(30,10, 8,2),fpppp(30,10, 8,3)/
     x 1.2921004d-08, 6.0490517d-10,-3.8967078d-11 /
      data fpppp(30,10, 9,1),fpppp(30,10, 9,2),fpppp(30,10, 9,3)/
     x-1.4379508d-08, 1.1881609d-08,-9.4545882d-12 /
      data fpppp(30,10,10,1),fpppp(30,10,10,2),fpppp(30,10,10,3)/
     x-8.5747490d-09,-6.0680755d-10, 1.5543089d-10 /
      data fpppp(30,10,11,1),fpppp(30,10,11,2),fpppp(30,10,11,3)/
     x 9.7512263d-10, 3.6601943d-09,-2.1534751d-10 /
      data fpppp(30,10,12,1),fpppp(30,10,12,2),fpppp(30,10,12,3)/
     x-7.1880145d-09,-6.2757000d-09, 1.6966739d-10 /
      data fpppp(30,10,13,1),fpppp(30,10,13,2),fpppp(30,10,13,3)/
     x 2.1640803d-08,-5.0042328d-09,-6.7372343d-11 /
      data fpppp(30,10,14,1),fpppp(30,10,14,2),fpppp(30,10,14,3)/
     x 2.3911573d-08, 3.6250119d-09,-4.5212172d-11 /
      data fpppp(30,10,15,1),fpppp(30,10,15,2),fpppp(30,10,15,3)/
     x 2.5232722d-08, 1.8702913d-09, 7.2326099d-11 /
      data fpppp(30,10,16,1),fpppp(30,10,16,2),fpppp(30,10,16,3)/
     x-2.6481662d-09,-4.6594948d-09,-7.3240824d-11 /
      data fpppp(30,10,17,1),fpppp(30,10,17,2),fpppp(30,10,17,3)/
     x-1.8291727d-08,-5.7865066d-09, 6.6393763d-11 /
      data fpppp(30,10,18,1),fpppp(30,10,18,2),fpppp(30,10,18,3)/
     x-1.9503713d-08, 7.8656912d-09,-4.9906307d-11 /
      data fpppp(30,10,19,1),fpppp(30,10,19,2),fpppp(30,10,19,3)/
     x-1.9266821d-08, 2.3500642d-09, 4.8898503d-11 /
      data fpppp(30,10,20,1),fpppp(30,10,20,2),fpppp(30,10,20,3)/
     x-3.9880291d-08,-2.1653977d-09,-1.5725689d-11 /
      data fpppp(30,10,21,1),fpppp(30,10,21,2),fpppp(30,10,21,3)/
     x-3.9880291d-08,-2.3271893d-09,-9.6040385d-12 /
      data fpppp(30,10,22,1),fpppp(30,10,22,2),fpppp(30,10,22,3)/
     x-1.9266821d-08, 2.9972310d-09, 2.4411902d-11 /
      data fpppp(30,10,23,1),fpppp(30,10,23,2),fpppp(30,10,23,3)/
     x-1.9503713d-08, 5.4388160d-09, 4.1918448d-11 /
      data fpppp(30,11, 1,1),fpppp(30,11, 1,2),fpppp(30,11, 1,3)/
     x 7.1138665d-09,-1.5065662d-08,-9.6406824d-11 /
      data fpppp(30,11, 2,1),fpppp(30,11, 2,2),fpppp(30,11, 2,3)/
     x-4.4130015d-09,-1.1839859d-08,-5.1265028d-11 /
      data fpppp(30,11, 3,1),fpppp(30,11, 3,2),fpppp(30,11, 3,3)/
     x-1.1782497d-08,-5.6774687d-09, 4.4148072d-11 /
      data fpppp(30,11, 4,1),fpppp(30,11, 4,2),fpppp(30,11, 4,3)/
     x-1.1782497d-08,-4.3648906d-09, 4.6456879d-11 /
      data fpppp(30,11, 5,1),fpppp(30,11, 5,2),fpppp(30,11, 5,3)/
     x-4.4130015d-09,-1.7090171d-08,-6.0500256d-11 /
      data fpppp(30,11, 6,1),fpppp(30,11, 6,2),fpppp(30,11, 6,3)/
     x 7.1138665d-09, 4.6230084d-09,-6.1774722d-11 /
      data fpppp(30,11, 7,1),fpppp(30,11, 7,2),fpppp(30,11, 7,3)/
     x-1.8017503d-08,-6.4556540d-09, 7.8346607d-11 /
      data fpppp(30,11, 8,1),fpppp(30,11, 8,2),fpppp(30,11, 8,3)/
     x 1.9533763d-08, 1.1954450d-08,-7.4192593d-11 /
      data fpppp(30,11, 9,1),fpppp(30,11, 9,2),fpppp(30,11, 9,3)/
     x 3.9572215d-08, 2.1971818d-08, 1.3727085d-10 /
      data fpppp(30,11,10,1),fpppp(30,11,10,2),fpppp(30,11,10,3)/
     x 2.3300763d-08, 3.7498650d-09,-2.2067345d-10 /
      data fpppp(30,11,11,1),fpppp(30,11,11,2),fpppp(30,11,11,3)/
     x 2.0693010d-09,-6.0336747d-09, 2.6206593d-10 /
      data fpppp(30,11,12,1),fpppp(30,11,12,2),fpppp(30,11,12,3)/
     x 5.9017400d-09, 7.8474824d-09,-2.0975667d-10 /
      data fpppp(30,11,13,1),fpppp(30,11,13,2),fpppp(30,11,13,3)/
     x-2.3856972d-08,-1.9490956d-08, 8.5505654d-11 /
      data fpppp(30,11,14,1),fpppp(30,11,14,2),fpppp(30,11,14,3)/
     x-1.2028063d-08, 4.6885452d-09, 8.8494195d-12 /
      data fpppp(30,11,15,1),fpppp(30,11,15,2),fpppp(30,11,15,3)/
     x-1.1409101d-08,-6.0241043d-09,-2.9148784d-11 /
      data fpppp(30,11,16,1),fpppp(30,11,16,2),fpppp(30,11,16,3)/
     x 1.2011739d-08, 4.0670060d-09, 5.9990029d-11 /
      data fpppp(30,11,17,1),fpppp(30,11,17,2),fpppp(30,11,17,3)/
     x 1.1701899d-08,-3.3970095d-09,-7.2349527d-11 /
      data fpppp(30,11,18,1),fpppp(30,11,18,2),fpppp(30,11,18,3)/
     x 2.3169289d-08, 8.3422200d-09, 6.8062052d-11 /
      data fpppp(30,11,19,1),fpppp(30,11,19,2),fpppp(30,11,19,3)/
     x 2.0976755d-08, 2.0408136d-09,-8.9244602d-11 /
      data fpppp(30,11,20,1),fpppp(30,11,20,2),fpppp(30,11,20,3)/
     x 2.5324932d-08,-2.4950427d-09, 3.4692347d-11 /
      data fpppp(30,11,21,1),fpppp(30,11,21,2),fpppp(30,11,21,3)/
     x 2.5324932d-08,-2.6936823d-09, 2.4479820d-11 /
      data fpppp(30,11,22,1),fpppp(30,11,22,2),fpppp(30,11,22,3)/
     x 2.0976755d-08, 2.8353718d-09,-4.8394495d-11 /
      data fpppp(30,11,23,1),fpppp(30,11,23,2),fpppp(30,11,23,3)/
     x 2.3169289d-08, 5.3626266d-09,-8.5125849d-11 /
      data fpppp(30,12, 1,1),fpppp(30,12, 1,2),fpppp(30,12, 1,3)/
     x-9.8249957d-09,-2.6779268d-08, 7.1207904d-11 /
      data fpppp(30,12, 2,1),fpppp(30,12, 2,2),fpppp(30,12, 2,3)/
     x-7.1047950d-09,-1.8034656d-08, 3.4866154d-11 /
      data fpppp(30,12, 3,1),fpppp(30,12, 3,2),fpppp(30,12, 3,3)/
     x 1.4573227d-08,-3.3772181d-10,-4.2737052d-11 /
      data fpppp(30,12, 4,1),fpppp(30,12, 4,2),fpppp(30,12, 4,3)/
     x 1.4573227d-08, 1.4849397d-09,-4.3213003d-11 /
      data fpppp(30,12, 5,1),fpppp(30,12, 5,2),fpppp(30,12, 5,3)/
     x-7.1047950d-09,-2.5325302d-08, 3.6769958d-11 /
      data fpppp(30,12, 6,1),fpppp(30,12, 6,2),fpppp(30,12, 6,3)/
     x-9.8249957d-09, 5.6065537d-10, 6.4068641d-11 /
      data fpppp(30,12, 7,1),fpppp(30,12, 7,2),fpppp(30,12, 7,3)/
     x 8.9275914d-09, 8.3010941d-09,-7.9535924d-11 /
      data fpppp(30,12, 8,1),fpppp(30,12, 8,2),fpppp(30,12, 8,3)/
     x-3.4183305d-09, 4.1256741d-10, 1.1305220d-10 /
      data fpppp(30,12, 9,1),fpppp(30,12, 9,2),fpppp(30,12, 9,3)/
     x-4.9364075d-09, 1.3362408d-08,-1.7574280d-10 /
      data fpppp(30,12,10,1),fpppp(30,12,10,2),fpppp(30,12,10,3)/
     x 1.1076511d-09, 1.2242337d-09, 2.1440408d-10 /
      data fpppp(30,12,11,1),fpppp(30,12,11,2),fpppp(30,12,11,3)/
     x 5.2003029d-09, 1.2454957d-08,-2.2536685d-10 /
      data fpppp(30,12,12,1),fpppp(30,12,12,2),fpppp(30,12,12,3)/
     x-3.0741266d-09,-1.3701521d-08, 1.9202071d-10 /
      data fpppp(30,12,13,1),fpppp(30,12,13,2),fpppp(30,12,13,3)/
     x 1.1218970d-08, 5.7234399d-09,-5.2845298d-11 /
      data fpppp(30,12,14,1),fpppp(30,12,14,2),fpppp(30,12,14,3)/
     x-1.0093806d-08,-1.3193643d-08,-4.0066825d-11 /
      data fpppp(30,12,15,1),fpppp(30,12,15,2),fpppp(30,12,15,3)/
     x 1.7502770d-09, 9.5307152d-09, 2.1989337d-11 /
      data fpppp(30,12,16,1),fpppp(30,12,16,2),fpppp(30,12,16,3)/
     x-4.6269597d-10,-1.4109216d-08,-2.7719178d-11 /
      data fpppp(30,12,17,1),fpppp(30,12,17,2),fpppp(30,12,17,3)/
     x 1.4483316d-08, 1.7627759d-08, 4.9283592d-11 /
      data fpppp(30,12,18,1),fpppp(30,12,18,2),fpppp(30,12,18,3)/
     x 6.3420356d-10,-6.0742429d-09,-2.6458998d-11 /
      data fpppp(30,12,19,1),fpppp(30,12,19,2),fpppp(30,12,19,3)/
     x 4.7579867d-09, 7.4503322d-09, 5.8269044d-11 /
      data fpppp(30,12,20,1),fpppp(30,12,20,2),fpppp(30,12,20,3)/
     x 1.0267098d-08,-4.1089619d-09,-3.9683160d-11 /
      data fpppp(30,12,21,1),fpppp(30,12,21,2),fpppp(30,12,21,3)/
     x 1.0267098d-08,-3.2109122d-09,-3.3491432d-11 /
      data fpppp(30,12,22,1),fpppp(30,12,22,2),fpppp(30,12,22,3)/
     x 4.7579867d-09, 3.8581336d-09, 3.3502132d-11 /
      data fpppp(30,12,23,1),fpppp(30,12,23,2),fpppp(30,12,23,3)/
     x 6.3420356d-10, 7.3965016d-09, 6.6416923d-11 /
      data fpppp(30,13, 1,1),fpppp(30,13, 1,2),fpppp(30,13, 1,3)/
     x 9.2475421d-09,-1.7494391d-08,-3.1112728d-11 /
      data fpppp(30,13, 2,1),fpppp(30,13, 2,2),fpppp(30,13, 2,3)/
     x 4.3332304d-09,-1.2584727d-08,-1.2823717d-11 /
      data fpppp(30,13, 3,1),fpppp(30,13, 3,2),fpppp(30,13, 3,3)/
     x-2.1040554d-08,-3.0461734d-09, 2.7984585d-11 /
      data fpppp(30,13, 4,1),fpppp(30,13, 4,2),fpppp(30,13, 4,3)/
     x-2.1040554d-08,-1.3274013d-09, 2.5153850d-11 /
      data fpppp(30,13, 5,1),fpppp(30,13, 5,2),fpppp(30,13, 5,3)/
     x 4.3332304d-09,-1.9459816d-08,-1.5007771d-12 /
      data fpppp(30,13, 6,1),fpppp(30,13, 6,2),fpppp(30,13, 6,3)/
     x 9.2475421d-09, 8.2871911d-09,-7.3573752d-11 /
      data fpppp(30,13, 7,1),fpppp(30,13, 7,2),fpppp(30,13, 7,3)/
     x 5.1248951d-09, 1.9976254d-09, 3.1013929d-11 /
      data fpppp(30,13, 8,1),fpppp(30,13, 8,2),fpppp(30,13, 8,3)/
     x 1.3231550d-09,-6.7830634d-11,-2.3809635d-11 /
      data fpppp(30,13, 9,1),fpppp(30,13, 9,2),fpppp(30,13, 9,3)/
     x-6.3818514d-09, 3.4625757d-09, 7.7657273d-11 /
      data fpppp(30,13,10,1),fpppp(30,13,10,2),fpppp(30,13,10,3)/
     x 5.8985245d-10, 1.4141535d-09,-1.1897721d-10 /
      data fpppp(30,13,11,1),fpppp(30,13,11,2),fpppp(30,13,11,3)/
     x 9.2939133d-09, 1.0338526d-08, 1.3558187d-10 /
      data fpppp(30,13,12,1),fpppp(30,13,12,2),fpppp(30,13,12,3)/
     x-4.7410700d-09,-2.6892917d-09,-1.4101340d-10 /
      data fpppp(30,13,13,1),fpppp(30,13,13,2),fpppp(30,13,13,3)/
     x-3.1750317d-09,-6.4220582d-09, 4.0444098d-11 /
      data fpppp(30,13,14,1),fpppp(30,13,14,2),fpppp(30,13,14,3)/
     x 1.8574307d-08, 5.1499402d-09, 7.5830879d-11 /
      data fpppp(30,13,15,1),fpppp(30,13,15,2),fpppp(30,13,15,3)/
     x 5.4182762d-09, 4.0544627d-09,-3.1029111d-11 /
      data fpppp(30,13,16,1),fpppp(30,13,16,2),fpppp(30,13,16,3)/
     x 8.0609901d-10,-9.2694128d-09, 1.5355878d-11 /
      data fpppp(30,13,17,1),fpppp(30,13,17,2),fpppp(30,13,17,3)/
     x-9.0254152d-09, 7.3054227d-09,-1.0441066d-11 /
      data fpppp(30,13,18,1),fpppp(30,13,18,2),fpppp(30,13,18,3)/
     x 3.6104443d-09, 9.4579642d-10,-2.4070357d-11 /
      data fpppp(30,13,19,1),fpppp(30,13,19,2),fpppp(30,13,19,3)/
     x 6.1835823d-09, 6.6298835d-09,-1.0798172d-11 /
      data fpppp(30,13,20,1),fpppp(30,13,20,2),fpppp(30,13,20,3)/
     x-7.2843244d-09,-6.1985367d-09, 1.3750972d-11 /
      data fpppp(30,13,21,1),fpppp(30,13,21,2),fpppp(30,13,21,3)/
     x-7.2843244d-09,-5.6445486d-09, 1.3837171d-11 /
      data fpppp(30,13,22,1),fpppp(30,13,22,2),fpppp(30,13,22,3)/
     x 6.1835823d-09, 4.4139310d-09,-1.1142966d-11 /
      data fpppp(30,13,23,1),fpppp(30,13,23,2),fpppp(30,13,23,3)/
     x 3.6104443d-09, 9.2556184d-09,-2.2777377d-11 /
      data fpppp(30,14, 1,1),fpppp(30,14, 1,2),fpppp(30,14, 1,3)/
     x-6.8259765d-09,-2.6853488d-08, 2.5908570d-11 /
      data fpppp(30,14, 2,1),fpppp(30,14, 2,2),fpppp(30,14, 2,3)/
     x-8.4758608d-09,-1.6718630d-08, 1.1097591d-11 /
      data fpppp(30,14, 3,1),fpppp(30,14, 3,2),fpppp(30,14, 3,3)/
     x 5.0009174d-09, 3.4712671d-09,-2.0542362d-11 /
      data fpppp(30,14, 4,1),fpppp(30,14, 4,2),fpppp(30,14, 4,3)/
     x 5.0009174d-09, 6.1446657d-09,-2.0713612d-11 /
      data fpppp(30,14, 5,1),fpppp(30,14, 5,2),fpppp(30,14, 5,3)/
     x-8.4758608d-09,-2.7412224d-08, 1.1782593d-11 /
      data fpppp(30,14, 6,1),fpppp(30,14, 6,2),fpppp(30,14, 6,3)/
     x-6.8259765d-09, 1.3247491d-08, 2.3339814d-11 /
      data fpppp(30,14, 7,1),fpppp(30,14, 7,2),fpppp(30,14, 7,3)/
     x-1.9019644d-08,-7.9416034d-09, 2.0476977d-11 /
      data fpppp(30,14, 8,1),fpppp(30,14, 8,2),fpppp(30,14, 8,3)/
     x-1.9443118d-08,-1.2836403d-09,-7.0914178d-11 /
      data fpppp(30,14, 9,1),fpppp(30,14, 9,2),fpppp(30,14, 9,3)/
     x-9.2789361d-09, 5.9425858d-09, 1.2519023d-11 /
      data fpppp(30,14,10,1),fpppp(30,14,10,2),fpppp(30,14,10,3)/
     x-1.2496975d-08, 5.7068712d-09, 8.4983981d-11 /
      data fpppp(30,14,11,1),fpppp(30,14,11,2),fpppp(30,14,11,3)/
     x-1.4570494d-08,-1.4446397d-08,-1.1828291d-10 /
      data fpppp(30,14,12,1),fpppp(30,14,12,2),fpppp(30,14,12,3)/
     x 1.3841400d-08, 2.2056264d-08, 1.1384273d-10 /
      data fpppp(30,14,13,1),fpppp(30,14,13,2),fpppp(30,14,13,3)/
     x 1.6432827d-09,-6.4707663d-09, 5.1518090d-12 /
      data fpppp(30,14,14,1),fpppp(30,14,14,2),fpppp(30,14,14,3)/
     x-1.7939306d-08,-8.8410580d-10,-1.0139814d-10 /
      data fpppp(30,14,15,1),fpppp(30,14,15,2),fpppp(30,14,15,3)/
     x-6.9748413d-09, 8.0743713d-09, 6.0610002d-11 /
      data fpppp(30,14,16,1),fpppp(30,14,16,2),fpppp(30,14,16,3)/
     x-8.3589694d-09,-1.0266858d-08,-2.9494463d-11 /
      data fpppp(30,14,17,1),fpppp(30,14,17,2),fpppp(30,14,17,3)/
     x-4.7545392d-09, 1.2106115d-08, 1.7158296d-11 /
      data fpppp(30,14,18,1),fpppp(30,14,18,2),fpppp(30,14,18,3)/
     x-1.4779247d-08, 7.5620055d-10, 1.9820053d-11 /
      data fpppp(30,14,19,1),fpppp(30,14,19,2),fpppp(30,14,19,3)/
     x-2.4815271d-08,-2.7643603d-09, 1.1927502d-11 /
      data fpppp(30,14,20,1),fpppp(30,14,20,2),fpppp(30,14,20,3)/
     x-8.4176765d-09,-3.1285283d-09,-2.0415797d-11 /
      data fpppp(30,14,21,1),fpppp(30,14,21,2),fpppp(30,14,21,3)/
     x-8.4176765d-09,-3.2875765d-09,-2.0073978d-11 /
      data fpppp(30,14,22,1),fpppp(30,14,22,2),fpppp(30,14,22,3)/
     x-2.4815271d-08,-2.1281674d-09, 1.0560226d-11 /
      data fpppp(30,14,23,1),fpppp(30,14,23,2),fpppp(30,14,23,3)/
     x-1.4779247d-08,-1.6295227d-09, 2.4947339d-11 /
      data fpppp(30,15, 1,1),fpppp(30,15, 1,2),fpppp(30,15, 1,3)/
     x-1.6570732d-08,-1.9381680d-08,-4.4883502d-11 /
      data fpppp(30,15, 2,1),fpppp(30,15, 2,2),fpppp(30,15, 2,3)/
     x-1.5421953d-08,-1.1513382d-08,-2.6842744d-11 /
      data fpppp(30,15, 3,1),fpppp(30,15, 3,2),fpppp(30,15, 3,3)/
     x-5.5256543d-09, 4.5958975d-09, 7.6511991d-12 /
      data fpppp(30,15, 4,1),fpppp(30,15, 4,2),fpppp(30,15, 4,3)/
     x-5.5256543d-09, 5.9107744d-09, 1.4939638d-11 /
      data fpppp(30,15, 5,1),fpppp(30,15, 5,2),fpppp(30,15, 5,3)/
     x-1.5421953d-08,-1.6772890d-08,-5.5996501d-11 /
      data fpppp(30,15, 6,1),fpppp(30,15, 6,2),fpppp(30,15, 6,3)/
     x-1.6570732d-08, 3.4147418d-10, 6.4443086d-11 /
      data fpppp(30,15, 7,1),fpppp(30,15, 7,2),fpppp(30,15, 7,3)/
     x 4.3184263d-09,-7.3805377d-09,-7.9469286d-11 /
      data fpppp(30,15, 8,1),fpppp(30,15, 8,2),fpppp(30,15, 8,3)/
     x 1.0432880d-08, 5.9926642d-09, 8.9427556d-11 /
      data fpppp(30,15, 9,1),fpppp(30,15, 9,2),fpppp(30,15, 9,3)/
     x 1.1168121d-08,-2.9780107d-09,-9.0307475d-12 /
      data fpppp(30,15,10,1),fpppp(30,15,10,2),fpppp(30,15,10,3)/
     x 9.3105131d-09, 5.6648785d-09,-1.1773040d-10 /
      data fpppp(30,15,11,1),fpppp(30,15,11,2),fpppp(30,15,11,3)/
     x 5.8096537d-09,-5.8246865d-09, 1.6593387d-10 /
      data fpppp(30,15,12,1),fpppp(30,15,12,2),fpppp(30,15,12,3)/
     x-7.5896072d-09, 6.8142005d-09,-9.1122281d-11 /
      data fpppp(30,15,13,1),fpppp(30,15,13,2),fpppp(30,15,13,3)/
     x 3.2012997d-09,-2.6244901d-09,-6.2376415d-11 /
      data fpppp(30,15,14,1),fpppp(30,15,14,2),fpppp(30,15,14,3)/
     x 1.6093692d-08, 1.0236431d-08, 1.1182676d-10 /
      data fpppp(30,15,15,1),fpppp(30,15,15,2),fpppp(30,15,15,3)/
     x 9.3509777d-10,-1.1871774d-09,-5.8346146d-11 /
      data fpppp(30,15,16,1),fpppp(30,15,16,2),fpppp(30,15,16,3)/
     x 9.2991209d-11,-1.8270877d-09, 6.8297883d-11 /
      data fpppp(30,15,17,1),fpppp(30,15,17,2),fpppp(30,15,17,3)/
     x-6.3820762d-11, 7.8595907d-09,-7.3960504d-11 /
      data fpppp(30,15,18,1),fpppp(30,15,18,2),fpppp(30,15,18,3)/
     x 1.5073600d-09,-3.0029283d-09, 4.2187778d-11 /
      data fpppp(30,15,19,1),fpppp(30,15,19,2),fpppp(30,15,19,3)/
     x 7.5669341d-09, 5.5471527d-09,-5.0733987d-11 /
      data fpppp(30,15,20,1),fpppp(30,15,20,2),fpppp(30,15,20,3)/
     x-1.5094579d-08,-6.3396737d-09, 2.5803188d-11 /
      data fpppp(30,15,21,1),fpppp(30,15,21,2),fpppp(30,15,21,3)/
     x-1.5094579d-08,-5.6704997d-09, 1.9696901d-11 /
      data fpppp(30,15,22,1),fpppp(30,15,22,2),fpppp(30,15,22,3)/
     x 7.5669341d-09, 2.8704565d-09,-2.6308839d-11 /
      data fpppp(30,15,23,1),fpppp(30,15,23,2),fpppp(30,15,23,3)/
     x 1.5073600d-09, 7.0346825d-09,-4.9406528d-11 /
      data fpppp(30,16, 1,1),fpppp(30,16, 1,2),fpppp(30,16, 1,3)/
     x 5.4574248d-09, 2.4735227d-09, 5.1276817d-11 /
      data fpppp(30,16, 2,1),fpppp(30,16, 2,2),fpppp(30,16, 2,3)/
     x 1.0661887d-08, 1.3442720d-09, 3.0970628d-11 /
      data fpppp(30,16, 3,1),fpppp(30,16, 3,2),fpppp(30,16, 3,3)/
     x 3.9978792d-09,-1.0242239d-09,-6.5027796d-12 /
      data fpppp(30,16, 4,1),fpppp(30,16, 4,2),fpppp(30,16, 4,3)/
     x 3.9978792d-09,-1.1140462d-09,-1.7072526d-11 /
      data fpppp(30,16, 5,1),fpppp(30,16, 5,2),fpppp(30,16, 5,3)/
     x 1.0661887d-08, 1.7035612d-09, 7.3249614d-11 /
      data fpppp(30,16, 6,1),fpppp(30,16, 6,2),fpppp(30,16, 6,3)/
     x 5.4574248d-09, 1.1261882d-09,-1.0726938d-10 /
      data fpppp(30,16, 7,1),fpppp(30,16, 7,2),fpppp(30,16, 7,3)/
     x-1.9244304d-08,-1.4608580d-08, 1.0098285d-10 /
      data fpppp(30,16, 8,1),fpppp(30,16, 8,2),fpppp(30,16, 8,3)/
     x-1.8101618d-08, 9.2504615d-09,-3.4969561d-11 /
      data fpppp(30,16, 9,1),fpppp(30,16, 9,2),fpppp(30,16, 9,3)/
     x-2.8484687d-08,-1.0490422d-08,-6.7284658d-11 /
      data fpppp(30,16,10,1),fpppp(30,16,10,2),fpppp(30,16,10,3)/
     x-1.3869231d-08, 5.2535572d-09, 1.3766563d-10 /
      data fpppp(30,16,11,1),fpppp(30,16,11,2),fpppp(30,16,11,3)/
     x-2.5760125d-10,-3.5661563d-09,-1.8147602d-10 /
      data fpppp(30,16,12,1),fpppp(30,16,12,2),fpppp(30,16,12,3)/
     x 9.0911294d-09, 4.0230962d-09, 1.2301213d-10 /
      data fpppp(30,16,13,1),fpppp(30,16,13,2),fpppp(30,16,13,3)/
     x 8.6338379d-09, 4.1257679d-09, 3.0914347d-11 /
      data fpppp(30,16,14,1),fpppp(30,16,14,2),fpppp(30,16,14,3)/
     x 7.4151427d-09,-2.4498504d-09,-8.4516622d-11 /
      data fpppp(30,16,15,1),fpppp(30,16,15,2),fpppp(30,16,15,3)/
     x 1.2517750d-08, 6.5389682d-09, 6.0644961d-11 /
      data fpppp(30,16,16,1),fpppp(30,16,16,2),fpppp(30,16,16,3)/
     x 1.2573023d-08, 2.3387474d-09,-5.6570865d-11 /
      data fpppp(30,16,17,1),fpppp(30,16,17,2),fpppp(30,16,17,3)/
     x 2.5943182d-09, 1.4168746d-09, 2.3085325d-12 /
      data fpppp(30,16,18,1),fpppp(30,16,18,2),fpppp(30,16,18,3)/
     x-3.4251014d-09, 3.5387626d-09, 9.8033877d-12 /
      data fpppp(30,16,19,1),fpppp(30,16,19,2),fpppp(30,16,19,3)/
     x-1.0038792d-08,-7.8004354d-09, 3.3885420d-11 /
      data fpppp(30,16,20,1),fpppp(30,16,20,2),fpppp(30,16,20,3)/
     x 6.0034240d-09, 9.8994188d-10,-1.2679404d-11 /
      data fpppp(30,16,21,1),fpppp(30,16,21,2),fpppp(30,16,21,3)/
     x 6.0034240d-09, 2.5696527d-10,-1.0504770d-11 /
      data fpppp(30,16,22,1),fpppp(30,16,22,2),fpppp(30,16,22,3)/
     x-1.0038792d-08,-4.8685289d-09, 2.5186885d-11 /
      data fpppp(30,16,23,1),fpppp(30,16,23,2),fpppp(30,16,23,3)/
     x-3.4251014d-09,-7.4558866d-09, 4.2422894d-11 /
      data fpppp(30,17, 1,1),fpppp(30,17, 1,2),fpppp(30,17, 1,3)/
     x-1.2587532d-08, 1.0427869d-08,-5.7577957d-11 /
      data fpppp(30,17, 2,1),fpppp(30,17, 2,2),fpppp(30,17, 2,3)/
     x-7.2177317d-09, 5.7484152d-09,-3.2331387d-11 /
      data fpppp(30,17, 3,1),fpppp(30,17, 3,2),fpppp(30,17, 3,3)/
     x-7.6429809d-09,-3.4508575d-09, 1.6880590d-11 /
      data fpppp(30,17, 4,1),fpppp(30,17, 4,2),fpppp(30,17, 4,3)/
     x-7.6429809d-09,-4.9000834d-09, 2.5434265d-11 /
      data fpppp(30,17, 5,1),fpppp(30,17, 5,2),fpppp(30,17, 5,3)/
     x-7.2177317d-09, 1.1545319d-08,-6.6546090d-11 /
      data fpppp(30,17, 6,1),fpppp(30,17, 6,2),fpppp(30,17, 6,3)/
     x-1.2587532d-08,-1.1310519d-08, 7.0727177d-11 /
      data fpppp(30,17, 7,1),fpppp(30,17, 7,2),fpppp(30,17, 7,3)/
     x 1.7736442d-09, 3.4636052d-09,-3.9288949d-11 /
      data fpppp(30,17, 8,1),fpppp(30,17, 8,2),fpppp(30,17, 8,3)/
     x-4.3739812d-09,-7.3770737d-09,-7.6334737d-11 /
      data fpppp(30,17, 9,1),fpppp(30,17, 9,2),fpppp(30,17, 9,3)/
     x 9.8606085d-09, 5.1382527d-09, 1.4013791d-10 /
      data fpppp(30,17,10,1),fpppp(30,17,10,2),fpppp(30,17,10,3)/
     x-3.5749719d-09, 1.8943030d-09,-1.1402083d-10 /
      data fpppp(30,17,11,1),fpppp(30,17,11,2),fpppp(30,17,11,3)/
     x-7.9173581d-09,-9.2223374d-09, 1.4235645d-10 /
      data fpppp(30,17,12,1),fpppp(30,17,12,2),fpppp(30,17,12,3)/
     x-1.5603522d-08, 5.5449922d-09,-1.2938249d-10 /
      data fpppp(30,17,13,1),fpppp(30,17,13,2),fpppp(30,17,13,3)/
     x-5.3952848d-09, 4.3992164d-09,-9.8421585d-12 /
      data fpppp(30,17,14,1),fpppp(30,17,14,2),fpppp(30,17,14,3)/
     x-9.5517606d-09,-8.8507353d-09, 1.0894073d-10 /
      data fpppp(30,17,15,1),fpppp(30,17,15,2),fpppp(30,17,15,3)/
     x 3.7176000d-09, 1.0260400d-08,-1.2647654d-10 /
      data fpppp(30,17,16,1),fpppp(30,17,16,2),fpppp(30,17,16,3)/
     x 4.8222539d-09,-1.7995188d-09, 4.4255933d-11 /
      data fpppp(30,17,17,1),fpppp(30,17,17,2),fpppp(30,17,17,3)/
     x 1.4491482d-08, 1.3092406d-09, 1.0188779d-10 /
      data fpppp(30,17,18,1),fpppp(30,17,18,2),fpppp(30,17,18,3)/
     x 1.9357574d-08, 5.8062220d-09,-1.1631736d-10 /
      data fpppp(30,17,19,1),fpppp(30,17,19,2),fpppp(30,17,19,3)/
     x 2.6673809d-08,-5.8247271d-09, 1.7695028d-11 /
      data fpppp(30,17,20,1),fpppp(30,17,20,2),fpppp(30,17,20,3)/
     x 2.2205521d-08, 1.4186197d-09, 9.8195733d-12 /
      data fpppp(30,17,21,1),fpppp(30,17,21,2),fpppp(30,17,21,3)/
     x 2.2205521d-08, 7.0606383d-10, 1.6355377d-11 /
      data fpppp(30,17,22,1),fpppp(30,17,22,2),fpppp(30,17,22,3)/
     x 2.6673809d-08,-2.9745035d-09,-8.4481881d-12 /
      data fpppp(30,17,23,1),fpppp(30,17,23,2),fpppp(30,17,23,3)/
     x 1.9357574d-08,-4.8821165d-09,-1.8280304d-11 /
      data fpppp(30,18, 1,1),fpppp(30,18, 1,2),fpppp(30,18, 1,3)/
     x-6.8340671d-11, 7.0735566d-09, 4.8923562d-11 /
      data fpppp(30,18, 2,1),fpppp(30,18, 2,2),fpppp(30,18, 2,3)/
     x-5.1111812d-09, 3.5070822d-09, 2.8577820d-11 /
      data fpppp(30,18, 3,1),fpppp(30,18, 3,2),fpppp(30,18, 3,3)/
     x-1.0963098d-08,-3.8446713d-09,-1.1799721d-11 /
      data fpppp(30,18, 4,1),fpppp(30,18, 4,2),fpppp(30,18, 4,3)/
     x-1.0963098d-08,-4.3533814d-09,-1.7435559d-11 /
      data fpppp(30,18, 5,1),fpppp(30,18, 5,2),fpppp(30,18, 5,3)/
     x-5.1111812d-09, 5.5419226d-09, 5.1121172d-11 /
      data fpppp(30,18, 6,1),fpppp(30,18, 6,2),fpppp(30,18, 6,3)/
     x-6.8340671d-11,-5.5709470d-10,-3.5614010d-11 /
      data fpppp(30,18, 7,1),fpppp(30,18, 7,2),fpppp(30,18, 7,3)/
     x-3.0365904d-09,-3.9640366d-09,-2.1147535d-12 /
      data fpppp(30,18, 8,1),fpppp(30,18, 8,2),fpppp(30,18, 8,3)/
     x 4.5968468d-10, 5.0783008d-09, 7.3433982d-11 /
      data fpppp(30,18, 9,1),fpppp(30,18, 9,2),fpppp(30,18, 9,3)/
     x-4.9134633d-09,-8.9312025d-09,-8.7481179d-11 /
      data fpppp(30,18,10,1),fpppp(30,18,10,2),fpppp(30,18,10,3)/
     x 1.9234910d-09, 1.4772603d-08, 4.2149000d-11 /
      data fpppp(30,18,11,1),fpppp(30,18,11,2),fpppp(30,18,11,3)/
     x-6.7463465d-10,-2.4196735d-08,-4.8660832d-11 /
      data fpppp(30,18,12,1),fpppp(30,18,12,2),fpppp(30,18,12,3)/
     x 1.1549481d-08, 2.5286430d-08, 3.3630766d-11 /
      data fpppp(30,18,13,1),fpppp(30,18,13,2),fpppp(30,18,13,3)/
     x 3.6373426d-09,-1.7251955d-08, 3.2713679d-11 /
      data fpppp(30,18,14,1),fpppp(30,18,14,2),fpppp(30,18,14,3)/
     x 1.0983992d-08, 1.1265849d-08,-8.7396797d-11 /
      data fpppp(30,18,15,1),fpppp(30,18,15,2),fpppp(30,18,15,3)/
     x 5.8550610d-09,-6.6143563d-09, 8.5603725d-11 /
      data fpppp(30,18,16,1),fpppp(30,18,16,2),fpppp(30,18,16,3)/
     x 1.0297593d-08, 5.7947961d-09,-2.5672539d-11 /
      data fpppp(30,18,17,1),fpppp(30,18,17,2),fpppp(30,18,17,3)/
     x 1.0241644d-08,-5.4066920d-09,-6.9323568d-11 /
      data fpppp(30,18,18,1),fpppp(30,18,18,2),fpppp(30,18,18,3)/
     x 1.4041064d-08, 1.1376404d-08, 7.8541169d-11 /
      data fpppp(30,18,19,1),fpppp(30,18,19,2),fpppp(30,18,19,3)/
     x 9.9891143d-09,-9.0966786d-09,-1.7502068d-11 /
      data fpppp(30,18,20,1),fpppp(30,18,20,2),fpppp(30,18,20,3)/
     x 1.3332228d-08, 2.4480896d-09, 1.6721548d-12 /
      data fpppp(30,18,21,1),fpppp(30,18,21,2),fpppp(30,18,21,3)/
     x 1.3332228d-08, 1.2205275d-09,-3.3116050d-12 /
      data fpppp(30,18,22,1),fpppp(30,18,22,2),fpppp(30,18,22,3)/
     x 9.9891143d-09,-4.1864302d-09, 2.4329713d-12 /
      data fpppp(30,18,23,1),fpppp(30,18,23,2),fpppp(30,18,23,3)/
     x 1.4041064d-08,-7.0370271d-09, 3.7847710d-12 /
      data fpppp(30,19, 1,1),fpppp(30,19, 1,2),fpppp(30,19, 1,3)/
     x 3.7182369d-09,-1.7894501d-22, 9.3894711d-11 /
      data fpppp(30,19, 2,1),fpppp(30,19, 2,2),fpppp(30,19, 2,3)/
     x-8.7149648d-09, 7.4913048d-22, 5.3998106d-11 /
      data fpppp(30,19, 3,1),fpppp(30,19, 3,2),fpppp(30,19, 3,3)/
     x-1.6660570d-08,-1.6747971d-23,-2.5604694d-11 /
      data fpppp(30,19, 4,1),fpppp(30,19, 4,2),fpppp(30,19, 4,3)/
     x-1.6660570d-08, 1.7321702d-22,-3.5912064d-11 /
      data fpppp(30,19, 5,1),fpppp(30,19, 5,2),fpppp(30,19, 5,3)/
     x-8.7149648d-09,-5.5106761d-22, 9.5227586d-11 /
      data fpppp(30,19, 6,1),fpppp(30,19, 6,2),fpppp(30,19, 6,3)/
     x 3.7182369d-09, 1.7122426d-23,-6.0715841d-11 /
      data fpppp(30,19, 7,1),fpppp(30,19, 7,2),fpppp(30,19, 7,3)/
     x-4.6734426d-10,-2.3589793d-22,-1.5639414d-11 /
      data fpppp(30,19, 8,1),fpppp(30,19, 8,2),fpppp(30,19, 8,3)/
     x 7.8344851d-09, 2.8544142d-22, 1.6859302d-10 /
      data fpppp(30,19, 9,1),fpppp(30,19, 9,2),fpppp(30,19, 9,3)/
     x-4.5105731d-09, 9.4297300d-23,-1.9080265d-10 /
      data fpppp(30,19,10,1),fpppp(30,19,10,2),fpppp(30,19,10,3)/
     x 8.7921815d-09,-2.2945711d-24, 8.1788461d-11 /
      data fpppp(30,19,11,1),fpppp(30,19,11,2),fpppp(30,19,11,3)/
     x 2.3102373d-09,-1.5551099d-23,-9.2578185d-11 /
      data fpppp(30,19,12,1),fpppp(30,19,12,2),fpppp(30,19,12,3)/
     x 2.3888868d-08, 3.3370980d-22, 7.7956060d-11 /
      data fpppp(30,19,13,1),fpppp(30,19,13,2),fpppp(30,19,13,3)/
     x 6.0808985d-09, 1.5116110d-22, 5.1465989d-11 /
      data fpppp(30,19,14,1),fpppp(30,19,14,2),fpppp(30,19,14,3)/
     x 2.0804700d-08,-8.0309913d-23,-1.7236436d-10 /
      data fpppp(30,19,15,1),fpppp(30,19,15,2),fpppp(30,19,15,3)/
     x 4.8674902d-09,-8.6271478d-23, 1.8362634d-10 /
      data fpppp(30,19,16,1),fpppp(30,19,16,2),fpppp(30,19,16,3)/
     x 1.1994043d-08,-3.1449349d-22,-4.6813791d-11 /
      data fpppp(30,19,17,1),fpppp(30,19,17,2),fpppp(30,19,17,3)/
     x 1.0605236d-08,-1.7217362d-22,-1.6316618d-10 /
      data fpppp(30,19,18,1),fpppp(30,19,18,2),fpppp(30,19,18,3)/
     x 1.6752892d-08, 2.7775573d-22, 1.8169133d-10 /
      data fpppp(30,19,19,1),fpppp(30,19,19,2),fpppp(30,19,19,3)/
     x 8.5607899d-09,-1.0512816d-22,-4.7268677d-11 /
      data fpppp(30,19,20,1),fpppp(30,19,20,2),fpppp(30,19,20,3)/
     x 1.1623332d-08, 2.7755606d-23, 2.2808493d-12 /
      data fpppp(30,19,21,1),fpppp(30,19,21,2),fpppp(30,19,21,3)/
     x 1.1623332d-08, 3.9007790d-22,-9.6851218d-12 /
      data fpppp(30,19,22,1),fpppp(30,19,22,2),fpppp(30,19,22,3)/
     x 8.5607899d-09, 2.7227571d-22, 5.9520701d-13 /
      data fpppp(30,19,23,1),fpppp(30,19,23,2),fpppp(30,19,23,3)/
     x 1.6752892d-08,-5.8093314d-22, 2.2017682d-12 /
 
      data fxyz( 1, 1, 1),fxyz( 1, 1, 2)/ 7.0987662d-05, 2.6982863d-05/
      data fxyz( 1, 1, 3),fxyz( 1, 1, 4)/-4.4280231d-05,-8.4587811d-05/
      data fxyz( 1, 1, 5),fxyz( 1, 1, 6)/ 1.8821318d-04,-5.3362603d-04/
      data fxyz( 1, 1, 7),fxyz( 1, 1, 8)/ 2.6820578d-03,-4.3644417d-03/
      data fxyz( 1, 1, 9),fxyz( 1, 1,10)/ 5.3299169d-05, 1.1431040d-03/
      data fxyz( 1, 1,11),fxyz( 1, 1,12)/ 3.7648485d-04, 1.1392593d-03/
      data fxyz( 1, 1,13),fxyz( 1, 1,14)/ 4.1931375d-04, 1.1508456d-03/
      data fxyz( 1, 1,15),fxyz( 1, 1,16)/-2.1464041d-04,-4.0223189d-03/
      data fxyz( 1, 1,17),fxyz( 1, 1,18)/ 2.6123832d-03,-5.9734235d-04/
      data fxyz( 1, 1,19),fxyz( 1, 1,20)/ 1.0867275d-04,-2.6659133d-05/
      data fxyz( 1, 1,21),fxyz( 1, 1,22)/ 9.8521000d-06,-3.7372182d-05/
      data fxyz( 1, 1,23)/               -4.9673851d-05/
      data fxyz( 1, 2, 1),fxyz( 1, 2, 2)/ 1.9658181d-05, 5.0915612d-06/
      data fxyz( 1, 2, 3),fxyz( 1, 2, 4)/-1.7450558d-05,-3.2626672d-05/
      data fxyz( 1, 2, 5),fxyz( 1, 2, 6)/ 6.5796020d-05,-2.0798354d-04/
      data fxyz( 1, 2, 7),fxyz( 1, 2, 8)/ 1.1147386d-03,-1.8233514d-03/
      data fxyz( 1, 2, 9),fxyz( 1, 2,10)/-1.4489964d-05, 5.2103684d-04/
      data fxyz( 1, 2,11),fxyz( 1, 2,12)/ 9.4208094d-05, 5.8855354d-04/
      data fxyz( 1, 2,13),fxyz( 1, 2,14)/ 1.1521861d-04, 5.1925101d-04/
      data fxyz( 1, 2,15),fxyz( 1, 2,16)/-1.2089440d-04,-1.6856417d-03/
      data fxyz( 1, 2,17),fxyz( 1, 2,18)/ 1.0722863d-03,-1.8411272d-04/
      data fxyz( 1, 2,19),fxyz( 1, 2,20)/-1.8725308d-05, 3.6932732d-06/
      data fxyz( 1, 2,21),fxyz( 1, 2,22)/ 1.1047327d-05,-4.8141525d-05/
      data fxyz( 1, 2,23)/               -7.3801908d-05/
      data fxyz( 1, 3, 1),fxyz( 1, 3, 2)/-1.3105567d-04,-5.4382122d-05/
      data fxyz( 1, 3, 3),fxyz( 1, 3, 4)/ 9.1532283d-05, 1.2370789d-04/
      data fxyz( 1, 3, 5),fxyz( 1, 3, 6)/-1.8308455d-04, 3.5157844d-04/
      data fxyz( 1, 3, 7),fxyz( 1, 3, 8)/-2.6504239d-03, 4.5704202d-03/
      data fxyz( 1, 3, 9),fxyz( 1, 3,10)/ 7.3525492d-05,-1.4285792d-03/
      data fxyz( 1, 3,11),fxyz( 1, 3,12)/ 2.3321130d-04,-2.2908613d-03/
      data fxyz( 1, 3,13),fxyz( 1, 3,14)/ 2.1928550d-04,-1.4878424d-03/
      data fxyz( 1, 3,15),fxyz( 1, 3,16)/ 3.4726393d-04, 4.2699325d-03/
      data fxyz( 1, 3,17),fxyz( 1, 3,18)/-2.4214087d-03,-2.0944682d-04/
      data fxyz( 1, 3,19),fxyz( 1, 3,20)/ 6.2055477d-04,-1.3846636d-04/
      data fxyz( 1, 3,21),fxyz( 1, 3,22)/-8.2253792d-05, 3.9570449d-04/
      data fxyz( 1, 3,23)/                6.3374171d-04/
      data fxyz( 1, 4, 1),fxyz( 1, 4, 2)/ 6.6075775d-05, 1.7682528d-05/
      data fxyz( 1, 4, 3),fxyz( 1, 4, 4)/-8.7020961d-05,-8.5264532d-05/
      data fxyz( 1, 4, 5),fxyz( 1, 4, 6)/ 1.0656815d-05, 9.2422197d-05/
      data fxyz( 1, 4, 7),fxyz( 1, 4, 8)/ 1.2768649d-03,-2.5201926d-03/
      data fxyz( 1, 4, 9),fxyz( 1, 4,10)/-3.8377511d-04, 1.2682258d-03/
      data fxyz( 1, 4,11),fxyz( 1, 4,12)/-1.1022654d-03, 2.9802057d-03/
      data fxyz( 1, 4,13),fxyz( 1, 4,14)/-1.1052147d-03, 1.3193099d-03/
      data fxyz( 1, 4,15),fxyz( 1, 4,16)/-4.9502089d-04,-2.4406325d-03/
      data fxyz( 1, 4,17),fxyz( 1, 4,18)/ 9.2248995d-04, 1.3001922d-03/
      data fxyz( 1, 4,19),fxyz( 1, 4,20)/-1.4235386d-03, 3.2316615d-04/
      data fxyz( 1, 4,21),fxyz( 1, 4,22)/ 1.5518230d-04,-7.5160325d-04/
      data fxyz( 1, 4,23)/               -1.2195655d-03/
      data fxyz( 1, 5, 1),fxyz( 1, 5, 2)/ 2.5508970d-04, 1.4711253d-04/
      data fxyz( 1, 5, 3),fxyz( 1, 5, 4)/-6.5997092d-05,-9.7969642d-05/
      data fxyz( 1, 5, 5),fxyz( 1, 5, 6)/ 2.7500273d-04,-2.2449854d-04/
      data fxyz( 1, 5, 7),fxyz( 1, 5, 8)/ 1.0313552d-04,-8.6486950d-06/
      data fxyz( 1, 5, 9),fxyz( 1, 5,10)/ 5.5397251d-04,-6.1837461d-04/
      data fxyz( 1, 5,11),fxyz( 1, 5,12)/ 9.4734439d-04,-1.8108232d-03/
      data fxyz( 1, 5,13),fxyz( 1, 5,14)/ 1.0375675d-03,-7.9183104d-04/
      data fxyz( 1, 5,15),fxyz( 1, 5,16)/ 8.9356405d-04,-4.5871239d-04/
      data fxyz( 1, 5,17),fxyz( 1, 5,18)/ 6.9884255d-04,-1.3064542d-03/
      data fxyz( 1, 5,19),fxyz( 1, 5,20)/ 1.3081940d-03,-3.4370142d-04/
      data fxyz( 1, 5,21),fxyz( 1, 5,22)/-1.8299576d-04, 6.6537132d-04/
      data fxyz( 1, 5,23)/                1.1041308d-03/
      data fxyz( 1, 6, 1),fxyz( 1, 6, 2)/-1.2296522d-03,-7.0806384d-04/
      data fxyz( 1, 6, 3),fxyz( 1, 6, 4)/ 3.2820004d-04, 4.7069450d-04/
      data fxyz( 1, 6, 5),fxyz( 1, 6, 6)/-1.2780417d-03, 9.0776468d-04/
      data fxyz( 1, 6, 7),fxyz( 1, 6, 8)/-3.9811884d-04, 1.5043133d-04/
      data fxyz( 1, 6, 9),fxyz( 1, 6,10)/-1.8129592d-04, 5.6485994d-05/
      data fxyz( 1, 6,11),fxyz( 1, 6,12)/-1.4625292d-04, 5.8696702d-04/
      data fxyz( 1, 6,13),fxyz( 1, 6,14)/-5.4760591d-04, 6.8500307d-04/
      data fxyz( 1, 6,15),fxyz( 1, 6,16)/-1.2802198d-03, 1.4373033d-03/
      data fxyz( 1, 6,17),fxyz( 1, 6,18)/-7.2083178d-04, 1.6283066d-04/
      data fxyz( 1, 6,19),fxyz( 1, 6,20)/-2.3859409d-04, 1.0300353d-04/
      data fxyz( 1, 6,21),fxyz( 1, 6,22)/ 7.6381521d-05,-1.3210606d-04/
      data fxyz( 1, 6,23)/               -2.3649947d-04/
      data fxyz( 1, 7, 1),fxyz( 1, 7, 2)/ 2.4800571d-03, 1.4499346d-03/
      data fxyz( 1, 7, 3),fxyz( 1, 7, 4)/-5.8121435d-04,-8.8966284d-04/
      data fxyz( 1, 7, 5),fxyz( 1, 7, 6)/ 2.6837286d-03,-2.1466702d-03/
      data fxyz( 1, 7, 7),fxyz( 1, 7, 8)/ 3.7250604d-04, 9.9734896d-04/
      data fxyz( 1, 7, 9),fxyz( 1, 7,10)/-1.0860803d-03, 9.8296203d-04/
      data fxyz( 1, 7,11),fxyz( 1, 7,12)/-5.9878250d-04,-4.0779898d-04/
      data fxyz( 1, 7,13),fxyz( 1, 7,14)/ 7.9816934d-04,-8.2272690d-04/
      data fxyz( 1, 7,15),fxyz( 1, 7,16)/ 8.9556671d-04,-5.5179496d-04/
      data fxyz( 1, 7,17),fxyz( 1, 7,18)/-1.9767072d-04, 8.2972297d-04/
      data fxyz( 1, 7,19),fxyz( 1, 7,20)/-7.2766134d-04, 1.6137746d-04/
      data fxyz( 1, 7,21),fxyz( 1, 7,22)/ 6.7757092d-05,-3.5317987d-04/
      data fxyz( 1, 7,23)/               -5.7458255d-04/
      data fxyz( 1, 8, 1),fxyz( 1, 8, 2)/-2.1883300d-03,-1.2878748d-03/
      data fxyz( 1, 8, 3),fxyz( 1, 8, 4)/ 5.0313178d-04, 7.4557754d-04/
      data fxyz( 1, 8, 5),fxyz( 1, 8, 6)/-2.2576578d-03, 1.4483564d-03/
      data fxyz( 1, 8, 7),fxyz( 1, 8, 8)/ 1.6534298d-03,-4.0968455d-03/
      data fxyz( 1, 8, 9),fxyz( 1, 8,10)/ 3.1949081d-03,-2.2446990d-03/
      data fxyz( 1, 8,11),fxyz( 1, 8,12)/ 1.0845262d-03, 2.0349992d-03/
      data fxyz( 1, 8,13),fxyz( 1, 8,14)/-3.9525584d-03, 4.0048388d-03/
      data fxyz( 1, 8,15),fxyz( 1, 8,16)/-2.7293237d-03, 1.0586196d-03/
      data fxyz( 1, 8,17),fxyz( 1, 8,18)/-1.3151271d-04,-5.9014297d-04/
      data fxyz( 1, 8,19),fxyz( 1, 8,20)/ 5.7978560d-04,-7.8430933d-05/
      data fxyz( 1, 8,21),fxyz( 1, 8,22)/-8.3156032d-06, 2.9932428d-04/
      data fxyz( 1, 8,23)/                4.6158698d-04/
      data fxyz( 1, 9, 1),fxyz( 1, 9, 2)/ 7.6166729d-04, 4.6009236d-04/
      data fxyz( 1, 9, 3),fxyz( 1, 9, 4)/-1.7605663d-04,-1.9370188d-04/
      data fxyz( 1, 9, 5),fxyz( 1, 9, 6)/ 5.3067337d-04, 4.9698853d-04/
      data fxyz( 1, 9, 7),fxyz( 1, 9, 8)/-4.3187240d-03, 7.8093484d-03/
      data fxyz( 1, 9, 9),fxyz( 1, 9,10)/-6.9169778d-03, 7.1730577d-03/
      data fxyz( 1, 9,11),fxyz( 1, 9,12)/-3.6671453d-03,-7.8775246d-03/
      data fxyz( 1, 9,13),fxyz( 1, 9,14)/ 1.4880558d-02,-1.4801651d-02/
      data fxyz( 1, 9,15),fxyz( 1, 9,16)/ 9.7906399d-03,-4.2205358d-03/
      data fxyz( 1, 9,17),fxyz( 1, 9,18)/ 1.7648211d-03,-1.1408551d-04/
      data fxyz( 1, 9,19),fxyz( 1, 9,20)/-5.3593711d-04, 2.0219379d-04/
      data fxyz( 1, 9,21),fxyz( 1, 9,22)/ 1.6581819d-04,-3.9043470d-04/
      data fxyz( 1, 9,23)/               -6.5971954d-04/
      data fxyz( 1,10, 1),fxyz( 1,10, 2)/-2.5874384d-05,-2.4421129d-05/
      data fxyz( 1,10, 3),fxyz( 1,10, 4)/ 1.7934710d-05,-5.0738304d-05/
      data fxyz( 1,10, 5),fxyz( 1,10, 6)/ 2.5027093d-04,-1.0559696d-03/
      data fxyz( 1,10, 7),fxyz( 1,10, 8)/ 3.8878690d-03,-7.7596587d-03/
      data fxyz( 1,10, 9),fxyz( 1,10,10)/ 9.3663018d-03,-1.2573462d-02/
      data fxyz( 1,10,11),fxyz( 1,10,12)/ 7.0913815d-03, 1.1050081d-02/
      data fxyz( 1,10,13),fxyz( 1,10,14)/-1.9082015d-02, 1.6269285d-02/
      data fxyz( 1,10,15),fxyz( 1,10,16)/-1.0114505d-02, 3.9960393d-03/
      data fxyz( 1,10,17),fxyz( 1,10,18)/-1.4921411d-03,-3.1014755d-04/
      data fxyz( 1,10,19),fxyz( 1,10,20)/ 2.4471271d-03,-1.3258177d-03/
      data fxyz( 1,10,21),fxyz( 1,10,22)/-1.1113566d-03, 1.5892824d-03/
      data fxyz( 1,10,23)/                2.9067702d-03/
      data fxyz( 1,11, 1),fxyz( 1,11, 2)/ 8.7652610d-04, 4.6872889d-04/
      data fxyz( 1,11, 3),fxyz( 1,11, 4)/-3.8475413d-04,-4.2039837d-04/
      data fxyz( 1,11, 5),fxyz( 1,11, 6)/ 6.1130583d-04, 3.4186258d-04/
      data fxyz( 1,11, 7),fxyz( 1,11, 8)/-1.6210198d-03, 4.0186209d-03/
      data fxyz( 1,11, 9),fxyz( 1,11,10)/-6.0583127d-03, 8.7588584d-03/
      data fxyz( 1,11,11),fxyz( 1,11,12)/-4.9927386d-03,-6.5038936d-03/
      data fxyz( 1,11,13),fxyz( 1,11,14)/ 9.6287004d-03,-6.0935706d-03/
      data fxyz( 1,11,15),fxyz( 1,11,16)/ 3.3932000d-03,-1.1961316d-03/
      data fxyz( 1,11,17),fxyz( 1,11,18)/ 2.1676319d-04, 9.3264766d-04/
      data fxyz( 1,11,19),fxyz( 1,11,20)/-3.9912224d-03, 2.1981721d-03/
      data fxyz( 1,11,21),fxyz( 1,11,22)/ 1.8273372d-03,-2.5078830d-03/
      data fxyz( 1,11,23)/               -4.6298751d-03/
      data fxyz( 1,12, 1),fxyz( 1,12, 2)/-3.8381166d-03,-2.0886862d-03/
      data fxyz( 1,12, 3),fxyz( 1,12, 4)/ 1.4830477d-03, 1.7928774d-03/
      data fxyz( 1,12, 5),fxyz( 1,12, 6)/-3.3280048d-03, 8.0932818d-04/
      data fxyz( 1,12, 7),fxyz( 1,12, 8)/ 2.4831389d-04,-1.1171803d-03/
      data fxyz( 1,12, 9),fxyz( 1,12,10)/ 1.7890555d-03,-2.3293595d-03/
      data fxyz( 1,12,11),fxyz( 1,12,12)/ 4.8045289d-04, 3.2206388d-03/
      data fxyz( 1,12,13),fxyz( 1,12,14)/-3.3978357d-03, 1.6492415d-03/
      data fxyz( 1,12,15),fxyz( 1,12,16)/-8.1894918d-04, 2.7295564d-04/
      data fxyz( 1,12,17),fxyz( 1,12,18)/ 4.4154507d-05,-6.0476633d-04/
      data fxyz( 1,12,19),fxyz( 1,12,20)/ 2.5494853d-03,-1.4218688d-03/
      data fxyz( 1,12,21),fxyz( 1,12,22)/-1.1841687d-03, 1.5986846d-03/
      data fxyz( 1,12,23)/                2.9607362d-03/
      data fxyz( 1,13, 1),fxyz( 1,13, 2)/ 1.7639205d-03, 9.6574430d-04/
      data fxyz( 1,13, 3),fxyz( 1,13, 4)/-6.6175798d-04,-8.0678964d-04/
      data fxyz( 1,13, 5),fxyz( 1,13, 6)/ 1.5458709d-03,-4.1155441d-04/
      data fxyz( 1,13, 7),fxyz( 1,13, 8)/-6.4476443d-05, 3.4889228d-04/
      data fxyz( 1,13, 9),fxyz( 1,13,10)/-3.9948210d-04,-3.0015976d-04/
      data fxyz( 1,13,11),fxyz( 1,13,12)/ 3.5026857d-03,-5.9793495d-03/
      data fxyz( 1,13,13),fxyz( 1,13,14)/ 1.5952531d-03, 3.3296633d-03/
      data fxyz( 1,13,15),fxyz( 1,13,16)/-2.5297830d-03, 6.6705377d-04/
      data fxyz( 1,13,17),fxyz( 1,13,18)/-2.1569688d-04, 2.6202669d-04/
      data fxyz( 1,13,19),fxyz( 1,13,20)/-7.9645053d-04, 4.2206200d-04/
      data fxyz( 1,13,21),fxyz( 1,13,22)/ 3.4482546d-04,-4.8750438d-04/
      data fxyz( 1,13,23)/               -8.9652138d-04/
      data fxyz( 1,14, 1),fxyz( 1,14, 2)/ 5.5575757d-03, 3.0349150d-03/
      data fxyz( 1,14, 3),fxyz( 1,14, 4)/-2.1010967d-03,-2.5730539d-03/
      data fxyz( 1,14, 5),fxyz( 1,14, 6)/ 4.9227438d-03,-1.5217825d-03/
      data fxyz( 1,14, 7),fxyz( 1,14, 8)/ 4.2376548d-04,-2.2277810d-04/
      data fxyz( 1,14, 9),fxyz( 1,14,10)/-3.5900216d-05, 1.1744384d-03/
      data fxyz( 1,14,11),fxyz( 1,14,12)/-5.1227293d-03, 7.5568774d-03/
      data fxyz( 1,14,13),fxyz( 1,14,14)/-1.5619132d-03,-4.6286497d-03/
      data fxyz( 1,14,15),fxyz( 1,14,16)/ 3.4407929d-03,-9.2207530d-04/
      data fxyz( 1,14,17),fxyz( 1,14,18)/ 2.6318102d-04,-1.7075331d-04/
      data fxyz( 1,14,19),fxyz( 1,14,20)/ 2.8207079d-04,-1.2345708d-04/
      data fxyz( 1,14,21),fxyz( 1,14,22)/-9.2979050d-05, 1.6015868d-04/
      data fxyz( 1,14,23)/                2.8641710d-04/
      data fxyz( 1,15, 1),fxyz( 1,15, 2)/-5.4326365d-03,-2.9538839d-03/
      data fxyz( 1,15, 3),fxyz( 1,15, 4)/ 2.0980668d-03, 2.5524751d-03/
      data fxyz( 1,15, 5),fxyz( 1,15, 6)/-4.7715171d-03, 1.3834878d-03/
      data fxyz( 1,15, 7),fxyz( 1,15, 8)/-3.4692231d-04, 1.0001971d-05/
      data fxyz( 1,15, 9),fxyz( 1,15,10)/ 1.7473908d-04,-4.5190363d-04/
      data fxyz( 1,15,11),fxyz( 1,15,12)/ 1.5906183d-03,-2.2155307d-03/
      data fxyz( 1,15,13),fxyz( 1,15,14)/ 2.8971655d-04, 1.4382402d-03/
      data fxyz( 1,15,15),fxyz( 1,15,16)/-9.7698569d-04, 2.5988579d-04/
      data fxyz( 1,15,17),fxyz( 1,15,18)/-7.5157312d-05, 4.4351005d-05/
      data fxyz( 1,15,19),fxyz( 1,15,20)/-6.5581216d-05, 2.5148961d-05/
      data fxyz( 1,15,21),fxyz( 1,15,22)/ 1.7920814d-05,-3.6668627d-05/
      data fxyz( 1,15,23)/               -6.4071205d-05/
      data fxyz( 1,16, 1),fxyz( 1,16, 2)/ 1.1234556d-03, 6.0013913d-04/
      data fxyz( 1,16, 3),fxyz( 1,16, 4)/-4.7082366d-04,-5.5907569d-04/
      data fxyz( 1,16, 5),fxyz( 1,16, 6)/ 9.5314727d-04,-2.0032492d-04/
      data fxyz( 1,16, 7),fxyz( 1,16, 8)/ 4.8772438d-05, 7.9124043d-05/
      data fxyz( 1,16, 9),fxyz( 1,16,10)/-9.8540631d-05,-1.8882086d-04/
      data fxyz( 1,16,11),fxyz( 1,16,12)/ 1.0127035d-03,-2.2971090d-03/
      data fxyz( 1,16,13),fxyz( 1,16,14)/ 2.7320613d-03,-1.7590952d-03/
      data fxyz( 1,16,15),fxyz( 1,16,16)/ 6.3361361d-04,-1.6440071d-04/
      data fxyz( 1,16,17),fxyz( 1,16,18)/ 5.0244005d-05,-1.5357176d-05/
      data fxyz( 1,16,19),fxyz( 1,16,20)/ 2.5595901d-05,-2.1802541d-06/
      data fxyz( 1,16,21),fxyz( 1,16,22)/ 3.7901562d-07, 1.5358822d-05/
      data fxyz( 1,16,23)/                2.3031870d-05/
      data fxyz( 1,17, 1),fxyz( 1,17, 2)/-9.0847082d-05,-4.8251677d-05/
      data fxyz( 1,17, 3),fxyz( 1,17, 4)/ 3.9529181d-05, 4.5645448d-05/
      data fxyz( 1,17, 5),fxyz( 1,17, 6)/-7.2716744d-05, 8.9692210d-07/
      data fxyz( 1,17, 7),fxyz( 1,17, 8)/ 5.4779258d-06,-1.3846806d-05/
      data fxyz( 1,17, 9),fxyz( 1,17,10)/-7.4955926d-06, 1.8862941d-04/
      data fxyz( 1,17,11),fxyz( 1,17,12)/-7.8189261d-04, 2.2843803d-03/
      data fxyz( 1,17,13),fxyz( 1,17,14)/-3.0282853d-03, 1.9147702d-03/
      data fxyz( 1,17,15),fxyz( 1,17,16)/-5.7377098d-04, 1.3367404d-04/
      data fxyz( 1,17,17),fxyz( 1,17,18)/-5.3441903d-05, 1.7751562d-06/
      data fxyz( 1,17,19),fxyz( 1,17,20)/-2.8165345d-05,-2.3942145d-05/
      data fxyz( 1,17,21),fxyz( 1,17,22)/-2.5456923d-05,-2.2106232d-05/
      data fxyz( 1,17,23)/               -2.0946517d-05/
      data fxyz( 1,18, 1),fxyz( 1,18, 2)/ 6.5616859d-05, 3.4644242d-05/
      data fxyz( 1,18, 3),fxyz( 1,18, 4)/-2.8834935d-05,-3.3893684d-05/
      data fxyz( 1,18, 5),fxyz( 1,18, 6)/ 5.4879239d-05,-1.0264379d-05/
      data fxyz( 1,18, 7),fxyz( 1,18, 8)/ 3.5895833d-06, 3.6802286d-06/
      data fxyz( 1,18, 9),fxyz( 1,18,10)/ 6.3458642d-06,-7.0815806d-05/
      data fxyz( 1,18,11),fxyz( 1,18,12)/ 2.8798818d-04,-8.8191657d-04/
      data fxyz( 1,18,13),fxyz( 1,18,14)/ 1.0699311d-03,-6.9782716d-04/
      data fxyz( 1,18,15),fxyz( 1,18,16)/ 2.2065656d-04,-3.7532965d-05/
      data fxyz( 1,18,17),fxyz( 1,18,18)/ 2.8562822d-05, 6.8526800d-06/
      data fxyz( 1,18,19),fxyz( 1,18,20)/ 2.4412697d-05, 2.6901820d-05/
      data fxyz( 1,18,21),fxyz( 1,18,22)/ 2.7680226d-05, 2.1299072d-05/
      data fxyz( 1,18,23)/                1.8528775d-05/
      data fxyz( 1,19, 1),fxyz( 1,19, 2)/-1.6956682d-04,-9.1398902d-05/
      data fxyz( 1,19, 3),fxyz( 1,19, 4)/ 6.8148650d-05, 8.2070119d-05/
      data fxyz( 1,19, 5),fxyz( 1,19, 6)/-1.4708478d-04, 3.9255218d-05/
      data fxyz( 1,19, 7),fxyz( 1,19, 8)/-1.0129094d-05,-1.0363561d-05/
      data fxyz( 1,19, 9),fxyz( 1,19,10)/ 4.2245487d-05,-1.4829088d-04/
      data fxyz( 1,19,11),fxyz( 1,19,12)/ 5.3944702d-04,-1.8345603d-03/
      data fxyz( 1,19,13),fxyz( 1,19,14)/ 2.3514152d-03,-1.5142923d-03/
      data fxyz( 1,19,15),fxyz( 1,19,16)/ 4.4313777d-04,-7.4659467d-05/
      data fxyz( 1,19,17),fxyz( 1,19,18)/ 5.7513080d-05, 1.5374435d-05/
      data fxyz( 1,19,19),fxyz( 1,19,20)/ 4.6608086d-05, 5.7001255d-05/
      data fxyz( 1,19,21),fxyz( 1,19,22)/ 5.8253636d-05, 4.1598560d-05/
      data fxyz( 1,19,23)/                3.4160159d-05/
      data fxyz( 2, 1, 1),fxyz( 2, 1, 2)/-3.0695302d-06,-1.3421965d-05/
      data fxyz( 2, 1, 3),fxyz( 2, 1, 4)/-2.5161535d-05,-4.3438917d-05/
      data fxyz( 2, 1, 5),fxyz( 2, 1, 6)/ 5.9687562d-05,-2.7723025d-04/
      data fxyz( 2, 1, 7),fxyz( 2, 1, 8)/ 1.0123953d-03,-1.6694297d-03/
      data fxyz( 2, 1, 9),fxyz( 2, 1,10)/ 6.8305225d-06, 5.1310813d-04/
      data fxyz( 2, 1,11),fxyz( 2, 1,12)/ 1.4314027d-04, 5.4206114d-04/
      data fxyz( 2, 1,13),fxyz( 2, 1,14)/ 1.6447467d-04, 5.1490482d-04/
      data fxyz( 2, 1,15),fxyz( 2, 1,16)/-1.2320210d-04,-1.4727733d-03/
      data fxyz( 2, 1,17),fxyz( 2, 1,18)/ 9.1881283d-04,-2.7264481d-04/
      data fxyz( 2, 1,19),fxyz( 2, 1,20)/ 1.6005811d-05,-1.4578775d-05/
      data fxyz( 2, 1,21),fxyz( 2, 1,22)/-1.9949796d-07,-4.1511296d-05/
      data fxyz( 2, 1,23)/               -5.6955661d-05/
      data fxyz( 2, 2, 1),fxyz( 2, 2, 2)/-2.8410188d-05,-2.1627667d-05/
      data fxyz( 2, 2, 3),fxyz( 2, 2, 4)/-4.6145629d-06,-8.9530454d-06/
      data fxyz( 2, 2, 5),fxyz( 2, 2, 6)/-4.2737374d-06,-9.3487425d-05/
      data fxyz( 2, 2, 7),fxyz( 2, 2, 8)/ 4.0997515d-04,-6.8697339d-04/
      data fxyz( 2, 2, 9),fxyz( 2, 2,10)/-1.8211111d-05, 2.3592359d-04/
      data fxyz( 2, 2,11),fxyz( 2, 2,12)/ 2.8769054d-05, 2.8061929d-04/
      data fxyz( 2, 2,13),fxyz( 2, 2,14)/ 3.9690503d-05, 2.3264196d-04/
      data fxyz( 2, 2,15),fxyz( 2, 2,16)/-6.4069956d-05,-6.1592408d-04/
      data fxyz( 2, 2,17),fxyz( 2, 2,18)/ 3.6767278d-04,-6.6188538d-05/
      data fxyz( 2, 2,19),fxyz( 2, 2,20)/-4.5429650d-05, 7.5410958d-06/
      data fxyz( 2, 2,21),fxyz( 2, 2,22)/ 7.3530835d-06,-4.4677601d-05/
      data fxyz( 2, 2,23)/               -6.9008724d-05/
      data fxyz( 2, 3, 1),fxyz( 2, 3, 2)/ 2.2799042d-04, 1.4937254d-04/
      data fxyz( 2, 3, 3),fxyz( 2, 3, 4)/-1.0780929d-05,-2.5329401d-05/
      data fxyz( 2, 3, 5),fxyz( 2, 3, 6)/ 2.0756642d-04, 9.7633495d-06/
      data fxyz( 2, 3, 7),fxyz( 2, 3, 8)/-9.0638461d-04, 1.6915015d-03/
      data fxyz( 2, 3, 9),fxyz( 2, 3,10)/ 7.7978734d-05,-6.5878088d-04/
      data fxyz( 2, 3,11),fxyz( 2, 3,12)/ 1.5706845d-04,-1.0942485d-03/
      data fxyz( 2, 3,13),fxyz( 2, 3,14)/ 1.4910554d-04,-6.8181174d-04/
      data fxyz( 2, 3,15),fxyz( 2, 3,16)/ 1.8974227d-04, 1.5505637d-03/
      data fxyz( 2, 3,17),fxyz( 2, 3,18)/-7.5740662d-04,-2.7882395d-04/
      data fxyz( 2, 3,19),fxyz( 2, 3,20)/ 5.6573142d-04,-1.3798661d-04/
      data fxyz( 2, 3,21),fxyz( 2, 3,22)/-8.2308264d-05, 3.4301804d-04/
      data fxyz( 2, 3,23)/                5.5635121d-04/
      data fxyz( 2, 4, 1),fxyz( 2, 4, 2)/-5.0170340d-04,-3.0684794d-04/
      data fxyz( 2, 4, 3),fxyz( 2, 4, 4)/ 7.6549390d-05, 1.3631204d-04/
      data fxyz( 2, 4, 5),fxyz( 2, 4, 6)/-5.4589853d-04, 3.9473631d-04/
      data fxyz( 2, 4, 7),fxyz( 2, 4, 8)/ 2.7604416d-04,-8.1608871d-04/
      data fxyz( 2, 4, 9),fxyz( 2, 4,10)/-2.5014159d-04, 6.0783436d-04/
      data fxyz( 2, 4,11),fxyz( 2, 4,12)/-5.6397932d-04, 1.4278745d-03/
      data fxyz( 2, 4,13),fxyz( 2, 4,14)/-5.6117663d-04, 6.1640253d-04/
      data fxyz( 2, 4,15),fxyz( 2, 4,16)/-2.3782580d-04,-8.6668358d-04/
      data fxyz( 2, 4,17),fxyz( 2, 4,18)/ 1.2630167d-04, 9.7536154d-04/
      data fxyz( 2, 4,19),fxyz( 2, 4,20)/-1.1771954d-03, 3.0325220d-04/
      data fxyz( 2, 4,21),fxyz( 2, 4,22)/ 1.6827914d-04,-6.3730313d-04/
      data fxyz( 2, 4,23)/               -1.0492343d-03/
      data fxyz( 2, 5, 1),fxyz( 2, 5, 2)/ 4.8923254d-04, 2.8445792d-04/
      data fxyz( 2, 5, 3),fxyz( 2, 5, 4)/-1.2294195d-04,-1.7789701d-04/
      data fxyz( 2, 5, 5),fxyz( 2, 5, 6)/ 5.0427816d-04,-3.3509336d-04/
      data fxyz( 2, 5, 7),fxyz( 2, 5, 8)/ 1.9701332d-04,-1.6861434d-04/
      data fxyz( 2, 5, 9),fxyz( 2, 5,10)/ 3.2240943d-04,-3.1110979d-04/
      data fxyz( 2, 5,11),fxyz( 2, 5,12)/ 4.7025257d-04,-8.7421268d-04/
      data fxyz( 2, 5,13),fxyz( 2, 5,14)/ 5.1066610d-04,-3.7025799d-04/
      data fxyz( 2, 5,15),fxyz( 2, 5,16)/ 3.7078002d-04,-2.0430177d-04/
      data fxyz( 2, 5,17),fxyz( 2, 5,18)/ 4.0197792d-04,-8.6376626d-04/
      data fxyz( 2, 5,19),fxyz( 2, 5,20)/ 9.5863576d-04,-2.6533544d-04/
      data fxyz( 2, 5,21),fxyz( 2, 5,22)/-1.5171573d-04, 5.0415691d-04/
      data fxyz( 2, 5,23)/                8.4052940d-04/
      data fxyz( 2, 6, 1),fxyz( 2, 6, 2)/-7.4205172d-04,-4.2679404d-04/
      data fxyz( 2, 6, 3),fxyz( 2, 6, 4)/ 2.0194388d-04, 2.8386881d-04/
      data fxyz( 2, 6, 5),fxyz( 2, 6, 6)/-7.5449375d-04, 4.8682219d-04/
      data fxyz( 2, 6, 7),fxyz( 2, 6, 8)/-2.0364816d-04, 1.0477709d-04/
      data fxyz( 2, 6, 9),fxyz( 2, 6,10)/-9.7379548d-05, 2.0648669d-05/
      data fxyz( 2, 6,11),fxyz( 2, 6,12)/-6.5362678d-05, 2.8804269d-04/
      data fxyz( 2, 6,13),fxyz( 2, 6,14)/-2.7716210d-04, 3.2737630d-04/
      data fxyz( 2, 6,15),fxyz( 2, 6,16)/-5.4798359d-04, 5.8070061d-04/
      data fxyz( 2, 6,17),fxyz( 2, 6,18)/-2.7673718d-04, 9.0699708d-05/
      data fxyz( 2, 6,19),fxyz( 2, 6,20)/-1.5688772d-04, 5.8399851d-05/
      data fxyz( 2, 6,21),fxyz( 2, 6,22)/ 4.1878255d-05,-9.0801335d-05/
      data fxyz( 2, 6,23)/               -1.5712424d-04/
      data fxyz( 2, 7, 1),fxyz( 2, 7, 2)/ 1.2876257d-03, 7.4896060d-04/
      data fxyz( 2, 7, 3),fxyz( 2, 7, 4)/-3.2134233d-04,-4.6830627d-04/
      data fxyz( 2, 7, 5),fxyz( 2, 7, 6)/ 1.3368163d-03,-9.1683334d-04/
      data fxyz( 2, 7, 7),fxyz( 2, 7, 8)/-2.8176525d-06, 6.2750311d-04/
      data fxyz( 2, 7, 9),fxyz( 2, 7,10)/-6.2787273d-04, 5.5432198d-04/
      data fxyz( 2, 7,11),fxyz( 2, 7,12)/-3.3758447d-04,-2.1431875d-04/
      data fxyz( 2, 7,13),fxyz( 2, 7,14)/ 4.3115372d-04,-4.2885813d-04/
      data fxyz( 2, 7,15),fxyz( 2, 7,16)/ 4.0517406d-04,-1.7279055d-04/
      data fxyz( 2, 7,17),fxyz( 2, 7,18)/-1.9005586d-04, 4.7457232d-04/
      data fxyz( 2, 7,19),fxyz( 2, 7,20)/-4.1033481d-04, 9.5421578d-05/
      data fxyz( 2, 7,21),fxyz( 2, 7,22)/ 4.2213028d-05,-1.9750061d-04/
      data fxyz( 2, 7,23)/               -3.2355593d-04/
      data fxyz( 2, 8, 1),fxyz( 2, 8, 2)/-1.0568866d-03,-6.1642740d-04/
      data fxyz( 2, 8, 3),fxyz( 2, 8, 4)/ 2.7709707d-04, 3.6515123d-04/
      data fxyz( 2, 8, 5),fxyz( 2, 8, 6)/-9.6864404d-04, 2.6392579d-04/
      data fxyz( 2, 8, 7),fxyz( 2, 8, 8)/ 1.4027271d-03,-2.5033904d-03/
      data fxyz( 2, 8, 9),fxyz( 2, 8,10)/ 1.8496238d-03,-1.2674496d-03/
      data fxyz( 2, 8,11),fxyz( 2, 8,12)/ 6.0784642d-04, 1.1204691d-03/
      data fxyz( 2, 8,13),fxyz( 2, 8,14)/-2.1823451d-03, 2.2073031d-03/
      data fxyz( 2, 8,15),fxyz( 2, 8,16)/-1.4850668d-03, 5.4997746d-04/
      data fxyz( 2, 8,17),fxyz( 2, 8,18)/-5.2076691d-05,-3.2740960d-04/
      data fxyz( 2, 8,19),fxyz( 2, 8,20)/ 3.0982877d-04,-3.7561774d-05/
      data fxyz( 2, 8,21),fxyz( 2, 8,22)/ 3.8224260d-07, 1.5805270d-04/
      data fxyz( 2, 8,23)/                2.4175065d-04/
      data fxyz( 2, 9, 1),fxyz( 2, 9, 2)/ 3.2569305d-04, 1.9538023d-04/
      data fxyz( 2, 9, 3),fxyz( 2, 9, 4)/-1.0053152d-04,-7.1358997d-05/
      data fxyz( 2, 9, 5),fxyz( 2, 9, 6)/ 7.8690156d-05, 7.6328084d-04/
      data fxyz( 2, 9, 7),fxyz( 2, 9, 8)/-2.9715988d-03, 4.7178593d-03/
      data fxyz( 2, 9, 9),fxyz( 2, 9,10)/-4.0023410d-03, 4.0270424d-03/
      data fxyz( 2, 9,11),fxyz( 2, 9,12)/-2.0454211d-03,-4.3501328d-03/
      data fxyz( 2, 9,13),fxyz( 2, 9,14)/ 8.2256873d-03,-8.1819477d-03/
      data fxyz( 2, 9,15),fxyz( 2, 9,16)/ 5.4070074d-03,-2.3249709d-03/
      data fxyz( 2, 9,17),fxyz( 2, 9,18)/ 9.7366847d-04,-7.5903842d-05/
      data fxyz( 2, 9,19),fxyz( 2, 9,20)/-2.4426999d-04, 8.3464659d-05/
      data fxyz( 2, 9,21),fxyz( 2, 9,22)/ 6.8212651d-05,-1.8326195d-04/
      data fxyz( 2, 9,23)/               -3.0468397d-04/
      data fxyz( 2,10, 1),fxyz( 2,10, 2)/ 1.3103112d-05, 2.2998428d-06/
      data fxyz( 2,10, 3),fxyz( 2,10, 4)/ 1.0672835d-05,-4.4492159d-05/
      data fxyz( 2,10, 5),fxyz( 2,10, 6)/ 2.2295982d-04,-8.1437180d-04/
      data fxyz( 2,10, 7),fxyz( 2,10, 8)/ 2.5288482d-03,-4.6618598d-03/
      data fxyz( 2,10, 9),fxyz( 2,10,10)/ 5.4108817d-03,-7.0544771d-03/
      data fxyz( 2,10,11),fxyz( 2,10,12)/ 3.9553153d-03, 6.1006426d-03/
      data fxyz( 2,10,13),fxyz( 2,10,14)/-1.0548109d-02, 8.9946058d-03/
      data fxyz( 2,10,15),fxyz( 2,10,16)/-5.5914824d-03, 2.2104813d-03/
      data fxyz( 2,10,17),fxyz( 2,10,18)/-8.3732866d-04,-1.1982573d-04/
      data fxyz( 2,10,19),fxyz( 2,10,20)/ 1.1587206d-03,-6.2670942d-04/
      data fxyz( 2,10,21),fxyz( 2,10,22)/-5.2646827d-04, 7.5775594d-04/
      data fxyz( 2,10,23)/                1.3837915d-03/
      data fxyz( 2,11, 1),fxyz( 2,11, 2)/ 4.9582658d-04, 2.6382937d-04/
      data fxyz( 2,11, 3),fxyz( 2,11, 4)/-2.2442153d-04,-2.3997200d-04/
      data fxyz( 2,11, 5),fxyz( 2,11, 6)/ 3.2603125d-04, 2.6256952d-04/
      data fxyz( 2,11, 7),fxyz( 2,11, 8)/-1.0322829d-03, 2.3979857d-03/
      data fxyz( 2,11, 9),fxyz( 2,11,10)/-3.4984495d-03, 4.9336981d-03/
      data fxyz( 2,11,11),fxyz( 2,11,12)/-2.8014193d-03,-3.5840897d-03/
      data fxyz( 2,11,13),fxyz( 2,11,14)/ 5.3210949d-03,-3.3687169d-03/
      data fxyz( 2,11,15),fxyz( 2,11,16)/ 1.8771831d-03,-6.6694362d-04/
      data fxyz( 2,11,17),fxyz( 2,11,18)/ 1.4307584d-04, 4.2697183d-04/
      data fxyz( 2,11,19),fxyz( 2,11,20)/-1.8802270d-03, 1.0375629d-03/
      data fxyz( 2,11,21),fxyz( 2,11,22)/ 8.6340940d-04,-1.1836129d-03/
      data fxyz( 2,11,23)/               -2.1853309d-03/
      data fxyz( 2,12, 1),fxyz( 2,12, 2)/-2.0687257d-03,-1.1280376d-03/
      data fxyz( 2,12, 3),fxyz( 2,12, 4)/ 7.9238276d-04, 9.5922720d-04/
      data fxyz( 2,12, 5),fxyz( 2,12, 6)/-1.7954154d-03, 4.3394100d-04/
      data fxyz( 2,12, 7),fxyz( 2,12, 8)/ 1.7215145d-04,-6.5368316d-04/
      data fxyz( 2,12, 9),fxyz( 2,12,10)/ 1.0118118d-03,-1.2965079d-03/
      data fxyz( 2,12,11),fxyz( 2,12,12)/ 2.7132633d-04, 1.7771014d-03/
      data fxyz( 2,12,13),fxyz( 2,12,14)/-1.8782515d-03, 9.1231199d-04/
      data fxyz( 2,12,15),fxyz( 2,12,16)/-4.5391067d-04, 1.5579265d-04/
      data fxyz( 2,12,17),fxyz( 2,12,18)/ 6.4765783d-06,-2.6512597d-04/
      data fxyz( 2,12,19),fxyz( 2,12,20)/ 1.1631738d-03,-6.5362210d-04/
      data fxyz( 2,12,21),fxyz( 2,12,22)/-5.4557758d-04, 7.3099570d-04/
      data fxyz( 2,12,23)/                1.3555418d-03/
      data fxyz( 2,13, 1),fxyz( 2,13, 2)/ 8.9058213d-04, 4.9106369d-04/
      data fxyz( 2,13, 3),fxyz( 2,13, 4)/-3.2243699d-04,-3.9700496d-04/
      data fxyz( 2,13, 5),fxyz( 2,13, 6)/ 7.8933560d-04,-2.2793755d-04/
      data fxyz( 2,13, 7),fxyz( 2,13, 8)/-4.6092593d-05, 1.9745293d-04/
      data fxyz( 2,13, 9),fxyz( 2,13,10)/-2.0695462d-04,-2.0253820d-04/
      data fxyz( 2,13,11),fxyz( 2,13,12)/ 1.9723438d-03,-3.3227977d-03/
      data fxyz( 2,13,13),fxyz( 2,13,14)/ 8.8733139d-04, 1.8388046d-03/
      data fxyz( 2,13,15),fxyz( 2,13,16)/-1.3976615d-03, 3.6685751d-04/
      data fxyz( 2,13,17),fxyz( 2,13,18)/-1.1200997d-04, 1.1757657d-04/
      data fxyz( 2,13,19),fxyz( 2,13,20)/-3.4488390d-04, 1.8202219d-04/
      data fxyz( 2,13,21),fxyz( 2,13,22)/ 1.4839799d-04,-2.1038707d-04/
      data fxyz( 2,13,23)/               -3.8678655d-04/
      data fxyz( 2,14, 1),fxyz( 2,14, 2)/ 3.0099253d-03, 1.6487450d-03/
      data fxyz( 2,14, 3),fxyz( 2,14, 4)/-1.1207548d-03,-1.3785567d-03/
      data fxyz( 2,14, 5),fxyz( 2,14, 6)/ 2.6799529d-03,-8.5710439d-04/
      data fxyz( 2,14, 7),fxyz( 2,14, 8)/ 2.2935269d-04,-1.2629240d-04/
      data fxyz( 2,14, 9),fxyz( 2,14,10)/-2.0362898d-05, 6.5567007d-04/
      data fxyz( 2,14,11),fxyz( 2,14,12)/-2.8448469d-03, 4.1920599d-03/
      data fxyz( 2,14,13),fxyz( 2,14,14)/-8.7343730d-04,-2.5546524d-03/
      data fxyz( 2,14,15),fxyz( 2,14,16)/ 1.9008897d-03,-5.0916549d-04/
      data fxyz( 2,14,17),fxyz( 2,14,18)/ 1.4277511d-04,-8.7362002d-05/
      data fxyz( 2,14,19),fxyz( 2,14,20)/ 1.2458385d-04,-4.9867293d-05/
      data fxyz( 2,14,21),fxyz( 2,14,22)/-3.5942148d-05, 6.8883270d-05/
      data fxyz( 2,14,23)/                1.2151517d-04/
      data fxyz( 2,15, 1),fxyz( 2,15, 2)/-2.9447476d-03,-1.6031938d-03/
      data fxyz( 2,15, 3),fxyz( 2,15, 4)/ 1.1300818d-03, 1.3776760d-03/
      data fxyz( 2,15, 5),fxyz( 2,15, 6)/-2.5935707d-03, 7.6916581d-04/
      data fxyz( 2,15, 7),fxyz( 2,15, 8)/-1.9026409d-04, 4.8781122d-06/
      data fxyz( 2,15, 9),fxyz( 2,15,10)/ 9.6208964d-05,-2.4843167d-04/
      data fxyz( 2,15,11),fxyz( 2,15,12)/ 8.7652381d-04,-1.2349567d-03/
      data fxyz( 2,15,13),fxyz( 2,15,14)/ 1.8069213d-04, 7.8173311d-04/
      data fxyz( 2,15,15),fxyz( 2,15,16)/-5.3629978d-04, 1.4275439d-04/
      data fxyz( 2,15,17),fxyz( 2,15,18)/-4.0371863d-05, 2.2946416d-05/
      data fxyz( 2,15,19),fxyz( 2,15,20)/-2.5804205d-05, 7.8892285d-06/
      data fxyz( 2,15,21),fxyz( 2,15,22)/ 4.8287432d-06,-1.3562264d-05/
      data fxyz( 2,15,23)/               -2.2960863d-05/
      data fxyz( 2,16, 1),fxyz( 2,16, 2)/ 6.4793034d-04, 3.4448661d-04/
      data fxyz( 2,16, 3),fxyz( 2,16, 4)/-2.7704591d-04,-3.2727800d-04/
      data fxyz( 2,16, 5),fxyz( 2,16, 6)/ 5.4541496d-04,-1.0555097d-04/
      data fxyz( 2,16, 7),fxyz( 2,16, 8)/ 2.9045375d-05, 4.6892558d-05/
      data fxyz( 2,16, 9),fxyz( 2,16,10)/-6.4119956d-05,-6.8753418d-05/
      data fxyz( 2,16,11),fxyz( 2,16,12)/ 4.7080898d-04,-1.1192802d-03/
      data fxyz( 2,16,13),fxyz( 2,16,14)/ 1.3750728d-03,-9.0767722d-04/
      data fxyz( 2,16,15),fxyz( 2,16,16)/ 3.3170420d-04,-8.6825537d-05/
      data fxyz( 2,16,17),fxyz( 2,16,18)/ 2.5835266d-05,-7.9214401d-06/
      data fxyz( 2,16,19),fxyz( 2,16,20)/ 1.0661708d-05,-1.0095172d-06/
      data fxyz( 2,16,21),fxyz( 2,16,22)/ 1.3113401d-07, 6.0991027d-06/
      data fxyz( 2,16,23)/                9.1883284d-06/
      data fxyz( 2,17, 1),fxyz( 2,17, 2)/-6.3522856d-05,-3.4050093d-05/
      data fxyz( 2,17, 3),fxyz( 2,17, 4)/ 2.6609102d-05, 3.0978374d-05/
      data fxyz( 2,17, 5),fxyz( 2,17, 6)/-5.1527182d-05, 2.0162280d-06/
      data fxyz( 2,17, 7),fxyz( 2,17, 8)/ 4.5982429d-06,-1.0980832d-05/
      data fxyz( 2,17, 9),fxyz( 2,17,10)/ 1.0489819d-05, 5.0190997d-05/
      data fxyz( 2,17,11),fxyz( 2,17,12)/-2.6655287d-04, 9.4357233d-04/
      data fxyz( 2,17,13),fxyz( 2,17,14)/-1.4105736d-03, 9.4795389d-04/
      data fxyz( 2,17,15),fxyz( 2,17,16)/-2.8334721d-04, 6.8331212d-05/
      data fxyz( 2,17,17),fxyz( 2,17,18)/-2.5113852d-05, 1.7951758d-06/
      data fxyz( 2,17,19),fxyz( 2,17,20)/-1.1376655d-05,-9.5097234d-06/
      data fxyz( 2,17,21),fxyz( 2,17,22)/-1.0176325d-05,-8.7102505d-06/
      data fxyz( 2,17,23)/               -8.2038429d-06/
      data fxyz( 2,18, 1),fxyz( 2,18, 2)/ 3.9040583d-05, 2.0468768d-05/
      data fxyz( 2,18, 3),fxyz( 2,18, 4)/-1.7635916d-05,-2.0597024d-05/
      data fxyz( 2,18, 5),fxyz( 2,18, 6)/ 3.2313200d-05,-5.3760373d-06/
      data fxyz( 2,18, 7),fxyz( 2,18, 8)/ 1.7089930d-06, 3.9468419d-06/
      data fxyz( 2,18, 9),fxyz( 2,18,10)/-3.1844989d-06,-1.4508865d-05/
      data fxyz( 2,18,11),fxyz( 2,18,12)/ 8.1632930d-05,-3.1624372d-04/
      data fxyz( 2,18,13),fxyz( 2,18,14)/ 4.6134257d-04,-3.3759350d-04/
      data fxyz( 2,18,15),fxyz( 2,18,16)/ 1.0497464d-04,-1.9779798d-05/
      data fxyz( 2,18,17),fxyz( 2,18,18)/ 1.2501427d-05, 2.4851913d-06/
      data fxyz( 2,18,19),fxyz( 2,18,20)/ 9.6879161d-06, 1.0595966d-05/
      data fxyz( 2,18,21),fxyz( 2,18,22)/ 1.0917753d-05, 8.4007703d-06/
      data fxyz( 2,18,23)/                7.3119882d-06/
      data fxyz( 2,19, 1),fxyz( 2,19, 2)/-9.0972161d-05,-4.8742532d-05/
      data fxyz( 2,19, 3),fxyz( 2,19, 4)/ 3.7519075d-05, 4.4922370d-05/
      data fxyz( 2,19, 5),fxyz( 2,19, 6)/-7.8355711d-05, 2.0077258d-05/
      data fxyz( 2,19, 7),fxyz( 2,19, 8)/-7.3396517d-06,-1.9257883d-06/
      data fxyz( 2,19, 9),fxyz( 2,19,10)/ 8.3652099d-06,-2.6738934d-05/
      data fxyz( 2,19,11),fxyz( 2,19,12)/ 1.1966226d-04,-6.2672588d-04/
      data fxyz( 2,19,13),fxyz( 2,19,14)/ 1.0025266d-03,-7.2566131d-04/
      data fxyz( 2,19,15),fxyz( 2,19,16)/ 2.0661841d-04,-3.8385734d-05/
      data fxyz( 2,19,17),fxyz( 2,19,18)/ 2.4812593d-05, 5.7542355d-06/
      data fxyz( 2,19,19),fxyz( 2,19,20)/ 1.8437364d-05, 2.2528543d-05/
      data fxyz( 2,19,21),fxyz( 2,19,22)/ 2.3039963d-05, 1.6391684d-05/
      data fxyz( 2,19,23)/                1.3425533d-05/
      data fxyz( 3, 1, 1),fxyz( 3, 1, 2)/-2.7200689d-04,-1.5389885d-04/
      data fxyz( 3, 1, 3),fxyz( 3, 1, 4)/ 4.3083877d-06, 1.7035085d-04/
      data fxyz( 3, 1, 5),fxyz( 3, 1, 6)/-8.1806870d-04, 2.2186300d-03/
      data fxyz( 3, 1, 7),fxyz( 3, 1, 8)/-5.5698405d-03, 5.0365073d-03/
      data fxyz( 3, 1, 9),fxyz( 3, 1,10)/ 4.7229931d-04,-9.5449427d-04/
      data fxyz( 3, 1,11),fxyz( 3, 1,12)/-1.9346282d-04,-7.6913174d-04/
      data fxyz( 3, 1,13),fxyz( 3, 1,14)/-3.2448278d-04,-8.0933104d-04/
      data fxyz( 3, 1,15),fxyz( 3, 1,16)/ 6.9016063d-04, 4.4641303d-03/
      data fxyz( 3, 1,17),fxyz( 3, 1,18)/-5.0819761d-03, 2.0119605d-03/
      data fxyz( 3, 1,19),fxyz( 3, 1,20)/-7.3298939d-04, 1.3985887d-04/
      data fxyz( 3, 1,21),fxyz( 3, 1,22)/-9.7746255d-06,-1.3445540d-04/
      data fxyz( 3, 1,23)/               -2.3254202d-04/
      data fxyz( 3, 2, 1),fxyz( 3, 2, 2)/-2.1439921d-04,-1.2284523d-04/
      data fxyz( 3, 2, 3),fxyz( 3, 2, 4)/ 2.6309400d-05, 1.0861626d-04/
      data fxyz( 3, 2, 5),fxyz( 3, 2, 6)/-4.5207268d-04, 1.0202037d-03/
      data fxyz( 3, 2, 7),fxyz( 3, 2, 8)/-2.4128803d-03, 2.1640654d-03/
      data fxyz( 3, 2, 9),fxyz( 3, 2,10)/ 2.1356762d-04,-4.2551947d-04/
      data fxyz( 3, 2,11),fxyz( 3, 2,12)/-5.4321923d-05,-3.6950570d-04/
      data fxyz( 3, 2,13),fxyz( 3, 2,14)/-1.1891727d-04,-3.5034628d-04/
      data fxyz( 3, 2,15),fxyz( 3, 2,16)/ 3.0481081d-04, 1.9061362d-03/
      data fxyz( 3, 2,17),fxyz( 3, 2,18)/-2.1853655d-03, 9.0081549d-04/
      data fxyz( 3, 2,19),fxyz( 3, 2,20)/-3.7215133d-04, 7.9646850d-05/
      data fxyz( 3, 2,21),fxyz( 3, 2,22)/ 9.2130226d-06,-9.0416017d-05/
      data fxyz( 3, 2,23)/               -1.5569192d-04/
      data fxyz( 3, 3, 1),fxyz( 3, 3, 2)/ 1.4778506d-03, 8.5761485d-04/
      data fxyz( 3, 3, 3),fxyz( 3, 3, 4)/-2.9405988d-04,-6.0451333d-04/
      data fxyz( 3, 3, 5),fxyz( 3, 3, 6)/ 2.0994286d-03,-3.1789511d-03/
      data fxyz( 3, 3, 7),fxyz( 3, 3, 8)/ 6.2474552d-03,-5.5150739d-03/
      data fxyz( 3, 3, 9),fxyz( 3, 3,10)/-5.3501850d-04, 1.0699148d-03/
      data fxyz( 3, 3,11),fxyz( 3, 3,12)/-2.5702010d-05, 1.2840669d-03/
      data fxyz( 3, 3,13),fxyz( 3, 3,14)/ 1.5710834d-05, 1.0826473d-03/
      data fxyz( 3, 3,15),fxyz( 3, 3,16)/-8.9047718d-04,-4.8598723d-03/
      data fxyz( 3, 3,17),fxyz( 3, 3,18)/ 5.6426271d-03,-2.5758696d-03/
      data fxyz( 3, 3,19),fxyz( 3, 3,20)/ 1.4400912d-03,-3.8313214d-04/
      data fxyz( 3, 3,21),fxyz( 3, 3,22)/-1.5211323d-04, 5.1601556d-04/
      data fxyz( 3, 3,23)/                8.8941404d-04/
      data fxyz( 3, 4, 1),fxyz( 3, 4, 2)/-2.5511471d-03,-1.4848476d-03/
      data fxyz( 3, 4, 3),fxyz( 3, 4, 4)/ 5.8386687d-04, 9.6223961d-04/
      data fxyz( 3, 4, 5),fxyz( 3, 4, 6)/-2.9983386d-03, 3.1244439d-03/
      data fxyz( 3, 4, 7),fxyz( 3, 4, 8)/-4.3540227d-03, 3.6292279d-03/
      data fxyz( 3, 4, 9),fxyz( 3, 4,10)/ 4.3088591d-04,-8.1725909d-04/
      data fxyz( 3, 4,11),fxyz( 3, 4,12)/ 3.8974134d-04,-1.4511735d-03/
      data fxyz( 3, 4,13),fxyz( 3, 4,14)/ 3.9861986d-04,-8.9338995d-04/
      data fxyz( 3, 4,15),fxyz( 3, 4,16)/ 7.4901844d-04, 3.1021693d-03/
      data fxyz( 3, 4,17),fxyz( 3, 4,18)/-3.7892171d-03, 2.2268357d-03/
      data fxyz( 3, 4,19),fxyz( 3, 4,20)/-1.8275819d-03, 5.6307325d-04/
      data fxyz( 3, 4,21),fxyz( 3, 4,22)/ 3.1765917d-04,-8.4592555d-04/
      data fxyz( 3, 4,23)/               -1.4543755d-03/
      data fxyz( 3, 5, 1),fxyz( 3, 5, 2)/ 1.8703394d-03, 1.0831061d-03/
      data fxyz( 3, 5, 3),fxyz( 3, 5, 4)/-4.7474867d-04,-7.0062804d-04/
      data fxyz( 3, 5, 5),fxyz( 3, 5, 6)/ 1.9866235d-03,-1.5178511d-03/
      data fxyz( 3, 5, 7),fxyz( 3, 5, 8)/ 1.2750724d-03,-9.0605837d-04/
      data fxyz( 3, 5, 9),fxyz( 3, 5,10)/-2.0542255d-04, 3.1074200d-04/
      data fxyz( 3, 5,11),fxyz( 3, 5,12)/-3.5489231d-04, 7.8677550d-04/
      data fxyz( 3, 5,13),fxyz( 3, 5,14)/-4.0557278d-04, 4.8435850d-04/
      data fxyz( 3, 5,15),fxyz( 3, 5,16)/-8.0500001d-04, 4.4071654d-05/
      data fxyz( 3, 5,17),fxyz( 3, 5,18)/ 5.3221783d-04,-7.4041090d-04/
      data fxyz( 3, 5,19),fxyz( 3, 5,20)/ 8.5824967d-04,-2.6723999d-04/
      data fxyz( 3, 5,21),fxyz( 3, 5,22)/-1.6642247d-04, 4.5497959d-04/
      data fxyz( 3, 5,23)/                7.7185189d-04/
      data fxyz( 3, 6, 1),fxyz( 3, 6, 2)/-1.4772084d-03,-8.2690767d-04/
      data fxyz( 3, 6, 3),fxyz( 3, 6, 4)/ 4.9129241d-04, 6.2306985d-04/
      data fxyz( 3, 6, 5),fxyz( 3, 6, 6)/-1.3540174d-03, 4.9945325d-04/
      data fxyz( 3, 6, 7),fxyz( 3, 6, 8)/-2.2044532d-04, 2.1122406d-04/
      data fxyz( 3, 6, 9),fxyz( 3, 6,10)/ 6.5626369d-05,-7.0521902d-05/
      data fxyz( 3, 6,11),fxyz( 3, 6,12)/ 8.4300363d-05,-2.4275721d-04/
      data fxyz( 3, 6,13),fxyz( 3, 6,14)/ 2.0896666d-04,-4.1384711d-04/
      data fxyz( 3, 6,15),fxyz( 3, 6,16)/ 1.1504948d-03,-1.4366802d-03/
      data fxyz( 3, 6,17),fxyz( 3, 6,18)/ 7.2996616d-04,-3.3049159d-05/
      data fxyz( 3, 6,19),fxyz( 3, 6,20)/-2.7644293d-05,-2.7890210d-05/
      data fxyz( 3, 6,21),fxyz( 3, 6,22)/-2.7628203d-05,-2.8692324d-05/
      data fxyz( 3, 6,23)/               -2.9119045d-05/
      data fxyz( 3, 7, 1),fxyz( 3, 7, 2)/ 1.3004083d-03, 6.8088998d-04/
      data fxyz( 3, 7, 3),fxyz( 3, 7, 4)/-6.2788251d-04,-6.6072442d-04/
      data fxyz( 3, 7, 5),fxyz( 3, 7, 6)/ 8.1225762d-04, 8.0777968d-04/
      data fxyz( 3, 7, 7),fxyz( 3, 7, 8)/-6.4406642d-04,-6.6607835d-05/
      data fxyz( 3, 7, 9),fxyz( 3, 7,10)/ 9.9979357d-05,-1.1255664d-04/
      data fxyz( 3, 7,11),fxyz( 3, 7,12)/ 6.5503760d-05, 1.1143900d-04/
      data fxyz( 3, 7,13),fxyz( 3, 7,14)/-1.8176062d-04, 3.0673401d-04/
      data fxyz( 3, 7,15),fxyz( 3, 7,16)/-7.5858910d-04, 9.8977753d-04/
      data fxyz( 3, 7,17),fxyz( 3, 7,18)/-5.0800752d-04,-7.4656466d-06/
      data fxyz( 3, 7,19),fxyz( 3, 7,20)/ 4.8094986d-05, 1.0982670d-05/
      data fxyz( 3, 7,21),fxyz( 3, 7,22)/ 1.4442150d-05, 3.4257065d-05/
      data fxyz( 3, 7,23)/                4.4426554d-05/
      data fxyz( 3, 8, 1),fxyz( 3, 8, 2)/-2.7346675d-05, 6.8687996d-05/
      data fxyz( 3, 8, 3),fxyz( 3, 8, 4)/ 3.4858294d-04, 2.1889680d-04/
      data fxyz( 3, 8, 5),fxyz( 3, 8, 6)/ 5.8743253d-04,-1.9726387d-03/
      data fxyz( 3, 8, 7),fxyz( 3, 8, 8)/ 8.1414810d-04, 4.6718292d-04/
      data fxyz( 3, 8, 9),fxyz( 3, 8,10)/-3.8085333d-04, 2.9358519d-04/
      data fxyz( 3, 8,11),fxyz( 3, 8,12)/-1.4587515d-04,-3.1783554d-04/
      data fxyz( 3, 8,13),fxyz( 3, 8,14)/ 6.0338653d-04,-6.4261322d-04/
      data fxyz( 3, 8,15),fxyz( 3, 8,16)/ 5.7091841d-04,-3.9870461d-04/
      data fxyz( 3, 8,17),fxyz( 3, 8,18)/ 1.5783769d-04, 7.5286488d-05/
      data fxyz( 3, 8,19),fxyz( 3, 8,20)/-1.4357339d-04, 4.3725412d-05/
      data fxyz( 3, 8,21),fxyz( 3, 8,22)/ 2.9187470d-05,-8.5421620d-05/
      data fxyz( 3, 8,23)/               -1.4278265d-04/
      data fxyz( 3, 9, 1),fxyz( 3, 9, 2)/-4.2453284d-04,-2.9454161d-04/
      data fxyz( 3, 9, 3),fxyz( 3, 9, 4)/-7.1198123d-05, 2.5417886d-05/
      data fxyz( 3, 9, 5),fxyz( 3, 9, 6)/-6.8100564d-04, 1.0247073d-03/
      data fxyz( 3, 9, 7),fxyz( 3, 9, 8)/ 2.2880036d-04,-1.0713978d-03/
      data fxyz( 3, 9, 9),fxyz( 3, 9,10)/ 8.1660656d-04,-9.6486081d-04/
      data fxyz( 3, 9,11),fxyz( 3, 9,12)/ 5.1132222d-04, 1.1790779d-03/
      data fxyz( 3, 9,13),fxyz( 3, 9,14)/-2.2113086d-03, 2.2054922d-03/
      data fxyz( 3, 9,15),fxyz( 3, 9,16)/-1.4931637d-03, 6.8438816d-04/
      data fxyz( 3, 9,17),fxyz( 3, 9,18)/-2.7881317d-04,-5.3934387d-05/
      data fxyz( 3, 9,19),fxyz( 3, 9,20)/ 3.7101744d-04,-1.8913974d-04/
      data fxyz( 3, 9,21),fxyz( 3, 9,22)/-1.5655943d-04, 2.4069620d-04/
      data fxyz( 3, 9,23)/                4.3477025d-04/
      data fxyz( 3,10, 1),fxyz( 3,10, 2)/ 1.0374503d-04, 7.2812255d-05/
      data fxyz( 3,10, 3),fxyz( 3,10, 4)/ 1.0400190d-05, 3.6233985d-06/
      data fxyz( 3,10, 5),fxyz( 3,10, 6)/ 9.9919420d-05, 2.0931606d-06/
      data fxyz( 3,10, 7),fxyz( 3,10, 8)/-5.1490926d-04, 8.2192983d-04/
      data fxyz( 3,10, 9),fxyz( 3,10,10)/-9.2199708d-04, 1.6076714d-03/
      data fxyz( 3,10,11),fxyz( 3,10,12)/-9.5769222d-04,-1.6623824d-03/
      data fxyz( 3,10,13),fxyz( 3,10,14)/ 2.8344806d-03,-2.4136464d-03/
      data fxyz( 3,10,15),fxyz( 3,10,16)/ 1.5047003d-03,-5.8824314d-04/
      data fxyz( 3,10,17),fxyz( 3,10,18)/ 1.5230599d-04, 3.3855488d-04/
      data fxyz( 3,10,19),fxyz( 3,10,20)/-1.4635995d-03, 7.9889442d-04/
      data fxyz( 3,10,21),fxyz( 3,10,22)/ 6.6323058d-04,-9.2094413d-04/
      data fxyz( 3,10,23)/               -1.6964027d-03/
      data fxyz( 3,11, 1),fxyz( 3,11, 2)/-1.3454302d-04,-7.8688816d-05/
      data fxyz( 3,11, 3),fxyz( 3,11, 4)/ 3.5038838d-05, 4.5468695d-05/
      data fxyz( 3,11, 5),fxyz( 3,11, 6)/-1.2040824d-04, 2.1904833d-05/
      data fxyz( 3,11, 7),fxyz( 3,11, 8)/ 1.2365876d-04,-2.6022583d-04/
      data fxyz( 3,11, 9),fxyz( 3,11,10)/ 4.6885114d-04,-9.9985596d-04/
      data fxyz( 3,11,11),fxyz( 3,11,12)/ 6.0218745d-04, 1.0052642d-03/
      data fxyz( 3,11,13),fxyz( 3,11,14)/-1.4361322d-03, 9.0341965d-04/
      data fxyz( 3,11,15),fxyz( 3,11,16)/-4.9516225d-04, 1.3995311d-04/
      data fxyz( 3,11,17),fxyz( 3,11,18)/ 1.2167065d-04,-7.2375355d-04/
      data fxyz( 3,11,19),fxyz( 3,11,20)/ 2.7585758d-03,-1.5075166d-03/
      data fxyz( 3,11,21),fxyz( 3,11,22)/-1.2477141d-03, 1.7193659d-03/
      data fxyz( 3,11,23)/                3.1732838d-03/
      data fxyz( 3,12, 1),fxyz( 3,12, 2)/ 7.7439530d-04, 4.1312908d-04/
      data fxyz( 3,12, 3),fxyz( 3,12, 4)/-3.2836361d-04,-3.8549975d-04/
      data fxyz( 3,12, 5),fxyz( 3,12, 6)/ 6.4167364d-04,-8.2646796d-05/
      data fxyz( 3,12, 7),fxyz( 3,12, 8)/-3.2051816d-05, 9.3881205d-05/
      data fxyz( 3,12, 9),fxyz( 3,12,10)/-1.6156745d-04, 2.7395550d-04/
      data fxyz( 3,12,11),fxyz( 3,12,12)/-3.0948030d-05,-4.9702666d-04/
      data fxyz( 3,12,13),fxyz( 3,12,14)/ 5.0816018d-04,-2.4254420d-04/
      data fxyz( 3,12,15),fxyz( 3,12,16)/ 1.1368904d-04,-8.2033138d-06/
      data fxyz( 3,12,17),fxyz( 3,12,18)/-1.2854364d-04, 5.5401486d-04/
      data fxyz( 3,12,19),fxyz( 3,12,20)/-2.0644273d-03, 1.1245114d-03/
      data fxyz( 3,12,21),fxyz( 3,12,22)/ 9.2957718d-04,-1.2846905d-03/
      data fxyz( 3,12,23)/               -2.3699979d-03/
      data fxyz( 3,13, 1),fxyz( 3,13, 2)/-5.1503460d-04,-2.6847050d-04/
      data fxyz( 3,13, 3),fxyz( 3,13, 4)/ 2.4133079d-04, 2.7379393d-04/
      data fxyz( 3,13, 5),fxyz( 3,13, 6)/-3.9832307d-04,-2.8087467d-05/
      data fxyz( 3,13, 7),fxyz( 3,13, 8)/ 4.8058878d-05,-6.2314031d-05/
      data fxyz( 3,13, 9),fxyz( 3,13,10)/ 9.9151926d-05,-5.8258509d-05/
      data fxyz( 3,13,11),fxyz( 3,13,12)/-4.1703796d-04, 8.4273980d-04/
      data fxyz( 3,13,13),fxyz( 3,13,14)/-2.2657615d-04,-4.9894048d-04/
      data fxyz( 3,13,15),fxyz( 3,13,16)/ 3.7699248d-04,-1.0053421d-04/
      data fxyz( 3,13,17),fxyz( 3,13,18)/ 4.0159576d-05,-6.8312326d-05/
      data fxyz( 3,13,19),fxyz( 3,13,20)/ 2.1217690d-04,-1.1173004d-04/
      data fxyz( 3,13,21),fxyz( 3,13,22)/-9.1240520d-05, 1.3021884d-04/
      data fxyz( 3,13,23)/                2.3903041d-04/
      data fxyz( 3,14, 1),fxyz( 3,14, 2)/-1.0536244d-03,-5.6220160d-04/
      data fxyz( 3,14, 3),fxyz( 3,14, 4)/ 4.4175638d-04, 5.2766526d-04/
      data fxyz( 3,14, 5),fxyz( 3,14, 6)/-9.0583711d-04, 2.3500881d-04/
      data fxyz( 3,14, 7),fxyz( 3,14, 8)/-1.1189005d-04, 3.5356464d-05/
      data fxyz( 3,14, 9),fxyz( 3,14,10)/-4.1072932d-07,-1.5491243d-04/
      data fxyz( 3,14,11),fxyz( 3,14,12)/ 7.4153940d-04,-1.1131604d-03/
      data fxyz( 3,14,13),fxyz( 3,14,14)/ 2.2593339d-04, 6.9595712d-04/
      data fxyz( 3,14,15),fxyz( 3,14,16)/-5.1208415d-04, 1.2879196d-04/
      data fxyz( 3,14,17),fxyz( 3,14,18)/-1.4724070d-05,-7.8969336d-05/
      data fxyz( 3,14,19),fxyz( 3,14,20)/ 3.2141347d-04,-1.7659094d-04/
      data fxyz( 3,14,21),fxyz( 3,14,22)/-1.4655368d-04, 2.0126445d-04/
      data fxyz( 3,14,23)/                3.7158951d-04/
      data fxyz( 3,15, 1),fxyz( 3,15, 2)/ 1.0199389d-03, 5.5007711d-04/
      data fxyz( 3,15, 3),fxyz( 3,15, 4)/-4.0951535d-04,-4.9221019d-04/
      data fxyz( 3,15, 5),fxyz( 3,15, 6)/ 8.8085649d-04,-2.2048377d-04/
      data fxyz( 3,15, 7),fxyz( 3,15, 8)/ 6.3841605d-05,-1.1926881d-06/
      data fxyz( 3,15, 9),fxyz( 3,15,10)/-4.6118640d-05, 1.4152770d-04/
      data fxyz( 3,15,11),fxyz( 3,15,12)/-4.0799288d-04, 4.8420156d-04/
      data fxyz( 3,15,13),fxyz( 3,15,14)/-8.8561384d-05,-2.3788599d-04/
      data fxyz( 3,15,15),fxyz( 3,15,16)/ 1.5453030d-04,-3.5632144d-05/
      data fxyz( 3,15,17),fxyz( 3,15,18)/ 7.8867782d-06, 2.4084413d-05/
      data fxyz( 3,15,19),fxyz( 3,15,20)/-7.8322155d-05, 4.8378032d-05/
      data fxyz( 3,15,21),fxyz( 3,15,22)/ 4.0710311d-05,-4.7651271d-05/
      data fxyz( 3,15,23)/               -9.0931401d-05/
      data fxyz( 3,16, 1),fxyz( 3,16, 2)/-1.1444456d-04,-6.9195575d-05/
      data fxyz( 3,16, 3),fxyz( 3,16, 4)/ 2.0296059d-05, 3.3369387d-05/
      data fxyz( 3,16, 5),fxyz( 3,16, 6)/-1.2148889d-04, 8.1655365d-05/
      data fxyz( 3,16, 7),fxyz( 3,16, 8)/-7.8441387d-06,-1.0361124d-05/
      data fxyz( 3,16, 9),fxyz( 3,16,10)/ 2.6498842d-05,-2.0882215d-05/
      data fxyz( 3,16,11),fxyz( 3,16,12)/ 9.0618251d-07, 2.6999955d-04/
      data fxyz( 3,16,13),fxyz( 3,16,14)/-4.8752650d-04, 4.1740340d-04/
      data fxyz( 3,16,15),fxyz( 3,16,16)/-1.5025377d-04, 2.4958731d-05/
      data fxyz( 3,16,17),fxyz( 3,16,18)/-1.9054304d-05,-1.2914896d-05/
      data fxyz( 3,16,19),fxyz( 3,16,20)/ 7.4268221d-06,-2.9877790d-05/
      data fxyz( 3,16,21),fxyz( 3,16,22)/-2.8085834d-05, 2.5899864d-07/
      data fxyz( 3,16,23)/                1.3964442d-05/
      data fxyz( 3,17, 1),fxyz( 3,17, 2)/-9.6174723d-06,-3.6776974d-06/
      data fxyz( 3,17, 3),fxyz( 3,17, 4)/ 9.4744379d-06, 8.7323569d-06/
      data fxyz( 3,17, 5),fxyz( 3,17, 6)/-7.0937338d-07,-2.0748687d-05/
      data fxyz( 3,17, 7),fxyz( 3,17, 8)/ 7.3416729d-06, 2.6303840d-06/
      data fxyz( 3,17, 9),fxyz( 3,17,10)/-3.6545469d-06,-9.2462547d-06/
      data fxyz( 3,17,11),fxyz( 3,17,12)/ 7.2992117d-05,-4.9869349d-04/
      data fxyz( 3,17,13),fxyz( 3,17,14)/ 4.7422294d-04,-4.6584031d-04/
      data fxyz( 3,17,15),fxyz( 3,17,16)/ 1.8663263d-04, 5.4178625d-06/
      data fxyz( 3,17,17),fxyz( 3,17,18)/ 5.0673673d-05, 3.4625194d-05/
      data fxyz( 3,17,19),fxyz( 3,17,20)/ 4.9401281d-05, 6.7673424d-05/
      data fxyz( 3,17,21),fxyz( 3,17,22)/ 6.7970058d-05, 4.8214746d-05/
      data fxyz( 3,17,23)/                3.9074702d-05/
      data fxyz( 3,18, 1),fxyz( 3,18, 2)/-4.8894881d-06,-3.4188037d-06/
      data fxyz( 3,18, 3),fxyz( 3,18, 4)/-6.9859609d-07, 5.6106839d-08/
      data fxyz( 3,18, 5),fxyz( 3,18, 6)/-6.4376154d-06, 6.4310559d-06/
      data fxyz( 3,18, 7),fxyz( 3,18, 8)/-6.0160660d-07,-1.1955408d-06/
      data fxyz( 3,18, 9),fxyz( 3,18,10)/ 4.5963290d-06,-5.7352761d-06/
      data fxyz( 3,18,11),fxyz( 3,18,12)/-1.7849862d-05, 1.9297283d-04/
      data fxyz( 3,18,13),fxyz( 3,18,14)/ 1.1361800d-04, 7.1986272d-05/
      data fxyz( 3,18,15),fxyz( 3,18,16)/-7.8717161d-05,-3.6876013d-05/
      data fxyz( 3,18,17),fxyz( 3,18,18)/-4.5177270d-05,-3.7328383d-05/
      data fxyz( 3,18,19),fxyz( 3,18,20)/-5.6112408d-05,-6.8801618d-05/
      data fxyz( 3,18,21),fxyz( 3,18,22)/-6.9412174d-05,-5.3670182d-05/
      data fxyz( 3,18,23)/               -4.6486733d-05/
      data fxyz( 3,19, 1),fxyz( 3,19, 2)/ 2.8438240d-05, 1.5485514d-05/
      data fxyz( 3,19, 3),fxyz( 3,19, 4)/-1.1056941d-05,-1.3180366d-05/
      data fxyz( 3,19, 5),fxyz( 3,19, 6)/ 2.3979216d-05,-3.4131424d-06/
      data fxyz( 3,19, 7),fxyz( 3,19, 8)/-1.9365744d-06,-2.1648475d-07/
      data fxyz( 3,19, 9),fxyz( 3,19,10)/ 1.8745578d-06, 9.7125837d-08/
      data fxyz( 3,19,11),fxyz( 3,19,12)/-6.2141009d-05, 4.6739361d-04/
      data fxyz( 3,19,13),fxyz( 3,19,14)/ 1.3082860d-04, 2.0379277d-04/
      data fxyz( 3,19,15),fxyz( 3,19,16)/-1.7199947d-04,-7.2669030d-05/
      data fxyz( 3,19,17),fxyz( 3,19,18)/-9.3719950d-05,-7.5140913d-05/
      data fxyz( 3,19,19),fxyz( 3,19,20)/-1.1948663d-04,-1.3841201d-04/
      data fxyz( 3,19,21),fxyz( 3,19,22)/-1.4009780d-04,-1.1274349d-04/
      data fxyz( 3,19,23)/               -1.0042768d-04/
      data fxyz( 4, 1, 1),fxyz( 4, 1, 2)/ 1.4113634d-04, 5.5876471d-05/
      data fxyz( 4, 1, 3),fxyz( 4, 1, 4)/-2.4509829d-06,-2.2010244d-04/
      data fxyz( 4, 1, 5),fxyz( 4, 1, 6)/ 9.2648229d-04,-3.1236355d-03/
      data fxyz( 4, 1, 7),fxyz( 4, 1, 8)/ 5.0419303d-03,-2.2957930d-03/
      data fxyz( 4, 1, 9),fxyz( 4, 1,10)/-8.5401292d-04, 5.0952620d-04/
      data fxyz( 4, 1,11),fxyz( 4, 1,12)/-1.6866111d-04, 4.1865707d-04/
      data fxyz( 4, 1,13),fxyz( 4, 1,14)/ 5.9740563d-06, 2.7546575d-04/
      data fxyz( 4, 1,15),fxyz( 4, 1,16)/-1.0232121d-03,-1.4547188d-03/
      data fxyz( 4, 1,17),fxyz( 4, 1,18)/ 3.9925001d-03,-2.5631113d-03/
      data fxyz( 4, 1,19),fxyz( 4, 1,20)/ 8.1516433d-04,-2.0395399d-04/
      data fxyz( 4, 1,21),fxyz( 4, 1,22)/-2.1017400d-05, 8.3417956d-05/
      data fxyz( 4, 1,23)/                1.8093755d-04/
      data fxyz( 4, 2, 1),fxyz( 4, 2, 2)/ 8.2334065d-05, 3.6681370d-05/
      data fxyz( 4, 2, 3),fxyz( 4, 2, 4)/-6.0745258d-06,-1.0244931d-04/
      data fxyz( 4, 2, 5),fxyz( 4, 2, 6)/ 4.2218052d-04,-1.3632878d-03/
      data fxyz( 4, 2, 7),fxyz( 4, 2, 8)/ 2.1775862d-03,-9.8620868d-04/
      data fxyz( 4, 2, 9),fxyz( 4, 2,10)/-3.7890322d-04, 2.3019180d-04/
      data fxyz( 4, 2,11),fxyz( 4, 2,12)/-7.5631123d-05, 1.7803690d-04/
      data fxyz( 4, 2,13),fxyz( 4, 2,14)/ 1.3253790d-05, 1.0399265d-04/
      data fxyz( 4, 2,15),fxyz( 4, 2,16)/-4.1850554d-04,-6.5500287d-04/
      data fxyz( 4, 2,17),fxyz( 4, 2,18)/ 1.7310827d-03,-1.1039600d-03/
      data fxyz( 4, 2,19),fxyz( 4, 2,20)/ 3.5118767d-04,-8.7150157d-05/
      data fxyz( 4, 2,21),fxyz( 4, 2,22)/-8.3666785d-06, 3.6053756d-05/
      data fxyz( 4, 2,23)/                7.7792220d-05/
      data fxyz( 4, 3, 1),fxyz( 4, 3, 2)/-3.9013860d-04,-1.9984961d-04/
      data fxyz( 4, 3, 3),fxyz( 4, 3, 4)/ 5.6041257d-05, 3.2181598d-04/
      data fxyz( 4, 3, 5),fxyz( 4, 3, 6)/-1.2629485d-03, 3.5964822d-03/
      data fxyz( 4, 3, 7),fxyz( 4, 3, 8)/-5.5330068d-03, 2.4251490d-03/
      data fxyz( 4, 3, 9),fxyz( 4, 3,10)/ 1.0130609d-03,-5.5753024d-04/
      data fxyz( 4, 3,11),fxyz( 4, 3,12)/ 1.6472419d-04,-4.7357701d-04/
      data fxyz( 4, 3,13),fxyz( 4, 3,14)/ 1.0356776d-04,-5.0739316d-04/
      data fxyz( 4, 3,15),fxyz( 4, 3,16)/ 1.2587456d-03, 1.6484268d-03/
      data fxyz( 4, 3,17),fxyz( 4, 3,18)/-4.5334500d-03, 2.9239245d-03/
      data fxyz( 4, 3,19),fxyz( 4, 3,20)/-9.3768998d-04, 2.3141082d-04/
      data fxyz( 4, 3,21),fxyz( 4, 3,22)/ 2.2208534d-05,-1.0088082d-04/
      data fxyz( 4, 3,23)/               -2.1410980d-04/
      data fxyz( 4, 4, 1),fxyz( 4, 4, 2)/ 5.8523511d-04, 3.2429498d-04/
      data fxyz( 4, 4, 3),fxyz( 4, 4, 4)/-1.1193060d-04,-3.2706132d-04/
      data fxyz( 4, 4, 5),fxyz( 4, 4, 6)/ 1.1848179d-03,-2.6417257d-03/
      data fxyz( 4, 4, 7),fxyz( 4, 4, 8)/ 3.7182717d-03,-1.5197000d-03/
      data fxyz( 4, 4, 9),fxyz( 4, 4,10)/-8.0396552d-04, 4.3410445d-04/
      data fxyz( 4, 4,11),fxyz( 4, 4,12)/-1.1055911d-04, 3.1328714d-04/
      data fxyz( 4, 4,13),fxyz( 4, 4,14)/-9.6738100d-05, 4.2091552d-04/
      data fxyz( 4, 4,15),fxyz( 4, 4,16)/-8.1790933d-04,-1.3111416d-03/
      data fxyz( 4, 4,17),fxyz( 4, 4,18)/ 3.2129207d-03,-2.0387569d-03/
      data fxyz( 4, 4,19),fxyz( 4, 4,20)/ 6.6058585d-04,-1.5617820d-04/
      data fxyz( 4, 4,21),fxyz( 4, 4,22)/-9.9519736d-06, 7.5680926d-05/
      data fxyz( 4, 4,23)/                1.5463661d-04/
      data fxyz( 4, 5, 1),fxyz( 4, 5, 2)/-7.6292788d-04,-4.3280544d-04/
      data fxyz( 4, 5, 3),fxyz( 4, 5, 4)/ 2.0546115d-04, 3.2645376d-04/
      data fxyz( 4, 5, 5),fxyz( 4, 5, 6)/-9.1677590d-04, 1.0519614d-03/
      data fxyz( 4, 5, 7),fxyz( 4, 5, 8)/-1.0915030d-03, 3.7767193d-04/
      data fxyz( 4, 5, 9),fxyz( 4, 5,10)/ 3.0368663d-04,-1.6846059d-04/
      data fxyz( 4, 5,11),fxyz( 4, 5,12)/ 3.8148503d-05,-8.7558113d-05/
      data fxyz( 4, 5,13),fxyz( 4, 5,14)/ 4.0869582d-05,-1.7667702d-04/
      data fxyz( 4, 5,15),fxyz( 4, 5,16)/ 3.0470594d-04, 3.1357529d-04/
      data fxyz( 4, 5,17),fxyz( 4, 5,18)/-8.3240816d-04, 5.0060852d-04/
      data fxyz( 4, 5,19),fxyz( 4, 5,20)/-1.1423892d-04, 1.1802289d-05/
      data fxyz( 4, 5,21),fxyz( 4, 5,22)/-2.0175559d-05, 1.3672470d-05/
      data fxyz( 4, 5,23)/                2.0940791d-05/
      data fxyz( 4, 6, 1),fxyz( 4, 6, 2)/ 2.0672848d-03, 1.1578207d-03/
      data fxyz( 4, 6, 3),fxyz( 4, 6, 4)/-6.7397546d-04,-8.7882266d-04/
      data fxyz( 4, 6, 5),fxyz( 4, 6, 6)/ 1.9772094d-03,-1.0054231d-03/
      data fxyz( 4, 6, 7),fxyz( 4, 6, 8)/ 5.0219496d-04,-2.1468322d-04/
      data fxyz( 4, 6, 9),fxyz( 4, 6,10)/-4.8181112d-05, 3.1973886d-05/
      data fxyz( 4, 6,11),fxyz( 4, 6,12)/-6.7413970d-06, 3.8007376d-05/
      data fxyz( 4, 6,13),fxyz( 4, 6,14)/-5.9801908d-05, 1.8751775d-04/
      data fxyz( 4, 6,15),fxyz( 4, 6,16)/-5.3287460d-04, 6.0866257d-04/
      data fxyz( 4, 6,17),fxyz( 4, 6,18)/-2.3246109d-04, 2.3864690d-05/
      data fxyz( 4, 6,19),fxyz( 4, 6,20)/-6.4780559d-05, 3.1722071d-05/
      data fxyz( 4, 6,21),fxyz( 4, 6,22)/ 2.5376511d-05,-3.9398317d-05/
      data fxyz( 4, 6,23)/               -7.1318719d-05/
      data fxyz( 4, 7, 1),fxyz( 4, 7, 2)/-2.9050581d-03,-1.6023425d-03/
      data fxyz( 4, 7, 3),fxyz( 4, 7, 4)/ 1.0480200d-03, 1.2950689d-03/
      data fxyz( 4, 7, 5),fxyz( 4, 7, 6)/-2.5905384d-03, 8.0067618d-04/
      data fxyz( 4, 7, 7),fxyz( 4, 7, 8)/-3.5457744d-04, 3.7420906d-04/
      data fxyz( 4, 7, 9),fxyz( 4, 7,10)/-1.1592427d-04, 5.4399741d-05/
      data fxyz( 4, 7,11),fxyz( 4, 7,12)/-2.8023725d-05,-2.5774580d-05/
      data fxyz( 4, 7,13),fxyz( 4, 7,14)/ 6.5970555d-05,-1.5370563d-04/
      data fxyz( 4, 7,15),fxyz( 4, 7,16)/ 4.3444453d-04,-5.9012725d-04/
      data fxyz( 4, 7,17),fxyz( 4, 7,18)/ 3.1352362d-04,-4.5398006d-05/
      data fxyz( 4, 7,19),fxyz( 4, 7,20)/ 1.2663346d-05,-8.7656474d-06/
      data fxyz( 4, 7,21),fxyz( 4, 7,22)/-5.5348777d-06,-2.5973274d-07/
      data fxyz( 4, 7,23)/                3.0635401d-06/
      data fxyz( 4, 8, 1),fxyz( 4, 8, 2)/ 1.3588555d-03, 7.0596525d-04/
      data fxyz( 4, 8, 3),fxyz( 4, 8, 4)/-6.2125322d-04,-7.4695922d-04/
      data fxyz( 4, 8, 5),fxyz( 4, 8, 6)/ 1.2087893d-03,-5.2673464d-04/
      data fxyz( 4, 8, 7),fxyz( 4, 8, 8)/ 1.4081361d-03,-1.3821575d-03/
      data fxyz( 4, 8, 9),fxyz( 4, 8,10)/ 4.8684434d-04,-1.8862909d-04/
      data fxyz( 4, 8,11),fxyz( 4, 8,12)/ 7.0049714d-05, 7.7070433d-05/
      data fxyz( 4, 8,13),fxyz( 4, 8,14)/-1.6519597d-04, 1.9080252d-04/
      data fxyz( 4, 8,15),fxyz( 4, 8,16)/-2.1414548d-04, 1.9275323d-04/
      data fxyz( 4, 8,17),fxyz( 4, 8,18)/-8.8922211d-05,-1.1886957d-05/
      data fxyz( 4, 8,19),fxyz( 4, 8,20)/ 4.5083098d-05,-1.6450498d-05/
      data fxyz( 4, 8,21),fxyz( 4, 8,22)/-1.2383138d-05, 2.8813655d-05/
      data fxyz( 4, 8,23)/                4.9123455d-05/
      data fxyz( 4, 9, 1),fxyz( 4, 9, 2)/-7.4878001d-05, 3.7705437d-06/
      data fxyz( 4, 9, 3),fxyz( 4, 9, 4)/ 1.1980629d-04, 2.1167577d-04/
      data fxyz( 4, 9, 5),fxyz( 4, 9, 6)/-3.6370739d-04, 1.3031642d-03/
      data fxyz( 4, 9, 7),fxyz( 4, 9, 8)/-3.0572598d-03, 2.5815330d-03/
      data fxyz( 4, 9, 9),fxyz( 4, 9,10)/-1.0295337d-03, 5.0384394d-04/
      data fxyz( 4, 9,11),fxyz( 4, 9,12)/-2.0450164d-04,-2.9807785d-04/
      data fxyz( 4, 9,13),fxyz( 4, 9,14)/ 5.8913405d-04,-5.9414500d-04/
      data fxyz( 4, 9,15),fxyz( 4, 9,16)/ 4.1455028d-04,-2.0453217d-04/
      data fxyz( 4, 9,17),fxyz( 4, 9,18)/ 8.3356890d-05, 2.4777807d-05/
      data fxyz( 4, 9,19),fxyz( 4, 9,20)/-1.4636620d-04, 7.6819287d-05/
      data fxyz( 4, 9,21),fxyz( 4, 9,22)/ 6.3751380d-05,-9.4094573d-05/
      data fxyz( 4, 9,23)/               -1.7124079d-04/
      data fxyz( 4,10, 1),fxyz( 4,10, 2)/ 1.3561468d-05,-9.9453732d-06/
      data fxyz( 4,10, 3),fxyz( 4,10, 4)/-1.4334761d-05,-9.4803987d-05/
      data fxyz( 4,10, 5),fxyz( 4,10, 6)/ 3.1193153d-04,-1.1934769d-03/
      data fxyz( 4,10, 7),fxyz( 4,10, 8)/ 2.3379116d-03,-2.0452479d-03/
      data fxyz( 4,10, 9),fxyz( 4,10,10)/ 1.0662295d-03,-7.3125120d-04/
      data fxyz( 4,10,11),fxyz( 4,10,12)/ 3.4859475d-04, 4.2214548d-04/
      data fxyz( 4,10,13),fxyz( 4,10,14)/-7.5332466d-04, 6.4560681d-04/
      data fxyz( 4,10,15),fxyz( 4,10,16)/-4.0517675d-04, 1.5911488d-04/
      data fxyz( 4,10,17),fxyz( 4,10,18)/-2.9937067d-05,-1.4127030d-04/
      data fxyz( 4,10,19),fxyz( 4,10,20)/ 5.8277774d-04,-3.1823607d-04/
      data fxyz( 4,10,21),fxyz( 4,10,22)/-2.6390754d-04, 3.6546360d-04/
      data fxyz( 4,10,23)/                6.7365774d-04/
      data fxyz( 4,11, 1),fxyz( 4,11, 2)/ 1.0893264d-04, 6.0458306d-05/
      data fxyz( 4,11, 3),fxyz( 4,11, 4)/-5.2447948d-05,-3.6640736d-05/
      data fxyz( 4,11, 5),fxyz( 4,11, 6)/-2.7705421d-06, 3.4604082d-04/
      data fxyz( 4,11, 7),fxyz( 4,11, 8)/-7.0561604d-04, 7.1307962d-04/
      data fxyz( 4,11, 9),fxyz( 4,11,10)/-4.8987928d-04, 4.4596790d-04/
      data fxyz( 4,11,11),fxyz( 4,11,12)/-2.3721162d-04,-2.4880683d-04/
      data fxyz( 4,11,13),fxyz( 4,11,14)/ 3.8031611d-04,-2.3993367d-04/
      data fxyz( 4,11,15),fxyz( 4,11,16)/ 1.2964191d-04,-2.5130828d-05/
      data fxyz( 4,11,17),fxyz( 4,11,18)/-8.2722070d-05, 3.8319446d-04/
      data fxyz( 4,11,19),fxyz( 4,11,20)/-1.4499472d-03, 7.9305004d-04/
      data fxyz( 4,11,21),fxyz( 4,11,22)/ 6.5634718d-04,-9.0313573d-04/
      data fxyz( 4,11,23)/               -1.6673485d-03/
      data fxyz( 4,12, 1),fxyz( 4,12, 2)/-1.4053885d-04,-7.7517699d-05/
      data fxyz( 4,12, 3),fxyz( 4,12, 4)/ 5.6174993d-05, 5.8542087d-05/
      data fxyz( 4,12, 5),fxyz( 4,12, 6)/-8.6986072d-05,-1.0503245d-04/
      data fxyz( 4,12, 7),fxyz( 4,12, 8)/ 2.1188778d-04,-1.5278987d-04/
      data fxyz( 4,12, 9),fxyz( 4,12,10)/ 5.1527652d-05,-3.7222182d-05/
      data fxyz( 4,12,11),fxyz( 4,12,12)/-7.2051044d-06, 1.3591238d-04/
      data fxyz( 4,12,13),fxyz( 4,12,14)/-1.3932423d-04, 6.5343096d-05/
      data fxyz( 4,12,15),fxyz( 4,12,16)/-2.7675454d-05,-8.2838858d-06/
      data fxyz( 4,12,17),fxyz( 4,12,18)/ 7.7134151d-05,-3.0509598d-04/
      data fxyz( 4,12,19),fxyz( 4,12,20)/ 1.1524849d-03,-6.3195870d-04/
      data fxyz( 4,12,21),fxyz( 4,12,22)/-5.2324092d-04, 7.1761375d-04/
      data fxyz( 4,12,23)/                1.3256707d-03/
      data fxyz( 4,13, 1),fxyz( 4,13, 2)/-5.7676959d-05,-3.1017168d-05/
      data fxyz( 4,13, 3),fxyz( 4,13, 4)/ 1.9534830d-05, 3.1043049d-05/
      data fxyz( 4,13, 5),fxyz( 4,13, 6)/-7.7050043d-05, 1.1494632d-04/
      data fxyz( 4,13, 7),fxyz( 4,13, 8)/-1.2297633d-04, 5.7065625d-05/
      data fxyz( 4,13, 9),fxyz( 4,13,10)/ 7.7317068d-06,-7.7282254d-05/
      data fxyz( 4,13,11),fxyz( 4,13,12)/ 2.0021952d-04,-2.7317274d-04/
      data fxyz( 4,13,13),fxyz( 4,13,14)/ 8.0466798d-05, 1.2741648d-04/
      data fxyz( 4,13,15),fxyz( 4,13,16)/-9.7217274d-05, 1.7258188d-05/
      data fxyz( 4,13,17),fxyz( 4,13,18)/ 2.2639888d-05,-1.0916550d-04/
      data fxyz( 4,13,19),fxyz( 4,13,20)/ 4.0000813d-04,-2.1748877d-04/
      data fxyz( 4,13,21),fxyz( 4,13,22)/-1.7964040d-04, 2.4861468d-04/
      data fxyz( 4,13,23)/                4.5855994d-04/
      data fxyz( 4,14, 1),fxyz( 4,14, 2)/ 1.8847372d-04, 1.1356968d-04/
      data fxyz( 4,14, 3),fxyz( 4,14, 4)/-3.3324713d-05,-5.7149668d-05/
      data fxyz( 4,14, 5),fxyz( 4,14, 6)/ 2.0886950d-04,-1.6890061d-04/
      data fxyz( 4,14, 7),fxyz( 4,14, 8)/ 6.0772072d-05,-3.1065788d-05/
      data fxyz( 4,14, 9),fxyz( 4,14,10)/ 4.0894598d-06, 5.5854654d-05/
      data fxyz( 4,14,11),fxyz( 4,14,12)/-2.5183811d-04, 3.7302872d-04/
      data fxyz( 4,14,13),fxyz( 4,14,14)/-1.1282759d-04,-1.7157623d-04/
      data fxyz( 4,14,15),fxyz( 4,14,16)/ 1.3068965d-04,-2.0917345d-05/
      data fxyz( 4,14,17),fxyz( 4,14,18)/-4.2396822d-05, 1.9191858d-04/
      data fxyz( 4,14,19),fxyz( 4,14,20)/-7.2186489d-04, 3.9778242d-04/
      data fxyz( 4,14,21),fxyz( 4,14,22)/ 3.2960430d-04,-4.4915244d-04/
      data fxyz( 4,14,23)/               -8.3075309d-04/
      data fxyz( 4,15, 1),fxyz( 4,15, 2)/-1.8416595d-04,-1.0568483d-04/
      data fxyz( 4,15, 3),fxyz( 4,15, 4)/ 5.1529816d-05, 7.0708417d-05/
      data fxyz( 4,15, 5),fxyz( 4,15, 6)/-1.8239923d-04, 1.0351306d-04/
      data fxyz( 4,15, 7),fxyz( 4,15, 8)/-2.3118870d-05,-3.9491923d-06/
      data fxyz( 4,15, 9),fxyz( 4,15,10)/ 3.4844968d-05,-1.2121884d-04/
      data fxyz( 4,15,11),fxyz( 4,15,12)/ 3.0396813d-04,-3.8168490d-04/
      data fxyz( 4,15,13),fxyz( 4,15,14)/ 2.0298693d-04, 1.3387053d-05/
      data fxyz( 4,15,15),fxyz( 4,15,16)/-3.0144177d-05, 3.7429269d-07/
      data fxyz( 4,15,17),fxyz( 4,15,18)/ 8.9892453d-06,-5.3676641d-05/
      data fxyz( 4,15,19),fxyz( 4,15,20)/ 1.9219226d-04,-1.1325304d-04/
      data fxyz( 4,15,21),fxyz( 4,15,22)/-9.4815856d-05, 1.1844352d-04/
      data fxyz( 4,15,23)/                2.2288114d-04/
      data fxyz( 4,16, 1),fxyz( 4,16, 2)/ 1.2715418d-04, 7.0226089d-05/
      data fxyz( 4,16, 3),fxyz( 4,16, 4)/-4.4836749d-05,-5.6957137d-05/
      data fxyz( 4,16, 5),fxyz( 4,16, 6)/ 1.1870764d-04,-5.4651638d-05/
      data fxyz( 4,16, 7),fxyz( 4,16, 8)/ 1.5334921d-05, 1.9962885d-05/
      data fxyz( 4,16, 9),fxyz( 4,16,10)/-7.9575792d-05, 2.7967584d-04/
      data fxyz( 4,16,11),fxyz( 4,16,12)/-7.2096753d-04, 9.1920077d-04/
      data fxyz( 4,16,13),fxyz( 4,16,14)/-5.8048815d-04, 8.4664841d-05/
      data fxyz( 4,16,15),fxyz( 4,16,16)/-2.0418092d-06, 1.7011167d-05/
      data fxyz( 4,16,17),fxyz( 4,16,18)/ 7.7390368d-06, 2.5593818d-05/
      data fxyz( 4,16,19),fxyz( 4,16,20)/-3.6755640d-05, 4.6390470d-05/
      data fxyz( 4,16,21),fxyz( 4,16,22)/ 4.1589000d-05,-1.7549758d-05/
      data fxyz( 4,16,23)/               -4.6428238d-05/
      data fxyz( 4,17, 1),fxyz( 4,17, 2)/-4.8746143d-05,-2.9903142d-05/
      data fxyz( 4,17, 3),fxyz( 4,17, 4)/ 7.0908189d-06, 1.3012640d-05/
      data fxyz( 4,17, 5),fxyz( 4,17, 6)/-5.3590427d-05, 4.0081172d-05/
      data fxyz( 4,17, 7),fxyz( 4,17, 8)/-2.5957922d-06,-2.1366744d-05/
      data fxyz( 4,17, 9),fxyz( 4,17,10)/ 9.4655308d-05,-3.4518758d-04/
      data fxyz( 4,17,11),fxyz( 4,17,12)/ 1.0278188d-03,-1.5858570d-03/
      data fxyz( 4,17,13),fxyz( 4,17,14)/ 1.4242221d-03,-3.1521182d-04/
      data fxyz( 4,17,15),fxyz( 4,17,16)/ 2.8166219d-05,-6.5998646d-05/
      data fxyz( 4,17,17),fxyz( 4,17,18)/-3.9646960d-05,-4.7379782d-05/
      data fxyz( 4,17,19),fxyz( 4,17,20)/-4.3783148d-05,-7.4770970d-05/
      data fxyz( 4,17,21),fxyz( 4,17,22)/-7.3913804d-05,-4.7211810d-05/
      data fxyz( 4,17,23)/               -3.4522301d-05/
      data fxyz( 4,18, 1),fxyz( 4,18, 2)/ 1.1918724d-05, 6.6859660d-06/
      data fxyz( 4,18, 3),fxyz( 4,18, 4)/-3.8453275d-06,-5.0384077d-06/
      data fxyz( 4,18, 5),fxyz( 4,18, 6)/ 1.1458287d-05,-5.9774794d-06/
      data fxyz( 4,18, 7),fxyz( 4,18, 8)/-1.4071737d-06, 1.2593563d-05/
      data fxyz( 4,18, 9),fxyz( 4,18,10)/-4.8212012d-05, 1.6940504d-04/
      data fxyz( 4,18,11),fxyz( 4,18,12)/-4.9138627d-04, 8.9978642d-04/
      data fxyz( 4,18,13),fxyz( 4,18,14)/-1.1471305d-03, 3.0885468d-04/
      data fxyz( 4,18,15),fxyz( 4,18,16)/-2.4374388d-05, 6.8000611d-05/
      data fxyz( 4,18,17),fxyz( 4,18,18)/ 4.2804592d-05, 4.6919343d-05/
      data fxyz( 4,18,19),fxyz( 4,18,20)/ 5.6851668d-05, 7.2621854d-05/
      data fxyz( 4,18,21),fxyz( 4,18,22)/ 7.2743986d-05, 5.6363142d-05/
      data fxyz( 4,18,23)/                4.8751317d-05/
      data fxyz( 4,19, 1),fxyz( 4,19, 2)/ 4.9935366d-06, 4.2126918d-06/
      data fxyz( 4,19, 3),fxyz( 4,19, 4)/ 3.1795875d-06, 2.0593518d-06/
      data fxyz( 4,19, 5),fxyz( 4,19, 6)/ 8.6936346d-06,-1.1809999d-05/
      data fxyz( 4,19, 7),fxyz( 4,19, 8)/-5.6812214d-06, 2.5042460d-05/
      data fxyz( 4,19, 9),fxyz( 4,19,10)/-1.0047978d-04, 3.5843880d-04/
      data fxyz( 4,19,11),fxyz( 4,19,12)/-1.0768795d-03, 1.9595152d-03/
      data fxyz( 4,19,13),fxyz( 4,19,14)/-2.4110365d-03, 6.4036600d-04/
      data fxyz( 4,19,15),fxyz( 4,19,16)/-5.3272529d-05, 1.3999728d-04/
      data fxyz( 4,19,17),fxyz( 4,19,18)/ 8.8159701d-05, 9.3426261d-05/
      data fxyz( 4,19,19),fxyz( 4,19,20)/ 1.2672582d-04, 1.4328489d-04/
      data fxyz( 4,19,21),fxyz( 4,19,22)/ 1.4449875d-04, 1.2187038d-04/
      data fxyz( 4,19,23)/                1.1163417d-04/
      data fxyz( 5, 1, 1),fxyz( 5, 1, 2)/-4.9033900d-05,-4.0078839d-05/
      data fxyz( 5, 1, 3),fxyz( 5, 1, 4)/ 1.7580113d-06,-3.7874996d-05/
      data fxyz( 5, 1, 5),fxyz( 5, 1, 6)/ 1.1845319d-04,-6.4352901d-04/
      data fxyz( 5, 1, 7),fxyz( 5, 1, 8)/ 1.4892861d-03,-1.3020388d-03/
      data fxyz( 5, 1, 9),fxyz( 5, 1,10)/ 6.6947694d-04,-3.4945011d-04/
      data fxyz( 5, 1,11),fxyz( 5, 1,12)/ 2.9324321d-04,-4.6615355d-04/
      data fxyz( 5, 1,13),fxyz( 5, 1,14)/ 2.3542724d-04,-2.5034044d-04/
      data fxyz( 5, 1,15),fxyz( 5, 1,16)/ 7.4641673d-04,-1.8979708d-03/
      data fxyz( 5, 1,17),fxyz( 5, 1,18)/ 2.4716010d-03,-1.3233975d-03/
      data fxyz( 5, 1,19),fxyz( 5, 1,20)/ 3.6806747d-04,-9.7125878d-05/
      data fxyz( 5, 1,21),fxyz( 5, 1,22)/-6.5299017d-06, 5.6835634d-06/
      data fxyz( 5, 1,23)/                3.5542107d-05/
      data fxyz( 5, 2, 1),fxyz( 5, 2, 2)/-4.5483950d-05,-3.0979066d-05/
      data fxyz( 5, 2, 3),fxyz( 5, 2, 4)/ 8.6192653d-06,-6.2844952d-06/
      data fxyz( 5, 2, 5),fxyz( 5, 2, 6)/ 2.8635976d-05,-2.6904036d-04/
      data fxyz( 5, 2, 7),fxyz( 5, 2, 8)/ 6.3709889d-04,-5.5487004d-04/
      data fxyz( 5, 2, 9),fxyz( 5, 2,10)/ 2.9173752d-04,-1.4846346d-04/
      data fxyz( 5, 2,11),fxyz( 5, 2,12)/ 1.1036493d-04,-1.8111446d-04/
      data fxyz( 5, 2,13),fxyz( 5, 2,14)/ 7.6244828d-05,-8.7985106d-05/
      data fxyz( 5, 2,15),fxyz( 5, 2,16)/ 2.9180032d-04,-7.6736710d-04/
      data fxyz( 5, 2,17),fxyz( 5, 2,18)/ 1.0380802d-03,-5.6952665d-04/
      data fxyz( 5, 2,19),fxyz( 5, 2,20)/ 1.5166083d-04,-3.7068162d-05/
      data fxyz( 5, 2,21),fxyz( 5, 2,22)/ 1.3461262d-06,-1.9963245d-06/
      data fxyz( 5, 2,23)/                6.6876755d-06/
      data fxyz( 5, 3, 1),fxyz( 5, 3, 2)/ 1.2771174d-04, 8.2688786d-05/
      data fxyz( 5, 3, 3),fxyz( 5, 3, 4)/-3.5463417d-05, 2.4668552d-06/
      data fxyz( 5, 3, 5),fxyz( 5, 3, 6)/-6.9032302d-05, 6.9666582d-04/
      data fxyz( 5, 3, 7),fxyz( 5, 3, 8)/-1.6318270d-03, 1.5236387d-03/
      data fxyz( 5, 3, 9),fxyz( 5, 3,10)/-8.3937219d-04, 3.9035831d-04/
      data fxyz( 5, 3,11),fxyz( 5, 3,12)/-2.3099759d-04, 3.5524640d-04/
      data fxyz( 5, 3,13),fxyz( 5, 3,14)/-2.4376029d-04, 3.8986640d-04/
      data fxyz( 5, 3,15),fxyz( 5, 3,16)/-9.3808508d-04, 2.0412605d-03/
      data fxyz( 5, 3,17),fxyz( 5, 3,18)/-2.5172449d-03, 1.3384478d-03/
      data fxyz( 5, 3,19),fxyz( 5, 3,20)/-3.2765762d-04, 6.7142545d-05/
      data fxyz( 5, 3,21),fxyz( 5, 3,22)/-2.0690311d-05, 2.3673811d-05/
      data fxyz( 5, 3,23)/                2.0954973d-05/
      data fxyz( 5, 4, 1),fxyz( 5, 4, 2)/-2.9285266d-04,-1.6963164d-04/
      data fxyz( 5, 4, 3),fxyz( 5, 4, 4)/ 9.8757677d-05, 9.1155231d-05/
      data fxyz( 5, 4, 5),fxyz( 5, 4, 6)/-1.3922185d-04,-4.0688936d-04/
      data fxyz( 5, 4, 7),fxyz( 5, 4, 8)/ 1.0578324d-03,-1.0575422d-03/
      data fxyz( 5, 4, 9),fxyz( 5, 4,10)/ 6.6631413d-04,-2.5324282d-04/
      data fxyz( 5, 4,11),fxyz( 5, 4,12)/-1.7665294d-05, 1.1981065d-05/
      data fxyz( 5, 4,13),fxyz( 5, 4,14)/-8.8591846d-07,-2.3651869d-04/
      data fxyz( 5, 4,15),fxyz( 5, 4,16)/ 5.4547099d-04,-1.0231956d-03/
      data fxyz( 5, 4,17),fxyz( 5, 4,18)/ 1.3537449d-03,-7.9294028d-04/
      data fxyz( 5, 4,19),fxyz( 5, 4,20)/ 1.1321526d-04, 1.6817780d-05/
      data fxyz( 5, 4,21),fxyz( 5, 4,22)/ 6.1966880d-05,-6.7381135d-05/
      data fxyz( 5, 4,23)/               -1.1570378d-04/
      data fxyz( 5, 5, 1),fxyz( 5, 5, 2)/ 3.8990098d-04, 2.1512703d-04/
      data fxyz( 5, 5, 3),fxyz( 5, 5, 4)/-1.4533816d-04,-1.6992641d-04/
      data fxyz( 5, 5, 5),fxyz( 5, 5, 6)/ 3.1348003d-04, 2.1077208d-05/
      data fxyz( 5, 5, 7),fxyz( 5, 5, 8)/-2.3694143d-04, 2.8964293d-04/
      data fxyz( 5, 5, 9),fxyz( 5, 5,10)/-2.3997573d-04, 6.1848941d-05/
      data fxyz( 5, 5,11),fxyz( 5, 5,12)/ 1.1752457d-04,-1.6100020d-04/
      data fxyz( 5, 5,13),fxyz( 5, 5,14)/ 1.2403413d-04, 6.0324668d-06/
      data fxyz( 5, 5,15),fxyz( 5, 5,16)/ 3.1157766d-05,-1.2065574d-04/
      data fxyz( 5, 5,17),fxyz( 5, 5,18)/-1.0337232d-04, 2.1749747d-04/
      data fxyz( 5, 5,19),fxyz( 5, 5,20)/-1.2229395d-05,-3.8658265d-05/
      data fxyz( 5, 5,21),fxyz( 5, 5,22)/-4.8977571d-05, 2.9047831d-05/
      data fxyz( 5, 5,23)/                6.2707870d-05/
      data fxyz( 5, 6, 1),fxyz( 5, 6, 2)/-8.1448364d-04,-4.4531759d-04/
      data fxyz( 5, 6, 3),fxyz( 5, 6, 4)/ 3.0658358d-04, 3.7512923d-04/
      data fxyz( 5, 6, 5),fxyz( 5, 6, 6)/-7.1950017d-04, 2.1370102d-04/
      data fxyz( 5, 6, 7),fxyz( 5, 6, 8)/-3.5665041d-05,-2.5162929d-05/
      data fxyz( 5, 6, 9),fxyz( 5, 6,10)/ 4.9545177d-05,-1.1810715d-05/
      data fxyz( 5, 6,11),fxyz( 5, 6,12)/-3.0214152d-05, 3.6529806d-05/
      data fxyz( 5, 6,13),fxyz( 5, 6,14)/-1.6443139d-05,-2.8239142d-05/
      data fxyz( 5, 6,15),fxyz( 5, 6,16)/ 2.0226413d-05, 1.6169261d-06/
      data fxyz( 5, 6,17),fxyz( 5, 6,18)/ 7.2676310d-05,-1.2160019d-04/
      data fxyz( 5, 6,19),fxyz( 5, 6,20)/ 5.8303260d-05,-4.7472419d-06/
      data fxyz( 5, 6,21),fxyz( 5, 6,22)/ 5.1891672d-06, 1.8557624d-05/
      data fxyz( 5, 6,23)/                2.7445946d-05/
      data fxyz( 5, 7, 1),fxyz( 5, 7, 2)/ 1.0571412d-03, 5.6955036d-04/
      data fxyz( 5, 7, 3),fxyz( 5, 7, 4)/-4.2591472d-04,-5.1231651d-04/
      data fxyz( 5, 7, 5),fxyz( 5, 7, 6)/ 9.1515749d-04,-2.3888551d-04/
      data fxyz( 5, 7, 7),fxyz( 5, 7, 8)/ 1.8259873d-04,-1.4948958d-04/
      data fxyz( 5, 7, 9),fxyz( 5, 7,10)/ 3.6825024d-05,-1.6838393d-05/
      data fxyz( 5, 7,11),fxyz( 5, 7,12)/ 1.5549542d-05,-3.5088033d-06/
      data fxyz( 5, 7,13),fxyz( 5, 7,14)/-1.4604439d-05, 4.3649879d-05/
      data fxyz( 5, 7,15),fxyz( 5, 7,16)/-8.8883297d-05, 1.1559350d-04/
      data fxyz( 5, 7,17),fxyz( 5, 7,18)/-8.7787274d-05, 4.4544113d-05/
      data fxyz( 5, 7,19),fxyz( 5, 7,20)/-2.4835776d-05, 7.9525703d-06/
      data fxyz( 5, 7,21),fxyz( 5, 7,22)/ 3.9328970d-06,-8.7570829d-06/
      data fxyz( 5, 7,23)/               -1.5750986d-05/
      data fxyz( 5, 8, 1),fxyz( 5, 8, 2)/-4.1128869d-04,-2.0104099d-04/
      data fxyz( 5, 8, 3),fxyz( 5, 8, 4)/ 2.2046241d-04, 2.7126033d-04/
      data fxyz( 5, 8, 5),fxyz( 5, 8, 6)/-4.0423268d-04, 3.5068017d-04/
      data fxyz( 5, 8, 7),fxyz( 5, 8, 8)/-8.4220108d-04, 6.5379135d-04/
      data fxyz( 5, 8, 9),fxyz( 5, 8,10)/-1.8888174d-04, 6.3458901d-05/
      data fxyz( 5, 8,11),fxyz( 5, 8,12)/-2.4133913d-05,-1.7050235d-05/
      data fxyz( 5, 8,13),fxyz( 5, 8,14)/ 4.3438602d-05,-5.2015838d-05/
      data fxyz( 5, 8,15),fxyz( 5, 8,16)/ 4.9562880d-05,-4.0086770d-05/
      data fxyz( 5, 8,17),fxyz( 5, 8,18)/ 2.4442329d-05,-6.2148683d-06/
      data fxyz( 5, 8,19),fxyz( 5, 8,20)/-4.7540954d-06, 2.8481065d-06/
      data fxyz( 5, 8,21),fxyz( 5, 8,22)/ 2.7490438d-06,-4.3578445d-06/
      data fxyz( 5, 8,23)/               -7.7008091d-06/
      data fxyz( 5, 9, 1),fxyz( 5, 9, 2)/-4.5194604d-05,-4.6261945d-05/
      data fxyz( 5, 9, 3),fxyz( 5, 9, 4)/-1.9346404d-05,-7.0451128d-05/
      data fxyz( 5, 9, 5),fxyz( 5, 9, 6)/ 1.5815695d-04,-8.1176546d-04/
      data fxyz( 5, 9, 7),fxyz( 5, 9, 8)/ 1.6268262d-03,-1.1470968d-03/
      data fxyz( 5, 9, 9),fxyz( 5, 9,10)/ 3.3942554d-04,-1.3844561d-04/
      data fxyz( 5, 9,11),fxyz( 5, 9,12)/ 5.6536280d-05, 7.8683464d-05/
      data fxyz( 5, 9,13),fxyz( 5, 9,14)/-1.5725404d-04, 1.5875371d-04/
      data fxyz( 5, 9,15),fxyz( 5, 9,16)/-1.0814557d-04, 5.0828954d-05/
      data fxyz( 5, 9,17),fxyz( 5, 9,18)/-2.2140404d-05,-3.9486812d-06/
      data fxyz( 5, 9,19),fxyz( 5, 9,20)/ 3.7265634d-05,-2.0075955d-05/
      data fxyz( 5, 9,21),fxyz( 5, 9,22)/-1.6849354d-05, 2.4359231d-05/
      data fxyz( 5, 9,23)/                4.4450330d-05/
      data fxyz( 5,10, 1),fxyz( 5,10, 2)/ 3.1210061d-05, 2.5067392d-05/
      data fxyz( 5,10, 3),fxyz( 5,10, 4)/-1.2832395d-05, 3.0457221d-05/
      data fxyz( 5,10, 5),fxyz( 5,10, 6)/-1.4809107d-04, 6.8055430d-04/
      data fxyz( 5,10, 7),fxyz( 5,10, 8)/-1.2136479d-03, 8.7895274d-04/
      data fxyz( 5,10, 9),fxyz( 5,10,10)/-3.0320887d-04, 1.6173431d-04/
      data fxyz( 5,10,11),fxyz( 5,10,12)/-8.0252260d-05,-1.1553783d-04/
      data fxyz( 5,10,13),fxyz( 5,10,14)/ 2.0243635d-04,-1.7275418d-04/
      data fxyz( 5,10,15),fxyz( 5,10,16)/ 1.0730129d-04,-4.1115635d-05/
      data fxyz( 5,10,17),fxyz( 5,10,18)/ 8.0740375d-06, 3.5514353d-05/
      data fxyz( 5,10,19),fxyz( 5,10,20)/-1.4800632d-04, 8.0923320d-05/
      data fxyz( 5,10,21),fxyz( 5,10,22)/ 6.7140670d-05,-9.2875719d-05/
      data fxyz( 5,10,23)/               -1.7122541d-04/
      data fxyz( 5,11, 1),fxyz( 5,11, 2)/-5.9416058d-05,-3.5683402d-05/
      data fxyz( 5,11, 3),fxyz( 5,11, 4)/ 2.0444449d-05, 1.1218167d-05/
      data fxyz( 5,11, 5),fxyz( 5,11, 6)/ 1.2217261d-06,-1.9781029d-04/
      data fxyz( 5,11, 7),fxyz( 5,11, 8)/ 4.1372065d-04,-3.7964909d-04/
      data fxyz( 5,11, 9),fxyz( 5,11,10)/ 2.0563250d-04,-1.1763298d-04/
      data fxyz( 5,11,11),fxyz( 5,11,12)/ 4.8470237d-05, 7.1085836d-05/
      data fxyz( 5,11,13),fxyz( 5,11,14)/-1.0293079d-04, 6.4593145d-05/
      data fxyz( 5,11,15),fxyz( 5,11,16)/-3.4431051d-05, 6.6185588d-06/
      data fxyz( 5,11,17),fxyz( 5,11,18)/ 2.0813001d-05,-9.6353977d-05/
      data fxyz( 5,11,19),fxyz( 5,11,20)/ 3.6573502d-04,-2.0031761d-04/
      data fxyz( 5,11,21),fxyz( 5,11,22)/-1.6584387d-04, 2.2784004d-04/
      data fxyz( 5,11,23)/                4.2075220d-04/
      data fxyz( 5,12, 1),fxyz( 5,12, 2)/ 2.0170606d-04, 1.0513592d-04/
      data fxyz( 5,12, 3),fxyz( 5,12, 4)/-9.7045451d-05,-1.0536607d-04/
      data fxyz( 5,12, 5),fxyz( 5,12, 6)/ 1.3841841d-04, 7.6896723d-05/
      data fxyz( 5,12, 7),fxyz( 5,12, 8)/-1.3840934d-04, 1.4929787d-04/
      data fxyz( 5,12, 9),fxyz( 5,12,10)/-1.2866049d-04, 8.8761303d-05/
      data fxyz( 5,12,11),fxyz( 5,12,12)/-2.1233940d-05,-3.5730732d-05/
      data fxyz( 5,12,13),fxyz( 5,12,14)/ 3.7416654d-05,-1.7516254d-05/
      data fxyz( 5,12,15),fxyz( 5,12,16)/ 7.6166146d-06, 2.0187167d-06/
      data fxyz( 5,12,17),fxyz( 5,12,18)/-1.8226137d-05, 7.4077445d-05/
      data fxyz( 5,12,19),fxyz( 5,12,20)/-2.7945241d-04, 1.5252310d-04/
      data fxyz( 5,12,21),fxyz( 5,12,22)/ 1.2617254d-04,-1.7405018d-04/
      data fxyz( 5,12,23)/               -3.2118093d-04/
      data fxyz( 5,13, 1),fxyz( 5,13, 2)/-1.4573163d-04,-7.1111244d-05/
      data fxyz( 5,13, 3),fxyz( 5,13, 4)/ 8.6691810d-05, 9.0362919d-05/
      data fxyz( 5,13, 5),fxyz( 5,13, 6)/-8.5795679d-05,-9.0664998d-05/
      data fxyz( 5,13, 7),fxyz( 5,13, 8)/ 6.9299091d-05,-4.4056808d-05/
      data fxyz( 5,13, 9),fxyz( 5,13,10)/ 3.2298004d-05,-2.0912773d-05/
      data fxyz( 5,13,11),fxyz( 5,13,12)/-2.9822347d-05, 7.2147522d-05/
      data fxyz( 5,13,13),fxyz( 5,13,14)/-2.4533858d-05,-3.3467791d-05/
      data fxyz( 5,13,15),fxyz( 5,13,16)/ 2.5746729d-05,-4.2490334d-06/
      data fxyz( 5,13,17),fxyz( 5,13,18)/-7.8308328d-06, 3.2793256d-05/
      data fxyz( 5,13,19),fxyz( 5,13,20)/-1.3194849d-04, 7.3869168d-05/
      data fxyz( 5,13,21),fxyz( 5,13,22)/ 6.1489897d-05,-8.2431401d-05/
      data fxyz( 5,13,23)/               -1.5289581d-04/
      data fxyz( 5,14, 1),fxyz( 5,14, 2)/-1.5028662d-04,-7.6872886d-05/
      data fxyz( 5,14, 3),fxyz( 5,14, 4)/ 7.3135108d-05, 8.5922610d-05/
      data fxyz( 5,14, 5),fxyz( 5,14, 6)/-1.2802289d-04, 4.1525907d-05/
      data fxyz( 5,14, 7),fxyz( 5,14, 8)/-4.6779897d-05, 1.1876785d-05/
      data fxyz( 5,14, 9),fxyz( 5,14,10)/ 9.9588789d-06,-5.6656158d-05/
      data fxyz( 5,14,11),fxyz( 5,14,12)/ 1.2917296d-04,-1.4933579d-04/
      data fxyz( 5,14,13),fxyz( 5,14,14)/ 5.2230275d-05, 3.9908975d-05/
      data fxyz( 5,14,15),fxyz( 5,14,16)/-3.3543812d-05, 4.8678771d-06/
      data fxyz( 5,14,17),fxyz( 5,14,18)/ 1.1487045d-05,-5.3284224d-05/
      data fxyz( 5,14,19),fxyz( 5,14,20)/ 2.0369955d-04,-1.1208321d-04/
      data fxyz( 5,14,21),fxyz( 5,14,22)/-9.2889428d-05, 1.2692441d-04/
      data fxyz( 5,14,23)/                2.3462255d-04/
      data fxyz( 5,15, 1),fxyz( 5,15, 2)/ 1.0679734d-04, 5.2959693d-05/
      data fxyz( 5,15, 3),fxyz( 5,15, 4)/-5.8854594d-05,-6.5070781d-05/
      data fxyz( 5,15, 5),fxyz( 5,15, 6)/ 7.7824439d-05, 1.3554548d-05/
      data fxyz( 5,15, 7),fxyz( 5,15, 8)/ 6.9391755d-06, 1.9032479d-06/
      data fxyz( 5,15, 9),fxyz( 5,15,10)/-2.1828628d-05, 9.3756759d-05/
      data fxyz( 5,15,11),fxyz( 5,15,12)/-2.2527793d-04, 2.5595332d-04/
      data fxyz( 5,15,13),fxyz( 5,15,14)/-1.3235427d-04, 1.7018631d-05/
      data fxyz( 5,15,15),fxyz( 5,15,16)/ 2.6221109d-06, 1.2425467d-06/
      data fxyz( 5,15,17),fxyz( 5,15,18)/-2.4468234d-06, 1.5553297d-05/
      data fxyz( 5,15,19),fxyz( 5,15,20)/-5.1962294d-05, 2.9805358d-05/
      data fxyz( 5,15,21),fxyz( 5,15,22)/ 2.4789195d-05,-3.1897643d-05/
      data fxyz( 5,15,23)/               -5.9689144d-05/
      data fxyz( 5,16, 1),fxyz( 5,16, 2)/ 2.2956037d-05, 1.1905387d-05/
      data fxyz( 5,16, 3),fxyz( 5,16, 4)/-1.0654450d-05,-1.2614674d-05/
      data fxyz( 5,16, 5),fxyz( 5,16, 6)/ 1.9746286d-05,-6.4473347d-06/
      data fxyz( 5,16, 7),fxyz( 5,16, 8)/ 7.6399171d-06,-1.6273412d-05/
      data fxyz( 5,16, 9),fxyz( 5,16,10)/ 6.4703862d-05,-2.2035754d-04/
      data fxyz( 5,16,11),fxyz( 5,16,12)/ 5.3758147d-04,-6.7118541d-04/
      data fxyz( 5,16,13),fxyz( 5,16,14)/ 3.9875719d-04,-8.8243143d-05/
      data fxyz( 5,16,15),fxyz( 5,16,16)/ 1.7814985d-05,-8.9820973d-06/
      data fxyz( 5,16,17),fxyz( 5,16,18)/-9.3290101d-07,-6.9852836d-06/
      data fxyz( 5,16,19),fxyz( 5,16,20)/ 1.0301730d-05,-1.2876261d-05/
      data fxyz( 5,16,21),fxyz( 5,16,22)/-1.1542238d-05, 4.9656394d-06/
      data fxyz( 5,16,23)/                1.3025055d-05/
      data fxyz( 5,17, 1),fxyz( 5,17, 2)/ 3.8666104d-06, 1.7124413d-06/
      data fxyz( 5,17, 3),fxyz( 5,17, 4)/-2.7926825d-06,-2.9868502d-06/
      data fxyz( 5,17, 5),fxyz( 5,17, 6)/ 2.4891123d-06, 9.5409401d-07/
      data fxyz( 5,17, 7),fxyz( 5,17, 8)/-8.6315798d-06, 3.8067481d-05/
      data fxyz( 5,17, 9),fxyz( 5,17,10)/-1.4068628d-04, 4.8100377d-04/
      data fxyz( 5,17,11),fxyz( 5,17,12)/-1.2045569d-03, 1.5839901d-03/
      data fxyz( 5,17,13),fxyz( 5,17,14)/-1.0503057d-03, 2.6502276d-04/
      data fxyz( 5,17,15),fxyz( 5,17,16)/-5.5641283d-05, 3.0410146d-05/
      data fxyz( 5,17,17),fxyz( 5,17,18)/ 7.3208311d-06, 1.3534736d-05/
      data fxyz( 5,17,19),fxyz( 5,17,20)/ 1.1430096d-05, 2.0074198d-05/
      data fxyz( 5,17,21),fxyz( 5,17,22)/ 1.9782811d-05, 1.2595644d-05/
      data fxyz( 5,17,23)/                9.1639294d-06/
      data fxyz( 5,18, 1),fxyz( 5,18, 2)/ 3.6884579d-07, 1.2628001d-08/
      data fxyz( 5,18, 3),fxyz( 5,18, 4)/-6.2575791d-07,-8.4439927d-07/
      data fxyz( 5,18, 5),fxyz( 5,18, 6)/ 8.8719345d-07,-2.9107746d-06/
      data fxyz( 5,18, 7),fxyz( 5,18, 8)/ 1.0455454d-05,-3.1500736d-05/
      data fxyz( 5,18, 9),fxyz( 5,18,10)/ 1.1671213d-04,-3.9238615d-04/
      data fxyz( 5,18,11),fxyz( 5,18,12)/ 9.7123395d-04,-1.3020164d-03/
      data fxyz( 5,18,13),fxyz( 5,18,14)/ 9.2343172d-04,-2.4774624d-04/
      data fxyz( 5,18,15),fxyz( 5,18,16)/ 5.0923032d-05,-2.9921171d-05/
      data fxyz( 5,18,17),fxyz( 5,18,18)/-8.3009005d-06,-1.3386713d-05/
      data fxyz( 5,18,19),fxyz( 5,18,20)/-1.4989462d-05,-1.9532911d-05/
      data fxyz( 5,18,21),fxyz( 5,18,22)/-1.9508345d-05,-1.5087726d-05/
      data fxyz( 5,18,23)/               -1.3018220d-05/
      data fxyz( 5,19, 1),fxyz( 5,19, 2)/-7.5836794d-06,-4.1137945d-06/
      data fxyz( 5,19, 3),fxyz( 5,19, 4)/ 3.1682646d-06, 3.4367298d-06/
      data fxyz( 5,19, 5),fxyz( 5,19, 6)/-5.1876553d-06,-3.5567012d-06/
      data fxyz( 5,19, 7),fxyz( 5,19, 8)/ 1.9440050d-05,-6.5666350d-05/
      data fxyz( 5,19, 9),fxyz( 5,19,10)/ 2.4188523d-04,-8.1584714d-04/
      data fxyz( 5,19,11),fxyz( 5,19,12)/ 2.0276165d-03,-2.7191138d-03/
      data fxyz( 5,19,13),fxyz( 5,19,14)/ 1.9192262d-03,-5.1307669d-04/
      data fxyz( 5,19,15),fxyz( 5,19,16)/ 1.0605289d-04,-6.1760043d-05/
      data fxyz( 5,19,17),fxyz( 5,19,18)/-1.7101071d-05,-2.6753456d-05/
      data fxyz( 5,19,19),fxyz( 5,19,20)/-3.3538184d-05,-3.8409286d-05/
      data fxyz( 5,19,21),fxyz( 5,19,22)/-3.8623442d-05,-3.2681561d-05/
      data fxyz( 5,19,23)/               -2.9965792d-05/
      data fxyz( 6, 1, 1),fxyz( 6, 1, 2)/ 3.6667808d-04, 2.2676297d-04/
      data fxyz( 6, 1, 3),fxyz( 6, 1, 4)/-7.1265116d-05,-7.4397650d-05/
      data fxyz( 6, 1, 5),fxyz( 6, 1, 6)/ 2.3929310d-04, 3.1969007d-04/
      data fxyz( 6, 1, 7),fxyz( 6, 1, 8)/-3.7348822d-04,-3.2586215d-04/
      data fxyz( 6, 1, 9),fxyz( 6, 1,10)/ 2.1035156d-06, 2.3593349d-04/
      data fxyz( 6, 1,11),fxyz( 6, 1,12)/-2.2601026d-04, 5.5103241d-04/
      data fxyz( 6, 1,13),fxyz( 6, 1,14)/-3.6548433d-04, 3.5027846d-04/
      data fxyz( 6, 1,15),fxyz( 6, 1,16)/-1.6718902d-04, 3.0293516d-04/
      data fxyz( 6, 1,17),fxyz( 6, 1,18)/-1.4696834d-03, 1.1376425d-03/
      data fxyz( 6, 1,19),fxyz( 6, 1,20)/-8.1331070d-05, 3.8863637d-07/
      data fxyz( 6, 1,21),fxyz( 6, 1,22)/-5.9284281d-05, 1.5736060d-04/
      data fxyz( 6, 1,23)/                2.4254877d-04/
      data fxyz( 6, 2, 1),fxyz( 6, 2, 2)/ 1.7295441d-04, 1.0736212d-04/
      data fxyz( 6, 2, 3),fxyz( 6, 2, 4)/-3.1638279d-05,-3.4358708d-05/
      data fxyz( 6, 2, 5),fxyz( 6, 2, 6)/ 1.1824383d-04, 1.3214798d-04/
      data fxyz( 6, 2, 7),fxyz( 6, 2, 8)/-1.6149129d-04,-1.7455686d-04/
      data fxyz( 6, 2, 9),fxyz( 6, 2,10)/ 2.7843878d-05, 8.4424734d-05/
      data fxyz( 6, 2,11),fxyz( 6, 2,12)/-7.3543516d-05, 2.2464522d-04/
      data fxyz( 6, 2,13),fxyz( 6, 2,14)/-1.2766176d-04, 1.3198533d-04/
      data fxyz( 6, 2,15),fxyz( 6, 2,16)/-6.1121784d-05, 1.0838040d-04/
      data fxyz( 6, 2,17),fxyz( 6, 2,18)/-6.2148020d-04, 4.7753274d-04/
      data fxyz( 6, 2,19),fxyz( 6, 2,20)/-2.4487476d-05,-1.4108124d-06/
      data fxyz( 6, 2,21),fxyz( 6, 2,22)/-2.5752078d-05, 7.2877586d-05/
      data fxyz( 6, 2,23)/                1.1241376d-04/
      data fxyz( 6, 3, 1),fxyz( 6, 3, 2)/-2.5785256d-04,-1.6255716d-04/
      data fxyz( 6, 3, 3),fxyz( 6, 3, 4)/ 4.6544720d-05, 3.7974165d-05/
      data fxyz( 6, 3, 5),fxyz( 6, 3, 6)/-1.2827495d-04,-3.8641088d-04/
      data fxyz( 6, 3, 7),fxyz( 6, 3, 8)/ 5.9323210d-04,-1.4674661d-04/
      data fxyz( 6, 3, 9),fxyz( 6, 3,10)/ 2.2735366d-04,-2.8577324d-04/
      data fxyz( 6, 3,11),fxyz( 6, 3,12)/ 2.4075437d-04,-4.4741240d-04/
      data fxyz( 6, 3,13),fxyz( 6, 3,14)/ 4.5456120d-04,-4.6858097d-04/
      data fxyz( 6, 3,15),fxyz( 6, 3,16)/ 4.8538062d-04,-8.1150901d-04/
      data fxyz( 6, 3,17),fxyz( 6, 3,18)/ 1.5172100d-03,-1.0011799d-03/
      data fxyz( 6, 3,19),fxyz( 6, 3,20)/ 9.6750155d-05,-1.1562925d-05/
      data fxyz( 6, 3,21),fxyz( 6, 3,22)/ 4.2953348d-05,-1.2131494d-04/
      data fxyz( 6, 3,23)/               -1.8343579d-04/
      data fxyz( 6, 4, 1),fxyz( 6, 4, 2)/ 1.4113205d-04, 9.4338061d-05/
      data fxyz( 6, 4, 3),fxyz( 6, 4, 4)/-1.0218850d-05,-2.7217227d-06/
      data fxyz( 6, 4, 5),fxyz( 6, 4, 6)/ 6.4349552d-05, 2.5358896d-04/
      data fxyz( 6, 4, 7),fxyz( 6, 4, 8)/-5.5158711d-04, 3.1329627d-04/
      data fxyz( 6, 4, 9),fxyz( 6, 4,10)/-1.8132953d-04, 1.0944105d-04/
      data fxyz( 6, 4,11),fxyz( 6, 4,12)/-1.1356739d-05, 9.0376504d-05/
      data fxyz( 6, 4,13),fxyz( 6, 4,14)/-1.6861722d-04, 2.6880884d-04/
      data fxyz( 6, 4,15),fxyz( 6, 4,16)/-5.0964005d-04, 8.0727283d-04/
      data fxyz( 6, 4,17),fxyz( 6, 4,18)/-8.6080447d-04, 3.8521742d-04/
      data fxyz( 6, 4,19),fxyz( 6, 4,20)/-7.3913431d-06, 7.5192856d-06/
      data fxyz( 6, 4,21),fxyz( 6, 4,22)/-1.1447505d-05, 6.8475819d-05/
      data fxyz( 6, 4,23)/                1.0071556d-04/
      data fxyz( 6, 5, 1),fxyz( 6, 5, 2)/ 5.0089768d-05, 1.6407678d-05/
      data fxyz( 6, 5, 3),fxyz( 6, 5, 4)/-5.1800337d-05,-5.8744148d-05/
      data fxyz( 6, 5, 5),fxyz( 6, 5, 6)/ 4.4182922d-05,-5.4067399d-05/
      data fxyz( 6, 5, 7),fxyz( 6, 5, 8)/ 2.2407025d-04,-1.3622586d-04/
      data fxyz( 6, 5, 9),fxyz( 6, 5,10)/ 1.9173864d-05, 3.9861283d-05/
      data fxyz( 6, 5,11),fxyz( 6, 5,12)/-1.0852839d-04, 9.4730162d-05/
      data fxyz( 6, 5,13),fxyz( 6, 5,14)/-4.8640623d-05,-9.1346887d-05/
      data fxyz( 6, 5,15),fxyz( 6, 5,16)/ 4.5500217d-04,-6.8978930d-04/
      data fxyz( 6, 5,17),fxyz( 6, 5,18)/ 3.8229258d-04,-1.0788418d-05/
      data fxyz( 6, 5,19),fxyz( 6, 5,20)/-1.6212731d-05,-1.1862707d-05/
      data fxyz( 6, 5,21),fxyz( 6, 5,22)/-1.2216551d-05,-1.4797353d-05/
      data fxyz( 6, 5,23)/               -1.6096086d-05/
      data fxyz( 6, 6, 1),fxyz( 6, 6, 2)/-3.6762288d-04,-1.9791433d-04/
      data fxyz( 6, 6, 3),fxyz( 6, 6, 4)/ 1.4745268d-04, 1.7946745d-04/
      data fxyz( 6, 6, 5),fxyz( 6, 6, 6)/-3.2597342d-04, 1.1259869d-04/
      data fxyz( 6, 6, 7),fxyz( 6, 6, 8)/-7.9125505d-05, 3.5309482d-05/
      data fxyz( 6, 6, 9),fxyz( 6, 6,10)/-3.1366832d-06,-1.0854395d-05/
      data fxyz( 6, 6,11),fxyz( 6, 6,12)/ 2.3924131d-05,-1.4982889d-05/
      data fxyz( 6, 6,13),fxyz( 6, 6,14)/-1.3549693d-05, 9.7265656d-05/
      data fxyz( 6, 6,15),fxyz( 6, 6,16)/-3.4058623d-04, 5.1636006d-04/
      data fxyz( 6, 6,17),fxyz( 6, 6,18)/-3.1713413d-04, 6.2368230d-05/
      data fxyz( 6, 6,19),fxyz( 6, 6,20)/-3.4593111d-06, 2.3539437d-06/
      data fxyz( 6, 6,21),fxyz( 6, 6,22)/-8.9955593d-07, 9.5546876d-06/
      data fxyz( 6, 6,23)/                1.3565735d-05/
      data fxyz( 6, 7, 1),fxyz( 6, 7, 2)/ 9.2305782d-04, 5.2192958d-04/
      data fxyz( 6, 7, 3),fxyz( 6, 7, 4)/-2.8444590d-04,-3.7751969d-04/
      data fxyz( 6, 7, 5),fxyz( 6, 7, 6)/ 8.9422474d-04,-4.7304900d-04/
      data fxyz( 6, 7, 7),fxyz( 6, 7, 8)/ 1.2895677d-04,-1.4705159d-05/
      data fxyz( 6, 7, 9),fxyz( 6, 7,10)/-1.3962086d-06, 5.6099908d-06/
      data fxyz( 6, 7,11),fxyz( 6, 7,12)/-6.2547665d-06, 3.0222593d-07/
      data fxyz( 6, 7,13),fxyz( 6, 7,14)/ 1.2337642d-05,-4.1326915d-05/
      data fxyz( 6, 7,15),fxyz( 6, 7,16)/ 1.1681773d-04,-1.6970948d-04/
      data fxyz( 6, 7,17),fxyz( 6, 7,18)/ 1.0176008d-04,-1.7250038d-05/
      data fxyz( 6, 7,19),fxyz( 6, 7,20)/-1.4657557d-05, 9.1531199d-06/
      data fxyz( 6, 7,21),fxyz( 6, 7,22)/ 8.7487291d-06,-1.3039993d-05/
      data fxyz( 6, 7,23)/               -2.3315901d-05/
      data fxyz( 6, 8, 1),fxyz( 6, 8, 2)/-1.1685982d-03,-6.7636527d-04/
      data fxyz( 6, 8, 3),fxyz( 6, 8, 4)/ 3.0749939d-04, 4.3160987d-04/
      data fxyz( 6, 8, 5),fxyz( 6, 8, 6)/-1.1728072d-03, 6.9305897d-04/
      data fxyz( 6, 8, 7),fxyz( 6, 8, 8)/-7.7619165d-05,-6.9021324d-05/
      data fxyz( 6, 8, 9),fxyz( 6, 8,10)/ 2.7668956d-05,-1.3113940d-05/
      data fxyz( 6, 8,11),fxyz( 6, 8,12)/ 6.3380204d-06, 4.3475527d-06/
      data fxyz( 6, 8,13),fxyz( 6, 8,14)/-1.3654912d-05, 2.1935049d-05/
      data fxyz( 6, 8,15),fxyz( 6, 8,16)/-3.8324087d-05, 4.7509305d-05/
      data fxyz( 6, 8,17),fxyz( 6, 8,18)/-2.7561996d-05, 2.5195728d-06/
      data fxyz( 6, 8,19),fxyz( 6, 8,20)/ 8.2920788d-06,-3.8617459d-06/
      data fxyz( 6, 8,21),fxyz( 6, 8,22)/-3.3185042d-06, 6.1191122d-06/
      data fxyz( 6, 8,23)/                1.0668198d-05/
      data fxyz( 6, 9, 1),fxyz( 6, 9, 2)/ 6.7968393d-04, 3.9843258d-04/
      data fxyz( 6, 9, 3),fxyz( 6, 9, 4)/-1.6357693d-04,-2.3475287d-04/
      data fxyz( 6, 9, 5),fxyz( 6, 9, 6)/ 6.8313633d-04,-3.8795515d-04/
      data fxyz( 6, 9, 7),fxyz( 6, 9, 8)/-5.4913740d-05, 1.2369456d-04/
      data fxyz( 6, 9, 9),fxyz( 6, 9,10)/-5.4433920d-05, 3.4565926d-05/
      data fxyz( 6, 9,11),fxyz( 6, 9,12)/-1.4742401d-05,-2.0490847d-05/
      data fxyz( 6, 9,13),fxyz( 6, 9,14)/ 4.1997361d-05,-4.4122706d-05/
      data fxyz( 6, 9,15),fxyz( 6, 9,16)/ 3.5047400d-05,-2.3026822d-05/
      data fxyz( 6, 9,17),fxyz( 6, 9,18)/ 1.1385768d-05, 8.6369136d-07/
      data fxyz( 6, 9,19),fxyz( 6, 9,20)/-1.0801300d-05, 5.6706931d-06/
      data fxyz( 6, 9,21),fxyz( 6, 9,22)/ 4.7520892d-06,-7.1268849d-06/
      data fxyz( 6, 9,23)/               -1.2915367d-05/
      data fxyz( 6,10, 1),fxyz( 6,10, 2)/-1.8821549d-04,-1.1062714d-04/
      data fxyz( 6,10, 3),fxyz( 6,10, 4)/ 4.3984986d-05, 6.4370089d-05/
      data fxyz( 6,10, 5),fxyz( 6,10, 6)/-1.9216755d-04, 1.1756105d-04/
      data fxyz( 6,10, 7),fxyz( 6,10, 8)/-2.6160429d-05, 2.8606059d-05/
      data fxyz( 6,10, 9),fxyz( 6,10,10)/-1.2748364d-06,-4.1285574d-05/
      data fxyz( 6,10,11),fxyz( 6,10,12)/ 2.2895293d-05, 3.0695773d-05/
      data fxyz( 6,10,13),fxyz( 6,10,14)/-5.3849227d-05, 4.6403273d-05/
      data fxyz( 6,10,15),fxyz( 6,10,16)/-2.9984595d-05, 1.3103404d-05/
      data fxyz( 6,10,17),fxyz( 6,10,18)/-3.4576644d-06,-9.3766638d-06/
      data fxyz( 6,10,19),fxyz( 6,10,20)/ 4.1171145d-05,-2.2606868d-05/
      data fxyz( 6,10,21),fxyz( 6,10,22)/-1.8794642d-05, 2.5922244d-05/
      data fxyz( 6,10,23)/                4.7806717d-05/
      data fxyz( 6,11, 1),fxyz( 6,11, 2)/ 9.1595334d-05, 5.0147454d-05/
      data fxyz( 6,11, 3),fxyz( 6,11, 4)/-3.2963167d-05,-4.2949131d-05/
      data fxyz( 6,11, 5),fxyz( 6,11, 6)/ 9.0091310d-05,-5.8194126d-05/
      data fxyz( 6,11, 7),fxyz( 6,11, 8)/ 8.9493335d-05,-1.2663290d-04/
      data fxyz( 6,11, 9),fxyz( 6,11,10)/ 8.3235577d-05,-3.1036623d-06/
      data fxyz( 6,11,11),fxyz( 6,11,12)/-1.1582618d-05,-1.9742259d-05/
      data fxyz( 6,11,13),fxyz( 6,11,14)/ 2.7777193d-05,-1.7300555d-05/
      data fxyz( 6,11,15),fxyz( 6,11,16)/ 9.4842702d-06,-2.1765573d-06/
      data fxyz( 6,11,17),fxyz( 6,11,18)/-5.1439075d-06, 2.5831218d-05/
      data fxyz( 6,11,19),fxyz( 6,11,20)/-9.8068461d-05, 5.3471059d-05/
      data fxyz( 6,11,21),fxyz( 6,11,22)/ 4.4232857d-05,-6.1115653d-05/
      data fxyz( 6,11,23)/               -1.1274181d-04/
      data fxyz( 6,12, 1),fxyz( 6,12, 2)/-5.8610159d-05,-3.2924473d-05/
      data fxyz( 6,12, 3),fxyz( 6,12, 4)/ 1.9210348d-05, 2.4295737d-05/
      data fxyz( 6,12, 5),fxyz( 6,12, 6)/-5.3266031d-05, 1.7670686d-05/
      data fxyz( 6,12, 7),fxyz( 6,12, 8)/-1.7303601d-05, 5.1928271d-05/
      data fxyz( 6,12, 9),fxyz( 6,12,10)/-6.2873447d-05, 3.7952199d-05/
      data fxyz( 6,12,11),fxyz( 6,12,12)/-1.3631326d-05, 1.2824102d-05/
      data fxyz( 6,12,13),fxyz( 6,12,14)/-1.1204232d-05, 4.9893657d-06/
      data fxyz( 6,12,15),fxyz( 6,12,16)/-2.0899123d-06,-2.0753625d-07/
      data fxyz( 6,12,17),fxyz( 6,12,18)/ 4.7777013d-06,-1.9441234d-05/
      data fxyz( 6,12,19),fxyz( 6,12,20)/ 7.0610278d-05,-3.8476076d-05/
      data fxyz( 6,12,21),fxyz( 6,12,22)/-3.1785009d-05, 4.3846010d-05/
      data fxyz( 6,12,23)/                8.0924770d-05/
      data fxyz( 6,13, 1),fxyz( 6,13, 2)/-9.5546711d-06,-4.0451150d-06/
      data fxyz( 6,13, 3),fxyz( 6,13, 4)/ 6.7948010d-06, 8.4857834d-06/
      data fxyz( 6,13, 5),fxyz( 6,13, 6)/-1.0809045d-05, 1.5810065d-05/
      data fxyz( 6,13, 7),fxyz( 6,13, 8)/-1.8044990d-05, 9.2457428d-07/
      data fxyz( 6,13, 9),fxyz( 6,13,10)/ 5.5248221d-08,-6.0179921d-06/
      data fxyz( 6,13,11),fxyz( 6,13,12)/ 1.9134116d-05,-2.3484470d-05/
      data fxyz( 6,13,13),fxyz( 6,13,14)/ 7.2462985d-06, 8.7034930d-06/
      data fxyz( 6,13,15),fxyz( 6,13,16)/-6.8481834d-06, 1.0371554d-06/
      data fxyz( 6,13,17),fxyz( 6,13,18)/ 1.8370421d-06,-9.9107342d-06/
      data fxyz( 6,13,19),fxyz( 6,13,20)/ 3.3843370d-05,-1.7809786d-05/
      data fxyz( 6,13,21),fxyz( 6,13,22)/-1.4588635d-05, 2.0958767d-05/
      data fxyz( 6,13,23)/                3.8406528d-05/
      data fxyz( 6,14, 1),fxyz( 6,14, 2)/-2.3432399d-05,-8.9455570d-06/
      data fxyz( 6,14, 3),fxyz( 6,14, 4)/ 2.2443535d-05, 2.1838281d-05/
      data fxyz( 6,14, 5),fxyz( 6,14, 6)/-6.5245399d-06,-3.2511213d-05/
      data fxyz( 6,14, 7),fxyz( 6,14, 8)/ 1.0238697d-05,-2.9583597d-06/
      data fxyz( 6,14, 9),fxyz( 6,14,10)/ 1.8376847d-06,-3.4598847d-06/
      data fxyz( 6,14,11),fxyz( 6,14,12)/-1.6653367d-05, 3.2928655d-05/
      data fxyz( 6,14,13),fxyz( 6,14,14)/-1.2360594d-05,-1.1384559d-05/
      data fxyz( 6,14,15),fxyz( 6,14,16)/ 9.2057005d-06,-1.5884149d-06/
      data fxyz( 6,14,17),fxyz( 6,14,18)/-3.1202253d-06, 1.4077226d-05/
      data fxyz( 6,14,19),fxyz( 6,14,20)/-5.1408353d-05, 2.8231062d-05/
      data fxyz( 6,14,21),fxyz( 6,14,22)/ 2.3358405d-05,-3.1917725d-05/
      data fxyz( 6,14,23)/               -5.9012628d-05/
      data fxyz( 6,15, 1),fxyz( 6,15, 2)/ 7.1137878d-05, 4.0465886d-05/
      data fxyz( 6,15, 3),fxyz( 6,15, 4)/-2.1487464d-05,-2.8089073d-05/
      data fxyz( 6,15, 5),fxyz( 6,15, 6)/ 6.6872324d-05,-2.7886265d-05/
      data fxyz( 6,15, 7),fxyz( 6,15, 8)/ 3.8694304d-06,-5.3034479d-06/
      data fxyz( 6,15, 9),fxyz( 6,15,10)/ 9.8997603d-06,-3.2936008d-05/
      data fxyz( 6,15,11),fxyz( 6,15,12)/ 6.9084507d-05,-7.2753896d-05/
      data fxyz( 6,15,13),fxyz( 6,15,14)/ 3.5897526d-05,-4.5939360d-06/
      data fxyz( 6,15,15),fxyz( 6,15,16)/-9.9049075d-07,-6.6265948d-08/
      data fxyz( 6,15,17),fxyz( 6,15,18)/ 6.5057605d-07,-3.4480664d-06/
      data fxyz( 6,15,19),fxyz( 6,15,20)/ 1.4373209d-05,-8.7926144d-06/
      data fxyz( 6,15,21),fxyz( 6,15,22)/-7.4335007d-06, 8.9367550d-06/
      data fxyz( 6,15,23)/                1.6938638d-05/
      data fxyz( 6,16, 1),fxyz( 6,16, 2)/-4.0361303d-05,-2.5997704d-05/
      data fxyz( 6,16, 3),fxyz( 6,16, 4)/ 1.6389525d-06, 7.1382995d-06/
      data fxyz( 6,16, 5),fxyz( 6,16, 6)/-4.7995092d-05, 4.2128903d-05/
      data fxyz( 6,16, 7),fxyz( 6,16, 8)/-7.4959563d-06, 9.5232514d-06/
      data fxyz( 6,16, 9),fxyz( 6,16,10)/-7.1175991d-06, 1.0260190d-05/
      data fxyz( 6,16,11),fxyz( 6,16,12)/-7.5778933d-05, 1.4138650d-04/
      data fxyz( 6,16,13),fxyz( 6,16,14)/-9.7181197d-05, 2.0772786d-05/
      data fxyz( 6,16,15),fxyz( 6,16,16)/-3.8941463d-06, 1.9670998d-06/
      data fxyz( 6,16,17),fxyz( 6,16,18)/ 5.8620371d-07, 1.8024704d-06/
      data fxyz( 6,16,19),fxyz( 6,16,20)/-2.6362478d-06, 3.2742090d-06/
      data fxyz( 6,16,21),fxyz( 6,16,22)/ 2.9325825d-06,-1.2697418d-06/
      data fxyz( 6,16,23)/               -3.3219269d-06/
      data fxyz( 6,17, 1),fxyz( 6,17, 2)/ 1.1992630d-05, 6.6631386d-06/
      data fxyz( 6,17, 3),fxyz( 6,17, 4)/-3.6932977d-06,-5.5551283d-06/
      data fxyz( 6,17, 5),fxyz( 6,17, 6)/ 1.4110461d-05,-1.5934829d-05/
      data fxyz( 6,17, 7),fxyz( 6,17, 8)/ 2.6808590d-05,-6.4161994d-05/
      data fxyz( 6,17, 9),fxyz( 6,17,10)/ 1.8165711d-04,-4.2735366d-04/
      data fxyz( 6,17,11),fxyz( 6,17,12)/ 6.7605836d-04,-6.3358227d-04/
      data fxyz( 6,17,13),fxyz( 6,17,14)/ 3.4344248d-04,-8.6800247d-05/
      data fxyz( 6,17,15),fxyz( 6,17,16)/ 1.9239188d-05,-9.1744661d-06/
      data fxyz( 6,17,17),fxyz( 6,17,18)/-1.7902111d-06,-3.6503604d-06/
      data fxyz( 6,17,19),fxyz( 6,17,20)/-3.0664715d-06,-5.4107673d-06/
      data fxyz( 6,17,21),fxyz( 6,17,22)/-5.3311204d-06,-3.3850589d-06/
      data fxyz( 6,17,23)/               -2.4556577d-06/
      data fxyz( 6,18, 1),fxyz( 6,18, 2)/-2.8520869d-06,-1.8449820d-06/
      data fxyz( 6,18, 3),fxyz( 6,18, 4)/-2.8386463d-07, 7.6082350d-07/
      data fxyz( 6,18, 5),fxyz( 6,18, 6)/-6.0237344d-06, 1.2818235d-05/
      data fxyz( 6,18, 7),fxyz( 6,18, 8)/-3.1035979d-05, 8.5950837d-05/
      data fxyz( 6,18, 9),fxyz( 6,18,10)/-2.6088171d-04, 6.7831943d-04/
      data fxyz( 6,18,11),fxyz( 6,18,12)/-1.0108616d-03, 7.9621044d-04/
      data fxyz( 6,18,13),fxyz( 6,18,14)/-3.6970026d-04, 9.9110262d-05/
      data fxyz( 6,18,15),fxyz( 6,18,16)/-2.2292675d-05, 1.0362815d-05/
      data fxyz( 6,18,17),fxyz( 6,18,18)/ 1.6686103d-06, 3.7632587d-06/
      data fxyz( 6,18,19),fxyz( 6,18,20)/ 3.9678313d-06, 5.2248840d-06/
      data fxyz( 6,18,21),fxyz( 6,18,22)/ 5.2067486d-06, 4.0403728d-06/
      data fxyz( 6,18,23)/                3.4912280d-06/
      data fxyz( 6,19, 1),fxyz( 6,19, 2)/ 1.5028104d-06, 1.4094584d-06/
      data fxyz( 6,19, 3),fxyz( 6,19, 4)/ 6.2794464d-07, 1.6455240d-06/
      data fxyz( 6,19, 5),fxyz( 6,19, 6)/-2.6608589d-06, 1.6766500d-05/
      data fxyz( 6,19, 7),fxyz( 6,19, 8)/-6.2552229d-05, 1.7212136d-04/
      data fxyz( 6,19, 9),fxyz( 6,19,10)/-5.2304523d-04, 1.3430534d-03/
      data fxyz( 6,19,11),fxyz( 6,19,12)/-2.0009939d-03, 1.5960713d-03/
      data fxyz( 6,19,13),fxyz( 6,19,14)/-7.5319545d-04, 2.0116833d-04/
      data fxyz( 6,19,15),fxyz( 6,19,16)/-4.5348768d-05, 2.1134712d-05/
      data fxyz( 6,19,17),fxyz( 6,19,18)/ 3.4602214d-06, 7.5007493d-06/
      data fxyz( 6,19,19),fxyz( 6,19,20)/ 8.8694122d-06, 1.0340356d-05/
      data fxyz( 6,19,21),fxyz( 6,19,22)/ 1.0372740d-05, 8.7398763d-06/
      data fxyz( 6,19,23)/                7.9865090d-06/
      data fxyz( 7, 1, 1),fxyz( 7, 1, 2)/-9.1915326d-04,-5.5031986d-04/
      data fxyz( 7, 1, 3),fxyz( 7, 1, 4)/ 1.7778177d-04, 2.8672914d-04/
      data fxyz( 7, 1, 5),fxyz( 7, 1, 6)/-9.8610937d-04, 7.1505740d-04/
      data fxyz( 7, 1, 7),fxyz( 7, 1, 8)/-1.2888555d-03, 3.0569852d-03/
      data fxyz( 7, 1, 9),fxyz( 7, 1,10)/-1.5538210d-03, 2.2104987d-04/
      data fxyz( 7, 1,11),fxyz( 7, 1,12)/-1.0052849d-04,-1.2229866d-03/
      data fxyz( 7, 1,13),fxyz( 7, 1,14)/ 5.5744633d-04,-3.9190976d-04/
      data fxyz( 7, 1,15),fxyz( 7, 1,16)/-8.4765386d-04, 1.7591414d-03/
      data fxyz( 7, 1,17),fxyz( 7, 1,18)/ 4.4515770d-04,-5.1302290d-04/
      data fxyz( 7, 1,19),fxyz( 7, 1,20)/-5.3945987d-04, 2.0107859d-04/
      data fxyz( 7, 1,21),fxyz( 7, 1,22)/ 1.8341934d-04,-4.6882286d-04/
      data fxyz( 7, 1,23)/               -7.7791169d-04/
      data fxyz( 7, 2, 1),fxyz( 7, 2, 2)/-4.3117899d-04,-2.5929578d-04/
      data fxyz( 7, 2, 3),fxyz( 7, 2, 4)/ 8.1530435d-05, 1.2964661d-04/
      data fxyz( 7, 2, 5),fxyz( 7, 2, 6)/-4.5176047d-04, 2.9056359d-04/
      data fxyz( 7, 2, 7),fxyz( 7, 2, 8)/-5.6629050d-04, 1.4735783d-03/
      data fxyz( 7, 2, 9),fxyz( 7, 2,10)/-7.6574121d-04, 1.2105389d-04/
      data fxyz( 7, 2,11),fxyz( 7, 2,12)/-7.0204987d-05,-5.4508714d-04/
      data fxyz( 7, 2,13),fxyz( 7, 2,14)/ 1.9445905d-04,-1.3805110d-04/
      data fxyz( 7, 2,15),fxyz( 7, 2,16)/-4.2270960d-04, 8.7416203d-04/
      data fxyz( 7, 2,17),fxyz( 7, 2,18)/ 1.8414458d-04,-2.4374883d-04/
      data fxyz( 7, 2,19),fxyz( 7, 2,20)/-2.4415150d-04, 8.9213741d-05/
      data fxyz( 7, 2,21),fxyz( 7, 2,22)/ 8.1809954d-05,-2.1453635d-04/
      data fxyz( 7, 2,23)/               -3.5480564d-04/
      data fxyz( 7, 3, 1),fxyz( 7, 3, 2)/ 4.2804644d-04, 2.5493235d-04/
      data fxyz( 7, 3, 3),fxyz( 7, 3, 4)/-8.1953486d-05,-1.4158112d-04/
      data fxyz( 7, 3, 5),fxyz( 7, 3, 6)/ 4.9344287d-04,-4.6636800d-04/
      data fxyz( 7, 3, 7),fxyz( 7, 3, 8)/ 6.7525920d-04,-1.3362344d-03/
      data fxyz( 7, 3, 9),fxyz( 7, 3,10)/ 5.1523303d-04, 2.2131367d-04/
      data fxyz( 7, 3,11),fxyz( 7, 3,12)/-2.7883856d-04, 1.1348963d-03/
      data fxyz( 7, 3,13),fxyz( 7, 3,14)/-1.1401657d-03, 9.0294018d-04/
      data fxyz( 7, 3,15),fxyz( 7, 3,16)/-1.1563208d-04,-8.9386414d-05/
      data fxyz( 7, 3,17),fxyz( 7, 3,18)/-9.2357247d-04, 5.8062157d-04/
      data fxyz( 7, 3,19),fxyz( 7, 3,20)/ 1.1382622d-04,-5.9153927d-05/
      data fxyz( 7, 3,21),fxyz( 7, 3,22)/-7.7480096d-05, 1.8713089d-04/
      data fxyz( 7, 3,23)/                3.0572904d-04/
      data fxyz( 7, 4, 1),fxyz( 7, 4, 2)/-1.2107216d-05,-1.2053685d-05/
      data fxyz( 7, 4, 3),fxyz( 7, 4, 4)/-1.0123350d-05,-1.3300694d-05/
      data fxyz( 7, 4, 5),fxyz( 7, 4, 6)/ 6.5568768d-07,-5.9767364d-05/
      data fxyz( 7, 4, 7),fxyz( 7, 4, 8)/ 1.0036244d-04, 1.4637335d-04/
      data fxyz( 7, 4, 9),fxyz( 7, 4,10)/ 7.1076850d-05,-3.7932169d-04/
      data fxyz( 7, 4,11),fxyz( 7, 4,12)/ 3.4887764d-04,-6.9241434d-04/
      data fxyz( 7, 4,13),fxyz( 7, 4,14)/ 9.2594071d-04,-8.1103273d-04/
      data fxyz( 7, 4,15),fxyz( 7, 4,16)/ 6.0397905d-04,-7.7794327d-04/
      data fxyz( 7, 4,17),fxyz( 7, 4,18)/ 9.3217420d-04,-5.3784517d-04/
      data fxyz( 7, 4,19),fxyz( 7, 4,20)/ 2.5246121d-04,-7.9761742d-05/
      data fxyz( 7, 4,21),fxyz( 7, 4,22)/-3.4887830d-05, 7.2965557d-05/
      data fxyz( 7, 4,23)/                1.3526351d-04/
      data fxyz( 7, 5, 1),fxyz( 7, 5, 2)/-5.2390313d-05,-2.8527883d-05/
      data fxyz( 7, 5, 3),fxyz( 7, 5, 4)/ 1.3122732d-05, 2.9718266d-05/
      data fxyz( 7, 5, 5),fxyz( 7, 5, 6)/-9.4910021d-05, 1.9654270d-04/
      data fxyz( 7, 5, 7),fxyz( 7, 5, 8)/-2.4594258d-04, 7.1364898d-05/
      data fxyz( 7, 5, 9),fxyz( 7, 5,10)/-6.9657622d-05, 1.7944877d-04/
      data fxyz( 7, 5,11),fxyz( 7, 5,12)/-1.3734177d-04, 1.9370222d-04/
      data fxyz( 7, 5,13),fxyz( 7, 5,14)/-2.8523295d-04, 3.5414174d-04/
      data fxyz( 7, 5,15),fxyz( 7, 5,16)/-6.0844461d-04, 8.6807769d-04/
      data fxyz( 7, 5,17),fxyz( 7, 5,18)/-6.5960279d-04, 3.2759833d-04/
      data fxyz( 7, 5,19),fxyz( 7, 5,20)/-2.2777546d-04, 7.3331219d-05/
      data fxyz( 7, 5,21),fxyz( 7, 5,22)/ 4.0298455d-05,-9.5644401d-05/
      data fxyz( 7, 5,23)/               -1.6789314d-04/
      data fxyz( 7, 6, 1),fxyz( 7, 6, 2)/-8.0448373d-06,-2.2819766d-06/
      data fxyz( 7, 6, 3),fxyz( 7, 6, 4)/ 1.0808828d-05, 9.5106479d-06/
      data fxyz( 7, 6, 5),fxyz( 7, 6, 6)/ 2.9107420d-06,-2.7517532d-05/
      data fxyz( 7, 6, 7),fxyz( 7, 6, 8)/ 2.6766462d-05,-5.1624743d-06/
      data fxyz( 7, 6, 9),fxyz( 7, 6,10)/ 1.4333311d-05,-4.7205205d-05/
      data fxyz( 7, 6,11),fxyz( 7, 6,12)/ 4.0539973d-05,-5.9846005d-05/
      data fxyz( 7, 6,13),fxyz( 7, 6,14)/ 9.8369966d-05,-1.6180448d-04/
      data fxyz( 7, 6,15),fxyz( 7, 6,16)/ 3.8492227d-04,-5.7345009d-04/
      data fxyz( 7, 6,17),fxyz( 7, 6,18)/ 3.8605103d-04,-1.4309905d-04/
      data fxyz( 7, 6,19),fxyz( 7, 6,20)/ 8.7555663d-05,-2.8379291d-05/
      data fxyz( 7, 6,21),fxyz( 7, 6,22)/-1.4862311d-05, 3.3487746d-05/
      data fxyz( 7, 6,23)/                5.9655635d-05/
      data fxyz( 7, 7, 1),fxyz( 7, 7, 2)/ 1.7997194d-04, 1.0336274d-04/
      data fxyz( 7, 7, 3),fxyz( 7, 7, 4)/-4.9486279d-05,-6.9284977d-05/
      data fxyz( 7, 7, 5),fxyz( 7, 7, 6)/ 1.8255753d-04,-1.1700853d-04/
      data fxyz( 7, 7, 7),fxyz( 7, 7, 8)/ 4.9351341d-05,-2.7120553d-05/
      data fxyz( 7, 7, 9),fxyz( 7, 7,10)/ 4.7280530d-06, 1.0004400d-05/
      data fxyz( 7, 7,11),fxyz( 7, 7,12)/-1.1057724d-05, 1.7655929d-05/
      data fxyz( 7, 7,13),fxyz( 7, 7,14)/-3.0159123d-05, 4.9679782d-05/
      data fxyz( 7, 7,15),fxyz( 7, 7,16)/-1.1137709d-04, 1.6201288d-04/
      data fxyz( 7, 7,17),fxyz( 7, 7,18)/-1.0894936d-04, 4.0756908d-05/
      data fxyz( 7, 7,19),fxyz( 7, 7,20)/-3.9881859d-05, 1.8561858d-05/
      data fxyz( 7, 7,21),fxyz( 7, 7,22)/ 1.3439429d-05,-1.9392143d-05/
      data fxyz( 7, 7,23)/               -3.6079525d-05/
      data fxyz( 7, 8, 1),fxyz( 7, 8, 2)/-3.4783402d-04,-2.0094299d-04/
      data fxyz( 7, 8, 3),fxyz( 7, 8, 4)/ 8.9161998d-05, 1.3231962d-04/
      data fxyz( 7, 8, 5),fxyz( 7, 8, 6)/-3.7357347d-04, 2.9953024d-04/
      data fxyz( 7, 8, 7),fxyz( 7, 8, 8)/-1.9028177d-04, 1.0387010d-04/
      data fxyz( 7, 8, 9),fxyz( 7, 8,10)/-2.8121663d-05, 5.2362966d-06/
      data fxyz( 7, 8,11),fxyz( 7, 8,12)/ 2.9604322d-07,-5.2644318d-06/
      data fxyz( 7, 8,13),fxyz( 7, 8,14)/ 1.0597771d-05,-1.6302475d-05/
      data fxyz( 7, 8,15),fxyz( 7, 8,16)/ 3.1527177d-05,-4.4014858d-05/
      data fxyz( 7, 8,17),fxyz( 7, 8,18)/ 2.9086247d-05,-1.0705707d-05/
      data fxyz( 7, 8,19),fxyz( 7, 8,20)/ 1.0769969d-05,-4.7985279d-06/
      data fxyz( 7, 8,21),fxyz( 7, 8,22)/-3.4342411d-06, 5.3128219d-06/
      data fxyz( 7, 8,23)/                9.7585944d-06/
      data fxyz( 7, 9, 1),fxyz( 7, 9, 2)/ 2.1141169d-04, 1.2029490d-04/
      data fxyz( 7, 9, 3),fxyz( 7, 9, 4)/-5.5109935d-05,-8.9839433d-05/
      data fxyz( 7, 9, 5),fxyz( 7, 9, 6)/ 2.5921289d-04,-3.0953078d-04/
      data fxyz( 7, 9, 7),fxyz( 7, 9, 8)/ 3.4682659d-04,-2.2487343d-04/
      data fxyz( 7, 9, 9),fxyz( 7, 9,10)/ 6.3779779d-05,-1.8741953d-05/
      data fxyz( 7, 9,11),fxyz( 7, 9,12)/ 6.4007173d-06, 5.7058766d-06/
      data fxyz( 7, 9,13),fxyz( 7, 9,14)/-1.2750940d-05, 1.4285946d-05/
      data fxyz( 7, 9,15),fxyz( 7, 9,16)/-1.4749220d-05, 1.4284408d-05/
      data fxyz( 7, 9,17),fxyz( 7, 9,18)/-8.7845536d-06, 2.4845892d-06/
      data fxyz( 7, 9,19),fxyz( 7, 9,20)/ 2.3289139d-07,-3.7937244d-07/
      data fxyz( 7, 9,21),fxyz( 7, 9,22)/-4.7269402d-07, 6.0617772d-07/
      data fxyz( 7, 9,23)/                1.0847654d-06/
      data fxyz( 7,10, 1),fxyz( 7,10, 2)/-4.0188233d-05,-2.1463899d-05/
      data fxyz( 7,10, 3),fxyz( 7,10, 4)/ 9.4834089d-06, 2.5541874d-05/
      data fxyz( 7,10, 5),fxyz( 7,10, 6)/-8.5697758d-05, 2.0068874d-04/
      data fxyz( 7,10, 7),fxyz( 7,10, 8)/-3.4333375d-04, 2.7887525d-04/
      data fxyz( 7,10, 9),fxyz( 7,10,10)/-1.0183750d-04, 2.8422306d-05/
      data fxyz( 7,10,11),fxyz( 7,10,12)/-1.0727227d-05,-6.9728471d-06/
      data fxyz( 7,10,13),fxyz( 7,10,14)/ 1.4517402d-05,-1.2885623d-05/
      data fxyz( 7,10,15),fxyz( 7,10,16)/ 9.2466778d-06,-5.5945164d-06/
      data fxyz( 7,10,17),fxyz( 7,10,18)/ 2.4636252d-06, 1.8562908d-06/
      data fxyz( 7,10,19),fxyz( 7,10,20)/-9.5133954d-06, 5.2139929d-06/
      data fxyz( 7,10,21),fxyz( 7,10,22)/ 4.3480530d-06,-6.0496358d-06/
      data fxyz( 7,10,23)/               -1.1132808d-05/
      data fxyz( 7,11, 1),fxyz( 7,11, 2)/ 1.3237218d-05, 5.8449943d-06/
      data fxyz( 7,11, 3),fxyz( 7,11, 4)/-6.4920710d-06,-1.2623046d-05/
      data fxyz( 7,11, 5),fxyz( 7,11, 6)/ 3.0368893d-05,-7.8727401d-05/
      data fxyz( 7,11, 7),fxyz( 7,11, 8)/ 1.6805506d-04,-1.7679914d-04/
      data fxyz( 7,11, 9),fxyz( 7,11,10)/ 1.0134471d-04,-3.4844070d-05/
      data fxyz( 7,11,11),fxyz( 7,11,12)/ 8.5768961d-06, 3.3466473d-06/
      data fxyz( 7,11,13),fxyz( 7,11,14)/-7.0368786d-06, 4.6242571d-06/
      data fxyz( 7,11,15),fxyz( 7,11,16)/-2.7408381d-06, 1.1051972d-06/
      data fxyz( 7,11,17),fxyz( 7,11,18)/ 1.0763350d-06,-6.7343428d-06/
      data fxyz( 7,11,19),fxyz( 7,11,20)/ 2.6061491d-05,-1.4402408d-05/
      data fxyz( 7,11,21),fxyz( 7,11,22)/-1.1949291d-05, 1.6249025d-05/
      data fxyz( 7,11,23)/                3.0062404d-05/
      data fxyz( 7,12, 1),fxyz( 7,12, 2)/ 3.3348778d-05, 1.6721289d-05/
      data fxyz( 7,12, 3),fxyz( 7,12, 4)/-1.8529354d-05,-1.9193814d-05/
      data fxyz( 7,12, 5),fxyz( 7,12, 6)/ 1.9379125d-05, 2.3381890d-05/
      data fxyz( 7,12, 7),fxyz( 7,12, 8)/-3.7998155d-05, 4.5708860d-05/
      data fxyz( 7,12, 9),fxyz( 7,12,10)/-3.9579693d-05, 2.4840094d-05/
      data fxyz( 7,12,11),fxyz( 7,12,12)/-7.0983129d-06,-1.4886788d-06/
      data fxyz( 7,12,13),fxyz( 7,12,14)/ 2.2874379d-06,-1.2001670d-06/
      data fxyz( 7,12,15),fxyz( 7,12,16)/ 5.8002053d-07, 1.0945420d-07/
      data fxyz( 7,12,17),fxyz( 7,12,18)/-1.2482210d-06, 5.2926005d-06/
      data fxyz( 7,12,19),fxyz( 7,12,20)/-2.1879702d-05, 1.2109063d-05/
      data fxyz( 7,12,21),fxyz( 7,12,22)/ 1.0066323d-05,-1.3708742d-05/
      data fxyz( 7,12,23)/               -2.5348502d-05/
      data fxyz( 7,13, 1),fxyz( 7,13, 2)/-5.2356906d-05,-2.5731141d-05/
      data fxyz( 7,13, 3),fxyz( 7,13, 4)/ 3.0035497d-05, 3.2290500d-05/
      data fxyz( 7,13, 5),fxyz( 7,13, 6)/-3.4751154d-05,-1.8531856d-05/
      data fxyz( 7,13, 7),fxyz( 7,13, 8)/ 1.2158371d-05,-5.2553102d-06/
      data fxyz( 7,13, 9),fxyz( 7,13,10)/-8.1999929d-06, 1.0139457d-05/
      data fxyz( 7,13,11),fxyz( 7,13,12)/-5.8303204d-06, 5.3862249d-06/
      data fxyz( 7,13,13),fxyz( 7,13,14)/-1.8685352d-06,-2.4310611d-06/
      data fxyz( 7,13,15),fxyz( 7,13,16)/ 1.8184448d-06,-2.8998924d-07/
      data fxyz( 7,13,17),fxyz( 7,13,18)/-6.8332428d-07, 1.8154488d-06/
      data fxyz( 7,13,19),fxyz( 7,13,20)/-9.4641546d-06, 5.7295562d-06/
      data fxyz( 7,13,21),fxyz( 7,13,22)/ 4.8575624d-06,-5.9761796d-06/
      data fxyz( 7,13,23)/               -1.1264457d-05/
      data fxyz( 7,14, 1),fxyz( 7,14, 2)/-1.8117954d-05,-6.8991200d-06/
      data fxyz( 7,14, 3),fxyz( 7,14, 4)/ 1.6684149d-05, 1.7484057d-05/
      data fxyz( 7,14, 5),fxyz( 7,14, 6)/-1.0098754d-05,-6.1193286d-06/
      data fxyz( 7,14, 7),fxyz( 7,14, 8)/-9.8793961d-06,-6.6700722d-07/
      data fxyz( 7,14, 9),fxyz( 7,14,10)/ 1.1305249d-05,-2.3417890d-05/
      data fxyz( 7,14,11),fxyz( 7,14,12)/ 2.0848111d-05,-1.2767663d-05/
      data fxyz( 7,14,13),fxyz( 7,14,14)/ 3.9900160d-06, 2.9270000d-06/
      data fxyz( 7,14,15),fxyz( 7,14,16)/-2.5350558d-06, 3.0737072d-07/
      data fxyz( 7,14,17),fxyz( 7,14,18)/ 7.9863935d-07,-3.6319721d-06/
      data fxyz( 7,14,19),fxyz( 7,14,20)/ 1.5520680d-05,-8.6808007d-06/
      data fxyz( 7,14,21),fxyz( 7,14,22)/-7.2355471d-06, 9.7396657d-06/
      data fxyz( 7,14,23)/                1.8046833d-05/
      data fxyz( 7,15, 1),fxyz( 7,15, 2)/ 9.6872330d-06, 3.3281514d-06/
      data fxyz( 7,15, 3),fxyz( 7,15, 4)/-1.0562278d-05,-1.0100583d-05/
      data fxyz( 7,15, 5),fxyz( 7,15, 6)/ 1.4813714d-06, 1.6612658d-05/
      data fxyz( 7,15, 7),fxyz( 7,15, 8)/-6.8670897d-06, 1.9813386d-05/
      data fxyz( 7,15, 9),fxyz( 7,15,10)/-5.0391681d-05, 6.1311712d-05/
      data fxyz( 7,15,11),fxyz( 7,15,12)/-3.5814725d-05, 1.6574625d-05/
      data fxyz( 7,15,13),fxyz( 7,15,14)/-9.0213740d-06, 8.0648870d-07/
      data fxyz( 7,15,15),fxyz( 7,15,16)/ 5.0895314d-07,-4.2006875d-08/
      data fxyz( 7,15,17),fxyz( 7,15,18)/-5.1618249d-08, 1.2589075d-06/
      data fxyz( 7,15,19),fxyz( 7,15,20)/-3.5498200d-06, 1.8606818d-06/
      data fxyz( 7,15,21),fxyz( 7,15,22)/ 1.5125666d-06,-2.1573589d-06/
      data fxyz( 7,15,23)/               -3.9628215d-06/
      data fxyz( 7,16, 1),fxyz( 7,16, 2)/ 1.9992851d-05, 1.0272393d-05/
      data fxyz( 7,16, 3),fxyz( 7,16, 4)/-9.3028218d-06,-1.1497912d-05/
      data fxyz( 7,16, 5),fxyz( 7,16, 6)/ 1.9052753d-05,-1.2933497d-05/
      data fxyz( 7,16, 7),fxyz( 7,16, 8)/ 2.7497517d-05,-6.2897731d-05/
      data fxyz( 7,16, 9),fxyz( 7,16,10)/ 1.5115012d-04,-1.9198247d-04/
      data fxyz( 7,16,11),fxyz( 7,16,12)/ 1.2019615d-04,-5.7613959d-05/
      data fxyz( 7,16,13),fxyz( 7,16,14)/ 3.1572016d-05,-7.0391891d-06/
      data fxyz( 7,16,15),fxyz( 7,16,16)/ 1.3328675d-06,-6.3227295d-07/
      data fxyz( 7,16,17),fxyz( 7,16,18)/-6.1839193d-08,-4.3581729d-07/
      data fxyz( 7,16,19),fxyz( 7,16,20)/ 8.0626040d-07,-1.0192369d-06/
      data fxyz( 7,16,21),fxyz( 7,16,22)/-9.1983932d-07, 4.0866994d-07/
      data fxyz( 7,16,23)/                1.0551470d-06/
      data fxyz( 7,17, 1),fxyz( 7,17, 2)/-1.4916920d-06,-1.0106911d-06/
      data fxyz( 7,17, 3),fxyz( 7,17, 4)/-1.2399577d-06, 9.6501254d-07/
      data fxyz( 7,17, 5),fxyz( 7,17, 6)/-9.8305719d-06, 3.1582861d-05/
      data fxyz( 7,17, 7),fxyz( 7,17, 8)/-8.7756790d-05, 2.3116637d-04/
      data fxyz( 7,17, 9),fxyz( 7,17,10)/-5.3869011d-04, 7.5295890d-04/
      data fxyz( 7,17,11),fxyz( 7,17,12)/-5.7170037d-04, 2.7935234d-04/
      data fxyz( 7,17,13),fxyz( 7,17,14)/-1.1899840d-04, 3.1053640d-05/
      data fxyz( 7,17,15),fxyz( 7,17,16)/-7.1876881d-06, 3.0962864d-06/
      data fxyz( 7,17,17),fxyz( 7,17,18)/ 2.5726148d-07, 1.0778482d-06/
      data fxyz( 7,17,19),fxyz( 7,17,20)/ 7.2884367d-07, 1.4586380d-06/
      data fxyz( 7,17,21),fxyz( 7,17,22)/ 1.4259050d-06, 8.5977567d-07/
      data fxyz( 7,17,23)/                5.8685318d-07/
      data fxyz( 7,18, 1),fxyz( 7,18, 2)/-2.2406217d-07,-4.7262537d-07/
      data fxyz( 7,18, 3),fxyz( 7,18, 4)/ 1.8710134d-07,-1.8995324d-06/
      data fxyz( 7,18, 5),fxyz( 7,18, 6)/ 7.8739095d-06,-3.1523568d-05/
      data fxyz( 7,18, 7),fxyz( 7,18, 8)/ 9.5304783d-05,-2.4941949d-04/
      data fxyz( 7,18, 9),fxyz( 7,18,10)/ 5.9347517d-04,-8.5482174d-04/
      data fxyz( 7,18,11),fxyz( 7,18,12)/ 6.5995108d-04,-3.0916035d-04/
      data fxyz( 7,18,13),fxyz( 7,18,14)/ 1.2361573d-04,-3.3230593d-05/
      data fxyz( 7,18,15),fxyz( 7,18,16)/ 7.8406020d-06,-3.2623566d-06/
      data fxyz( 7,18,17),fxyz( 7,18,18)/-2.6006533d-07,-1.0818721d-06/
      data fxyz( 7,18,19),fxyz( 7,18,20)/-1.0128154d-06,-1.4258738d-06/
      data fxyz( 7,18,21),fxyz( 7,18,22)/-1.4134458d-06,-1.0625275d-06/
      data fxyz( 7,18,23)/               -8.9545153d-07/
      data fxyz( 7,19, 1),fxyz( 7,19, 2)/-5.4570530d-06,-3.3120311d-06/
      data fxyz( 7,19, 3),fxyz( 7,19, 4)/ 3.5101047d-06,-3.8480043d-07/
      data fxyz( 7,19, 5),fxyz( 7,19, 6)/ 1.2267589d-05,-6.3880629d-05/
      data fxyz( 7,19, 7),fxyz( 7,19, 8)/ 1.9313325d-04,-5.0867679d-04/
      data fxyz( 7,19, 9),fxyz( 7,19,10)/ 1.2050675d-03,-1.7332532d-03/
      data fxyz( 7,19,11),fxyz( 7,19,12)/ 1.3420174d-03,-6.3325048d-04/
      data fxyz( 7,19,13),fxyz( 7,19,14)/ 2.5389142d-04,-6.8264237d-05/
      data fxyz( 7,19,15),fxyz( 7,19,16)/ 1.6140651d-05,-6.7389417d-06/
      data fxyz( 7,19,17),fxyz( 7,19,18)/-5.3841286d-07,-2.1920536d-06/
      data fxyz( 7,19,19),fxyz( 7,19,20)/-2.2789766d-06,-2.7782751d-06/
      data fxyz( 7,19,21),fxyz( 7,19,22)/-2.7713408d-06,-2.3067139d-06/
      data fxyz( 7,19,23)/               -2.0880388d-06/
      data fxyz( 8, 1, 1),fxyz( 8, 1, 2)/ 2.7505674d-03, 1.7378417d-03/
      data fxyz( 8, 1, 3),fxyz( 8, 1, 4)/-3.0587692d-04,-5.2709049d-04/
      data fxyz( 8, 1, 5),fxyz( 8, 1, 6)/ 2.6226960d-03,-5.6763610d-04/
      data fxyz( 8, 1, 7),fxyz( 8, 1, 8)/ 1.3232329d-03,-4.9663411d-03/
      data fxyz( 8, 1, 9),fxyz( 8, 1,10)/ 2.3194623d-03,-5.5100762d-04/
      data fxyz( 8, 1,11),fxyz( 8, 1,12)/-3.8748454d-04, 2.0037723d-03/
      data fxyz( 8, 1,13),fxyz( 8, 1,14)/-7.1451842d-04,-1.1530497d-04/
      data fxyz( 8, 1,15),fxyz( 8, 1,16)/ 1.4674931d-03,-3.7391305d-03/
      data fxyz( 8, 1,17),fxyz( 8, 1,18)/ 2.0226034d-05, 6.4017525d-04/
      data fxyz( 8, 1,19),fxyz( 8, 1,20)/ 1.9415000d-03,-4.1213769d-04/
      data fxyz( 8, 1,21),fxyz( 8, 1,22)/-2.9822840d-04, 1.4858628d-03/
      data fxyz( 8, 1,23)/                2.3488146d-03/
      data fxyz( 8, 2, 1),fxyz( 8, 2, 2)/ 1.3655756d-03, 8.5958681d-04/
      data fxyz( 8, 2, 3),fxyz( 8, 2, 4)/-1.6217350d-04,-2.7155084d-04/
      data fxyz( 8, 2, 5),fxyz( 8, 2, 6)/ 1.2970962d-03,-2.7508457d-04/
      data fxyz( 8, 2, 7),fxyz( 8, 2, 8)/ 6.3833102d-04,-2.4104056d-03/
      data fxyz( 8, 2, 9),fxyz( 8, 2,10)/ 1.1084861d-03,-2.3175041d-04/
      data fxyz( 8, 2,11),fxyz( 8, 2,12)/-1.9962156d-04, 9.2364811d-04/
      data fxyz( 8, 2,13),fxyz( 8, 2,14)/-2.6177180d-04,-9.9142636d-05/
      data fxyz( 8, 2,15),fxyz( 8, 2,16)/ 7.2262637d-04,-1.8430384d-03/
      data fxyz( 8, 2,17),fxyz( 8, 2,18)/ 3.5975537d-05, 3.2108479d-04/
      data fxyz( 8, 2,19),fxyz( 8, 2,20)/ 9.4419574d-04,-2.1210612d-04/
      data fxyz( 8, 2,21),fxyz( 8, 2,22)/-1.5691379d-04, 7.2342641d-04/
      data fxyz( 8, 2,23)/                1.1489698d-03/
      data fxyz( 8, 3, 1),fxyz( 8, 3, 2)/-1.6475406d-03,-1.0435630d-03/
      data fxyz( 8, 3, 3),fxyz( 8, 3, 4)/ 1.4620454d-04, 3.2902690d-04/
      data fxyz( 8, 3, 5),fxyz( 8, 3, 6)/-1.7748525d-03, 1.0947949d-03/
      data fxyz( 8, 3, 7),fxyz( 8, 3, 8)/-1.0857251d-03, 2.2909582d-03/
      data fxyz( 8, 3, 9),fxyz( 8, 3,10)/-5.0521013d-04,-7.2343630d-04/
      data fxyz( 8, 3,11),fxyz( 8, 3,12)/ 1.0284109d-03,-1.9698210d-03/
      data fxyz( 8, 3,13),fxyz( 8, 3,14)/ 1.9288649d-03,-1.2980103d-03/
      data fxyz( 8, 3,15),fxyz( 8, 3,16)/ 1.0761618d-05, 1.2490215d-03/
      data fxyz( 8, 3,17),fxyz( 8, 3,18)/ 2.2042954d-04, 6.2989750d-05/
      data fxyz( 8, 3,19),fxyz( 8, 3,20)/-1.2712240d-03, 2.2775185d-04/
      data fxyz( 8, 3,21),fxyz( 8, 3,22)/ 1.3121376d-04,-8.8507165d-04/
      data fxyz( 8, 3,23)/               -1.3850817d-03/
      data fxyz( 8, 4, 1),fxyz( 8, 4, 2)/ 1.0377785d-03, 6.4041943d-04/
      data fxyz( 8, 4, 3),fxyz( 8, 4, 4)/-1.2177856d-04,-2.7802869d-04/
      data fxyz( 8, 4, 5),fxyz( 8, 4, 6)/ 1.2654200d-03,-1.3059734d-03/
      data fxyz( 8, 4, 7),fxyz( 8, 4, 8)/ 8.2725849d-04,-5.1667698d-04/
      data fxyz( 8, 4, 9),fxyz( 8, 4,10)/-7.0938632d-04, 1.6231786d-03/
      data fxyz( 8, 4,11),fxyz( 8, 4,12)/-1.3841498d-03, 1.4834172d-03/
      data fxyz( 8, 4,13),fxyz( 8, 4,14)/-1.9631137d-03, 1.7557270d-03/
      data fxyz( 8, 4,15),fxyz( 8, 4,16)/-8.1661011d-04, 1.5519413d-04/
      data fxyz( 8, 4,17),fxyz( 8, 4,18)/-1.8558220d-04,-4.0858924d-04/
      data fxyz( 8, 4,19),fxyz( 8, 4,20)/ 7.7676053d-04,-1.7178260d-04/
      data fxyz( 8, 4,21),fxyz( 8, 4,22)/-9.4503971d-05, 4.6764599d-04/
      data fxyz( 8, 4,23)/                7.5059027d-04/
      data fxyz( 8, 5, 1),fxyz( 8, 5, 2)/-5.2909413d-04,-3.2329019d-04/
      data fxyz( 8, 5, 3),fxyz( 8, 5, 4)/ 6.2998770d-05, 1.5875786d-04/
      data fxyz( 8, 5, 5),fxyz( 8, 5, 6)/-7.0632654d-04, 9.0729221d-04/
      data fxyz( 8, 5, 7),fxyz( 8, 5, 8)/-5.5234950d-04, 1.1213855d-04/
      data fxyz( 8, 5, 9),fxyz( 8, 5,10)/ 5.3829554d-04,-1.0341974d-03/
      data fxyz( 8, 5,11),fxyz( 8, 5,12)/ 7.9002853d-04,-5.9373638d-04/
      data fxyz( 8, 5,13),fxyz( 8, 5,14)/ 8.1425900d-04,-8.7565010d-04/
      data fxyz( 8, 5,15),fxyz( 8, 5,16)/ 5.6143690d-04,-2.7808964d-04/
      data fxyz( 8, 5,17),fxyz( 8, 5,18)/ 9.5884854d-05, 2.1510070d-04/
      data fxyz( 8, 5,19),fxyz( 8, 5,20)/-3.4127976d-04, 1.0203522d-04/
      data fxyz( 8, 5,21),fxyz( 8, 5,22)/ 6.5804485d-05,-1.9635682d-04/
      data fxyz( 8, 5,23)/               -3.2836030d-04/
      data fxyz( 8, 6, 1),fxyz( 8, 6, 2)/ 4.4946617d-05, 3.0542337d-05/
      data fxyz( 8, 6, 3),fxyz( 8, 6, 4)/ 1.1919031d-05,-9.5062321d-06/
      data fxyz( 8, 6, 5),fxyz( 8, 6, 6)/ 1.1624339d-04,-2.7643233d-04/
      data fxyz( 8, 6, 7),fxyz( 8, 6, 8)/ 2.1995539d-04,-4.8248318d-05/
      data fxyz( 8, 6, 9),fxyz( 8, 6,10)/-1.3877473d-04, 2.7608901d-04/
      data fxyz( 8, 6,11),fxyz( 8, 6,12)/-2.1260784d-04, 1.6167582d-04/
      data fxyz( 8, 6,13),fxyz( 8, 6,14)/-2.2516796d-04, 2.5431417d-04/
      data fxyz( 8, 6,15),fxyz( 8, 6,16)/-2.1057865d-04, 1.6582515d-04/
      data fxyz( 8, 6,17),fxyz( 8, 6,18)/-8.1574106d-05,-4.9948294d-05/
      data fxyz( 8, 6,19),fxyz( 8, 6,20)/ 9.5194537d-05,-2.8036089d-05/
      data fxyz( 8, 6,21),fxyz( 8, 6,22)/-1.8416606d-05, 5.6716602d-05/
      data fxyz( 8, 6,23)/                9.4343961d-05/
      data fxyz( 8, 7, 1),fxyz( 8, 7, 2)/-3.1388272d-05,-7.8454020d-06/
      data fxyz( 8, 7, 3),fxyz( 8, 7, 4)/ 4.8042326d-05, 3.8524565d-05/
      data fxyz( 8, 7, 5),fxyz( 8, 7, 6)/ 3.0225644d-05,-1.7415469d-04/
      data fxyz( 8, 7, 7),fxyz( 8, 7, 8)/ 1.0628104d-04,-3.4438806d-05/
      data fxyz( 8, 7, 9),fxyz( 8, 7,10)/ 4.9624535d-05,-7.7392128d-05/
      data fxyz( 8, 7,11),fxyz( 8, 7,12)/ 5.8486527d-05,-4.4452484d-05/
      data fxyz( 8, 7,13),fxyz( 8, 7,14)/ 6.1925768d-05,-7.0634807d-05/
      data fxyz( 8, 7,15),fxyz( 8, 7,16)/ 5.8943053d-05,-4.6719634d-05/
      data fxyz( 8, 7,17),fxyz( 8, 7,18)/ 2.1982949d-05, 1.3814627d-05/
      data fxyz( 8, 7,19),fxyz( 8, 7,20)/-3.7966349d-05, 1.6491168d-05/
      data fxyz( 8, 7,21),fxyz( 8, 7,22)/ 1.2826873d-05,-2.3309168d-05/
      data fxyz( 8, 7,23)/               -4.1149800d-05/
      data fxyz( 8, 8, 1),fxyz( 8, 8, 2)/-5.4625095d-05,-5.8683896d-05/
      data fxyz( 8, 8, 3),fxyz( 8, 8, 4)/-1.0210817d-04,-4.1336192d-05/
      data fxyz( 8, 8, 5),fxyz( 8, 8, 6)/-3.0177181d-04, 8.5695459d-04/
      data fxyz( 8, 8, 7),fxyz( 8, 8, 8)/-6.1057867d-04, 1.7568460d-04/
      data fxyz( 8, 8, 9),fxyz( 8, 8,10)/-5.7702730d-05, 3.2516629d-05/
      data fxyz( 8, 8,11),fxyz( 8, 8,12)/-1.9111502d-05, 1.3402554d-05/
      data fxyz( 8, 8,13),fxyz( 8, 8,14)/-1.7652902d-05, 1.9751612d-05/
      data fxyz( 8, 8,15),fxyz( 8, 8,16)/-1.6352736d-05, 1.2480394d-05/
      data fxyz( 8, 8,17),fxyz( 8, 8,18)/-5.8780802d-06,-4.0666272d-06/
      data fxyz( 8, 8,19),fxyz( 8, 8,20)/ 1.1337543d-05,-4.7424854d-06/
      data fxyz( 8, 8,21),fxyz( 8, 8,22)/-3.6550716d-06, 6.9878882d-06/
      data fxyz( 8, 8,23)/                1.2244580d-05/
      data fxyz( 8, 9, 1),fxyz( 8, 9, 2)/ 3.6338180d-04, 2.4502896d-04/
      data fxyz( 8, 9, 3),fxyz( 8, 9, 4)/ 6.1969454d-05,-6.1499541d-05/
      data fxyz( 8, 9, 5),fxyz( 8, 9, 6)/ 7.3890494d-04,-1.4886531d-03/
      data fxyz( 8, 9, 7),fxyz( 8, 9, 8)/ 1.0711299d-03,-3.4393457d-04/
      data fxyz( 8, 9, 9),fxyz( 8, 9,10)/ 9.4562765d-05,-2.8195076d-05/
      data fxyz( 8, 9,11),fxyz( 8, 9,12)/ 1.0293080d-05,-6.7143557d-06/
      data fxyz( 8, 9,13),fxyz( 8, 9,14)/ 7.9240908d-06,-8.1055691d-06/
      data fxyz( 8, 9,15),fxyz( 8, 9,16)/ 6.0840035d-06,-4.0201533d-06/
      data fxyz( 8, 9,17),fxyz( 8, 9,18)/ 1.8641740d-06, 1.2312892d-06/
      data fxyz( 8, 9,19),fxyz( 8, 9,20)/-3.2939684d-06, 1.4146287d-06/
      data fxyz( 8, 9,21),fxyz( 8, 9,22)/ 1.0955178d-06,-2.0175248d-06/
      data fxyz( 8, 9,23)/               -3.5553743d-06/
      data fxyz( 8,10, 1),fxyz( 8,10, 2)/-2.9723910d-04,-1.9185871d-04/
      data fxyz( 8,10, 3),fxyz( 8,10, 4)/-1.5555872d-05, 7.1090648d-05/
      data fxyz( 8,10, 5),fxyz( 8,10, 6)/-5.3844479d-04, 1.0024587d-03/
      data fxyz( 8,10, 7),fxyz( 8,10, 8)/-7.7673175d-04, 3.1718907d-04/
      data fxyz( 8,10, 9),fxyz( 8,10,10)/-1.0018017d-04, 2.2225709d-05/
      data fxyz( 8,10,11),fxyz( 8,10,12)/-6.2432567d-06, 4.9285645d-06/
      data fxyz( 8,10,13),fxyz( 8,10,14)/-5.5526106d-06, 4.7346569d-06/
      data fxyz( 8,10,15),fxyz( 8,10,16)/-3.1068508d-06, 1.5625415d-06/
      data fxyz( 8,10,17),fxyz( 8,10,18)/-5.7697874d-07,-9.1946021d-07/
      data fxyz( 8,10,19),fxyz( 8,10,20)/ 3.9020494d-06,-2.0797871d-06/
      data fxyz( 8,10,21),fxyz( 8,10,22)/-1.7184090d-06, 2.4565368d-06/
      data fxyz( 8,10,23)/                4.5012123d-06/
      data fxyz( 8,11, 1),fxyz( 8,11, 2)/ 8.8390062d-05, 5.5187887d-05/
      data fxyz( 8,11, 3),fxyz( 8,11, 4)/-1.9557527d-06,-2.6462538d-05/
      data fxyz( 8,11, 5),fxyz( 8,11, 6)/ 1.5321503d-04,-2.7921171d-04/
      data fxyz( 8,11, 7),fxyz( 8,11, 8)/ 2.4565140d-04,-1.3850804d-04/
      data fxyz( 8,11, 9),fxyz( 8,11,10)/ 6.7949935d-05,-1.9603020d-05/
      data fxyz( 8,11,11),fxyz( 8,11,12)/ 3.4786353d-06,-3.0146053d-06/
      data fxyz( 8,11,13),fxyz( 8,11,14)/ 2.6445858d-06,-1.6697033d-06/
      data fxyz( 8,11,15),fxyz( 8,11,16)/ 9.2434554d-07,-2.9783069d-07/
      data fxyz( 8,11,17),fxyz( 8,11,18)/-3.0773602d-07, 2.0606652d-06/
      data fxyz( 8,11,19),fxyz( 8,11,20)/-7.4811293d-06, 3.9529783d-06/
      data fxyz( 8,11,21),fxyz( 8,11,22)/ 3.2467578d-06,-4.6562474d-06/
      data fxyz( 8,11,23)/               -8.5326420d-06/
      data fxyz( 8,12, 1),fxyz( 8,12, 2)/-1.6618180d-05,-1.1953149d-05/
      data fxyz( 8,12, 3),fxyz( 8,12, 4)/-5.4406430d-06, 6.5633765d-07/
      data fxyz( 8,12, 5),fxyz( 8,12, 6)/-3.6341072d-05, 7.4836529d-05/
      data fxyz( 8,12, 7),fxyz( 8,12, 8)/-5.3384995d-05, 2.4112592d-05/
      data fxyz( 8,12, 9),fxyz( 8,12,10)/-1.7285350d-05, 1.3348025d-05/
      data fxyz( 8,12,11),fxyz( 8,12,12)/-5.0762405d-06, 1.7977913d-06/
      data fxyz( 8,12,13),fxyz( 8,12,14)/-1.2271647d-06, 5.0502980d-07/
      data fxyz( 8,12,15),fxyz( 8,12,16)/-1.9064833d-07, 5.2630214d-08/
      data fxyz( 8,12,17),fxyz( 8,12,18)/ 3.7512283d-07,-1.6989803d-06/
      data fxyz( 8,12,19),fxyz( 8,12,20)/ 4.3997497d-06,-2.2136874d-06/
      data fxyz( 8,12,21),fxyz( 8,12,22)/-1.7776905d-06, 2.6557622d-06/
      data fxyz( 8,12,23)/                4.8409727d-06/
      data fxyz( 8,13, 1),fxyz( 8,13, 2)/-1.5414113d-05,-6.3196559d-06/
      data fxyz( 8,13, 3),fxyz( 8,13, 4)/ 1.3503874d-05, 1.2916912d-05/
      data fxyz( 8,13, 5),fxyz( 8,13, 6)/-3.9718111d-06,-2.4218531d-05/
      data fxyz( 8,13, 7),fxyz( 8,13, 8)/ 1.5218262d-05,-9.2182941d-06/
      data fxyz( 8,13, 9),fxyz( 8,13,10)/ 4.1447988d-06,-4.6166570d-06/
      data fxyz( 8,13,11),fxyz( 8,13,12)/ 5.1062148d-06,-2.9429934d-06/
      data fxyz( 8,13,13),fxyz( 8,13,14)/ 8.4128485d-07, 4.6669661d-07/
      data fxyz( 8,13,15),fxyz( 8,13,16)/-4.5256874d-07, 1.5627128d-08/
      data fxyz( 8,13,17),fxyz( 8,13,18)/ 9.4943025d-08,-9.1777068d-07/
      data fxyz( 8,13,19),fxyz( 8,13,20)/ 2.2576542d-06,-9.6795982d-07/
      data fxyz( 8,13,21),fxyz( 8,13,22)/-7.4577415d-07, 1.3689115d-06/
      data fxyz( 8,13,23)/                2.4150144d-06/
      data fxyz( 8,14, 1),fxyz( 8,14, 2)/-1.7851638d-05,-7.7827217d-06/
      data fxyz( 8,14, 3),fxyz( 8,14, 4)/ 1.3149916d-05, 1.4276238d-05/
      data fxyz( 8,14, 5),fxyz( 8,14, 6)/-1.2288010d-05,-9.5680908d-07/
      data fxyz( 8,14, 7),fxyz( 8,14, 8)/-1.2546368d-05, 2.0093811d-05/
      data fxyz( 8,14, 9),fxyz( 8,14,10)/-3.9597498d-05, 4.0398583d-05/
      data fxyz( 8,14,11),fxyz( 8,14,12)/-2.1324182d-05, 7.4395323d-06/
      data fxyz( 8,14,13),fxyz( 8,14,14)/-2.3076914d-06,-4.7501609d-07/
      data fxyz( 8,14,15),fxyz( 8,14,16)/ 5.3925764d-07,-7.0673211d-08/
      data fxyz( 8,14,17),fxyz( 8,14,18)/-3.1182045d-07, 1.1778906d-06/
      data fxyz( 8,14,19),fxyz( 8,14,20)/-3.1587235d-06, 1.6352108d-06/
      data fxyz( 8,14,21),fxyz( 8,14,22)/ 1.3231642d-06,-1.9105368d-06/
      data fxyz( 8,14,23)/               -3.5028097d-06/
      data fxyz( 8,15, 1),fxyz( 8,15, 2)/ 1.9337519d-05, 9.9728762d-06/
      data fxyz( 8,15, 3),fxyz( 8,15, 4)/-9.0567667d-06,-1.0872304d-05/
      data fxyz( 8,15, 5),fxyz( 8,15, 6)/ 1.7235025d-05,-7.8955391d-06/
      data fxyz( 8,15, 7),fxyz( 8,15, 8)/ 2.4637728d-05,-6.3874550d-05/
      data fxyz( 8,15, 9),fxyz( 8,15,10)/ 1.2633251d-04,-1.4209429d-04/
      data fxyz( 8,15,11),fxyz( 8,15,12)/ 8.0748289d-05,-2.5734576d-05/
      data fxyz( 8,15,13),fxyz( 8,15,14)/ 7.9284924d-06,-1.6975725d-06/
      data fxyz( 8,15,15),fxyz( 8,15,16)/ 2.7326969d-07,-1.1643803d-07/
      data fxyz( 8,15,17),fxyz( 8,15,18)/ 1.4991059d-07,-1.7243351d-07/
      data fxyz( 8,15,19),fxyz( 8,15,20)/ 1.1830013d-06,-8.2387633d-07/
      data fxyz( 8,15,21),fxyz( 8,15,22)/-7.1507992d-07, 7.4781570d-07/
      data fxyz( 8,15,23)/                1.4595127d-06/
      data fxyz( 8,16, 1),fxyz( 8,16, 2)/ 3.0892643d-06, 8.8576841d-07/
      data fxyz( 8,16, 3),fxyz( 8,16, 4)/-4.8585643d-06,-3.0690916d-06/
      data fxyz( 8,16, 5),fxyz( 8,16, 6)/-6.2721225d-06, 2.9931355d-05/
      data fxyz( 8,16, 7),fxyz( 8,16, 8)/-7.4300593d-05, 1.9976399d-04/
      data fxyz( 8,16, 9),fxyz( 8,16,10)/-3.6476941d-04, 3.7179510d-04/
      data fxyz( 8,16,11),fxyz( 8,16,12)/-1.9846784d-04, 6.3951804d-05/
      data fxyz( 8,16,13),fxyz( 8,16,14)/-2.1057482d-05, 5.2366408d-06/
      data fxyz( 8,16,15),fxyz( 8,16,16)/-1.3351977d-06, 4.8673401d-07/
      data fxyz( 8,16,17),fxyz( 8,16,18)/-4.3483881d-08, 1.9712220d-07/
      data fxyz( 8,16,19),fxyz( 8,16,20)/-2.0637954d-07, 1.9951732d-07/
      data fxyz( 8,16,21),fxyz( 8,16,22)/ 1.7137237d-07,-9.3799738d-08/
      data fxyz( 8,16,23)/               -2.2505204d-07/
      data fxyz( 8,17, 1),fxyz( 8,17, 2)/-5.6508690d-06,-4.0918436d-06/
      data fxyz( 8,17, 3),fxyz( 8,17, 4)/ 2.2035088d-06,-2.9670126d-06/
      data fxyz( 8,17, 5),fxyz( 8,17, 6)/ 1.6590242d-05,-8.3208689d-05/
      data fxyz( 8,17, 7),fxyz( 8,17, 8)/ 2.4661996d-04,-5.6742315d-04/
      data fxyz( 8,17, 9),fxyz( 8,17,10)/ 8.4059720d-04,-6.8717009d-04/
      data fxyz( 8,17,11),fxyz( 8,17,12)/ 3.1591677d-04,-1.1176816d-04/
      data fxyz( 8,17,13),fxyz( 8,17,14)/ 4.2942940d-05,-1.0965763d-05/
      data fxyz( 8,17,15),fxyz( 8,17,16)/ 2.8158865d-06,-1.1502646d-06/
      data fxyz( 8,17,17),fxyz( 8,17,18)/ 4.7676410d-08,-3.3401576d-07/
      data fxyz( 8,17,19),fxyz( 8,17,20)/-1.7923073d-07,-4.0561869d-07/
      data fxyz( 8,17,21),fxyz( 8,17,22)/-3.9325638d-07,-2.2867998d-07/
      data fxyz( 8,17,23)/               -1.4858105d-07/
      data fxyz( 8,18, 1),fxyz( 8,18, 2)/ 6.3686688d-06, 4.1523833d-06/
      data fxyz( 8,18, 3),fxyz( 8,18, 4)/-3.6494726d-06, 1.6927044d-06/
      data fxyz( 8,18, 5),fxyz( 8,18, 6)/-1.7216325d-05, 8.6501325d-05/
      data fxyz( 8,18, 7),fxyz( 8,18, 8)/-2.4978031d-04, 5.4505453d-04/
      data fxyz( 8,18, 9),fxyz( 8,18,10)/-7.0824190d-04, 4.7739360d-04/
      data fxyz( 8,18,11),fxyz( 8,18,12)/-1.9153287d-04, 8.1536759d-05/
      data fxyz( 8,18,13),fxyz( 8,18,14)/-3.3405686d-05, 8.9267453d-06/
      data fxyz( 8,18,15),fxyz( 8,18,16)/-2.1207771d-06, 9.4922343d-07/
      data fxyz( 8,18,17),fxyz( 8,18,18)/ 4.9818818d-08, 3.0852420d-07/
      data fxyz( 8,18,19),fxyz( 8,18,20)/ 2.6001278d-07, 3.7373692d-07/
      data fxyz( 8,18,21),fxyz( 8,18,22)/ 3.6891496d-07, 2.7930063d-07/
      data fxyz( 8,18,23)/                2.3619475d-07/
      data fxyz( 8,19, 1),fxyz( 8,19, 2)/ 1.2456872d-05, 8.6189419d-06/
      data fxyz( 8,19, 3),fxyz( 8,19, 4)/-5.8124385d-06, 5.0502392d-06/
      data fxyz( 8,19, 5),fxyz( 8,19, 6)/-3.4831769d-05, 1.7539704d-04/
      data fxyz( 8,19, 7),fxyz( 8,19, 8)/-5.1266035d-04, 1.1204851d-03/
      data fxyz( 8,19, 9),fxyz( 8,19,10)/-1.4701651d-03, 1.0066633d-03/
      data fxyz( 8,19,11),fxyz( 8,19,12)/-4.0702987d-04, 1.6940600d-04/
      data fxyz( 8,19,13),fxyz( 8,19,14)/-6.9654585d-05, 1.8506422d-05/
      data fxyz( 8,19,15),fxyz( 8,19,16)/-4.4609413d-06, 1.9811438d-06/
      data fxyz( 8,19,17),fxyz( 8,19,18)/ 7.7394906d-08, 6.1572761d-07/
      data fxyz( 8,19,19),fxyz( 8,19,20)/ 5.8151494d-07, 7.5752350d-07/
      data fxyz( 8,19,21),fxyz( 8,19,22)/ 7.5200056d-07, 6.0360671d-07/
      data fxyz( 8,19,23)/                5.3288347d-07/
      data fxyz( 9, 1, 1),fxyz( 9, 1, 2)/-6.1374215d-03,-3.6175629d-03/
      data fxyz( 9, 1, 3),fxyz( 9, 1, 4)/ 1.4037758d-03, 2.0659026d-03/
      data fxyz( 9, 1, 5),fxyz( 9, 1, 6)/-6.2660699d-03, 3.7944795d-03/
      data fxyz( 9, 1, 7),fxyz( 9, 1, 8)/-3.1530410d-03, 3.8204955d-03/
      data fxyz( 9, 1, 9),fxyz( 9, 1,10)/-1.3598606d-03, 2.0517100d-04/
      data fxyz( 9, 1,11),fxyz( 9, 1,12)/ 1.1710906d-03,-1.7673105d-03/
      data fxyz( 9, 1,13),fxyz( 9, 1,14)/ 2.3468072d-04, 7.3882523d-04/
      data fxyz( 9, 1,15),fxyz( 9, 1,16)/-1.0345211d-03, 3.2254755d-03/
      data fxyz( 9, 1,17),fxyz( 9, 1,18)/-2.4117986d-03, 2.4434605d-03/
      data fxyz( 9, 1,19),fxyz( 9, 1,20)/-5.2063238d-03, 1.9071121d-03/
      data fxyz( 9, 1,21),fxyz( 9, 1,22)/ 1.3864133d-03,-3.1235287d-03/
      data fxyz( 9, 1,23)/               -5.3670213d-03/
      data fxyz( 9, 2, 1),fxyz( 9, 2, 2)/-2.8830520d-03,-1.6972670d-03/
      data fxyz( 9, 2, 3),fxyz( 9, 2, 4)/ 6.7234472d-04, 9.7221799d-04/
      data fxyz( 9, 2, 5),fxyz( 9, 2, 6)/-2.8967601d-03, 1.6150471d-03/
      data fxyz( 9, 2, 7),fxyz( 9, 2, 8)/-1.3885032d-03, 1.8210501d-03/
      data fxyz( 9, 2, 9),fxyz( 9, 2,10)/-6.2139878d-04, 4.3986421d-05/
      data fxyz( 9, 2,11),fxyz( 9, 2,12)/ 6.0570607d-04,-8.4560399d-04/
      data fxyz( 9, 2,13),fxyz( 9, 2,14)/ 7.5405017d-05, 3.7457474d-04/
      data fxyz( 9, 2,15),fxyz( 9, 2,16)/-4.9413163d-04, 1.5393681d-03/
      data fxyz( 9, 2,17),fxyz( 9, 2,18)/-1.0161908d-03, 9.2485218d-04/
      data fxyz( 9, 2,19),fxyz( 9, 2,20)/-2.3507252d-03, 8.8712777d-04/
      data fxyz( 9, 2,21),fxyz( 9, 2,22)/ 6.5991691d-04,-1.4418818d-03/
      data fxyz( 9, 2,23)/               -2.4833107d-03/
      data fxyz( 9, 3, 1),fxyz( 9, 3, 2)/ 3.9890552d-03, 2.3943034d-03/
      data fxyz( 9, 3, 3),fxyz( 9, 3, 4)/-6.9034010d-04,-1.2725334d-03/
      data fxyz( 9, 3, 5),fxyz( 9, 3, 6)/ 4.7230764d-03,-4.7438438d-03/
      data fxyz( 9, 3, 7),fxyz( 9, 3, 8)/ 3.3995789d-03,-2.1306312d-03/
      data fxyz( 9, 3, 9),fxyz( 9, 3,10)/ 1.0026405d-04, 1.0202205d-03/
      data fxyz( 9, 3,11),fxyz( 9, 3,12)/-1.5261777d-03, 1.7571017d-03/
      data fxyz( 9, 3,13),fxyz( 9, 3,14)/-1.3604032d-03, 6.8489120d-04/
      data fxyz( 9, 3,15),fxyz( 9, 3,16)/ 8.3798255d-05,-1.6641799d-03/
      data fxyz( 9, 3,17),fxyz( 9, 3,18)/ 2.6206958d-03,-3.6799166d-03/
      data fxyz( 9, 3,19),fxyz( 9, 3,20)/ 3.9799455d-03,-1.1391225d-03/
      data fxyz( 9, 3,21),fxyz( 9, 3,22)/-6.6212439d-04, 2.0719530d-03/
      data fxyz( 9, 3,23)/                3.4750553d-03/
      data fxyz( 9, 4, 1),fxyz( 9, 4, 2)/-1.8009198d-03,-1.1135869d-03/
      data fxyz( 9, 4, 3),fxyz( 9, 4, 4)/ 1.5636306d-04, 5.1144902d-04/
      data fxyz( 9, 4, 5),fxyz( 9, 4, 6)/-2.5339307d-03, 3.5253696d-03/
      data fxyz( 9, 4, 7),fxyz( 9, 4, 8)/-2.3947440d-03, 7.5051341d-04/
      data fxyz( 9, 4, 9),fxyz( 9, 4,10)/ 8.8072336d-04,-1.9845107d-03/
      data fxyz( 9, 4,11),fxyz( 9, 4,12)/ 1.8246858d-03,-1.5236899d-03/
      data fxyz( 9, 4,13),fxyz( 9, 4,14)/ 1.6716523d-03,-1.3657767d-03/
      data fxyz( 9, 4,15),fxyz( 9, 4,16)/ 5.3033659d-04, 4.4331404d-04/
      data fxyz( 9, 4,17),fxyz( 9, 4,18)/-1.5868933d-03, 2.5168763d-03/
      data fxyz( 9, 4,19),fxyz( 9, 4,20)/-1.8521360d-03, 3.5655807d-04/
      data fxyz( 9, 4,21),fxyz( 9, 4,22)/ 1.0024148d-04,-8.2686962d-04/
      data fxyz( 9, 4,23)/               -1.3278726d-03/
      data fxyz( 9, 5, 1),fxyz( 9, 5, 2)/ 7.8050649d-04, 4.7601686d-04/
      data fxyz( 9, 5, 3),fxyz( 9, 5, 4)/-9.0886028d-05,-2.4064211d-04/
      data fxyz( 9, 5, 5),fxyz( 9, 5, 6)/ 1.0750412d-03,-1.4658347d-03/
      data fxyz( 9, 5, 7),fxyz( 9, 5, 8)/ 9.8314765d-04,-2.0758538d-04/
      data fxyz( 9, 5, 9),fxyz( 9, 5,10)/-6.5222781d-04, 1.2793870d-03/
      data fxyz( 9, 5,11),fxyz( 9, 5,12)/-1.0775799d-03, 7.3579441d-04/
      data fxyz( 9, 5,13),fxyz( 9, 5,14)/-8.0777416d-04, 7.5201487d-04/
      data fxyz( 9, 5,15),fxyz( 9, 5,16)/-3.8484149d-04, 3.7321293d-06/
      data fxyz( 9, 5,17),fxyz( 9, 5,18)/ 2.9646990d-04,-5.0154790d-04/
      data fxyz( 9, 5,19),fxyz( 9, 5,20)/ 2.8241341d-04,-9.4159628d-06/
      data fxyz( 9, 5,21),fxyz( 9, 5,22)/ 3.4261965d-05, 1.0770170d-04/
      data fxyz( 9, 5,23)/                1.5362102d-04/
      data fxyz( 9, 6, 1),fxyz( 9, 6, 2)/-5.6820952d-04,-3.2801540d-04/
      data fxyz( 9, 6, 3),fxyz( 9, 6, 4)/ 1.3968431d-04, 2.2193772d-04/
      data fxyz( 9, 6, 5),fxyz( 9, 6, 6)/-6.5702905d-04, 6.6559164d-04/
      data fxyz( 9, 6, 7),fxyz( 9, 6, 8)/-4.2557504d-04, 1.0065131d-04/
      data fxyz( 9, 6, 9),fxyz( 9, 6,10)/ 1.6307315d-04,-3.3952108d-04/
      data fxyz( 9, 6,11),fxyz( 9, 6,12)/ 2.8838846d-04,-1.9775820d-04/
      data fxyz( 9, 6,13),fxyz( 9, 6,14)/ 2.1830598d-04,-2.0664245d-04/
      data fxyz( 9, 6,15),fxyz( 9, 6,16)/ 1.1960150d-04,-2.5417500d-05/
      data fxyz( 9, 6,17),fxyz( 9, 6,18)/-6.4036666d-05, 1.2769116d-04/
      data fxyz( 9, 6,19),fxyz( 9, 6,20)/-7.4281289d-05, 3.4928945d-06/
      data fxyz( 9, 6,21),fxyz( 9, 6,22)/-7.8172514d-06,-2.9040706d-05/
      data fxyz( 9, 6,23)/               -4.1961024d-05/
      data fxyz( 9, 7, 1),fxyz( 9, 7, 2)/-6.8936521d-05,-3.5358169d-05/
      data fxyz( 9, 7, 3),fxyz( 9, 7, 4)/ 3.5989412d-05, 3.7049968d-05/
      data fxyz( 9, 7, 5),fxyz( 9, 7, 6)/-3.9600390d-05,-5.3028191d-05/
      data fxyz( 9, 7, 7),fxyz( 9, 7, 8)/ 5.8510099d-05,-1.5698801d-05/
      data fxyz( 9, 7, 9),fxyz( 9, 7,10)/-4.6835287d-05, 9.1929922d-05/
      data fxyz( 9, 7,11),fxyz( 9, 7,12)/-7.7975462d-05, 5.3516927d-05/
      data fxyz( 9, 7,13),fxyz( 9, 7,14)/-5.8932201d-05, 5.5909997d-05/
      data fxyz( 9, 7,15),fxyz( 9, 7,16)/-3.2988957d-05, 7.4595015d-06/
      data fxyz( 9, 7,17),fxyz( 9, 7,18)/ 1.5774324d-05,-3.3893734d-05/
      data fxyz( 9, 7,19),fxyz( 9, 7,20)/ 1.1212599d-05, 5.7762482d-06/
      data fxyz( 9, 7,21),fxyz( 9, 7,22)/ 8.0377971d-06, 2.1664037d-06/
      data fxyz( 9, 7,23)/                2.9499756d-08/
      data fxyz( 9, 8, 1),fxyz( 9, 8, 2)/ 6.1129864d-04, 3.4239339d-04/
      data fxyz( 9, 8, 3),fxyz( 9, 8, 4)/-1.9612860d-04,-2.6210982d-04/
      data fxyz( 9, 8, 5),fxyz( 9, 8, 6)/ 6.0631829d-04,-3.7841973d-04/
      data fxyz( 9, 8, 7),fxyz( 9, 8, 8)/ 1.6673850d-04,-3.2615445d-05/
      data fxyz( 9, 8, 9),fxyz( 9, 8,10)/ 2.2362638d-05,-2.7623029d-05/
      data fxyz( 9, 8,11),fxyz( 9, 8,12)/ 2.2208852d-05,-1.5155961d-05/
      data fxyz( 9, 8,13),fxyz( 9, 8,14)/ 1.6128745d-05,-1.5136458d-05/
      data fxyz( 9, 8,15),fxyz( 9, 8,16)/ 8.8781454d-06,-2.1192873d-06/
      data fxyz( 9, 8,17),fxyz( 9, 8,18)/-4.3144227d-06, 8.9927986d-06/
      data fxyz( 9, 8,19),fxyz( 9, 8,20)/-2.2154711d-06,-1.7844295d-06/
      data fxyz( 9, 8,21),fxyz( 9, 8,22)/-2.3260160d-06,-4.9125090d-08/
      data fxyz( 9, 8,23)/                8.6900095d-07/
      data fxyz( 9, 9, 1),fxyz( 9, 9, 2)/-5.5970682d-04,-3.2468568d-04/
      data fxyz( 9, 9, 3),fxyz( 9, 9, 4)/ 1.3566034d-04, 2.1138405d-04/
      data fxyz( 9, 9, 5),fxyz( 9, 9, 6)/-6.2758055d-04, 5.7614893d-04/
      data fxyz( 9, 9, 7),fxyz( 9, 9, 8)/-2.6104100d-04, 2.6112658d-05/
      data fxyz( 9, 9, 9),fxyz( 9, 9,10)/-1.0235510d-05, 8.7688554d-06/
      data fxyz( 9, 9,11),fxyz( 9, 9,12)/-6.5621264d-06, 4.9882636d-06/
      data fxyz( 9, 9,13),fxyz( 9, 9,14)/-5.3159286d-06, 4.8132586d-06/
      data fxyz( 9, 9,15),fxyz( 9, 9,16)/-2.8455443d-06, 7.5535891d-07/
      data fxyz( 9, 9,17),fxyz( 9, 9,18)/ 1.0452295d-06,-2.3010678d-06/
      data fxyz( 9, 9,19),fxyz( 9, 9,20)/ 9.8405162d-07, 2.4858119d-07/
      data fxyz( 9, 9,21),fxyz( 9, 9,22)/ 4.2081247d-07, 2.9512650d-07/
      data fxyz( 9, 9,23)/                2.8240138d-07/
      data fxyz( 9,10, 1),fxyz( 9,10, 2)/ 2.4922352d-04, 1.5009683d-04/
      data fxyz( 9,10, 3),fxyz( 9,10, 4)/-3.8541685d-05,-8.0149379d-05/
      data fxyz( 9,10, 5),fxyz( 9,10, 6)/ 3.1652761d-04,-3.7489188d-04/
      data fxyz( 9,10, 7),fxyz( 9,10, 8)/ 1.5739283d-04, 2.2522609d-05/
      data fxyz( 9,10, 9),fxyz( 9,10,10)/-1.5919803d-05, 8.4405937d-07/
      data fxyz( 9,10,11),fxyz( 9,10,12)/ 5.1481107d-07,-1.7418585d-06/
      data fxyz( 9,10,13),fxyz( 9,10,14)/ 2.2700730d-06,-2.0001614d-06/
      data fxyz( 9,10,15),fxyz( 9,10,16)/ 1.1871305d-06,-4.1490966d-07/
      data fxyz( 9,10,17),fxyz( 9,10,18)/-1.4163023d-07, 6.5718712d-07/
      data fxyz( 9,10,19),fxyz( 9,10,20)/-6.2255059d-07, 1.3142398d-07/
      data fxyz( 9,10,21),fxyz( 9,10,22)/ 5.3974967d-08,-3.1275454d-07/
      data fxyz( 9,10,23)/               -5.0454805d-07/
      data fxyz( 9,11, 1),fxyz( 9,11, 2)/-6.6346912d-05,-4.0950261d-05/
      data fxyz( 9,11, 3),fxyz( 9,11, 4)/ 6.1688085d-06, 1.8947879d-05/
      data fxyz( 9,11, 5),fxyz( 9,11, 6)/-9.2066542d-05, 1.2533914d-04/
      data fxyz( 9,11, 7),fxyz( 9,11, 8)/-6.0044169d-05,-1.1070895d-05/
      data fxyz( 9,11, 9),fxyz( 9,11,10)/ 1.9973186d-05,-6.6787667d-06/
      data fxyz( 9,11,11),fxyz( 9,11,12)/ 6.3641744d-07, 2.7637413d-07/
      data fxyz( 9,11,13),fxyz( 9,11,14)/-7.9419827d-07, 5.9515956d-07/
      data fxyz( 9,11,15),fxyz( 9,11,16)/-3.3992366d-07, 1.2114533d-07/
      data fxyz( 9,11,17),fxyz( 9,11,18)/ 8.8896675d-08,-5.3259470d-07/
      data fxyz( 9,11,19),fxyz( 9,11,20)/ 1.6931711d-06,-9.4213661d-07/
      data fxyz( 9,11,21),fxyz( 9,11,22)/-7.7810609d-07, 1.0370491d-06/
      data fxyz( 9,11,23)/                1.9278630d-06/
      data fxyz( 9,12, 1),fxyz( 9,12, 2)/ 2.5253471d-05, 1.4194839d-05/
      data fxyz( 9,12, 3),fxyz( 9,12, 4)/-7.3028788d-06,-1.1151741d-05/
      data fxyz( 9,12, 5),fxyz( 9,12, 6)/ 2.9590286d-05,-3.2479456d-05/
      data fxyz( 9,12, 7),fxyz( 9,12, 8)/ 2.6627278d-05,-1.3161141d-05/
      data fxyz( 9,12, 9),fxyz( 9,12,10)/ 3.9077205d-06, 1.9100708d-06/
      data fxyz( 9,12,11),fxyz( 9,12,12)/-7.0109975d-07,-2.9064457d-07/
      data fxyz( 9,12,13),fxyz( 9,12,14)/ 2.1833827d-07,-1.8986610d-07/
      data fxyz( 9,12,15),fxyz( 9,12,16)/ 8.5100768d-08, 3.2204482d-08/
      data fxyz( 9,12,17),fxyz( 9,12,18)/-7.0909399d-08, 2.4542673d-07/
      data fxyz( 9,12,19),fxyz( 9,12,20)/-2.0392650d-06, 1.2138558d-06/
      data fxyz( 9,12,21),fxyz( 9,12,22)/ 1.0333425d-06,-1.3172116d-06/
      data fxyz( 9,12,23)/               -2.4622737d-06/
      data fxyz( 9,13, 1),fxyz( 9,13, 2)/-2.3194116d-05,-1.1667014d-05/
      data fxyz( 9,13, 3),fxyz( 9,13, 4)/ 1.1954809d-05, 1.3843251d-05/
      data fxyz( 9,13, 5),fxyz( 9,13, 6)/-1.9220783d-05, 5.1325197d-06/
      data fxyz( 9,13, 7),fxyz( 9,13, 8)/-7.3508367d-06, 3.5460756d-06/
      data fxyz( 9,13, 9),fxyz( 9,13,10)/-6.4799127d-06, 6.0515598d-06/
      data fxyz( 9,13,11),fxyz( 9,13,12)/-2.2224534d-06, 7.4948791d-07/
      data fxyz( 9,13,13),fxyz( 9,13,14)/-2.8961057d-07,-1.3129765d-07/
      data fxyz( 9,13,15),fxyz( 9,13,16)/ 7.2867503d-08,-4.7111379d-09/
      data fxyz( 9,13,17),fxyz( 9,13,18)/-1.1013300d-07, 4.3756895d-08/
      data fxyz( 9,13,19),fxyz( 9,13,20)/-7.3185805d-07, 5.5446915d-07/
      data fxyz( 9,13,21),fxyz( 9,13,22)/ 4.8915739d-07,-4.7061103d-07/
      data fxyz( 9,13,23)/               -9.3591943d-07/
      data fxyz( 9,14, 1),fxyz( 9,14, 2)/-8.9632175d-06,-3.3422120d-06/
      data fxyz( 9,14, 3),fxyz( 9,14, 4)/ 8.8030987d-06, 8.6275755d-06/
      data fxyz( 9,14, 5),fxyz( 9,14, 6)/-2.6401193d-06,-1.1596065d-05/
      data fxyz( 9,14, 7),fxyz( 9,14, 8)/ 9.4796019d-06,-1.4493603d-05/
      data fxyz( 9,14, 9),fxyz( 9,14,10)/ 9.1984462d-06,-4.8572958d-06/
      data fxyz( 9,14,11),fxyz( 9,14,12)/ 2.8912941d-06,-1.4028036d-06/
      data fxyz( 9,14,13),fxyz( 9,14,14)/ 3.5516853d-07, 2.0076339d-07/
      data fxyz( 9,14,15),fxyz( 9,14,16)/-1.7014647d-07,-4.5608421d-08/
      data fxyz( 9,14,17),fxyz( 9,14,18)/ 9.7590581d-08,-2.3094275d-07/
      data fxyz( 9,14,19),fxyz( 9,14,20)/ 1.4512158d-06,-8.5400310d-07/
      data fxyz( 9,14,21),fxyz( 9,14,22)/-7.2308882d-07, 9.2755870d-07/
      data fxyz( 9,14,23)/                1.7327714d-06/
      data fxyz( 9,15, 1),fxyz( 9,15, 2)/ 1.0840954d-05, 5.4722232d-06/
      data fxyz( 9,15, 3),fxyz( 9,15, 4)/-6.3488914d-06,-5.7946807d-06/
      data fxyz( 9,15, 5),fxyz( 9,15, 6)/ 3.2553805d-06, 1.9154114d-05/
      data fxyz( 9,15, 7),fxyz( 9,15, 8)/-3.9735891d-05, 5.9382294d-05/
      data fxyz( 9,15, 9),fxyz( 9,15,10)/-6.0634332d-05, 4.1482284d-05/
      data fxyz( 9,15,11),fxyz( 9,15,12)/-1.7738559d-05, 5.0688384d-06/
      data fxyz( 9,15,13),fxyz( 9,15,14)/-1.6661126d-06, 2.4842292d-07/
      data fxyz( 9,15,15),fxyz( 9,15,16)/ 1.1084178d-08, 1.7960605d-08/
      data fxyz( 9,15,17),fxyz( 9,15,18)/ 2.3251450d-08, 1.8429501d-07/
      data fxyz( 9,15,19),fxyz( 9,15,20)/-1.9090485d-07, 1.4725984d-08/
      data fxyz( 9,15,21),fxyz( 9,15,22)/-7.6392490d-09,-1.0144391d-07/
      data fxyz( 9,15,23)/               -1.5118349d-07/
      data fxyz( 9,16, 1),fxyz( 9,16, 2)/-2.0616529d-06,-2.3979417d-06/
      data fxyz( 9,16, 3),fxyz( 9,16, 4)/-1.1537729d-06,-4.5921513d-06/
      data fxyz( 9,16, 5),fxyz( 9,16, 6)/ 1.1355572d-05,-5.3637329d-05/
      data fxyz( 9,16, 7),fxyz( 9,16, 8)/ 1.4363238d-04,-1.9863306d-04/
      data fxyz( 9,16, 9),fxyz( 9,16,10)/ 1.4906489d-04,-4.6447000d-05/
      data fxyz( 9,16,11),fxyz( 9,16,12)/-9.6762308d-07, 4.3181197d-07/
      data fxyz( 9,16,13),fxyz( 9,16,14)/ 1.2247850d-06,-1.5182408d-07/
      data fxyz( 9,16,15),fxyz( 9,16,16)/-1.0535081d-08, 3.8888251d-10/
      data fxyz( 9,16,17),fxyz( 9,16,18)/-5.9821674d-08, 4.8063298d-08/
      data fxyz( 9,16,19),fxyz( 9,16,20)/ 2.5655293d-08,-8.9825659d-08/
      data fxyz( 9,16,21),fxyz( 9,16,22)/-8.8331207d-08, 1.9677488d-08/
      data fxyz( 9,16,23)/                7.0480066d-08/
      data fxyz( 9,17, 1),fxyz( 9,17, 2)/ 2.3072196d-05, 1.4705462d-05/
      data fxyz( 9,17, 3),fxyz( 9,17, 4)/-1.0318248d-05, 2.0979890d-06/
      data fxyz( 9,17, 5),fxyz( 9,17, 6)/-3.4959488d-05, 2.0931576d-04/
      data fxyz( 9,17, 7),fxyz( 9,17, 8)/-5.2302357d-04, 6.2140728d-04/
      data fxyz( 9,17, 9),fxyz( 9,17,10)/-2.7773015d-04,-5.2298210d-05/
      data fxyz( 9,17,11),fxyz( 9,17,12)/ 6.7307077d-05,-9.3032752d-06/
      data fxyz( 9,17,13),fxyz( 9,17,14)/-3.6107077d-07, 1.4766277d-07/
      data fxyz( 9,17,15),fxyz( 9,17,16)/ 6.6304579d-08, 8.7510891d-08/
      data fxyz( 9,17,17),fxyz( 9,17,18)/ 9.3104174d-08, 1.2813498d-08/
      data fxyz( 9,17,19),fxyz( 9,17,20)/ 1.0122163d-07, 8.4848493d-08/
      data fxyz( 9,17,21),fxyz( 9,17,22)/ 8.9407778d-08, 8.2984490d-08/
      data fxyz( 9,17,23)/                8.1202765d-08/
      data fxyz( 9,18, 1),fxyz( 9,18, 2)/-2.3367977d-05,-1.5188023d-05/
      data fxyz( 9,18, 3),fxyz( 9,18, 4)/ 9.9113450d-06,-3.3377200d-06/
      data fxyz( 9,18, 5),fxyz( 9,18, 6)/ 3.7808237d-05,-2.2210395d-04/
      data fxyz( 9,18, 7),fxyz( 9,18, 8)/ 5.5228741d-04,-6.0973357d-04/
      data fxyz( 9,18, 9),fxyz( 9,18,10)/ 2.1766682d-04, 6.3212768d-05/
      data fxyz( 9,18,11),fxyz( 9,18,12)/-4.0776707d-05, 7.7576726d-07/
      data fxyz( 9,18,13),fxyz( 9,18,14)/ 2.5069580d-06,-7.0999237d-07/
      data fxyz( 9,18,15),fxyz( 9,18,16)/ 1.2456527d-07,-1.1249432d-07/
      data fxyz( 9,18,17),fxyz( 9,18,18)/-5.6351546d-08,-5.3593314d-08/
      data fxyz( 9,18,19),fxyz( 9,18,20)/-9.2793543d-08,-1.0152551d-07/
      data fxyz( 9,18,21),fxyz( 9,18,22)/-1.0319285d-07,-8.6124180d-08/
      data fxyz( 9,18,23)/               -7.8603425d-08/
      data fxyz( 9,19, 1),fxyz( 9,19, 2)/-4.9358430d-05,-3.1653825d-05/
      data fxyz( 9,19, 3),fxyz( 9,19, 4)/ 2.1742633d-05,-5.3089006d-06/
      data fxyz( 9,19, 5),fxyz( 9,19, 6)/ 7.6552309d-05,-4.5513143d-04/
      data fxyz( 9,19, 7),fxyz( 9,19, 8)/ 1.1298935d-03,-1.2548227d-03/
      data fxyz( 9,19, 9),fxyz( 9,19,10)/ 4.4958036d-04, 1.4404883d-04/
      data fxyz( 9,19,11),fxyz( 9,19,12)/-9.8472353d-05, 5.1936298d-06/
      data fxyz( 9,19,13),fxyz( 9,19,14)/ 4.1024483d-06,-1.2370355d-06/
      data fxyz( 9,19,15),fxyz( 9,19,16)/ 1.8813423d-07,-2.3046318d-07/
      data fxyz( 9,19,17),fxyz( 9,19,18)/-1.1941253d-07,-1.1109812d-07/
      data fxyz( 9,19,19),fxyz( 9,19,20)/-2.0978543d-07,-1.8474289d-07/
      data fxyz( 9,19,21),fxyz( 9,19,22)/-1.8998216d-07,-1.8882837d-07/
      data fxyz( 9,19,23)/               -1.8968708d-07/
      data fxyz(10, 1, 1),fxyz(10, 1, 2)/ 2.9290176d-03, 1.5965750d-03/
      data fxyz(10, 1, 3),fxyz(10, 1, 4)/-1.1311967d-03,-1.3542559d-03/
      data fxyz(10, 1, 5),fxyz(10, 1, 6)/ 2.4888116d-03,-4.1686980d-04/
      data fxyz(10, 1, 7),fxyz(10, 1, 8)/ 6.5127609d-04,-1.0478901d-03/
      data fxyz(10, 1, 9),fxyz(10, 1,10)/ 3.7621705d-04,-9.3072008d-06/
      data fxyz(10, 1,11),fxyz(10, 1,12)/-7.3970513d-04, 9.1893782d-04/
      data fxyz(10, 1,13),fxyz(10, 1,14)/ 1.2537239d-04,-4.5968089d-04/
      data fxyz(10, 1,15),fxyz(10, 1,16)/ 1.3036614d-04,-6.0443863d-04/
      data fxyz(10, 1,17),fxyz(10, 1,18)/-8.6211244d-06, 7.2260382d-04/
      data fxyz(10, 1,19),fxyz(10, 1,20)/ 1.6368896d-03,-1.2283696d-03/
      data fxyz(10, 1,21),fxyz(10, 1,22)/-1.1214991d-03, 1.2094073d-03/
      data fxyz(10, 1,23)/                2.3256625d-03/
      data fxyz(10, 2, 1),fxyz(10, 2, 2)/ 1.4425309d-03, 7.8423699d-04/
      data fxyz(10, 2, 3),fxyz(10, 2, 4)/-5.6411927d-04,-6.7309785d-04/
      data fxyz(10, 2, 5),fxyz(10, 2, 6)/ 1.2201513d-03,-1.9214782d-04/
      data fxyz(10, 2, 7),fxyz(10, 2, 8)/ 3.2641090d-04,-5.2127432d-04/
      data fxyz(10, 2, 9),fxyz(10, 2,10)/ 1.8652739d-04, 2.4756722d-06/
      data fxyz(10, 2,11),fxyz(10, 2,12)/-3.7546974d-04, 4.5341503d-04/
      data fxyz(10, 2,13),fxyz(10, 2,14)/ 7.6392305d-05,-2.5626326d-04/
      data fxyz(10, 2,15),fxyz(10, 2,16)/ 9.3467290d-05,-3.0461963d-04/
      data fxyz(10, 2,17),fxyz(10, 2,18)/-1.1720533d-05, 3.7282422d-04/
      data fxyz(10, 2,19),fxyz(10, 2,20)/ 7.9427649d-04,-6.0541904d-04/
      data fxyz(10, 2,21),fxyz(10, 2,22)/-5.5440748d-04, 5.9023025d-04/
      data fxyz(10, 2,23)/                1.1379976d-03/
      data fxyz(10, 3, 1),fxyz(10, 3, 2)/-1.8041812d-03,-1.0136327d-03/
      data fxyz(10, 3, 3),fxyz(10, 3, 4)/ 5.6152025d-04, 7.6955943d-04/
      data fxyz(10, 3, 5),fxyz(10, 3, 6)/-1.8457894d-03, 1.3164066d-03/
      data fxyz(10, 3, 7),fxyz(10, 3, 8)/-1.2786129d-03, 9.3385752d-04/
      data fxyz(10, 3, 9),fxyz(10, 3,10)/-2.7385915d-04,-9.3683182d-05/
      data fxyz(10, 3,11),fxyz(10, 3,12)/ 6.5594840d-04,-8.4963144d-04/
      data fxyz(10, 3,13),fxyz(10, 3,14)/ 2.2276158d-04, 2.1972699d-04/
      data fxyz(10, 3,15),fxyz(10, 3,16)/-6.9890428d-05, 2.5985138d-04/
      data fxyz(10, 3,17),fxyz(10, 3,18)/-2.0761954d-04, 1.3988261d-04/
      data fxyz(10, 3,19),fxyz(10, 3,20)/-1.1433246d-03, 6.4164459d-04/
      data fxyz(10, 3,21),fxyz(10, 3,22)/ 5.4119239d-04,-7.4151585d-04/
      data fxyz(10, 3,23)/               -1.3669003d-03/
      data fxyz(10, 4, 1),fxyz(10, 4, 2)/ 1.1098954d-03, 6.3785847d-04/
      data fxyz(10, 4, 3),fxyz(10, 4, 4)/-2.6780738d-04,-4.5303058d-04/
      data fxyz(10, 4, 5),fxyz(10, 4, 6)/ 1.3787513d-03,-1.6684526d-03/
      data fxyz(10, 4, 7),fxyz(10, 4, 8)/ 1.5969184d-03,-8.6081692d-04/
      data fxyz(10, 4, 9),fxyz(10, 4,10)/ 2.1319336d-04, 1.8795401d-04/
      data fxyz(10, 4,11),fxyz(10, 4,12)/-6.4777311d-04, 7.7865497d-04/
      data fxyz(10, 4,13),fxyz(10, 4,14)/-3.1459192d-04,-2.5828691d-04/
      data fxyz(10, 4,15),fxyz(10, 4,16)/ 2.0935788d-04,-1.0195961d-04/
      data fxyz(10, 4,17),fxyz(10, 4,18)/ 2.7128005d-04,-5.0199198d-04/
      data fxyz(10, 4,19),fxyz(10, 4,20)/ 7.5153211d-04,-2.9568741d-04/
      data fxyz(10, 4,21),fxyz(10, 4,22)/-2.1298679d-04, 4.2072960d-04/
      data fxyz(10, 4,23)/                7.3851742d-04/
      data fxyz(10, 5, 1),fxyz(10, 5, 2)/-9.4086603d-04,-5.2663989d-04/
      data fxyz(10, 5, 3),fxyz(10, 5, 4)/ 2.8510349d-04, 4.1790061d-04/
      data fxyz(10, 5, 5),fxyz(10, 5, 6)/-1.0578284d-03, 1.0510909d-03/
      data fxyz(10, 5, 7),fxyz(10, 5, 8)/-9.7044524d-04, 4.9239783d-04/
      data fxyz(10, 5, 9),fxyz(10, 5,10)/-1.1978392d-04,-1.2475383d-04/
      data fxyz(10, 5,11),fxyz(10, 5,12)/ 3.7802644d-04,-4.1605353d-04/
      data fxyz(10, 5,13),fxyz(10, 5,14)/ 1.3483088d-04, 2.2213527d-04/
      data fxyz(10, 5,15),fxyz(10, 5,16)/-1.9668459d-04, 5.5992965d-05/
      data fxyz(10, 5,17),fxyz(10, 5,18)/-1.2304354d-04, 2.4507678d-04/
      data fxyz(10, 5,19),fxyz(10, 5,20)/-3.3508664d-04, 1.2943549d-04/
      data fxyz(10, 5,21),fxyz(10, 5,22)/ 9.1606044d-05,-1.8376884d-04/
      data fxyz(10, 5,23)/               -3.2236497d-04/
      data fxyz(10, 6, 1),fxyz(10, 6, 2)/ 8.8137455d-04, 4.8313672d-04/
      data fxyz(10, 6, 3),fxyz(10, 6, 4)/-3.1832587d-04,-4.0915823d-04/
      data fxyz(10, 6, 5),fxyz(10, 6, 6)/ 8.4646619d-04,-4.8111096d-04/
      data fxyz(10, 6, 7),fxyz(10, 6, 8)/ 3.3891687d-04,-1.5192576d-04/
      data fxyz(10, 6, 9),fxyz(10, 6,10)/ 3.8030608d-05, 3.2066497d-05/
      data fxyz(10, 6,11),fxyz(10, 6,12)/-1.0098827d-04, 1.1162308d-04/
      data fxyz(10, 6,13),fxyz(10, 6,14)/-3.6729383d-05,-5.7694491d-05/
      data fxyz(10, 6,15),fxyz(10, 6,16)/ 4.8026774d-05,-7.7178449d-06/
      data fxyz(10, 6,17),fxyz(10, 6,18)/ 2.8461362d-05,-6.3718908d-05/
      data fxyz(10, 6,19),fxyz(10, 6,20)/ 8.4111674d-05,-3.1701187d-05/
      data fxyz(10, 6,21),fxyz(10, 6,22)/-2.2118438d-05, 4.5780677d-05/
      data fxyz(10, 6,23)/                8.0022331d-05/
      data fxyz(10, 7, 1),fxyz(10, 7, 2)/-4.4213781d-04,-2.4067923d-04/
      data fxyz(10, 7, 3),fxyz(10, 7, 4)/ 1.6773090d-04, 2.0848283d-04/
      data fxyz(10, 7, 5),fxyz(10, 7, 6)/-4.0368697d-04, 1.6914121d-04/
      data fxyz(10, 7, 7),fxyz(10, 7, 8)/-9.6810288d-05, 4.0842204d-05/
      data fxyz(10, 7, 9),fxyz(10, 7,10)/-1.0543935d-05,-8.6398194d-06/
      data fxyz(10, 7,11),fxyz(10, 7,12)/ 2.7206826d-05,-3.0074932d-05/
      data fxyz(10, 7,13),fxyz(10, 7,14)/ 1.0096368d-05, 1.4695102d-05/
      data fxyz(10, 7,15),fxyz(10, 7,16)/-1.1984365d-05, 1.1534644d-06/
      data fxyz(10, 7,17),fxyz(10, 7,18)/-7.7248058d-06, 1.5576890d-05/
      data fxyz(10, 7,19),fxyz(10, 7,20)/-2.6247362d-05, 1.2538877d-05/
      data fxyz(10, 7,21),fxyz(10, 7,22)/ 9.6943597d-06,-1.4869293d-05/
      data fxyz(10, 7,23)/               -2.7090869d-05/
      data fxyz(10, 8, 1),fxyz(10, 8, 2)/ 3.9721767d-05, 2.4138756d-05/
      data fxyz(10, 8, 3),fxyz(10, 8, 4)/-6.7754884d-06,-1.1111855d-05/
      data fxyz(10, 8, 5),fxyz(10, 8, 6)/ 4.1484221d-05,-2.5323728d-05/
      data fxyz(10, 8, 7),fxyz(10, 8, 8)/-1.0644682d-06, 2.2874211d-07/
      data fxyz(10, 8, 9),fxyz(10, 8,10)/-2.1968769d-07, 3.1481644d-06/
      data fxyz(10, 8,11),fxyz(10, 8,12)/-7.8293493d-06, 8.5180151d-06/
      data fxyz(10, 8,13),fxyz(10, 8,14)/-3.1722157d-06,-3.4037994d-06/
      data fxyz(10, 8,15),fxyz(10, 8,16)/ 2.6209204d-06,-1.0213424d-07/
      data fxyz(10, 8,17),fxyz(10, 8,18)/ 1.9280553d-06,-4.1286352d-06/
      data fxyz(10, 8,19),fxyz(10, 8,20)/ 7.6510942d-06,-3.5881642d-06/
      data fxyz(10, 8,21),fxyz(10, 8,22)/-2.7800289d-06, 4.4185530d-06/
      data fxyz(10, 8,23)/                7.9933940d-06/
      data fxyz(10, 9, 1),fxyz(10, 9, 2)/-2.7703186d-05,-1.9620835d-05/
      data fxyz(10, 9, 3),fxyz(10, 9, 4)/-5.1405095d-06,-1.7226646d-07/
      data fxyz(10, 9, 5),fxyz(10, 9, 6)/-3.9493807d-05, 4.6820459d-05/
      data fxyz(10, 9, 7),fxyz(10, 9, 8)/ 9.5486148d-06,-1.9051575d-05/
      data fxyz(10, 9, 9),fxyz(10, 9,10)/ 5.1424296d-06,-2.1662843d-06/
      data fxyz(10, 9,11),fxyz(10, 9,12)/ 2.6884935d-06,-2.9976207d-06/
      data fxyz(10, 9,13),fxyz(10, 9,14)/ 1.5669412d-06, 2.3963040d-07/
      data fxyz(10, 9,15),fxyz(10, 9,16)/-3.2107237d-07,-1.5957995d-07/
      data fxyz(10, 9,17),fxyz(10, 9,18)/-3.1627909d-07, 9.5313198d-07/
      data fxyz(10, 9,19),fxyz(10, 9,20)/-1.7051560d-06, 8.1789806d-07/
      data fxyz(10, 9,21),fxyz(10, 9,22)/ 6.3582307d-07,-9.7685603d-07/
      data fxyz(10, 9,23)/               -1.7779929d-06/
      data fxyz(10,10, 1),fxyz(10,10, 2)/ 5.1424457d-05, 3.1729343d-05/
      data fxyz(10,10, 3),fxyz(10,10, 4)/-4.7362611d-06,-1.4778131d-05/
      data fxyz(10,10, 5),fxyz(10,10, 6)/ 7.1896824d-05,-9.9203598d-05/
      data fxyz(10,10, 7),fxyz(10,10, 8)/ 4.5280752d-05, 9.4107123d-06/
      data fxyz(10,10, 9),fxyz(10,10,10)/-8.9774195d-06, 1.0255716d-06/
      data fxyz(10,10,11),fxyz(10,10,12)/-1.1005438d-06, 1.1282882d-06/
      data fxyz(10,10,13),fxyz(10,10,14)/-8.6291708d-07, 2.6957466d-07/
      data fxyz(10,10,15),fxyz(10,10,16)/-1.0515354d-07, 1.9402808d-07/
      data fxyz(10,10,17),fxyz(10,10,18)/-1.5974249d-07,-1.1846469d-08/
      data fxyz(10,10,19),fxyz(10,10,20)/ 5.5688556d-07,-3.5817631d-07/
      data fxyz(10,10,21),fxyz(10,10,22)/-3.1090918d-07, 3.6781704d-07/
      data fxyz(10,10,23)/                6.9716050d-07/
      data fxyz(10,11, 1),fxyz(10,11, 2)/-1.5141347d-05,-1.0092498d-05/
      data fxyz(10,11, 3),fxyz(10,11, 4)/-2.4068066d-06, 3.0764162d-06/
      data fxyz(10,11, 5),fxyz(10,11, 6)/-3.2025389d-05, 6.7106995d-05/
      data fxyz(10,11, 7),fxyz(10,11, 8)/-5.7465830d-05, 1.8006166d-05/
      data fxyz(10,11, 9),fxyz(10,11,10)/ 3.8490807d-06,-1.8887824d-06/
      data fxyz(10,11,11),fxyz(10,11,12)/-5.1915876d-08,-4.1583912d-07/
      data fxyz(10,11,13),fxyz(10,11,14)/ 2.3938167d-07,-5.6374201d-08/
      data fxyz(10,11,15),fxyz(10,11,16)/ 1.0975106d-08,-9.7978498d-08/
      data fxyz(10,11,17),fxyz(10,11,18)/ 1.1706211d-07,-1.3429916d-08/
      data fxyz(10,11,19),fxyz(10,11,20)/-5.6341933d-07, 3.1841904d-07/
      data fxyz(10,11,21),fxyz(10,11,22)/ 2.7277755d-07,-3.8085338d-07/
      data fxyz(10,11,23)/               -6.9805222d-07/
      data fxyz(10,12, 1),fxyz(10,12, 2)/ 9.3256371d-06, 5.0263381d-06/
      data fxyz(10,12, 3),fxyz(10,12, 4)/-3.2722702d-06,-4.8720766d-06/
      data fxyz(10,12, 5),fxyz(10,12, 6)/ 1.1425564d-05,-1.4671458d-05/
      data fxyz(10,12, 7),fxyz(10,12, 8)/ 1.8617180d-05,-1.4043464d-05/
      data fxyz(10,12, 9),fxyz(10,12,10)/ 5.4712192d-06, 3.0675256d-07/
      data fxyz(10,12,11),fxyz(10,12,12)/-1.7975788d-07,-1.8354646d-08/
      data fxyz(10,12,13),fxyz(10,12,14)/-9.4195604d-08,-3.6980555d-09/
      data fxyz(10,12,15),fxyz(10,12,16)/-1.0154286d-09, 5.1792317d-08/
      data fxyz(10,12,17),fxyz(10,12,18)/-1.6694516d-08,-1.3765319d-07/
      data fxyz(10,12,19),fxyz(10,12,20)/ 5.0690507d-09, 4.1045830d-08/
      data fxyz(10,12,21),fxyz(10,12,22)/ 4.7023666d-08,-1.8842293d-08/
      data fxyz(10,12,23)/               -4.7985652d-08/
      data fxyz(10,13, 1),fxyz(10,13, 2)/-1.4246961d-05,-7.0166014d-06/
      data fxyz(10,13, 3),fxyz(10,13, 4)/ 7.9521678d-06, 8.8706709d-06/
      data fxyz(10,13, 5),fxyz(10,13, 6)/-1.0690614d-05,-4.6941457d-07/
      data fxyz(10,13, 7),fxyz(10,13, 8)/-9.9333556d-07,-3.6964109d-06/
      data fxyz(10,13, 9),fxyz(10,13,10)/ 4.1228638d-06,-9.4045119d-07/
      data fxyz(10,13,11),fxyz(10,13,12)/-2.4799611d-07,-6.4766359d-08/
      data fxyz(10,13,13),fxyz(10,13,14)/-1.1903226d-08, 2.3446901d-08/
      data fxyz(10,13,15),fxyz(10,13,16)/-4.7501636d-08,-2.1431215d-08/
      data fxyz(10,13,17),fxyz(10,13,18)/ 3.5189203d-08,-1.7419577d-07/
      data fxyz(10,13,19),fxyz(10,13,20)/ 1.3208615d-07, 2.5977313d-08/
      data fxyz(10,13,21),fxyz(10,13,22)/ 4.2866524d-08, 6.4529309d-08/
      data fxyz(10,13,23)/                7.9142398d-08/
      data fxyz(10,14, 1),fxyz(10,14, 2)/-5.3118702d-06,-1.6493529d-06/
      data fxyz(10,14, 3),fxyz(10,14, 4)/ 5.8967044d-06, 6.4255439d-06/
      data fxyz(10,14, 5),fxyz(10,14, 6)/-3.7647110d-06, 2.6207226d-06/
      data fxyz(10,14, 7),fxyz(10,14, 8)/-1.0319597d-05, 8.6339814d-06/
      data fxyz(10,14, 9),fxyz(10,14,10)/-1.7182469d-05, 1.2304218d-05/
      data fxyz(10,14,11),fxyz(10,14,12)/-2.1696483d-06, 5.7858014d-07/
      data fxyz(10,14,13),fxyz(10,14,14)/-1.7139754d-07,-4.7581775d-08/
      data fxyz(10,14,15),fxyz(10,14,16)/ 1.7116051d-08, 1.9823536d-08/
      data fxyz(10,14,17),fxyz(10,14,18)/-8.3309289d-08, 1.9750335d-07/
      data fxyz(10,14,19),fxyz(10,14,20)/-2.3318559d-08,-4.5747561d-08/
      data fxyz(10,14,21),fxyz(10,14,22)/-5.5732769d-08, 1.6622271d-08/
      data fxyz(10,14,23)/                4.7725235d-08/
      data fxyz(10,15, 1),fxyz(10,15, 2)/ 1.4708282d-06,-2.1986924d-08/
      data fxyz(10,15, 3),fxyz(10,15, 4)/-2.1272282d-06,-4.0411126d-06/
      data fxyz(10,15, 5),fxyz(10,15, 6)/ 7.6335508d-06,-2.7237438d-05/
      data fxyz(10,15, 7),fxyz(10,15, 8)/ 3.9733851d-05,-3.5739411d-05/
      data fxyz(10,15, 9),fxyz(10,15,10)/ 4.7972862d-05,-2.7590100d-05/
      data fxyz(10,15,11),fxyz(10,15,12)/ 9.5544309d-07,-4.7204467d-07/
      data fxyz(10,15,13),fxyz(10,15,14)/ 1.7332587d-07, 7.9969524d-09/
      data fxyz(10,15,15),fxyz(10,15,16)/ 5.6277703d-09,-1.9654396d-08/
      data fxyz(10,15,17),fxyz(10,15,18)/ 2.0896304d-08, 4.6359931d-08/
      data fxyz(10,15,19),fxyz(10,15,20)/ 1.0604553d-07,-1.1746488d-07/
      data fxyz(10,15,21),fxyz(10,15,22)/-1.0968052d-07, 7.4908101d-08/
      data fxyz(10,15,23)/                1.6312529d-07/
      data fxyz(10,16, 1),fxyz(10,16, 2)/ 2.5252036d-05, 1.4895870d-05/
      data fxyz(10,16, 3),fxyz(10,16, 4)/-1.0370384d-05,-4.9900654d-06/
      data fxyz(10,16, 5),fxyz(10,16, 6)/-6.6254046d-06, 1.0595682d-04/
      data fxyz(10,16, 7),fxyz(10,16, 8)/-1.1972303d-04, 8.6721175d-06/
      data fxyz(10,16, 9),fxyz(10,16,10)/ 1.8729168d-05,-1.7102982d-05/
      data fxyz(10,16,11),fxyz(10,16,12)/ 2.2832885d-05,-4.3251119d-06/
      data fxyz(10,16,13),fxyz(10,16,14)/ 1.0563313d-06,-3.0221644d-07/
      data fxyz(10,16,15),fxyz(10,16,16)/ 8.3374897d-08,-2.5099789d-08/
      data fxyz(10,16,17),fxyz(10,16,18)/ 1.1390030d-07,-8.8782883d-08/
      data fxyz(10,16,19),fxyz(10,16,20)/ 7.1049143d-08,-3.1845131d-08/
      data fxyz(10,16,21),fxyz(10,16,22)/-2.1978865d-08, 3.1584075d-08/
      data fxyz(10,16,23)/                5.9211119d-08/
      data fxyz(10,17, 1),fxyz(10,17, 2)/-8.3434481d-05,-5.1607979d-05/
      data fxyz(10,17, 3),fxyz(10,17, 4)/ 2.9529687d-05, 6.8881546d-06/
      data fxyz(10,17, 5),fxyz(10,17, 6)/ 3.8958150d-05,-4.2305746d-04/
      data fxyz(10,17, 7),fxyz(10,17, 8)/ 5.8077213d-04,-1.0088984d-04/
      data fxyz(10,17, 9),fxyz(10,17,10)/-1.9142619d-04, 1.1182437d-04/
      data fxyz(10,17,11),fxyz(10,17,12)/-4.2347120d-05, 9.3914400d-06/
      data fxyz(10,17,13),fxyz(10,17,14)/-1.4163283d-06, 5.2519062d-07/
      data fxyz(10,17,15),fxyz(10,17,16)/-1.2696952d-07, 5.8937484d-08/
      data fxyz(10,17,17),fxyz(10,17,18)/-1.3884351d-07, 1.0373506d-07/
      data fxyz(10,17,19),fxyz(10,17,20)/-1.1562678d-07, 6.2555585d-09/
      data fxyz(10,17,21),fxyz(10,17,22)/-6.8571122d-09,-6.3176098d-08/
      data fxyz(10,17,23)/               -9.2955003d-08/
      data fxyz(10,18, 1),fxyz(10,18, 2)/ 8.7430031d-05, 5.3891300d-05/
      data fxyz(10,18, 3),fxyz(10,18, 4)/-3.2338130d-05,-7.2068719d-06/
      data fxyz(10,18, 5),fxyz(10,18, 6)/-4.6633732d-05, 4.6439890d-04/
      data fxyz(10,18, 7),fxyz(10,18, 8)/-6.8382695d-04, 2.1807832d-04/
      data fxyz(10,18, 9),fxyz(10,18,10)/ 1.2658229d-04,-7.6356033d-05/
      data fxyz(10,18,11),fxyz(10,18,12)/ 2.0658585d-05,-3.8621439d-06/
      data fxyz(10,18,13),fxyz(10,18,14)/ 5.1947408d-08,-5.6136946d-08/
      data fxyz(10,18,15),fxyz(10,18,16)/ 5.4216650d-08,-2.0498015d-08/
      data fxyz(10,18,17),fxyz(10,18,18)/ 8.5965343d-08,-4.1464752d-08/
      data fxyz(10,18,19),fxyz(10,18,20)/ 7.2560994d-08,-5.2525028d-10/
      data fxyz(10,18,21),fxyz(10,18,22)/ 6.5063633d-09, 4.4434539d-08/
      data fxyz(10,18,23)/                6.4009452d-08/
      data fxyz(10,19, 1),fxyz(10,19, 2)/ 1.7842282d-04, 1.1024683d-04/
      data fxyz(10,19, 3),fxyz(10,19, 4)/-6.5129407d-05,-1.3880971d-05/
      data fxyz(10,19, 5),fxyz(10,19, 6)/-9.4746918d-05, 9.4714937d-04/
      data fxyz(10,19, 7),fxyz(10,19, 8)/-1.3869705d-03, 4.1460931d-04/
      data fxyz(10,19, 9),fxyz(10,19,10)/ 2.9368682d-04,-1.7393422d-04/
      data fxyz(10,19,11),fxyz(10,19,12)/ 4.7039801d-05,-9.4099748d-06/
      data fxyz(10,19,13),fxyz(10,19,14)/ 3.9424161d-07,-2.3496890d-07/
      data fxyz(10,19,15),fxyz(10,19,16)/ 1.2353694d-07,-5.3227007d-08/
      data fxyz(10,19,17),fxyz(10,19,18)/ 1.7433058d-07,-9.0173776d-08/
      data fxyz(10,19,19),fxyz(10,19,20)/ 1.5364485d-07, 5.5172263d-09/
      data fxyz(10,19,21),fxyz(10,19,22)/ 2.0372204d-08, 9.4224945d-08/
      data fxyz(10,19,23)/                1.3265088d-07/
      data fxyz(11, 1, 1),fxyz(11, 1, 2)/-9.8011129d-04,-5.3682778d-04/
      data fxyz(11, 1, 3),fxyz(11, 1, 4)/ 3.5981119d-04, 4.5300617d-04/
      data fxyz(11, 1, 5),fxyz(11, 1, 6)/-9.0960771d-04, 4.1781347d-04/
      data fxyz(11, 1, 7),fxyz(11, 1, 8)/-4.1808589d-04, 3.3604022d-04/
      data fxyz(11, 1, 9),fxyz(11, 1,10)/-1.5041616d-04, 1.1206742d-04/
      data fxyz(11, 1,11),fxyz(11, 1,12)/ 1.5506023d-04,-3.1566449d-04/
      data fxyz(11, 1,13),fxyz(11, 1,14)/ 1.0271785d-04,-3.8856084d-04/
      data fxyz(11, 1,15),fxyz(11, 1,16)/ 8.7712802d-04,-4.4441810d-04/
      data fxyz(11, 1,17),fxyz(11, 1,18)/ 2.7418688d-05,-1.1719999d-05/
      data fxyz(11, 1,19),fxyz(11, 1,20)/-6.2521657d-04, 4.0286544d-04/
      data fxyz(11, 1,21),fxyz(11, 1,22)/ 3.5096980d-04,-4.1763401d-04/
      data fxyz(11, 1,23)/               -7.9015462d-04/
      data fxyz(11, 2, 1),fxyz(11, 2, 2)/-4.8413624d-04,-2.6508092d-04/
      data fxyz(11, 2, 3),fxyz(11, 2, 4)/ 1.7795590d-04, 2.2409895d-04/
      data fxyz(11, 2, 5),fxyz(11, 2, 6)/-4.4965312d-04, 2.0800953d-04/
      data fxyz(11, 2, 7),fxyz(11, 2, 8)/-2.2119681d-04, 1.8557720d-04/
      data fxyz(11, 2, 9),fxyz(11, 2,10)/-9.0995221d-05, 6.9921302d-05/
      data fxyz(11, 2,11),fxyz(11, 2,12)/ 7.2987270d-05,-1.5367471d-04/
      data fxyz(11, 2,13),fxyz(11, 2,14)/ 2.9610225d-05,-1.2810033d-04/
      data fxyz(11, 2,15),fxyz(11, 2,16)/ 3.5005850d-04,-1.7429073d-04/
      data fxyz(11, 2,17),fxyz(11, 2,18)/ 1.4399962d-05,-1.6618209d-05/
      data fxyz(11, 2,19),fxyz(11, 2,20)/-3.0482880d-04, 1.9753082d-04/
      data fxyz(11, 2,21),fxyz(11, 2,22)/ 1.7272172d-04,-2.0559239d-04/
      data fxyz(11, 2,23)/               -3.8875473d-04/
      data fxyz(11, 3, 1),fxyz(11, 3, 2)/ 8.3071576d-04, 4.6805517d-04/
      data fxyz(11, 3, 3),fxyz(11, 3, 4)/-2.3997201d-04,-3.6090166d-04/
      data fxyz(11, 3, 5),fxyz(11, 3, 6)/ 9.5177377d-04,-9.8322900d-04/
      data fxyz(11, 3, 7),fxyz(11, 3, 8)/ 9.9020856d-04,-6.2185854d-04/
      data fxyz(11, 3, 9),fxyz(11, 3,10)/ 4.2346406d-04,-4.1924319d-04/
      data fxyz(11, 3,11),fxyz(11, 3,12)/ 1.8475825d-05, 2.7572391d-04/
      data fxyz(11, 3,13),fxyz(11, 3,14)/-5.0787945d-05, 2.0187192d-04/
      data fxyz(11, 3,15),fxyz(11, 3,16)/-7.7864308d-04, 5.4281420d-04/
      data fxyz(11, 3,17),fxyz(11, 3,18)/ 2.8120428d-05,-2.8773488d-04/
      data fxyz(11, 3,19),fxyz(11, 3,20)/ 6.3087290d-04,-2.9477080d-04/
      data fxyz(11, 3,21),fxyz(11, 3,22)/-2.3066123d-04, 3.7443464d-04/
      data fxyz(11, 3,23)/                6.7390860d-04/
      data fxyz(11, 4, 1),fxyz(11, 4, 2)/-7.2050160d-04,-4.1367103d-04/
      data fxyz(11, 4, 3),fxyz(11, 4, 4)/ 1.6835426d-04, 3.0042461d-04/
      data fxyz(11, 4, 5),fxyz(11, 4, 6)/-9.4195241d-04, 1.2605536d-03/
      data fxyz(11, 4, 7),fxyz(11, 4, 8)/-1.3491931d-03, 8.7011025d-04/
      data fxyz(11, 4, 9),fxyz(11, 4,10)/-6.5471087d-04, 6.5615664d-04/
      data fxyz(11, 4,11),fxyz(11, 4,12)/-1.3250091d-04,-2.3080839d-04/
      data fxyz(11, 4,13),fxyz(11, 4,14)/-1.0566920d-04, 2.8855307d-04/
      data fxyz(11, 4,15),fxyz(11, 4,16)/ 1.9836752d-04,-3.0450235d-04/
      data fxyz(11, 4,17),fxyz(11, 4,18)/-5.1746275d-05, 3.7291307d-04/
      data fxyz(11, 4,19),fxyz(11, 4,20)/-5.8702412d-04, 2.1731207d-04/
      data fxyz(11, 4,21),fxyz(11, 4,22)/ 1.5392786d-04,-3.3348727d-04/
      data fxyz(11, 4,23)/               -5.7785013d-04/
      data fxyz(11, 5, 1),fxyz(11, 5, 2)/ 4.7355342d-04, 2.6991120d-04/
      data fxyz(11, 5, 3),fxyz(11, 5, 4)/-1.2025991d-04,-2.0111882d-04/
      data fxyz(11, 5, 5),fxyz(11, 5, 6)/ 5.9334681d-04,-7.3933013d-04/
      data fxyz(11, 5, 7),fxyz(11, 5, 8)/ 8.0691943d-04,-5.4344711d-04/
      data fxyz(11, 5, 9),fxyz(11, 5,10)/ 4.1406024d-04,-4.0814709d-04/
      data fxyz(11, 5,11),fxyz(11, 5,12)/ 8.7812480d-05, 1.1639748d-04/
      data fxyz(11, 5,13),fxyz(11, 5,14)/ 1.2438957d-04,-3.5969040d-04/
      data fxyz(11, 5,15),fxyz(11, 5,16)/ 1.5454895d-04, 2.7274948d-05/
      data fxyz(11, 5,17),fxyz(11, 5,18)/ 2.7243358d-05,-1.7993860d-04/
      data fxyz(11, 5,19),fxyz(11, 5,20)/ 3.1563873d-04,-1.1558598d-04/
      data fxyz(11, 5,21),fxyz(11, 5,22)/-8.2509295d-05, 1.8333198d-04/
      data fxyz(11, 5,23)/                3.1621169d-04/
      data fxyz(11, 6, 1),fxyz(11, 6, 2)/-2.1642512d-04,-1.1999360d-04/
      data fxyz(11, 6, 3),fxyz(11, 6, 4)/ 7.0284677d-05, 9.8915862d-05/
      data fxyz(11, 6, 5),fxyz(11, 6, 6)/-2.3451834d-04, 2.1304265d-04/
      data fxyz(11, 6, 7),fxyz(11, 6, 8)/-2.2392768d-04, 1.4882729d-04/
      data fxyz(11, 6, 9),fxyz(11, 6,10)/-1.1140126d-04, 1.0971490d-04/
      data fxyz(11, 6,11),fxyz(11, 6,12)/-2.3536468d-05,-3.1341030d-05/
      data fxyz(11, 6,13),fxyz(11, 6,14)/-3.2967223d-05, 9.5438333d-05/
      data fxyz(11, 6,15),fxyz(11, 6,16)/-3.9316279d-05,-8.8944302d-06/
      data fxyz(11, 6,17),fxyz(11, 6,18)/-7.0008698d-06, 5.2971350d-05/
      data fxyz(11, 6,19),fxyz(11, 6,20)/-9.3292264d-05, 3.3749090d-05/
      data fxyz(11, 6,21),fxyz(11, 6,22)/ 2.3991990d-05,-5.4263863d-05/
      data fxyz(11, 6,23)/               -9.3385155d-05/
      data fxyz(11, 7, 1),fxyz(11, 7, 2)/-1.0891971d-04,-6.7220227d-05/
      data fxyz(11, 7, 3),fxyz(11, 7, 4)/ 1.4751728d-05, 2.7673866d-05/
      data fxyz(11, 7, 5),fxyz(11, 7, 6)/-1.1890878d-04, 8.4912354d-05/
      data fxyz(11, 7, 7),fxyz(11, 7, 8)/ 1.7548715d-05,-2.9663499d-05/
      data fxyz(11, 7, 9),fxyz(11, 7,10)/ 2.6848230d-05,-2.8690980d-05/
      data fxyz(11, 7,11),fxyz(11, 7,12)/ 6.0251930d-06, 8.6453967d-06/
      data fxyz(11, 7,13),fxyz(11, 7,14)/ 8.2452973d-06,-2.4329781d-05/
      data fxyz(11, 7,15),fxyz(11, 7,16)/ 8.8343484d-06, 3.0699208d-06/
      data fxyz(11, 7,17),fxyz(11, 7,18)/ 1.1359531d-06,-1.5202084d-05/
      data fxyz(11, 7,19),fxyz(11, 7,20)/ 2.3597362d-05,-6.7393261d-06/
      data fxyz(11, 7,21),fxyz(11, 7,22)/-4.2255650d-06, 1.3542318d-05/
      data fxyz(11, 7,23)/                2.2504333d-05/
      data fxyz(11, 8, 1),fxyz(11, 8, 2)/ 7.6956600d-04, 4.5475211d-04/
      data fxyz(11, 8, 3),fxyz(11, 8, 4)/-1.6796367d-04,-2.5876313d-04/
      data fxyz(11, 8, 5),fxyz(11, 8, 6)/ 8.1794997d-04,-5.9242596d-04/
      data fxyz(11, 8, 7),fxyz(11, 8, 8)/ 1.6005396d-04,-3.4050941d-05/
      data fxyz(11, 8, 9),fxyz(11, 8,10)/ 4.0022304d-06, 4.5007036d-06/
      data fxyz(11, 8,11),fxyz(11, 8,12)/-6.7491154d-07,-2.8466862d-06/
      data fxyz(11, 8,13),fxyz(11, 8,14)/-1.4184503d-06, 5.1666251d-06/
      data fxyz(11, 8,15),fxyz(11, 8,16)/-1.2443587d-06,-1.4074238d-06/
      data fxyz(11, 8,17),fxyz(11, 8,18)/-1.1368522d-07, 3.8803788d-06/
      data fxyz(11, 8,19),fxyz(11, 8,20)/-5.5862472d-06, 1.5302343d-06/
      data fxyz(11, 8,21),fxyz(11, 8,22)/ 9.2322554d-07,-3.1582123d-06/
      data fxyz(11, 8,23)/               -5.2247522d-06/
      data fxyz(11, 9, 1),fxyz(11, 9, 2)/-1.2136295d-03,-7.1889231d-04/
      data fxyz(11, 9, 3),fxyz(11, 9, 4)/ 2.5706989d-04, 4.0440056d-04/
      data fxyz(11, 9, 5),fxyz(11, 9, 6)/-1.3082150d-03, 9.9633055d-04/
      data fxyz(11, 9, 7),fxyz(11, 9, 8)/-3.0123787d-04, 7.0462485d-05/
      data fxyz(11, 9, 9),fxyz(11, 9,10)/-1.7698228d-05, 3.3269904d-06/
      data fxyz(11, 9,11),fxyz(11, 9,12)/-1.2315179d-06, 1.3601200d-06/
      data fxyz(11, 9,13),fxyz(11, 9,14)/-3.5227425d-07,-5.7787980d-07/
      data fxyz(11, 9,15),fxyz(11, 9,16)/-1.3744726d-07, 5.6817295d-07/
      data fxyz(11, 9,17),fxyz(11, 9,18)/-1.4014194d-07,-7.9515603d-07/
      data fxyz(11, 9,19),fxyz(11, 9,20)/ 1.5275880d-06,-4.8843385d-07/
      data fxyz(11, 9,21),fxyz(11, 9,22)/-3.3351830d-07, 9.0792578d-07/
      data fxyz(11, 9,23)/                1.5285772d-06/
      data fxyz(11,10, 1),fxyz(11,10, 2)/ 7.8062775d-04, 4.6283564d-04/
      data fxyz(11,10, 3),fxyz(11,10, 4)/-1.6200432d-04,-2.6025483d-04/
      data fxyz(11,10, 5),fxyz(11,10, 6)/ 8.5583769d-04,-6.9312996d-04/
      data fxyz(11,10, 7),fxyz(11,10, 8)/ 2.4724277d-04,-6.1220092d-05/
      data fxyz(11,10, 9),fxyz(11,10,10)/ 1.2502638d-05,-4.0616060d-06/
      data fxyz(11,10,11),fxyz(11,10,12)/ 9.5067984d-07,-7.2293295d-07/
      data fxyz(11,10,13),fxyz(11,10,14)/ 3.2322623d-07,-1.5329816d-08/
      data fxyz(11,10,15),fxyz(11,10,16)/ 1.0631362d-07,-2.9687737d-07/
      data fxyz(11,10,17),fxyz(11,10,18)/ 2.3972653d-07,-2.8076666d-08/
      data fxyz(11,10,19),fxyz(11,10,20)/-1.3714582d-07, 2.9332142d-08/
      data fxyz(11,10,21),fxyz(11,10,22)/ 2.0467006d-08,-1.0168527d-07/
      data fxyz(11,10,23)/               -1.6105370d-07/
      data fxyz(11,11, 1),fxyz(11,11, 2)/-2.1550957d-04,-1.2802868d-04/
      data fxyz(11,11, 3),fxyz(11,11, 4)/ 4.3064630d-05, 7.1704662d-05/
      data fxyz(11,11, 5),fxyz(11,11, 6)/-2.4258881d-04, 2.1409091d-04/
      data fxyz(11,11, 7),fxyz(11,11, 8)/-1.0253500d-04, 4.0095251d-05/
      data fxyz(11,11, 9),fxyz(11,11,10)/-8.6269720d-06, 2.4363327d-06/
      data fxyz(11,11,11),fxyz(11,11,12)/-9.3790351d-07, 2.3775908d-07/
      data fxyz(11,11,13),fxyz(11,11,14)/-1.2234670d-07,-3.7183360d-08/
      data fxyz(11,11,15),fxyz(11,11,16)/-5.5204126d-09, 1.3266546d-07/
      data fxyz(11,11,17),fxyz(11,11,18)/-1.7375672d-07, 1.1524216d-07/
      data fxyz(11,11,19),fxyz(11,11,20)/-7.8278397d-08,-6.0703123d-09/
      data fxyz(11,11,21),fxyz(11,11,22)/-1.6855961d-08,-3.5135802d-08/
      data fxyz(11,11,23)/               -4.6542568d-08/
      data fxyz(11,12, 1),fxyz(11,12, 2)/ 5.9231652d-05, 3.4613113d-05/
      data fxyz(11,12, 3),fxyz(11,12, 4)/-1.3924759d-05,-2.1303002d-05/
      data fxyz(11,12, 5),fxyz(11,12, 6)/ 6.4126088d-05,-5.1442002d-05/
      data fxyz(11,12, 7),fxyz(11,12, 8)/ 2.6049384d-05,-1.8851144d-05/
      data fxyz(11,12, 9),fxyz(11,12,10)/ 1.5744891d-05,-7.3740286d-06/
      data fxyz(11,12,11),fxyz(11,12,12)/ 1.7504715d-06,-5.4917343d-07/
      data fxyz(11,12,13),fxyz(11,12,14)/ 1.1890226d-07,-5.4361822d-08/
      data fxyz(11,12,15),fxyz(11,12,16)/ 1.9470280d-08,-3.3649942d-08/
      data fxyz(11,12,17),fxyz(11,12,18)/ 7.5297735d-08,-1.0304658d-07/
      data fxyz(11,12,19),fxyz(11,12,20)/-2.6882160d-07, 1.9524111d-07/
      data fxyz(11,12,21),fxyz(11,12,22)/ 1.7709217d-07,-1.9622585d-07/
      data fxyz(11,12,23)/               -3.7528064d-07/
      data fxyz(11,13, 1),fxyz(11,13, 2)/-2.3972004d-05,-1.3130569d-05/
      data fxyz(11,13, 3),fxyz(11,13, 4)/ 8.5931370d-06, 1.1232035d-05/
      data fxyz(11,13, 5),fxyz(11,13, 6)/-2.3686160d-05, 1.5611462d-05/
      data fxyz(11,13, 7),fxyz(11,13, 8)/-1.1571817d-05, 1.8995796d-05/
      data fxyz(11,13, 9),fxyz(11,13,10)/-3.4917784d-05, 2.5049924d-05/
      data fxyz(11,13,11),fxyz(11,13,12)/-6.8173215d-06, 1.7716148d-06/
      data fxyz(11,13,13),fxyz(11,13,14)/-4.6951339d-07, 6.4934149d-08/
      data fxyz(11,13,15),fxyz(11,13,16)/-2.6723767d-08, 3.9297496d-08/
      data fxyz(11,13,17),fxyz(11,13,18)/-6.3698272d-08,-7.6446792d-09/
      data fxyz(11,13,19),fxyz(11,13,20)/-5.2136397d-10, 3.9948512d-08/
      data fxyz(11,13,21),fxyz(11,13,22)/ 3.9390160d-08, 1.7120462d-09/
      data fxyz(11,13,23)/               -1.6019967d-08/
      data fxyz(11,14, 1),fxyz(11,14, 2)/-3.2713669d-06,-6.9922239d-07/
      data fxyz(11,14, 3),fxyz(11,14, 4)/ 5.4005633d-06, 4.3714804d-06/
      data fxyz(11,14, 5),fxyz(11,14, 6)/ 3.4171094d-06,-1.8707611d-05/
      data fxyz(11,14, 7),fxyz(11,14, 8)/ 1.7957340d-05,-7.2310111d-05/
      data fxyz(11,14, 9),fxyz(11,14,10)/ 1.3487902d-04,-9.1380794d-05/
      data fxyz(11,14,11),fxyz(11,14,12)/ 2.4449677d-05,-6.5857032d-06/
      data fxyz(11,14,13),fxyz(11,14,14)/ 1.7123247d-06,-3.9949385d-07/
      data fxyz(11,14,15),fxyz(11,14,16)/ 7.8735550d-08,-9.6919784d-08/
      data fxyz(11,14,17),fxyz(11,14,18)/ 9.6479832d-08, 1.3269161d-09/
      data fxyz(11,14,19),fxyz(11,14,20)/ 1.6193614d-07,-1.1878854d-07/
      data fxyz(11,14,21),fxyz(11,14,22)/-1.0494610d-07, 1.0656638d-07/
      data fxyz(11,14,23)/                2.0896353d-07/
      data fxyz(11,15, 1),fxyz(11,15, 2)/ 1.2634846d-05, 6.3073252d-06/
      data fxyz(11,15, 3),fxyz(11,15, 4)/-8.5545283d-06,-6.2744865d-06/
      data fxyz(11,15, 5),fxyz(11,15, 6)/-2.8128418d-06, 4.6835472d-05/
      data fxyz(11,15, 7),fxyz(11,15, 8)/-6.3817713d-05, 2.6162718d-04/
      data fxyz(11,15, 9),fxyz(11,15,10)/-5.0413688d-04, 3.4643690d-04/
      data fxyz(11,15,11),fxyz(11,15,12)/-9.3887720d-05, 2.5235469d-05/
      data fxyz(11,15,13),fxyz(11,15,14)/-6.7429956d-06, 1.7906919d-06/
      data fxyz(11,15,15),fxyz(11,15,16)/-4.8420201d-07, 1.9146099d-07/
      data fxyz(11,15,17),fxyz(11,15,18)/-8.1755833d-08, 4.9259029d-08/
      data fxyz(11,15,19),fxyz(11,15,20)/ 6.4254643d-08,-6.4010724d-08/
      data fxyz(11,15,21),fxyz(11,15,22)/-6.0457585d-08, 5.0042089d-08/
      data fxyz(11,15,23)/                1.0255611d-07/
      data fxyz(11,16, 1),fxyz(11,16, 2)/-2.7204366d-05,-1.3638115d-05/
      data fxyz(11,16, 3),fxyz(11,16, 4)/ 1.8513733d-05, 1.3121441d-05/
      data fxyz(11,16, 5),fxyz(11,16, 6)/ 7.9310543d-06,-1.0808875d-04/
      data fxyz(11,16, 7),fxyz(11,16, 8)/ 7.5729684d-06,-1.9896658d-04/
      data fxyz(11,16, 9),fxyz(11,16,10)/ 7.2131752d-04,-5.7732582d-04/
      data fxyz(11,16,11),fxyz(11,16,12)/ 1.5890748d-04,-4.1861842d-05/
      data fxyz(11,16,13),fxyz(11,16,14)/ 1.1444061d-05,-3.0699334d-06/
      data fxyz(11,16,15),fxyz(11,16,16)/ 8.7863585d-07,-2.4960778d-07/
      data fxyz(11,16,17),fxyz(11,16,18)/ 4.1381587d-08, 3.9060952d-08/
      data fxyz(11,16,19),fxyz(11,16,20)/-5.9636240d-08, 8.3158579d-09/
      data fxyz(11,16,21),fxyz(11,16,22)/ 2.1255967d-09,-3.4875195d-08/
      data fxyz(11,16,23)/               -5.3792967d-08/
      data fxyz(11,17, 1),fxyz(11,17, 2)/ 1.0897710d-04, 5.3083177d-05/
      data fxyz(11,17, 3),fxyz(11,17, 4)/-7.9380908d-05,-5.7170973d-05/
      data fxyz(11,17, 5),fxyz(11,17, 6)/-3.5756564d-05, 4.4212613d-04/
      data fxyz(11,17, 7),fxyz(11,17, 8)/-1.3048736d-04,-1.5816895d-04/
      data fxyz(11,17, 9),fxyz(11,17,10)/-3.4523053d-04, 4.0555427d-04/
      data fxyz(11,17,11),fxyz(11,17,12)/-1.0816810d-04, 2.9487657d-05/
      data fxyz(11,17,13),fxyz(11,17,14)/-8.0275110d-06, 2.2586639d-06/
      data fxyz(11,17,15),fxyz(11,17,16)/-6.0800154d-07, 1.5983013d-07/
      data fxyz(11,17,17),fxyz(11,17,18)/ 3.2633973d-08,-4.6498563d-08/
      data fxyz(11,17,19),fxyz(11,17,20)/ 1.0192253d-07,-4.7510721d-08/
      data fxyz(11,17,21),fxyz(11,17,22)/-3.7155186d-08, 6.0500386d-08/
      data fxyz(11,17,23)/                1.0883446d-07/
      data fxyz(11,18, 1),fxyz(11,18, 2)/-1.1453544d-04,-5.6104161d-05/
      data fxyz(11,18, 3),fxyz(11,18, 4)/ 8.4298729d-05, 5.7710960d-05/
      data fxyz(11,18, 5),fxyz(11,18, 6)/ 5.0246917d-05,-5.1335198d-04/
      data fxyz(11,18, 7),fxyz(11,18, 8)/ 3.3198137d-04, 8.5324222d-05/
      data fxyz(11,18, 9),fxyz(11,18,10)/ 2.0443195d-05,-8.5792982d-05/
      data fxyz(11,18,11),fxyz(11,18,12)/ 2.0948213d-05,-6.6432820d-06/
      data fxyz(11,18,13),fxyz(11,18,14)/ 1.8874338d-06,-5.4828062d-07/
      data fxyz(11,18,15),fxyz(11,18,16)/ 1.4684515d-07,-1.3480902d-08/
      data fxyz(11,18,17),fxyz(11,18,18)/-5.2818550d-08, 4.6425197d-08/
      data fxyz(11,18,19),fxyz(11,18,20)/-1.0746800d-07, 4.0105830d-08/
      data fxyz(11,18,21),fxyz(11,18,22)/ 2.9531732d-08,-6.5171613d-08/
      data fxyz(11,18,23)/               -1.1218627d-07/
      data fxyz(11,19, 1),fxyz(11,19, 2)/-2.3527826d-04,-1.1503189d-04/
      data fxyz(11,19, 3),fxyz(11,19, 4)/ 1.7324286d-04, 1.1968594d-04/
      data fxyz(11,19, 5),fxyz(11,19, 6)/ 9.9195798d-05,-1.0386321d-03/
      data fxyz(11,19, 7),fxyz(11,19, 8)/ 6.2287038d-04, 2.7090438d-04/
      data fxyz(11,19, 9),fxyz(11,19,10)/-2.3089300d-05,-1.5593242d-04/
      data fxyz(11,19,11),fxyz(11,19,12)/ 3.6866843d-05,-1.2065524d-05/
      data fxyz(11,19,13),fxyz(11,19,14)/ 3.4062308d-06,-1.0307846d-06/
      data fxyz(11,19,15),fxyz(11,19,16)/ 2.6126782d-07,-2.0292235d-08/
      data fxyz(11,19,17),fxyz(11,19,18)/-1.1635538d-07, 8.8353736d-08/
      data fxyz(11,19,19),fxyz(11,19,20)/-2.1087302d-07, 8.6738630d-08/
      data fxyz(11,19,21),fxyz(11,19,22)/ 6.5942165d-08,-1.2768716d-07/
      data fxyz(11,19,23)/               -2.2359324d-07/
      data fxyz(12, 1, 1),fxyz(12, 1, 2)/ 1.1222827d-03, 6.4903367d-04/
      data fxyz(12, 1, 3),fxyz(12, 1, 4)/-2.9637635d-04,-4.1659265d-04/
      data fxyz(12, 1, 5),fxyz(12, 1, 6)/ 1.1298988d-03,-6.8096171d-04/
      data fxyz(12, 1, 7),fxyz(12, 1, 8)/ 2.4224338d-04,-1.0336885d-04/
      data fxyz(12, 1, 9),fxyz(12, 1,10)/-7.7468801d-06, 8.2532874d-06/
      data fxyz(12, 1,11),fxyz(12, 1,12)/-7.2856977d-05, 1.4471232d-04/
      data fxyz(12, 1,13),fxyz(12, 1,14)/-2.4348528d-04, 9.6339070d-04/
      data fxyz(12, 1,15),fxyz(12, 1,16)/-1.6011839d-03, 9.4062885d-04/
      data fxyz(12, 1,17),fxyz(12, 1,18)/-1.1051297d-04,-4.5812753d-04/
      data fxyz(12, 1,19),fxyz(12, 1,20)/ 9.6320309d-04,-3.7442392d-04/
      data fxyz(12, 1,21),fxyz(12, 1,22)/-2.7732471d-04, 5.7480627d-04/
      data fxyz(12, 1,23)/                9.9836052d-04/
      data fxyz(12, 2, 1),fxyz(12, 2, 2)/ 5.5892658d-04, 3.2313812d-04/
      data fxyz(12, 2, 3),fxyz(12, 2, 4)/-1.4767261d-04,-2.0796053d-04/
      data fxyz(12, 2, 5),fxyz(12, 2, 6)/ 5.6428980d-04,-3.4539222d-04/
      data fxyz(12, 2, 7),fxyz(12, 2, 8)/ 1.3012145d-04,-5.7709032d-05/
      data fxyz(12, 2, 9),fxyz(12, 2,10)/ 9.7603147d-07, 6.0783439d-07/
      data fxyz(12, 2,11),fxyz(12, 2,12)/-3.4851400d-05, 6.7197145d-05/
      data fxyz(12, 2,13),fxyz(12, 2,14)/-1.0039428d-04, 4.0322234d-04/
      data fxyz(12, 2,15),fxyz(12, 2,16)/-6.8029261d-04, 3.9690307d-04/
      data fxyz(12, 2,17),fxyz(12, 2,18)/-3.6202425d-05,-2.3425290d-04/
      data fxyz(12, 2,19),fxyz(12, 2,20)/ 4.8092734d-04,-1.8636583d-04/
      data fxyz(12, 2,21),fxyz(12, 2,22)/-1.3763559d-04, 2.8600638d-04/
      data fxyz(12, 2,23)/                4.9670070d-04/
      data fxyz(12, 3, 1),fxyz(12, 3, 2)/-1.8489793d-03,-1.0810063d-03/
      data fxyz(12, 3, 3),fxyz(12, 3, 4)/ 4.3981376d-04, 6.5827729d-04/
      data fxyz(12, 3, 5),fxyz(12, 3, 6)/-1.9548605d-03, 1.4279736d-03/
      data fxyz(12, 3, 7),fxyz(12, 3, 8)/-6.1023666d-04, 2.7801758d-04/
      data fxyz(12, 3, 9),fxyz(12, 3,10)/-1.2194076d-04, 1.1125649d-04/
      data fxyz(12, 3,11),fxyz(12, 3,12)/ 7.2810077d-06,-1.3697387d-04/
      data fxyz(12, 3,13),fxyz(12, 3,14)/ 2.5379359d-04,-9.9840634d-04/
      data fxyz(12, 3,15),fxyz(12, 3,16)/ 1.7020009d-03,-1.0126181d-03/
      data fxyz(12, 3,17),fxyz(12, 3,18)/-2.8928991d-05, 1.0445952d-03/
      data fxyz(12, 3,19),fxyz(12, 3,20)/-1.6887555d-03, 5.8215007d-04/
      data fxyz(12, 3,21),fxyz(12, 3,22)/ 4.0209754d-04,-9.6854536d-04/
      data fxyz(12, 3,23)/               -1.6561927d-03/
      data fxyz(12, 4, 1),fxyz(12, 4, 2)/ 2.1990390d-03, 1.2887204d-03/
      data fxyz(12, 4, 3),fxyz(12, 4, 4)/-5.0843905d-04,-7.7710483d-04/
      data fxyz(12, 4, 5),fxyz(12, 4, 6)/ 2.3633835d-03,-1.8309477d-03/
      data fxyz(12, 4, 7),fxyz(12, 4, 8)/ 8.4823184d-04,-4.0148960d-04/
      data fxyz(12, 4, 9),fxyz(12, 4,10)/ 2.1588140d-04,-1.9212424d-04/
      data fxyz(12, 4,11),fxyz(12, 4,12)/ 3.4969504d-05, 1.0215057d-04/
      data fxyz(12, 4,13),fxyz(12, 4,14)/-1.3085754d-04, 5.4507610d-04/
      data fxyz(12, 4,15),fxyz(12, 4,16)/-1.0306133d-03, 6.0814466d-04/
      data fxyz(12, 4,17),fxyz(12, 4,18)/ 2.1297433d-04,-1.3689639d-03/
      data fxyz(12, 4,19),fxyz(12, 4,20)/ 2.0474865d-03,-6.8093636d-04/
      data fxyz(12, 4,21),fxyz(12, 4,22)/-4.5832333d-04, 1.1570344d-03/
      data fxyz(12, 4,23)/                1.9702314d-03/
      data fxyz(12, 5, 1),fxyz(12, 5, 2)/-1.2438036d-03,-7.2675310d-04/
      data fxyz(12, 5, 3),fxyz(12, 5, 4)/ 2.9426314d-04, 4.4642405d-04/
      data fxyz(12, 5, 5),fxyz(12, 5, 6)/-1.3353967d-03, 1.0386100d-03/
      data fxyz(12, 5, 7),fxyz(12, 5, 8)/-5.0503163d-04, 2.4301069d-04/
      data fxyz(12, 5, 9),fxyz(12, 5,10)/-1.3532336d-04, 1.1800854d-04/
      data fxyz(12, 5,11),fxyz(12, 5,12)/-2.4200155d-05,-4.1310547d-05/
      data fxyz(12, 5,13),fxyz(12, 5,14)/ 8.8760618d-06,-6.7710481d-05/
      data fxyz(12, 5,15),fxyz(12, 5,16)/ 2.1294655d-04,-1.1838927d-04/
      data fxyz(12, 5,17),fxyz(12, 5,18)/-1.7692335d-04, 7.8236625d-04/
      data fxyz(12, 5,19),fxyz(12, 5,20)/-1.1465389d-03, 3.7992170d-04/
      data fxyz(12, 5,21),fxyz(12, 5,22)/ 2.5454574d-04,-6.4503510d-04/
      data fxyz(12, 5,23)/               -1.0982731d-03/
      data fxyz(12, 6, 1),fxyz(12, 6, 2)/ 3.6773470d-04, 2.1140742d-04/
      data fxyz(12, 6, 3),fxyz(12, 6, 4)/-9.9091261d-05,-1.4194586d-04/
      data fxyz(12, 6, 5),fxyz(12, 6, 6)/ 3.8282582d-04,-2.7508433d-04/
      data fxyz(12, 6, 7),fxyz(12, 6, 8)/ 1.3968004d-04,-6.5402989d-05/
      data fxyz(12, 6, 9),fxyz(12, 6,10)/ 3.6744605d-05,-3.1643546d-05/
      data fxyz(12, 6,11),fxyz(12, 6,12)/ 6.5232047d-06, 1.1082781d-05/
      data fxyz(12, 6,13),fxyz(12, 6,14)/-2.5957141d-06, 1.8659027d-05/
      data fxyz(12, 6,15),fxyz(12, 6,16)/-5.7724458d-05, 3.2546164d-05/
      data fxyz(12, 6,17),fxyz(12, 6,18)/ 4.8170967d-05,-2.1059464d-04/
      data fxyz(12, 6,19),fxyz(12, 6,20)/ 3.1062690d-04,-1.0432740d-04/
      data fxyz(12, 6,21),fxyz(12, 6,22)/-7.0393844d-05, 1.7489269d-04/
      data fxyz(12, 6,23)/                2.9840868d-04/
      data fxyz(12, 7, 1),fxyz(12, 7, 2)/-7.2692767d-05,-3.9212052d-05/
      data fxyz(12, 7, 3),fxyz(12, 7, 4)/ 2.8241240d-05, 3.5750661d-05/
      data fxyz(12, 7, 5),fxyz(12, 7, 6)/-6.9249735d-05, 3.9948545d-05/
      data fxyz(12, 7, 7),fxyz(12, 7, 8)/-3.3078547d-05, 1.5627017d-05/
      data fxyz(12, 7, 9),fxyz(12, 7,10)/-9.6223297d-06, 8.2141964d-06/
      data fxyz(12, 7,11),fxyz(12, 7,12)/-1.6409125d-06,-3.0949890d-06/
      data fxyz(12, 7,13),fxyz(12, 7,14)/ 1.0921292d-06,-5.9829574d-06/
      data fxyz(12, 7,15),fxyz(12, 7,16)/ 1.6374696d-05,-9.5158739d-06/
      data fxyz(12, 7,17),fxyz(12, 7,18)/-1.2975851d-05, 5.5011922d-05/
      data fxyz(12, 7,19),fxyz(12, 7,20)/-8.2500521d-05, 2.8845577d-05/
      data fxyz(12, 7,21),fxyz(12, 7,22)/ 1.9851560d-05,-4.6524453d-05/
      data fxyz(12, 7,23)/               -7.9898331d-05/
      data fxyz(12, 8, 1),fxyz(12, 8, 2)/-4.8903220d-05,-3.7147439d-05/
      data fxyz(12, 8, 3),fxyz(12, 8, 4)/-1.7496060d-05,-7.8017930d-06/
      data fxyz(12, 8, 5),fxyz(12, 8, 6)/-7.5924507d-05, 9.6510786d-05/
      data fxyz(12, 8, 7),fxyz(12, 8, 8)/-6.2454829d-06, 6.2987766d-07/
      data fxyz(12, 8, 9),fxyz(12, 8,10)/ 1.0451959d-06,-1.7284408d-06/
      data fxyz(12, 8,11),fxyz(12, 8,12)/ 1.6637579d-07, 1.0007015d-06/
      data fxyz(12, 8,13),fxyz(12, 8,14)/-8.1340911d-07, 2.4656437d-06/
      data fxyz(12, 8,15),fxyz(12, 8,16)/-5.1781363d-06, 2.8680335d-06/
      data fxyz(12, 8,17),fxyz(12, 8,18)/ 3.3121727d-06,-1.4626368d-05/
      data fxyz(12, 8,19),fxyz(12, 8,20)/ 2.2562119d-05,-7.9494475d-06/
      data fxyz(12, 8,21),fxyz(12, 8,22)/-5.5082821d-06, 1.2797457d-05/
      data fxyz(12, 8,23)/                2.1991113d-05/
      data fxyz(12, 9, 1),fxyz(12, 9, 2)/ 8.4086205d-05, 6.4071927d-05/
      data fxyz(12, 9, 3),fxyz(12, 9, 4)/ 2.8954426d-05, 1.5356509d-05/
      data fxyz(12, 9, 5),fxyz(12, 9, 6)/ 1.1846359d-04,-1.1988255d-04/
      data fxyz(12, 9, 7),fxyz(12, 9, 8)/-2.9895373d-05, 4.7976013d-06/
      data fxyz(12, 9, 9),fxyz(12, 9,10)/-1.1716960d-06, 3.4231022d-07/
      data fxyz(12, 9,11),fxyz(12, 9,12)/-2.7202828d-08,-4.3670809d-07/
      data fxyz(12, 9,13),fxyz(12, 9,14)/ 4.7193038d-07,-1.0512477d-06/
      data fxyz(12, 9,15),fxyz(12, 9,16)/ 1.6109250d-06,-8.2720541d-07/
      data fxyz(12, 9,17),fxyz(12, 9,18)/-8.2142482d-07, 3.8936417d-06/
      data fxyz(12, 9,19),fxyz(12, 9,20)/-5.8411817d-06, 2.0128057d-06/
      data fxyz(12, 9,21),fxyz(12, 9,22)/ 1.3767289d-06,-3.2968745d-06/
      data fxyz(12, 9,23)/               -5.6475100d-06/
      data fxyz(12,10, 1),fxyz(12,10, 2)/-9.9266395d-05,-6.7007892d-05/
      data fxyz(12,10, 3),fxyz(12,10, 4)/-2.4060774d-06, 5.5101318d-06/
      data fxyz(12,10, 5),fxyz(12,10, 6)/-9.8672729d-05, 1.9476743d-05/
      data fxyz(12,10, 7),fxyz(12,10, 8)/ 9.8625445d-05,-2.7159068d-05/
      data fxyz(12,10, 9),fxyz(12,10,10)/ 2.6549238d-06,-4.5869834d-07/
      data fxyz(12,10,11),fxyz(12,10,12)/-6.9946394d-08, 1.2598403d-07/
      data fxyz(12,10,13),fxyz(12,10,14)/-1.9261357d-07, 3.1264230d-07/
      data fxyz(12,10,15),fxyz(12,10,16)/-4.2953718d-07, 1.8828614d-07/
      data fxyz(12,10,17),fxyz(12,10,18)/ 2.0973157d-07,-1.0027743d-06/
      data fxyz(12,10,19),fxyz(12,10,20)/ 1.5293885d-06,-5.4642124d-07/
      data fxyz(12,10,21),fxyz(12,10,22)/-3.8024052d-07, 8.6466558d-07/
      data fxyz(12,10,23)/                1.4899366d-06/
      data fxyz(12,11, 1),fxyz(12,11, 2)/ 6.5098951d-05, 3.9434314d-05/
      data fxyz(12,11, 3),fxyz(12,11, 4)/-1.3730967d-05,-1.6934117d-05/
      data fxyz(12,11, 5),fxyz(12,11, 6)/ 5.2246913d-05, 1.7051706d-05/
      data fxyz(12,11, 7),fxyz(12,11, 8)/-6.8399452d-05, 2.4073538d-05/
      data fxyz(12,11, 9),fxyz(12,11,10)/ 3.7720186d-06,-5.1131344d-06/
      data fxyz(12,11,11),fxyz(12,11,12)/ 1.1073436d-06,-4.4450769d-07/
      data fxyz(12,11,13),fxyz(12,11,14)/ 1.1477505d-07,-7.8515038d-08/
      data fxyz(12,11,15),fxyz(12,11,16)/ 1.0141961d-07,-4.1167419d-08/
      data fxyz(12,11,17),fxyz(12,11,18)/-8.2541309d-08, 2.5416806d-07/
      data fxyz(12,11,19),fxyz(12,11,20)/-4.1163444d-07, 1.3138299d-07/
      data fxyz(12,11,21),fxyz(12,11,22)/ 8.7749578d-08,-2.3710078d-07/
      data fxyz(12,11,23)/               -4.0033319d-07/
      data fxyz(12,12, 1),fxyz(12,12, 2)/-1.2805782d-05,-8.3208471d-06/
      data fxyz(12,12, 3),fxyz(12,12, 4)/ 7.4185489d-07, 1.7006336d-06/
      data fxyz(12,12, 5),fxyz(12,12, 6)/-1.2155962d-05, 1.5758979d-06/
      data fxyz(12,12, 7),fxyz(12,12, 8)/ 8.3748733d-06, 1.5376151d-05/
      data fxyz(12,12, 9),fxyz(12,12,10)/-3.3758199d-05, 2.3451103d-05/
      data fxyz(12,12,11),fxyz(12,12,12)/-6.3504848d-06, 1.6733938d-06/
      data fxyz(12,12,13),fxyz(12,12,14)/-4.6757018d-07, 1.0590528d-07/
      data fxyz(12,12,15),fxyz(12,12,16)/-4.7646703d-08, 6.6319538d-09/
      data fxyz(12,12,17),fxyz(12,12,18)/ 5.6825760d-08,-1.0352508d-07/
      data fxyz(12,12,19),fxyz(12,12,20)/-7.3137478d-08, 6.9974350d-08/
      data fxyz(12,12,21),fxyz(12,12,22)/ 6.8246601d-08,-6.6226480d-08/
      data fxyz(12,12,23)/               -1.2944132d-07/
      data fxyz(12,13, 1),fxyz(12,13, 2)/-4.2348436d-06,-1.5067075d-06/
      data fxyz(12,13, 3),fxyz(12,13, 4)/ 4.4598369d-06, 4.2488942d-06/
      data fxyz(12,13, 5),fxyz(12,13, 6)/-6.6293668d-07,-7.3989843d-06/
      data fxyz(12,13, 7),fxyz(12,13, 8)/ 1.6785574d-05,-8.5361531d-05/
      data fxyz(12,13, 9),fxyz(12,13,10)/ 1.4179714d-04,-9.0653683d-05/
      data fxyz(12,13,11),fxyz(12,13,12)/ 2.4218724d-05,-6.5010164d-06/
      data fxyz(12,13,13),fxyz(12,13,14)/ 1.6829946d-06,-4.2007152d-07/
      data fxyz(12,13,15),fxyz(12,13,16)/ 5.5910661d-08, 8.0863155d-09/
      data fxyz(12,13,17),fxyz(12,13,18)/-4.5178411d-09,-3.6776560d-08/
      data fxyz(12,13,19),fxyz(12,13,20)/ 4.0135666d-08, 3.8732248d-09/
      data fxyz(12,13,21),fxyz(12,13,22)/ 8.3274035d-09, 2.2318951d-08/
      data fxyz(12,13,23)/                3.0036121d-08/
      data fxyz(12,14, 1),fxyz(12,14, 2)/-5.5407808d-06,-2.5514757d-06/
      data fxyz(12,14, 3),fxyz(12,14, 4)/ 2.6916695d-06, 4.7260594d-06/
      data fxyz(12,14, 5),fxyz(12,14, 6)/-1.0689035d-05, 2.4975067d-05/
      data fxyz(12,14, 7),fxyz(12,14, 8)/-8.3625411d-05, 3.2084653d-04/
      data fxyz(12,14, 9),fxyz(12,14,10)/-5.2483214d-04, 3.3850763d-04/
      data fxyz(12,14,11),fxyz(12,14,12)/-9.0794609d-05, 2.4307088d-05/
      data fxyz(12,14,13),fxyz(12,14,14)/-6.4193861d-06, 1.6064033d-06/
      data fxyz(12,14,15),fxyz(12,14,16)/-3.9205881d-07, 1.0949969d-07/
      data fxyz(12,14,17),fxyz(12,14,18)/-7.0115275d-08, 9.0588654d-08/
      data fxyz(12,14,19),fxyz(12,14,20)/ 6.5729704d-08,-6.4877514d-08/
      data fxyz(12,14,21),fxyz(12,14,22)/-6.3164330d-08, 5.8876966d-08/
      data fxyz(12,14,23)/                1.1628642d-07/
      data fxyz(12,15, 1),fxyz(12,15, 2)/ 1.2169509d-06, 7.1741355d-07/
      data fxyz(12,15, 3),fxyz(12,15, 4)/ 3.6043333d-06,-3.3210413d-06/
      data fxyz(12,15, 5),fxyz(12,15, 6)/ 2.8418912d-05,-1.0266367d-04/
      data fxyz(12,15, 7),fxyz(12,15, 8)/ 3.2183051d-04,-1.2209420d-03/
      data fxyz(12,15, 9),fxyz(12,15,10)/ 1.9775245d-03,-1.2699052d-03/
      data fxyz(12,15,11),fxyz(12,15,12)/ 3.4018938d-04,-9.1027223d-05/
      data fxyz(12,15,13),fxyz(12,15,14)/ 2.4343545d-05,-6.4439170d-06/
      data fxyz(12,15,15),fxyz(12,15,16)/ 1.7323051d-06,-5.1650135d-07/
      data fxyz(12,15,17),fxyz(12,15,18)/ 1.8519455d-07,-4.7252711d-08/
      data fxyz(12,15,19),fxyz(12,15,20)/ 3.2487943d-08,-2.6455887d-08/
      data fxyz(12,15,21),fxyz(12,15,22)/-2.1365012d-08, 1.2124442d-08/
      data fxyz(12,15,23)/                2.9110420d-08/
      data fxyz(12,16, 1),fxyz(12,16, 2)/ 1.7414212d-05, 6.8627725d-06/
      data fxyz(12,16, 3),fxyz(12,16, 4)/-2.2327954d-05,-1.0812082d-05/
      data fxyz(12,16, 5),fxyz(12,16, 6)/-3.9200714d-05, 1.9015229d-04/
      data fxyz(12,16, 7),fxyz(12,16, 8)/-4.2517869d-04, 1.7365761d-03/
      data fxyz(12,16, 9),fxyz(12,16,10)/-3.0093457d-03, 1.9828559d-03/
      data fxyz(12,16,11),fxyz(12,16,12)/-5.2787366d-04, 1.4195424d-04/
      data fxyz(12,16,13),fxyz(12,16,14)/-3.7938164d-05, 1.0208743d-05/
      data fxyz(12,16,15),fxyz(12,16,16)/-2.7590128d-06, 7.9848796d-07/
      data fxyz(12,16,17),fxyz(12,16,18)/-2.4101166d-07, 1.3449279d-07/
      data fxyz(12,16,19),fxyz(12,16,20)/-9.9754790d-08, 1.1835732d-08/
      data fxyz(12,16,21),fxyz(12,16,22)/-1.7555568d-09,-4.5389634d-08/
      data fxyz(12,16,23)/               -6.9376548d-08/
      data fxyz(12,17, 1),fxyz(12,17, 2)/-5.0633139d-05,-1.3722339d-05/
      data fxyz(12,17, 3),fxyz(12,17, 4)/ 7.5606120d-05, 5.7696815d-05/
      data fxyz(12,17, 5),fxyz(12,17, 6)/ 5.7914878d-05,-3.1927270d-04/
      data fxyz(12,17, 7),fxyz(12,17, 8)/ 2.2933282d-04,-8.0568335d-04/
      data fxyz(12,17, 9),fxyz(12,17,10)/ 1.6879511d-03,-1.1930889d-03/
      data fxyz(12,17,11),fxyz(12,17,12)/ 3.1743223d-04,-8.5288051d-05/
      data fxyz(12,17,13),fxyz(12,17,14)/ 2.3009975d-05,-6.1620947d-06/
      data fxyz(12,17,15),fxyz(12,17,16)/ 1.7250043d-06,-4.9464722d-07/
      data fxyz(12,17,17),fxyz(12,17,18)/ 1.6829591d-07,-1.4568916d-07/
      data fxyz(12,17,19),fxyz(12,17,20)/ 1.0863201d-07,-1.8254756d-08/
      data fxyz(12,17,21),fxyz(12,17,22)/-3.3717665d-09, 4.9100046d-08/
      data fxyz(12,17,23)/                7.7555689d-08/
      data fxyz(12,18, 1),fxyz(12,18, 2)/ 5.3284578d-05, 1.3152067d-05/
      data fxyz(12,18, 3),fxyz(12,18, 4)/-8.1864687d-05,-6.6082286d-05/
      data fxyz(12,18, 5),fxyz(12,18, 6)/-4.9977541d-05, 2.9002061d-04/
      data fxyz(12,18, 7),fxyz(12,18, 8)/-1.1976066d-04, 6.5879531d-05/
      data fxyz(12,18, 9),fxyz(12,18,10)/-2.3812461d-04, 1.9887978d-04/
      data fxyz(12,18,11),fxyz(12,18,12)/-5.3688481d-05, 1.4326076d-05/
      data fxyz(12,18,13),fxyz(12,18,14)/-4.0039661d-06, 1.0766823d-06/
      data fxyz(12,18,15),fxyz(12,18,16)/-3.2804450d-07, 1.1750864d-07/
      data fxyz(12,18,17),fxyz(12,18,18)/-3.5580509d-08, 2.3201392d-08/
      data fxyz(12,18,19),fxyz(12,18,20)/ 2.5910614d-08,-3.1102699d-08/
      data fxyz(12,18,21),fxyz(12,18,22)/-2.9711144d-08, 2.0344392d-08/
      data fxyz(12,18,23)/                4.4074724d-08/
      data fxyz(12,19, 1),fxyz(12,19, 2)/ 1.0806942d-04, 2.6466610d-05/
      data fxyz(12,19, 3),fxyz(12,19, 4)/-1.6636267d-04,-1.3492196d-04/
      data fxyz(12,19, 5),fxyz(12,19, 6)/-9.9296243d-05, 5.7968012d-04/
      data fxyz(12,19, 7),fxyz(12,19, 8)/-1.8210986d-04,-3.7935391d-05/
      data fxyz(12,19, 9),fxyz(12,19,10)/-2.7180814d-04, 2.8573033d-04/
      data fxyz(12,19,11),fxyz(12,19,12)/-7.7258734d-05, 2.0552655d-05/
      data fxyz(12,19,13),fxyz(12,19,14)/-5.8858844d-06, 1.5698551d-06/
      data fxyz(12,19,15),fxyz(12,19,16)/-5.1336018d-07, 1.8529563d-07/
      data fxyz(12,19,17),fxyz(12,19,18)/-6.4261501d-08, 6.3785515d-08/
      data fxyz(12,19,19),fxyz(12,19,20)/ 2.6362990d-08,-4.8877084d-08/
      data fxyz(12,19,21),fxyz(12,19,22)/-4.8986759d-08, 2.6801691d-08/
      data fxyz(12,19,23)/                6.2140387d-08/
      data fxyz(13, 1, 1),fxyz(13, 1, 2)/-2.5557300d-03,-1.4930083d-03/
      data fxyz(13, 1, 3),fxyz(13, 1, 4)/ 6.2087554d-04, 9.0678547d-04/
      data fxyz(13, 1, 5),fxyz(13, 1, 6)/-2.6366480d-03, 1.7329190d-03/
      data fxyz(13, 1, 7),fxyz(13, 1, 8)/-5.0859079d-04, 1.8130331d-04/
      data fxyz(13, 1, 9),fxyz(13, 1,10)/-2.4802527d-05,-4.3142548d-05/
      data fxyz(13, 1,11),fxyz(13, 1,12)/ 6.6014653d-05,-4.5298596d-05/
      data fxyz(13, 1,13),fxyz(13, 1,14)/ 1.2240363d-04,-6.0844188d-04/
      data fxyz(13, 1,15),fxyz(13, 1,16)/ 9.5458946d-04,-4.5230497d-04/
      data fxyz(13, 1,17),fxyz(13, 1,18)/-2.6224534d-04, 1.4433888d-03/
      data fxyz(13, 1,19),fxyz(13, 1,20)/-2.3021816d-03, 8.0022396d-04/
      data fxyz(13, 1,21),fxyz(13, 1,22)/ 5.5370372d-04,-1.3161007d-03/
      data fxyz(13, 1,23)/               -2.2544148d-03/
      data fxyz(13, 2, 1),fxyz(13, 2, 2)/-1.3656884d-03,-7.9771501d-04/
      data fxyz(13, 2, 3),fxyz(13, 2, 4)/ 3.3179592d-04, 4.8505215d-04/
      data fxyz(13, 2, 5),fxyz(13, 2, 6)/-1.4107399d-03, 9.3315499d-04/
      data fxyz(13, 2, 7),fxyz(13, 2, 8)/-2.7647147d-04, 9.4670899d-05/
      data fxyz(13, 2, 9),fxyz(13, 2,10)/-1.3052750d-05,-2.0315902d-05/
      data fxyz(13, 2,11),fxyz(13, 2,12)/ 3.1549557d-05,-1.9683670d-05/
      data fxyz(13, 2,13),fxyz(13, 2,14)/ 4.8782867d-05,-2.5703437d-04/
      data fxyz(13, 2,15),fxyz(13, 2,16)/ 4.0488848d-04,-1.8130153d-04/
      data fxyz(13, 2,17),fxyz(13, 2,18)/-1.5818800d-04, 7.8753899d-04/
      data fxyz(13, 2,19),fxyz(13, 2,20)/-1.2428085d-03, 4.3133673d-04/
      data fxyz(13, 2,21),fxyz(13, 2,22)/ 2.9787398d-04,-7.0895749d-04/
      data fxyz(13, 2,23)/               -1.2144022d-03/
      data fxyz(13, 3, 1),fxyz(13, 3, 2)/ 5.7929295d-03, 3.3868354d-03/
      data fxyz(13, 3, 3),fxyz(13, 3, 4)/-1.3931904d-03,-2.0509981d-03/
      data fxyz(13, 3, 5),fxyz(13, 3, 6)/ 6.0180661d-03,-4.0741855d-03/
      data fxyz(13, 3, 7),fxyz(13, 3, 8)/ 1.2639447d-03,-4.6148190d-04/
      data fxyz(13, 3, 9),fxyz(13, 3,10)/ 1.4852339d-04,-3.7989023d-05/
      data fxyz(13, 3,11),fxyz(13, 3,12)/-2.1161508d-05, 5.2948983d-05/
      data fxyz(13, 3,13),fxyz(13, 3,14)/-1.5449039d-04, 6.5250925d-04/
      data fxyz(13, 3,15),fxyz(13, 3,16)/-1.0010626d-03, 3.6547648d-04/
      data fxyz(13, 3,17),fxyz(13, 3,18)/ 8.0222131d-04,-3.4803570d-03/
      data fxyz(13, 3,19),fxyz(13, 3,20)/ 5.3331766d-03,-1.8274932d-03/
      data fxyz(13, 3,21),fxyz(13, 3,22)/-1.2505069d-03, 3.0252311d-03/
      data fxyz(13, 3,23)/                5.1744386d-03/
      data fxyz(13, 4, 1),fxyz(13, 4, 2)/-7.9384698d-03,-4.6410143d-03/
      data fxyz(13, 4, 3),fxyz(13, 4, 4)/ 1.9074967d-03, 2.8130608d-03/
      data fxyz(13, 4, 5),fxyz(13, 4, 6)/-8.2632707d-03, 5.6449918d-03/
      data fxyz(13, 4, 7),fxyz(13, 4, 8)/-1.7746781d-03, 6.2568668d-04/
      data fxyz(13, 4, 9),fxyz(13, 4,10)/-2.1429273d-04, 8.6087039d-05/
      data fxyz(13, 4,11),fxyz(13, 4,12)/-1.0011679d-05,-3.8980411d-05/
      data fxyz(13, 4,13),fxyz(13, 4,14)/ 9.6020079d-05,-3.9142353d-04/
      data fxyz(13, 4,15),fxyz(13, 4,16)/ 5.8986159d-04,-5.2956532d-05/
      data fxyz(13, 4,17),fxyz(13, 4,18)/-1.2346013d-03, 4.8939086d-03/
      data fxyz(13, 4,19),fxyz(13, 4,20)/-7.3989803d-03, 2.5284764d-03/
      data fxyz(13, 4,21),fxyz(13, 4,22)/ 1.7250412d-03,-4.1852394d-03/
      data fxyz(13, 4,23)/               -7.1576197d-03/
      data fxyz(13, 5, 1),fxyz(13, 5, 2)/ 4.7010448d-03, 2.7484394d-03/
      data fxyz(13, 5, 3),fxyz(13, 5, 4)/-1.1286299d-03,-1.6660287d-03/
      data fxyz(13, 5, 5),fxyz(13, 5, 6)/ 4.8980347d-03,-3.3599376d-03/
      data fxyz(13, 5, 7),fxyz(13, 5, 8)/ 1.0585903d-03,-3.6180859d-04/
      data fxyz(13, 5, 9),fxyz(13, 5,10)/ 1.2180601d-04,-5.1776052d-05/
      data fxyz(13, 5,11),fxyz(13, 5,12)/ 1.0172240d-05, 1.2889184d-05/
      data fxyz(13, 5,13),fxyz(13, 5,14)/-1.5979832d-05, 7.6169693d-05/
      data fxyz(13, 5,15),fxyz(13, 5,16)/-1.1016979d-04,-1.0812459d-04/
      data fxyz(13, 5,17),fxyz(13, 5,18)/ 7.8035207d-04,-2.9668380d-03/
      data fxyz(13, 5,19),fxyz(13, 5,20)/ 4.4500696d-03,-1.5166354d-03/
      data fxyz(13, 5,21),fxyz(13, 5,22)/-1.0323932d-03, 2.5131006d-03/
      data fxyz(13, 5,23)/                4.2967956d-03/
      data fxyz(13, 6, 1),fxyz(13, 6, 2)/-1.2962508d-03,-7.5707477d-04/
      data fxyz(13, 6, 3),fxyz(13, 6, 4)/ 3.1413444d-04, 4.6142863d-04/
      data fxyz(13, 6, 5),fxyz(13, 6, 6)/-1.3462515d-03, 9.1316193d-04/
      data fxyz(13, 6, 7),fxyz(13, 6, 8)/-2.8521881d-04, 9.8012234d-05/
      data fxyz(13, 6, 9),fxyz(13, 6,10)/-3.2681950d-05, 1.3988330d-05/
      data fxyz(13, 6,11),fxyz(13, 6,12)/-2.7817847d-06,-3.4868017d-06/
      data fxyz(13, 6,13),fxyz(13, 6,14)/ 4.2463151d-06,-2.0364130d-05/
      data fxyz(13, 6,15),fxyz(13, 6,16)/ 2.9152850d-05, 3.1258705d-05/
      data fxyz(13, 6,17),fxyz(13, 6,18)/-2.1701613d-04, 8.2684294d-04/
      data fxyz(13, 6,19),fxyz(13, 6,20)/-1.2321093d-03, 4.1663660d-04/
      data fxyz(13, 6,21),fxyz(13, 6,22)/ 2.8237867d-04,-6.9507762d-04/
      data fxyz(13, 6,23)/               -1.1870260d-03/
      data fxyz(13, 7, 1),fxyz(13, 7, 2)/ 4.5401333d-04, 2.5956780d-04/
      data fxyz(13, 7, 3),fxyz(13, 7, 4)/-1.3015232d-04,-1.7731286d-04/
      data fxyz(13, 7, 5),fxyz(13, 7, 6)/ 4.4820996d-04,-2.5339477d-04/
      data fxyz(13, 7, 7),fxyz(13, 7, 8)/ 7.6379991d-05,-2.6768676d-05/
      data fxyz(13, 7, 9),fxyz(13, 7,10)/ 8.3903113d-06,-3.6096767d-06/
      data fxyz(13, 7,11),fxyz(13, 7,12)/ 6.1200492d-07, 1.0139601d-06/
      data fxyz(13, 7,13),fxyz(13, 7,14)/-1.2728616d-06, 5.6304107d-06/
      data fxyz(13, 7,15),fxyz(13, 7,16)/-8.1629780d-06,-8.5246607d-06/
      data fxyz(13, 7,17),fxyz(13, 7,18)/ 5.7968461d-05,-2.2262964d-04/
      data fxyz(13, 7,19),fxyz(13, 7,20)/ 3.3170057d-04,-1.1155823d-04/
      data fxyz(13, 7,21),fxyz(13, 7,22)/-7.5426066d-05, 1.8717190d-04/
      data fxyz(13, 7,23)/                3.1935286d-04/
      data fxyz(13, 8, 1),fxyz(13, 8, 2)/-8.8766515d-04,-4.7880311d-04/
      data fxyz(13, 8, 3),fxyz(13, 8, 4)/ 3.5668338d-04, 4.2781464d-04/
      data fxyz(13, 8, 5),fxyz(13, 8, 6)/-7.6332814d-04, 1.7930369d-04/
      data fxyz(13, 8, 7),fxyz(13, 8, 8)/-4.4798797d-05, 1.3817175d-05/
      data fxyz(13, 8, 9),fxyz(13, 8,10)/-3.7035838d-06, 9.2450733d-07/
      data fxyz(13, 8,11),fxyz(13, 8,12)/-1.4689557d-07,-3.1583264d-07/
      data fxyz(13, 8,13),fxyz(13, 8,14)/ 4.3885708d-07,-1.7831590d-06/
      data fxyz(13, 8,15),fxyz(13, 8,16)/ 2.3925158d-06, 2.1598836d-06/
      data fxyz(13, 8,17),fxyz(13, 8,18)/-1.5479218d-05, 5.9662104d-05/
      data fxyz(13, 8,19),fxyz(13, 8,20)/-8.8400749d-05, 2.9640320d-05/
      data fxyz(13, 8,21),fxyz(13, 8,22)/ 1.9997187d-05,-4.9828214d-05/
      data fxyz(13, 8,23)/               -8.4984903d-05/
      data fxyz(13, 9, 1),fxyz(13, 9, 2)/ 1.4400050d-03, 7.6697881d-04/
      data fxyz(13, 9, 3),fxyz(13, 9, 4)/-6.1404670d-04,-7.2110029d-04/
      data fxyz(13, 9, 5),fxyz(13, 9, 6)/ 1.1951932d-03,-1.6579879d-04/
      data fxyz(13, 9, 7),fxyz(13, 9, 8)/ 2.3070716d-05,-7.5197413d-06/
      data fxyz(13, 9, 9),fxyz(13, 9,10)/ 1.0392025d-06, 1.2930095d-07/
      data fxyz(13, 9,11),fxyz(13, 9,12)/-1.5493878d-07, 8.2456274d-08/
      data fxyz(13, 9,13),fxyz(13, 9,14)/-2.0971949d-07, 5.7456643d-07/
      data fxyz(13, 9,15),fxyz(13, 9,16)/-7.0725458d-07,-5.4254879d-07/
      data fxyz(13, 9,17),fxyz(13, 9,18)/ 4.1343134d-06,-1.5962909d-05/
      data fxyz(13, 9,19),fxyz(13, 9,20)/ 2.3792677d-05,-8.0123142d-06/
      data fxyz(13, 9,21),fxyz(13, 9,22)/-5.4206409d-06, 1.3425984d-05/
      data fxyz(13, 9,23)/                2.2912189d-05/
      data fxyz(13,10, 1),fxyz(13,10, 2)/-7.8506401d-04,-4.0922485d-04/
      data fxyz(13,10, 3),fxyz(13,10, 4)/ 3.6715312d-04, 4.1788854d-04/
      data fxyz(13,10, 5),fxyz(13,10, 6)/-6.1216654d-04,-2.4032665d-05/
      data fxyz(13,10, 7),fxyz(13,10, 8)/ 3.9392723d-05,-1.6257155d-05/
      data fxyz(13,10, 9),fxyz(13,10,10)/ 6.1622679d-06,-3.5851614d-06/
      data fxyz(13,10,11),fxyz(13,10,12)/ 8.6162820d-07,-3.3286843d-07/
      data fxyz(13,10,13),fxyz(13,10,14)/ 1.3680952d-07,-1.8851378d-07/
      data fxyz(13,10,15),fxyz(13,10,16)/ 1.9076543d-07, 1.5823824d-07/
      data fxyz(13,10,17),fxyz(13,10,18)/-1.1561008d-06, 4.3249319d-06/
      data fxyz(13,10,19),fxyz(13,10,20)/-6.3513743d-06, 2.1022424d-06/
      data fxyz(13,10,21),fxyz(13,10,22)/ 1.4081921d-06,-3.5751729d-06/
      data fxyz(13,10,23)/               -6.0858233d-06/
      data fxyz(13,11, 1),fxyz(13,11, 2)/ 9.6610474d-05, 4.3143043d-05/
      data fxyz(13,11, 3),fxyz(13,11, 4)/-7.0876046d-05,-7.1845505d-05/
      data fxyz(13,11, 5),fxyz(13,11, 6)/ 4.7020881d-05, 8.2068582d-05/
      data fxyz(13,11, 7),fxyz(13,11, 8)/-3.7613916d-05, 2.7243339d-05/
      data fxyz(13,11, 9),fxyz(13,11,10)/-1.9474676d-05, 1.0681020d-05/
      data fxyz(13,11,11),fxyz(13,11,12)/-3.0337303d-06, 7.8963412d-07/
      data fxyz(13,11,13),fxyz(13,11,14)/-2.3995086d-07, 1.0357439d-07/
      data fxyz(13,11,15),fxyz(13,11,16)/-6.7451447d-08,-7.9454077d-08/
      data fxyz(13,11,17),fxyz(13,11,18)/ 3.6435164d-07,-1.1912541d-06/
      data fxyz(13,11,19),fxyz(13,11,20)/ 1.6092545d-06,-5.3013853d-07/
      data fxyz(13,11,21),fxyz(13,11,22)/-3.4981138d-07, 8.8794585d-07/
      data fxyz(13,11,23)/                1.5136531d-06/
      data fxyz(13,12, 1),fxyz(13,12, 2)/-2.5298111d-05,-1.1464246d-05/
      data fxyz(13,12, 3),fxyz(13,12, 4)/ 1.7973901d-05, 1.8334142d-05/
      data fxyz(13,12, 5),fxyz(13,12, 6)/-1.2905209d-05,-1.9894497d-05/
      data fxyz(13,12, 7),fxyz(13,12, 8)/ 1.3777821d-05,-3.8587815d-05/
      data fxyz(13,12, 9),fxyz(13,12,10)/ 6.0064190d-05,-3.7677543d-05/
      data fxyz(13,12,11),fxyz(13,12,12)/ 1.0071234d-05,-2.7575332d-06/
      data fxyz(13,12,13),fxyz(13,12,14)/ 6.8152225d-07,-1.7350513d-07/
      data fxyz(13,12,15),fxyz(13,12,16)/ 3.1210706d-08, 7.5243266d-08/
      data fxyz(13,12,17),fxyz(13,12,18)/-1.6789600d-07, 2.9205231d-07/
      data fxyz(13,12,19),fxyz(13,12,20)/-4.2160925d-07, 1.5114989d-07/
      data fxyz(13,12,21),fxyz(13,12,22)/ 1.0458585d-07,-2.3535308d-07/
      data fxyz(13,12,23)/               -4.0640833d-07/
      data fxyz(13,13, 1),fxyz(13,13, 2)/ 1.7012156d-06, 7.0547700d-07/
      data fxyz(13,13, 3),fxyz(13,13, 4)/-1.8020950d-06,-1.1478638d-06/
      data fxyz(13,13, 5),fxyz(13,13, 6)/-1.9114477d-06, 1.1514683d-05/
      data fxyz(13,13, 7),fxyz(13,13, 8)/-3.5780601d-05, 1.3494235d-04/
      data fxyz(13,13, 9),fxyz(13,13,10)/-2.1670967d-04, 1.3940257d-04/
      data fxyz(13,13,11),fxyz(13,13,12)/-3.7438792d-05, 1.0051329d-05/
      data fxyz(13,13,13),fxyz(13,13,14)/-2.6422893d-06, 6.1007591d-07/
      data fxyz(13,13,15),fxyz(13,13,16)/-1.1984184d-07,-2.7381847d-08/
      data fxyz(13,13,17),fxyz(13,13,18)/ 9.1211824d-08,-7.7582096d-08/
      data fxyz(13,13,19),fxyz(13,13,20)/ 3.8976850d-08,-3.9206823d-09/
      data fxyz(13,13,21),fxyz(13,13,22)/ 2.5624408d-09, 1.3044357d-08/
      data fxyz(13,13,23)/                1.9664751d-08/
      data fxyz(13,14, 1),fxyz(13,14, 2)/-7.5865466d-06,-4.0301105d-06/
      data fxyz(13,14, 3),fxyz(13,14, 4)/ 4.4596929d-06, 2.9391724d-06/
      data fxyz(13,14, 5),fxyz(13,14, 6)/ 2.0519714d-06,-3.0394354d-05/
      data fxyz(13,14, 7),fxyz(13,14, 8)/ 1.2243263d-04,-4.9978216d-04/
      data fxyz(13,14, 9),fxyz(13,14,10)/ 8.1171178d-04,-5.2105319d-04/
      data fxyz(13,14,11),fxyz(13,14,12)/ 1.3962929d-04,-3.7419129d-05/
      data fxyz(13,14,13),fxyz(13,14,14)/ 9.9753406d-06,-2.5785405d-06/
      data fxyz(13,14,15),fxyz(13,14,16)/ 6.0321337d-07,-1.4493701d-07/
      data fxyz(13,14,17),fxyz(13,14,18)/ 4.4164730d-08, 2.8103858d-09/
      data fxyz(13,14,19),fxyz(13,14,20)/ 7.3215078d-08,-4.6465526d-08/
      data fxyz(13,14,21),fxyz(13,14,22)/-4.0472378d-08, 4.9242488d-08/
      data fxyz(13,14,23)/                9.2707598d-08/
      data fxyz(13,15, 1),fxyz(13,15, 2)/ 1.1606049d-05, 8.1831107d-06/
      data fxyz(13,15, 3),fxyz(13,15, 4)/-2.6682184d-06, 3.4855899d-06/
      data fxyz(13,15, 5),fxyz(13,15, 6)/-1.6432123d-05, 1.0391317d-04/
      data fxyz(13,15, 7),fxyz(13,15, 8)/-4.5970215d-04, 1.8583464d-03/
      data fxyz(13,15, 9),fxyz(13,15,10)/-3.0193695d-03, 1.9395601d-03/
      data fxyz(13,15,11),fxyz(13,15,12)/-5.1938902d-04, 1.3930555d-04/
      data fxyz(13,15,13),fxyz(13,15,14)/-3.7277897d-05, 9.9430510d-06/
      data fxyz(13,15,15),fxyz(13,15,16)/-2.6353589d-06, 7.2023513d-07/
      data fxyz(13,15,17),fxyz(13,15,18)/-2.2886775d-07, 1.4227505d-07/
      data fxyz(13,15,19),fxyz(13,15,20)/-8.2446932d-08, 9.0610327d-09/
      data fxyz(13,15,21),fxyz(13,15,22)/-3.6332252d-09,-3.1669901d-08/
      data fxyz(13,15,23)/               -4.8138818d-08/
      data fxyz(13,16, 1),fxyz(13,16, 2)/-5.1810826d-06,-6.8744105d-06/
      data fxyz(13,16, 3),fxyz(13,16, 4)/-9.6311081d-07,-1.7657865d-05/
      data fxyz(13,16, 5),fxyz(13,16, 6)/ 5.9904607d-05,-2.5560240d-04/
      data fxyz(13,16, 7),fxyz(13,16, 8)/ 7.8555948d-04,-2.7987576d-03/
      data fxyz(13,16, 9),fxyz(13,16,10)/ 4.6019343d-03,-3.0096055d-03/
      data fxyz(13,16,11),fxyz(13,16,12)/ 8.0784932d-04,-2.1614830d-04/
      data fxyz(13,16,13),fxyz(13,16,14)/ 5.8012121d-05,-1.5502995d-05/
      data fxyz(13,16,15),fxyz(13,16,16)/ 4.1825739d-06,-1.1432130d-06/
      data fxyz(13,16,17),fxyz(13,16,18)/ 3.6420912d-07,-2.6303667d-07/
      data fxyz(13,16,19),fxyz(13,16,20)/ 2.6488033d-07,-9.1713565d-08/
      data fxyz(13,16,21),fxyz(13,16,22)/-5.8754982d-08, 1.3304599d-07/
      data fxyz(13,16,23)/                2.3134207d-07/
      data fxyz(13,17, 1),fxyz(13,17, 2)/ 9.1002066d-06, 6.3457343d-06/
      data fxyz(13,17, 3),fxyz(13,17, 4)/-1.2524048d-05, 1.0168800d-05/
      data fxyz(13,17, 5),fxyz(13,17, 6)/-8.4425654d-05, 3.4949291d-04/
      data fxyz(13,17, 7),fxyz(13,17, 8)/-6.1033293d-04, 1.5451381d-03/
      data fxyz(13,17, 9),fxyz(13,17,10)/-2.6376247d-03, 1.8140691d-03/
      data fxyz(13,17,11),fxyz(13,17,12)/-4.8693716d-04, 1.3043538d-04/
      data fxyz(13,17,13),fxyz(13,17,14)/-3.4941786d-05, 9.3932139d-06/
      data fxyz(13,17,15),fxyz(13,17,16)/-2.5113075d-06, 7.2278631d-07/
      data fxyz(13,17,17),fxyz(13,17,18)/-2.5012003d-07, 2.4039430d-07/
      data fxyz(13,17,19),fxyz(13,17,20)/-2.7571436d-07, 8.6296560d-08/
      data fxyz(13,17,21),fxyz(13,17,22)/ 5.3778502d-08,-1.4564213d-07/
      data fxyz(13,17,23)/               -2.4737657d-07/
      data fxyz(13,18, 1),fxyz(13,18, 2)/-1.1291252d-05,-3.7789388d-06/
      data fxyz(13,18, 3),fxyz(13,18, 4)/ 1.8497303d-05, 7.6850542d-06/
      data fxyz(13,18, 5),fxyz(13,18, 6)/ 3.9470057d-05,-1.7347499d-04/
      data fxyz(13,18, 7),fxyz(13,18, 8)/ 1.7951342d-04,-2.1405094d-04/
      data fxyz(13,18, 9),fxyz(13,18,10)/ 3.9765831d-04,-3.0901141d-04/
      data fxyz(13,18,11),fxyz(13,18,12)/ 8.2438195d-05,-2.2330021d-05/
      data fxyz(13,18,13),fxyz(13,18,14)/ 5.9486284d-06,-1.6241661d-06/
      data fxyz(13,18,15),fxyz(13,18,16)/ 4.5791710d-07,-1.5841872d-07/
      data fxyz(13,18,17),fxyz(13,18,18)/ 6.0726373d-08,-5.2839409d-08/
      data fxyz(13,18,19),fxyz(13,18,20)/ 5.2962847d-08,-2.0878637d-08/
      data fxyz(13,18,21),fxyz(13,18,22)/-1.4220649d-08, 2.6330895d-08/
      data fxyz(13,18,23)/                4.7030412d-08/
      data fxyz(13,19, 1),fxyz(13,19, 2)/-2.1776211d-05,-7.2336639d-06/
      data fxyz(13,19, 3),fxyz(13,19, 4)/ 3.7352286d-05, 1.3861426d-05/
      data fxyz(13,19, 5),fxyz(13,19, 6)/ 8.6729776d-05,-3.7413911d-04/
      data fxyz(13,19, 7),fxyz(13,19, 8)/ 3.4486299d-04,-2.2950148d-04/
      data fxyz(13,19, 9),fxyz(13,19,10)/ 4.9727216d-04,-4.4730474d-04/
      data fxyz(13,19,11),fxyz(13,19,12)/ 1.1919588d-04,-3.2424256d-05/
      data fxyz(13,19,13),fxyz(13,19,14)/ 8.5978082d-06,-2.3805206d-06/
      data fxyz(13,19,15),fxyz(13,19,16)/ 6.6625425d-07,-2.5470822d-07/
      data fxyz(13,19,17),fxyz(13,19,18)/ 1.0723691d-07,-1.1845464d-07/
      data fxyz(13,19,19),fxyz(13,19,20)/ 1.3327666d-07,-4.6572313d-08/
      data fxyz(13,19,21),fxyz(13,19,22)/-3.0639047d-08, 6.9543590d-08/
      data fxyz(13,19,23)/                1.2054436d-07/
      data fxyz(14, 1, 1),fxyz(14, 1, 2)/ 6.4037969d-03, 3.7592822d-03/
      data fxyz(14, 1, 3),fxyz(14, 1, 4)/-1.4840477d-03,-2.2251509d-03/
      data fxyz(14, 1, 5),fxyz(14, 1, 6)/ 6.7236948d-03,-4.7127504d-03/
      data fxyz(14, 1, 7),fxyz(14, 1, 8)/ 1.4036180d-03,-3.9919775d-04/
      data fxyz(14, 1, 9),fxyz(14, 1,10)/ 6.4061670d-05, 1.2960123d-04/
      data fxyz(14, 1,11),fxyz(14, 1,12)/-1.4681915d-04,-7.6520932d-05/
      data fxyz(14, 1,13),fxyz(14, 1,14)/ 1.2973308d-04, 7.3929230d-05/
      data fxyz(14, 1,15),fxyz(14, 1,16)/-1.3477422d-04,-2.0027948d-04/
      data fxyz(14, 1,17),fxyz(14, 1,18)/ 1.1351920d-03,-4.0761078d-03/
      data fxyz(14, 1,19),fxyz(14, 1,20)/ 5.8867483d-03,-1.9499619d-03/
      data fxyz(14, 1,21),fxyz(14, 1,22)/-1.3034435d-03, 3.3006748d-03/
      data fxyz(14, 1,23)/                5.6216682d-03/
      data fxyz(14, 2, 1),fxyz(14, 2, 2)/ 2.8251925d-03, 1.6581066d-03/
      data fxyz(14, 2, 3),fxyz(14, 2, 4)/-6.5564448d-04,-9.8315220d-04/
      data fxyz(14, 2, 5),fxyz(14, 2, 6)/ 2.9681375d-03,-2.0874233d-03/
      data fxyz(14, 2, 7),fxyz(14, 2, 8)/ 6.3916187d-04,-1.8793154d-04/
      data fxyz(14, 2, 9),fxyz(14, 2,10)/ 2.7834499d-05, 6.3775267d-05/
      data fxyz(14, 2,11),fxyz(14, 2,12)/-7.1849277d-05,-3.7878722d-05/
      data fxyz(14, 2,13),fxyz(14, 2,14)/ 6.5676669d-05, 2.6930489d-05/
      data fxyz(14, 2,15),fxyz(14, 2,16)/-5.6168013d-05,-8.9230798d-05/
      data fxyz(14, 2,17),fxyz(14, 2,18)/ 4.9652606d-04,-1.7888157d-03/
      data fxyz(14, 2,19),fxyz(14, 2,20)/ 2.5902442d-03,-8.5879109d-04/
      data fxyz(14, 2,21),fxyz(14, 2,22)/-5.7452164d-04, 1.4531664d-03/
      data fxyz(14, 2,23)/                2.4752261d-03/
      data fxyz(14, 3, 1),fxyz(14, 3, 2)/-7.8614607d-03,-4.6106927d-03/
      data fxyz(14, 3, 3),fxyz(14, 3, 4)/ 1.8300157d-03, 2.7491560d-03/
      data fxyz(14, 3, 5),fxyz(14, 3, 6)/-8.2872541d-03, 5.9256443d-03/
      data fxyz(14, 3, 7),fxyz(14, 3, 8)/-2.0181695d-03, 7.2763151d-04/
      data fxyz(14, 3, 9),fxyz(14, 3,10)/-1.9574101d-04,-1.1365237d-05/
      data fxyz(14, 3,11),fxyz(14, 3,12)/ 5.5151911d-05, 2.9902185d-05/
      data fxyz(14, 3,13),fxyz(14, 3,14)/-4.0326216d-05,-1.1713102d-04/
      data fxyz(14, 3,15),fxyz(14, 3,16)/ 1.4635107d-04, 2.4346663d-04/
      data fxyz(14, 3,17),fxyz(14, 3,18)/-1.3310246d-03, 4.8387919d-03/
      data fxyz(14, 3,19),fxyz(14, 3,20)/-7.0302763d-03, 2.3359708d-03/
      data fxyz(14, 3,21),fxyz(14, 3,22)/ 1.5650855d-03,-3.9467351d-03/
      data fxyz(14, 3,23)/               -6.7244874d-03/
      data fxyz(14, 4, 1),fxyz(14, 4, 2)/ 6.3300567d-03, 3.7071911d-03/
      data fxyz(14, 4, 3),fxyz(14, 4, 4)/-1.4847234d-03,-2.2346192d-03/
      data fxyz(14, 4, 5),fxyz(14, 4, 6)/ 6.7067742d-03,-4.9183799d-03/
      data fxyz(14, 4, 7),fxyz(14, 4, 8)/ 1.9495623d-03,-8.2184438d-04/
      data fxyz(14, 4, 9),fxyz(14, 4,10)/ 2.3640267d-04,-5.3904854d-05/
      data fxyz(14, 4,11),fxyz(14, 4,12)/ 4.3485412d-08,-4.3023488d-06/
      data fxyz(14, 4,13),fxyz(14, 4,14)/ 4.8354104d-07, 7.8527164d-05/
      data fxyz(14, 4,15),fxyz(14, 4,16)/-8.4824907d-05,-1.9960656d-04/
      data fxyz(14, 4,17),fxyz(14, 4,18)/ 1.0025215d-03,-3.7247049d-03/
      data fxyz(14, 4,19),fxyz(14, 4,20)/ 5.4832607d-03,-1.8318362d-03/
      data fxyz(14, 4,21),fxyz(14, 4,22)/-1.2327059d-03, 3.0867396d-03/
      data fxyz(14, 4,23)/                5.2622490d-03/
      data fxyz(14, 5, 1),fxyz(14, 5, 2)/-2.3629427d-03,-1.3801935d-03/
      data fxyz(14, 5, 3),fxyz(14, 5, 4)/ 5.6326191d-04, 8.4752455d-04/
      data fxyz(14, 5, 5),fxyz(14, 5, 6)/-2.5172441d-03, 1.9009969d-03/
      data fxyz(14, 5, 7),fxyz(14, 5, 8)/-8.9107923d-04, 4.2132735d-04/
      data fxyz(14, 5, 9),fxyz(14, 5,10)/-1.1852333d-04, 3.3209328d-05/
      data fxyz(14, 5,11),fxyz(14, 5,12)/-4.6027668d-06, 1.3661058d-06/
      data fxyz(14, 5,13),fxyz(14, 5,14)/-2.6771878d-06,-1.3093814d-05/
      data fxyz(14, 5,15),fxyz(14, 5,16)/ 1.2424576d-05, 8.3281033d-05/
      data fxyz(14, 5,17),fxyz(14, 5,18)/-3.6245270d-04, 1.3908219d-03/
      data fxyz(14, 5,19),fxyz(14, 5,20)/-2.0973459d-03, 7.0864740d-04/
      data fxyz(14, 5,21),fxyz(14, 5,22)/ 4.8091173d-04,-1.1864033d-03/
      data fxyz(14, 5,23)/               -2.0252131d-03/
      data fxyz(14, 6, 1),fxyz(14, 6, 2)/ 5.2692575d-04, 3.0973908d-04/
      data fxyz(14, 6, 3),fxyz(14, 6, 4)/-1.1804695d-04,-1.8387144d-04/
      data fxyz(14, 6, 5),fxyz(14, 6, 6)/ 5.7303701d-04,-4.6044150d-04/
      data fxyz(14, 6, 7),fxyz(14, 6, 8)/ 2.2710987d-04,-1.0944217d-04/
      data fxyz(14, 6, 9),fxyz(14, 6,10)/ 3.0926805d-05,-8.6593742d-06/
      data fxyz(14, 6,11),fxyz(14, 6,12)/ 1.1430004d-06,-3.8135125d-07/
      data fxyz(14, 6,13),fxyz(14, 6,14)/ 7.1256823d-07, 3.2260111d-06/
      data fxyz(14, 6,15),fxyz(14, 6,16)/-2.2279008d-06,-2.6146291d-05/
      data fxyz(14, 6,17),fxyz(14, 6,18)/ 1.1111007d-04,-4.2262365d-04/
      data fxyz(14, 6,19),fxyz(14, 6,20)/ 6.4032902d-04,-2.1797534d-04/
      data fxyz(14, 6,21),fxyz(14, 6,22)/-1.4850566d-04, 3.6245028d-04/
      data fxyz(14, 6,23)/                6.1942163d-04/
      data fxyz(14, 7, 1),fxyz(14, 7, 2)/ 2.1162403d-04, 1.1021321d-04/
      data fxyz(14, 7, 3),fxyz(14, 7, 4)/-9.9861084d-05,-1.1252166d-04/
      data fxyz(14, 7, 5),fxyz(14, 7, 6)/ 1.6085553d-04, 2.1715324d-05/
      data fxyz(14, 7, 7),fxyz(14, 7, 8)/-3.4676846d-05, 2.1606089d-05/
      data fxyz(14, 7, 9),fxyz(14, 7,10)/-6.3048603d-06, 1.4646884d-06/
      data fxyz(14, 7,11),fxyz(14, 7,12)/-5.7000678d-08, 4.4895593d-08/
      data fxyz(14, 7,13),fxyz(14, 7,14)/-1.2483033d-07,-9.8559697d-07/
      data fxyz(14, 7,15),fxyz(14, 7,16)/ 3.0669133d-07, 7.2303474d-06/
      data fxyz(14, 7,17),fxyz(14, 7,18)/-3.0217852d-05, 1.1262690d-04/
      data fxyz(14, 7,19),fxyz(14, 7,20)/-1.6983714d-04, 5.8045334d-05/
      data fxyz(14, 7,21),fxyz(14, 7,22)/ 3.9589202d-05,-9.6012607d-05/
      data fxyz(14, 7,23)/               -1.6421509d-04/
      data fxyz(14, 8, 1),fxyz(14, 8, 2)/ 5.2950402d-05, 2.3087059d-05/
      data fxyz(14, 8, 3),fxyz(14, 8, 4)/-4.0302425d-05,-4.1358365d-05/
      data fxyz(14, 8, 5),fxyz(14, 8, 6)/ 2.7310819d-05, 3.7111303d-05/
      data fxyz(14, 8, 7),fxyz(14, 8, 8)/-3.5718544d-07,-2.7583245d-06/
      data fxyz(14, 8, 9),fxyz(14, 8,10)/ 4.4368980d-07, 1.2815281d-07/
      data fxyz(14, 8,11),fxyz(14, 8,12)/-2.0408118d-07,-6.4254119d-08/
      data fxyz(14, 8,13),fxyz(14, 8,14)/-4.7060651d-08, 3.3386280d-07/
      data fxyz(14, 8,15),fxyz(14, 8,16)/-5.2317606d-08,-2.1075251d-06/
      data fxyz(14, 8,17),fxyz(14, 8,18)/ 8.2228240d-06,-3.0183555d-05/
      data fxyz(14, 8,19),fxyz(14, 8,20)/ 4.5928232d-05,-1.5786005d-05/
      data fxyz(14, 8,21),fxyz(14, 8,22)/-1.0806016d-05, 2.6008276d-05/
      data fxyz(14, 8,23)/                4.4516277d-05/
      data fxyz(14, 9, 1),fxyz(14, 9, 2)/-7.0741156d-04,-3.5836140d-04/
      data fxyz(14, 9, 3),fxyz(14, 9, 4)/ 3.6570872d-04, 4.0752408d-04/
      data fxyz(14, 9, 5),fxyz(14, 9, 6)/-5.2562282d-04,-8.0181225d-05/
      data fxyz(14, 9, 7),fxyz(14, 9, 8)/ 1.0816210d-05,-3.0707062d-06/
      data fxyz(14, 9, 9),fxyz(14, 9,10)/ 1.3884336d-06,-8.0921006d-07/
      data fxyz(14, 9,11),fxyz(14, 9,12)/ 1.7440964d-07, 5.5913132d-09/
      data fxyz(14, 9,13),fxyz(14, 9,14)/-4.8374997d-09,-1.5211708d-07/
      data fxyz(14, 9,15),fxyz(14, 9,16)/ 2.8393980d-08, 5.9307808d-07/
      data fxyz(14, 9,17),fxyz(14, 9,18)/-2.2013981d-06, 8.1637699d-06/
      data fxyz(14, 9,19),fxyz(14, 9,20)/-1.2258745d-05, 4.1518861d-06/
      data fxyz(14, 9,21),fxyz(14, 9,22)/ 2.8189363d-06,-6.9269458d-06/
      data fxyz(14, 9,23)/               -1.1830477d-05/
      data fxyz(14,10, 1),fxyz(14,10, 2)/ 2.3764788d-04, 9.1861716d-05/
      data fxyz(14,10, 3),fxyz(14,10, 4)/-2.2398803d-04,-2.1794909d-04/
      data fxyz(14,10, 5),fxyz(14,10, 6)/ 6.7705958d-05, 3.2823198d-04/
      data fxyz(14,10, 7),fxyz(14,10, 8)/-8.0312132d-05, 1.9528005d-05/
      data fxyz(14,10, 9),fxyz(14,10,10)/-8.3830360d-06, 2.9572993d-06/
      data fxyz(14,10,11),fxyz(14,10,12)/-8.9843496d-07, 1.8202498d-07/
      data fxyz(14,10,13),fxyz(14,10,14)/-4.7034944d-08, 4.8821886d-08/
      data fxyz(14,10,15),fxyz(14,10,16)/ 2.6721579d-08,-2.3810722d-07/
      data fxyz(14,10,17),fxyz(14,10,18)/ 6.3022733d-07,-2.2420428d-06/
      data fxyz(14,10,19),fxyz(14,10,20)/ 3.3482188d-06,-1.1490043d-06/
      data fxyz(14,10,21),fxyz(14,10,22)/-7.8402174d-07, 1.8882886d-06/
      data fxyz(14,10,23)/                3.2326954d-06/
      data fxyz(14,11, 1),fxyz(14,11, 2)/ 1.7189424d-04, 1.1408300d-04/
      data fxyz(14,11, 3),fxyz(14,11, 4)/ 7.2979940d-06,-2.2620410d-05/
      data fxyz(14,11, 5),fxyz(14,11, 6)/ 2.3375661d-04,-2.7688182d-04/
      data fxyz(14,11, 7),fxyz(14,11, 8)/ 8.0923844d-05,-2.1838581d-05/
      data fxyz(14,11, 9),fxyz(14,11,10)/ 1.4238029d-05,-7.6894943d-06/
      data fxyz(14,11,11),fxyz(14,11,12)/ 1.9725692d-06,-5.9033024d-07/
      data fxyz(14,11,13),fxyz(14,11,14)/ 1.1129376d-07,-1.6222023d-08/
      data fxyz(14,11,15),fxyz(14,11,16)/-1.6128723d-08, 1.0359998d-07/
      data fxyz(14,11,17),fxyz(14,11,18)/-2.3757387d-07, 6.2883198d-07/
      data fxyz(14,11,19),fxyz(14,11,20)/-9.4415187d-07, 3.1434179d-07/
      data fxyz(14,11,21),fxyz(14,11,22)/ 2.1179681d-07,-5.3397195d-07/
      data fxyz(14,11,23)/               -9.0934270d-07/
      data fxyz(14,12, 1),fxyz(14,12, 2)/-1.4562514d-05,-1.2806652d-05/
      data fxyz(14,12, 3),fxyz(14,12, 4)/-1.1891801d-05,-6.9083071d-06/
      data fxyz(14,12, 5),fxyz(14,12, 6)/-3.2740628d-05, 6.0189894d-05/
      data fxyz(14,12, 7),fxyz(14,12, 8)/-2.2814043d-05, 2.5373916d-05/
      data fxyz(14,12, 9),fxyz(14,12,10)/-3.6553592d-05, 2.3645716d-05/
      data fxyz(14,12,11),fxyz(14,12,12)/-6.3854674d-06, 1.6906760d-06/
      data fxyz(14,12,13),fxyz(14,12,14)/-4.3531834d-07, 8.9791448d-08/
      data fxyz(14,12,15),fxyz(14,12,16)/-1.2543527d-08,-8.3885604d-08/
      data fxyz(14,12,17),fxyz(14,12,18)/ 1.5793279d-07,-1.7642797d-07/
      data fxyz(14,12,19),fxyz(14,12,20)/ 1.0623965d-07,-2.2706569d-08/
      data fxyz(14,12,21),fxyz(14,12,22)/-6.4323983d-09, 4.1142970d-08/
      data fxyz(14,12,23)/                6.7684587d-08/
      data fxyz(14,13, 1),fxyz(14,13, 2)/-3.9829171d-06,-9.5720269d-07/
      data fxyz(14,13, 3),fxyz(14,13, 4)/ 5.5336185d-06, 5.5211103d-06/
      data fxyz(14,13, 5),fxyz(14,13, 6)/-9.0716972d-07,-4.1705407d-06/
      data fxyz(14,13, 7),fxyz(14,13, 8)/ 4.6876674d-06,-7.2848125d-05/
      data fxyz(14,13, 9),fxyz(14,13,10)/ 1.3390915d-04,-8.7431242d-05/
      data fxyz(14,13,11),fxyz(14,13,12)/ 2.3439173d-05,-6.2677590d-06/
      data fxyz(14,13,13),fxyz(14,13,14)/ 1.6514903d-06,-4.2806416d-07/
      data fxyz(14,13,15),fxyz(14,13,16)/ 5.5232758d-08, 7.2027606d-08/
      data fxyz(14,13,17),fxyz(14,13,18)/-8.8512382d-08, 1.0789517d-08/
      data fxyz(14,13,19),fxyz(14,13,20)/ 9.5486876d-08,-4.5212111d-08/
      data fxyz(14,13,21),fxyz(14,13,22)/-3.8074917d-08, 6.6938100d-08/
      data fxyz(14,13,23)/                1.1784743d-07/
      data fxyz(14,14, 1),fxyz(14,14, 2)/-1.3145391d-05,-6.2522051d-06/
      data fxyz(14,14, 3),fxyz(14,14, 4)/ 9.7187450d-06, 7.6190295d-06/
      data fxyz(14,14, 5),fxyz(14,14, 6)/ 2.1466572d-06,-4.4641125d-05/
      data fxyz(14,14, 7),fxyz(14,14, 8)/ 1.5382970d-06, 2.6965967d-04/
      data fxyz(14,14, 9),fxyz(14,14,10)/-4.9765083d-04, 3.2558740d-04/
      data fxyz(14,14,11),fxyz(14,14,12)/-8.7231217d-05, 2.3402042d-05/
      data fxyz(14,14,13),fxyz(14,14,14)/-6.2525796d-06, 1.6210676d-06/
      data fxyz(14,14,15),fxyz(14,14,16)/-3.9708806d-07, 7.0671728d-08/
      data fxyz(14,14,17),fxyz(14,14,18)/ 5.5943629d-09, 5.4362968d-08/
      data fxyz(14,14,19),fxyz(14,14,20)/-5.8706369d-08, 1.3096728d-08/
      data fxyz(14,14,21),fxyz(14,14,22)/ 6.1389375d-09,-3.0875208d-08/
      data fxyz(14,14,23)/               -5.0003886d-08/
      data fxyz(14,15, 1),fxyz(14,15, 2)/-1.9251884d-05,-1.5331224d-05/
      data fxyz(14,15, 3),fxyz(14,15, 4)/-1.6016765d-05,-1.1459524d-07/
      data fxyz(14,15, 5),fxyz(14,15, 6)/-7.8939904d-05, 2.1928066d-04/
      data fxyz(14,15, 7),fxyz(14,15, 8)/-4.4003017d-05,-9.8397607d-04/
      data fxyz(14,15, 9),fxyz(14,15,10)/ 1.8504389d-03,-1.2143421d-03/
      data fxyz(14,15,11),fxyz(14,15,12)/ 3.2573030d-04,-8.7200473d-05/
      data fxyz(14,15,13),fxyz(14,15,14)/ 2.3415372d-05,-6.2401876d-06/
      data fxyz(14,15,15),fxyz(14,15,16)/ 1.6662662d-06,-4.6117571d-07/
      data fxyz(14,15,17),fxyz(14,15,18)/ 1.3999525d-07,-9.4199759d-08/
      data fxyz(14,15,19),fxyz(14,15,20)/ 1.3172752d-07,-5.2269085d-08/
      data fxyz(14,15,21),fxyz(14,15,22)/-3.7468815d-08, 7.2526436d-08/
      data fxyz(14,15,23)/                1.2780429d-07/
      data fxyz(14,16, 1),fxyz(14,16, 2)/ 4.1226495d-05, 3.3504331d-05/
      data fxyz(14,16, 3),fxyz(14,16, 4)/ 4.0287899d-05,-5.4146083d-07/
      data fxyz(14,16, 5),fxyz(14,16, 6)/ 1.9682177d-04,-5.7121391d-04/
      data fxyz(14,16, 7),fxyz(14,16, 8)/ 3.3081035d-04, 1.3715834d-03/
      data fxyz(14,16, 9),fxyz(14,16,10)/-2.8369804d-03, 1.8958885d-03/
      data fxyz(14,16,11),fxyz(14,16,12)/-5.0713707d-04, 1.3613775d-04/
      data fxyz(14,16,13),fxyz(14,16,14)/-3.6427196d-05, 9.7726658d-06/
      data fxyz(14,16,15),fxyz(14,16,16)/-2.6019163d-06, 7.1928932d-07/
      data fxyz(14,16,17),fxyz(14,16,18)/-2.3806321d-07, 1.9336849d-07/
      data fxyz(14,16,19),fxyz(14,16,20)/-2.2413054d-07, 7.1163928d-08/
      data fxyz(14,16,21),fxyz(14,16,22)/ 4.4804603d-08,-1.1869324d-07/
      data fxyz(14,16,23)/               -2.0202139d-07/
      data fxyz(14,17, 1),fxyz(14,17, 2)/ 1.0345265d-05,-4.2565218d-06/
      data fxyz(14,17, 3),fxyz(14,17, 4)/-6.0048574d-05,-1.7169181d-05/
      data fxyz(14,17, 5),fxyz(14,17, 6)/-1.7577409d-04, 6.5353616d-04/
      data fxyz(14,17, 7),fxyz(14,17, 8)/-5.7887680d-04,-6.0662303d-04/
      data fxyz(14,17, 9),fxyz(14,17,10)/ 1.6559405d-03,-1.1507285d-03/
      data fxyz(14,17,11),fxyz(14,17,12)/ 3.0763647d-04,-8.2568381d-05/
      data fxyz(14,17,13),fxyz(14,17,14)/ 2.2128399d-05,-5.8875740d-06/
      data fxyz(14,17,15),fxyz(14,17,16)/ 1.5985789d-06,-4.2827988d-07/
      data fxyz(14,17,17),fxyz(14,17,18)/ 1.5773539d-07,-1.5084170d-07/
      data fxyz(14,17,19),fxyz(14,17,20)/ 1.9672767d-07,-7.8480135d-08/
      data fxyz(14,17,21),fxyz(14,17,22)/-5.5885214d-08, 1.0634798d-07/
      data fxyz(14,17,23)/                1.8808212d-07/
      data fxyz(14,18, 1),fxyz(14,18, 2)/-1.2818619d-05,-4.9403501d-06/
      data fxyz(14,18, 3),fxyz(14,18, 4)/ 1.9446504d-05, 6.3130196d-06/
      data fxyz(14,18, 5),fxyz(14,18, 6)/ 4.7593586d-05,-2.0982088d-04/
      data fxyz(14,18, 7),fxyz(14,18, 8)/ 2.3029590d-04, 2.5027507d-05/
      data fxyz(14,18, 9),fxyz(14,18,10)/-2.6236814d-04, 1.9746066d-04/
      data fxyz(14,18,11),fxyz(14,18,12)/-5.3136598d-05, 1.4164378d-05/
      data fxyz(14,18,13),fxyz(14,18,14)/-3.8470482d-06, 1.0221307d-06/
      data fxyz(14,18,15),fxyz(14,18,16)/-2.9924070d-07, 9.3394070d-08/
      data fxyz(14,18,17),fxyz(14,18,18)/-2.6555681d-08, 1.4288610d-08/
      data fxyz(14,18,19),fxyz(14,18,20)/-5.2271851d-08, 2.2093801d-08/
      data fxyz(14,18,21),fxyz(14,18,22)/ 1.7286945d-08,-3.3044427d-08/
      data fxyz(14,18,23)/               -5.7814229d-08/
      data fxyz(14,19, 1),fxyz(14,19, 2)/-3.8187460d-05,-1.6217614d-05/
      data fxyz(14,19, 3),fxyz(14,19, 4)/ 4.7561138d-05, 1.8335243d-05/
      data fxyz(14,19, 5),fxyz(14,19, 6)/ 1.0068597d-04,-4.7657589d-04/
      data fxyz(14,19, 7),fxyz(14,19, 8)/ 5.4836579d-04,-8.8995372d-05/
      data fxyz(14,19, 9),fxyz(14,19,10)/-3.4889693d-04, 2.8999090d-04/
      data fxyz(14,19,11),fxyz(14,19,12)/-7.8039209d-05, 2.0771741d-05/
      data fxyz(14,19,13),fxyz(14,19,14)/-5.6707692d-06, 1.4832799d-06/
      data fxyz(14,19,15),fxyz(14,19,16)/-4.5468465d-07, 1.3814141d-07/
      data fxyz(14,19,17),fxyz(14,19,18)/-4.5106845d-08, 3.3893063d-08/
      data fxyz(14,19,19),fxyz(14,19,20)/-1.0988345d-07, 5.1176881d-08/
      data fxyz(14,19,21),fxyz(14,19,22)/ 4.0784254d-08,-6.8312941d-08/
      data fxyz(14,19,23)/               -1.2199633d-07/
      data fxyz(15, 1, 1),fxyz(15, 1, 2)/-2.1401819d-04,-1.4759299d-04/
      data fxyz(15, 1, 3),fxyz(15, 1, 4)/-2.9533435d-05, 1.2956846d-05/
      data fxyz(15, 1, 5),fxyz(15, 1, 6)/-3.1755412d-04, 4.2333603d-04/
      data fxyz(15, 1, 7),fxyz(15, 1, 8)/-2.0869469d-04, 7.3814283d-05/
      data fxyz(15, 1, 9),fxyz(15, 1,10)/ 1.4533977d-04,-5.7542413d-04/
      data fxyz(15, 1,11),fxyz(15, 1,12)/ 5.4206059d-04, 3.3888689d-04/
      data fxyz(15, 1,13),fxyz(15, 1,14)/-6.1897113d-04, 2.0627333d-04/
      data fxyz(15, 1,15),fxyz(15, 1,16)/ 9.4217979d-06,-2.2078965d-05/
      data fxyz(15, 1,17),fxyz(15, 1,18)/ 7.8783380d-05,-1.7782969d-04/
      data fxyz(15, 1,19),fxyz(15, 1,20)/ 4.0442913d-04,-2.1389530d-04/
      data fxyz(15, 1,21),fxyz(15, 1,22)/-1.7255937d-04, 2.3908541d-04/
      data fxyz(15, 1,23)/                4.4220923d-04/
      data fxyz(15, 2, 1),fxyz(15, 2, 2)/-9.0437106d-05,-6.1515989d-05/
      data fxyz(15, 2, 3),fxyz(15, 2, 4)/-1.0720366d-05, 8.8414816d-06/
      data fxyz(15, 2, 5),fxyz(15, 2, 6)/-1.3976338d-04, 2.0299061d-04/
      data fxyz(15, 2, 7),fxyz(15, 2, 8)/-1.3012902d-04, 5.2538008d-05/
      data fxyz(15, 2, 9),fxyz(15, 2,10)/ 6.6246767d-05,-2.7978502d-04/
      data fxyz(15, 2,11),fxyz(15, 2,12)/ 2.6412384d-04, 1.6559041d-04/
      data fxyz(15, 2,13),fxyz(15, 2,14)/-3.0292071d-04, 1.0326461d-04/
      data fxyz(15, 2,15),fxyz(15, 2,16)/ 3.7652883d-07,-9.3712805d-06/
      data fxyz(15, 2,17),fxyz(15, 2,18)/ 3.3193117d-05,-8.1461404d-05/
      data fxyz(15, 2,19),fxyz(15, 2,20)/ 1.8264846d-04,-9.3668275d-05/
      data fxyz(15, 2,21),fxyz(15, 2,22)/-7.5010474d-05, 1.0801726d-04/
      data fxyz(15, 2,23)/                1.9840561d-04/
      data fxyz(15, 3, 1),fxyz(15, 3, 2)/ 2.9799037d-04, 1.8932432d-04/
      data fxyz(15, 3, 3),fxyz(15, 3, 4)/-2.9634222d-06,-7.3957541d-05/
      data fxyz(15, 3, 5),fxyz(15, 3, 6)/ 4.7330080d-04,-7.6692141d-04/
      data fxyz(15, 3, 7),fxyz(15, 3, 8)/ 7.5264125d-04,-4.4634062d-04/
      data fxyz(15, 3, 9),fxyz(15, 3,10)/ 4.5649731d-05, 2.3356587d-04/
      data fxyz(15, 3,11),fxyz(15, 3,12)/-2.4408984d-04,-1.5759277d-04/
      data fxyz(15, 3,13),fxyz(15, 3,14)/ 2.8006734d-04,-7.0428372d-05/
      data fxyz(15, 3,15),fxyz(15, 3,16)/-4.6572109d-05, 3.2125656d-05/
      data fxyz(15, 3,17),fxyz(15, 3,18)/-8.3189055d-05, 2.4771884d-04/
      data fxyz(15, 3,19),fxyz(15, 3,20)/-5.0153290d-04, 2.3745406d-04/
      data fxyz(15, 3,21),fxyz(15, 3,22)/ 1.8551835d-04,-2.9379005d-04/
      data fxyz(15, 3,23)/               -5.3131683d-04/
      data fxyz(15, 4, 1),fxyz(15, 4, 2)/-2.4054452d-04,-1.3650695d-04/
      data fxyz(15, 4, 3),fxyz(15, 4, 4)/ 4.3489960d-05, 1.1863624d-04/
      data fxyz(15, 4, 5),fxyz(15, 4, 6)/-4.3709207d-04, 8.8664966d-04/
      data fxyz(15, 4, 7),fxyz(15, 4, 8)/-1.1793045d-03, 7.2638898d-04/
      data fxyz(15, 4, 9),fxyz(15, 4,10)/-1.7968318d-04,-1.5074491d-05/
      data fxyz(15, 4,11),fxyz(15, 4,12)/ 5.3665714d-05, 4.3827494d-05/
      data fxyz(15, 4,13),fxyz(15, 4,14)/-7.1226305d-05, 3.2736092d-06/
      data fxyz(15, 4,15),fxyz(15, 4,16)/ 3.9141044d-05,-2.7139789d-05/
      data fxyz(15, 4,17),fxyz(15, 4,18)/ 4.8200459d-05,-2.3794275d-04/
      data fxyz(15, 4,19),fxyz(15, 4,20)/ 4.3268817d-04,-1.6955720d-04/
      data fxyz(15, 4,21),fxyz(15, 4,22)/-1.2438258d-04, 2.5198967d-04/
      data fxyz(15, 4,23)/                4.3967661d-04/
      data fxyz(15, 5, 1),fxyz(15, 5, 2)/-3.6628407d-05,-2.9589083d-05/
      data fxyz(15, 5, 3),fxyz(15, 5, 4)/-3.7337596d-07,-2.5103399d-05/
      data fxyz(15, 5, 5),fxyz(15, 5, 6)/ 6.9331008d-05,-4.0757875d-04/
      data fxyz(15, 5, 7),fxyz(15, 5, 8)/ 7.1927133d-04,-4.4762353d-04/
      data fxyz(15, 5, 9),fxyz(15, 5,10)/ 1.1868676d-04,-1.5025015d-05/
      data fxyz(15, 5,11),fxyz(15, 5,12)/-9.0915693d-06,-1.2737204d-05/
      data fxyz(15, 5,13),fxyz(15, 5,14)/ 2.0062489d-05,-2.0772811d-06/
      data fxyz(15, 5,15),fxyz(15, 5,16)/-8.5035128d-06, 1.0238484d-05/
      data fxyz(15, 5,17),fxyz(15, 5,18)/-8.2159190d-06, 1.1074233d-04/
      data fxyz(15, 5,19),fxyz(15, 5,20)/-2.2158597d-04, 8.0672220d-05/
      data fxyz(15, 5,21),fxyz(15, 5,22)/ 5.8201550d-05,-1.3170329d-04/
      data fxyz(15, 5,23)/               -2.2631772d-04/
      data fxyz(15, 6, 1),fxyz(15, 6, 2)/ 2.4867531d-04, 1.3973717d-04/
      data fxyz(15, 6, 3),fxyz(15, 6, 4)/-8.5278399d-05,-1.0001919d-04/
      data fxyz(15, 6, 5),fxyz(15, 6, 6)/ 1.9870035d-04, 2.7563386d-05/
      data fxyz(15, 6, 7),fxyz(15, 6, 8)/-1.7059632d-04, 1.1403197d-04/
      data fxyz(15, 6, 9),fxyz(15, 6,10)/-3.0298559d-05, 3.6071787d-06/
      data fxyz(15, 6,11),fxyz(15, 6,12)/ 2.5036409d-06, 3.3478020d-06/
      data fxyz(15, 6,13),fxyz(15, 6,14)/-5.4039782d-06, 5.6113989d-07/
      data fxyz(15, 6,15),fxyz(15, 6,16)/ 1.8858935d-06,-2.2400599d-06/
      data fxyz(15, 6,17),fxyz(15, 6,18)/ 1.9352069d-06,-2.9396187d-05/
      data fxyz(15, 6,19),fxyz(15, 6,20)/ 8.7306021d-05,-4.0789795d-05/
      data fxyz(15, 6,21),fxyz(15, 6,22)/-3.2412567d-05, 5.3797112d-05/
      data fxyz(15, 6,23)/                9.6262223d-05/
      data fxyz(15, 7, 1),fxyz(15, 7, 2)/-7.3508568d-04,-3.9925193d-04/
      data fxyz(15, 7, 3),fxyz(15, 7, 4)/ 2.8674098d-04, 3.4562997d-04/
      data fxyz(15, 7, 5),fxyz(15, 7, 6)/-6.3480788d-04, 1.4824912d-04/
      data fxyz(15, 7, 7),fxyz(15, 7, 8)/ 3.2914268d-06,-1.9419493d-05/
      data fxyz(15, 7, 9),fxyz(15, 7,10)/ 4.7744822d-06,-1.7954431d-07/
      data fxyz(15, 7,11),fxyz(15, 7,12)/-9.0398299d-07,-8.4636185d-07/
      data fxyz(15, 7,13),fxyz(15, 7,14)/ 1.4069256d-06,-2.7971311d-07/
      data fxyz(15, 7,15),fxyz(15, 7,16)/-1.1116829d-07,-3.5507612d-07/
      data fxyz(15, 7,17),fxyz(15, 7,18)/-1.0439140d-07, 7.1102886d-06/
      data fxyz(15, 7,19),fxyz(15, 7,20)/-2.1221632d-05, 1.0174547d-05/
      data fxyz(15, 7,21),fxyz(15, 7,22)/ 8.1341920d-06,-1.3060214d-05/
      data fxyz(15, 7,23)/               -2.3495031d-05/
      data fxyz(15, 8, 1),fxyz(15, 8, 2)/ 4.6612590d-04, 2.5269750d-04/
      data fxyz(15, 8, 3),fxyz(15, 8, 4)/-1.8298866d-04,-2.2089435d-04/
      data fxyz(15, 8, 5),fxyz(15, 8, 6)/ 4.0432025d-04,-1.0245940d-04/
      data fxyz(15, 8, 7),fxyz(15, 8, 8)/ 1.6556280d-05, 3.5953168d-07/
      data fxyz(15, 8, 9),fxyz(15, 8,10)/ 1.2473129d-07,-4.2105471d-07/
      data fxyz(15, 8,11),fxyz(15, 8,12)/ 2.4443508d-07, 2.3972796d-07/
      data fxyz(15, 8,13),fxyz(15, 8,14)/-4.0613117d-07, 7.3963282d-08/
      data fxyz(15, 8,15),fxyz(15, 8,16)/-2.2311873d-07, 4.9460204d-07/
      data fxyz(15, 8,17),fxyz(15, 8,18)/-1.9374121d-07,-1.7309490d-06/
      data fxyz(15, 8,19),fxyz(15, 8,20)/ 5.9124768d-06,-2.9142854d-06/
      data fxyz(15, 8,21),fxyz(15, 8,22)/-2.3559350d-06, 3.6790752d-06/
      data fxyz(15, 8,23)/                6.6443068d-06/
      data fxyz(15, 9, 1),fxyz(15, 9, 2)/ 8.1513203d-04, 4.4221357d-04/
      data fxyz(15, 9, 3),fxyz(15, 9, 4)/-3.1833246d-04,-3.8582114d-04/
      data fxyz(15, 9, 5),fxyz(15, 9, 6)/ 7.1216830d-04,-1.9719824d-04/
      data fxyz(15, 9, 7),fxyz(15, 9, 8)/ 5.4086596d-05,-1.5923596d-05/
      data fxyz(15, 9, 9),fxyz(15, 9,10)/ 4.0182946d-06,-1.0227494d-06/
      data fxyz(15, 9,11),fxyz(15, 9,12)/ 2.5821396d-07,-2.5018564d-07/
      data fxyz(15, 9,13),fxyz(15, 9,14)/ 1.2527378d-07,-2.8233719d-10/
      data fxyz(15, 9,15),fxyz(15, 9,16)/ 7.9083101d-08,-1.9422482d-07/
      data fxyz(15, 9,17),fxyz(15, 9,18)/ 1.2380797d-07, 4.3493401d-07/
      data fxyz(15, 9,19),fxyz(15, 9,20)/-1.4616849d-06, 6.9190312d-07/
      data fxyz(15, 9,21),fxyz(15, 9,22)/ 5.5416767d-07,-9.1074314d-07/
      data fxyz(15, 9,23)/               -1.6310976d-06/
      data fxyz(15,10, 1),fxyz(15,10, 2)/-9.2692619d-04,-5.0454951d-04/
      data fxyz(15,10, 3),fxyz(15,10, 4)/ 3.5546342d-04, 4.3435333d-04/
      data fxyz(15,10, 5),fxyz(15,10, 6)/-8.2010917d-04, 2.5642253d-04/
      data fxyz(15,10, 7),fxyz(15,10, 8)/-7.5127789d-05, 1.7939863d-05/
      data fxyz(15,10, 9),fxyz(15,10,10)/-4.9506559d-06, 8.9836660d-07/
      data fxyz(15,10,11),fxyz(15,10,12)/-3.3430383d-07, 1.3621729d-07/
      data fxyz(15,10,13),fxyz(15,10,14)/-7.1909316d-08,-9.4070681d-09/
      data fxyz(15,10,15),fxyz(15,10,16)/-4.4998308d-08, 1.3917401d-07/
      data fxyz(15,10,17),fxyz(15,10,18)/-1.2975251d-07,-6.7670068d-08/
      data fxyz(15,10,19),fxyz(15,10,20)/ 3.5651767d-07,-1.9409896d-07/
      data fxyz(15,10,21),fxyz(15,10,22)/-1.6176626d-07, 2.2718688d-07/
      data fxyz(15,10,23)/                4.1732039d-07/
      data fxyz(15,11, 1),fxyz(15,11, 2)/ 3.3478932d-04, 1.8516644d-04/
      data fxyz(15,11, 3),fxyz(15,11, 4)/-1.1720714d-04,-1.4913919d-04/
      data fxyz(15,11, 5),fxyz(15,11, 6)/ 3.1289462d-04,-1.4419137d-04/
      data fxyz(15,11, 7),fxyz(15,11, 8)/ 5.4045698d-05,-1.0804599d-05/
      data fxyz(15,11, 9),fxyz(15,11,10)/ 7.8985732d-07, 5.9486927d-07/
      data fxyz(15,11,11),fxyz(15,11,12)/-2.4112669d-07,-8.6625383d-09/
      data fxyz(15,11,13),fxyz(15,11,14)/ 2.4531427d-08,-6.0570125d-09/
      data fxyz(15,11,15),fxyz(15,11,16)/ 5.1299107d-08,-1.3573368d-07/
      data fxyz(15,11,17),fxyz(15,11,18)/ 1.1110275d-07,-5.8723170d-09/
      data fxyz(15,11,19),fxyz(15,11,20)/-1.2531887d-07, 4.9809398d-08/
      data fxyz(15,11,21),fxyz(15,11,22)/ 4.0260043d-08,-8.7121452d-08/
      data fxyz(15,11,23)/               -1.4911264d-07/
      data fxyz(15,12, 1),fxyz(15,12, 2)/-1.6191267d-04,-9.0574555d-05/
      data fxyz(15,12, 3),fxyz(15,12, 4)/ 5.2866338d-05, 6.9362696d-05/
      data fxyz(15,12, 5),fxyz(15,12, 6)/-1.5655999d-04, 8.5532703d-05/
      data fxyz(15,12, 7),fxyz(15,12, 8)/-3.6068311d-05, 5.8188968d-06/
      data fxyz(15,12, 9),fxyz(15,12,10)/ 7.1626186d-06,-5.5508860d-06/
      data fxyz(15,12,11),fxyz(15,12,12)/ 1.4723413d-06,-4.1158313d-07/
      data fxyz(15,12,13),fxyz(15,12,14)/ 9.2442253d-08,-2.3079975d-08/
      data fxyz(15,12,15),fxyz(15,12,16)/-3.7353349d-08, 1.1733164d-07/
      data fxyz(15,12,17),fxyz(15,12,18)/-1.0065224d-07,-2.2599407d-08/
      data fxyz(15,12,19),fxyz(15,12,20)/ 5.5895041d-08,-1.6540718d-08/
      data fxyz(15,12,21),fxyz(15,12,22)/-1.1210126d-08, 3.4572673d-08/
      data fxyz(15,12,23)/                5.7359471d-08/
      data fxyz(15,13, 1),fxyz(15,13, 2)/ 4.9035243d-05, 2.7587091d-05/
      data fxyz(15,13, 3),fxyz(15,13, 4)/-1.4277878d-05,-2.1444751d-05/
      data fxyz(15,13, 5),fxyz(15,13, 6)/ 5.6254583d-05,-5.8467850d-05/
      data fxyz(15,13, 7),fxyz(15,13, 8)/ 4.0816857d-05, 5.8832426d-06/
      data fxyz(15,13, 9),fxyz(15,13,10)/-3.2477377d-05, 2.2511821d-05/
      data fxyz(15,13,11),fxyz(15,13,12)/-5.9910348d-06, 1.6081966d-06/
      data fxyz(15,13,13),fxyz(15,13,14)/-4.7526810d-07, 1.2904044d-07/
      data fxyz(15,13,15),fxyz(15,13,16)/ 4.6738113d-09,-9.3197572d-08/
      data fxyz(15,13,17),fxyz(15,13,18)/ 8.9625854d-08, 3.9670306d-08/
      data fxyz(15,13,19),fxyz(15,13,20)/-7.5555942d-08, 1.5491189d-08/
      data fxyz(15,13,21),fxyz(15,13,22)/ 8.0047220d-09,-4.5610073d-08/
      data fxyz(15,13,23)/               -7.2626702d-08/
      data fxyz(15,14, 1),fxyz(15,14, 2)/ 2.1608108d-05, 9.5166644d-06/
      data fxyz(15,14, 3),fxyz(15,14, 4)/-2.0837451d-05,-1.3060664d-05/
      data fxyz(15,14, 5),fxyz(15,14, 6)/-2.1590485d-05, 1.3825992d-04/
      data fxyz(15,14, 7),fxyz(15,14, 8)/-1.2307122d-04,-2.7855754d-05/
      data fxyz(15,14, 9),fxyz(15,14,10)/ 1.2316567d-04,-8.4671567d-05/
      data fxyz(15,14,11),fxyz(15,14,12)/ 2.2657691d-05,-5.9907117d-06/
      data fxyz(15,14,13),fxyz(15,14,14)/ 1.6578892d-06,-4.8649626d-07/
      data fxyz(15,14,15),fxyz(15,14,16)/ 9.2172510d-08, 2.2764619d-08/
      data fxyz(15,14,17),fxyz(15,14,18)/-1.7330735d-08,-1.8847294d-08/
      data fxyz(15,14,19),fxyz(15,14,20)/ 7.2781084d-08,-3.0288522d-08/
      data fxyz(15,14,21),fxyz(15,14,22)/-2.3655887d-08, 4.6250540d-08/
      data fxyz(15,14,23)/                8.0642243d-08/
      data fxyz(15,15, 1),fxyz(15,15, 2)/-1.5620326d-05, 2.9791586d-06/
      data fxyz(15,15, 3),fxyz(15,15, 4)/ 6.4228666d-05, 2.6790097d-05/
      data fxyz(15,15, 5),fxyz(15,15, 6)/ 1.5273343d-04,-5.7719885d-04/
      data fxyz(15,15, 7),fxyz(15,15, 8)/ 4.7642060d-04, 1.0968491d-04/
      data fxyz(15,15, 9),fxyz(15,15,10)/-4.6500110d-04, 3.1739139d-04/
      data fxyz(15,15,11),fxyz(15,15,12)/-8.4653963d-05, 2.2732615d-05/
      data fxyz(15,15,13),fxyz(15,15,14)/-6.0894787d-06, 1.6791764d-06/
      data fxyz(15,15,15),fxyz(15,15,16)/-4.5885274d-07, 9.8604265d-08/
      data fxyz(15,15,17),fxyz(15,15,18)/-2.6400421d-08, 5.4505219d-08/
      data fxyz(15,15,19),fxyz(15,15,20)/-4.6410481d-08, 1.1459188d-08/
      data fxyz(15,15,21),fxyz(15,15,22)/ 5.3869632d-09,-2.2121580d-08/
      data fxyz(15,15,23)/               -3.6578160d-08/
      data fxyz(15,16, 1),fxyz(15,16, 2)/ 4.0153424d-06,-3.1066111d-05/
      data fxyz(15,16, 3),fxyz(15,16, 4)/-1.6835235d-04,-5.9656884d-05/
      data fxyz(15,16, 5),fxyz(15,16, 6)/-4.6584796d-04, 1.6344473d-03/
      data fxyz(15,16, 7),fxyz(15,16, 8)/-1.3417326d-03,-4.8688805d-06/
      data fxyz(15,16, 9),fxyz(15,16,10)/ 6.8490748d-04,-4.8398984d-04/
      data fxyz(15,16,11),fxyz(15,16,12)/ 1.3009945d-04,-3.4699151d-05/
      data fxyz(15,16,13),fxyz(15,16,14)/ 9.3540188d-06,-2.4946576d-06/
      data fxyz(15,16,15),fxyz(15,16,16)/ 6.8931530d-07,-1.5183708d-07/
      data fxyz(15,16,17),fxyz(15,16,18)/ 4.4639343d-08,-9.7578506d-08/
      data fxyz(15,16,19),fxyz(15,16,20)/ 1.2280741d-07,-4.6736734d-08/
      data fxyz(15,16,21),fxyz(15,16,22)/-3.2519652d-08, 6.5939082d-08/
      data fxyz(15,16,23)/                1.1567771d-07/
      data fxyz(15,17, 1),fxyz(15,17, 2)/-6.5499772d-05, 5.9124822d-06/
      data fxyz(15,17, 3),fxyz(15,17, 4)/ 2.3514091d-04, 1.0178712d-04/
      data fxyz(15,17, 5),fxyz(15,17, 6)/ 5.3932763d-04,-2.0658066d-03/
      data fxyz(15,17, 7),fxyz(15,17, 8)/ 1.7143825d-03,-2.5936167d-04/
      data fxyz(15,17, 9),fxyz(15,17,10)/-3.4487618d-04, 2.7844475d-04/
      data fxyz(15,17,11),fxyz(15,17,12)/-7.5071495d-05, 2.0028147d-05/
      data fxyz(15,17,13),fxyz(15,17,14)/-5.3624262d-06, 1.4794715d-06/
      data fxyz(15,17,15),fxyz(15,17,16)/-4.1131079d-07, 1.1007389d-07/
      data fxyz(15,17,17),fxyz(15,17,18)/-2.0586829d-08, 7.1930043d-08/
      data fxyz(15,17,19),fxyz(15,17,20)/-1.4273709d-07, 5.4287846d-08/
      data fxyz(15,17,21),fxyz(15,17,22)/ 3.9733473d-08,-8.4519605d-08/
      data fxyz(15,17,23)/               -1.4638554d-07/
      data fxyz(15,18, 1),fxyz(15,18, 2)/ 4.2923557d-05, 8.8149384d-06/
      data fxyz(15,18, 3),fxyz(15,18, 4)/-9.0889419d-05,-4.4314112d-05/
      data fxyz(15,18, 5),fxyz(15,18, 6)/-1.7748629d-04, 7.4155316d-04/
      data fxyz(15,18, 7),fxyz(15,18, 8)/-6.2079368d-04, 1.4040931d-04/
      data fxyz(15,18, 9),fxyz(15,18,10)/ 3.2265716d-05,-4.2767333d-05/
      data fxyz(15,18,11),fxyz(15,18,12)/ 1.1333168d-05,-3.1269290d-06/
      data fxyz(15,18,13),fxyz(15,18,14)/ 8.1788788d-07,-2.7590735d-07/
      data fxyz(15,18,15),fxyz(15,18,16)/ 1.1874112d-07,-4.2079939d-08/
      data fxyz(15,18,17),fxyz(15,18,18)/-7.3365767d-09,-1.9572144d-09/
      data fxyz(15,18,19),fxyz(15,18,20)/ 4.6233629d-08,-3.1850178d-08/
      data fxyz(15,18,21),fxyz(15,18,22)/-2.7832933d-08, 3.0164650d-08/
      data fxyz(15,18,23)/                5.8301455d-08/
      data fxyz(15,19, 1),fxyz(15,19, 2)/ 1.0050733d-04, 2.1453434d-05/
      data fxyz(15,19, 3),fxyz(15,19, 4)/-2.0848444d-04,-1.0254528d-04/
      data fxyz(15,19, 5),fxyz(15,19, 6)/-4.0230321d-04, 1.6895947d-03/
      data fxyz(15,19, 7),fxyz(15,19, 8)/-1.4156009d-03, 3.5324778d-04/
      data fxyz(15,19, 9),fxyz(15,19,10)/ 7.4288784d-06,-5.4366082d-05/
      data fxyz(15,19,11),fxyz(15,19,12)/ 1.4430515d-05,-4.0298983d-06/
      data fxyz(15,19,13),fxyz(15,19,14)/ 1.0276994d-06,-3.9428394d-07/
      data fxyz(15,19,15),fxyz(15,19,16)/ 1.8288503d-07,-7.5929540d-08/
      data fxyz(15,19,17),fxyz(15,19,18)/-1.6508160d-08,-6.3028131d-09/
      data fxyz(15,19,19),fxyz(15,19,20)/ 1.0534286d-07,-6.4513172d-08/
      data fxyz(15,19,21),fxyz(15,19,22)/-5.5450902d-08, 6.9093780d-08/
      data fxyz(15,19,23)/                1.2963124d-07/
      data fxyz(16, 1, 1),fxyz(16, 1, 2)/-3.0739735d-03,-1.6839680d-03/
      data fxyz(16, 1, 3),fxyz(16, 1, 4)/ 1.1492813d-03, 1.4036156d-03/
      data fxyz(16, 1, 5),fxyz(16, 1, 6)/-2.7013050d-03, 7.4104040d-04/
      data fxyz(16, 1, 7),fxyz(16, 1, 8)/-5.9507003d-05, 7.3939938d-05/
      data fxyz(16, 1, 9),fxyz(16, 1,10)/-2.7986138d-04, 9.5100242d-04/
      data fxyz(16, 1,11),fxyz(16, 1,12)/-1.0588849d-03,-3.4430486d-04/
      data fxyz(16, 1,13),fxyz(16, 1,14)/ 1.1398615d-03,-5.9568125d-04/
      data fxyz(16, 1,15),fxyz(16, 1,16)/ 1.0645864d-04, 4.1154342d-05/
      data fxyz(16, 1,17),fxyz(16, 1,18)/-1.6347125d-04, 8.8716068d-04/
      data fxyz(16, 1,19),fxyz(16, 1,20)/-2.6932803d-03, 1.3476824d-03/
      data fxyz(16, 1,21),fxyz(16, 1,22)/ 1.0882098d-03,-1.6553897d-03/
      data fxyz(16, 1,23)/               -3.0049289d-03/
      data fxyz(16, 2, 1),fxyz(16, 2, 2)/-1.2232293d-03,-6.6956528d-04/
      data fxyz(16, 2, 3),fxyz(16, 2, 4)/ 4.5989918d-04, 5.5957647d-04/
      data fxyz(16, 2, 5),fxyz(16, 2, 6)/-1.0682744d-03, 2.7193002d-04/
      data fxyz(16, 2, 7),fxyz(16, 2, 8)/ 4.7084314d-06, 1.9340525d-05/
      data fxyz(16, 2, 9),fxyz(16, 2,10)/-1.3278972d-04, 4.6284060d-04/
      data fxyz(16, 2,11),fxyz(16, 2,12)/-5.1652149d-04,-1.6820948d-04/
      data fxyz(16, 2,13),fxyz(16, 2,14)/ 5.5651701d-04,-2.9182455d-04/
      data fxyz(16, 2,15),fxyz(16, 2,16)/ 5.3519803d-05, 1.5298422d-05/
      data fxyz(16, 2,17),fxyz(16, 2,18)/-6.6590157d-05, 3.6089715d-04/
      data fxyz(16, 2,19),fxyz(16, 2,20)/-1.1069206d-03, 5.5696705d-04/
      data fxyz(16, 2,21),fxyz(16, 2,22)/ 4.5043388d-04,-6.8078795d-04/
      data fxyz(16, 2,23)/               -1.2371003d-03/
      data fxyz(16, 3, 1),fxyz(16, 3, 2)/ 2.3780327d-03, 1.2994855d-03/
      data fxyz(16, 3, 3),fxyz(16, 3, 4)/-9.0976072d-04,-1.0881318d-03/
      data fxyz(16, 3, 5),fxyz(16, 3, 6)/ 2.0129697d-03,-2.9753327d-04/
      data fxyz(16, 3, 7),fxyz(16, 3, 8)/-3.2228295d-04, 2.0094466d-04/
      data fxyz(16, 3, 9),fxyz(16, 3,10)/ 6.2109252d-05,-4.2478128d-04/
      data fxyz(16, 3,11),fxyz(16, 3,12)/ 4.8603199d-04, 1.5982538d-04/
      data fxyz(16, 3,13),fxyz(16, 3,14)/-5.2805377d-04, 2.6780605d-04/
      data fxyz(16, 3,15),fxyz(16, 3,16)/-3.9566446d-05,-3.5720389d-05/
      data fxyz(16, 3,17),fxyz(16, 3,18)/ 1.2914618d-04,-7.1166293d-04/
      data fxyz(16, 3,19),fxyz(16, 3,20)/ 2.2859488d-03,-1.1635613d-03/
      data fxyz(16, 3,21),fxyz(16, 3,22)/-9.4485641d-04, 1.4111292d-03/
      data fxyz(16, 3,23)/                2.5689105d-03/
      data fxyz(16, 4, 1),fxyz(16, 4, 2)/-1.4751757d-04,-7.2731851d-05/
      data fxyz(16, 4, 3),fxyz(16, 4, 4)/ 1.0155160d-04, 7.7002010d-05/
      data fxyz(16, 4, 5),fxyz(16, 4, 6)/ 2.5466496d-05,-5.1576137d-04/
      data fxyz(16, 4, 7),fxyz(16, 4, 8)/ 7.1994953d-04,-4.4416363d-04/
      data fxyz(16, 4, 9),fxyz(16, 4,10)/ 8.9612647d-05, 8.5707055d-05/
      data fxyz(16, 4,11),fxyz(16, 4,12)/-1.2207984d-04,-4.3927914d-05/
      data fxyz(16, 4,13),fxyz(16, 4,14)/ 1.4166743d-04,-6.7771998d-05/
      data fxyz(16, 4,15),fxyz(16, 4,16)/ 7.8632298d-06, 1.3309189d-06/
      data fxyz(16, 4,17),fxyz(16, 4,18)/-2.1110823d-05, 1.2781489d-04/
      data fxyz(16, 4,19),fxyz(16, 4,20)/-6.4396576d-04, 3.7025574d-04/
      data fxyz(16, 4,21),fxyz(16, 4,22)/ 3.1115366d-04,-4.0755740d-04/
      data fxyz(16, 4,23)/               -7.5871645d-04/
      data fxyz(16, 5, 1),fxyz(16, 5, 2)/-9.2816854d-04,-5.1386323d-04/
      data fxyz(16, 5, 3),fxyz(16, 5, 4)/ 3.1596293d-04, 4.1741208d-04/
      data fxyz(16, 5, 5),fxyz(16, 5, 6)/-9.1965986d-04, 5.9356882d-04/
      data fxyz(16, 5, 7),fxyz(16, 5, 8)/-5.0712043d-04, 3.0186806d-04/
      data fxyz(16, 5, 9),fxyz(16, 5,10)/-7.1432565d-05,-9.4243340d-06/
      data fxyz(16, 5,11),fxyz(16, 5,12)/ 2.9234435d-05, 1.2712746d-05/
      data fxyz(16, 5,13),fxyz(16, 5,14)/-3.8518648d-05, 1.9755609d-05/
      data fxyz(16, 5,15),fxyz(16, 5,16)/-4.7177001d-06, 1.4010679d-05/
      data fxyz(16, 5,17),fxyz(16, 5,18)/-2.8167244d-05, 1.5732664d-04/
      data fxyz(16, 5,19),fxyz(16, 5,20)/-2.7019733d-04, 9.1931965d-05/
      data fxyz(16, 5,21),fxyz(16, 5,22)/ 6.3616254d-05,-1.5693448d-04/
      data fxyz(16, 5,23)/               -2.6740902d-04/
      data fxyz(16, 6, 1),fxyz(16, 6, 2)/ 2.0892794d-04, 1.1585239d-04/
      data fxyz(16, 6, 3),fxyz(16, 6, 4)/-7.0102340d-05,-9.3714869d-05/
      data fxyz(16, 6, 5),fxyz(16, 6, 6)/ 2.1030251d-04,-1.4525998d-04/
      data fxyz(16, 6, 7),fxyz(16, 6, 8)/ 1.3176787d-04,-8.0078012d-05/
      data fxyz(16, 6, 9),fxyz(16, 6,10)/ 1.8832660d-05, 2.4802442d-06/
      data fxyz(16, 6,11),fxyz(16, 6,12)/-7.8402675d-06,-3.4687103d-06/
      data fxyz(16, 6,13),fxyz(16, 6,14)/ 1.0295753d-05,-5.3624043d-06/
      data fxyz(16, 6,15),fxyz(16, 6,16)/ 1.1180778d-06,-3.0319035d-06/
      data fxyz(16, 6,17),fxyz(16, 6,18)/ 3.1781200d-06,-2.5767400d-05/
      data fxyz(16, 6,19),fxyz(16, 6,20)/-3.5695279d-06, 1.9281287d-05/
      data fxyz(16, 6,21),fxyz(16, 6,22)/ 1.9828795d-05,-5.7595579d-06/
      data fxyz(16, 6,23)/               -1.7554787d-05/
      data fxyz(16, 7, 1),fxyz(16, 7, 2)/ 3.4276067d-04, 1.8507535d-04/
      data fxyz(16, 7, 3),fxyz(16, 7, 4)/-1.3769283d-04,-1.6416846d-04/
      data fxyz(16, 7, 5),fxyz(16, 7, 6)/ 2.9097787d-04,-5.4373769d-05/
      data fxyz(16, 7, 7),fxyz(16, 7, 8)/-1.0565990d-05, 1.4477601d-05/
      data fxyz(16, 7, 9),fxyz(16, 7,10)/-3.4144268d-06,-1.2183928d-06/
      data fxyz(16, 7,11),fxyz(16, 7,12)/ 2.1660816d-06, 9.7163885d-07/
      data fxyz(16, 7,13),fxyz(16, 7,14)/-2.8251841d-06, 1.5716293d-06/
      data fxyz(16, 7,15),fxyz(16, 7,16)/-8.8935664d-07, 1.3075684d-06/
      data fxyz(16, 7,17),fxyz(16, 7,18)/-1.2596071d-06, 6.6620866d-06/
      data fxyz(16, 7,19),fxyz(16, 7,20)/ 2.7837812d-06,-5.9648611d-06/
      data fxyz(16, 7,21),fxyz(16, 7,22)/-5.9551588d-06, 2.7449722d-06/
      data fxyz(16, 7,23)/                6.8076206d-06/
      data fxyz(16, 8, 1),fxyz(16, 8, 2)/-1.7977272d-04,-9.7382854d-05/
      data fxyz(16, 8, 3),fxyz(16, 8, 4)/ 7.0916756d-05, 8.5354420d-05/
      data fxyz(16, 8, 5),fxyz(16, 8, 6)/-1.5513351d-04, 3.6792255d-05/
      data fxyz(16, 8, 7),fxyz(16, 8, 8)/-3.0435873d-06,-2.1617262d-06/
      data fxyz(16, 8, 9),fxyz(16, 8,10)/ 4.1473135d-07, 4.0079527d-07/
      data fxyz(16, 8,11),fxyz(16, 8,12)/-5.8384323d-07,-4.0577352d-07/
      data fxyz(16, 8,13),fxyz(16, 8,14)/ 7.9120071d-07,-5.8808678d-07/
      data fxyz(16, 8,15),fxyz(16, 8,16)/ 6.2755812d-07,-7.8606154d-07/
      data fxyz(16, 8,17),fxyz(16, 8,18)/ 6.2872696d-07,-1.8282812d-06/
      data fxyz(16, 8,19),fxyz(16, 8,20)/-4.1229242d-07, 1.3730665d-06/
      data fxyz(16, 8,21),fxyz(16, 8,22)/ 1.4007321d-06,-5.2295468d-07/
      data fxyz(16, 8,23)/               -1.4132977d-06/
      data fxyz(16, 9, 1),fxyz(16, 9, 2)/-9.3261898d-04,-5.0467390d-04/
      data fxyz(16, 9, 3),fxyz(16, 9, 4)/ 3.6861691d-04, 4.4515207d-04/
      data fxyz(16, 9, 5),fxyz(16, 9, 6)/-8.1081452d-04, 2.1540834d-04/
      data fxyz(16, 9, 7),fxyz(16, 9, 8)/-5.9814025d-05, 1.6647699d-05/
      data fxyz(16, 9, 9),fxyz(16, 9,10)/-4.4889987d-06, 1.0539808d-06/
      data fxyz(16, 9,11),fxyz(16, 9,12)/-2.5955176d-07, 2.5921346d-07/
      data fxyz(16, 9,13),fxyz(16, 9,14)/-2.2327802d-07, 6.4347135d-08/
      data fxyz(16, 9,15),fxyz(16, 9,16)/-1.9276842d-07, 3.5939861d-07/
      data fxyz(16, 9,17),fxyz(16, 9,18)/-2.9073542d-07, 6.0273081d-07/
      data fxyz(16, 9,19),fxyz(16, 9,20)/ 1.1215761d-07,-4.2438050d-07/
      data fxyz(16, 9,21),fxyz(16, 9,22)/-4.3578186d-07, 1.5776307d-07/
      data fxyz(16, 9,23)/                4.3171034d-07/
      data fxyz(16,10, 1),fxyz(16,10, 2)/ 1.3943570d-03, 7.5800899d-04/
      data fxyz(16,10, 3),fxyz(16,10, 4)/-5.3934709d-04,-6.5527898d-04/
      data fxyz(16,10, 5),fxyz(16,10, 6)/ 1.2217365d-03,-3.4462129d-04/
      data fxyz(16,10, 7),fxyz(16,10, 8)/ 8.7535816d-05,-2.5083850d-05/
      data fxyz(16,10, 9),fxyz(16,10,10)/ 6.2142642d-06,-1.7763130d-06/
      data fxyz(16,10,11),fxyz(16,10,12)/ 4.3347913d-07,-1.8830028d-07/
      data fxyz(16,10,13),fxyz(16,10,14)/-6.2689645d-09, 1.4467731d-07/
      data fxyz(16,10,15),fxyz(16,10,16)/-2.3529988d-08,-1.8680613d-07/
      data fxyz(16,10,17),fxyz(16,10,18)/ 2.2635233d-07,-2.5770154d-07/
      data fxyz(16,10,19),fxyz(16,10,20)/ 3.0631798d-09, 8.0556815d-08/
      data fxyz(16,10,21),fxyz(16,10,22)/ 9.1218256d-08,-3.9582583d-08/
      data fxyz(16,10,23)/               -9.7779924d-08/
      data fxyz(16,11, 1),fxyz(16,11, 2)/-8.7757613d-04,-4.8162914d-04/
      data fxyz(16,11, 3),fxyz(16,11, 4)/ 3.2353851d-04, 3.9929633d-04/
      data fxyz(16,11, 5),fxyz(16,11, 6)/-7.8466041d-04, 2.5879111d-04/
      data fxyz(16,11, 7),fxyz(16,11, 8)/-6.1515879d-05, 1.7357019d-05/
      data fxyz(16,11, 9),fxyz(16,11,10)/-4.2062264d-06, 8.2830378d-07/
      data fxyz(16,11,11),fxyz(16,11,12)/-2.9683618d-07, 5.1650827d-08/
      data fxyz(16,11,13),fxyz(16,11,14)/ 2.6677633d-08,-8.0490482d-08/
      data fxyz(16,11,15),fxyz(16,11,16)/-1.7065007d-09, 1.4653230d-07/
      data fxyz(16,11,17),fxyz(16,11,18)/-1.8394947d-07, 1.1115542d-07/
      data fxyz(16,11,19),fxyz(16,11,20)/-4.3066481d-08,-8.7184521d-09/
      data fxyz(16,11,21),fxyz(16,11,22)/-1.6799986d-08,-1.0740346d-08/
      data fxyz(16,11,23)/               -1.0067589d-08/
      data fxyz(16,12, 1),fxyz(16,12, 2)/ 4.2878313d-04, 2.3690062d-04/
      data fxyz(16,12, 3),fxyz(16,12, 4)/-1.5213060d-04,-1.9088538d-04/
      data fxyz(16,12, 5),fxyz(16,12, 6)/ 3.9191974d-04,-1.5253859d-04/
      data fxyz(16,12, 7),fxyz(16,12, 8)/ 4.1719275d-05,-8.8376529d-06/
      data fxyz(16,12, 9),fxyz(16,12,10)/ 5.4753521d-07, 7.9880746d-07/
      data fxyz(16,12,11),fxyz(16,12,12)/-2.1089274d-07, 4.6848155d-08/
      data fxyz(16,12,13),fxyz(16,12,14)/-5.1505805d-08, 4.8383961d-08/
      data fxyz(16,12,15),fxyz(16,12,16)/ 1.5064756d-08,-1.1898213d-07/
      data fxyz(16,12,17),fxyz(16,12,18)/ 1.0567801d-07,-2.6240605d-10/
      data fxyz(16,12,19),fxyz(16,12,20)/-5.3238833d-08, 1.3956173d-08/
      data fxyz(16,12,21),fxyz(16,12,22)/ 9.9529724d-09,-3.7226030d-08/
      data fxyz(16,12,23)/               -6.0310417d-08/
      data fxyz(16,13, 1),fxyz(16,13, 2)/-1.6180791d-04,-9.0716419d-05/
      data fxyz(16,13, 3),fxyz(16,13, 4)/ 5.1943504d-05, 6.8881736d-05/
      data fxyz(16,13, 5),fxyz(16,13, 6)/-1.5846935d-04, 9.2265573d-05/
      data fxyz(16,13, 7),fxyz(16,13, 8)/-3.8186689d-05, 3.8352911d-06/
      data fxyz(16,13, 9),fxyz(16,13,10)/ 7.1940192d-06,-5.4960790d-06/
      data fxyz(16,13,11),fxyz(16,13,12)/ 1.4864850d-06,-3.9369146d-07/
      data fxyz(16,13,13),fxyz(16,13,14)/ 1.4584861d-07,-9.7924639d-08/
      data fxyz(16,13,15),fxyz(16,13,16)/ 1.9518484d-08, 5.4119227d-08/
      data fxyz(16,13,17),fxyz(16,13,18)/-2.3682762d-08,-6.0819588d-08/
      data fxyz(16,13,19),fxyz(16,13,20)/ 1.2051445d-07,-4.9188355d-08/
      data fxyz(16,13,21),fxyz(16,13,22)/-3.6821487d-08, 7.1046980d-08/
      data fxyz(16,13,23)/                1.2468343d-07/
      data fxyz(16,14, 1),fxyz(16,14, 2)/-5.6553342d-05,-2.6477612d-05/
      data fxyz(16,14, 3),fxyz(16,14, 4)/ 4.0359218d-05, 3.6178756d-05/
      data fxyz(16,14, 5),fxyz(16,14, 6)/-9.7557625d-06,-1.1926028d-04/
      data fxyz(16,14, 7),fxyz(16,14, 8)/ 8.6077872d-05, 1.2843033d-06/
      data fxyz(16,14, 9),fxyz(16,14,10)/-3.1289249d-05, 2.1782026d-05/
      data fxyz(16,14,11),fxyz(16,14,12)/-5.7282860d-06, 1.5469021d-06/
      data fxyz(16,14,13),fxyz(16,14,14)/-4.4386087d-07, 1.6722811d-07/
      data fxyz(16,14,15),fxyz(16,14,16)/-7.7055450d-08, 7.7654253d-09/
      data fxyz(16,14,17),fxyz(16,14,18)/ 2.5307669d-09, 7.1980473d-08/
      data fxyz(16,14,19),fxyz(16,14,20)/-9.5029762d-08, 3.3924897d-08/
      data fxyz(16,14,21),fxyz(16,14,22)/ 2.3140606d-08,-5.1892596d-08/
      data fxyz(16,14,23)/               -8.9783901d-08/
      data fxyz(16,15, 1),fxyz(16,15, 2)/ 2.3892924d-05,-6.9208688d-06/
      data fxyz(16,15, 3),fxyz(16,15, 4)/-9.0975407d-05,-5.9431688d-05/
      data fxyz(16,15, 5),fxyz(16,15, 6)/-1.3309575d-04, 4.9704871d-04/
      data fxyz(16,15, 7),fxyz(16,15, 8)/-3.0469558d-04,-1.2491954d-05/
      data fxyz(16,15, 9),fxyz(16,15,10)/ 1.1626167d-04,-8.0680667d-05/
      data fxyz(16,15,11),fxyz(16,15,12)/ 2.1797341d-05,-5.7064592d-06/
      data fxyz(16,15,13),fxyz(16,15,14)/ 1.5664468d-06,-4.5773027d-07/
      data fxyz(16,15,15),fxyz(16,15,16)/ 1.3206183d-07,-8.9828091d-09/
      data fxyz(16,15,17),fxyz(16,15,18)/-1.2850688d-08,-2.0126543d-08/
      data fxyz(16,15,19),fxyz(16,15,20)/ 6.2873004d-08,-2.5920774d-08/
      data fxyz(16,15,21),fxyz(16,15,22)/-2.0013971d-08, 3.9245793d-08/
      data fxyz(16,15,23)/                6.8475498d-08/
      data fxyz(16,16, 1),fxyz(16,16, 2)/ 5.3399612d-05, 8.4192877d-05/
      data fxyz(16,16, 3),fxyz(16,16, 4)/ 2.0355617d-04, 1.1014515d-04/
      data fxyz(16,16, 5),fxyz(16,16, 6)/ 4.5783696d-04,-1.3477657d-03/
      data fxyz(16,16, 7),fxyz(16,16, 8)/ 8.2285456d-04,-7.3795126d-05/
      data fxyz(16,16, 9),fxyz(16,16,10)/-1.5082256d-04, 1.2043878d-04/
      data fxyz(16,16,11),fxyz(16,16,12)/-3.1961733d-05, 8.5989885d-06/
      data fxyz(16,16,13),fxyz(16,16,14)/-2.2383692d-06, 6.4719391d-07/
      data fxyz(16,16,15),fxyz(16,16,16)/-1.4156873d-07,-2.5126271d-08/
      data fxyz(16,16,17),fxyz(16,16,18)/ 2.9163047d-08, 1.5344831d-08/
      data fxyz(16,16,19),fxyz(16,16,20)/-5.9480045d-08, 2.3829470d-08/
      data fxyz(16,16,21),fxyz(16,16,22)/ 1.8432193d-08,-3.7890934d-08/
      data fxyz(16,16,23)/               -6.5614334d-08/
      data fxyz(16,17, 1),fxyz(16,17, 2)/ 2.3489643d-05,-5.2757934d-05/
      data fxyz(16,17, 3),fxyz(16,17, 4)/-2.7703801d-04,-1.7047629d-04/
      data fxyz(16,17, 5),fxyz(16,17, 6)/-4.7900484d-04, 1.6219155d-03/
      data fxyz(16,17, 7),fxyz(16,17, 8)/-1.0456223d-03, 1.9547438d-04/
      data fxyz(16,17, 9),fxyz(16,17,10)/ 4.8930169d-05,-6.3560958d-05/
      data fxyz(16,17,11),fxyz(16,17,12)/ 1.6651349d-05,-4.5028736d-06/
      data fxyz(16,17,13),fxyz(16,17,14)/ 1.1881963d-06,-3.4674022d-07/
      data fxyz(16,17,15),fxyz(16,17,16)/ 1.2270011d-07, 3.2959748d-08/
      data fxyz(16,17,17),fxyz(16,17,18)/-3.9588945d-08,-6.5465619d-09/
      data fxyz(16,17,19),fxyz(16,17,20)/ 5.6320322d-08,-3.6265202d-08/
      data fxyz(16,17,21),fxyz(16,17,22)/-3.1230070d-08, 3.6179791d-08/
      data fxyz(16,17,23)/                6.8980429d-08/
      data fxyz(16,18, 1),fxyz(16,18, 2)/-2.6382341d-05, 8.4058895d-06/
      data fxyz(16,18, 3),fxyz(16,18, 4)/ 1.0361252d-04, 6.7456783d-05/
      data fxyz(16,18, 5),fxyz(16,18, 6)/ 1.5302883d-04,-5.6871838d-04/
      data fxyz(16,18, 7),fxyz(16,18, 8)/ 3.8038983d-04,-8.9821861d-05/
      data fxyz(16,18, 9),fxyz(16,18,10)/ 6.4206436d-06, 7.1071674d-06/
      data fxyz(16,18,11),fxyz(16,18,12)/-1.9677440d-06, 4.7429482d-07/
      data fxyz(16,18,13),fxyz(16,18,14)/-1.7096550d-07, 7.9113816d-08/
      data fxyz(16,18,15),fxyz(16,18,16)/-6.5783557d-08, 3.6379873d-09/
      data fxyz(16,18,17),fxyz(16,18,18)/ 2.9473503d-08,-2.3316357d-08/
      data fxyz(16,18,19),fxyz(16,18,20)/-1.4586728d-08, 8.3922249d-09/
      data fxyz(16,18,21),fxyz(16,18,22)/ 8.2975785d-09,-1.4208143d-08/
      data fxyz(16,18,23)/               -2.4736052d-08/
      data fxyz(16,19, 1),fxyz(16,19, 2)/-7.0550893d-05, 1.2965532d-05/
      data fxyz(16,19, 3),fxyz(16,19, 4)/ 2.3819313d-04, 1.5723142d-04/
      data fxyz(16,19, 5),fxyz(16,19, 6)/ 3.3681237d-04,-1.2849765d-03/
      data fxyz(16,19, 7),fxyz(16,19, 8)/ 8.6511941d-04,-2.1667075d-04/
      data fxyz(16,19, 9),fxyz(16,19,10)/ 3.3128907d-05, 5.0130453d-06/
      data fxyz(16,19,11),fxyz(16,19,12)/-1.3776444d-06, 2.8602593d-07/
      data fxyz(16,19,13),fxyz(16,19,14)/-1.6277665d-07, 9.9314089d-08/
      data fxyz(16,19,15),fxyz(16,19,16)/-1.2490936d-07,-7.1012203d-10/
      data fxyz(16,19,17),fxyz(16,19,18)/ 5.9160397d-08,-4.1549465d-08/
      data fxyz(16,19,19),fxyz(16,19,20)/-3.2148802d-08, 2.3120481d-08/
      data fxyz(16,19,21),fxyz(16,19,22)/ 2.2342395d-08,-2.9036460d-08/
      data fxyz(16,19,23)/               -5.3220749d-08/
      data fxyz(17, 1, 1),fxyz(17, 1, 2)/-2.4872485d-04,-1.5231452d-04/
      data fxyz(17, 1, 3),fxyz(17, 1, 4)/ 3.4566890d-05, 6.9063179d-05/
      data fxyz(17, 1, 5),fxyz(17, 1, 6)/-2.9029967d-04, 2.6871947d-04/
      data fxyz(17, 1, 7),fxyz(17, 1, 8)/-1.4316501d-04,-2.8982175d-05/
      data fxyz(17, 1, 9),fxyz(17, 1,10)/ 2.2765451d-04,-4.9936158d-04/
      data fxyz(17, 1,11),fxyz(17, 1,12)/ 6.7972163d-04,-1.8355983d-05/
      data fxyz(17, 1,13),fxyz(17, 1,14)/-6.6746716d-04, 4.5278238d-04/
      data fxyz(17, 1,15),fxyz(17, 1,16)/-2.2061449d-05, 2.2605878d-05/
      data fxyz(17, 1,17),fxyz(17, 1,18)/-1.2970073d-04, 2.3958047d-04/
      data fxyz(17, 1,19),fxyz(17, 1,20)/-3.7515938d-04, 1.3659899d-04/
      data fxyz(17, 1,21),fxyz(17, 1,22)/ 9.6081881d-05,-2.1309095d-04/
      data fxyz(17, 1,23)/               -3.6817616d-04/
      data fxyz(17, 2, 1),fxyz(17, 2, 2)/-7.2463762d-05,-4.5803824d-05/
      data fxyz(17, 2, 3),fxyz(17, 2, 4)/ 4.5542455d-06, 1.6402391d-05/
      data fxyz(17, 2, 5),fxyz(17, 2, 6)/-9.3196406d-05, 1.0525842d-04/
      data fxyz(17, 2, 7),fxyz(17, 2, 8)/-6.3265234d-05,-1.9419378d-05/
      data fxyz(17, 2, 9),fxyz(17, 2,10)/ 1.1190473d-04,-2.4415443d-04/
      data fxyz(17, 2,11),fxyz(17, 2,12)/ 3.3177886d-04,-9.0268127d-06/
      data fxyz(17, 2,13),fxyz(17, 2,14)/-3.2567940d-04, 2.2047353d-04/
      data fxyz(17, 2,15),fxyz(17, 2,16)/-9.4225274d-06, 3.2354099d-06/
      data fxyz(17, 2,17),fxyz(17, 2,18)/-5.1096364d-05, 8.0973787d-05/
      data fxyz(17, 2,19),fxyz(17, 2,20)/-1.0141461d-04, 3.0839112d-05/
      data fxyz(17, 2,21),fxyz(17, 2,22)/ 1.9251764d-05,-5.5065220d-05/
      data fxyz(17, 2,23)/               -9.2836439d-05/
      data fxyz(17, 3, 1),fxyz(17, 3, 2)/-3.2216372d-04,-1.6431925d-04/
      data fxyz(17, 3, 3),fxyz(17, 3, 4)/ 1.6740598d-04, 1.7880356d-04/
      data fxyz(17, 3, 5),fxyz(17, 3, 6)/-2.0990954d-04,-1.5120013d-04/
      data fxyz(17, 3, 7),fxyz(17, 3, 8)/ 2.2019441d-04,-9.3039878d-05/
      data fxyz(17, 3, 9),fxyz(17, 3,10)/-8.0983752d-05, 2.2301742d-04/
      data fxyz(17, 3,11),fxyz(17, 3,12)/-3.1401010d-04, 7.4483933d-06/
      data fxyz(17, 3,13),fxyz(17, 3,14)/ 3.1004502d-04,-2.1403725d-04/
      data fxyz(17, 3,15),fxyz(17, 3,16)/ 2.0264923d-05,-6.8847953d-05/
      data fxyz(17, 3,17),fxyz(17, 3,18)/ 1.3126856d-04,-6.4301751d-05/
      data fxyz(17, 3,19),fxyz(17, 3,20)/-2.4301008d-04, 1.7909334d-04/
      data fxyz(17, 3,21),fxyz(17, 3,22)/ 1.6125996d-04,-1.7167655d-04/
      data fxyz(17, 3,23)/               -3.3180248d-04/
      data fxyz(17, 4, 1),fxyz(17, 4, 2)/ 9.1899998d-04, 5.0475674d-04/
      data fxyz(17, 4, 3),fxyz(17, 4, 4)/-3.4476762d-04,-4.1151211d-04/
      data fxyz(17, 4, 5),fxyz(17, 4, 6)/ 7.7173473d-04,-8.2167450d-05/
      data fxyz(17, 4, 7),fxyz(17, 4, 8)/-2.0880550d-04, 1.2448116d-04/
      data fxyz(17, 4, 9),fxyz(17, 4,10)/-3.8867825d-06,-5.1687161d-05/
      data fxyz(17, 4,11),fxyz(17, 4,12)/ 8.2662599d-05,-1.0875273d-06/
      data fxyz(17, 4,13),fxyz(17, 4,14)/-8.3008851d-05, 5.9158720d-05/
      data fxyz(17, 4,15),fxyz(17, 4,16)/-9.7174784d-06, 4.3563816d-05/
      data fxyz(17, 4,17),fxyz(17, 4,18)/-4.9528475d-05,-2.5623631d-04/
      data fxyz(17, 4,19),fxyz(17, 4,20)/ 1.0690853d-03,-5.6170181d-04/
      data fxyz(17, 4,21),fxyz(17, 4,22)/-4.6266594d-04, 6.7294181d-04/
      data fxyz(17, 4,23)/                1.2293017d-03/
      data fxyz(17, 5, 1),fxyz(17, 5, 2)/-5.3383297d-04,-3.0077343d-04/
      data fxyz(17, 5, 3),fxyz(17, 5, 4)/ 1.7416821d-04, 2.1699365d-04/
      data fxyz(17, 5, 5),fxyz(17, 5, 6)/-4.7207520d-04, 1.0854868d-04/
      data fxyz(17, 5, 7),fxyz(17, 5, 8)/ 9.9147198d-05,-5.6090652d-05/
      data fxyz(17, 5, 9),fxyz(17, 5,10)/ 8.7821382d-06, 1.2202702d-05/
      data fxyz(17, 5,11),fxyz(17, 5,12)/-2.1629395d-05, 1.6039277d-07/
      data fxyz(17, 5,13),fxyz(17, 5,14)/ 2.2125672d-05,-1.5045856d-05/
      data fxyz(17, 5,15),fxyz(17, 5,16)/ 8.7935314d-07, 4.8570249d-08/
      data fxyz(17, 5,17),fxyz(17, 5,18)/-1.2879021d-05, 2.5764661d-04/
      data fxyz(17, 5,19),fxyz(17, 5,20)/-8.4257741d-04, 4.1750259d-04/
      data fxyz(17, 5,21),fxyz(17, 5,22)/ 3.3736360d-04,-5.2202146d-04/
      data fxyz(17, 5,23)/               -9.4443822d-04/
      data fxyz(17, 6, 1),fxyz(17, 6, 2)/ 4.7513359d-05, 2.9679709d-05/
      data fxyz(17, 6, 3),fxyz(17, 6, 4)/-6.2311344d-06,-1.0263349d-05/
      data fxyz(17, 6, 5),fxyz(17, 6, 6)/ 4.5808566d-05,-1.2969856d-05/
      data fxyz(17, 6, 7),fxyz(17, 6, 8)/-3.1816091d-05, 1.6067586d-05/
      data fxyz(17, 6, 9),fxyz(17, 6,10)/-2.8949219d-06,-3.2488151d-06/
      data fxyz(17, 6,11),fxyz(17, 6,12)/ 5.6997686d-06, 5.0954969d-09/
      data fxyz(17, 6,13),fxyz(17, 6,14)/-5.9905150d-06, 4.0025117d-06/
      data fxyz(17, 6,15),fxyz(17, 6,16)/-5.2248221d-07, 1.2385258d-07/
      data fxyz(17, 6,17),fxyz(17, 6,18)/ 2.5710787d-06,-6.7346962d-05/
      data fxyz(17, 6,19),fxyz(17, 6,20)/ 2.1317728d-04,-1.0359524d-04/
      data fxyz(17, 6,21),fxyz(17, 6,22)/-8.3262100d-05, 1.3184473d-04/
      data fxyz(17, 6,23)/                2.3765009d-04/
      data fxyz(17, 7, 1),fxyz(17, 7, 2)/-7.8365880d-05,-4.3496606d-05/
      data fxyz(17, 7, 3),fxyz(17, 7, 4)/ 2.7484931d-05, 3.4027017d-05/
      data fxyz(17, 7, 5),fxyz(17, 7, 6)/-6.9664949d-05, 1.9765406d-05/
      data fxyz(17, 7, 7),fxyz(17, 7, 8)/ 4.0085129d-06,-3.3344131d-06/
      data fxyz(17, 7, 9),fxyz(17, 7,10)/ 3.2857897d-07, 8.8433131d-07/
      data fxyz(17, 7,11),fxyz(17, 7,12)/-1.5388163d-06,-7.0163204d-08/
      data fxyz(17, 7,13),fxyz(17, 7,14)/ 1.6567810d-06,-1.2571583d-06/
      data fxyz(17, 7,15),fxyz(17, 7,16)/ 3.5370680d-07,-4.2693587d-07/
      data fxyz(17, 7,17),fxyz(17, 7,18)/-5.2835344d-07, 1.7874194d-05/
      data fxyz(17, 7,19),fxyz(17, 7,20)/-5.5610956d-05, 2.6982005d-05/
      data fxyz(17, 7,21),fxyz(17, 7,22)/ 2.1664195d-05,-3.4339716d-05/
      data fxyz(17, 7,23)/               -6.1892957d-05/
      data fxyz(17, 8, 1),fxyz(17, 8, 2)/ 2.6230206d-05, 1.4665485d-05/
      data fxyz(17, 8, 3),fxyz(17, 8, 4)/-8.7943367d-06,-1.1107355d-05/
      data fxyz(17, 8, 5),fxyz(17, 8, 6)/ 2.3917557d-05,-8.4650627d-06/
      data fxyz(17, 8, 7),fxyz(17, 8, 8)/-9.0137788d-08, 6.7476898d-07/
      data fxyz(17, 8, 9),fxyz(17, 8,10)/-2.4623799d-08,-2.7365626d-07/
      data fxyz(17, 8,11),fxyz(17, 8,12)/ 3.2218765d-07, 5.7720119d-08/
      data fxyz(17, 8,13),fxyz(17, 8,14)/-5.5289901d-07, 4.9253522d-07/
      data fxyz(17, 8,15),fxyz(17, 8,16)/-4.0053550d-07, 4.0265478d-07/
      data fxyz(17, 8,17),fxyz(17, 8,18)/ 1.7069123d-08,-4.6099642d-06/
      data fxyz(17, 8,19),fxyz(17, 8,20)/ 1.5070922d-05,-7.4173117d-06/
      data fxyz(17, 8,21),fxyz(17, 8,22)/-5.9849354d-06, 9.3414163d-06/
      data fxyz(17, 8,23)/                1.6875681d-05/
      data fxyz(17, 9, 1),fxyz(17, 9, 2)/ 2.1254569d-04, 1.1423708d-04/
      data fxyz(17, 9, 3),fxyz(17, 9, 4)/-8.6772718d-05,-1.0366284d-04/
      data fxyz(17, 9, 5),fxyz(17, 9, 6)/ 1.8179756d-04,-4.0806095d-05/
      data fxyz(17, 9, 7),fxyz(17, 9, 8)/ 1.1634086d-05,-3.3389071d-06/
      data fxyz(17, 9, 9),fxyz(17, 9,10)/ 8.1097511d-07,-2.1568699d-07/
      data fxyz(17, 9,11),fxyz(17, 9,12)/ 2.8374553d-08,-9.2329721d-08/
      data fxyz(17, 9,13),fxyz(17, 9,14)/ 1.3173015d-07,-1.2895352d-07/
      data fxyz(17, 9,15),fxyz(17, 9,16)/ 1.7299675d-07,-2.1580245d-07/
      data fxyz(17, 9,17),fxyz(17, 9,18)/ 1.3344749d-07, 1.1852598d-06/
      data fxyz(17, 9,19),fxyz(17, 9,20)/-3.9856600d-06, 1.9190931d-06/
      data fxyz(17, 9,21),fxyz(17, 9,22)/ 1.5428365d-06,-2.4806338d-06/
      data fxyz(17, 9,23)/               -4.4585884d-06/
      data fxyz(17,10, 1),fxyz(17,10, 2)/-3.9494615d-04,-2.1007020d-04/
      data fxyz(17,10, 3),fxyz(17,10, 4)/ 1.6878692d-04, 1.9907176d-04/
      data fxyz(17,10, 5),fxyz(17,10, 6)/-3.3120956d-04, 5.9326463d-05/
      data fxyz(17,10, 7),fxyz(17,10, 8)/-1.9657499d-05, 4.3181914d-06/
      data fxyz(17,10, 9),fxyz(17,10,10)/-1.4315300d-06, 2.8123320d-07/
      data fxyz(17,10,11),fxyz(17,10,12)/-1.3045011d-07, 3.2757747d-08/
      data fxyz(17,10,13),fxyz(17,10,14)/ 3.9779830d-08,-9.2084530d-08/
      data fxyz(17,10,15),fxyz(17,10,16)/ 2.0461683d-08, 1.2500604d-07/
      data fxyz(17,10,17),fxyz(17,10,18)/-1.6803318d-07,-2.6064710d-07/
      data fxyz(17,10,19),fxyz(17,10,20)/ 1.0595159d-06,-5.3262937d-07/
      data fxyz(17,10,21),fxyz(17,10,22)/-4.3469437d-07, 6.6777586d-07/
      data fxyz(17,10,23)/                1.2083780d-06/
      data fxyz(17,11, 1),fxyz(17,11, 2)/ 3.8018974d-04, 2.0163048d-04/
      data fxyz(17,11, 3),fxyz(17,11, 4)/-1.6461738d-04,-1.9328082d-04/
      data fxyz(17,11, 5),fxyz(17,11, 6)/ 3.1628423d-04,-4.9761807d-05/
      data fxyz(17,11, 7),fxyz(17,11, 8)/ 1.7280557d-05,-4.0868236d-06/
      data fxyz(17,11, 9),fxyz(17,11,10)/ 9.7681064d-07,-3.0860783d-07/
      data fxyz(17,11,11),fxyz(17,11,12)/ 1.9500660d-08,-5.9741916d-09/
      data fxyz(17,11,13),fxyz(17,11,14)/-5.1976314d-08, 7.6250590d-08/
      data fxyz(17,11,15),fxyz(17,11,16)/-6.2087132d-09,-1.0161675d-07/
      data fxyz(17,11,17),fxyz(17,11,18)/ 1.1857030d-07, 3.9724735d-08/
      data fxyz(17,11,19),fxyz(17,11,20)/-3.1992099d-07, 1.4879737d-07/
      data fxyz(17,11,21),fxyz(17,11,22)/ 1.2134257d-07,-2.1010182d-07/
      data fxyz(17,11,23)/               -3.7209715d-07/
      data fxyz(17,12, 1),fxyz(17,12, 2)/-3.1110726d-04,-1.6735027d-04/
      data fxyz(17,12, 3),fxyz(17,12, 4)/ 1.2656858d-04, 1.5129932d-04/
      data fxyz(17,12, 5),fxyz(17,12, 6)/-2.6627325d-04, 5.9853912d-05/
      data fxyz(17,12, 7),fxyz(17,12, 8)/-1.6204373d-05, 4.6198755d-06/
      data fxyz(17,12, 9),fxyz(17,12,10)/-7.4173900d-07, 8.2214120d-08/
      data fxyz(17,12,11),fxyz(17,12,12)/-6.2385565d-09,-3.7507202d-08/
      data fxyz(17,12,13),fxyz(17,12,14)/ 2.2142306d-08,-2.0216934d-08/
      data fxyz(17,12,15),fxyz(17,12,16)/-3.2579749d-09, 4.1948330d-08/
      data fxyz(17,12,17),fxyz(17,12,18)/-4.4921104d-08,-2.3598404d-08/
      data fxyz(17,12,19),fxyz(17,12,20)/ 9.2431554d-08,-4.3777810d-08/
      data fxyz(17,12,21),fxyz(17,12,22)/-3.5252763d-08, 5.8331365d-08/
      data fxyz(17,12,23)/                1.0427730d-07/
      data fxyz(17,13, 1),fxyz(17,13, 2)/ 1.5669892d-04, 8.5910694d-05/
      data fxyz(17,13, 3),fxyz(17,13, 4)/-5.7939437d-05,-7.1657571d-05/
      data fxyz(17,13, 5),fxyz(17,13, 6)/ 1.4078323d-04,-4.9073084d-05/
      data fxyz(17,13, 7),fxyz(17,13, 8)/ 1.3514016d-05,-2.3055174d-06/
      data fxyz(17,13, 9),fxyz(17,13,10)/-7.0980610d-07, 8.5165103d-07/
      data fxyz(17,13,11),fxyz(17,13,12)/-1.9825806d-07, 7.3315052d-08/
      data fxyz(17,13,13),fxyz(17,13,14)/-4.3126837d-08, 3.5507274d-08/
      data fxyz(17,13,15),fxyz(17,13,16)/-3.4259634d-08, 1.1126362d-08/
      data fxyz(17,13,17),fxyz(17,13,18)/-5.0290339d-09, 5.6350526d-08/
      data fxyz(17,13,19),fxyz(17,13,20)/-4.3684212d-08, 2.0901067d-09/
      data fxyz(17,13,21),fxyz(17,13,22)/-3.6723658d-09,-2.0634322d-08/
      data fxyz(17,13,23)/               -3.0086561d-08/
      data fxyz(17,14, 1),fxyz(17,14, 2)/ 6.6374902d-05, 3.1633052d-05/
      data fxyz(17,14, 3),fxyz(17,14, 4)/-4.1740467d-05,-4.3618749d-05/
      data fxyz(17,14, 5),fxyz(17,14, 6)/ 3.9146178d-05, 3.8200676d-05/
      data fxyz(17,14, 7),fxyz(17,14, 8)/-1.3037962d-05,-2.0271702d-06/
      data fxyz(17,14, 9),fxyz(17,14,10)/ 5.4575044d-06,-3.8328117d-06/
      data fxyz(17,14,11),fxyz(17,14,12)/ 1.0819296d-06,-2.4348041d-07/
      data fxyz(17,14,13),fxyz(17,14,14)/ 7.8590562d-08,-6.1135671d-08/
      data fxyz(17,14,15),fxyz(17,14,16)/ 4.5189154d-08,-2.4676691d-08/
      data fxyz(17,14,17),fxyz(17,14,18)/ 2.3370434d-08,-2.9979124d-08/
      data fxyz(17,14,19),fxyz(17,14,20)/ 4.0659697d-08,-1.0901110d-08/
      data fxyz(17,14,21),fxyz(17,14,22)/-6.4058319d-09, 2.2678583d-08/
      data fxyz(17,14,23)/                3.7450051d-08/
      data fxyz(17,15, 1),fxyz(17,15, 2)/-5.2842622d-06, 1.1486757d-05/
      data fxyz(17,15, 3),fxyz(17,15, 4)/ 5.3345771d-05, 4.2983817d-05/
      data fxyz(17,15, 5),fxyz(17,15, 6)/ 5.2934572d-05,-1.6071357d-04/
      data fxyz(17,15, 7),fxyz(17,15, 8)/ 4.4337403d-05, 3.2209229d-06/
      data fxyz(17,15, 9),fxyz(17,15,10)/-1.9700478d-05, 1.4900294d-05/
      data fxyz(17,15,11),fxyz(17,15,12)/-3.7769456d-06, 1.0537066d-06/
      data fxyz(17,15,13),fxyz(17,15,14)/-2.4604538d-07, 8.7246518d-08/
      data fxyz(17,15,15),fxyz(17,15,16)/-4.7742536d-08, 2.0511513d-09/
      data fxyz(17,15,17),fxyz(17,15,18)/ 2.1673155d-08,-1.2399097d-08/
      data fxyz(17,15,19),fxyz(17,15,20)/ 9.5297814d-09,-2.3169686d-10/
      data fxyz(17,15,21),fxyz(17,15,22)/ 1.0254662d-09, 4.5011291d-09/
      data fxyz(17,15,23)/                6.4583486d-09/
      data fxyz(17,16, 1),fxyz(17,16, 2)/-1.3944726d-04,-1.0411563d-04/
      data fxyz(17,16, 3),fxyz(17,16, 4)/-4.7878286d-05,-1.3800062d-05/
      data fxyz(17,16, 5),fxyz(17,16, 6)/-2.4042853d-04, 3.7172611d-04/
      data fxyz(17,16, 7),fxyz(17,16, 8)/-1.2893398d-04, 1.8668202d-05/
      data fxyz(17,16, 9),fxyz(17,16,10)/ 2.7666703d-05,-2.1340603d-05/
      data fxyz(17,16,11),fxyz(17,16,12)/ 5.8267184d-06,-1.4707506d-06/
      data fxyz(17,16,13),fxyz(17,16,14)/ 4.2020581d-07,-1.0216286d-07/
      data fxyz(17,16,15),fxyz(17,16,16)/ 3.7401395d-08, 2.0293254d-08/
      data fxyz(17,16,17),fxyz(17,16,18)/-3.7113816d-08, 1.5424798d-08/
      data fxyz(17,16,19),fxyz(17,16,20)/-3.3582264d-09,-3.1735902d-09/
      data fxyz(17,16,21),fxyz(17,16,22)/-4.0692795d-09, 2.2453090d-10/
      data fxyz(17,16,23)/                1.9894586d-09/
      data fxyz(17,17, 1),fxyz(17,17, 2)/ 7.6068102d-05, 6.6275455d-05/
      data fxyz(17,17, 3),fxyz(17,17, 4)/ 6.2511218d-05, 3.2376207d-05/
      data fxyz(17,17, 5),fxyz(17,17, 6)/ 1.8681550d-04,-3.7595707d-04/
      data fxyz(17,17, 7),fxyz(17,17, 8)/ 1.7304142d-04,-4.0584269d-05/
      data fxyz(17,17, 9),fxyz(17,17,10)/-1.0253843d-05, 1.0856456d-05/
      data fxyz(17,17,11),fxyz(17,17,12)/-3.1413502d-06, 7.6168857d-07/
      data fxyz(17,17,13),fxyz(17,17,14)/-2.1971503d-07, 8.9533641d-08/
      data fxyz(17,17,15),fxyz(17,17,16)/-1.2275171d-08,-1.0342478d-08/
      data fxyz(17,17,17),fxyz(17,17,18)/ 2.3332416d-08,-2.2777143d-10/
      data fxyz(17,17,19),fxyz(17,17,20)/-2.0315956d-08, 1.7576696d-09/
      data fxyz(17,17,21),fxyz(17,17,22)/ 3.1514381d-10,-1.4545853d-08/
      data fxyz(17,17,23)/               -2.1865658d-08/
      data fxyz(17,18, 1),fxyz(17,18, 2)/-8.2652071d-06,-1.0907325d-05/
      data fxyz(17,18, 3),fxyz(17,18, 4)/-2.1381126d-05,-1.2959915d-05/
      data fxyz(17,18, 5),fxyz(17,18, 6)/-4.4592169d-05, 1.1805296d-04/
      data fxyz(17,18, 7),fxyz(17,18, 8)/-6.5759247d-05, 1.6855326d-05/
      data fxyz(17,18, 9),fxyz(17,18,10)/-1.1564652d-06,-1.3194258d-06/
      data fxyz(17,18,11),fxyz(17,18,12)/ 2.9756367d-07,-1.1859339d-07/
      data fxyz(17,18,13),fxyz(17,18,14)/ 2.1144197d-08,-3.3731310d-08/
      data fxyz(17,18,15),fxyz(17,18,16)/ 1.2803558d-08, 7.5059890d-09/
      data fxyz(17,18,17),fxyz(17,18,18)/-1.4847281d-08, 5.9338353d-09/
      data fxyz(17,18,19),fxyz(17,18,20)/-3.7794032d-09,-5.2630756d-09/
      data fxyz(17,18,21),fxyz(17,18,22)/-5.6912809d-09,-2.0665820d-09/
      data fxyz(17,18,23)/               -4.8924398d-10/
      data fxyz(17,19, 1),fxyz(17,19, 2)/-6.9274685d-06,-1.7354713d-05/
      data fxyz(17,19, 3),fxyz(17,19, 4)/-4.9764370d-05,-3.2149639d-05/
      data fxyz(17,19, 5),fxyz(17,19, 6)/-8.7813639d-05, 2.5729350d-04/
      data fxyz(17,19, 7),fxyz(17,19, 8)/-1.5005247d-04, 4.0954331d-05/
      data fxyz(17,19, 9),fxyz(17,19,10)/-5.4927800d-06,-8.1732417d-07/
      data fxyz(17,19,11),fxyz(17,19,12)/ 1.9162542d-07,-1.0952645d-07/
      data fxyz(17,19,13),fxyz(17,19,14)/ 1.0351978d-08,-6.7007274d-08/
      data fxyz(17,19,15),fxyz(17,19,16)/ 1.6523631d-08, 1.1501828d-08/
      data fxyz(17,19,17),fxyz(17,19,18)/-2.4848142d-08, 5.8628202d-09/
      data fxyz(17,19,19),fxyz(17,19,20)/ 3.1873548d-09,-8.8689623d-09/
      data fxyz(17,19,21),fxyz(17,19,22)/-8.7288919d-09, 2.6270733d-09/
      data fxyz(17,19,23)/                7.9638758d-09/
      data fxyz(18, 1, 1),fxyz(18, 1, 2)/ 2.2299560d-04, 1.1326235d-04/
      data fxyz(18, 1, 3),fxyz(18, 1, 4)/-1.0933303d-04,-1.3129081d-04/
      data fxyz(18, 1, 5),fxyz(18, 1, 6)/ 2.0109345d-04,-1.0637101d-04/
      data fxyz(18, 1, 7),fxyz(18, 1, 8)/ 1.4980596d-04, 3.9161113d-05/
      data fxyz(18, 1, 9),fxyz(18, 1,10)/-1.3601433d-04, 1.4334789d-04/
      data fxyz(18, 1,11),fxyz(18, 1,12)/-2.1484098d-04, 5.1200928d-05/
      data fxyz(18, 1,13),fxyz(18, 1,14)/ 1.8406719d-04,-1.3788977d-04/
      data fxyz(18, 1,15),fxyz(18, 1,16)/-6.4326850d-05, 3.0242928d-05/
      data fxyz(18, 1,17),fxyz(18, 1,18)/ 1.1624223d-04, 2.5417804d-06/
      data fxyz(18, 1,19),fxyz(18, 1,20)/ 8.2082623d-05,-1.0223047d-04/
      data fxyz(18, 1,21),fxyz(18, 1,22)/-9.4371914d-05, 5.0648391d-05/
      data fxyz(18, 1,23)/                1.2042015d-04/
      data fxyz(18, 2, 1),fxyz(18, 2, 2)/ 7.9373088d-05, 4.0833242d-05/
      data fxyz(18, 2, 3),fxyz(18, 2, 4)/-3.6860549d-05,-4.5420840d-05/
      data fxyz(18, 2, 5),fxyz(18, 2, 6)/ 7.5074403d-05,-4.9031269d-05/
      data fxyz(18, 2, 7),fxyz(18, 2, 8)/ 6.3636012d-05, 2.2645987d-05/
      data fxyz(18, 2, 9),fxyz(18, 2,10)/-6.7745676d-05, 7.0231250d-05/
      data fxyz(18, 2,11),fxyz(18, 2,12)/-1.0492848d-04, 2.5054943d-05/
      data fxyz(18, 2,13),fxyz(18, 2,14)/ 8.9748012d-05,-6.6999703d-05/
      data fxyz(18, 2,15),fxyz(18, 2,16)/-3.2872244d-05, 1.8957688d-05/
      data fxyz(18, 2,17),fxyz(18, 2,18)/ 4.5840618d-05, 7.9411968d-06/
      data fxyz(18, 2,19),fxyz(18, 2,20)/ 8.1413166d-06,-2.7119841d-05/
      data fxyz(18, 2,21),fxyz(18, 2,22)/-2.6329240d-05, 4.9789129d-06/
      data fxyz(18, 2,23)/                1.9800211d-05/
      data fxyz(18, 3, 1),fxyz(18, 3, 2)/ 1.4355648d-04, 8.2232038d-05/
      data fxyz(18, 3, 3),fxyz(18, 3, 4)/-4.8208918d-05,-4.9903909d-05/
      data fxyz(18, 3, 5),fxyz(18, 3, 6)/ 8.9012003d-05, 1.1813161d-04/
      data fxyz(18, 3, 7),fxyz(18, 3, 8)/-2.0153604d-04, 4.1979079d-05/
      data fxyz(18, 3, 9),fxyz(18, 3,10)/ 4.3193032d-05,-6.2384097d-05/
      data fxyz(18, 3,11),fxyz(18, 3,12)/ 9.8215946d-05,-2.3156490d-05/
      data fxyz(18, 3,13),fxyz(18, 3,14)/-8.6628455d-05, 6.7146512d-05/
      data fxyz(18, 3,15),fxyz(18, 3,16)/ 1.3452555d-05, 3.5698703d-05/
      data fxyz(18, 3,17),fxyz(18, 3,18)/-1.6796710d-04, 5.5680222d-05/
      data fxyz(18, 3,19),fxyz(18, 3,20)/ 1.3292262d-04,-5.4717966d-05/
      data fxyz(18, 3,21),fxyz(18, 3,22)/-4.6894801d-05, 1.0162996d-04/
      data fxyz(18, 3,23)/                1.7302769d-04/
      data fxyz(18, 4, 1),fxyz(18, 4, 2)/-5.1958081d-04,-2.7476684d-04/
      data fxyz(18, 4, 3),fxyz(18, 4, 4)/ 2.3381570d-04, 2.6184865d-04/
      data fxyz(18, 4, 5),fxyz(18, 4, 6)/-3.8689865d-04,-9.9086484d-05/
      data fxyz(18, 4, 7),fxyz(18, 4, 8)/ 1.5979928d-04,-6.4156595d-05/
      data fxyz(18, 4, 9),fxyz(18, 4,10)/ 4.7865661d-06, 1.3246018d-05/
      data fxyz(18, 4,11),fxyz(18, 4,12)/-2.4951342d-05, 5.8611459d-06/
      data fxyz(18, 4,13),fxyz(18, 4,14)/ 2.4195594d-05,-2.0103794d-05/
      data fxyz(18, 4,15),fxyz(18, 4,16)/ 7.7316820d-06,-4.5652175d-05/
      data fxyz(18, 4,17),fxyz(18, 4,18)/ 1.2014655d-04,-4.4769384d-05/
      data fxyz(18, 4,19),fxyz(18, 4,20)/-4.3782521d-04, 2.7716456d-04/
      data fxyz(18, 4,21),fxyz(18, 4,22)/ 2.4266846d-04,-2.9984083d-04/
      data fxyz(18, 4,23)/               -5.6221080d-04/
      data fxyz(18, 5, 1),fxyz(18, 5, 2)/ 3.6600087d-04, 1.8940851d-04/
      data fxyz(18, 5, 3),fxyz(18, 5, 4)/-1.7689617d-04,-1.9808434d-04/
      data fxyz(18, 5, 5),fxyz(18, 5, 6)/ 2.7416118d-04, 4.8178325d-05/
      data fxyz(18, 5, 7),fxyz(18, 5, 8)/-5.6099426d-05, 2.7276965d-05/
      data fxyz(18, 5, 9),fxyz(18, 5,10)/-3.3172159d-06,-2.8788186d-06/
      data fxyz(18, 5,11),fxyz(18, 5,12)/ 6.4401254d-06,-1.6160098d-06/
      data fxyz(18, 5,13),fxyz(18, 5,14)/-6.5807709d-06, 5.4665145d-06/
      data fxyz(18, 5,15),fxyz(18, 5,16)/-2.0104956d-06, 1.4194301d-05/
      data fxyz(18, 5,17),fxyz(18, 5,18)/-3.0143818d-05, 5.2257895d-06/
      data fxyz(18, 5,19),fxyz(18, 5,20)/ 3.4079714d-04,-2.2568170d-04/
      data fxyz(18, 5,21),fxyz(18, 5,22)/-1.9720410d-04, 2.2688674d-04/
      data fxyz(18, 5,23)/                4.3238982d-04/
      data fxyz(18, 6, 1),fxyz(18, 6, 2)/-8.7540637d-05,-4.4683212d-05/
      data fxyz(18, 6, 3),fxyz(18, 6, 4)/ 4.4457577d-05, 4.9176541d-05/
      data fxyz(18, 6, 5),fxyz(18, 6, 6)/-6.3559068d-05,-1.6756176d-05/
      data fxyz(18, 6, 7),fxyz(18, 6, 8)/ 1.5328362d-05,-7.8684053d-06/
      data fxyz(18, 6, 9),fxyz(18, 6,10)/ 7.5049281d-07, 6.3013460d-07/
      data fxyz(18, 6,11),fxyz(18, 6,12)/-1.7340393d-06, 4.3873443d-07/
      data fxyz(18, 6,13),fxyz(18, 6,14)/ 1.7591756d-06,-1.5759088d-06/
      data fxyz(18, 6,15),fxyz(18, 6,16)/ 4.3957084d-07,-4.0970574d-06/
      data fxyz(18, 6,17),fxyz(18, 6,18)/ 8.0903807d-06,-1.9665643d-06/
      data fxyz(18, 6,19),fxyz(18, 6,20)/-9.0777317d-05, 6.0820325d-05/
      data fxyz(18, 6,21),fxyz(18, 6,22)/ 5.3246449d-05,-6.0481814d-05/
      data fxyz(18, 6,23)/               -1.1557470d-04/
      data fxyz(18, 7, 1),fxyz(18, 7, 2)/ 4.0739284d-05, 2.1316464d-05/
      data fxyz(18, 7, 3),fxyz(18, 7, 4)/-1.8789153d-05,-2.1439899d-05/
      data fxyz(18, 7, 5),fxyz(18, 7, 6)/ 3.1919446d-05, 9.7810094d-07/
      data fxyz(18, 7, 7),fxyz(18, 7, 8)/-3.0843623d-06, 1.7477858d-06/
      data fxyz(18, 7, 9),fxyz(18, 7,10)/-2.0900234d-07,-2.3259956d-07/
      data fxyz(18, 7,11),fxyz(18, 7,12)/ 4.2279414d-07,-1.3139836d-07/
      data fxyz(18, 7,13),fxyz(18, 7,14)/-5.1632058d-07, 4.7155575d-07/
      data fxyz(18, 7,15),fxyz(18, 7,16)/-2.6555771d-07, 1.1641329d-06/
      data fxyz(18, 7,17),fxyz(18, 7,18)/-2.2682111d-06, 6.9884542d-07/
      data fxyz(18, 7,19),fxyz(18, 7,20)/ 2.5377289d-05,-1.6999750d-05/
      data fxyz(18, 7,21),fxyz(18, 7,22)/-1.4889573d-05, 1.6936581d-05/
      data fxyz(18, 7,23)/                3.2351500d-05/
      data fxyz(18, 8, 1),fxyz(18, 8, 2)/-1.4576057d-05,-7.7420126d-06/
      data fxyz(18, 8, 3),fxyz(18, 8, 4)/ 6.3115106d-06, 7.3455126d-06/
      data fxyz(18, 8, 5),fxyz(18, 8, 6)/-1.1878021d-05, 9.3397282d-07/
      data fxyz(18, 8, 7),fxyz(18, 8, 8)/ 5.9589618d-07,-3.3285297d-07/
      data fxyz(18, 8, 9),fxyz(18, 8,10)/ 5.0617648d-08, 5.3627131d-08/
      data fxyz(18, 8,11),fxyz(18, 8,12)/-1.1820957d-07,-2.9761631d-08/
      data fxyz(18, 8,13),fxyz(18, 8,14)/ 1.4914416d-07,-2.2257731d-07/
      data fxyz(18, 8,15),fxyz(18, 8,16)/ 2.0788821d-07,-3.9795640d-07/
      data fxyz(18, 8,17),fxyz(18, 8,18)/ 7.3343595d-07,-1.5620187d-07/
      data fxyz(18, 8,19),fxyz(18, 8,20)/-6.6570094d-06, 4.3858715d-06/
      data fxyz(18, 8,21),fxyz(18, 8,22)/ 3.8326681d-06,-4.4441957d-06/
      data fxyz(18, 8,23)/               -8.4542531d-06/
      data fxyz(18, 9, 1),fxyz(18, 9, 2)/-3.1994684d-05,-1.7361058d-05/
      data fxyz(18, 9, 3),fxyz(18, 9, 4)/ 1.2472766d-05, 1.5139674d-05/
      data fxyz(18, 9, 5),fxyz(18, 9, 6)/-2.8028689d-05, 8.0089350d-06/
      data fxyz(18, 9, 7),fxyz(18, 9, 8)/-2.2476215d-06, 6.2700810d-07/
      data fxyz(18, 9, 9),fxyz(18, 9,10)/-1.9234652d-07, 3.6608322d-08/
      data fxyz(18, 9,11),fxyz(18, 9,12)/-6.3480008d-09, 4.2991291d-08/
      data fxyz(18, 9,13),fxyz(18, 9,14)/-5.5637513d-08, 8.1126638d-08/
      data fxyz(18, 9,15),fxyz(18, 9,16)/-1.2036703d-07, 1.8094909d-07/
      data fxyz(18, 9,17),fxyz(18, 9,18)/-2.1233014d-07, 7.6677314d-08/
      data fxyz(18, 9,19),fxyz(18, 9,20)/ 1.7931418d-06,-1.2361109d-06/
      data fxyz(18, 9,21),fxyz(18, 9,22)/-1.0875294d-06, 1.1988160d-06/
      data fxyz(18, 9,23)/                2.3053989d-06/
      data fxyz(18,10, 1),fxyz(18,10, 2)/ 5.1404640d-05, 2.7999700d-05/
      data fxyz(18,10, 3),fxyz(18,10, 4)/-1.9763159d-05,-2.3946683d-05/
      data fxyz(18,10, 5),fxyz(18,10, 6)/ 4.4733798d-05,-1.1348228d-05/
      data fxyz(18,10, 7),fxyz(18,10, 8)/ 2.0614286d-06,-9.0460026d-07/
      data fxyz(18,10, 9),fxyz(18,10,10)/ 1.0325396d-07,-1.0283894d-07/
      data fxyz(18,10,11),fxyz(18,10,12)/ 1.6309905d-08,-1.1501703d-08/
      data fxyz(18,10,13),fxyz(18,10,14)/-6.3133826d-09, 3.2234094d-09/
      data fxyz(18,10,15),fxyz(18,10,16)/ 3.9560451d-08,-7.0397504d-08/
      data fxyz(18,10,17),fxyz(18,10,18)/ 9.2505321d-08,-5.0089466d-08/
      data fxyz(18,10,19),fxyz(18,10,20)/-4.8650653d-07, 3.1247881d-07/
      data fxyz(18,10,21),fxyz(18,10,22)/ 2.7406376d-07,-3.3284636d-07/
      data fxyz(18,10,23)/               -6.2631510d-07/
      data fxyz(18,11, 1),fxyz(18,11, 2)/-8.3262532d-05,-4.4470566d-05/
      data fxyz(18,11, 3),fxyz(18,11, 4)/ 3.4995579d-05, 4.1399695d-05/
      data fxyz(18,11, 5),fxyz(18,11, 6)/-7.0087028d-05, 1.2799201d-05/
      data fxyz(18,11, 7),fxyz(18,11, 8)/-3.2592204d-06, 8.6945860d-07/
      data fxyz(18,11, 9),fxyz(18,11,10)/-2.5339305d-07, 1.9731118d-08/
      data fxyz(18,11,11),fxyz(18,11,12)/-3.4724829d-08,-1.0032951d-08/
      data fxyz(18,11,13),fxyz(18,11,14)/ 1.8096939d-08,-1.4093368d-08/
      data fxyz(18,11,15),fxyz(18,11,16)/-4.8156673d-09, 3.4722248d-08/
      data fxyz(18,11,17),fxyz(18,11,18)/-5.8372341d-08, 2.4357473d-08/
      data fxyz(18,11,19),fxyz(18,11,20)/ 1.0280699d-07,-7.6061326d-08/
      data fxyz(18,11,21),fxyz(18,11,22)/-6.8375184d-08, 7.2062418d-08/
      data fxyz(18,11,23)/                1.3964960d-07/
      data fxyz(18,12, 1),fxyz(18,12, 2)/ 1.1587070d-04, 6.1868323d-05/
      data fxyz(18,12, 3),fxyz(18,12, 4)/-4.8685590d-05,-5.7725172d-05/
      data fxyz(18,12, 5),fxyz(18,12, 6)/ 9.8026653d-05,-1.9723037d-05/
      data fxyz(18,12, 7),fxyz(18,12, 8)/ 6.2415577d-06,-1.3099265d-06/
      data fxyz(18,12, 9),fxyz(18,12,10)/ 3.7735116d-07,-2.5500639d-08/
      data fxyz(18,12,11),fxyz(18,12,12)/-6.3244439d-09,-3.0867606d-09/
      data fxyz(18,12,13),fxyz(18,12,14)/ 1.0915438d-09, 6.8432605d-09/
      data fxyz(18,12,15),fxyz(18,12,16)/-8.2540505d-10,-2.1202981d-08/
      data fxyz(18,12,17),fxyz(18,12,18)/ 2.0269131d-08, 9.2082037d-10/
      data fxyz(18,12,19),fxyz(18,12,20)/-3.3874761d-08, 1.6384744d-08/
      data fxyz(18,12,21),fxyz(18,12,22)/ 1.3619711d-08,-2.2814631d-08/
      data fxyz(18,12,23)/               -4.0554666d-08/
      data fxyz(18,13, 1),fxyz(18,13, 2)/-5.8510244d-05,-3.1869279d-05/
      data fxyz(18,13, 3),fxyz(18,13, 4)/ 2.2412497d-05, 2.7323009d-05/
      data fxyz(18,13, 5),fxyz(18,13, 6)/-5.1511327d-05, 1.5147436d-05/
      data fxyz(18,13, 7),fxyz(18,13, 8)/-3.9475214d-06, 9.2599799d-07/
      data fxyz(18,13, 9),fxyz(18,13,10)/ 8.4549719d-08,-1.0793204d-07/
      data fxyz(18,13,11),fxyz(18,13,12)/ 7.1553349d-08,-1.3194323d-08/
      data fxyz(18,13,13),fxyz(18,13,14)/-5.6990095d-09, 1.7963952d-09/
      data fxyz(18,13,15),fxyz(18,13,16)/ 1.1941423d-08,-1.2923034d-08/
      data fxyz(18,13,17),fxyz(18,13,18)/ 6.7960838d-09,-5.4292795d-09/
      data fxyz(18,13,19),fxyz(18,13,20)/ 4.2273922d-08,-2.4829668d-08/
      data fxyz(18,13,21),fxyz(18,13,22)/-2.1078804d-08, 2.7270464d-08/
      data fxyz(18,13,23)/                5.0833686d-08/
      data fxyz(18,14, 1),fxyz(18,14, 2)/-2.0958581d-05,-9.4925144d-06/
      data fxyz(18,14, 3),fxyz(18,14, 4)/ 1.4724825d-05, 1.5342231d-05/
      data fxyz(18,14, 5),fxyz(18,14, 6)/-1.1962139d-05,-1.1697487d-05/
      data fxyz(18,14, 7),fxyz(18,14, 8)/ 1.2113402d-06,-4.2362257d-08/
      data fxyz(18,14, 9),fxyz(18,14,10)/-1.1276219d-06, 9.1850430d-07/
      data fxyz(18,14,11),fxyz(18,14,12)/-1.7219283d-07, 6.3787773d-08/
      data fxyz(18,14,13),fxyz(18,14,14)/-1.0973972d-08, 5.7033506d-09/
      data fxyz(18,14,15),fxyz(18,14,16)/-2.0545505d-08, 2.2758026d-08/
      data fxyz(18,14,17),fxyz(18,14,18)/ 2.3966886d-09, 9.2403602d-10/
      data fxyz(18,14,19),fxyz(18,14,20)/-2.0052656d-08, 1.3999908d-08/
      data fxyz(18,14,21),fxyz(18,14,22)/ 1.2249850d-08,-1.3052424d-08/
      data fxyz(18,14,23)/               -2.5326834d-08/
      data fxyz(18,15, 1),fxyz(18,15, 2)/ 1.4212262d-05, 2.1925865d-06/
      data fxyz(18,15, 3),fxyz(18,15, 4)/-2.4639412d-05,-2.2757196d-05/
      data fxyz(18,15, 5),fxyz(18,15, 6)/-5.3362759d-06, 4.2445496d-05/
      data fxyz(18,15, 7),fxyz(18,15, 8)/-5.7413571d-06, 6.2805151d-07/
      data fxyz(18,15, 9),fxyz(18,15,10)/ 5.0193854d-06,-3.0288911d-06/
      data fxyz(18,15,11),fxyz(18,15,12)/ 9.0646496d-07,-1.8448086d-07/
      data fxyz(18,15,13),fxyz(18,15,14)/ 6.5448235d-08,-2.9774239d-08/
      data fxyz(18,15,15),fxyz(18,15,16)/ 2.2057967d-08,-8.7578953d-09/
      data fxyz(18,15,17),fxyz(18,15,18)/-1.4765094d-08, 2.6117474d-08/
      data fxyz(18,15,19),fxyz(18,15,20)/-5.8487448d-09, 5.8859484d-10/
      data fxyz(18,15,21),fxyz(18,15,22)/-1.0713883d-09, 7.9118764d-10/
      data fxyz(18,15,23)/                1.2177276d-09/
      data fxyz(18,16, 1),fxyz(18,16, 2)/ 4.8126196d-05, 3.2789069d-05/
      data fxyz(18,16, 3),fxyz(18,16, 4)/ 5.0270114d-06,-3.9036172d-06/
      data fxyz(18,16, 5),fxyz(18,16, 6)/ 6.8511583d-05,-8.5833233d-05/
      data fxyz(18,16, 7),fxyz(18,16, 8)/ 2.6315915d-05,-3.7715410d-06/
      data fxyz(18,16, 9),fxyz(18,16,10)/-6.1207732d-06, 4.7056437d-06/
      data fxyz(18,16,11),fxyz(18,16,12)/-1.2411810d-06, 3.6036140d-07/
      data fxyz(18,16,13),fxyz(18,16,14)/-7.9349659d-08, 5.0172251d-08/
      data fxyz(18,16,15),fxyz(18,16,16)/-2.2818668d-08, 3.7024257d-09/
      data fxyz(18,16,17),fxyz(18,16,18)/ 1.4144630d-08,-1.8494447d-08/
      data fxyz(18,16,19),fxyz(18,16,20)/ 1.0792932d-08,-4.6351170d-09/
      data fxyz(18,16,21),fxyz(18,16,22)/-2.9031328d-09, 3.8649947d-09/
      data fxyz(18,16,23)/                7.4853166d-09/
      data fxyz(18,17, 1),fxyz(18,17, 2)/-4.6444637d-05,-2.9320477d-05/
      data fxyz(18,17, 3),fxyz(18,17, 4)/ 2.4857768d-06, 1.1040437d-05/
      data fxyz(18,17, 5),fxyz(18,17, 6)/-6.3539116d-05, 8.1875260d-05/
      data fxyz(18,17, 7),fxyz(18,17, 8)/-3.8909350d-05, 7.4633441d-06/
      data fxyz(18,17, 9),fxyz(18,17,10)/ 1.6352307d-06,-2.6532086d-06/
      data fxyz(18,17,11),fxyz(18,17,12)/ 5.8689513d-07,-2.1668584d-07/
      data fxyz(18,17,13),fxyz(18,17,14)/ 6.3861403d-08,-2.8951727d-08/
      data fxyz(18,17,15),fxyz(18,17,16)/ 2.6519736d-08, 3.8248288d-09/
      data fxyz(18,17,17),fxyz(18,17,18)/-9.1129959d-10,-5.6047162d-09/
      data fxyz(18,17,19),fxyz(18,17,20)/-4.3818576d-09,-3.8957934d-09/
      data fxyz(18,17,21),fxyz(18,17,22)/-3.8485136d-09,-4.5709770d-09/
      data fxyz(18,17,23)/               -4.8955186d-09/
      data fxyz(18,18, 1),fxyz(18,18, 2)/ 6.2250894d-06, 4.6072474d-06/
      data fxyz(18,18, 3),fxyz(18,18, 4)/ 2.3526319d-06, 2.3130125d-07/
      data fxyz(18,18, 5),fxyz(18,18, 6)/ 1.3092570d-05,-2.5594870d-05/
      data fxyz(18,18, 7),fxyz(18,18, 8)/ 1.4534194d-05,-3.5043659d-06/
      data fxyz(18,18, 9),fxyz(18,18,10)/ 2.6584537d-07, 2.6976656d-07/
      data fxyz(18,18,11),fxyz(18,18,12)/-9.5031553d-08, 1.4353002d-08/
      data fxyz(18,18,13),fxyz(18,18,14)/-2.5648539d-08, 9.5744314d-09/
      data fxyz(18,18,15),fxyz(18,18,16)/-9.2770050d-09,-1.8800629d-09/
      data fxyz(18,18,17),fxyz(18,18,18)/ 1.8942321d-09,-3.4944570d-09/
      data fxyz(18,18,19),fxyz(18,18,20)/ 2.2679050d-09,-6.7453788d-09/
      data fxyz(18,18,21),fxyz(18,18,22)/-6.2721876d-09, 3.7514021d-10/
      data fxyz(18,18,23)/                3.6034108d-09/
      data fxyz(18,19, 1),fxyz(18,19, 2)/ 1.6826085d-05, 1.1095752d-05/
      data fxyz(18,19, 3),fxyz(18,19, 4)/ 1.5314613d-06,-3.2197801d-06/
      data fxyz(18,19, 5),fxyz(18,19, 6)/ 3.0100717d-05,-5.4442537d-05/
      data fxyz(18,19, 7),fxyz(18,19, 8)/ 3.4072365d-05,-8.1284772d-06/
      data fxyz(18,19, 9),fxyz(18,19,10)/ 1.5037141d-06, 2.5507673d-07/
      data fxyz(18,19,11),fxyz(18,19,12)/-5.9814574d-08, 1.4510104d-08/
      data fxyz(18,19,13),fxyz(18,19,14)/-4.8666765d-08, 1.4486265d-08/
      data fxyz(18,19,15),fxyz(18,19,16)/-2.0749419d-08,-5.9200133d-09/
      data fxyz(18,19,17),fxyz(18,19,18)/-4.0351078d-10, 1.6956513d-09/
      data fxyz(18,19,19),fxyz(18,19,20)/ 2.6820813d-09,-8.5695615d-09/
      data fxyz(18,19,21),fxyz(18,19,22)/-8.2734921d-09, 1.4978035d-09/
      data fxyz(18,19,23)/                6.1366932d-09/
      data fxyz(19, 1, 1),fxyz(19, 1, 2)/-6.0592087d-05,-3.9515186d-05/
      data fxyz(19, 1, 3),fxyz(19, 1, 4)/-3.1551995d-08, 9.9104695d-06/
      data fxyz(19, 1, 5),fxyz(19, 1, 6)/-7.9283272d-05, 8.8538235d-05/
      data fxyz(19, 1, 7),fxyz(19, 1, 8)/-4.6895828d-05,-2.7546359d-05/
      data fxyz(19, 1, 9),fxyz(19, 1,10)/ 6.6623462d-05,-4.4498157d-05/
      data fxyz(19, 1,11),fxyz(19, 1,12)/ 6.1917036d-05,-1.3358897d-05/
      data fxyz(19, 1,13),fxyz(19, 1,14)/-4.6049121d-05, 3.1179103d-05/
      data fxyz(19, 1,15),fxyz(19, 1,16)/ 4.9735534d-05,-3.3096170d-05/
      data fxyz(19, 1,17),fxyz(19, 1,18)/-5.2608215d-06,-5.8225404d-05/
      data fxyz(19, 1,19),fxyz(19, 1,20)/ 1.1422878d-04,-4.8995843d-05/
      data fxyz(19, 1,21),fxyz(19, 1,22)/-3.7193992d-05, 6.7021371d-05/
      data fxyz(19, 1,23)/                1.1880237d-04/
      data fxyz(19, 2, 1),fxyz(19, 2, 2)/-2.9934027d-05,-1.9325304d-05/
      data fxyz(19, 2, 3),fxyz(19, 2, 4)/ 7.5509031d-07, 5.3971137d-06/
      data fxyz(19, 2, 5),fxyz(19, 2, 6)/-3.7893397d-05, 3.9696324d-05/
      data fxyz(19, 2, 7),fxyz(19, 2, 8)/-2.0217356d-05,-1.4832563d-05/
      data fxyz(19, 2, 9),fxyz(19, 2,10)/ 3.2974700d-05,-2.1751609d-05/
      data fxyz(19, 2,11),fxyz(19, 2,12)/ 3.0295120d-05,-6.4946365d-06/
      data fxyz(19, 2,13),fxyz(19, 2,14)/-2.2394565d-05, 1.5159973d-05/
      data fxyz(19, 2,15),fxyz(19, 2,16)/ 2.4788103d-05,-1.7844098d-05/
      data fxyz(19, 2,17),fxyz(19, 2,18)/ 9.6555820d-07,-3.4500271d-05/
      data fxyz(19, 2,19),fxyz(19, 2,20)/ 6.1590100d-05,-2.5502144d-05/
      data fxyz(19, 2,21),fxyz(19, 2,22)/-1.9011634d-05, 3.5628058d-05/
      data fxyz(19, 2,23)/                6.2857384d-05/
      data fxyz(19, 3, 1),fxyz(19, 3, 2)/-1.4829089d-04,-7.3142984d-05/
      data fxyz(19, 3, 3),fxyz(19, 3, 4)/ 8.5139477d-05, 8.9949821d-05/
      data fxyz(19, 3, 5),fxyz(19, 3, 6)/-9.2384360d-05,-7.6135731d-05/
      data fxyz(19, 3, 7),fxyz(19, 3, 8)/ 6.2441095d-05,-8.0031803d-06/
      data fxyz(19, 3, 9),fxyz(19, 3,10)/-2.5011250d-05, 1.9527104d-05/
      data fxyz(19, 3,11),fxyz(19, 3,12)/-2.7954779d-05, 6.3125294d-06/
      data fxyz(19, 3,13),fxyz(19, 3,14)/ 2.2100782d-05,-1.5412912d-05/
      data fxyz(19, 3,15),fxyz(19, 3,16)/-1.7766193d-05,-3.5234656d-06/
      data fxyz(19, 3,17),fxyz(19, 3,18)/ 4.3649409d-05,-1.8798643d-05/
      data fxyz(19, 3,19),fxyz(19, 3,20)/-1.5007701d-04, 1.0109812d-04/
      data fxyz(19, 3,21),fxyz(19, 3,22)/ 8.9302545d-05,-1.0289471d-04/
      data fxyz(19, 3,23)/               -1.9573225d-04/
      data fxyz(19, 4, 1),fxyz(19, 4, 2)/ 2.5490448d-04, 1.3206581d-04/
      data fxyz(19, 4, 3),fxyz(19, 4, 4)/-1.2306824d-04,-1.3722869d-04/
      data fxyz(19, 4, 5),fxyz(19, 4, 6)/ 1.8870761d-04, 4.2497721d-05/
      data fxyz(19, 4, 7),fxyz(19, 4, 8)/-5.0830378d-05, 1.9421651d-05/
      data fxyz(19, 4, 9),fxyz(19, 4,10)/ 2.1829552d-06,-4.0567619d-06/
      data fxyz(19, 4,11),fxyz(19, 4,12)/ 6.9932664d-06,-1.6804747d-06/
      data fxyz(19, 4,13),fxyz(19, 4,14)/-6.3466384d-06, 4.9523474d-06/
      data fxyz(19, 4,15),fxyz(19, 4,16)/ 1.3035381d-06, 1.4057203d-05/
      data fxyz(19, 4,17),fxyz(19, 4,18)/-4.1267889d-05, 2.4985253d-05/
      data fxyz(19, 4,19),fxyz(19, 4,20)/ 1.9485539d-04,-1.3317459d-04/
      data fxyz(19, 4,21),fxyz(19, 4,22)/-1.1784465d-04, 1.3353562d-04/
      data fxyz(19, 4,23)/                2.5493440d-04/
      data fxyz(19, 5, 1),fxyz(19, 5, 2)/-1.4969478d-04,-7.8162758d-05/
      data fxyz(19, 5, 3),fxyz(19, 5, 4)/ 6.9837053d-05, 7.9082446d-05/
      data fxyz(19, 5, 5),fxyz(19, 5, 6)/-1.1514433d-04,-1.1013875d-05/
      data fxyz(19, 5, 7),fxyz(19, 5, 8)/ 1.8422921d-05,-7.5580951d-06/
      data fxyz(19, 5, 9),fxyz(19, 5,10)/-1.2002077d-07, 8.0284985d-07/
      data fxyz(19, 5,11),fxyz(19, 5,12)/-1.9045157d-06, 3.4605541d-07/
      data fxyz(19, 5,13),fxyz(19, 5,14)/ 1.6333674d-06,-1.4397157d-06/
      data fxyz(19, 5,15),fxyz(19, 5,16)/-4.4891228d-07,-3.8247134d-06/
      data fxyz(19, 5,17),fxyz(19, 5,18)/ 1.1688618d-05, 2.2314294d-06/
      data fxyz(19, 5,19),fxyz(19, 5,20)/-1.2984107d-04, 8.2858978d-05/
      data fxyz(19, 5,21),fxyz(19, 5,22)/ 7.1878003d-05,-8.5917176d-05/
      data fxyz(19, 5,23)/               -1.6248319d-04/
      data fxyz(19, 6, 1),fxyz(19, 6, 2)/ 4.5169046d-05, 2.3618535d-05/
      data fxyz(19, 6, 3),fxyz(19, 6, 4)/-2.0963162d-05,-2.3759610d-05/
      data fxyz(19, 6, 5),fxyz(19, 6, 6)/ 3.4804326d-05, 3.2223302d-06/
      data fxyz(19, 6, 7),fxyz(19, 6, 8)/-4.9560566d-06, 1.8113566d-06/
      data fxyz(19, 6, 9),fxyz(19, 6,10)/-1.3098965d-07,-3.1144371d-07/
      data fxyz(19, 6,11),fxyz(19, 6,12)/ 4.9140162d-07,-5.0107452d-08/
      data fxyz(19, 6,13),fxyz(19, 6,14)/-4.4767296d-07, 3.3029250d-07/
      data fxyz(19, 6,15),fxyz(19, 6,16)/ 1.3916518d-08, 8.8224604d-07/
      data fxyz(19, 6,17),fxyz(19, 6,18)/-2.9506514d-06,-8.3412229d-07/
      data fxyz(19, 6,19),fxyz(19, 6,20)/ 4.0241012d-05,-2.5696919d-05/
      data fxyz(19, 6,21),fxyz(19, 6,22)/-2.2286500d-05, 2.6599335d-05/
      data fxyz(19, 6,23)/                5.0322169d-05/
      data fxyz(19, 7, 1),fxyz(19, 7, 2)/-1.5608301d-05,-8.2840048d-06/
      data fxyz(19, 7, 3),fxyz(19, 7, 4)/ 6.8011014d-06, 7.8682768d-06/
      data fxyz(19, 7, 5),fxyz(19, 7, 6)/-1.2552706d-05, 3.9932907d-07/
      data fxyz(19, 7, 7),fxyz(19, 7, 8)/ 1.1548502d-06,-3.9680123d-07/
      data fxyz(19, 7, 9),fxyz(19, 7,10)/ 6.2143631d-09, 8.2467070d-08/
      data fxyz(19, 7,11),fxyz(19, 7,12)/-1.6813875d-07,-5.0530022d-08/
      data fxyz(19, 7,13),fxyz(19, 7,14)/ 1.0788379d-07,-1.0762497d-07/
      data fxyz(19, 7,15),fxyz(19, 7,16)/ 3.2999146d-08,-2.8004430d-07/
      data fxyz(19, 7,17),fxyz(19, 7,18)/ 9.0736207d-07, 3.4697769d-07/
      data fxyz(19, 7,19),fxyz(19, 7,20)/-1.0269595d-05, 6.4212638d-06/
      data fxyz(19, 7,21),fxyz(19, 7,22)/ 5.5475784d-06,-6.7748534d-06/
      data fxyz(19, 7,23)/               -1.2758304d-05/
      data fxyz(19, 8, 1),fxyz(19, 8, 2)/ 5.3927150d-06, 2.8457410d-06/
      data fxyz(19, 8, 3),fxyz(19, 8, 4)/-2.3925614d-06,-2.7766846d-06/
      data fxyz(19, 8, 5),fxyz(19, 8, 6)/ 4.3822335d-06,-3.6913179d-07/
      data fxyz(19, 8, 7),fxyz(19, 8, 8)/-1.4414181d-07, 1.3565635d-07/
      data fxyz(19, 8, 9),fxyz(19, 8,10)/ 5.1264399d-08,-2.4695352d-08/
      data fxyz(19, 8,11),fxyz(19, 8,12)/ 3.0243907d-08, 1.9436653d-08/
      data fxyz(19, 8,13),fxyz(19, 8,14)/-5.2766145d-08, 5.1449809d-08/
      data fxyz(19, 8,15),fxyz(19, 8,16)/-3.8804604d-08, 1.2941922d-07/
      data fxyz(19, 8,17),fxyz(19, 8,18)/-2.2316280d-07,-3.5870599d-09/
      data fxyz(19, 8,19),fxyz(19, 8,20)/ 2.7930427d-06,-1.8520137d-06/
      data fxyz(19, 8,21),fxyz(19, 8,22)/-1.6163655d-06, 1.8504497d-06/
      data fxyz(19, 8,23)/                3.5311364d-06/
      data fxyz(19, 9, 1),fxyz(19, 9, 2)/ 8.7857710d-06, 4.7289306d-06/
      data fxyz(19, 9, 3),fxyz(19, 9, 4)/-3.5590255d-06,-4.2682541d-06/
      data fxyz(19, 9, 5),fxyz(19, 9, 6)/ 7.5658453d-06,-1.8526591d-06/
      data fxyz(19, 9, 7),fxyz(19, 9, 8)/ 6.2770870d-07,-2.0564932d-07/
      data fxyz(19, 9, 9),fxyz(19, 9,10)/ 2.5114355d-08, 7.9663585d-09/
      data fxyz(19, 9,11),fxyz(19, 9,12)/ 1.7876307d-08,-6.4667663d-09/
      data fxyz(19, 9,13),fxyz(19, 9,14)/ 2.4911953d-08,-2.3879341d-08/
      data fxyz(19, 9,15),fxyz(19, 9,16)/ 4.7115855d-08,-6.0090944d-08/
      data fxyz(19, 9,17),fxyz(19, 9,18)/ 9.7735230d-08, 6.1316061d-09/
      data fxyz(19, 9,19),fxyz(19, 9,20)/-7.5880818d-07, 4.4942981d-07/
      data fxyz(19, 9,21),fxyz(19, 9,22)/ 3.8635461d-07,-5.0650739d-07/
      data fxyz(19, 9,23)/               -9.3999637d-07/
      data fxyz(19,10, 1),fxyz(19,10, 2)/-1.0424305d-05,-5.5767886d-06/
      data fxyz(19,10, 3),fxyz(19,10, 4)/ 4.3328316d-06, 5.1691821d-06/
      data fxyz(19,10, 5),fxyz(19,10, 6)/-8.9221907d-06, 2.1209532d-06/
      data fxyz(19,10, 7),fxyz(19,10, 8)/-6.7486429d-07, 1.1691781d-07/
      data fxyz(19,10, 9),fxyz(19,10,10)/-1.0078457d-07, 8.5294705d-09/
      data fxyz(19,10,11),fxyz(19,10,12)/-1.0616051d-08, 1.7224360d-09/
      data fxyz(19,10,13),fxyz(19,10,14)/ 7.0471484d-09,-1.9854329d-10/
      data fxyz(19,10,15),fxyz(19,10,16)/-1.6270153d-08, 4.8771453d-08/
      data fxyz(19,10,17),fxyz(19,10,18)/-4.4740173d-08, 3.8162574d-09/
      data fxyz(19,10,19),fxyz(19,10,20)/ 1.8742756d-07,-1.3720858d-07/
      data fxyz(19,10,21),fxyz(19,10,22)/-1.2130155d-07, 1.2379943d-07/
      data fxyz(19,10,23)/                2.4242176d-07/
      data fxyz(19,11, 1),fxyz(19,11, 2)/ 2.1781857d-05, 1.1715889d-05/
      data fxyz(19,11, 3),fxyz(19,11, 4)/-8.8695547d-06,-1.0592410d-05/
      data fxyz(19,11, 5),fxyz(19,11, 6)/ 1.8607309d-05,-4.0609701d-06/
      data fxyz(19,11, 7),fxyz(19,11, 8)/ 1.0331736d-06,-2.7354816d-07/
      data fxyz(19,11, 9),fxyz(19,11,10)/ 7.7030617d-08,-7.2656948d-08/
      data fxyz(19,11,11),fxyz(19,11,12)/ 9.7511661d-09, 1.1712655d-08/
      data fxyz(19,11,13),fxyz(19,11,14)/-1.4639821d-08, 1.0902486d-08/
      data fxyz(19,11,15),fxyz(19,11,16)/-2.2164463d-09,-1.2049895d-08/
      data fxyz(19,11,17),fxyz(19,11,18)/ 2.2656256d-08,-2.2537280d-08/
      data fxyz(19,11,19),fxyz(19,11,20)/-5.6902155d-08, 3.9044507d-08/
      data fxyz(19,11,21),fxyz(19,11,22)/ 3.5287862d-08,-4.1875576d-08/
      data fxyz(19,11,23)/               -7.8886952d-08/
      data fxyz(19,12, 1),fxyz(19,12, 2)/-3.3219590d-05,-1.8017510d-05/
      data fxyz(19,12, 3),fxyz(19,12, 4)/ 1.3017866d-05, 1.5713760d-05/
      data fxyz(19,12, 5),fxyz(19,12, 6)/-2.8801086d-05, 7.2188198d-06/
      data fxyz(19,12, 7),fxyz(19,12, 8)/-1.6087133d-06, 5.5714144d-07/
      data fxyz(19,12, 9),fxyz(19,12,10)/-6.7427239d-08, 4.2719751d-08/
      data fxyz(19,12,11),fxyz(19,12,12)/-1.1881461d-08,-5.0042216d-09/
      data fxyz(19,12,13),fxyz(19,12,14)/ 1.2995664d-08,-7.7844998d-09/
      data fxyz(19,12,15),fxyz(19,12,16)/ 6.3149697d-09,-4.2614086d-09/
      data fxyz(19,12,17),fxyz(19,12,18)/-1.5774286d-08, 1.4980736d-08/
      data fxyz(19,12,19),fxyz(19,12,20)/ 1.5420489d-08,-1.2455037d-08/
      data fxyz(19,12,21),fxyz(19,12,22)/-1.1816667d-08, 1.2867008d-08/
      data fxyz(19,12,23)/                2.4556289d-08/
      data fxyz(19,13, 1),fxyz(19,13, 2)/ 1.5617611d-05, 8.5249587d-06/
      data fxyz(19,13, 3),fxyz(19,13, 4)/-5.9097296d-06,-7.2464717d-06/
      data fxyz(19,13, 5),fxyz(19,13, 6)/ 1.3871927d-05,-4.4335206d-06/
      data fxyz(19,13, 7),fxyz(19,13, 8)/ 1.0948889d-06,-2.4145707d-07/
      data fxyz(19,13, 9),fxyz(19,13,10)/ 3.9200880d-08, 8.7315593d-08/
      data fxyz(19,13,11),fxyz(19,13,12)/-7.1160167d-09, 6.2685941d-09/
      data fxyz(19,13,13),fxyz(19,13,14)/ 3.6334544d-10, 8.2081929d-09/
      data fxyz(19,13,15),fxyz(19,13,16)/-1.2632952d-08, 1.0819876d-08/
      data fxyz(19,13,17),fxyz(19,13,18)/-2.1577460d-09, 4.3437596d-09/
      data fxyz(19,13,19),fxyz(19,13,20)/ 2.6714053d-09,-3.3429348d-09/
      data fxyz(19,13,21),fxyz(19,13,22)/-3.2890896d-09, 2.4560247d-09/
      data fxyz(19,13,23)/                5.1514368d-09/
      data fxyz(19,14, 1),fxyz(19,14, 2)/ 3.2311643d-06, 1.1911945d-06/
      data fxyz(19,14, 3),fxyz(19,14, 4)/-3.2121342d-06,-3.1561958d-06/
      data fxyz(19,14, 5),fxyz(19,14, 6)/ 9.6744097d-07, 4.0702400d-06/
      data fxyz(19,14, 7),fxyz(19,14, 8)/-7.0018577d-07, 1.1330942d-07/
      data fxyz(19,14, 9),fxyz(19,14,10)/ 3.7442343d-07,-1.6531173d-07/
      data fxyz(19,14,11),fxyz(19,14,12)/ 9.1959592d-08,-1.3751993d-08/
      data fxyz(19,14,13),fxyz(19,14,14)/ 3.6393233d-09,-1.4275166d-09/
      data fxyz(19,14,15),fxyz(19,14,16)/ 2.2945750d-08,-2.0151352d-08/
      data fxyz(19,14,17),fxyz(19,14,18)/-1.0019659d-09, 6.4792485d-09/
      data fxyz(19,14,19),fxyz(19,14,20)/-3.7941630d-09, 5.5721716d-09/
      data fxyz(19,14,21),fxyz(19,14,22)/ 4.8770276d-09,-1.0135869d-09/
      data fxyz(19,14,23)/               -3.9479120d-09/
      data fxyz(19,15, 1),fxyz(19,15, 2)/-1.0788423d-05,-4.3890144d-06/
      data fxyz(19,15, 3),fxyz(19,15, 4)/ 9.3676954d-06, 9.2912355d-06/
      data fxyz(19,15, 5),fxyz(19,15, 6)/-4.0831746d-06,-1.1935322d-05/
      data fxyz(19,15, 7),fxyz(19,15, 8)/ 2.1818335d-06, 2.4110337d-07/
      data fxyz(19,15, 9),fxyz(19,15,10)/-1.1469840d-06, 9.0788573d-07/
      data fxyz(19,15,11),fxyz(19,15,12)/-2.0271381d-07, 8.1319774d-08/
      data fxyz(19,15,13),fxyz(19,15,14)/-2.2666970d-08, 1.4109934d-08/
      data fxyz(19,15,15),fxyz(19,15,16)/-1.9071718d-08, 2.0210340d-08/
      data fxyz(19,15,17),fxyz(19,15,18)/ 1.5746489d-08,-2.3036783d-08/
      data fxyz(19,15,19),fxyz(19,15,20)/ 1.2963021d-08,-3.4887206d-09/
      data fxyz(19,15,21),fxyz(19,15,22)/-1.4154318d-09, 4.6698660d-09/
      data fxyz(19,15,23)/                8.0625487d-09/
      data fxyz(19,16, 1),fxyz(19,16, 2)/-5.6559019d-06,-4.5741158d-06/
      data fxyz(19,16, 3),fxyz(19,16, 4)/-3.2822741d-06,-1.4862990d-06/
      data fxyz(19,16, 5),fxyz(19,16, 6)/-1.1758016d-05, 2.1283724d-05/
      data fxyz(19,16, 7),fxyz(19,16, 8)/-7.7783869d-06, 5.9303204d-07/
      data fxyz(19,16, 9),fxyz(19,16,10)/ 1.5258740d-06,-1.3244532d-06/
      data fxyz(19,16,11),fxyz(19,16,12)/ 3.4739180d-07,-9.7680890d-08/
      data fxyz(19,16,13),fxyz(19,16,14)/ 4.9712797d-08,-2.5695517d-08/
      data fxyz(19,16,15),fxyz(19,16,16)/ 1.9894477d-08,-8.4746593d-09/
      data fxyz(19,16,17),fxyz(19,16,18)/-9.5153446d-09, 2.3092593d-08/
      data fxyz(19,16,19),fxyz(19,16,20)/-1.4150660d-08, 1.6426991d-09/
      data fxyz(19,16,21),fxyz(19,16,22)/-4.7502973d-10,-5.6797447d-09/
      data fxyz(19,16,23)/               -8.6733394d-09/
      data fxyz(19,17, 1),fxyz(19,17, 2)/ 1.3336696d-05, 8.2235970d-06/
      data fxyz(19,17, 3),fxyz(19,17, 4)/-1.4311769d-06,-3.7094430d-06/
      data fxyz(19,17, 5),fxyz(19,17, 6)/ 1.7336662d-05,-2.0837296d-05/
      data fxyz(19,17, 7),fxyz(19,17, 8)/ 1.0706482d-05,-2.1741048d-06/
      data fxyz(19,17, 9),fxyz(19,17,10)/-6.2263992d-07, 6.0546515d-07/
      data fxyz(19,17,11),fxyz(19,17,12)/-2.3135590d-07, 4.9521462d-08/
      data fxyz(19,17,13),fxyz(19,17,14)/-3.7168536d-08, 2.5690138d-08/
      data fxyz(19,17,15),fxyz(19,17,16)/-1.4591554d-08, 3.2644979d-09/
      data fxyz(19,17,17),fxyz(19,17,18)/ 7.2798178d-09,-1.2273369d-08/
      data fxyz(19,17,19),fxyz(19,17,20)/ 1.1409689d-08,-8.0803175d-09/
      data fxyz(19,17,21),fxyz(19,17,22)/-6.5243811d-09, 5.1859430d-09/
      data fxyz(19,17,23)/                1.1065677d-08/
      data fxyz(19,18, 1),fxyz(19,18, 2)/-1.2401732d-06,-1.0147982d-06/
      data fxyz(19,18, 3),fxyz(19,18, 4)/-8.3928099d-07,-3.0127994d-07/
      data fxyz(19,18, 5),fxyz(19,18, 6)/-3.1668024d-06, 6.8298426d-06/
      data fxyz(19,18, 7),fxyz(19,18, 8)/-3.8827471d-06, 9.8958311d-07/
      data fxyz(19,18, 9),fxyz(19,18,10)/-5.2935377d-08,-7.5676675d-08/
      data fxyz(19,18,11),fxyz(19,18,12)/ 2.1229124d-08,-1.5473409d-08/
      data fxyz(19,18,13),fxyz(19,18,14)/ 7.0310536d-09,-1.0350456d-08/
      data fxyz(19,18,15),fxyz(19,18,16)/ 5.2073031d-09,-9.4649534d-10/
      data fxyz(19,18,17),fxyz(19,18,18)/-5.2257712d-09, 3.6554506d-09/
      data fxyz(19,18,19),fxyz(19,18,20)/-1.3976034d-08,-5.2201981d-10/
      data fxyz(19,18,21),fxyz(19,18,22)/-1.6569894d-09,-9.4361562d-09/
      data fxyz(19,18,23)/               -1.3369093d-08/
      data fxyz(19,19, 1),fxyz(19,19, 2)/-6.2257660d-06,-3.9571626d-06/
      data fxyz(19,19, 3),fxyz(19,19, 4)/ 1.1238671d-07, 1.4979383d-06/
      data fxyz(19,19, 5),fxyz(19,19, 6)/-9.4993688d-06, 1.4557507d-05/
      data fxyz(19,19, 7),fxyz(19,19, 8)/-9.0222340d-06, 2.4587497d-06/
      data fxyz(19,19, 9),fxyz(19,19,10)/-2.5986467d-07,-1.0801313d-08/
      data fxyz(19,19,11),fxyz(19,19,12)/ 3.6290511d-08,-1.9840501d-08/
      data fxyz(19,19,13),fxyz(19,19,14)/ 1.3778951d-08,-2.1412121d-08/
      data fxyz(19,19,15),fxyz(19,19,16)/ 9.4961920d-09,-6.0030276d-10/
      data fxyz(19,19,17),fxyz(19,19,18)/-9.3597170d-09, 4.9286184d-09/
      data fxyz(19,19,19),fxyz(19,19,20)/-2.4805737d-08, 2.0987595d-09/
      data fxyz(19,19,21),fxyz(19,19,22)/ 9.1332895d-11,-1.6776031d-08/
      data fxyz(19,19,23)/               -2.5182781d-08/
      data fxyz(20, 1, 1),fxyz(20, 1, 2)/ 1.0240925d-05, 4.2148606d-06/
      data fxyz(20, 1, 3),fxyz(20, 1, 4)/-7.3011204d-06,-9.7458946d-06/
      data fxyz(20, 1, 5),fxyz(20, 1, 6)/ 1.3993958d-05,-2.6430688d-05/
      data fxyz(20, 1, 7),fxyz(20, 1, 8)/ 2.2011507d-05, 1.2922877d-05/
      data fxyz(20, 1, 9),fxyz(20, 1,10)/-1.7581993d-05, 1.5920258d-05/
      data fxyz(20, 1,11),fxyz(20, 1,12)/-1.7422485d-05, 5.8317795d-06/
      data fxyz(20, 1,13),fxyz(20, 1,14)/ 1.5946184d-05,-7.3057687d-06/
      data fxyz(20, 1,15),fxyz(20, 1,16)/-1.3529934d-05, 1.8638100d-05/
      data fxyz(20, 1,17),fxyz(20, 1,18)/-6.4483765d-06, 7.6831617d-05/
      data fxyz(20, 1,19),fxyz(20, 1,20)/-1.2325406d-04, 3.1995474d-05/
      data fxyz(20, 1,21),fxyz(20, 1,22)/ 1.9058664d-05,-7.1506820d-05/
      data fxyz(20, 1,23)/               -1.1722053d-04/
      data fxyz(20, 2, 1),fxyz(20, 2, 2)/ 1.1629975d-05, 5.3554128d-06/
      data fxyz(20, 2, 3),fxyz(20, 2, 4)/-7.1919044d-06,-8.7637064d-06/
      data fxyz(20, 2, 5),fxyz(20, 2, 6)/ 1.1642621d-05,-1.1947054d-05/
      data fxyz(20, 2, 7),fxyz(20, 2, 8)/ 1.0291244d-05, 6.8131366d-06/
      data fxyz(20, 2, 9),fxyz(20, 2,10)/-8.6142326d-06, 7.8384279d-06/
      data fxyz(20, 2,11),fxyz(20, 2,12)/-8.4884246d-06, 2.8633698d-06/
      data fxyz(20, 2,13),fxyz(20, 2,14)/ 7.7915084d-06,-3.4921017d-06/
      data fxyz(20, 2,15),fxyz(20, 2,16)/-6.6852377d-06, 9.7256579d-06/
      data fxyz(20, 2,17),fxyz(20, 2,18)/-4.1522271d-06, 3.9913618d-05/
      data fxyz(20, 2,19),fxyz(20, 2,20)/-5.8146007d-05, 1.2895649d-05/
      data fxyz(20, 2,21),fxyz(20, 2,22)/ 6.6672123d-06,-3.3232261d-05/
      data fxyz(20, 2,23)/               -5.3512931d-05/
      data fxyz(20, 3, 1),fxyz(20, 3, 2)/ 1.4049804d-04, 7.2125757d-05/
      data fxyz(20, 3, 3),fxyz(20, 3, 4)/-6.9895564d-05,-7.7754320d-05/
      data fxyz(20, 3, 5),fxyz(20, 3, 6)/ 1.0356078d-04, 2.2616699d-05/
      data fxyz(20, 3, 7),fxyz(20, 3, 8)/-1.7091292d-05, 8.6493978d-07/
      data fxyz(20, 3, 9),fxyz(20, 3,10)/ 7.1589809d-06,-6.6345336d-06/
      data fxyz(20, 3,11),fxyz(20, 3,12)/ 8.1990074d-06,-2.4474018d-06/
      data fxyz(20, 3,13),fxyz(20, 3,14)/-7.3010968d-06, 4.1114604d-06/
      data fxyz(20, 3,15),fxyz(20, 3,16)/ 5.2134545d-06,-1.8257530d-06/
      data fxyz(20, 3,17),fxyz(20, 3,18)/-6.9508978d-06,-1.3542404d-05/
      data fxyz(20, 3,19),fxyz(20, 3,20)/ 1.4153840d-04,-8.5056953d-05/
      data fxyz(20, 3,21),fxyz(20, 3,22)/-7.2676006d-05, 9.2014606d-05/
      data fxyz(20, 3,23)/                1.7217181d-04/
      data fxyz(20, 4, 1),fxyz(20, 4, 2)/-1.7681045d-04,-9.0808171d-05/
      data fxyz(20, 4, 3),fxyz(20, 4, 4)/ 8.7245841d-05, 9.8159874d-05/
      data fxyz(20, 4, 5),fxyz(20, 4, 6)/-1.3446430d-04,-1.3099966d-05/
      data fxyz(20, 4, 7),fxyz(20, 4, 8)/ 1.0344128d-05,-5.6486610d-06/
      data fxyz(20, 4, 9),fxyz(20, 4,10)/-8.8689254d-07, 1.2614652d-06/
      data fxyz(20, 4,11),fxyz(20, 4,12)/-2.2503607d-06, 4.4009351d-07/
      data fxyz(20, 4,13),fxyz(20, 4,14)/ 1.8890532d-06,-1.5496106d-06/
      data fxyz(20, 4,15),fxyz(20, 4,16)/-5.7683854d-07,-4.1407724d-06/
      data fxyz(20, 4,17),fxyz(20, 4,18)/ 8.0823018d-06,-9.1153484d-06/
      data fxyz(20, 4,19),fxyz(20, 4,20)/-1.2979443d-04, 9.2975164d-05/
      data fxyz(20, 4,21),fxyz(20, 4,22)/ 8.2311957d-05,-8.7141605d-05/
      data fxyz(20, 4,23)/               -1.6906346d-04/
      data fxyz(20, 5, 1),fxyz(20, 5, 2)/ 7.4426364d-05, 3.8696309d-05/
      data fxyz(20, 5, 3),fxyz(20, 5, 4)/-3.5139508d-05,-3.9914536d-05/
      data fxyz(20, 5, 5),fxyz(20, 5, 6)/ 5.7796419d-05, 2.8009512d-06/
      data fxyz(20, 5, 7),fxyz(20, 5, 8)/-4.0900332d-06, 2.0003257d-06/
      data fxyz(20, 5, 9),fxyz(20, 5,10)/-9.6984436d-08,-3.8054517d-07/
      data fxyz(20, 5,11),fxyz(20, 5,12)/ 5.4369363d-07,-1.0753988d-07/
      data fxyz(20, 5,13),fxyz(20, 5,14)/-5.5473377d-07, 3.4217245d-07/
      data fxyz(20, 5,15),fxyz(20, 5,16)/ 3.2653992d-08, 9.9100008d-07/
      data fxyz(20, 5,17),fxyz(20, 5,18)/-2.0511813d-06,-2.5801162d-07/
      data fxyz(20, 5,19),fxyz(20, 5,20)/ 5.9850752d-05,-4.0152211d-05/
      data fxyz(20, 5,21),fxyz(20, 5,22)/-3.5083692d-05, 3.9576673d-05/
      data fxyz(20, 5,23)/                7.5769782d-05/
      data fxyz(20, 6, 1),fxyz(20, 6, 2)/-1.6992432d-05,-8.8828690d-06/
      data fxyz(20, 6, 3),fxyz(20, 6, 4)/ 7.8604449d-06, 8.9705089d-06/
      data fxyz(20, 6, 5),fxyz(20, 6, 6)/-1.3323125d-05,-3.4147281d-07/
      data fxyz(20, 6, 7),fxyz(20, 6, 8)/ 1.2565247d-06,-6.0707656d-07/
      data fxyz(20, 6, 9),fxyz(20, 6,10)/-6.0101269d-08, 6.0951561d-08/
      data fxyz(20, 6,11),fxyz(20, 6,12)/-1.5030490d-07, 1.5180229d-08/
      data fxyz(20, 6,13),fxyz(20, 6,14)/ 1.6385999d-07,-1.2924471d-07/
      data fxyz(20, 6,15),fxyz(20, 6,16)/-5.3760199d-08,-2.9891909d-07/
      data fxyz(20, 6,17),fxyz(20, 6,18)/ 6.6988934d-07, 4.9076195d-07/
      data fxyz(20, 6,19),fxyz(20, 6,20)/-1.4627769d-05, 9.5108797d-06/
      data fxyz(20, 6,21),fxyz(20, 6,22)/ 8.2585111d-06,-9.6182940d-06/
      data fxyz(20, 6,23)/               -1.8294768d-05/
      data fxyz(20, 7, 1),fxyz(20, 7, 2)/ 6.1986797d-06, 3.2188342d-06/
      data fxyz(20, 7, 3),fxyz(20, 7, 4)/-2.9278226d-06,-3.3455935d-06/
      data fxyz(20, 7, 5),fxyz(20, 7, 6)/ 4.8899175d-06,-6.7882472d-08/
      data fxyz(20, 7, 7),fxyz(20, 7, 8)/-1.3516018d-07, 1.7775445d-07/
      data fxyz(20, 7, 9),fxyz(20, 7,10)/ 7.1856435d-08,-2.6213627d-08/
      data fxyz(20, 7,11),fxyz(20, 7,12)/ 1.0451481d-08,-3.1412303d-08/
      data fxyz(20, 7,13),fxyz(20, 7,14)/-7.6773008d-08, 5.6246786d-08/
      data fxyz(20, 7,15),fxyz(20, 7,16)/ 3.4592890d-08, 1.0458189d-07/
      data fxyz(20, 7,17),fxyz(20, 7,18)/-1.2887667d-07, 3.5941308d-08/
      data fxyz(20, 7,19),fxyz(20, 7,20)/ 4.1230437d-06,-2.8500623d-06/
      data fxyz(20, 7,21),fxyz(20, 7,22)/-2.5015867d-06, 2.7291415d-06/
      data fxyz(20, 7,23)/                5.2630748d-06/
      data fxyz(20, 8, 1),fxyz(20, 8, 2)/-1.9706964d-06,-1.0646442d-06/
      data fxyz(20, 8, 3),fxyz(20, 8, 4)/ 7.9545308d-07, 9.3797885d-07/
      data fxyz(20, 8, 5),fxyz(20, 8, 6)/-1.6347472d-06, 1.6719013d-07/
      data fxyz(20, 8, 7),fxyz(20, 8, 8)/ 4.9277710d-08, 3.3374113d-08/
      data fxyz(20, 8, 9),fxyz(20, 8,10)/-3.4642367d-09, 2.3229570d-08/
      data fxyz(20, 8,11),fxyz(20, 8,12)/ 9.2910549d-09, 1.0318648d-08/
      data fxyz(20, 8,13),fxyz(20, 8,14)/ 3.1466508d-08,-2.3139215d-08/
      data fxyz(20, 8,15),fxyz(20, 8,16)/ 8.8311594d-09,-6.0732293d-10/
      data fxyz(20, 8,17),fxyz(20, 8,18)/ 7.5918949d-08, 1.4539581d-08/
      data fxyz(20, 8,19),fxyz(20, 8,20)/-1.0956929d-06, 6.7024026d-07/
      data fxyz(20, 8,21),fxyz(20, 8,22)/ 5.7842057d-07,-7.2841419d-07/
      data fxyz(20, 8,23)/               -1.3627557d-06/
      data fxyz(20, 9, 1),fxyz(20, 9, 2)/-2.3052206d-06,-1.2659004d-06/
      data fxyz(20, 9, 3),fxyz(20, 9, 4)/ 8.4758009d-07, 1.0464402d-06/
      data fxyz(20, 9, 5),fxyz(20, 9, 6)/-2.0613408d-06, 6.7768092d-07/
      data fxyz(20, 9, 7),fxyz(20, 9, 8)/-1.7430279d-07, 3.7747797d-08/
      data fxyz(20, 9, 9),fxyz(20, 9,10)/-4.2026415d-09, 3.3234478d-08/
      data fxyz(20, 9,11),fxyz(20, 9,12)/-6.7981385d-09, 8.4148618d-09/
      data fxyz(20, 9,13),fxyz(20, 9,14)/ 4.7941863d-09, 1.7212662d-08/
      data fxyz(20, 9,15),fxyz(20, 9,16)/-6.3840849d-09, 2.6977509d-08/
      data fxyz(20, 9,17),fxyz(20, 9,18)/-3.2746173d-08, 1.1428240d-08/
      data fxyz(20, 9,19),fxyz(20, 9,20)/ 2.9207675d-07,-2.2360991d-07/
      data fxyz(20, 9,21),fxyz(20, 9,22)/-1.9886455d-07, 1.9309531d-07/
      data fxyz(20, 9,23)/                3.8260867d-07/
      data fxyz(20,10, 1),fxyz(20,10, 2)/ 4.2263143d-06, 2.2649695d-06/
      data fxyz(20,10, 3),fxyz(20,10, 4)/-1.7519415d-06,-2.0773903d-06/
      data fxyz(20,10, 5),fxyz(20,10, 6)/ 3.5667648d-06,-6.5541795d-07/
      data fxyz(20,10, 7),fxyz(20,10, 8)/ 2.0952445d-07,-1.0255239d-07/
      data fxyz(20,10, 9),fxyz(20,10,10)/ 4.3096854d-08,-8.8713300d-08/
      data fxyz(20,10,11),fxyz(20,10,12)/ 5.1708748d-08,-3.5135225d-09/
      data fxyz(20,10,13),fxyz(20,10,14)/-1.1025138d-08, 1.1409399d-08/
      data fxyz(20,10,15),fxyz(20,10,16)/ 8.7195343d-09,-1.7460074d-08/
      data fxyz(20,10,17),fxyz(20,10,18)/ 3.6372927d-08,-2.0604330d-08/
      data fxyz(20,10,19),fxyz(20,10,20)/-8.9049343d-08, 4.6952684d-08/
      data fxyz(20,10,21),fxyz(20,10,22)/ 4.0691008d-08,-6.4002642d-08/
      data fxyz(20,10,23)/               -1.1452946d-07/
      data fxyz(20,11, 1),fxyz(20,11, 2)/-6.2224928d-06,-3.3448612d-06/
      data fxyz(20,11, 3),fxyz(20,11, 4)/ 2.5411621d-06, 3.0317402d-06/
      data fxyz(20,11, 5),fxyz(20,11, 6)/-5.3071736d-06, 1.1361789d-06/
      data fxyz(20,11, 7),fxyz(20,11, 8)/-2.6453761d-07, 1.1703198d-07/
      data fxyz(20,11, 9),fxyz(20,11,10)/-1.2544241d-07, 1.2621292d-07/
      data fxyz(20,11,11),fxyz(20,11,12)/-7.2050422d-08, 7.6329511d-09/
      data fxyz(20,11,13),fxyz(20,11,14)/ 1.7500146d-08,-1.8151148d-08/
      data fxyz(20,11,15),fxyz(20,11,16)/ 7.7614511d-09, 1.1004593d-09/
      data fxyz(20,11,17),fxyz(20,11,18)/-1.4772843d-08, 1.0717165d-08/
      data fxyz(20,11,19),fxyz(20,11,20)/ 1.5813992d-08,-1.4808651d-08/
      data fxyz(20,11,21),fxyz(20,11,22)/-1.3888363d-08, 1.2132841d-08/
      data fxyz(20,11,23)/                2.4521480d-08/
      data fxyz(20,12, 1),fxyz(20,12, 2)/ 9.1111774d-06, 4.8859651d-06/
      data fxyz(20,12, 3),fxyz(20,12, 4)/-3.7481381d-06,-4.4830038d-06/
      data fxyz(20,12, 5),fxyz(20,12, 6)/ 7.8254282d-06,-1.9118094d-06/
      data fxyz(20,12, 7),fxyz(20,12, 8)/ 5.8398935d-07,-9.0691292d-08/
      data fxyz(20,12, 9),fxyz(20,12,10)/ 1.1542762d-07,-8.8589125d-08/
      data fxyz(20,12,11),fxyz(20,12,12)/ 4.5468223d-08, 1.2446624d-08/
      data fxyz(20,12,13),fxyz(20,12,14)/-1.8245445d-08, 1.4654280d-08/
      data fxyz(20,12,15),fxyz(20,12,16)/-1.6423450d-08, 1.2746414d-08/
      data fxyz(20,12,17),fxyz(20,12,18)/-1.4134532d-09,-7.7174466d-09/
      data fxyz(20,12,19),fxyz(20,12,20)/-3.2049449d-09, 4.9822491d-09/
      data fxyz(20,12,21),fxyz(20,12,22)/ 5.0150882d-09,-3.3363015d-09/
      data fxyz(20,12,23)/               -7.2248596d-09/
      data fxyz(20,13, 1),fxyz(20,13, 2)/-6.1065975d-06,-3.3038468d-06/
      data fxyz(20,13, 3),fxyz(20,13, 4)/ 2.4195430d-06, 2.9139260d-06/
      data fxyz(20,13, 5),fxyz(20,13, 6)/-5.2813790d-06, 1.3091485d-06/
      data fxyz(20,13, 7),fxyz(20,13, 8)/-4.1967056d-07, 1.1570390d-07/
      data fxyz(20,13, 9),fxyz(20,13,10)/ 2.5150140d-08, 3.5954012d-08/
      data fxyz(20,13,11),fxyz(20,13,12)/ 3.1096601d-09,-9.0605149d-09/
      data fxyz(20,13,13),fxyz(20,13,14)/ 2.0424436d-08,-1.4201366d-08/
      data fxyz(20,13,15),fxyz(20,13,16)/ 2.7009078d-08,-3.9373337d-08/
      data fxyz(20,13,17),fxyz(20,13,18)/ 1.6388320d-08, 5.7564181d-09/
      data fxyz(20,13,19),fxyz(20,13,20)/ 2.0198538d-09,-2.0300207d-09/
      data fxyz(20,13,21),fxyz(20,13,22)/-2.1176769d-09, 2.3704784d-09/
      data fxyz(20,13,23)/                4.4415759d-09/
      data fxyz(20,14, 1),fxyz(20,14, 2)/-2.2560948d-06,-9.8917500d-07/
      data fxyz(20,14, 3),fxyz(20,14, 4)/ 1.7008806d-06, 1.7442325d-06/
      data fxyz(20,14, 5),fxyz(20,14, 6)/-1.1625825d-06,-1.6058167d-06/
      data fxyz(20,14, 7),fxyz(20,14, 8)/ 1.2807988d-07,-2.1713610d-08/
      data fxyz(20,14, 9),fxyz(20,14,10)/-4.8397387d-08, 9.3180594d-08/
      data fxyz(20,14,11),fxyz(20,14,12)/-8.2753236d-09, 1.9098807d-08/
      data fxyz(20,14,13),fxyz(20,14,14)/-4.9101948d-09, 1.0567759d-08/
      data fxyz(20,14,15),fxyz(20,14,16)/-2.9667567d-08, 4.7762337d-08/
      data fxyz(20,14,17),fxyz(20,14,18)/-1.6997905d-08,-1.2573873d-08/
      data fxyz(20,14,19),fxyz(20,14,20)/ 1.0537610d-08,-4.2447184d-10/
      data fxyz(20,14,21),fxyz(20,14,22)/ 9.1542314d-10, 5.1780301d-09/
      data fxyz(20,14,23)/                7.5245520d-09/
      data fxyz(20,15, 1),fxyz(20,15, 2)/ 3.3309766d-06, 1.4142578d-06/
      data fxyz(20,15, 3),fxyz(20,15, 4)/-2.6876431d-06,-2.6970118d-06/
      data fxyz(20,15, 5),fxyz(20,15, 6)/ 1.4517329d-06, 3.1904452d-06/
      data fxyz(20,15, 7),fxyz(20,15, 8)/-7.5409409d-07,-6.0582754d-08/
      data fxyz(20,15, 9),fxyz(20,15,10)/ 3.8278275d-07,-2.5182419d-07/
      data fxyz(20,15,11),fxyz(20,15,12)/ 9.3822009d-08,-3.3442111d-08/
      data fxyz(20,15,13),fxyz(20,15,14)/ 1.4476404d-08, 4.6012966d-10/
      data fxyz(20,15,15),fxyz(20,15,16)/ 2.0212012d-08,-1.9250091d-08/
      data fxyz(20,15,17),fxyz(20,15,18)/-2.9247722d-09, 2.2129759d-08/
      data fxyz(20,15,19),fxyz(20,15,20)/-1.5112766d-08, 2.8576068d-09/
      data fxyz(20,15,21),fxyz(20,15,22)/ 6.9168759d-10,-6.4490891d-09/
      data fxyz(20,15,23)/               -1.0359030d-08/
      data fxyz(20,16, 1),fxyz(20,16, 2)/ 3.2563071d-06, 2.2350339d-06/
      data fxyz(20,16, 3),fxyz(20,16, 4)/ 4.1144708d-07,-2.2705083d-07/
      data fxyz(20,16, 5),fxyz(20,16, 6)/ 4.7890255d-06,-6.3211615d-06/
      data fxyz(20,16, 7),fxyz(20,16, 8)/ 2.2957297d-06,-3.4327065d-07/
      data fxyz(20,16, 9),fxyz(20,16,10)/-5.7366083d-07, 3.7775333d-07/
      data fxyz(20,16,11),fxyz(20,16,12)/-1.3447948d-07, 5.3711080d-08/
      data fxyz(20,16,13),fxyz(20,16,14)/-2.8813583d-08, 1.1341811d-08/
      data fxyz(20,16,15),fxyz(20,16,16)/-7.8318807d-09, 5.4333610d-09/
      data fxyz(20,16,17),fxyz(20,16,18)/ 1.6969345d-08,-1.5540615d-08/
      data fxyz(20,16,19),fxyz(20,16,20)/ 1.1299745d-08,-6.2104811d-09/
      data fxyz(20,16,21),fxyz(20,16,22)/-4.5485286d-09, 4.6519350d-09/
      data fxyz(20,16,23)/                9.3886720d-09/
      data fxyz(20,17, 1),fxyz(20,17, 2)/-3.8421347d-06,-2.4435367d-06/
      data fxyz(20,17, 3),fxyz(20,17, 4)/ 1.4973986d-07, 8.5624796d-07/
      data fxyz(20,17, 5),fxyz(20,17, 6)/-5.2695691d-06, 6.7554869d-06/
      data fxyz(20,17, 7),fxyz(20,17, 8)/-3.1446586d-06, 6.9292834d-07/
      data fxyz(20,17, 9),fxyz(20,17,10)/ 1.5664968d-07,-2.5002026d-07/
      data fxyz(20,17,11),fxyz(20,17,12)/ 5.4483103d-08,-4.6001160d-08/
      data fxyz(20,17,13),fxyz(20,17,14)/ 1.9188363d-08,-1.7549731d-08/
      data fxyz(20,17,15),fxyz(20,17,16)/ 6.5189846d-09,-2.4377063d-09/
      data fxyz(20,17,17),fxyz(20,17,18)/-6.9878522d-09, 6.1233727d-09/
      data fxyz(20,17,19),fxyz(20,17,20)/-8.3003175d-09, 3.7292342d-09/
      data fxyz(20,17,21),fxyz(20,17,22)/ 2.7780880d-09,-4.4957325d-09/
      data fxyz(20,17,23)/               -8.1438210d-09/
      data fxyz(20,18, 1),fxyz(20,18, 2)/ 4.8106830d-07, 3.4999761d-07/
      data fxyz(20,18, 3),fxyz(20,18, 4)/ 1.6672771d-07,-4.0650462d-09/
      data fxyz(20,18, 5),fxyz(20,18, 6)/ 1.0331686d-06,-2.0808230d-06/
      data fxyz(20,18, 7),fxyz(20,18, 8)/ 1.2343752d-06,-2.7456902d-07/
      data fxyz(20,18, 9),fxyz(20,18,10)/ 2.7680189d-08, 3.2187026d-08/
      data fxyz(20,18,11),fxyz(20,18,12)/-9.1714471d-09, 5.4828514d-09/
      data fxyz(20,18,13),fxyz(20,18,14)/-4.6510964d-09, 5.1124470d-09/
      data fxyz(20,18,15),fxyz(20,18,16)/-5.3982969d-09, 5.0985307d-10/
      data fxyz(20,18,17),fxyz(20,18,18)/-4.1411733d-09,-2.1569853d-09/
      data fxyz(20,18,19),fxyz(20,18,20)/ 1.5112698d-09,-6.7123847d-09/
      data fxyz(20,18,21),fxyz(20,18,22)/-6.3560891d-09, 8.6087407d-11/
      data fxyz(20,18,23)/                3.1874486d-09/
      data fxyz(20,19, 1),fxyz(20,19, 2)/ 1.5409442d-06, 1.0086448d-06/
      data fxyz(20,19, 3),fxyz(20,19, 4)/ 1.0408840d-07,-3.0906040d-07/
      data fxyz(20,19, 5),fxyz(20,19, 6)/ 2.6612400d-06,-4.6562877d-06/
      data fxyz(20,19, 7),fxyz(20,19, 8)/ 2.8078599d-06,-6.6958171d-07/
      data fxyz(20,19, 9),fxyz(20,19,10)/ 1.4421927d-07, 5.4399772d-08/
      data fxyz(20,19,11),fxyz(20,19,12)/-6.4967225d-10, 1.3767934d-08/
      data fxyz(20,19,13),fxyz(20,19,14)/-7.9644399d-09, 1.3044991d-08/
      data fxyz(20,19,15),fxyz(20,19,16)/-9.8103936d-09, 3.6637625d-10/
      data fxyz(20,19,17),fxyz(20,19,18)/-8.9527447d-09,-1.8818159d-09/
      data fxyz(20,19,19),fxyz(20,19,20)/ 2.9195286d-09,-1.1330765d-08/
      data fxyz(20,19,21),fxyz(20,19,22)/-1.0787182d-08, 7.4519663d-10/
      data fxyz(20,19,23)/                6.2719289d-09/
      data fxyz(21, 1, 1),fxyz(21, 1, 2)/ 1.0315510d-05, 7.1608895d-06/
      data fxyz(21, 1, 3),fxyz(21, 1, 4)/ 8.5120588d-07, 6.3325056d-08/
      data fxyz(21, 1, 5),fxyz(21, 1, 6)/ 1.0312413d-05,-1.5027024d-06/
      data fxyz(21, 1, 7),fxyz(21, 1, 8)/-5.3229623d-06,-3.7482715d-06/
      data fxyz(21, 1, 9),fxyz(21, 1,10)/ 1.9808948d-06,-2.9516170d-06/
      data fxyz(21, 1,11),fxyz(21, 1,12)/ 2.5791685d-06,-1.0380124d-06/
      data fxyz(21, 1,13),fxyz(21, 1,14)/-2.6776396d-06, 7.8521425d-07/
      data fxyz(21, 1,15),fxyz(21, 1,16)/ 1.4182336d-06,-4.5283142d-06/
      data fxyz(21, 1,17),fxyz(21, 1,18)/-7.9053793d-07,-1.8106328d-05/
      data fxyz(21, 1,19),fxyz(21, 1,20)/ 2.9633577d-05,-4.9409367d-06/
      data fxyz(21, 1,21),fxyz(21, 1,22)/-1.9089108d-06, 1.7505473d-05/
      data fxyz(21, 1,23)/                2.7374060d-05/
      data fxyz(21, 2, 1),fxyz(21, 2, 2)/ 1.6594092d-06, 1.7973151d-06/
      data fxyz(21, 2, 3),fxyz(21, 2, 4)/ 2.1920799d-06, 2.0183887d-06/
      data fxyz(21, 2, 5),fxyz(21, 2, 6)/ 2.4920799d-06,-9.4595859d-07/
      data fxyz(21, 2, 7),fxyz(21, 2, 8)/-2.6822063d-06,-1.9032533d-06/
      data fxyz(21, 2, 9),fxyz(21, 2,10)/ 9.7625724d-07,-1.4429087d-06/
      data fxyz(21, 2,11),fxyz(21, 2,12)/ 1.2526963d-06,-5.1704929d-07/
      data fxyz(21, 2,13),fxyz(21, 2,14)/-1.3124348d-06, 3.7775741d-07/
      data fxyz(21, 2,15),fxyz(21, 2,16)/ 7.0781884d-07,-2.3033071d-06/
      data fxyz(21, 2,17),fxyz(21, 2,18)/-3.7318955d-07,-9.2295077d-06/
      data fxyz(21, 2,19),fxyz(21, 2,20)/ 1.2456368d-05,-7.1937524d-07/
      data fxyz(21, 2,21),fxyz(21, 2,22)/ 6.0188535d-07, 7.1713260d-06/
      data fxyz(21, 2,23)/                1.0589401d-05/
      data fxyz(21, 3, 1),fxyz(21, 3, 2)/-3.5958318d-05,-1.9558978d-05/
      data fxyz(21, 3, 3),fxyz(21, 3, 4)/ 1.4189264d-05, 1.6627361d-05/
      data fxyz(21, 3, 5),fxyz(21, 3, 6)/-2.9311366d-05, 6.1313453d-07/
      data fxyz(21, 3, 7),fxyz(21, 3, 8)/ 3.3813637d-06, 8.5065524d-07/
      data fxyz(21, 3, 9),fxyz(21, 3,10)/-6.7605299d-07, 1.3440983d-06/
      data fxyz(21, 3,11),fxyz(21, 3,12)/-1.1500192d-06, 5.0385689d-07/
      data fxyz(21, 3,13),fxyz(21, 3,14)/ 1.2912621d-06,-3.9570869d-07/
      data fxyz(21, 3,15),fxyz(21, 3,16)/-4.0490977d-07, 1.2323147d-06/
      data fxyz(21, 3,17),fxyz(21, 3,18)/ 1.8234175d-06, 6.5722613d-06/
      data fxyz(21, 3,19),fxyz(21, 3,20)/-3.3500791d-05, 1.6467448d-05/
      data fxyz(21, 3,21),fxyz(21, 3,22)/ 1.3458355d-05,-2.1464418d-05/
      data fxyz(21, 3,23)/               -3.8564137d-05/
      data fxyz(21, 4, 1),fxyz(21, 4, 2)/ 2.7789646d-05, 1.5059245d-05/
      data fxyz(21, 4, 3),fxyz(21, 4, 4)/-1.1110638d-05,-1.3052347d-05/
      data fxyz(21, 4, 5),fxyz(21, 4, 6)/ 2.2826083d-05,-1.3359951d-06/
      data fxyz(21, 4, 7),fxyz(21, 4, 8)/-2.5349155d-06, 4.2344725d-07/
      data fxyz(21, 4, 9),fxyz(21, 4,10)/-6.1509018d-08,-3.4294030d-07/
      data fxyz(21, 4,11),fxyz(21, 4,12)/ 2.1411679d-07,-2.2503786d-07/
      data fxyz(21, 4,13),fxyz(21, 4,14)/-4.3976352d-07, 1.1185760d-07/
      data fxyz(21, 4,15),fxyz(21, 4,16)/-1.0953974d-07, 1.8078505d-07/
      data fxyz(21, 4,17),fxyz(21, 4,18)/-2.2073808d-06,-1.8632891d-06/
      data fxyz(21, 4,19),fxyz(21, 4,20)/ 2.1271878d-05,-1.1724145d-05/
      data fxyz(21, 4,21),fxyz(21, 4,22)/-9.8950317d-06, 1.3955427d-05/
      data fxyz(21, 4,23)/                2.5573404d-05/
      data fxyz(21, 5, 1),fxyz(21, 5, 2)/-6.5214689d-06,-3.6144493d-06/
      data fxyz(21, 5, 3),fxyz(21, 5, 4)/ 2.3416287d-06, 2.8198160d-06/
      data fxyz(21, 5, 5),fxyz(21, 5, 6)/-5.5271981d-06, 6.5133922d-07/
      data fxyz(21, 5, 7),fxyz(21, 5, 8)/ 1.1228735d-06,-3.1395230d-07/
      data fxyz(21, 5, 9),fxyz(21, 5,10)/-3.3505432d-08,-1.6508522d-09/
      data fxyz(21, 5,11),fxyz(21, 5,12)/-5.8582280d-08, 9.3894373d-08/
      data fxyz(21, 5,13),fxyz(21, 5,14)/ 1.2051178d-07,-1.0670221d-07/
      data fxyz(21, 5,15),fxyz(21, 5,16)/-2.7754622d-08,-1.0938123d-07/
      data fxyz(21, 5,17),fxyz(21, 5,18)/ 8.3799488d-07, 9.9049729d-07/
      data fxyz(21, 5,19),fxyz(21, 5,20)/-5.8752602d-06, 2.8932867d-06/
      data fxyz(21, 5,21),fxyz(21, 5,22)/ 2.3731405d-06,-3.7946755d-06/
      data fxyz(21, 5,23)/               -6.8116954d-06/
      data fxyz(21, 6, 1),fxyz(21, 6, 2)/ 2.8471067d-06, 1.4758819d-06/
      data fxyz(21, 6, 3),fxyz(21, 6, 4)/-1.3627682d-06,-1.5372237d-06/
      data fxyz(21, 6, 5),fxyz(21, 6, 6)/ 2.1737041d-06, 2.3027336d-07/
      data fxyz(21, 6, 7),fxyz(21, 6, 8)/-1.6037425d-07, 6.4590424d-08/
      data fxyz(21, 6, 9),fxyz(21, 6,10)/-2.2295001d-08,-4.7837304d-09/
      data fxyz(21, 6,11),fxyz(21, 6,12)/ 3.8449828d-09,-5.0552739d-08/
      data fxyz(21, 6,13),fxyz(21, 6,14)/-4.3065094d-08, 4.0710357d-08/
      data fxyz(21, 6,15),fxyz(21, 6,16)/-1.4471229d-08, 1.0645218d-08/
      data fxyz(21, 6,17),fxyz(21, 6,18)/-9.2959758d-08, 5.1395861d-08/
      data fxyz(21, 6,19),fxyz(21, 6,20)/ 2.3873025d-06,-1.5950985d-06/
      data fxyz(21, 6,21),fxyz(21, 6,22)/-1.3959991d-06, 1.5909049d-06/
      data fxyz(21, 6,23)/                3.0378867d-06/
      data fxyz(21, 7, 1),fxyz(21, 7, 2)/-8.1076166d-07,-4.6733382d-07/
      data fxyz(21, 7, 3),fxyz(21, 7, 4)/ 2.3393589d-07, 2.9456830d-07/
      data fxyz(21, 7, 5),fxyz(21, 7, 6)/-7.0986343d-07, 9.8724386d-08/
      data fxyz(21, 7, 7),fxyz(21, 7, 8)/ 1.0161469d-07, 5.8379633d-08/
      data fxyz(21, 7, 9),fxyz(21, 7,10)/ 4.1348466d-08, 1.1380974d-08/
      data fxyz(21, 7,11),fxyz(21, 7,12)/-1.5785740d-08,-4.5860200d-09/
      data fxyz(21, 7,13),fxyz(21, 7,14)/-1.1616214d-09,-1.1048793d-08/
      data fxyz(21, 7,15),fxyz(21, 7,16)/ 4.2238968d-08, 4.8859080d-08/
      data fxyz(21, 7,17),fxyz(21, 7,18)/ 6.9320887d-08, 8.0088324d-08/
      data fxyz(21, 7,19),fxyz(21, 7,20)/-5.4439279d-07, 2.1917368d-07/
      data fxyz(21, 7,21),fxyz(21, 7,22)/ 1.7261615d-07,-3.5816264d-07/
      data fxyz(21, 7,23)/               -6.1827475d-07/
      data fxyz(21, 8, 1),fxyz(21, 8, 2)/ 3.1201130d-07, 1.4723953d-07/
      data fxyz(21, 8, 3),fxyz(21, 8, 4)/-1.9305122d-07,-2.1543655d-07/
      data fxyz(21, 8, 5),fxyz(21, 8, 6)/ 2.3678083d-07,-2.3768581d-08/
      data fxyz(21, 8, 7),fxyz(21, 8, 8)/ 4.1235665d-08, 1.9762048d-08/
      data fxyz(21, 8, 9),fxyz(21, 8,10)/ 1.5329889d-08, 1.0160052d-08/
      data fxyz(21, 8,11),fxyz(21, 8,12)/ 1.3764916d-08, 2.0455089d-08/
      data fxyz(21, 8,13),fxyz(21, 8,14)/ 1.3350965d-08, 1.4161562d-08/
      data fxyz(21, 8,15),fxyz(21, 8,16)/-1.0041812d-08, 4.8513141d-09/
      data fxyz(21, 8,17),fxyz(21, 8,18)/ 2.1715914d-08,-5.5132865d-10/
      data fxyz(21, 8,19),fxyz(21, 8,20)/ 1.5085673d-07,-1.4463185d-07/
      data fxyz(21, 8,21),fxyz(21, 8,22)/-1.3089913d-07, 9.5925829d-08/
      data fxyz(21, 8,23)/                2.0543954d-07/
      data fxyz(21, 9, 1),fxyz(21, 9, 2)/ 5.0139734d-07, 2.5766984d-07/
      data fxyz(21, 9, 3),fxyz(21, 9, 4)/-2.4352758d-07,-2.8041020d-07/
      data fxyz(21, 9, 5),fxyz(21, 9, 6)/ 4.0520031d-07,-5.1841897d-08/
      data fxyz(21, 9, 7),fxyz(21, 9, 8)/ 2.5438186d-08, 6.0922992d-10/
      data fxyz(21, 9, 9),fxyz(21, 9,10)/ 2.9374414d-08,-8.9122757d-09/
      data fxyz(21, 9,11),fxyz(21, 9,12)/ 1.9832022d-08,-5.0815442d-09/
      data fxyz(21, 9,13),fxyz(21, 9,14)/ 3.8083060d-09, 9.4506008d-09/
      data fxyz(21, 9,15),fxyz(21, 9,16)/ 2.0819354d-08,-8.4338512d-10/
      data fxyz(21, 9,17),fxyz(21, 9,18)/ 3.4425260d-09,-1.2918610d-09/
      data fxyz(21, 9,19),fxyz(21, 9,20)/-5.6478261d-08, 1.0776787d-08/
      data fxyz(21, 9,21),fxyz(21, 9,22)/ 6.6673523d-09,-4.0040523d-08/
      data fxyz(21, 9,23)/               -6.2933380d-08/
      data fxyz(21,10, 1),fxyz(21,10, 2)/-2.8716639d-07,-1.6425731d-07/
      data fxyz(21,10, 3),fxyz(21,10, 4)/ 8.1222608d-08, 1.1254183d-07/
      data fxyz(21,10, 5),fxyz(21,10, 6)/-2.8953421d-07, 1.8262200d-07/
      data fxyz(21,10, 7),fxyz(21,10, 8)/-2.8113854d-08, 1.7374549d-09/
      data fxyz(21,10, 9),fxyz(21,10,10)/-6.7781674d-08, 9.0454468d-08/
      data fxyz(21,10,11),fxyz(21,10,12)/-5.3533464d-08, 1.3642928d-08/
      data fxyz(21,10,13),fxyz(21,10,14)/ 5.0056486d-09,-2.4962527d-09/
      data fxyz(21,10,15),fxyz(21,10,16)/-6.5487673d-10, 8.9540121d-09/
      data fxyz(21,10,17),fxyz(21,10,18)/-6.8556225d-09, 5.0660167d-09/
      data fxyz(21,10,19),fxyz(21,10,20)/ 8.7662279d-09,-1.7268397d-08/
      data fxyz(21,10,21),fxyz(21,10,22)/-1.6516037d-08, 5.7567907d-09/
      data fxyz(21,10,23)/                1.6351406d-08/
      data fxyz(21,11, 1),fxyz(21,11, 2)/ 1.1596804d-06, 6.1178944d-07/
      data fxyz(21,11, 3),fxyz(21,11, 4)/-5.1215006d-07,-5.9984704d-07/
      data fxyz(21,11, 5),fxyz(21,11, 6)/ 9.6257736d-07,-1.5577429d-07/
      data fxyz(21,11, 7),fxyz(21,11, 8)/ 9.3289356d-08,-3.8996294d-08/
      data fxyz(21,11, 9),fxyz(21,11,10)/ 8.2335553d-08,-1.4136273d-07/
      data fxyz(21,11,11),fxyz(21,11,12)/ 8.7200360d-08,-1.2619339d-08/
      data fxyz(21,11,13),fxyz(21,11,14)/-5.2380467d-09, 7.6411120d-09/
      data fxyz(21,11,15),fxyz(21,11,16)/-4.2412283d-09, 1.6184879d-09/
      data fxyz(21,11,17),fxyz(21,11,18)/ 2.2181102d-09,-7.0898182d-09/
      data fxyz(21,11,19),fxyz(21,11,20)/-5.5485392d-09, 3.0448303d-09/
      data fxyz(21,11,21),fxyz(21,11,22)/ 2.9276328d-09,-5.0797493d-09/
      data fxyz(21,11,23)/               -8.8477803d-09/
      data fxyz(21,12, 1),fxyz(21,12, 2)/-1.9253864d-06,-1.0453716d-06/
      data fxyz(21,12, 3),fxyz(21,12, 4)/ 7.5529576d-07, 9.0418340d-07/
      data fxyz(21,12, 5),fxyz(21,12, 6)/-1.6409222d-06, 3.0792827d-07/
      data fxyz(21,12, 7),fxyz(21,12, 8)/-5.8757833d-08, 8.4180101d-08/
      data fxyz(21,12, 9),fxyz(21,12,10)/-5.6592918d-08, 9.1732948d-08/
      data fxyz(21,12,11),fxyz(21,12,12)/-4.3173009d-08, 7.8132359d-09/
      data fxyz(21,12,13),fxyz(21,12,14)/ 9.7127789d-09,-1.1026760d-08/
      data fxyz(21,12,15),fxyz(21,12,16)/ 6.3913368d-09,-1.1109929d-08/
      data fxyz(21,12,17),fxyz(21,12,18)/ 7.3288107d-09, 9.5444230d-10/
      data fxyz(21,12,19),fxyz(21,12,20)/ 2.2387431d-09,-2.2650044d-09/
      data fxyz(21,12,21),fxyz(21,12,22)/-2.1042742d-09, 1.5958223d-09/
      data fxyz(21,12,23)/                3.3653954d-09/
      data fxyz(21,13, 1),fxyz(21,13, 2)/ 3.5103321d-07, 2.1987371d-07/
      data fxyz(21,13, 3),fxyz(21,13, 4)/-3.3597104d-08,-8.1871304d-08/
      data fxyz(21,13, 5),fxyz(21,13, 6)/ 4.1297051d-07,-3.7307979d-07/
      data fxyz(21,13, 7),fxyz(21,13, 8)/ 7.2192153d-09,-8.5593841d-09/
      data fxyz(21,13, 9),fxyz(21,13,10)/ 5.3687334d-08,-1.2391274d-08/
      data fxyz(21,13,11),fxyz(21,13,12)/ 1.5495210d-08, 1.4776205d-08/
      data fxyz(21,13,13),fxyz(21,13,14)/-8.8185161d-09, 8.7615266d-09/
      data fxyz(21,13,15),fxyz(21,13,16)/-2.2701909d-08, 3.2606855d-08/
      data fxyz(21,13,17),fxyz(21,13,18)/-1.8809485d-08, 2.1859299d-09/
      data fxyz(21,13,19),fxyz(21,13,20)/ 1.6041941d-09, 1.1833568d-09/
      data fxyz(21,13,21),fxyz(21,13,22)/ 1.1650651d-09, 1.6773609d-09/
      data fxyz(21,13,23)/                1.9115544d-09/
      data fxyz(21,14, 1),fxyz(21,14, 2)/-6.3160243d-09, 8.2380051d-09/
      data fxyz(21,14, 3),fxyz(21,14, 4)/ 3.8754115d-08, 3.9928533d-08/
      data fxyz(21,14, 5),fxyz(21,14, 6)/ 3.5403299d-09, 1.1300258d-08/
      data fxyz(21,14, 7),fxyz(21,14, 8)/-1.3014273d-07,-6.7287528d-09/
      data fxyz(21,14, 9),fxyz(21,14,10)/ 2.4289625d-08, 1.8389499d-08/
      data fxyz(21,14,11),fxyz(21,14,12)/ 1.0911725d-08,-6.7060673d-09/
      data fxyz(21,14,13),fxyz(21,14,14)/ 1.1595504d-08,-1.2486477d-09/
      data fxyz(21,14,15),fxyz(21,14,16)/ 2.5580327d-08,-4.2914851d-08/
      data fxyz(21,14,17),fxyz(21,14,18)/ 2.0207380d-08, 5.0097300d-09/
      data fxyz(21,14,19),fxyz(21,14,20)/-3.6096154d-09, 7.9591248d-10/
      data fxyz(21,14,21),fxyz(21,14,22)/ 2.8917553d-10,-1.5826676d-09/
      data fxyz(21,14,23)/               -2.5913242d-09/
      data fxyz(21,15, 1),fxyz(21,15, 2)/-3.4278830d-07,-1.0046256d-07/
      data fxyz(21,15, 3),fxyz(21,15, 4)/ 4.2756739d-07, 4.1223652d-07/
      data fxyz(21,15, 5),fxyz(21,15, 6)/-3.9139079d-08,-5.7275134d-07/
      data fxyz(21,15, 7),fxyz(21,15, 8)/ 3.9998549d-08,-3.1926816d-08/
      data fxyz(21,15, 9),fxyz(21,15,10)/-6.7851786d-08, 4.4075718d-08/
      data fxyz(21,15,11),fxyz(21,15,12)/-1.4623603d-08, 1.4546664d-08/
      data fxyz(21,15,13),fxyz(21,15,14)/-2.2563411d-09,-1.1210911d-10/
      data fxyz(21,15,15),fxyz(21,15,16)/-3.3426584d-09, 1.7476397d-08/
      data fxyz(21,15,17),fxyz(21,15,18)/-1.6620009d-09,-9.5608960d-09/
      data fxyz(21,15,19),fxyz(21,15,20)/ 4.9576055d-09,-1.0449412d-09/
      data fxyz(21,15,21),fxyz(21,15,22)/-2.2280402d-10, 1.6690568d-09/
      data fxyz(21,15,23)/                2.7711617d-09/
      data fxyz(21,16, 1),fxyz(21,16, 2)/-6.9501547d-08,-1.2782851d-07/
      data fxyz(21,16, 3),fxyz(21,16, 4)/-3.0050887d-07,-2.1704433d-07/
      data fxyz(21,16, 5),fxyz(21,16, 6)/-4.6168668d-07, 1.1824666d-06/
      data fxyz(21,16, 7),fxyz(21,16, 8)/-3.3257214d-07, 4.7411119d-09/
      data fxyz(21,16, 9),fxyz(21,16,10)/ 4.6179362d-08,-9.3277763d-08/
      data fxyz(21,16,11),fxyz(21,16,12)/ 2.0134253d-08,-2.3572390d-08/
      data fxyz(21,16,13),fxyz(21,16,14)/ 6.9934092d-09, 1.0904627d-09/
      data fxyz(21,16,15),fxyz(21,16,16)/-1.7573258d-09, 7.4891089d-09/
      data fxyz(21,16,17),fxyz(21,16,18)/-5.7676641d-09, 7.8687550d-09/
      data fxyz(21,16,19),fxyz(21,16,20)/-3.0483949d-09,-1.1372297d-09/
      data fxyz(21,16,21),fxyz(21,16,22)/-1.6977847d-09,-8.0617461d-10/
      data fxyz(21,16,23)/               -5.3957123d-10/
      data fxyz(21,17, 1),fxyz(21,17, 2)/ 7.0584964d-07, 4.1300364d-07/
      data fxyz(21,17, 3),fxyz(21,17, 4)/-1.5125239d-07,-2.6197681d-07/
      data fxyz(21,17, 5),fxyz(21,17, 6)/ 8.5590132d-07,-9.5501666d-07/
      data fxyz(21,17, 7),fxyz(21,17, 8)/ 5.8404101d-07,-7.2927220d-08/
      data fxyz(21,17, 9),fxyz(21,17,10)/-3.8815659d-08, 2.7553652d-08/
      data fxyz(21,17,11),fxyz(21,17,12)/-3.2579204d-08, 4.8258372d-09/
      data fxyz(21,17,13),fxyz(21,17,14)/-1.3868157d-08, 8.7100811d-10/
      data fxyz(21,17,15),fxyz(21,17,16)/-2.0860899d-09,-1.7864290d-09/
      data fxyz(21,17,17),fxyz(21,17,18)/-9.2553992d-10, 1.3513670d-09/
      data fxyz(21,17,19),fxyz(21,17,20)/ 1.8017052d-09,-1.5437975d-09/
      data fxyz(21,17,21),fxyz(21,17,22)/-1.4483114d-09, 1.4197610d-09/
      data fxyz(21,17,23)/                2.7836578d-09/
      data fxyz(21,18, 1),fxyz(21,18, 2)/-4.1829333d-08,-4.6947006d-08/
      data fxyz(21,18, 3),fxyz(21,18, 4)/-7.2562355d-08,-4.6926767d-08/
      data fxyz(21,18, 5),fxyz(21,18, 6)/-1.4948936d-07, 3.4270449d-07/
      data fxyz(21,18, 7),fxyz(21,18, 8)/-1.7086553d-07, 5.5723449d-08/
      data fxyz(21,18, 9),fxyz(21,18,10)/ 9.4788932d-09,-4.6561830d-10/
      data fxyz(21,18,11),fxyz(21,18,12)/ 5.4685800d-09, 6.0346306d-10/
      data fxyz(21,18,13),fxyz(21,18,14)/ 1.7285138d-09,-2.7920946d-09/
      data fxyz(21,18,15),fxyz(21,18,16)/ 1.4480620d-09,-4.6056372d-09/
      data fxyz(21,18,17),fxyz(21,18,18)/ 3.2204299d-09,-6.6970943d-09/
      data fxyz(21,18,19),fxyz(21,18,20)/-4.3306206d-09,-1.4739593d-09/
      data fxyz(21,18,21),fxyz(21,18,22)/-1.4249072d-09,-4.5268292d-09/
      data fxyz(21,18,23)/               -5.9613122d-09/
      data fxyz(21,19, 1),fxyz(21,19, 2)/-3.5435683d-07,-2.2095971d-07/
      data fxyz(21,19, 3),fxyz(21,19, 4)/ 2.6289520d-08, 9.3842554d-08/
      data fxyz(21,19, 5),fxyz(21,19, 6)/-4.9117185d-07, 6.5893867d-07/
      data fxyz(21,19, 7),fxyz(21,19, 8)/-4.4819501d-07, 1.2542583d-07/
      data fxyz(21,19, 9),fxyz(21,19,10)/ 1.9690710d-08, 1.4043879d-08/
      data fxyz(21,19,11),fxyz(21,19,12)/ 1.7584581d-08, 5.7012607d-09/
      data fxyz(21,19,13),fxyz(21,19,14)/ 6.9085455d-09,-5.4712979d-09/
      data fxyz(21,19,15),fxyz(21,19,16)/ 3.8785237d-09,-9.2695110d-09/
      data fxyz(21,19,17),fxyz(21,19,18)/ 7.5653009d-09,-1.4308106d-08/
      data fxyz(21,19,19),fxyz(21,19,20)/-7.3251105d-09,-1.5402371d-09/
      data fxyz(21,19,21),fxyz(21,19,22)/-1.3369117d-09,-8.1384120d-09/
      data fxyz(21,19,23)/               -1.1258225d-08/
      data fxyz(22, 1, 1),fxyz(22, 1, 2)/ 1.1374145d-06, 6.2302511d-08/
      data fxyz(22, 1, 3),fxyz(22, 1, 4)/-2.2577622d-06,-2.2293188d-06/
      data fxyz(22, 1, 5),fxyz(22, 1, 6)/-5.1471022d-08, 1.5640652d-06/
      data fxyz(22, 1, 7),fxyz(22, 1, 8)/ 1.9032435d-06, 9.2008108d-07/
      data fxyz(22, 1, 9),fxyz(22, 1,10)/-7.8961306d-07, 4.8721255d-07/
      data fxyz(22, 1,11),fxyz(22, 1,12)/-9.8229370d-07,-6.6001295d-09/
      data fxyz(22, 1,13),fxyz(22, 1,14)/ 4.2311464d-07,-5.1701087d-07/
      data fxyz(22, 1,15),fxyz(22, 1,16)/-6.5056330d-07, 1.0898146d-06/
      data fxyz(22, 1,17),fxyz(22, 1,18)/ 6.2998665d-07, 5.9061889d-06/
      data fxyz(22, 1,19),fxyz(22, 1,20)/-4.9472680d-06,-9.4945075d-07/
      data fxyz(22, 1,21),fxyz(22, 1,22)/-1.5532057d-06,-2.5322480d-06/
      data fxyz(22, 1,23)/               -3.1501358d-06/
      data fxyz(22, 2, 1),fxyz(22, 2, 2)/ 1.0790198d-06, 3.5113632d-07/
      data fxyz(22, 2, 3),fxyz(22, 2, 4)/-1.1937289d-06,-1.2197777d-06/
      data fxyz(22, 2, 5),fxyz(22, 2, 6)/ 4.5533136d-07, 6.8828835d-07/
      data fxyz(22, 2, 7),fxyz(22, 2, 8)/ 8.5020091d-07, 4.1350197d-07/
      data fxyz(22, 2, 9),fxyz(22, 2,10)/-4.2344718d-07, 2.0864298d-07/
      data fxyz(22, 2,11),fxyz(22, 2,12)/-5.0730224d-07,-3.0033147d-08/
      data fxyz(22, 2,13),fxyz(22, 2,14)/ 1.7885048d-07,-2.7945654d-07/
      data fxyz(22, 2,15),fxyz(22, 2,16)/-3.5564874d-07, 5.0528860d-07/
      data fxyz(22, 2,17),fxyz(22, 2,18)/ 2.0805281d-07, 2.8646562d-06/
      data fxyz(22, 2,19),fxyz(22, 2,20)/-2.1011059d-06,-5.0967537d-07/
      data fxyz(22, 2,21),fxyz(22, 2,22)/-7.8064513d-07,-1.0172269d-06/
      data fxyz(22, 2,23)/               -1.1998903d-06/
      data fxyz(22, 3, 1),fxyz(22, 3, 2)/ 7.1703147d-06, 4.1657301d-06/
      data fxyz(22, 3, 3),fxyz(22, 3, 4)/-1.9661536d-06,-2.5025491d-06/
      data fxyz(22, 3, 5),fxyz(22, 3, 6)/ 6.3113122d-06,-8.7561807d-07/
      data fxyz(22, 3, 7),fxyz(22, 3, 8)/-1.3969455d-06,-3.9355128d-07/
      data fxyz(22, 3, 9),fxyz(22, 3,10)/ 1.5126754d-07,-3.4095710d-07/
      data fxyz(22, 3,11),fxyz(22, 3,12)/ 3.2362275d-07,-1.2874056d-07/
      data fxyz(22, 3,13),fxyz(22, 3,14)/-3.3107252d-07, 1.2948320d-07/
      data fxyz(22, 3,15),fxyz(22, 3,16)/ 8.7453675d-08,-4.6634471d-07/
      data fxyz(22, 3,17),fxyz(22, 3,18)/-9.4001687d-07,-2.4090621d-06/
      data fxyz(22, 3,19),fxyz(22, 3,20)/ 7.2364311d-06,-2.4040266d-06/
      data fxyz(22, 3,21),fxyz(22, 3,22)/-1.7326165d-06, 4.5507906d-06/
      data fxyz(22, 3,23)/                7.6620899d-06/
      data fxyz(22, 4, 1),fxyz(22, 4, 2)/-8.2623041d-06,-4.3598360d-06/
      data fxyz(22, 4, 3),fxyz(22, 4, 4)/ 3.6890248d-06, 4.2377736d-06/
      data fxyz(22, 4, 5),fxyz(22, 4, 6)/-6.5548315d-06,-3.1071076d-08/
      data fxyz(22, 4, 7),fxyz(22, 4, 8)/ 5.3527135d-07,-1.4894503d-07/
      data fxyz(22, 4, 9),fxyz(22, 4,10)/-3.9387000d-09, 5.8049623d-08/
      data fxyz(22, 4,11),fxyz(22, 4,12)/-9.1219597d-08, 3.6012412d-08/
      data fxyz(22, 4,13),fxyz(22, 4,14)/ 8.8810413d-08,-6.1426038d-08/
      data fxyz(22, 4,15),fxyz(22, 4,16)/ 1.1898604d-08,-8.3102385d-08/
      data fxyz(22, 4,17),fxyz(22, 4,18)/ 4.5338885d-07, 1.2986899d-07/
      data fxyz(22, 4,19),fxyz(22, 4,20)/-6.1458444d-06, 3.8710654d-06/
      data fxyz(22, 4,21),fxyz(22, 4,22)/ 3.3512740d-06,-4.0666789d-06/
      data fxyz(22, 4,23)/               -7.6670014d-06/
      data fxyz(22, 5, 1),fxyz(22, 5, 2)/ 2.8860614d-06, 1.5037608d-06/
      data fxyz(22, 5, 3),fxyz(22, 5, 4)/-1.3542853d-06,-1.5363322d-06/
      data fxyz(22, 5, 5),fxyz(22, 5, 6)/ 2.2319482d-06, 1.5535861d-07/
      data fxyz(22, 5, 7),fxyz(22, 5, 8)/-1.5587666d-07, 7.8038576d-08/
      data fxyz(22, 5, 9),fxyz(22, 5,10)/-5.9220149d-08,-3.5643171d-08/
      data fxyz(22, 5,11),fxyz(22, 5,12)/ 3.4919443d-08, 1.4801399d-08/
      data fxyz(22, 5,13),fxyz(22, 5,14)/-1.1660250d-08,-2.4209541d-09/
      data fxyz(22, 5,15),fxyz(22, 5,16)/-4.9196944d-08, 3.3286123d-08/
      data fxyz(22, 5,17),fxyz(22, 5,18)/-8.4411400d-08, 1.2351540d-08/
      data fxyz(22, 5,19),fxyz(22, 5,20)/ 2.3299503d-06,-1.5424488d-06/
      data fxyz(22, 5,21),fxyz(22, 5,22)/-1.3466552d-06, 1.5467759d-06/
      data fxyz(22, 5,23)/                2.9492554d-06/
      data fxyz(22, 6, 1),fxyz(22, 6, 2)/-6.4579204d-07,-3.7003844d-07/
      data fxyz(22, 6, 3),fxyz(22, 6, 4)/ 1.9387364d-07, 2.4110350d-07/
      data fxyz(22, 6, 5),fxyz(22, 6, 6)/-5.5895786d-07, 6.2655788d-08/
      data fxyz(22, 6, 7),fxyz(22, 6, 8)/ 8.7751716d-08, 2.8360572d-09/
      data fxyz(22, 6, 9),fxyz(22, 6,10)/ 6.2203329d-08, 3.8117058d-08/
      data fxyz(22, 6,11),fxyz(22, 6,12)/-2.1498936d-08,-3.5175522d-08/
      data fxyz(22, 6,13),fxyz(22, 6,14)/-1.1752583d-08, 2.6999587d-08/
      data fxyz(22, 6,15),fxyz(22, 6,16)/ 5.6068729d-08, 1.0534542d-08/
      data fxyz(22, 6,17),fxyz(22, 6,18)/ 5.3836906d-08, 1.0941202d-07/
      data fxyz(22, 6,19),fxyz(22, 6,20)/-5.9351585d-07, 2.5463872d-07/
      data fxyz(22, 6,21),fxyz(22, 6,22)/ 2.0248366d-07,-3.8489560d-07/
      data fxyz(22, 6,23)/               -6.7291393d-07/
      data fxyz(22, 7, 1),fxyz(22, 7, 2)/ 2.5468991d-07, 1.1496597d-07/
      data fxyz(22, 7, 3),fxyz(22, 7, 4)/-1.7424053d-07,-1.9209393d-07/
      data fxyz(22, 7, 5),fxyz(22, 7, 6)/ 1.8637957d-07,-1.3111093d-08/
      data fxyz(22, 7, 7),fxyz(22, 7, 8)/ 3.4622449d-08, 4.3876880d-08/
      data fxyz(22, 7, 9),fxyz(22, 7,10)/ 5.4794377d-09,-3.2325863d-09/
      data fxyz(22, 7,11),fxyz(22, 7,12)/ 1.7804817d-08, 2.8634190d-08/
      data fxyz(22, 7,13),fxyz(22, 7,14)/ 1.5979041d-08,-3.9329169d-09/
      data fxyz(22, 7,15),fxyz(22, 7,16)/-3.7072535d-09, 3.5609005d-08/
      data fxyz(22, 7,17),fxyz(22, 7,18)/ 4.0157801d-08,-8.6985129d-09/
      data fxyz(22, 7,19),fxyz(22, 7,20)/ 1.5577486d-07,-1.6963411d-07/
      data fxyz(22, 7,21),fxyz(22, 7,22)/-1.5461840d-07, 9.5712034d-08/
      data fxyz(22, 7,23)/                2.1653709d-07/
      data fxyz(22, 8, 1),fxyz(22, 8, 2)/-6.9688686d-08,-5.0425382d-08/
      data fxyz(22, 8, 3),fxyz(22, 8, 4)/-1.3099745d-08,-6.1822216d-09/
      data fxyz(22, 8, 5),fxyz(22, 8, 6)/-7.8095476d-08, 3.4074166d-08/
      data fxyz(22, 8, 7),fxyz(22, 8, 8)/ 9.9777858d-09, 9.4428593d-09/
      data fxyz(22, 8, 9),fxyz(22, 8,10)/ 1.0868324d-08, 1.4154610d-08/
      data fxyz(22, 8,11),fxyz(22, 8,12)/ 1.3191085d-08, 2.8404569d-09/
      data fxyz(22, 8,13),fxyz(22, 8,14)/ 9.7178185d-09, 1.1109332d-08/
      data fxyz(22, 8,15),fxyz(22, 8,16)/ 1.8084136d-08, 1.4039423d-10/
      data fxyz(22, 8,17),fxyz(22, 8,18)/-6.5431678d-10, 1.4815563d-08/
      data fxyz(22, 8,19),fxyz(22, 8,20)/-5.4737747d-08,-1.2361581d-09/
      data fxyz(22, 8,21),fxyz(22, 8,22)/-5.7229010d-09,-3.6790775d-08/
      data fxyz(22, 8,23)/               -5.2485581d-08/
      data fxyz(22, 9, 1),fxyz(22, 9, 2)/-8.0764279d-08,-5.3084406d-08/
      data fxyz(22, 9, 3),fxyz(22, 9, 4)/ 2.0691419d-09, 9.3499569d-09/
      data fxyz(22, 9, 5),fxyz(22, 9, 6)/-8.2207666d-08, 2.8447946d-08/
      data fxyz(22, 9, 7),fxyz(22, 9, 8)/ 1.3986204d-08, 1.5942732d-08/
      data fxyz(22, 9, 9),fxyz(22, 9,10)/ 5.4661140d-09, 1.0493640d-08/
      data fxyz(22, 9,11),fxyz(22, 9,12)/-6.5295684d-09, 7.1321852d-09/
      data fxyz(22, 9,13),fxyz(22, 9,14)/ 2.6024844d-09, 8.0962940d-09/
      data fxyz(22, 9,15),fxyz(22, 9,16)/ 5.6793682d-10, 1.2359976d-08/
      data fxyz(22, 9,17),fxyz(22, 9,18)/ 1.7318202d-09,-7.9087070d-09/
      data fxyz(22, 9,19),fxyz(22, 9,20)/ 4.8252891d-09,-1.7983054d-08/
      data fxyz(22, 9,21),fxyz(22, 9,22)/-1.6873344d-08, 3.8644931d-10/
      data fxyz(22, 9,23)/                8.7369420d-09/
      data fxyz(22,10, 1),fxyz(22,10, 2)/ 2.1241010d-07, 1.0875210d-07/
      data fxyz(22,10, 3),fxyz(22,10, 4)/-1.0497957d-07,-1.1966667d-07/
      data fxyz(22,10, 5),fxyz(22,10, 6)/ 1.6750049d-07,-7.8963928d-09/
      data fxyz(22,10, 7),fxyz(22,10, 8)/ 1.1109254d-08,-6.7172080d-09/
      data fxyz(22,10, 9),fxyz(22,10,10)/ 2.8198043d-08,-3.6010047d-08/
      data fxyz(22,10,11),fxyz(22,10,12)/ 2.5073649d-08,-5.5044161d-09/
      data fxyz(22,10,13),fxyz(22,10,14)/ 2.9303229d-09, 3.5083216d-09/
      data fxyz(22,10,15),fxyz(22,10,16)/ 5.5324475d-09,-4.2075300d-09/
      data fxyz(22,10,17),fxyz(22,10,18)/ 4.0365519d-10,-1.8295333d-09/
      data fxyz(22,10,19),fxyz(22,10,20)/-6.0727309d-09,-8.7232534d-10/
      data fxyz(22,10,21),fxyz(22,10,22)/-1.1889418d-09,-4.8062651d-09/
      data fxyz(22,10,23)/               -6.5787803d-09/
      data fxyz(22,11, 1),fxyz(22,11, 2)/-2.5956895d-07,-1.4317247d-07/
      data fxyz(22,11, 3),fxyz(22,11, 4)/ 9.3694624d-08, 1.1566403d-07/
      data fxyz(22,11, 5),fxyz(22,11, 6)/-2.3105007d-07, 6.9972088d-08/
      data fxyz(22,11, 7),fxyz(22,11, 8)/-1.3207525d-08, 1.2889153d-08/
      data fxyz(22,11, 9),fxyz(22,11,10)/-3.9816408d-08, 6.6134052d-08/
      data fxyz(22,11,11),fxyz(22,11,12)/-3.7068336d-08, 7.4359067d-09/
      data fxyz(22,11,13),fxyz(22,11,14)/ 2.8666231d-09,-1.1658377d-09/
      data fxyz(22,11,15),fxyz(22,11,16)/-2.6056876d-10, 8.4373472d-10/
      data fxyz(22,11,17),fxyz(22,11,18)/-1.6413522d-09,-2.2286298d-10/
      data fxyz(22,11,19),fxyz(22,11,20)/ 3.9517357d-09,-3.9718633d-09/
      data fxyz(22,11,21),fxyz(22,11,22)/-3.5981792d-09, 2.4569994d-09/
      data fxyz(22,11,23)/                5.3823984d-09/
      data fxyz(22,12, 1),fxyz(22,12, 2)/ 3.1827493d-07, 1.7416066d-07/
      data fxyz(22,12, 3),fxyz(22,12, 4)/-1.1808615d-07,-1.4708273d-07/
      data fxyz(22,12, 5),fxyz(22,12, 6)/ 2.9014698d-07,-1.1667374d-07/
      data fxyz(22,12, 7),fxyz(22,12, 8)/ 2.7931066d-08,-1.2968554d-08/
      data fxyz(22,12, 9),fxyz(22,12,10)/ 3.3479849d-08,-3.5177469d-08/
      data fxyz(22,12,11),fxyz(22,12,12)/ 2.8677578d-08,-1.8920966d-09/
      data fxyz(22,12,13),fxyz(22,12,14)/-4.1431392d-09, 4.1703351d-10/
      data fxyz(22,12,15),fxyz(22,12,16)/-1.2450438d-09, 1.3763007d-09/
      data fxyz(22,12,17),fxyz(22,12,18)/ 1.6666172d-09,-1.1380335d-09/
      data fxyz(22,12,19),fxyz(22,12,20)/ 1.0746986d-11, 3.1637023d-10/
      data fxyz(22,12,21),fxyz(22,12,22)/ 3.6413082d-10,-1.8029535d-10/
      data fxyz(22,12,23)/               -4.2162474d-10/
      data fxyz(22,13, 1),fxyz(22,13, 2)/-3.4936404d-07,-1.7547592d-07/
      data fxyz(22,13, 3),fxyz(22,13, 4)/ 1.8460288d-07, 2.0654542d-07/
      data fxyz(22,13, 5),fxyz(22,13, 6)/-2.6324610d-07,-2.0225884d-08/
      data fxyz(22,13, 7),fxyz(22,13, 8)/-4.9763709d-08, 1.3487198d-08/
      data fxyz(22,13, 9),fxyz(22,13,10)/-7.0892786d-09, 1.8224572d-08/
      data fxyz(22,13,11),fxyz(22,13,12)/ 2.4479017d-09, 2.4018072d-10/
      data fxyz(22,13,13),fxyz(22,13,14)/ 4.7164819d-09,-3.1242192d-09/
      data fxyz(22,13,15),fxyz(22,13,16)/ 3.2490690d-09,-8.7502253d-09/
      data fxyz(22,13,17),fxyz(22,13,18)/ 5.0878497d-09, 5.5531796d-09/
      data fxyz(22,13,19),fxyz(22,13,20)/-6.1488402d-09, 2.0557430d-09/
      data fxyz(22,13,21),fxyz(22,13,22)/ 1.3185203d-09,-3.1999493d-09/
      data fxyz(22,13,23)/               -5.5051612d-09/
      data fxyz(22,14, 1),fxyz(22,14, 2)/-1.0593731d-07,-3.3477065d-08/
      data fxyz(22,14, 3),fxyz(22,14, 4)/ 1.2184269d-07, 1.2175904d-07/
      data fxyz(22,14, 5),fxyz(22,14, 6)/-3.3142462d-08,-1.0719207d-07/
      data fxyz(22,14, 7),fxyz(22,14, 8)/-3.5813381d-08,-2.0432407d-08/
      data fxyz(22,14, 9),fxyz(22,14,10)/ 1.3816182d-09,-2.1756759d-10/
      data fxyz(22,14,11),fxyz(22,14,12)/ 1.1504663d-09, 1.2241525d-08/
      data fxyz(22,14,13),fxyz(22,14,14)/-2.7827307d-09, 9.5934614d-10/
      data fxyz(22,14,15),fxyz(22,14,16)/-6.4576982d-09, 1.1563225d-08/
      data fxyz(22,14,17),fxyz(22,14,18)/-4.7695188d-09,-3.7041570d-09/
      data fxyz(22,14,19),fxyz(22,14,20)/ 1.0045422d-08,-3.8776101d-09/
      data fxyz(22,14,21),fxyz(22,14,22)/-2.9165186d-09, 6.2010558d-09/
      data fxyz(22,14,23)/                1.0712215d-08/
      data fxyz(22,15, 1),fxyz(22,15, 2)/ 1.9678296d-07, 9.2890948d-08/
      data fxyz(22,15, 3),fxyz(22,15, 4)/-1.2847377d-07,-1.3068058d-07/
      data fxyz(22,15, 5),fxyz(22,15, 6)/ 1.0171820d-07, 1.6368078d-07/
      data fxyz(22,15, 7),fxyz(22,15, 8)/-3.8319899d-08,-2.2818016d-08/
      data fxyz(22,15, 9),fxyz(22,15,10)/ 5.7473227d-10,-1.5947268d-08/
      data fxyz(22,15,11),fxyz(22,15,12)/ 4.0866623d-09,-6.8277622d-09/
      data fxyz(22,15,13),fxyz(22,15,14)/ 6.8034041d-09, 3.0576302d-09/
      data fxyz(22,15,15),fxyz(22,15,16)/-2.2314309d-09, 2.8357646d-09/
      data fxyz(22,15,17),fxyz(22,15,18)/-4.8054185d-09, 5.7300439d-09/
      data fxyz(22,15,19),fxyz(22,15,20)/-6.2445843d-09, 2.8326155d-09/
      data fxyz(22,15,21),fxyz(22,15,22)/ 2.0631224d-09,-3.1666119d-09/
      data fxyz(22,15,23)/               -5.8123527d-09/
      data fxyz(22,16, 1),fxyz(22,16, 2)/ 1.6704588d-07, 1.0377165d-07/
      data fxyz(22,16, 3),fxyz(22,16, 4)/-1.7022742d-08,-4.2910936d-08/
      data fxyz(22,16, 5),fxyz(22,16, 6)/ 2.0732443d-07,-2.2127702d-07/
      data fxyz(22,16, 7),fxyz(22,16, 8)/ 1.2199165d-07,-1.0507168d-08/
      data fxyz(22,16, 9),fxyz(22,16,10)/-3.3882978d-08, 6.7149817d-09/
      data fxyz(22,16,11),fxyz(22,16,12)/-1.7111114d-08, 3.9711322d-09/
      data fxyz(22,16,13),fxyz(22,16,14)/-6.1498328d-09, 2.5405913d-09/
      data fxyz(22,16,15),fxyz(22,16,16)/ 9.9978133d-09,-1.3221775d-08/
      data fxyz(22,16,17),fxyz(22,16,18)/ 1.0820169d-08,-7.1206086d-09/
      data fxyz(22,16,19),fxyz(22,16,20)/ 3.3211297d-09,-1.2488956d-09/
      data fxyz(22,16,21),fxyz(22,16,22)/-6.5200873d-10, 9.3358223d-10/
      data fxyz(22,16,23)/                1.8326945d-09/
      data fxyz(22,17, 1),fxyz(22,17, 2)/-1.4771282d-07,-1.0106853d-07/
      data fxyz(22,17, 3),fxyz(22,17, 4)/-1.7877918d-08, 1.1454633d-08/
      data fxyz(22,17, 5),fxyz(22,17, 6)/-2.1839873d-07, 2.9227545d-07/
      data fxyz(22,17, 7),fxyz(22,17, 8)/-1.1041481d-07, 3.9909823d-08/
      data fxyz(22,17, 9),fxyz(22,17,10)/ 1.3990456d-08,-1.2104737d-08/
      data fxyz(22,17,11),fxyz(22,17,12)/ 1.1111379d-09,-1.0352171d-08/
      data fxyz(22,17,13),fxyz(22,17,14)/ 1.6611489d-09,-5.3543389d-09/
      data fxyz(22,17,15),fxyz(22,17,16)/-2.8649041d-09, 8.3332800d-09/
      data fxyz(22,17,17),fxyz(22,17,18)/-4.1125038d-09, 2.7198042d-09/
      data fxyz(22,17,19),fxyz(22,17,20)/-4.4322705d-09, 5.1910701d-10/
      data fxyz(22,17,21),fxyz(22,17,22)/ 6.9927378d-11,-2.6355520d-09/
      data fxyz(22,17,23)/               -4.0178902d-09/
      data fxyz(22,18, 1),fxyz(22,18, 2)/ 1.6212924d-08, 8.5359002d-09/
      data fxyz(22,18, 3),fxyz(22,18, 4)/-4.2112106d-09,-1.0692605d-08/
      data fxyz(22,18, 5),fxyz(22,18, 6)/ 3.4461478d-08,-8.1007992d-08/
      data fxyz(22,18, 7),fxyz(22,18, 8)/ 5.5147951d-08,-2.7816715d-09/
      data fxyz(22,18, 9),fxyz(22,18,10)/ 6.2404148d-09, 5.8080460d-09/
      data fxyz(22,18,11),fxyz(22,18,12)/ 2.4499115d-09, 1.3110315d-09/
      data fxyz(22,18,13),fxyz(22,18,14)/-1.2274025d-09, 1.4547661d-09/
      data fxyz(22,18,15),fxyz(22,18,16)/-1.5706742d-09,-8.6759992d-10/
      data fxyz(22,18,17),fxyz(22,18,18)/-2.0839061d-09,-6.7394121d-10/
      data fxyz(22,18,19),fxyz(22,18,20)/ 6.3161458d-10,-2.3039446d-09/
      data fxyz(22,18,21),fxyz(22,18,22)/-2.1769439d-09, 1.2361140d-10/
      data fxyz(22,18,23)/                1.2310707d-09/
      data fxyz(22,19, 1),fxyz(22,19, 2)/ 4.3371684d-08, 2.8299012d-08/
      data fxyz(22,19, 3),fxyz(22,19, 4)/ 5.3063876d-09,-1.0979041d-08/
      data fxyz(22,19, 5),fxyz(22,19, 6)/ 9.3440726d-08,-2.0090974d-07/
      data fxyz(22,19, 7),fxyz(22,19, 8)/ 1.0700522d-07,-1.8870741d-08/
      data fxyz(22,19, 9),fxyz(22,19,10)/ 1.4382795d-08, 1.3225829d-08/
      data fxyz(22,19,11),fxyz(22,19,12)/ 8.6125359d-09, 5.5495181d-09/
      data fxyz(22,19,13),fxyz(22,19,14)/-1.0589444d-09, 4.0627181d-09/
      data fxyz(22,19,15),fxyz(22,19,16)/-4.3212864d-09,-1.2810700d-09/
      data fxyz(22,19,17),fxyz(22,19,18)/-4.9013856d-09,-2.8649857d-10/
      data fxyz(22,19,19),fxyz(22,19,20)/ 2.0334181d-09,-3.8152665d-09/
      data fxyz(22,19,21),fxyz(22,19,22)/-3.5755844d-09, 1.0746897d-09/
      data fxyz(22,19,23)/                3.3087329d-09/
      data fxyz(23, 1, 1),fxyz(23, 1, 2)/-4.5592390d-08,-1.1920434d-08/
      data fxyz(23, 1, 3),fxyz(23, 1, 4)/ 6.4844362d-08, 5.6775805d-08/
      data fxyz(23, 1, 5),fxyz(23, 1, 6)/ 2.0353794d-08,-1.6662074d-07/
      data fxyz(23, 1, 7),fxyz(23, 1, 8)/-2.2424499d-07,-4.7107948d-08/
      data fxyz(23, 1, 9),fxyz(23, 1,10)/ 2.9981518d-07,-1.0551655d-07/
      data fxyz(23, 1,11),fxyz(23, 1,12)/ 2.2960938d-07,-4.2820061d-08/
      data fxyz(23, 1,13),fxyz(23, 1,14)/-1.3789128d-07, 1.5096020d-07/
      data fxyz(23, 1,15),fxyz(23, 1,16)/ 2.6186584d-07,-9.1132749d-08/
      data fxyz(23, 1,17),fxyz(23, 1,18)/ 1.2336573d-07,-1.2810056d-06/
      data fxyz(23, 1,19),fxyz(23, 1,20)/ 1.3310450d-06,-3.0797387d-07/
      data fxyz(23, 1,21),fxyz(23, 1,22)/-1.4767674d-07, 6.8985652d-07/
      data fxyz(23, 1,23)/                1.1234513d-06/
      data fxyz(23, 2, 1),fxyz(23, 2, 2)/-1.6972681d-07,-6.8963898d-08/
      data fxyz(23, 2, 3),fxyz(23, 2, 4)/ 1.4322125d-07, 1.4975815d-07/
      data fxyz(23, 2, 5),fxyz(23, 2, 6)/-9.5111511d-08,-7.1673258d-08/
      data fxyz(23, 2, 7),fxyz(23, 2, 8)/-1.1161853d-07,-3.9771340d-08/
      data fxyz(23, 2, 9),fxyz(23, 2,10)/ 1.2781137d-07,-7.2431362d-08/
      data fxyz(23, 2,11),fxyz(23, 2,12)/ 9.3770514d-08,-3.7033745d-08/
      data fxyz(23, 2,13),fxyz(23, 2,14)/-8.5280520d-08, 5.2720737d-08/
      data fxyz(23, 2,15),fxyz(23, 2,16)/ 1.0980614d-07,-6.3033690d-08/
      data fxyz(23, 2,17),fxyz(23, 2,18)/ 6.3601075d-08,-6.3092303d-07/
      data fxyz(23, 2,19),fxyz(23, 2,20)/ 5.8703500d-07,-4.9531989d-08/
      data fxyz(23, 2,21),fxyz(23, 2,22)/ 2.2383642d-08, 2.9937247d-07/
      data fxyz(23, 2,23)/                4.4781143d-07/
      data fxyz(23, 3, 1),fxyz(23, 3, 2)/-1.8068525d-06,-9.4016733d-07/
      data fxyz(23, 3, 3),fxyz(23, 3, 4)/ 8.4025674d-07, 9.7458389d-07/
      data fxyz(23, 3, 5),fxyz(23, 3, 6)/-1.4774760d-06, 2.0805485d-07/
      data fxyz(23, 3, 7),fxyz(23, 3, 8)/ 2.3074683d-07,-4.2551307d-08/
      data fxyz(23, 3, 9),fxyz(23, 3,10)/-1.5079141d-07,-3.2230216d-09/
      data fxyz(23, 3,11),fxyz(23, 3,12)/-1.8387311d-07,-6.9503575d-08/
      data fxyz(23, 3,13),fxyz(23, 3,14)/-1.3061742d-08,-1.2515484d-07/
      data fxyz(23, 3,15),fxyz(23, 3,16)/-1.3280763d-07,-2.6064287d-08/
      data fxyz(23, 3,17),fxyz(23, 3,18)/ 1.0501051d-07, 6.0382848d-07/
      data fxyz(23, 3,19),fxyz(23, 3,20)/-1.7173017d-06, 9.5568786d-07/
      data fxyz(23, 3,21),fxyz(23, 3,22)/ 7.8629584d-07,-1.0397336d-06/
      data fxyz(23, 3,23)/               -1.9370519d-06/
      data fxyz(23, 4, 1),fxyz(23, 4, 2)/ 1.8514912d-06, 1.0381891d-06/
      data fxyz(23, 4, 3),fxyz(23, 4, 4)/-6.2801290d-07,-7.6204226d-07/
      data fxyz(23, 4, 5),fxyz(23, 4, 6)/ 1.5743066d-06,-1.5894923d-07/
      data fxyz(23, 4, 7),fxyz(23, 4, 8)/-2.3097396d-07,-9.9232632d-09/
      data fxyz(23, 4, 9),fxyz(23, 4,10)/-5.6297770d-08,-6.0445702d-08/
      data fxyz(23, 4,11),fxyz(23, 4,12)/ 3.4799910d-08, 3.1923106d-08/
      data fxyz(23, 4,13),fxyz(23, 4,14)/-9.4710422d-09,-2.4304004d-08/
      data fxyz(23, 4,15),fxyz(23, 4,16)/-5.8482146d-08,-2.0141087d-08/
      data fxyz(23, 4,17),fxyz(23, 4,18)/-2.0768936d-07,-2.0776121d-07/
      data fxyz(23, 4,19),fxyz(23, 4,20)/ 1.4395049d-06,-6.5281518d-07/
      data fxyz(23, 4,21),fxyz(23, 4,22)/-5.2827330d-07, 9.4133742d-07/
      data fxyz(23, 4,23)/                1.6603669d-06/
      data fxyz(23, 5, 1),fxyz(23, 5, 2)/-5.9205725d-07,-3.1963633d-07/
      data fxyz(23, 5, 3),fxyz(23, 5, 4)/ 2.3970711d-07, 2.8243453d-07/
      data fxyz(23, 5, 5),fxyz(23, 5, 6)/-4.9054600d-07, 4.8854016d-08/
      data fxyz(23, 5, 7),fxyz(23, 5, 8)/ 6.1170327d-08,-3.9184380d-08/
      data fxyz(23, 5, 9),fxyz(23, 5,10)/ 1.7349479d-08, 3.0663248d-08/
      data fxyz(23, 5,11),fxyz(23, 5,12)/-1.8456578d-08,-4.0050831d-08/
      data fxyz(23, 5,13),fxyz(23, 5,14)/-7.4394783d-09, 2.2739694d-08/
      data fxyz(23, 5,15),fxyz(23, 5,16)/ 1.9302285d-08,-3.0422476d-08/
      data fxyz(23, 5,17),fxyz(23, 5,18)/ 3.5761638d-08, 7.7593080d-08/
      data fxyz(23, 5,19),fxyz(23, 5,20)/-5.1604959d-07, 2.8976629d-07/
      data fxyz(23, 5,21),fxyz(23, 5,22)/ 2.4373670d-07,-3.3193122d-07/
      data fxyz(23, 5,23)/               -6.1285081d-07/
      data fxyz(23, 6, 1),fxyz(23, 6, 2)/ 1.6935037d-07, 7.5534295d-08/
      data fxyz(23, 6, 3),fxyz(23, 6, 4)/-1.1849227d-07,-1.3075608d-07/
      data fxyz(23, 6, 5),fxyz(23, 6, 6)/ 1.2458953d-07,-1.4606746d-08/
      data fxyz(23, 6, 7),fxyz(23, 6, 8)/ 8.9510521d-10, 4.6789732d-08/
      data fxyz(23, 6, 9),fxyz(23, 6,10)/ 2.1442179d-08,-1.8854044d-09/
      data fxyz(23, 6,11),fxyz(23, 6,12)/ 7.6623527d-09, 1.8690722d-08/
      data fxyz(23, 6,13),fxyz(23, 6,14)/ 7.3281700d-09,-3.7603341d-09/
      data fxyz(23, 6,15),fxyz(23, 6,16)/ 1.6469262d-08, 4.1546488d-08/
      data fxyz(23, 6,17),fxyz(23, 6,18)/ 1.0408528d-08,-2.7084323d-08/
      data fxyz(23, 6,19),fxyz(23, 6,20)/ 1.4181872d-07,-1.3531779d-07/
      data fxyz(23, 6,21),fxyz(23, 6,22)/-1.2116114d-07, 8.5192122d-08/
      data fxyz(23, 6,23)/                1.8526542d-07/
      data fxyz(23, 7, 1),fxyz(23, 7, 2)/-4.9171138d-08,-3.8741409d-08/
      data fxyz(23, 7, 3),fxyz(23, 7, 4)/-1.9190152d-08,-1.4293368d-08/
      data fxyz(23, 7, 5),fxyz(23, 7, 6)/-5.8328545d-08, 2.4280623d-08/
      data fxyz(23, 7, 7),fxyz(23, 7, 8)/ 2.1834305d-08, 3.3829934d-09/
      data fxyz(23, 7, 9),fxyz(23, 7,10)/ 1.4002822d-09, 1.1320227d-08/
      data fxyz(23, 7,11),fxyz(23, 7,12)/ 1.6221420d-08, 1.1768693d-08/
      data fxyz(23, 7,13),fxyz(23, 7,14)/ 1.0134334d-08, 1.1116541d-08/
      data fxyz(23, 7,15),fxyz(23, 7,16)/ 1.6742578d-09, 2.9780741d-10/
      data fxyz(23, 7,17),fxyz(23, 7,18)/ 1.8882807d-08, 2.7232003d-08/
      data fxyz(23, 7,19),fxyz(23, 7,20)/-4.8285548d-08,-1.8965661d-08/
      data fxyz(23, 7,21),fxyz(23, 7,22)/-2.3199847d-08,-3.1348808d-08/
      data fxyz(23, 7,23)/               -3.6280773d-08/
      data fxyz(23, 8, 1),fxyz(23, 8, 2)/ 2.2517141d-08, 6.5849556d-09/
      data fxyz(23, 8, 3),fxyz(23, 8, 4)/-2.6288291d-08,-2.8505806d-08/
      data fxyz(23, 8, 5),fxyz(23, 8, 6)/ 1.5455016d-08,-1.0745585d-08/
      data fxyz(23, 8, 7),fxyz(23, 8, 8)/ 6.3697272d-09, 5.3091368d-09/
      data fxyz(23, 8, 9),fxyz(23, 8,10)/ 1.4620517d-08, 8.6906148d-09/
      data fxyz(23, 8,11),fxyz(23, 8,12)/ 6.8265515d-10, 4.1446593d-09/
      data fxyz(23, 8,13),fxyz(23, 8,14)/ 2.5254260d-09, 9.8095706d-09/
      data fxyz(23, 8,15),fxyz(23, 8,16)/ 7.4549237d-09, 1.2146634d-08/
      data fxyz(23, 8,17),fxyz(23, 8,18)/-9.5817425d-10,-1.0142523d-08/
      data fxyz(23, 8,19),fxyz(23, 8,20)/ 4.4631428d-09,-1.8806083d-08/
      data fxyz(23, 8,21),fxyz(23, 8,22)/-1.7597319d-08,-3.7191508d-10/
      data fxyz(23, 8,23)/                7.9889437d-09/
      data fxyz(23, 9, 1),fxyz(23, 9, 2)/ 4.0857153d-08, 1.6149250d-08/
      data fxyz(23, 9, 3),fxyz(23, 9, 4)/-3.5745448d-08,-3.7584364d-08/
      data fxyz(23, 9, 5),fxyz(23, 9, 6)/ 2.3504913d-08, 1.3273416d-08/
      data fxyz(23, 9, 7),fxyz(23, 9, 8)/ 5.8596980d-09, 1.0994767d-08/
      data fxyz(23, 9, 9),fxyz(23, 9,10)/-3.9500472d-09, 1.9436425d-10/
      data fxyz(23, 9,11),fxyz(23, 9,12)/ 5.9577900d-09, 1.2266093d-09/
      data fxyz(23, 9,13),fxyz(23, 9,14)/ 7.1699213d-09,-2.7960415d-09/
      data fxyz(23, 9,15),fxyz(23, 9,16)/ 7.8397168d-09,-2.2118173d-09/
      data fxyz(23, 9,17),fxyz(23, 9,18)/ 5.7969142d-09,-1.8294435d-10/
      data fxyz(23, 9,19),fxyz(23, 9,20)/-8.8040016d-09,-5.2982587d-09/
      data fxyz(23, 9,21),fxyz(23, 9,22)/-5.7851450d-09,-6.8564566d-09/
      data fxyz(23, 9,23)/               -7.4862383d-09/
      data fxyz(23,10, 1),fxyz(23,10, 2)/-2.4952885d-08,-1.7048545d-08/
      data fxyz(23,10, 3),fxyz(23,10, 4)/-1.5497777d-09, 9.6865403d-10/
      data fxyz(23,10, 5),fxyz(23,10, 6)/-2.7122272d-08, 1.2823591d-08/
      data fxyz(23,10, 7),fxyz(23,10, 8)/ 9.7889513d-09, 1.5562827d-11/
      data fxyz(23,10, 9),fxyz(23,10,10)/-1.6549439d-09, 1.0125339d-08/
      data fxyz(23,10,11),fxyz(23,10,12)/-7.3750392d-09, 4.6659802d-09/
      data fxyz(23,10,13),fxyz(23,10,14)/ 1.3640028d-10, 6.5328604d-09/
      data fxyz(23,10,15),fxyz(23,10,16)/-3.4606913d-09, 3.5518804d-09/
      data fxyz(23,10,17),fxyz(23,10,18)/-4.1499211d-09,-2.3758977d-10/
      data fxyz(23,10,19),fxyz(23,10,20)/-5.7683214d-10,-2.4568620d-09/
      data fxyz(23,10,21),fxyz(23,10,22)/-2.4313191d-09,-6.7900396d-10/
      data fxyz(23,10,23)/                1.4555455d-10/
      data fxyz(23,11, 1),fxyz(23,11, 2)/ 7.5697150d-08, 3.9601564d-08/
      data fxyz(23,11, 3),fxyz(23,11, 4)/-3.4284819d-08,-4.0342096d-08/
      data fxyz(23,11, 5),fxyz(23,11, 6)/ 6.3830672d-08,-1.5162002d-08/
      data fxyz(23,11, 7),fxyz(23,11, 8)/ 3.8436263d-09, 1.3648075d-10/
      data fxyz(23,11, 9),fxyz(23,11,10)/ 1.5391158d-08,-1.9365531d-08/
      data fxyz(23,11,11),fxyz(23,11,12)/ 1.2752634d-08,-2.4084103d-09/
      data fxyz(23,11,13),fxyz(23,11,14)/ 2.1582441d-10,-1.5949186d-09/
      data fxyz(23,11,15),fxyz(23,11,16)/ 4.2013860d-09,-1.4457250d-09/
      data fxyz(23,11,17),fxyz(23,11,18)/ 6.5670388d-10,-2.1955051d-09/
      data fxyz(23,11,19),fxyz(23,11,20)/ 1.2373167d-09,-1.1142253d-09/
      data fxyz(23,11,21),fxyz(23,11,22)/-8.9918377d-10, 3.7715061d-10/
      data fxyz(23,11,23)/                1.0301177d-09/
      data fxyz(23,12, 1),fxyz(23,12, 2)/-1.4655100d-07,-7.6599218d-08/
      data fxyz(23,12, 3),fxyz(23,12, 4)/ 6.7473502d-08, 7.7665428d-08/
      data fxyz(23,12, 5),fxyz(23,12, 6)/-1.1736692d-07, 6.3278952d-09/
      data fxyz(23,12, 7),fxyz(23,12, 8)/-1.5123220d-08, 7.5658656d-09/
      data fxyz(23,12, 9),fxyz(23,12,10)/-6.3457209d-09, 1.7979847d-08/
      data fxyz(23,12,11),fxyz(23,12,12)/-8.4400220d-09, 1.5781255d-09/
      data fxyz(23,12,13),fxyz(23,12,14)/-9.3535329d-11, 2.0312001d-09/
      data fxyz(23,12,15),fxyz(23,12,16)/-3.5593783d-09, 2.4341639d-09/
      data fxyz(23,12,17),fxyz(23,12,18)/-2.2435866d-09, 3.3049166d-09/
      data fxyz(23,12,19),fxyz(23,12,20)/-1.3231451d-09, 1.7129883d-10/
      data fxyz(23,12,21),fxyz(23,12,22)/-8.1492410d-11,-3.1198011d-10/
      data fxyz(23,12,23)/               -4.8695203d-10/
      data fxyz(23,13, 1),fxyz(23,13, 2)/ 8.7711591d-09, 1.1482890d-08/
      data fxyz(23,13, 3),fxyz(23,13, 4)/ 1.9278455d-08, 1.5805206d-08/
      data fxyz(23,13, 5),fxyz(23,13, 6)/ 2.5375885d-08,-4.3327574d-08/
      data fxyz(23,13, 7),fxyz(23,13, 8)/-1.1509225d-08,-9.5827654d-09/
      data fxyz(23,13, 9),fxyz(23,13,10)/ 7.9930062d-09,-1.0664478d-09/
      data fxyz(23,13,11),fxyz(23,13,12)/ 5.8962775d-09, 1.5076030d-09/
      data fxyz(23,13,13),fxyz(23,13,14)/-7.7953234d-10,-2.3856828d-09/
      data fxyz(23,13,15),fxyz(23,13,16)/ 3.5132976d-09,-3.2742350d-09/
      data fxyz(23,13,17),fxyz(23,13,18)/ 4.3005370d-09,-4.8024583d-09/
      data fxyz(23,13,19),fxyz(23,13,20)/ 3.2692177d-09,-9.7358339d-11/
      data fxyz(23,13,21),fxyz(23,13,22)/ 3.6036689d-10, 1.4383168d-09/
      data fxyz(23,13,23)/                2.0634201d-09/
      data fxyz(23,14, 1),fxyz(23,14, 2)/ 7.2686598d-09, 8.8697594d-09/
      data fxyz(23,14, 3),fxyz(23,14, 4)/ 1.2748722d-08, 1.1964661d-08/
      data fxyz(23,14, 5),fxyz(23,14, 6)/ 1.2006005d-08,-4.4922610d-09/
      data fxyz(23,14, 7),fxyz(23,14, 8)/-2.1140232d-08,-7.1866775d-09/
      data fxyz(23,14, 9),fxyz(23,14,10)/-6.3101926d-09, 4.0240393d-09/
      data fxyz(23,14,11),fxyz(23,14,12)/ 3.4833535d-09,-2.2759970d-09/
      data fxyz(23,14,13),fxyz(23,14,14)/ 2.0100738d-09, 4.0662556d-09/
      data fxyz(23,14,15),fxyz(23,14,16)/-8.4785712d-09, 8.8085792d-09/
      data fxyz(23,14,17),fxyz(23,14,18)/-6.2959667d-09, 7.0326399d-09/
      data fxyz(23,14,19),fxyz(23,14,20)/-4.7486014d-09, 1.0121049d-09/
      data fxyz(23,14,21),fxyz(23,14,22)/ 3.2525815d-10,-2.0012145d-09/
      data fxyz(23,14,23)/               -3.2700609d-09/
      data fxyz(23,15, 1),fxyz(23,15, 2)/-1.1707496d-08, 1.7214213d-10/
      data fxyz(23,15, 3),fxyz(23,15, 4)/ 2.6125418d-08, 2.5255829d-08/
      data fxyz(23,15, 5),fxyz(23,15, 6)/ 3.6504970d-09,-2.4751327d-08/
      data fxyz(23,15, 7),fxyz(23,15, 8)/ 4.2459246d-09,-1.0872370d-08/
      data fxyz(23,15, 9),fxyz(23,15,10)/-8.8487711d-09,-3.7163384d-09/
      data fxyz(23,15,11),fxyz(23,15,12)/-2.5749298d-09, 5.2438112d-09/
      data fxyz(23,15,13),fxyz(23,15,14)/ 3.5681314d-10,-8.6798066d-09/
      data fxyz(23,15,15),fxyz(23,15,16)/ 2.5466110d-08,-3.5872205d-08/
      data fxyz(23,15,17),fxyz(23,15,18)/ 2.3836703d-08,-1.0239236d-08/
      data fxyz(23,15,19),fxyz(23,15,20)/ 7.4431701d-09,-2.1414727d-09/
      data fxyz(23,15,21),fxyz(23,15,22)/-1.0898000d-09, 3.2364791d-09/
      data fxyz(23,15,23)/                5.5358554d-09/
      data fxyz(23,16, 1),fxyz(23,16, 2)/-3.0314592d-09,-9.3874341d-09/
      data fxyz(23,16, 3),fxyz(23,16, 4)/-2.6477556d-08,-2.0404748d-08/
      data fxyz(23,16, 5),fxyz(23,16, 6)/-3.3678664d-08, 8.8060653d-08/
      data fxyz(23,16, 7),fxyz(23,16, 8)/-1.3005911d-08, 4.7507184d-09/
      data fxyz(23,16, 9),fxyz(23,16,10)/-1.9108221d-09,-7.8038584d-09/
      data fxyz(23,16,11),fxyz(23,16,12)/-1.2864598d-09,-4.9076863d-09/
      data fxyz(23,16,13),fxyz(23,16,14)/ 1.8573729d-09, 7.9017196d-09/
      data fxyz(23,16,15),fxyz(23,16,16)/-3.4774106d-08, 5.6451621d-08/
      data fxyz(23,16,17),fxyz(23,16,18)/-3.7077187d-08, 1.3513410d-08/
      data fxyz(23,16,19),fxyz(23,16,20)/-9.2532047d-09, 2.8288277d-09/
      data fxyz(23,16,21),fxyz(23,16,22)/ 1.4804940d-09,-3.8598700d-09/
      data fxyz(23,16,23)/               -6.7115955d-09/
      data fxyz(23,17, 1),fxyz(23,17, 2)/ 5.1093132d-08, 2.7295136d-08/
      data fxyz(23,17, 3),fxyz(23,17, 4)/-1.9416498d-08,-2.6913622d-08/
      data fxyz(23,17, 5),fxyz(23,17, 6)/ 5.7283633d-08,-6.1363732d-08/
      data fxyz(23,17, 7),fxyz(23,17, 8)/ 4.4241685d-08, 1.7982719d-09/
      data fxyz(23,17, 9),fxyz(23,17,10)/ 2.7996045d-09, 3.6741944d-10/
      data fxyz(23,17,11),fxyz(23,17,12)/-2.9800809d-09, 2.3301041d-10/
      data fxyz(23,17,13),fxyz(23,17,14)/-4.3726756d-09,-1.4324682d-09/
      data fxyz(23,17,15),fxyz(23,17,16)/ 1.9473120d-08,-3.4004157d-08/
      data fxyz(23,17,17),fxyz(23,17,18)/ 2.2337576d-08,-8.4472239d-09/
      data fxyz(23,17,19),fxyz(23,17,20)/ 5.8656216d-09,-2.8125071d-09/
      data fxyz(23,17,21),fxyz(23,17,22)/-1.9408628d-09, 2.3790446d-09/
      data fxyz(23,17,23)/                4.6274398d-09/
      data fxyz(23,18, 1),fxyz(23,18, 2)/-3.3990632d-09,-4.9253669d-09/
      data fxyz(23,18, 3),fxyz(23,18, 4)/-9.1551838d-09,-7.4766431d-09/
      data fxyz(23,18, 5),fxyz(23,18, 6)/-1.1639530d-08, 2.1779047d-08/
      data fxyz(23,18, 7),fxyz(23,18, 8)/-7.7636372d-09, 5.9223602d-09/
      data fxyz(23,18, 9),fxyz(23,18,10)/ 3.2201436d-09, 2.3013722d-09/
      data fxyz(23,18,11),fxyz(23,18,12)/ 5.4803399d-10, 4.0990400d-10/
      data fxyz(23,18,13),fxyz(23,18,14)/ 1.0635251d-09,-7.2457879d-10/
      data fxyz(23,18,15),fxyz(23,18,16)/-3.2904759d-09, 5.7731242d-09/
      data fxyz(23,18,17),fxyz(23,18,18)/-3.9764927d-09, 8.6995574d-10/
      data fxyz(23,18,19),fxyz(23,18,20)/-2.7250244d-09, 5.6112759d-11/
      data fxyz(23,18,21),fxyz(23,18,22)/-1.7614250d-10,-1.7960033d-09/
      data fxyz(23,18,23)/               -2.6138731d-09/
      data fxyz(23,19, 1),fxyz(23,19, 2)/-2.6857891d-08,-1.7459278d-08/
      data fxyz(23,19, 3),fxyz(23,19, 4)/ 1.9177146d-10, 4.5472352d-09/
      data fxyz(23,19, 5),fxyz(23,19, 6)/-3.4881133d-08, 3.8474065d-08/
      data fxyz(23,19, 7),fxyz(23,19, 8)/-2.8553840d-08, 8.0245814d-09/
      data fxyz(23,19, 9),fxyz(23,19,10)/ 4.8663648d-09, 6.0174179d-09/
      data fxyz(23,19,11),fxyz(23,19,12)/ 2.5842243d-09, 2.0050270d-09/
      data fxyz(23,19,13),fxyz(23,19,14)/ 3.1665118d-09,-2.8858543d-09/
      data fxyz(23,19,15),fxyz(23,19,16)/-4.0509801d-09, 8.3409600d-09/
      data fxyz(23,19,17),fxyz(23,19,18)/-5.7966094d-09, 1.2506173d-09/
      data fxyz(23,19,19),fxyz(23,19,20)/-4.5415354d-09, 4.9331698d-10/
      data fxyz(23,19,21),fxyz(23,19,22)/ 1.0684149d-10,-2.9956334d-09/
      data fxyz(23,19,23)/               -4.5465151d-09/
      data fxyz(24, 1, 1),fxyz(24, 1, 2)/-1.3683906d-08,-6.5683567d-08/
      data fxyz(24, 1, 3),fxyz(24, 1, 4)/-1.7879025d-07,-1.7585229d-07/
      data fxyz(24, 1, 5),fxyz(24, 1, 6)/-7.7435408d-08, 3.0385499d-08/
      data fxyz(24, 1, 7),fxyz(24, 1, 8)/ 9.9649336d-08, 8.5529153d-08/
      data fxyz(24, 1, 9),fxyz(24, 1,10)/ 1.9490261d-08, 7.5585095d-08/
      data fxyz(24, 1,11),fxyz(24, 1,12)/-6.1535156d-09, 3.4124670d-08/
      data fxyz(24, 1,13),fxyz(24, 1,14)/ 6.2120558d-08, 3.0264845d-08/
      data fxyz(24, 1,15),fxyz(24, 1,16)/ 3.0385167d-08, 1.0105184d-07/
      data fxyz(24, 1,17),fxyz(24, 1,18)/ 4.1289715d-08, 2.4552811d-07/
      data fxyz(24, 1,19),fxyz(24, 1,20)/-3.2337801d-07,-1.1542826d-07/
      data fxyz(24, 1,21),fxyz(24, 1,22)/-1.4703978d-07,-1.9693194d-07/
      data fxyz(24, 1,23)/               -2.2864468d-07/
      data fxyz(24, 2, 1),fxyz(24, 2, 2)/ 3.0588952d-08,-5.8021629d-09/
      data fxyz(24, 2, 3),fxyz(24, 2, 4)/-8.3321525d-08,-8.4129322d-08/
      data fxyz(24, 2, 5),fxyz(24, 2, 6)/-2.5709734d-09, 1.8471991d-08/
      data fxyz(24, 2, 7),fxyz(24, 2, 8)/ 4.6304248d-08, 3.5636078d-08/
      data fxyz(24, 2, 9),fxyz(24, 2,10)/-1.2938846d-10, 2.7110954d-08/
      data fxyz(24, 2,11),fxyz(24, 2,12)/-1.2630623d-08, 6.7888620d-09/
      data fxyz(24, 2,13),fxyz(24, 2,14)/ 2.0644264d-08, 5.1433067d-09/
      data fxyz(24, 2,15),fxyz(24, 2,16)/ 5.2638773d-09, 4.3695493d-08/
      data fxyz(24, 2,17),fxyz(24, 2,18)/ 1.6813412d-08, 1.2665049d-07/
      data fxyz(24, 2,19),fxyz(24, 2,20)/-1.3070546d-07,-5.0598815d-08/
      data fxyz(24, 2,21),fxyz(24, 2,22)/-6.4589592d-08,-7.4742347d-08/
      data fxyz(24, 2,23)/               -8.3211174d-08/
      data fxyz(24, 3, 1),fxyz(24, 3, 2)/ 4.0143833d-07, 2.4506762d-07/
      data fxyz(24, 3, 3),fxyz(24, 3, 4)/-7.4906163d-08,-1.0134224d-07/
      data fxyz(24, 3, 5),fxyz(24, 3, 6)/ 3.5081191d-07, 4.8972341d-09/
      data fxyz(24, 3, 7),fxyz(24, 3, 8)/-4.5167601d-08,-2.6693671d-08/
      data fxyz(24, 3, 9),fxyz(24, 3,10)/-2.8663046d-08,-6.4065217d-08/
      data fxyz(24, 3,11),fxyz(24, 3,12)/-2.1853822d-08,-3.8197671d-08/
      data fxyz(24, 3,13),fxyz(24, 3,14)/-5.2763667d-08,-4.2162482d-08/
      data fxyz(24, 3,15),fxyz(24, 3,16)/-3.3764536d-08,-3.1376377d-08/
      data fxyz(24, 3,17),fxyz(24, 3,18)/-2.0847345d-08,-6.8635691d-08/
      data fxyz(24, 3,19),fxyz(24, 3,20)/ 4.0169311d-07,-1.0077461d-07/
      data fxyz(24, 3,21),fxyz(24, 3,22)/-6.7318260d-08, 2.6786772d-07/
      data fxyz(24, 3,23)/                4.3320953d-07/
      data fxyz(24, 4, 1),fxyz(24, 4, 2)/-3.7073012d-07,-1.7252192d-07/
      data fxyz(24, 4, 3),fxyz(24, 4, 4)/ 2.3819596d-07, 2.6272042d-07/
      data fxyz(24, 4, 5),fxyz(24, 4, 6)/-2.7061977d-07,-2.8631495d-09/
      data fxyz(24, 4, 7),fxyz(24, 4, 8)/-3.1957883d-09,-4.5495059d-08/
      data fxyz(24, 4, 9),fxyz(24, 4,10)/-2.5997675d-08,-5.7842839d-09/
      data fxyz(24, 4,11),fxyz(24, 4,12)/-2.1465703d-08,-2.1406668d-08/
      data fxyz(24, 4,13),fxyz(24, 4,14)/-1.4410870d-08,-1.1823394d-08/
      data fxyz(24, 4,15),fxyz(24, 4,16)/-2.4118018d-08,-4.4443911d-08/
      data fxyz(24, 4,17),fxyz(24, 4,18)/-1.2362515d-08, 3.5080844d-09/
      data fxyz(24, 4,19),fxyz(24, 4,20)/-2.5494936d-07, 2.5156793d-07/
      data fxyz(24, 4,21),fxyz(24, 4,22)/ 2.2807906d-07,-1.6099388d-07/
      data fxyz(24, 4,23)/               -3.4882495d-07/
      data fxyz(24, 5, 1),fxyz(24, 5, 2)/ 1.0387783d-07, 5.4549276d-08/
      data fxyz(24, 5, 3),fxyz(24, 5, 4)/-4.6992662d-08,-5.4276355d-08/
      data fxyz(24, 5, 5),fxyz(24, 5, 6)/ 8.3684049d-08,-5.3775640d-09/
      data fxyz(24, 5, 7),fxyz(24, 5, 8)/-1.7770992d-08, 1.2323821d-08/
      data fxyz(24, 5, 9),fxyz(24, 5,10)/ 1.2817982d-08,-2.1668799d-09/
      data fxyz(24, 5,11),fxyz(24, 5,12)/-2.9464214d-09,-1.6190686d-09/
      data fxyz(24, 5,13),fxyz(24, 5,14)/-2.7973311d-09,-1.0078860d-09/
      data fxyz(24, 5,15),fxyz(24, 5,16)/ 1.0080443d-08, 9.9780891d-09/
      data fxyz(24, 5,17),fxyz(24, 5,18)/-1.3381829d-08,-1.6289410d-08/
      data fxyz(24, 5,19),fxyz(24, 5,20)/ 9.1641878d-08,-5.3976840d-08/
      data fxyz(24, 5,21),fxyz(24, 5,22)/-4.5627789d-08, 5.8245671d-08/
      data fxyz(24, 5,23)/                1.0894637d-07/
      data fxyz(24, 6, 1),fxyz(24, 6, 2)/-2.1912916d-08,-2.0172901d-08/
      data fxyz(24, 6, 3),fxyz(24, 6, 4)/-1.7557113d-08,-1.5609686d-08/
      data fxyz(24, 6, 5),fxyz(24, 6, 6)/-2.7962606d-08, 7.2984783d-09/
      data fxyz(24, 6, 7),fxyz(24, 6, 8)/ 2.3729587d-08, 6.0299375d-09/
      data fxyz(24, 6, 9),fxyz(24, 6,10)/-4.6487692d-09, 3.7436857d-09/
      data fxyz(24, 6,11),fxyz(24, 6,12)/ 1.1035834d-08, 1.3675100d-08/
      data fxyz(24, 6,13),fxyz(24, 6,14)/ 7.8323851d-09, 4.0872724d-09/
      data fxyz(24, 6,15),fxyz(24, 6,16)/-4.8135071d-09, 4.1337773d-09/
      data fxyz(24, 6,17),fxyz(24, 6,18)/ 1.9488528d-08, 1.4047451d-08/
      data fxyz(24, 6,19),fxyz(24, 6,20)/-3.1570920d-08,-1.4127970d-08/
      data fxyz(24, 6,21),fxyz(24, 6,22)/-1.6679793d-08,-2.1363626d-08/
      data fxyz(24, 6,23)/               -2.4229901d-08/
      data fxyz(24, 7, 1),fxyz(24, 7, 2)/ 8.7397280d-09, 1.2852083d-10/
      data fxyz(24, 7, 3),fxyz(24, 7, 4)/-1.7888455d-08,-1.8650774d-08/
      data fxyz(24, 7, 5),fxyz(24, 7, 6)/ 3.1777979d-09,-2.6950609d-09/
      data fxyz(24, 7, 7),fxyz(24, 7, 8)/-3.0125529d-09, 4.5733407d-09/
      data fxyz(24, 7, 9),fxyz(24, 7,10)/ 1.2695849d-08, 9.6243991d-09/
      data fxyz(24, 7,11),fxyz(24, 7,12)/ 3.5036215d-09,-3.4244353d-11/
      data fxyz(24, 7,13),fxyz(24, 7,14)/ 6.3887626d-09, 5.8128439d-09/
      data fxyz(24, 7,15),fxyz(24, 7,16)/ 1.2136443d-08, 5.3185131d-09/
      data fxyz(24, 7,17),fxyz(24, 7,18)/-2.9690138d-09,-5.3488981d-09/
      data fxyz(24, 7,19),fxyz(24, 7,20)/ 3.6345474d-09,-1.6918801d-08/
      data fxyz(24, 7,21),fxyz(24, 7,22)/-1.6037076d-08, 1.0764718d-10/
      data fxyz(24, 7,23)/                7.8769778d-09/
      data fxyz(24, 8, 1),fxyz(24, 8, 2)/-6.1796924d-09,-6.9898602d-09/
      data fxyz(24, 8, 3),fxyz(24, 8, 4)/-9.0366149d-09,-8.4929233d-09/
      data fxyz(24, 8, 5),fxyz(24, 8, 6)/-9.1646267d-09, 1.9756822d-09/
      data fxyz(24, 8, 7),fxyz(24, 8, 8)/ 2.1621640d-09, 8.0305694d-09/
      data fxyz(24, 8, 9),fxyz(24, 8,10)/ 1.5769135d-09, 3.1042859d-09/
      data fxyz(24, 8,11),fxyz(24, 8,12)/ 3.8738234d-09, 4.3949763d-09/
      data fxyz(24, 8,13),fxyz(24, 8,14)/ 2.5075182d-09, 2.7667924d-09/
      data fxyz(24, 8,15),fxyz(24, 8,16)/ 3.5017402d-09, 3.7086189d-09/
      data fxyz(24, 8,17),fxyz(24, 8,18)/ 4.4654477d-09,-1.2870341d-09/
      data fxyz(24, 8,19),fxyz(24, 8,20)/-9.4818932d-09,-6.0395193d-09/
      data fxyz(24, 8,21),fxyz(24, 8,22)/-6.5047709d-09,-7.6208868d-09/
      data fxyz(24, 8,23)/               -8.2658080d-09/
      data fxyz(24, 9, 1),fxyz(24, 9, 2)/-9.0973329d-10,-2.3406393d-09/
      data fxyz(24, 9, 3),fxyz(24, 9, 4)/-5.5366060d-09,-5.3095619d-09/
      data fxyz(24, 9, 5),fxyz(24, 9, 6)/-3.2488159d-09, 2.4959289d-09/
      data fxyz(24, 9, 7),fxyz(24, 9, 8)/ 5.3705953d-09,-4.3603727d-09/
      data fxyz(24, 9, 9),fxyz(24, 9,10)/ 3.1762039d-09, 5.5619837d-10/
      data fxyz(24, 9,11),fxyz(24, 9,12)/ 3.1326681d-09, 3.1629688d-09/
      data fxyz(24, 9,13),fxyz(24, 9,14)/ 7.2367769d-10, 4.9549690d-09/
      data fxyz(24, 9,15),fxyz(24, 9,16)/-2.1377298d-09, 2.4452072d-09/
      data fxyz(24, 9,17),fxyz(24, 9,18)/-2.4062440d-09, 1.1193466d-09/
      data fxyz(24, 9,19),fxyz(24, 9,20)/-1.0480253d-09,-3.9223212d-09/
      data fxyz(24, 9,21),fxyz(24, 9,22)/-3.9615317d-09,-8.9118347d-10/
      data fxyz(24, 9,23)/                5.3118958d-10/
      data fxyz(24,10, 1),fxyz(24,10, 2)/ 1.5160336d-08, 6.5947327d-09/
      data fxyz(24,10, 3),fxyz(24,10, 4)/-1.1292417d-08,-1.2110919d-08/
      data fxyz(24,10, 5),fxyz(24,10, 6)/ 9.8687392d-09, 2.8828120d-09/
      data fxyz(24,10, 7),fxyz(24,10, 8)/ 1.5671696d-09, 3.8270300d-09/
      data fxyz(24,10, 9),fxyz(24,10,10)/-5.3856652d-10,-1.8516851d-09/
      data fxyz(24,10,11),fxyz(24,10,12)/ 1.9177794d-09, 3.1454281d-10/
      data fxyz(24,10,13),fxyz(24,10,14)/ 2.7718766d-09,-2.5499642d-09/
      data fxyz(24,10,15),fxyz(24,10,16)/ 4.3798439d-09,-2.3853661d-09/
      data fxyz(24,10,17),fxyz(24,10,18)/ 2.8859474d-09,-2.5409578d-09/
      data fxyz(24,10,19),fxyz(24,10,20)/-6.7132080d-10,-1.3459336d-09/
      data fxyz(24,10,21),fxyz(24,10,22)/-1.2422411d-09,-1.0860910d-09/
      data fxyz(24,10,23)/               -9.8556959d-10/
      data fxyz(24,11, 1),fxyz(24,11, 2)/-1.5790407d-08,-9.1351865d-09/
      data fxyz(24,11, 3),fxyz(24,11, 4)/ 4.3542731d-09, 5.7047938d-09/
      data fxyz(24,11, 5),fxyz(24,11, 6)/-1.4537269d-08, 4.4674035d-09/
      data fxyz(24,11, 7),fxyz(24,11, 8)/-1.7591635d-09, 5.0737743d-09/
      data fxyz(24,11, 9),fxyz(24,11,10)/-4.1557562d-09, 5.7301247d-09/
      data fxyz(24,11,11),fxyz(24,11,12)/-4.6463033d-09, 1.6911359d-09/
      data fxyz(24,11,13),fxyz(24,11,14)/-5.4694137d-10, 2.7279216d-09/
      data fxyz(24,11,15),fxyz(24,11,16)/-2.6669919d-09, 1.8933990d-09/
      data fxyz(24,11,17),fxyz(24,11,18)/-2.0861342d-09, 2.1498306d-09/
      data fxyz(24,11,19),fxyz(24,11,20)/-7.0608213d-11,-8.9492799d-10/
      data fxyz(24,11,21),fxyz(24,11,22)/-9.8206832d-10, 2.7795311d-10/
      data fxyz(24,11,23)/                8.4272569d-10/
      data fxyz(24,12, 1),fxyz(24,12, 2)/ 7.4856718d-09, 5.1041603d-09/
      data fxyz(24,12, 3),fxyz(24,12, 4)/ 8.1218435d-10,-6.0752587d-10/
      data fxyz(24,12, 5),fxyz(24,12, 6)/ 1.0783001d-08,-1.3809982d-08/
      data fxyz(24,12, 7),fxyz(24,12, 8)/ 2.8762365d-09,-7.0886211d-09/
      data fxyz(24,12, 9),fxyz(24,12,10)/ 8.9805052d-09,-5.3116644d-09/
      data fxyz(24,12,11),fxyz(24,12,12)/ 5.2882388d-09,-2.9085197d-09/
      data fxyz(24,12,13),fxyz(24,12,14)/ 2.4988185d-09,-2.1258338d-09/
      data fxyz(24,12,15),fxyz(24,12,16)/ 2.3180920d-09,-1.6479319d-09/
      data fxyz(24,12,17),fxyz(24,12,18)/ 1.5771582d-09,-2.7838108d-09/
      data fxyz(24,12,19),fxyz(24,12,20)/ 1.1879318d-09, 3.5696884d-10/
      data fxyz(24,12,21),fxyz(24,12,22)/ 5.6390833d-10, 3.6017383d-10/
      data fxyz(24,12,23)/                3.2028160d-10/
      data fxyz(24,13, 1),fxyz(24,13, 2)/-2.6523433d-08,-1.1491703d-08/
      data fxyz(24,13, 3),fxyz(24,13, 4)/ 2.0063297d-08, 2.1211034d-08/
      data fxyz(24,13, 5),fxyz(24,13, 6)/-1.6082653d-08,-9.3073710d-09/
      data fxyz(24,13, 7),fxyz(24,13, 8)/-1.2501703d-08, 4.3577137d-09/
      data fxyz(24,13, 9),fxyz(24,13,10)/-4.9796879d-09, 8.6486659d-09/
      data fxyz(24,13,11),fxyz(24,13,12)/-4.3992995d-09, 3.5678438d-09/
      data fxyz(24,13,13),fxyz(24,13,14)/-3.5775338d-09, 3.9213589d-09/
      data fxyz(24,13,15),fxyz(24,13,16)/-2.7756050d-09, 2.8249058d-09/
      data fxyz(24,13,17),fxyz(24,13,18)/-2.6221082d-09, 2.2286084d-09/
      data fxyz(24,13,19),fxyz(24,13,20)/-1.5405124d-09, 5.8582896d-10/
      data fxyz(24,13,21),fxyz(24,13,22)/ 3.5981250d-10,-6.3644655d-10/
      data fxyz(24,13,23)/               -1.1616385d-09/
      data fxyz(24,14, 1),fxyz(24,14, 2)/-8.2323726d-09,-1.5460759d-09/
      data fxyz(24,14, 3),fxyz(24,14, 4)/ 1.2733876d-08, 1.2817573d-08/
      data fxyz(24,14, 5),fxyz(24,14, 6)/-1.8808661d-09,-6.9769092d-09/
      data fxyz(24,14, 7),fxyz(24,14, 8)/-5.7155468d-09,-8.2194692d-09/
      data fxyz(24,14, 9),fxyz(24,14,10)/ 4.5417187d-09,-7.0508159d-09/
      data fxyz(24,14,11),fxyz(24,14,12)/ 6.5320119d-09,-3.3168622d-09/
      data fxyz(24,14,13),fxyz(24,14,14)/ 1.0055925d-08,-1.6297519d-08/
      data fxyz(24,14,15),fxyz(24,14,16)/ 1.4209592d-08,-1.0373061d-08/
      data fxyz(24,14,17),fxyz(24,14,18)/ 7.1907688d-09,-3.0059923d-09/
      data fxyz(24,14,19),fxyz(24,14,20)/ 1.2902347d-09,-1.7363814d-10/
      data fxyz(24,14,21),fxyz(24,14,22)/ 6.2724243d-11, 3.4478514d-10/
      data fxyz(24,14,23)/                5.3944353d-10/
      data fxyz(24,15, 1),fxyz(24,15, 2)/ 1.6296895d-08, 8.4592337d-09/
      data fxyz(24,15, 3),fxyz(24,15, 4)/-8.1456515d-09,-8.4783333d-09/
      data fxyz(24,15, 5),fxyz(24,15, 6)/ 9.7899608d-09, 1.1306668d-08/
      data fxyz(24,15, 7),fxyz(24,15, 8)/-1.9157696d-09,-1.0236839d-09/
      data fxyz(24,15, 9),fxyz(24,15,10)/-6.7325751d-09, 3.4241658d-09/
      data fxyz(24,15,11),fxyz(24,15,12)/-4.1249628d-09, 4.4442513d-09/
      data fxyz(24,15,13),fxyz(24,15,14)/-1.6916181d-08, 3.1269903d-08/
      data fxyz(24,15,15),fxyz(24,15,16)/-3.8379815d-08, 3.9846142d-08/
      data fxyz(24,15,17),fxyz(24,15,18)/-2.4644092d-08, 8.8856557d-09/
      data fxyz(24,15,19),fxyz(24,15,20)/-3.0047494d-09, 3.9662759d-10/
      data fxyz(24,15,21),fxyz(24,15,22)/-2.4313733d-10,-4.4568971d-10/
      data fxyz(24,15,23)/               -7.1081813d-10/
      data fxyz(24,16, 1),fxyz(24,16, 2)/ 1.5175565d-08, 8.0470577d-09/
      data fxyz(24,16, 3),fxyz(24,16, 4)/-6.4070407d-09,-7.8442690d-09/
      data fxyz(24,16, 5),fxyz(24,16, 6)/ 1.3795971d-08,-6.3828599d-09/
      data fxyz(24,16, 7),fxyz(24,16, 8)/ 1.0029621d-08,-6.2521013d-10/
      data fxyz(24,16, 9),fxyz(24,16,10)/-3.3231799d-11,-4.0461226d-09/
      data fxyz(24,16,11),fxyz(24,16,12)/-6.7724958d-11,-2.9319178d-09/
      data fxyz(24,16,13),fxyz(24,16,14)/ 1.0625490d-08,-2.4449798d-08/
      data fxyz(24,16,15),fxyz(24,16,16)/ 4.5700679d-08,-5.9689091d-08/
      data fxyz(24,16,17),fxyz(24,16,18)/ 3.7959775d-08,-1.1872057d-08/
      data fxyz(24,16,19),fxyz(24,16,20)/ 4.8536373d-09,-1.2597471d-09/
      data fxyz(24,16,21),fxyz(24,16,22)/-3.3038288d-10, 1.1361803d-09/
      data fxyz(24,16,23)/                2.0684069d-09/
      data fxyz(24,17, 1),fxyz(24,17, 2)/-8.4948596d-09,-6.5809908d-09/
      data fxyz(24,17, 3),fxyz(24,17, 4)/-3.3981392d-09,-1.7911219d-09/
      data fxyz(24,17, 5),fxyz(24,17, 6)/-1.3009060d-08, 1.5610400d-08/
      data fxyz(24,17, 7),fxyz(24,17, 8)/-1.4862062d-09, 4.3053484d-09/
      data fxyz(24,17, 9),fxyz(24,17,10)/ 4.8157024d-10, 1.1326583d-09/
      data fxyz(24,17,11),fxyz(24,17,12)/-1.6849880d-09,-4.8470873d-10/
      data fxyz(24,17,13),fxyz(24,17,14)/-2.4977068d-09, 7.7731997d-09/
      data fxyz(24,17,15),fxyz(24,17,16)/-2.4128782d-08, 3.5578758d-08/
      data fxyz(24,17,17),fxyz(24,17,18)/-2.2584002d-08, 6.5119685d-09/
      data fxyz(24,17,19),fxyz(24,17,20)/-3.3793400d-09, 8.4730883d-10/
      data fxyz(24,17,21),fxyz(24,17,22)/ 2.8415639d-10,-1.1267303d-09/
      data fxyz(24,17,23)/               -1.9353180d-09/
      data fxyz(24,18, 1),fxyz(24,18, 2)/ 1.8965950d-09, 4.7597388d-10/
      data fxyz(24,18, 3),fxyz(24,18, 4)/-2.3820621d-09,-2.7078285d-09/
      data fxyz(24,18, 5),fxyz(24,18, 6)/ 1.7790394d-09,-2.9899008d-09/
      data fxyz(24,18, 7),fxyz(24,18, 8)/ 2.9521138d-09, 1.1798477d-09/
      data fxyz(24,18, 9),fxyz(24,18,10)/ 1.1261116d-09, 2.3397827d-10/
      data fxyz(24,18,11),fxyz(24,18,12)/ 1.4446093d-09,-9.2234998d-11/
      data fxyz(24,18,13),fxyz(24,18,14)/ 4.0179113d-10,-1.5159941d-09/
      data fxyz(24,18,15),fxyz(24,18,16)/ 4.4544079d-09,-6.5925531d-09/
      data fxyz(24,18,17),fxyz(24,18,18)/ 3.5860370d-09,-1.3581446d-09/
      data fxyz(24,18,19),fxyz(24,18,20)/ 2.9960784d-10,-6.5924856d-10/
      data fxyz(24,18,21),fxyz(24,18,22)/-5.5931729d-10,-1.0011724d-10/
      data fxyz(24,18,23)/                1.4082445d-10/
      data fxyz(24,19, 1),fxyz(24,19, 2)/ 2.5560843d-09, 1.3372205d-09/
      data fxyz(24,19, 3),fxyz(24,19, 4)/-7.9660659d-10,-1.6331483d-09/
      data fxyz(24,19, 5),fxyz(24,19, 6)/ 4.6833874d-09,-9.9920414d-09/
      data fxyz(24,19, 7),fxyz(24,19, 8)/ 2.8321058d-09, 3.5607826d-10/
      data fxyz(24,19, 9),fxyz(24,19,10)/ 1.7335846d-09, 1.0717156d-09/
      data fxyz(24,19,11),fxyz(24,19,12)/ 3.2179608d-09, 8.8730597d-10/
      data fxyz(24,19,13),fxyz(24,19,14)/-1.2766238d-09, 1.0554383d-09/
      data fxyz(24,19,15),fxyz(24,19,16)/ 4.9196974d-09,-9.4955326d-09/
      data fxyz(24,19,17),fxyz(24,19,18)/ 4.9806998d-09,-1.7270753d-09/
      data fxyz(24,19,19),fxyz(24,19,20)/ 5.7514851d-10,-1.1333450d-09/
      data fxyz(24,19,21),fxyz(24,19,22)/-9.8621583d-10,-1.3368088d-11/
      data fxyz(24,19,23)/                4.7986197d-10/
      data fxyz(25, 1, 1),fxyz(25, 1, 2)/-1.7234545d-08,-9.6556011d-09/
      data fxyz(25, 1, 3),fxyz(25, 1, 4)/ 6.6823675d-09, 6.5119620d-09/
      data fxyz(25, 1, 5),fxyz(25, 1, 6)/-8.9739791d-09,-1.9790628d-08/
      data fxyz(25, 1, 7),fxyz(25, 1, 8)/-2.6103214d-08,-9.0648836d-09/
      data fxyz(25, 1, 9),fxyz(25, 1,10)/ 1.9165345d-08, 7.5693822d-10/
      data fxyz(25, 1,11),fxyz(25, 1,12)/ 2.9073681d-08, 1.7947042d-08/
      data fxyz(25, 1,13),fxyz(25, 1,14)/ 6.4365986d-09, 1.9529050d-08/
      data fxyz(25, 1,15),fxyz(25, 1,16)/ 1.5975335d-08,-1.1487507d-08/
      data fxyz(25, 1,17),fxyz(25, 1,18)/-5.3589739d-09,-9.1488745d-08/
      data fxyz(25, 1,19),fxyz(25, 1,20)/ 7.3769801d-08,-1.5657188d-08/
      data fxyz(25, 1,21),fxyz(25, 1,22)/-5.8316592d-09, 3.4467686d-08/
      data fxyz(25, 1,23)/                5.5894187d-08/
      data fxyz(25, 2, 1),fxyz(25, 2, 2)/-1.6808693d-08,-8.1982116d-09/
      data fxyz(25, 2, 3),fxyz(25, 2, 4)/ 9.9152402d-09, 1.0506003d-08/
      data fxyz(25, 2, 5),fxyz(25, 2, 6)/-1.0561263d-08,-7.9472482d-09/
      data fxyz(25, 2, 7),fxyz(25, 2, 8)/-1.2163890d-08,-4.5996247d-09/
      data fxyz(25, 2, 9),fxyz(25, 2,10)/ 8.8502927d-09,-1.4462056d-09/
      data fxyz(25, 2,11),fxyz(25, 2,12)/ 1.1320248d-08, 5.5522331d-09/
      data fxyz(25, 2,13),fxyz(25, 2,14)/ 3.1695024d-10, 7.7193359d-09/
      data fxyz(25, 2,15),fxyz(25, 2,16)/ 7.3550624d-09,-5.7989978d-09/
      data fxyz(25, 2,17),fxyz(25, 2,18)/-1.3397265d-09,-4.4117860d-08/
      data fxyz(25, 2,19),fxyz(25, 2,20)/ 3.2804660d-08,-1.9867177d-09/
      data fxyz(25, 2,21),fxyz(25, 2,22)/ 2.4353628d-09, 1.5116338d-08/
      data fxyz(25, 2,23)/                2.2213348d-08/
      data fxyz(25, 3, 1),fxyz(25, 3, 2)/-1.1854479d-07,-6.1747176d-08/
      data fxyz(25, 3, 3),fxyz(25, 3, 4)/ 5.4935046d-08, 6.3732196d-08/
      data fxyz(25, 3, 5),fxyz(25, 3, 6)/-9.6935776d-08, 1.3412461d-08/
      data fxyz(25, 3, 7),fxyz(25, 3, 8)/ 2.2367935d-08, 2.5040191d-09/
      data fxyz(25, 3, 9),fxyz(25, 3,10)/-7.9801821d-09,-8.7819791d-10/
      data fxyz(25, 3,11),fxyz(25, 3,12)/-2.0074234d-08,-1.4886934d-08/
      data fxyz(25, 3,13),fxyz(25, 3,14)/-1.0117099d-08,-9.2707558d-09/
      data fxyz(25, 3,15),fxyz(25, 3,16)/-4.9832119d-09, 4.1418301d-09/
      data fxyz(25, 3,17),fxyz(25, 3,18)/ 1.5198460d-08, 3.9511363d-08/
      data fxyz(25, 3,19),fxyz(25, 3,20)/-1.1376748d-07, 6.1876088d-08/
      data fxyz(25, 3,21),fxyz(25, 3,22)/ 5.0709356d-08,-6.9100546d-08/
      data fxyz(25, 3,23)/               -1.2798963d-07/
      data fxyz(25, 4, 1),fxyz(25, 4, 2)/ 1.3728593d-07, 7.7226099d-08/
      data fxyz(25, 4, 3),fxyz(25, 4, 4)/-4.6299414d-08,-5.5354142d-08/
      data fxyz(25, 4, 5),fxyz(25, 4, 6)/ 1.1344501d-07, 1.4650170d-09/
      data fxyz(25, 4, 7),fxyz(25, 4, 8)/-1.5173996d-08, 3.7331544d-10/
      data fxyz(25, 4, 9),fxyz(25, 4,10)/-2.0066799d-09,-1.0009220d-08/
      data fxyz(25, 4,11),fxyz(25, 4,12)/-3.7250425d-09,-7.1708465d-09/
      data fxyz(25, 4,13),fxyz(25, 4,14)/-5.4507443d-09,-8.1295265d-09/
      data fxyz(25, 4,15),fxyz(25, 4,16)/-4.3084802d-09,-8.0045845d-10/
      data fxyz(25, 4,17),fxyz(25, 4,18)/-1.2079640d-08,-3.7635967d-09/
      data fxyz(25, 4,19),fxyz(25, 4,20)/ 1.0928487d-07,-4.9934281d-08/
      data fxyz(25, 4,21),fxyz(25, 4,22)/-4.1041050d-08, 7.3711946d-08/
      data fxyz(25, 4,23)/                1.2963487d-07/
      data fxyz(25, 5, 1),fxyz(25, 5, 2)/-4.0770929d-08,-2.1386768d-08/
      data fxyz(25, 5, 3),fxyz(25, 5, 4)/ 1.8570518d-08, 2.1335873d-08/
      data fxyz(25, 5, 5),fxyz(25, 5, 6)/-3.2448190d-08, 7.0940323d-10/
      data fxyz(25, 5, 7),fxyz(25, 5, 8)/ 1.0757286d-08,-4.5503642d-09/
      data fxyz(25, 5, 9),fxyz(25, 5,10)/-9.9731035d-09,-6.7301712d-10/
      data fxyz(25, 5,11),fxyz(25, 5,12)/ 2.0807346d-09, 7.2500677d-09/
      data fxyz(25, 5,13),fxyz(25, 5,14)/ 9.3995782d-10,-1.3172506d-09/
      data fxyz(25, 5,15),fxyz(25, 5,16)/-8.7970396d-09,-5.6205748d-09/
      data fxyz(25, 5,17),fxyz(25, 5,18)/ 6.5418220d-09, 7.0753931d-09/
      data fxyz(25, 5,19),fxyz(25, 5,20)/-3.7080035d-08, 2.3445645d-08/
      data fxyz(25, 5,21),fxyz(25, 5,22)/ 2.0008900d-08,-2.3333058d-08/
      data fxyz(25, 5,23)/               -4.4475771d-08/
      data fxyz(25, 6, 1),fxyz(25, 6, 2)/ 9.5883961d-09, 4.6414531d-09/
      data fxyz(25, 6, 3),fxyz(25, 6, 4)/-5.5562669d-09,-6.2612930d-09/
      data fxyz(25, 6, 5),fxyz(25, 6, 6)/ 7.4615577d-09,-9.8699595d-10/
      data fxyz(25, 6, 7),fxyz(25, 6, 8)/-8.0807483d-09, 3.5184803d-10/
      data fxyz(25, 6, 9),fxyz(25, 6,10)/ 9.0117160d-09, 2.8251057d-09/
      data fxyz(25, 6,11),fxyz(25, 6,12)/ 1.0689342d-09,-5.5241196d-09/
      data fxyz(25, 6,13),fxyz(25, 6,14)/ 3.3384693d-09, 1.5923346d-09/
      data fxyz(25, 6,15),fxyz(25, 6,16)/ 7.8219255d-09, 1.2637103d-09/
      data fxyz(25, 6,17),fxyz(25, 6,18)/-6.4422240d-09,-6.3179177d-09/
      data fxyz(25, 6,19),fxyz(25, 6,20)/ 1.0618005d-08,-6.1576762d-09/
      data fxyz(25, 6,21),fxyz(25, 6,22)/-4.9821426d-09, 5.9158705d-09/
      data fxyz(25, 6,23)/                1.1315086d-08/
      data fxyz(25, 7, 1),fxyz(25, 7, 2)/-7.6081684d-09,-5.4548084d-09/
      data fxyz(25, 7, 3),fxyz(25, 7, 4)/-1.0195707d-09,-7.0613644d-10/
      data fxyz(25, 7, 5),fxyz(25, 7, 6)/-6.7085452d-09,-2.9066552d-09/
      data fxyz(25, 7, 7),fxyz(25, 7, 8)/ 2.3934053d-09, 4.3824989d-09/
      data fxyz(25, 7, 9),fxyz(25, 7,10)/-6.9001627d-10, 2.4888737d-09/
      data fxyz(25, 7,11),fxyz(25, 7,12)/ 7.9570924d-11, 5.7716633d-09/
      data fxyz(25, 7,13),fxyz(25, 7,14)/-2.3928680d-09, 4.3408275d-09/
      data fxyz(25, 7,15),fxyz(25, 7,16)/-8.4370653d-10, 3.2481668d-09/
      data fxyz(25, 7,17),fxyz(25, 7,18)/ 2.2028285d-09,-1.2096925d-09/
      data fxyz(25, 7,19),fxyz(25, 7,20)/-8.2945829d-09,-3.5155451d-10/
      data fxyz(25, 7,21),fxyz(25, 7,22)/-8.6381576d-10,-6.2455379d-09/
      data fxyz(25, 7,23)/               -8.8936113d-09/
      data fxyz(25, 8, 1),fxyz(25, 8, 2)/ 1.4264538d-09, 1.0186673d-10/
      data fxyz(25, 8, 3),fxyz(25, 8, 4)/-2.7042375d-09,-2.7607565d-09/
      data fxyz(25, 8, 5),fxyz(25, 8, 6)/ 3.2794274d-10, 5.7866875d-10/
      data fxyz(25, 8, 7),fxyz(25, 8, 8)/ 1.5215721d-09,-3.0911084d-09/
      data fxyz(25, 8, 9),fxyz(25, 8,10)/ 1.6706709d-09,-5.2353183d-10/
      data fxyz(25, 8,11),fxyz(25, 8,12)/ 3.9088309d-09,-5.0903225d-10/
      data fxyz(25, 8,13),fxyz(25, 8,14)/ 3.9973502d-09,-4.3623907d-10/
      data fxyz(25, 8,15),fxyz(25, 8,16)/ 9.6189571d-10,-1.3077873d-09/
      data fxyz(25, 8,17),fxyz(25, 8,18)/-6.3570688d-10, 9.1977251d-10/
      data fxyz(25, 8,19),fxyz(25, 8,20)/ 8.8386085d-10,-2.7809041d-09/
      data fxyz(25, 8,21),fxyz(25, 8,22)/-2.7014272d-09, 5.6595351d-10/
      data fxyz(25, 8,23)/                2.1119250d-09/
      data fxyz(25, 9, 1),fxyz(25, 9, 2)/ 2.9018363d-09, 1.1072897d-09/
      data fxyz(25, 9, 3),fxyz(25, 9, 4)/-2.6113933d-09,-2.8332478d-09/
      data fxyz(25, 9, 5),fxyz(25, 9, 6)/ 1.9947076d-09,-4.2598079d-10/
      data fxyz(25, 9, 7),fxyz(25, 9, 8)/-1.4853803d-10, 1.6395396d-09/
      data fxyz(25, 9, 9),fxyz(25, 9,10)/ 3.2237267d-10, 1.7217660d-09/
      data fxyz(25, 9,11),fxyz(25, 9,12)/-1.6579109d-09, 1.1567531d-09/
      data fxyz(25, 9,13),fxyz(25, 9,14)/ 1.0571413d-10,-8.5642232d-10/
      data fxyz(25, 9,15),fxyz(25, 9,16)/ 2.3843502d-09,-3.7998612d-10/
      data fxyz(25, 9,17),fxyz(25, 9,18)/ 1.4332749d-09,-1.6892475d-09/
      data fxyz(25, 9,19),fxyz(25, 9,20)/-2.8188353d-10,-7.7901869d-10/
      data fxyz(25, 9,21),fxyz(25, 9,22)/-7.0120095d-10,-5.9315449d-10/
      data fxyz(25, 9,23)/               -5.2198141d-10/
      data fxyz(25,10, 1),fxyz(25,10, 2)/-3.0806570d-09,-1.7940929d-09/
      data fxyz(25,10, 3),fxyz(25,10, 4)/ 7.4906829d-10, 1.1231514d-09/
      data fxyz(25,10, 5),fxyz(25,10, 6)/-3.2904253d-09, 2.5305895d-09/
      data fxyz(25,10, 7),fxyz(25,10, 8)/-2.3115862d-09, 3.3160883d-09/
      data fxyz(25,10, 9),fxyz(25,10,10)/-3.3154483d-09, 1.7766578d-09/
      data fxyz(25,10,11),fxyz(25,10,12)/ 9.3394928d-11,-2.5696151d-10/
      data fxyz(25,10,13),fxyz(25,10,14)/-3.3503569d-10, 1.4959689d-09/
      data fxyz(25,10,15),fxyz(25,10,16)/-2.8592264d-09, 2.6121189d-09/
      data fxyz(25,10,17),fxyz(25,10,18)/-1.7540644d-09, 2.5132598d-09/
      data fxyz(25,10,19),fxyz(25,10,20)/-9.7102229d-10,-4.9714039d-10/
      data fxyz(25,10,21),fxyz(25,10,22)/-6.7303091d-10,-2.6746020d-10/
      data fxyz(25,10,23)/               -1.2509801d-10/
      data fxyz(25,11, 1),fxyz(25,11, 2)/ 4.6334513d-09, 2.5861364d-09/
      data fxyz(25,11, 3),fxyz(25,11, 4)/-1.4405851d-09,-2.0712535d-09/
      data fxyz(25,11, 5),fxyz(25,11, 6)/ 5.1088099d-09,-4.8265745d-09/
      data fxyz(25,11, 7),fxyz(25,11, 8)/ 9.4675798d-09,-1.3792008d-08/
      data fxyz(25,11, 9),fxyz(25,11,10)/ 1.0214817d-08,-6.1238740d-09/
      data fxyz(25,11,11),fxyz(25,11,12)/ 3.2486806d-09,-1.8288076d-10/
      data fxyz(25,11,13),fxyz(25,11,14)/ 1.7844199d-10,-8.4036711d-10/
      data fxyz(25,11,15),fxyz(25,11,16)/ 1.8812968d-09,-2.3488220d-09/
      data fxyz(25,11,17),fxyz(25,11,18)/ 2.2855774d-09,-2.1366934d-09/
      data fxyz(25,11,19),fxyz(25,11,20)/ 9.3600280d-10,-1.5332766d-10/
      data fxyz(25,11,21),fxyz(25,11,22)/ 1.6658911d-11, 2.5605651d-10/
      data fxyz(25,11,23)/                4.1310515d-10/
      data fxyz(25,12, 1),fxyz(25,12, 2)/-7.5274429d-09,-3.8265578d-09/
      data fxyz(25,12, 3),fxyz(25,12, 4)/ 3.6389322d-09, 4.4526441d-09/
      data fxyz(25,12, 5),fxyz(25,12, 6)/-7.0814050d-09, 4.6782342d-09/
      data fxyz(25,12, 7),fxyz(25,12, 8)/-1.5473642d-08, 2.1484288d-08/
      data fxyz(25,12, 9),fxyz(25,12,10)/-1.5894168d-08, 9.3758185d-09/
      data fxyz(25,12,11),fxyz(25,12,12)/-5.5964833d-09, 1.9944449d-09/
      data fxyz(25,12,13),fxyz(25,12,14)/-8.0395794d-10, 2.2561709d-09/
      data fxyz(25,12,15),fxyz(25,12,16)/-1.2873671d-09, 1.2252310d-09/
      data fxyz(25,12,17),fxyz(25,12,18)/-2.2399519d-09, 1.5000569d-09/
      data fxyz(25,12,19),fxyz(25,12,20)/ 1.2774526d-10,-4.3679853d-10/
      data fxyz(25,12,21),fxyz(25,12,22)/-4.8943419d-10, 3.3828790d-10/
      data fxyz(25,12,23)/                7.1052203d-10/
      data fxyz(25,13, 1),fxyz(25,13, 2)/ 8.7163164d-10, 6.3902863d-10/
      data fxyz(25,13, 3),fxyz(25,13, 4)/ 3.4017840d-10,-9.0949791d-12/
      data fxyz(25,13, 5),fxyz(25,13, 6)/ 2.0361221d-09,-4.3674690d-09/
      data fxyz(25,13, 7),fxyz(25,13, 8)/ 9.0681379d-09,-1.6211554d-08/
      data fxyz(25,13, 9),fxyz(25,13,10)/ 1.7094579d-08,-1.5425069d-08/
      data fxyz(25,13,11),fxyz(25,13,12)/ 9.7799496d-09,-3.7065469d-09/
      data fxyz(25,13,13),fxyz(25,13,14)/ 5.0091452d-09,-6.1840638d-09/
      data fxyz(25,13,15),fxyz(25,13,16)/ 3.4842926d-09,-1.4864478d-09/
      data fxyz(25,13,17),fxyz(25,13,18)/ 1.4626597d-09,-9.0189589d-10/
      data fxyz(25,13,19),fxyz(25,13,20)/-9.4513768d-10, 8.0273732d-10/
      data fxyz(25,13,21),fxyz(25,13,22)/ 7.6196596d-10,-7.8205221d-10/
      data fxyz(25,13,23)/               -1.5134664d-09/
      data fxyz(25,14, 1),fxyz(25,14, 2)/ 1.6966648d-09, 1.0243673d-09/
      data fxyz(25,14, 3),fxyz(25,14, 4)/-3.7618954d-10,-4.4633109d-10/
      data fxyz(25,14, 5),fxyz(25,14, 6)/ 1.3049335d-09, 6.4454153d-10/
      data fxyz(25,14, 7),fxyz(25,14, 8)/-3.9300462d-09, 7.2618429d-09/
      data fxyz(25,14, 9),fxyz(25,14,10)/-1.5222024d-08, 2.0384196d-08/
      data fxyz(25,14,11),fxyz(25,14,12)/-1.3898639d-08, 8.2899385d-09/
      data fxyz(25,14,13),fxyz(25,14,14)/-1.8983487d-08, 2.8305368d-08/
      data fxyz(25,14,15),fxyz(25,14,16)/-1.8670961d-08, 7.9138547d-09/
      data fxyz(25,14,17),fxyz(25,14,18)/-3.6510643d-09, 5.5007853d-10/
      data fxyz(25,14,19),fxyz(25,14,20)/ 7.1126791d-10,-2.4888224d-10/
      data fxyz(25,14,21),fxyz(25,14,22)/-2.1996169d-10, 5.9558573d-10/
      data fxyz(25,14,23)/                9.8388668d-10/
      data fxyz(25,15, 1),fxyz(25,15, 2)/-9.5629227d-10,-1.3934713d-10/
      data fxyz(25,15, 3),fxyz(25,15, 4)/ 1.6472210d-09, 1.5842710d-09/
      data fxyz(25,15, 5),fxyz(25,15, 6)/ 1.1245289d-10,-1.9005423d-09/
      data fxyz(25,15, 7),fxyz(25,15, 8)/ 1.0734466d-09,-3.1257400d-09/
      data fxyz(25,15, 9),fxyz(25,15,10)/ 7.9371917d-09,-1.3371681d-08/
      data fxyz(25,15,11),fxyz(25,15,12)/ 1.0614940d-08,-1.0832564d-08/
      data fxyz(25,15,13),fxyz(25,15,14)/ 3.1133809d-08,-4.9350035d-08/
      data fxyz(25,15,15),fxyz(25,15,16)/ 4.0167586d-08,-2.5997781d-08/
      data fxyz(25,15,17),fxyz(25,15,18)/ 1.3818699d-08,-2.8829305d-09/
      data fxyz(25,15,19),fxyz(25,15,20)/-5.3593088d-11, 1.4402832d-10/
      data fxyz(25,15,21),fxyz(25,15,22)/ 2.7395462d-10,-5.7329829d-10/
      data fxyz(25,15,23)/               -9.3403597d-10/
      data fxyz(25,16, 1),fxyz(25,16, 2)/-2.5409408d-09,-1.8391377d-09/
      data fxyz(25,16, 3),fxyz(25,16, 4)/-6.4643151d-10,-1.0190578d-10/
      data fxyz(25,16, 5),fxyz(25,16, 6)/-4.0172406d-09, 5.6269452d-09/
      data fxyz(25,16, 7),fxyz(25,16, 8)/-1.6880887d-10, 2.0371934d-10/
      data fxyz(25,16, 9),fxyz(25,16,10)/-2.4664981d-09, 4.0572895d-09/
      data fxyz(25,16,11),fxyz(25,16,12)/-4.4751639d-09, 6.0971016d-09/
      data fxyz(25,16,13),fxyz(25,16,14)/-2.0285987d-08, 3.4203518d-08/
      data fxyz(25,16,15),fxyz(25,16,16)/-3.7561540d-08, 3.5627277d-08/
      data fxyz(25,16,17),fxyz(25,16,18)/-2.0501633d-08, 4.7445820d-09/
      data fxyz(25,16,19),fxyz(25,16,20)/-6.7326423d-10, 9.8932603d-12/
      data fxyz(25,16,21),fxyz(25,16,22)/-2.6241622d-10, 4.1597369d-10/
      data fxyz(25,16,23)/                6.5993979d-10/
      data fxyz(25,17, 1),fxyz(25,17, 2)/ 4.7962238d-09, 2.7398069d-09/
      data fxyz(25,17, 3),fxyz(25,17, 4)/-1.3323380d-09,-1.9176477d-09/
      data fxyz(25,17, 5),fxyz(25,17, 6)/ 5.0810458d-09,-3.9834218d-09/
      data fxyz(25,17, 7),fxyz(25,17, 8)/ 1.4737356d-09, 6.2569294d-10/
      data fxyz(25,17, 9),fxyz(25,17,10)/ 1.0266080d-09,-2.0731252d-09/
      data fxyz(25,17,11),fxyz(25,17,12)/ 1.9422008d-09,-1.8077069d-09/
      data fxyz(25,17,13),fxyz(25,17,14)/ 4.7484442d-09,-1.0467220d-08/
      data fxyz(25,17,15),fxyz(25,17,16)/ 1.6662070d-08,-2.0146863d-08/
      data fxyz(25,17,17),fxyz(25,17,18)/ 1.1774276d-08,-2.2912160d-09/
      data fxyz(25,17,19),fxyz(25,17,20)/ 2.1121538d-10,-9.0795693d-11/
      data fxyz(25,17,21),fxyz(25,17,22)/ 3.4680728d-11,-2.9069030d-10/
      data fxyz(25,17,23)/               -4.0906973d-10/
      data fxyz(25,18, 1),fxyz(25,18, 2)/-9.6560533d-10,-6.8619876d-10/
      data fxyz(25,18, 3),fxyz(25,18, 4)/-1.7726118d-10,-2.0127289d-11/
      data fxyz(25,18, 5),fxyz(25,18, 6)/-1.3147343d-09, 1.3914031d-09/
      data fxyz(25,18, 7),fxyz(25,18, 8)/-3.8640755d-10, 2.7255643d-10/
      data fxyz(25,18, 9),fxyz(25,18,10)/-1.4123380d-10, 1.2157175d-09/
      data fxyz(25,18,11),fxyz(25,18,12)/-1.2833871d-09, 7.9929258d-10/
      data fxyz(25,18,13),fxyz(25,18,14)/-1.1388582d-09, 2.5934032d-09/
      data fxyz(25,18,15),fxyz(25,18,16)/-3.6047476d-09, 3.6199806d-09/
      data fxyz(25,18,17),fxyz(25,18,18)/-1.9051129d-09,-6.6331841d-11/
      data fxyz(25,18,19),fxyz(25,18,20)/ 2.1598115d-10,-1.2797267d-10/
      data fxyz(25,18,21),fxyz(25,18,22)/-1.0695250d-10, 1.3190049d-10/
      data fxyz(25,18,23)/                2.4897060d-10/
      data fxyz(25,19, 1),fxyz(25,19, 2)/-2.9848648d-09,-1.8250758d-09/
      data fxyz(25,19, 3),fxyz(25,19, 4)/ 4.5182039d-10, 8.1646102d-10/
      data fxyz(25,19, 5),fxyz(25,19, 6)/-3.2836383d-09, 2.4847446d-09/
      data fxyz(25,19, 7),fxyz(25,19, 8)/-1.2457828d-09, 1.4087995d-10/
      data fxyz(25,19, 9),fxyz(25,19,10)/ 2.2623815d-11, 1.8133438d-09/
      data fxyz(25,19,11),fxyz(25,19,12)/-1.7538457d-09, 4.0291834d-10/
      data fxyz(25,19,13),fxyz(25,19,14)/ 1.8086204d-09,-8.4064852d-10/
      data fxyz(25,19,15),fxyz(25,19,16)/-2.5885857d-09, 4.6608287d-09/
      data fxyz(25,19,17),fxyz(25,19,18)/-2.4544168d-09,-4.8735685d-10/
      data fxyz(25,19,19),fxyz(25,19,20)/ 4.7209373d-10,-1.8329592d-10/
      data fxyz(25,19,21),fxyz(25,19,22)/-1.2323426d-10, 2.3184707d-10/
      data fxyz(25,19,23)/                4.1356813d-10/
      data fxyz(26, 1, 1),fxyz(26, 1, 2)/-2.3980256d-09,-6.2842864d-09/
      data fxyz(26, 1, 3),fxyz(26, 1, 4)/-1.4561679d-08,-1.4649720d-08/
      data fxyz(26, 1, 5),fxyz(26, 1, 6)/-5.9321227d-09,-3.7186393d-09/
      data fxyz(26, 1, 7),fxyz(26, 1, 8)/ 5.4779028d-09, 6.9428649d-09/
      data fxyz(26, 1, 9),fxyz(26, 1,10)/ 2.6875897d-09, 8.9067704d-09/
      data fxyz(26, 1,11),fxyz(26, 1,12)/ 3.7925240d-09, 4.6339809d-09/
      data fxyz(26, 1,13),fxyz(26, 1,14)/ 9.1303298d-09, 4.1376605d-09/
      data fxyz(26, 1,15),fxyz(26, 1,16)/ 5.8965652d-09, 6.4543778d-09/
      data fxyz(26, 1,17),fxyz(26, 1,18)/ 3.3716747d-09, 7.8937341d-09/
      data fxyz(26, 1,19),fxyz(26, 1,20)/-2.0346766d-08,-1.1246114d-08/
      data fxyz(26, 1,21),fxyz(26, 1,22)/-1.2788241d-08,-1.4178259d-08/
      data fxyz(26, 1,23)/               -1.5238168d-08/
      data fxyz(26, 2, 1),fxyz(26, 2, 2)/ 1.8876201d-09,-8.1065610d-10/
      data fxyz(26, 2, 3),fxyz(26, 2, 4)/-6.4823879d-09,-6.6753931d-09/
      data fxyz(26, 2, 5),fxyz(26, 2, 6)/-3.8635288d-11,-1.0074579d-09/
      data fxyz(26, 2, 7),fxyz(26, 2, 8)/ 2.9811827d-09, 2.8679661d-09/
      data fxyz(26, 2, 9),fxyz(26, 2,10)/ 1.7129027d-10, 3.0734856d-09/
      data fxyz(26, 2,11),fxyz(26, 2,12)/ 6.0861504d-10, 1.0663600d-09/
      data fxyz(26, 2,13),fxyz(26, 2,14)/ 3.2691791d-09, 6.9950323d-10/
      data fxyz(26, 2,15),fxyz(26, 2,16)/ 1.8408263d-09, 2.6844447d-09/
      data fxyz(26, 2,17),fxyz(26, 2,18)/ 1.8103523d-09, 5.0903785d-09/
      data fxyz(26, 2,19),fxyz(26, 2,20)/-7.7590935d-09,-4.7896011d-09/
      data fxyz(26, 2,21),fxyz(26, 2,22)/-5.4653243d-09,-5.0562007d-09/
      data fxyz(26, 2,23)/               -5.0454692d-09/
      data fxyz(26, 3, 1),fxyz(26, 3, 2)/ 2.3918937d-08, 1.5535364d-08/
      data fxyz(26, 3, 3),fxyz(26, 3, 4)/-1.6432691d-09,-3.0190602d-09/
      data fxyz(26, 3, 5),fxyz(26, 3, 6)/ 2.1038528d-08, 3.2820703d-09/
      data fxyz(26, 3, 7),fxyz(26, 3, 8)/-3.1114163d-09,-1.6646731d-09/
      data fxyz(26, 3, 9),fxyz(26, 3,10)/-1.2275608d-09,-6.6551409d-09/
      data fxyz(26, 3,11),fxyz(26, 3,12)/-4.3183372d-09,-6.2415081d-09/
      data fxyz(26, 3,13),fxyz(26, 3,14)/-6.1185594d-09,-3.8584529d-09/
      data fxyz(26, 3,15),fxyz(26, 3,16)/-3.2954819d-09,-3.0285908d-10/
      data fxyz(26, 3,17),fxyz(26, 3,18)/-2.4161252d-09,-9.9512544d-10/
      data fxyz(26, 3,19),fxyz(26, 3,20)/ 2.3574568d-08,-2.8023065d-09/
      data fxyz(26, 3,21),fxyz(26, 3,22)/-1.0517257d-09, 1.6572245d-08/
      data fxyz(26, 3,23)/                2.5263586d-08/
      data fxyz(26, 4, 1),fxyz(26, 4, 2)/-1.6159595d-08,-6.1719799d-09/
      data fxyz(26, 4, 3),fxyz(26, 4, 4)/ 1.4536453d-08, 1.5750251d-08/
      data fxyz(26, 4, 5),fxyz(26, 4, 6)/-1.1027175d-08, 2.0473848d-09/
      data fxyz(26, 4, 7),fxyz(26, 4, 8)/ 3.3815607d-09,-4.5952206d-09/
      data fxyz(26, 4, 9),fxyz(26, 4,10)/-6.5374811d-09,-2.7500716d-09/
      data fxyz(26, 4,11),fxyz(26, 4,12)/-3.1446381d-09,-4.5851114d-10/
      data fxyz(26, 4,13),fxyz(26, 4,14)/-3.1632406d-09,-4.4971130d-09/
      data fxyz(26, 4,15),fxyz(26, 4,16)/-4.6497978d-09,-6.0293652d-09/
      data fxyz(26, 4,17),fxyz(26, 4,18)/ 2.6854404d-09, 4.4068900d-09/
      data fxyz(26, 4,19),fxyz(26, 4,20)/-1.0702731d-08, 1.4827253d-08/
      data fxyz(26, 4,21),fxyz(26, 4,22)/ 1.3544487d-08,-5.5716650d-09/
      data fxyz(26, 4,23)/               -1.4834607d-08/
      data fxyz(26, 5, 1),fxyz(26, 5, 2)/ 4.1107763d-09, 2.6097757d-09/
      data fxyz(26, 5, 3),fxyz(26, 5, 4)/-4.6433056d-10,-7.1339645d-10/
      data fxyz(26, 5, 5),fxyz(26, 5, 6)/ 3.6060393d-09, 3.7478791d-10/
      data fxyz(26, 5, 7),fxyz(26, 5, 8)/-4.3013058d-09, 3.3033598d-10/
      data fxyz(26, 5, 9),fxyz(26, 5,10)/ 3.3391708d-09,-1.4413867d-10/
      data fxyz(26, 5,11),fxyz(26, 5,12)/-7.8664369d-11,-4.1547848d-09/
      data fxyz(26, 5,13),fxyz(26, 5,14)/ 1.5955161d-10, 6.1670287d-10/
      data fxyz(26, 5,15),fxyz(26, 5,16)/ 7.7273493d-10, 1.7236289d-09/
      data fxyz(26, 5,17),fxyz(26, 5,18)/-3.5460725d-09,-2.8787709d-09/
      data fxyz(26, 5,19),fxyz(26, 5,20)/ 6.3685620d-09,-9.3396316d-10/
      data fxyz(26, 5,21),fxyz(26, 5,22)/-3.3324269d-10, 3.9656801d-09/
      data fxyz(26, 5,23)/                6.1320362d-09/
      data fxyz(26, 6, 1),fxyz(26, 6, 2)/-2.8962570d-09,-2.3296266d-09/
      data fxyz(26, 6, 3),fxyz(26, 6, 4)/-1.1012262d-09,-1.1260629d-09/
      data fxyz(26, 6, 5),fxyz(26, 6, 6)/-2.2302796d-09,-3.2688081d-09/
      data fxyz(26, 6, 7),fxyz(26, 6, 8)/ 1.7937200d-09, 2.6252109d-09/
      data fxyz(26, 6, 9),fxyz(26, 6,10)/-1.0375922d-09, 2.0528365d-09/
      data fxyz(26, 6,11),fxyz(26, 6,12)/-5.1038475d-10, 5.1278652d-09/
      data fxyz(26, 6,13),fxyz(26, 6,14)/-1.5303161d-09, 2.2389652d-09/
      data fxyz(26, 6,15),fxyz(26, 6,16)/ 6.2760801d-10, 4.4467121d-10/
      data fxyz(26, 6,17),fxyz(26, 6,18)/ 1.3480235d-09,-1.3243654d-09/
      data fxyz(26, 6,19),fxyz(26, 6,20)/-4.5758226d-09,-1.0238090d-11/
      data fxyz(26, 6,21),fxyz(26, 6,22)/-2.6571577d-10,-3.5539118d-09/
      data fxyz(26, 6,23)/               -5.1565307d-09/
      data fxyz(26, 7, 1),fxyz(26, 7, 2)/-3.8817520d-10,-8.8165496d-10/
      data fxyz(26, 7, 3),fxyz(26, 7, 4)/-2.0128794d-09,-1.8837857d-09/
      data fxyz(26, 7, 5),fxyz(26, 7, 6)/-1.3980300d-09, 1.5482312d-09/
      data fxyz(26, 7, 7),fxyz(26, 7, 8)/ 2.0813055d-10,-2.1910905d-09/
      data fxyz(26, 7, 9),fxyz(26, 7,10)/ 2.0694408d-09,-7.7334041d-10/
      data fxyz(26, 7,11),fxyz(26, 7,12)/ 4.0803903d-09,-1.6484944d-09/
      data fxyz(26, 7,13),fxyz(26, 7,14)/ 5.0009573d-09,-1.3399827d-09/
      data fxyz(26, 7,15),fxyz(26, 7,16)/ 1.5097207d-09,-8.7985163d-10/
      data fxyz(26, 7,17),fxyz(26, 7,18)/-5.4936334d-10, 3.3767014d-10/
      data fxyz(26, 7,19),fxyz(26, 7,20)/ 2.5267311d-10,-2.2503257d-09/
      data fxyz(26, 7,21),fxyz(26, 7,22)/-2.1989142d-09, 4.7027075d-11/
      data fxyz(26, 7,23)/                1.1088428d-09/
      data fxyz(26, 8, 1),fxyz(26, 8, 2)/ 1.2288524d-09, 2.7796398d-10/
      data fxyz(26, 8, 3),fxyz(26, 8, 4)/-1.6805203d-09,-1.8190042d-09/
      data fxyz(26, 8, 5),fxyz(26, 8, 6)/ 8.3189936d-10,-8.4840533d-10/
      data fxyz(26, 8, 7),fxyz(26, 8, 8)/-4.4075332d-10, 1.8521995d-09/
      data fxyz(26, 8, 9),fxyz(26, 8,10)/ 6.6790849d-11, 2.4258955d-09/
      data fxyz(26, 8,11),fxyz(26, 8,12)/-2.3354032d-09, 2.3785722d-09/
      data fxyz(26, 8,13),fxyz(26, 8,14)/-1.9485283d-09, 2.2100750d-09/
      data fxyz(26, 8,15),fxyz(26, 8,16)/-2.3514086d-10, 1.4005590d-09/
      data fxyz(26, 8,17),fxyz(26, 8,18)/ 9.8908001d-11,-7.2720791d-10/
      data fxyz(26, 8,19),fxyz(26, 8,20)/-4.6150388d-10,-1.0628373d-09/
      data fxyz(26, 8,21),fxyz(26, 8,22)/-1.0369041d-09,-5.6523672d-10/
      data fxyz(26, 8,23)/               -3.3820976d-10/
      data fxyz(26, 9, 1),fxyz(26, 9, 2)/-1.3097996d-09,-1.0403392d-09/
      data fxyz(26, 9, 3),fxyz(26, 9, 4)/-5.7702908d-10,-3.7734517d-10/
      data fxyz(26, 9, 5),fxyz(26, 9, 6)/-1.8390749d-09, 1.6854591d-09/
      data fxyz(26, 9, 7),fxyz(26, 9, 8)/-2.6247769d-10, 2.2947986d-09/
      data fxyz(26, 9, 9),fxyz(26, 9,10)/-1.8437328d-09, 7.6473254d-11/
      data fxyz(26, 9,11),fxyz(26, 9,12)/ 1.5085443d-09,-1.2676092d-09/
      data fxyz(26, 9,13),fxyz(26, 9,14)/ 6.0557982d-10,-5.9877014d-11/
      data fxyz(26, 9,15),fxyz(26, 9,16)/-7.6919147d-10, 1.1892466d-09/
      data fxyz(26, 9,17),fxyz(26, 9,18)/-4.0512050d-11, 1.2415147d-09/
      data fxyz(26, 9,19),fxyz(26, 9,20)/-1.1204055d-09,-4.8271722d-10/
      data fxyz(26, 9,21),fxyz(26, 9,22)/-6.0895969d-10,-6.1543565d-10/
      data fxyz(26, 9,23)/               -6.5212243d-10/
      data fxyz(26,10, 1),fxyz(26,10, 2)/ 1.5102768d-09, 7.7275518d-10/
      data fxyz(26,10, 3),fxyz(26,10, 4)/-7.0055980d-10,-8.8796445d-10/
      data fxyz(26,10, 5),fxyz(26,10, 6)/ 1.5223738d-09,-1.3007931d-09/
      data fxyz(26,10, 7),fxyz(26,10, 8)/ 4.0222006d-09,-6.9913836d-09/
      data fxyz(26,10, 9),fxyz(26,10,10)/ 6.0593359d-09,-2.7619777d-09/
      data fxyz(26,10,11),fxyz(26,10,12)/ 4.2442863d-10, 7.5224356d-10/
      data fxyz(26,10,13),fxyz(26,10,14)/-6.8139433d-10,-1.6403564d-10/
      data fxyz(26,10,15),fxyz(26,10,16)/ 1.8217897d-09,-2.1627496d-09/
      data fxyz(26,10,17),fxyz(26,10,18)/ 1.7415724d-09,-1.5081323d-09/
      data fxyz(26,10,19),fxyz(26,10,20)/ 9.8764624d-10,-3.6072840d-10/
      data fxyz(26,10,21),fxyz(26,10,22)/-2.1238884d-10, 3.9428800d-10/
      data fxyz(26,10,23)/                7.1696107d-10/
      data fxyz(26,11, 1),fxyz(26,11, 2)/-3.4232967d-10,-1.7391281d-10/
      data fxyz(26,11, 3),fxyz(26,11, 4)/ 4.8934626d-11, 2.9051482d-10/
      data fxyz(26,11, 5),fxyz(26,11, 6)/-1.1402336d-09, 3.2813732d-09/
      data fxyz(26,11, 7),fxyz(26,11, 8)/-1.1968105d-08, 1.9166257d-08/
      data fxyz(26,11, 9),fxyz(26,11,10)/-1.4432475d-08, 6.1117492d-09/
      data fxyz(26,11,11),fxyz(26,11,12)/-1.6396626d-09,-1.5932014d-10/
      data fxyz(26,11,13),fxyz(26,11,14)/ 1.3687563d-09,-1.8061627d-10/
      data fxyz(26,11,15),fxyz(26,11,16)/-1.4488457d-09, 1.8740020d-09/
      data fxyz(26,11,17),fxyz(26,11,18)/-2.0131980d-09, 1.4893132d-09/
      data fxyz(26,11,19),fxyz(26,11,20)/ 1.7734517d-13,-4.2935130d-10/
      data fxyz(26,11,21),fxyz(26,11,22)/-4.9052326d-10, 2.4486517d-10/
      data fxyz(26,11,23)/                5.7173391d-10/
      data fxyz(26,12, 1),fxyz(26,12, 2)/-1.2258938d-09,-6.9288627d-10/
      data fxyz(26,12, 3),fxyz(26,12, 4)/ 6.2356084d-10, 3.1855655d-10/
      data fxyz(26,12, 5),fxyz(26,12, 6)/ 5.2713087d-10,-5.8009580d-09/
      data fxyz(26,12, 7),fxyz(26,12, 8)/ 1.8116674d-08,-2.8500539d-08/
      data fxyz(26,12, 9),fxyz(26,12,10)/ 2.1527554d-08,-9.6662794d-09/
      data fxyz(26,12,11),fxyz(26,12,12)/ 3.4504059d-09, 1.6282896d-10/
      data fxyz(26,12,13),fxyz(26,12,14)/-1.3448234d-10,-1.1986063d-09/
      data fxyz(26,12,15),fxyz(26,12,16)/ 1.5656456d-09,-1.2511295d-09/
      data fxyz(26,12,17),fxyz(26,12,18)/ 1.5203909d-09,-3.9685948d-10/
      data fxyz(26,12,19),fxyz(26,12,20)/-1.0396974d-09, 3.7267885d-10/
      data fxyz(26,12,21),fxyz(26,12,22)/ 3.1087757d-10,-7.9249230d-10/
      data fxyz(26,12,23)/               -1.3238786d-09/
      data fxyz(26,13, 1),fxyz(26,13, 2)/-3.3640524d-10, 1.1784196d-10/
      data fxyz(26,13, 3),fxyz(26,13, 4)/ 1.0030525d-09, 1.1573611d-09/
      data fxyz(26,13, 5),fxyz(26,13, 6)/-4.9939214d-10, 1.9782226d-09/
      data fxyz(26,13, 7),fxyz(26,13, 8)/-1.2959929d-08, 2.0496141d-08/
      data fxyz(26,13, 9),fxyz(26,13,10)/-2.1584113d-08, 1.8734827d-08/
      data fxyz(26,13,11),fxyz(26,13,12)/-9.3828294d-09, 1.5963063d-09/
      data fxyz(26,13,13),fxyz(26,13,14)/-3.2058333d-09, 6.0249233d-09/
      data fxyz(26,13,15),fxyz(26,13,16)/-3.2202877d-09, 7.8128107d-10/
      data fxyz(26,13,17),fxyz(26,13,18)/-7.0081298d-10,-6.9158051d-10/
      data fxyz(26,13,19),fxyz(26,13,20)/ 1.3813449d-09,-3.1881814d-10/
      data fxyz(26,13,21),fxyz(26,13,22)/-1.8275794d-10, 8.3710412d-10/
      data fxyz(26,13,23)/                1.3493225d-09/
      data fxyz(26,14, 1),fxyz(26,14, 2)/-1.3834508d-09,-5.2189866d-10/
      data fxyz(26,14, 3),fxyz(26,14, 4)/ 1.3156393d-09, 1.3307682d-09/
      data fxyz(26,14, 5),fxyz(26,14, 6)/-5.8241401d-10,-1.1565182d-09/
      data fxyz(26,14, 7),fxyz(26,14, 8)/ 3.1435558d-09,-9.7349004d-09/
      data fxyz(26,14, 9),fxyz(26,14,10)/ 1.9191219d-08,-2.5658036d-08/
      data fxyz(26,14,11),fxyz(26,14,12)/ 1.5853531d-08,-6.4141426d-09/
      data fxyz(26,14,13),fxyz(26,14,14)/ 1.4306720d-08,-2.1403762d-08/
      data fxyz(26,14,15),fxyz(26,14,16)/ 1.2726216d-08,-2.6213895d-09/
      data fxyz(26,14,17),fxyz(26,14,18)/-1.6668358d-10, 1.1802644d-09/
      data fxyz(26,14,19),fxyz(26,14,20)/-1.5424915d-09, 6.3123673d-10/
      data fxyz(26,14,21),fxyz(26,14,22)/ 4.5383977d-10,-8.3290372d-10/
      data fxyz(26,14,23)/               -1.4806899d-09/
      data fxyz(26,15, 1),fxyz(26,15, 2)/ 4.1635044d-10, 1.6823675d-10/
      data fxyz(26,15, 3),fxyz(26,15, 4)/-3.8519933d-10,-3.4711252d-10/
      data fxyz(26,15, 5),fxyz(26,15, 6)/ 1.5889493d-11, 9.8765266d-10/
      data fxyz(26,15, 7),fxyz(26,15, 8)/-3.2396137d-10, 2.8089963d-09/
      data fxyz(26,15, 9),fxyz(26,15,10)/-1.1004656d-08, 1.6390202d-08/
      data fxyz(26,15,11),fxyz(26,15,12)/-1.2117109d-08, 9.1998428d-09/
      data fxyz(26,15,13),fxyz(26,15,14)/-2.2869721d-08, 3.4049476d-08/
      data fxyz(26,15,15),fxyz(26,15,16)/-2.1787872d-08, 6.8902912d-09/
      data fxyz(26,15,17),fxyz(26,15,18)/-9.6267422d-10,-1.6183047d-09/
      data fxyz(26,15,19),fxyz(26,15,20)/ 1.8143285d-09,-6.7447132d-10/
      data fxyz(26,15,21),fxyz(26,15,22)/-4.5639823d-10, 9.4203614d-10/
      data fxyz(26,15,23)/                1.6527917d-09/
      data fxyz(26,16, 1),fxyz(26,16, 2)/ 1.9743691d-09, 1.0836815d-09/
      data fxyz(26,16, 3),fxyz(26,16, 4)/-7.5251020d-10,-8.7925302d-10/
      data fxyz(26,16, 5),fxyz(26,16, 6)/ 1.5906528d-09, 7.3226728d-11/
      data fxyz(26,16, 7),fxyz(26,16, 8)/-7.5413677d-10, 7.6448646d-10/
      data fxyz(26,16, 9),fxyz(26,16,10)/ 2.0549986d-09,-4.9348673d-09/
      data fxyz(26,16,11),fxyz(26,16,12)/ 4.4811790d-09,-5.6418844d-09/
      data fxyz(26,16,13),fxyz(26,16,14)/ 1.4831342d-08,-2.2040222d-08/
      data fxyz(26,16,15),fxyz(26,16,16)/ 1.5605061d-08,-7.4711820d-09/
      data fxyz(26,16,17),fxyz(26,16,18)/ 2.5336488d-09, 1.2638492d-09/
      data fxyz(26,16,19),fxyz(26,16,20)/-1.6942637d-09, 4.5159675d-10/
      data fxyz(26,16,21),fxyz(26,16,22)/ 2.6364512d-10,-9.4245714d-10/
      data fxyz(26,16,23)/               -1.5554253d-09/
      data fxyz(26,17, 1),fxyz(26,17, 2)/-3.5927374d-10,-3.7966568d-10/
      data fxyz(26,17, 3),fxyz(26,17, 4)/-4.5474004d-10,-3.9982970d-10/
      data fxyz(26,17, 5),fxyz(26,17, 6)/-5.9930704d-10, 4.6438135d-10/
      data fxyz(26,17, 7),fxyz(26,17, 8)/ 1.5034404d-09,-8.8719513d-10/
      data fxyz(26,17, 9),fxyz(26,17,10)/-6.3455283d-11, 1.5846611d-09/
      data fxyz(26,17,11),fxyz(26,17,12)/-1.8603724d-09, 1.5911806d-09/
      data fxyz(26,17,13),fxyz(26,17,14)/-3.9702320d-09, 6.1010678d-09/
      data fxyz(26,17,15),fxyz(26,17,16)/-5.1665177d-09, 3.6719320d-09/
      data fxyz(26,17,17),fxyz(26,17,18)/-1.5530922d-09,-1.0003082d-09/
      data fxyz(26,17,19),fxyz(26,17,20)/ 1.1922595d-09,-2.9069174d-10/
      data fxyz(26,17,21),fxyz(26,17,22)/-1.5376397d-10, 6.4454847d-10/
      data fxyz(26,17,23)/                1.0536083d-09/
      data fxyz(26,18, 1),fxyz(26,18, 2)/-1.6962823d-11,-3.8201361d-11/
      data fxyz(26,18, 3),fxyz(26,18, 4)/-7.5999805d-11,-8.9497044d-11/
      data fxyz(26,18, 5),fxyz(26,18, 6)/ 1.5787596d-11,-2.1942141d-10/
      data fxyz(26,18, 7),fxyz(26,18, 8)/ 8.0291723d-11, 2.3259551d-10/
      data fxyz(26,18, 9),fxyz(26,18,10)/ 3.7761274d-10,-7.5568588d-10/
      data fxyz(26,18,11),fxyz(26,18,12)/ 1.0231978d-09,-5.9142928d-10/
      data fxyz(26,18,13),fxyz(26,18,14)/ 8.8948689d-10,-1.7707535d-09/
      data fxyz(26,18,15),fxyz(26,18,16)/ 1.3404820d-09,-8.2306405d-10/
      data fxyz(26,18,17),fxyz(26,18,18)/ 1.0922852d-10, 6.7353880d-10/
      data fxyz(26,18,19),fxyz(26,18,20)/-6.7155120d-10, 1.6459156d-10/
      data fxyz(26,18,21),fxyz(26,18,22)/ 8.2220203d-11,-3.4206577d-10/
      data fxyz(26,18,23)/               -5.6203159d-10/
      data fxyz(26,19, 1),fxyz(26,19, 2)/-4.3921012d-10,-2.1239748d-10/
      data fxyz(26,19, 3),fxyz(26,19, 4)/ 2.7960612d-10, 2.6914723d-10/
      data fxyz(26,19, 5),fxyz(26,19, 6)/-1.7056191d-10,-5.9609349d-10/
      data fxyz(26,19, 7),fxyz(26,19, 8)/-2.9122101d-10, 5.6053694d-10/
      data fxyz(26,19, 9),fxyz(26,19,10)/ 8.7388778d-11,-5.6463990d-10/
      data fxyz(26,19,11),fxyz(26,19,12)/ 1.2710189d-09,-8.3846356d-11/
      data fxyz(26,19,13),fxyz(26,19,14)/-1.0111636d-09, 6.4688566d-10/
      data fxyz(26,19,15),fxyz(26,19,16)/ 5.3602328d-11,-8.5002868d-10/
      data fxyz(26,19,17),fxyz(26,19,18)/ 1.2896019d-10, 1.2222417d-09/
      data fxyz(26,19,19),fxyz(26,19,20)/-1.1781237d-09, 2.7771149d-10/
      data fxyz(26,19,21),fxyz(26,19,22)/ 1.3152059d-10,-5.9336005d-10/
      data fxyz(26,19,23)/               -9.7062193d-10/
      data fxyz(27, 1, 1),fxyz(27, 1, 2)/-2.6359310d-09,-1.5273616d-09/
      data fxyz(27, 1, 3),fxyz(27, 1, 4)/ 7.6564751d-10, 9.1001678d-10/
      data fxyz(27, 1, 5),fxyz(27, 1, 6)/-2.1048387d-09,-4.7039187d-10/
      data fxyz(27, 1, 7),fxyz(27, 1, 8)/-2.0409451d-09,-1.5997176d-09/
      data fxyz(27, 1, 9),fxyz(27, 1,10)/ 2.2620335d-09,-2.8920004d-10/
      data fxyz(27, 1,11),fxyz(27, 1,12)/ 2.5659488d-09, 1.6979762d-09/
      data fxyz(27, 1,13),fxyz(27, 1,14)/ 3.1041614d-10, 2.0727854d-09/
      data fxyz(27, 1,15),fxyz(27, 1,16)/ 9.9627847d-10,-7.6492740d-10/
      data fxyz(27, 1,17),fxyz(27, 1,18)/-1.5400533d-09,-3.6361464d-09/
      data fxyz(27, 1,19),fxyz(27, 1,20)/ 1.7302450d-09,-4.0469386d-10/
      data fxyz(27, 1,21),fxyz(27, 1,22)/-1.0266714d-10, 5.2213816d-10/
      data fxyz(27, 1,23)/                8.9425443d-10/
      data fxyz(27, 2, 1),fxyz(27, 2, 2)/-1.5894304d-09,-8.5192983d-10/
      data fxyz(27, 2, 3),fxyz(27, 2, 4)/ 6.6761808d-10, 7.7403632d-10/
      data fxyz(27, 2, 5),fxyz(27, 2, 6)/-1.2776028d-09, 6.8431067d-12/
      data fxyz(27, 2, 7),fxyz(27, 2, 8)/-8.8377338d-10,-7.0512311d-10/
      data fxyz(27, 2, 9),fxyz(27, 2,10)/ 1.0585564d-09,-2.7844437d-10/
      data fxyz(27, 2,11),fxyz(27, 2,12)/ 9.4850449d-10, 5.3906993d-10/
      data fxyz(27, 2,13),fxyz(27, 2,14)/-2.0520278d-10, 9.1921498d-10/
      data fxyz(27, 2,15),fxyz(27, 2,16)/ 3.8058193d-10,-2.7221664d-10/
      data fxyz(27, 2,17),fxyz(27, 2,18)/-6.0213144d-10,-1.6442169d-09/
      data fxyz(27, 2,19),fxyz(27, 2,20)/ 7.7780186d-10, 4.5886331d-11/
      data fxyz(27, 2,21),fxyz(27, 2,22)/ 1.7706890d-10, 2.5307160d-10/
      data fxyz(27, 2,23)/                3.2352154d-10/
      data fxyz(27, 3, 1),fxyz(27, 3, 2)/-4.1772988d-09,-2.0048124d-09/
      data fxyz(27, 3, 3),fxyz(27, 3, 4)/ 2.4814035d-09, 2.7773498d-09/
      data fxyz(27, 3, 5),fxyz(27, 3, 6)/-3.1885975d-09, 2.6189552d-10/
      data fxyz(27, 3, 7),fxyz(27, 3, 8)/ 1.4990876d-09, 7.4850559d-10/
      data fxyz(27, 3, 9),fxyz(27, 3,10)/-1.6214081d-09,-1.1383066d-10/
      data fxyz(27, 3,11),fxyz(27, 3,12)/-1.5371795d-09,-5.4517201d-10/
      data fxyz(27, 3,13),fxyz(27, 3,14)/-6.2703383d-10,-1.2331959d-09/
      data fxyz(27, 3,15),fxyz(27, 3,16)/-3.6335902d-10,-3.9758823d-10/
      data fxyz(27, 3,17),fxyz(27, 3,18)/ 1.8001073d-09, 1.5005999d-09/
      data fxyz(27, 3,19),fxyz(27, 3,20)/-4.2030881d-09, 2.7295465d-09/
      data fxyz(27, 3,21),fxyz(27, 3,22)/ 2.3052308d-09,-2.5058253d-09/
      data fxyz(27, 3,23)/               -4.8641356d-09/
      data fxyz(27, 4, 1),fxyz(27, 4, 2)/ 5.9551242d-09, 3.2414051d-09/
      data fxyz(27, 4, 3),fxyz(27, 4, 4)/-2.3961630d-09,-2.7068655d-09/
      data fxyz(27, 4, 5),fxyz(27, 4, 6)/ 4.4842151d-09, 1.2945869d-09/
      data fxyz(27, 4, 7),fxyz(27, 4, 8)/-4.0796380d-10, 2.4551438d-10/
      data fxyz(27, 4, 9),fxyz(27, 4,10)/ 8.6633341d-10,-4.8772010d-10/
      data fxyz(27, 4,11),fxyz(27, 4,12)/-9.8402446d-10,-1.8907390d-09/
      data fxyz(27, 4,13),fxyz(27, 4,14)/-1.3771224d-09, 1.1033505d-10/
      data fxyz(27, 4,15),fxyz(27, 4,16)/-6.5844458d-10, 1.6403284d-09/
      data fxyz(27, 4,17),fxyz(27, 4,18)/-9.2276311d-10, 6.1031067d-10/
      data fxyz(27, 4,19),fxyz(27, 4,20)/ 4.9155856d-09,-2.4025732d-09/
      data fxyz(27, 4,21),fxyz(27, 4,22)/-2.0360978d-09, 3.4496839d-09/
      data fxyz(27, 4,23)/                6.1074421d-09/
      data fxyz(27, 5, 1),fxyz(27, 5, 2)/-1.4743640d-09,-5.9137682d-10/
      data fxyz(27, 5, 3),fxyz(27, 5, 4)/ 1.3125542d-09, 1.2918770d-09/
      data fxyz(27, 5, 5),fxyz(27, 5, 6)/-5.0866791d-10,-1.7845224d-09/
      data fxyz(27, 5, 7),fxyz(27, 5, 8)/ 4.6883000d-10,-2.5921284d-10/
      data fxyz(27, 5, 9),fxyz(27, 5,10)/-8.6682450d-10,-1.6031529d-10/
      data fxyz(27, 5,11),fxyz(27, 5,12)/ 4.0570727d-10, 1.4613063d-09/
      data fxyz(27, 5,13),fxyz(27, 5,14)/ 6.1440013d-10,-8.3814991d-10/
      data fxyz(27, 5,15),fxyz(27, 5,16)/ 7.7180102d-10,-1.8267471d-09/
      data fxyz(27, 5,17),fxyz(27, 5,18)/ 7.1316504d-10,-8.4272431d-10/
      data fxyz(27, 5,19),fxyz(27, 5,20)/-1.8188101d-09, 1.7117137d-09/
      data fxyz(27, 5,21),fxyz(27, 5,22)/ 1.5871727d-09,-1.3206462d-09/
      data fxyz(27, 5,23)/               -2.7108392d-09/
      data fxyz(27, 6, 1),fxyz(27, 6, 2)/-9.5407911d-10,-5.0993763d-10/
      data fxyz(27, 6, 3),fxyz(27, 6, 4)/ 3.6362236d-10, 5.0042293d-10/
      data fxyz(27, 6, 5),fxyz(27, 6, 6)/-1.0571399d-09, 1.0979294d-09/
      data fxyz(27, 6, 7),fxyz(27, 6, 8)/-1.2558603d-09,-1.1054190d-09/
      data fxyz(27, 6, 9),fxyz(27, 6,10)/ 2.5455534d-10, 1.7041582d-10/
      data fxyz(27, 6,11),fxyz(27, 6,12)/ 1.2341951d-09,-3.6925234d-10/
      data fxyz(27, 6,13),fxyz(27, 6,14)/ 1.5902953d-09, 3.5683591d-10/
      data fxyz(27, 6,15),fxyz(27, 6,16)/-7.9601459d-10, 3.4270156d-10/
      data fxyz(27, 6,17),fxyz(27, 6,18)/-1.5656978d-09, 3.3451858d-10/
      data fxyz(27, 6,19),fxyz(27, 6,20)/ 3.0163326d-10,-1.6108471d-10/
      data fxyz(27, 6,21),fxyz(27, 6,22)/-1.5239564d-10, 2.6687698d-10/
      data fxyz(27, 6,23)/                4.6485463d-10/
      data fxyz(27, 7, 1),fxyz(27, 7, 2)/ 8.7199376d-10, 3.5761278d-10/
      data fxyz(27, 7, 3),fxyz(27, 7, 4)/-6.7470421d-10,-7.9707815d-10/
      data fxyz(27, 7, 5),fxyz(27, 7, 6)/ 8.4710853d-10,-9.6361531d-10/
      data fxyz(27, 7, 7),fxyz(27, 7, 8)/ 3.2305669d-10, 1.0769022d-09/
      data fxyz(27, 7, 9),fxyz(27, 7,10)/-1.0958198d-10, 8.6920584d-10/
      data fxyz(27, 7,11),fxyz(27, 7,12)/-1.2306616d-09, 8.7660481d-10/
      data fxyz(27, 7,13),fxyz(27, 7,14)/-1.4465010d-09, 1.0193416d-09/
      data fxyz(27, 7,15),fxyz(27, 7,16)/ 1.2187630d-10, 3.5756246d-10/
      data fxyz(27, 7,17),fxyz(27, 7,18)/ 4.9911607d-10,-3.3627139d-10/
      data fxyz(27, 7,19),fxyz(27, 7,20)/-2.5922612d-10,-3.2787809d-10/
      data fxyz(27, 7,21),fxyz(27, 7,22)/-3.2270011d-10,-2.7993806d-10/
      data fxyz(27, 7,23)/               -2.5860164d-10/
      data fxyz(27, 8, 1),fxyz(27, 8, 2)/-4.0059078d-10,-3.9586357d-10/
      data fxyz(27, 8, 3),fxyz(27, 8, 4)/-4.4707950d-10,-3.3972456d-10/
      data fxyz(27, 8, 5),fxyz(27, 8, 6)/-8.2528333d-10, 1.2097333d-09/
      data fxyz(27, 8, 7),fxyz(27, 8, 8)/ 3.1632601d-10, 1.7490967d-10/
      data fxyz(27, 8, 9),fxyz(27, 8,10)/ 1.5889542d-10,-7.9217388d-10/
      data fxyz(27, 8,11),fxyz(27, 8,12)/ 9.9709469d-10,-1.1569568d-09/
      data fxyz(27, 8,13),fxyz(27, 8,14)/ 6.1723078d-10,-6.8017705d-10/
      data fxyz(27, 8,15),fxyz(27, 8,16)/ 3.0708648d-10, 2.5727576d-11/
      data fxyz(27, 8,17),fxyz(27, 8,18)/ 5.1520181d-10, 2.5688029d-10/
      data fxyz(27, 8,19),fxyz(27, 8,20)/-1.6839765d-10,-2.6983028d-10/
      data fxyz(27, 8,21),fxyz(27, 8,22)/-2.8777060d-10,-9.6636373d-11/
      data fxyz(27, 8,23)/               -1.2224486d-11/
      data fxyz(27, 9, 1),fxyz(27, 9, 2)/ 8.4674966d-10, 5.6943092d-10/
      data fxyz(27, 9, 3),fxyz(27, 9, 4)/ 6.1928126d-11,-8.9887275d-11/
      data fxyz(27, 9, 5),fxyz(27, 9, 6)/ 1.1766925d-09,-1.4304814d-09/
      data fxyz(27, 9, 7),fxyz(27, 9, 8)/ 9.0077773d-10,-1.4894643d-09/
      data fxyz(27, 9, 9),fxyz(27, 9,10)/ 1.4216425d-09,-4.8741402d-10/
      data fxyz(27, 9,11),fxyz(27, 9,12)/-4.3794065d-10, 5.7809300d-10/
      data fxyz(27, 9,13),fxyz(27, 9,14)/-7.1329527d-11,-1.5520080d-10/
      data fxyz(27, 9,15),fxyz(27, 9,16)/ 6.9836924d-10,-9.1876695d-10/
      data fxyz(27, 9,17),fxyz(27, 9,18)/ 2.3310956d-10,-4.5526106d-10/
      data fxyz(27, 9,19),fxyz(27, 9,20)/ 6.8913875d-10,-1.2791971d-10/
      data fxyz(27, 9,21),fxyz(27, 9,22)/-5.5497535d-11, 3.9945006d-10/
      data fxyz(27, 9,23)/                6.3107152d-10/
      data fxyz(27,10, 1),fxyz(27,10, 2)/-1.0784637d-09,-6.0702748d-10/
      data fxyz(27,10, 3),fxyz(27,10, 4)/ 3.1747644d-10, 4.6748024d-10/
      data fxyz(27,10, 5),fxyz(27,10, 6)/-1.2070427d-09, 1.1715933d-09/
      data fxyz(27,10, 7),fxyz(27,10, 8)/-2.3584327d-09, 3.5972421d-09/
      data fxyz(27,10, 9),fxyz(27,10,10)/-3.2085178d-09, 1.3848464d-09/
      data fxyz(27,10,11),fxyz(27,10,12)/-6.3297591d-11, 2.0266007d-10/
      data fxyz(27,10,13),fxyz(27,10,14)/ 2.9249090d-10, 5.7927879d-11/
      data fxyz(27,10,15),fxyz(27,10,16)/-1.3486732d-09, 1.6529016d-09/
      data fxyz(27,10,17),fxyz(27,10,18)/-1.2567431d-09, 7.6241517d-10/
      data fxyz(27,10,19),fxyz(27,10,20)/-4.8593779d-10, 1.1971533d-10/
      data fxyz(27,10,21),fxyz(27,10,22)/ 4.7041706d-11,-1.9524328d-10/
      data fxyz(27,10,23)/               -3.2768924d-10/
      data fxyz(27,11, 1),fxyz(27,11, 2)/ 2.0048778d-10, 5.6553999d-11/
      data fxyz(27,11, 3),fxyz(27,11, 4)/-1.8645968d-10,-3.0093743d-10/
      data fxyz(27,11, 5),fxyz(27,11, 6)/ 5.1446500d-10,-1.5166785d-09/
      data fxyz(27,11, 7),fxyz(27,11, 8)/ 5.8171113d-09,-9.2277732d-09/
      data fxyz(27,11, 9),fxyz(27,11,10)/ 6.5792081d-09,-1.9309415d-09/
      data fxyz(27,11,11),fxyz(27,11,12)/ 4.6437619d-10,-5.4294236d-10/
      data fxyz(27,11,13),fxyz(27,11,14)/-1.1188116d-10,-7.5228826d-11/
      data fxyz(27,11,15),fxyz(27,11,16)/ 1.3698825d-09,-1.6655173d-09/
      data fxyz(27,11,17),fxyz(27,11,18)/ 1.6339082d-09,-7.2307562d-10/
      data fxyz(27,11,19),fxyz(27,11,20)/-1.8963011d-10, 7.3185116d-12/
      data fxyz(27,11,21),fxyz(27,11,22)/ 2.8277506d-11,-2.7346608d-10/
      data fxyz(27,11,23)/               -4.0869070d-10/
      data fxyz(27,12, 1),fxyz(27,12, 2)/ 6.5839601d-10, 3.8635299d-10/
      data fxyz(27,12, 3),fxyz(27,12, 4)/-2.5118310d-10,-1.5565626d-10/
      data fxyz(27,12, 5),fxyz(27,12, 6)/ 4.2456568d-12, 2.0912985d-09/
      data fxyz(27,12, 7),fxyz(27,12, 8)/-8.4190689d-09, 1.3468264d-08/
      data fxyz(27,12, 9),fxyz(27,12,10)/-9.5165782d-09, 3.4741914d-09/
      data fxyz(27,12,11),fxyz(27,12,12)/-8.3602814d-10, 4.6257925d-10/
      data fxyz(27,12,13),fxyz(27,12,14)/-9.4165061d-10, 1.1605548d-09/
      data fxyz(27,12,15),fxyz(27,12,16)/-1.4947877d-09, 1.4780745d-09/
      data fxyz(27,12,17),fxyz(27,12,18)/-1.3673730d-09, 5.7079655d-10/
      data fxyz(27,12,19),fxyz(27,12,20)/ 4.3108128d-10,-2.0182387d-10/
      data fxyz(27,12,21),fxyz(27,12,22)/-1.9443587d-10, 4.0152929d-10/
      data fxyz(27,12,23)/                6.8161650d-10/
      data fxyz(27,13, 1),fxyz(27,13, 2)/-1.0451607d-09,-5.9785881d-10/
      data fxyz(27,13, 3),fxyz(27,13, 4)/ 3.6229700d-10, 3.5940651d-10/
      data fxyz(27,13, 5),fxyz(27,13, 6)/-5.8629683d-10,-1.0885181d-09/
      data fxyz(27,13, 7),fxyz(27,13, 8)/ 5.1741584d-09,-9.2057764d-09/
      data fxyz(27,13, 9),fxyz(27,13,10)/ 9.7001797d-09,-7.5956777d-09/
      data fxyz(27,13,11),fxyz(27,13,12)/ 3.1339173d-09,-4.7984015d-10/
      data fxyz(27,13,13),fxyz(27,13,14)/ 1.9582360d-09,-2.8958229d-09/
      data fxyz(27,13,15),fxyz(27,13,16)/ 1.7764903d-09,-9.7536106d-10/
      data fxyz(27,13,17),fxyz(27,13,18)/ 7.7691162d-10,-6.1160732d-11/
      data fxyz(27,13,19),fxyz(27,13,20)/-3.3463112d-10, 1.1383797d-10/
      data fxyz(27,13,21),fxyz(27,13,22)/ 9.0922342d-11,-2.4296859d-10/
      data fxyz(27,13,23)/               -4.0489520d-10/
      data fxyz(27,14, 1),fxyz(27,14, 2)/ 6.5055833d-10, 3.5579308d-10/
      data fxyz(27,14, 3),fxyz(27,14, 4)/-2.4493949d-10,-2.9902717d-10/
      data fxyz(27,14, 5),fxyz(27,14, 6)/ 5.7214382d-10,-1.6075695d-10/
      data fxyz(27,14, 7),fxyz(27,14, 8)/-1.2268465d-09, 3.9215632d-09/
      data fxyz(27,14, 9),fxyz(27,14,10)/-8.6650544d-09, 1.1161186d-08/
      data fxyz(27,14,11),fxyz(27,14,12)/-6.0570185d-09, 1.8271582d-09/
      data fxyz(27,14,13),fxyz(27,14,14)/-4.7202281d-09, 7.2275282d-09/
      data fxyz(27,14,15),fxyz(27,14,16)/-4.0927078d-09, 8.5941731d-10/
      data fxyz(27,14,17),fxyz(27,14,18)/ 8.6485242d-11,-6.6093407d-10/
      data fxyz(27,14,19),fxyz(27,14,20)/ 5.7972663d-10,-1.6418319d-10/
      data fxyz(27,14,21),fxyz(27,14,22)/-8.8812055d-11, 2.7824208d-10/
      data fxyz(27,14,23)/                4.6963299d-10/
      data fxyz(27,15, 1),fxyz(27,15, 2)/ 3.3664760d-10, 2.1436687d-10/
      data fxyz(27,15, 3),fxyz(27,15, 4)/-4.3068697d-11,-5.1109223d-11/
      data fxyz(27,15, 5),fxyz(27,15, 6)/ 2.4652897d-10, 2.1603971d-10/
      data fxyz(27,15, 7),fxyz(27,15, 8)/-2.1787163d-10,-1.4135016d-09/
      data fxyz(27,15, 9),fxyz(27,15,10)/ 4.8348043d-09,-7.4160393d-09/
      data fxyz(27,15,11),fxyz(27,15,12)/ 4.9497184d-09,-2.9526889d-09/
      data fxyz(27,15,13),fxyz(27,15,14)/ 7.1852713d-09,-1.0365476d-08/
      data fxyz(27,15,15),fxyz(27,15,16)/ 6.5569173d-09,-1.7233390d-09/
      data fxyz(27,15,17),fxyz(27,15,18)/-2.1787804d-10, 1.1095856d-09/
      data fxyz(27,15,19),fxyz(27,15,20)/-1.1412278d-09, 3.1299470d-10/
      data fxyz(27,15,21),fxyz(27,15,22)/ 1.7393850d-10,-5.8500303d-10/
      data fxyz(27,15,23)/               -9.7625739d-10/
      data fxyz(27,16, 1),fxyz(27,16, 2)/-3.3681465d-10,-2.2051428d-10/
      data fxyz(27,16, 3),fxyz(27,16, 4)/ 2.9089969d-11, 2.8408911d-11/
      data fxyz(27,16, 5),fxyz(27,16, 6)/-2.1779005d-10,-3.4703052d-10/
      data fxyz(27,16, 7),fxyz(27,16, 8)/ 1.0035846d-09,-5.3230981d-10/
      data fxyz(27,16, 9),fxyz(27,16,10)/-7.6354939d-10, 2.0145508d-09/
      data fxyz(27,16,11),fxyz(27,16,12)/-1.9778582d-09, 2.0693076d-09/
      data fxyz(27,16,13),fxyz(27,16,14)/-4.8136060d-09, 6.6234525d-09/
      data fxyz(27,16,15),fxyz(27,16,16)/-4.4117461d-09, 2.0819279d-09/
      data fxyz(27,16,17),fxyz(27,16,18)/-4.8142530d-10,-8.1394193d-10/
      data fxyz(27,16,19),fxyz(27,16,20)/ 8.9781201d-10,-2.7330038d-10/
      data fxyz(27,16,21),fxyz(27,16,22)/-1.6610387d-10, 4.6902599d-10/
      data fxyz(27,16,23)/                7.9400566d-10/
      data fxyz(27,17, 1),fxyz(27,17, 2)/-4.7546541d-10,-2.3548935d-10/
      data fxyz(27,17, 3),fxyz(27,17, 4)/ 2.4173852d-10, 3.0649999d-10/
      data fxyz(27,17, 5),fxyz(27,17, 6)/-4.9453522d-10, 4.9595662d-10/
      data fxyz(27,17, 7),fxyz(27,17, 8)/-1.0043397d-09, 9.8789498d-10/
      data fxyz(27,17, 9),fxyz(27,17,10)/-4.4929750d-10,-3.8578354d-10/
      data fxyz(27,17,11),fxyz(27,17,12)/ 5.9695508d-10,-6.0455184d-10/
      data fxyz(27,17,13),fxyz(27,17,14)/ 1.3005119d-09,-1.6872354d-09/
      data fxyz(27,17,15),fxyz(27,17,16)/ 1.1501291d-09,-1.0450350d-09/
      data fxyz(27,17,17),fxyz(27,17,18)/ 5.6827904d-10, 4.2205786d-10/
      data fxyz(27,17,19),fxyz(27,17,20)/-4.9858061d-10, 1.5252411d-10/
      data fxyz(27,17,21),fxyz(27,17,22)/ 9.4399710d-11,-2.6608301d-10/
      data fxyz(27,17,23)/               -4.4980813d-10/
      data fxyz(27,18, 1),fxyz(27,18, 2)/ 2.3788025d-10, 1.2644875d-10/
      data fxyz(27,18, 3),fxyz(27,18, 4)/-1.0192399d-10,-1.2013984d-10/
      data fxyz(27,18, 5),fxyz(27,18, 6)/ 1.9931216d-10,-3.5357542d-11/
      data fxyz(27,18, 7),fxyz(27,18, 8)/ 1.6599460d-10,-2.5879230d-10/
      data fxyz(27,18, 9),fxyz(27,18,10)/ 9.3561671d-11, 1.0497853d-10/
      data fxyz(27,18,11),fxyz(27,18,12)/-1.4598067d-10,-1.0791471d-13/
      data fxyz(27,18,13),fxyz(27,18,14)/-1.4238795d-10, 3.2269168d-10/
      data fxyz(27,18,15),fxyz(27,18,16)/-2.4284171d-10, 2.0539505d-10/
      data fxyz(27,18,17),fxyz(27,18,18)/-6.3866932d-11,-3.5509736d-10/
      data fxyz(27,18,19),fxyz(27,18,20)/ 3.9111765d-10,-5.3045353d-11/
      data fxyz(27,18,21),fxyz(27,18,22)/-7.7847009d-12, 2.1007504d-10/
      data fxyz(27,18,23)/                3.2381242d-10/
      data fxyz(27,19, 1),fxyz(27,19, 2)/ 7.0779836d-10, 3.8069737d-10/
      data fxyz(27,19, 3),fxyz(27,19, 4)/-2.8664048d-10,-3.4542799d-10/
      data fxyz(27,19, 5),fxyz(27,19, 6)/ 6.1584738d-10,-1.7401419d-10/
      data fxyz(27,19, 7),fxyz(27,19, 8)/ 4.2825505d-10,-7.1493899d-10/
      data fxyz(27,19, 9),fxyz(27,19,10)/ 5.7110448d-10,-2.3028694d-10/
      data fxyz(27,19,11),fxyz(27,19,12)/ 5.9011879d-11,-3.3232209d-10/
      data fxyz(27,19,13),fxyz(27,19,14)/ 5.7386013d-10,-6.1612841d-10/
      data fxyz(27,19,15),fxyz(27,19,16)/ 3.5128634d-10, 2.0514140d-10/
      data fxyz(27,19,17),fxyz(27,19,18)/-2.1548424d-10,-5.5706544d-10/
      data fxyz(27,19,19),fxyz(27,19,20)/ 6.2764708d-10,-7.8216544d-11/
      data fxyz(27,19,21),fxyz(27,19,22)/-6.3439711d-12, 3.4015679d-10/
      data fxyz(27,19,23)/                5.2102316d-10/
      data fxyz(28, 1, 1),fxyz(28, 1, 2)/ 5.3397399d-10, 1.9809510d-10/
      data fxyz(28, 1, 3),fxyz(28, 1, 4)/-4.8909931d-10,-5.4605493d-10/
      data fxyz(28, 1, 5),fxyz(28, 1, 6)/ 4.2591759d-10,-3.2036036d-10/
      data fxyz(28, 1, 7),fxyz(28, 1, 8)/ 4.7303710d-10, 7.8386848d-10/
      data fxyz(28, 1, 9),fxyz(28, 1,10)/-9.3582162d-10, 9.1946725d-10/
      data fxyz(28, 1,11),fxyz(28, 1,12)/-1.0372161d-09, 4.6592437d-10/
      data fxyz(28, 1,13),fxyz(28, 1,14)/ 3.3653645d-10,-2.8276018d-10/
      data fxyz(28, 1,15),fxyz(28, 1,16)/-3.2290500d-10, 6.4181993d-10/
      data fxyz(28, 1,17),fxyz(28, 1,18)/ 9.8853291d-11, 7.0674852d-10/
      data fxyz(28, 1,19),fxyz(28, 1,20)/-5.2781203d-10,-4.0316397d-10/
      data fxyz(28, 1,21),fxyz(28, 1,22)/-4.6452772d-10,-2.8235703d-10/
      data fxyz(28, 1,23)/               -2.1370771d-10/
      data fxyz(28, 2, 1),fxyz(28, 2, 2)/ 4.1751592d-10, 1.8592381d-10/
      data fxyz(28, 2, 3),fxyz(28, 2, 4)/-2.8866359d-10,-3.2660603d-10/
      data fxyz(28, 2, 5),fxyz(28, 2, 6)/ 3.3769357d-10,-1.5162065d-10/
      data fxyz(28, 2, 7),fxyz(28, 2, 8)/ 2.5342619d-10, 3.7430268d-10/
      data fxyz(28, 2, 9),fxyz(28, 2,10)/-4.6916471d-10, 3.9929406d-10/
      data fxyz(28, 2,11),fxyz(28, 2,12)/-4.8850250d-10, 1.6651694d-10/
      data fxyz(28, 2,13),fxyz(28, 2,14)/ 2.1112772d-10,-2.2745256d-10/
      data fxyz(28, 2,15),fxyz(28, 2,16)/-1.2123590d-10, 2.5258654d-10/
      data fxyz(28, 2,17),fxyz(28, 2,18)/ 9.3513771d-11, 3.4967375d-10/
      data fxyz(28, 2,19),fxyz(28, 2,20)/-1.8080343d-10,-2.0927367d-10/
      data fxyz(28, 2,21),fxyz(28, 2,22)/-2.3382388d-10,-8.2602594d-11/
      data fxyz(28, 2,23)/               -1.8579384d-11/
      data fxyz(28, 3, 1),fxyz(28, 3, 2)/ 1.3798135d-09, 7.4645434d-10/
      data fxyz(28, 3, 3),fxyz(28, 3, 4)/-5.7177595d-10,-6.3996962d-10/
      data fxyz(28, 3, 5),fxyz(28, 3, 6)/ 1.0192290d-09, 3.5690838d-10/
      data fxyz(28, 3, 7),fxyz(28, 3, 8)/-7.9227962d-11,-4.6719581d-10/
      data fxyz(28, 3, 9),fxyz(28, 3,10)/ 8.2847158d-10,-6.3444310d-10/
      data fxyz(28, 3,11),fxyz(28, 3,12)/ 6.0868795d-10,-1.1358104d-09/
      data fxyz(28, 3,13),fxyz(28, 3,14)/-5.8796449d-11,-8.4967551d-11/
      data fxyz(28, 3,15),fxyz(28, 3,16)/ 2.5952944d-10,-2.9645926d-11/
      data fxyz(28, 3,17),fxyz(28, 3,18)/ 2.1806049d-11,-9.3343701d-11/
      data fxyz(28, 3,19),fxyz(28, 3,20)/ 1.1980908d-09,-5.3687609d-10/
      data fxyz(28, 3,21),fxyz(28, 3,22)/-4.3714101d-10, 7.9915046d-10/
      data fxyz(28, 3,23)/                1.4026825d-09/
      data fxyz(28, 4, 1),fxyz(28, 4, 2)/-1.4335336d-09,-6.9747148d-10/
      data fxyz(28, 4, 3),fxyz(28, 4, 4)/ 8.3752998d-10, 9.1151054d-10/
      data fxyz(28, 4, 5),fxyz(28, 4, 6)/-9.9339373d-10,-3.2382520d-10/
      data fxyz(28, 4, 7),fxyz(28, 4, 8)/-1.6230744d-11, 2.0307012d-10/
      data fxyz(28, 4, 9),fxyz(28, 4,10)/-7.8231995d-10, 1.2929365d-10/
      data fxyz(28, 4,11),fxyz(28, 4,12)/-2.1379067d-10, 1.0720819d-09/
      data fxyz(28, 4,13),fxyz(28, 4,14)/ 1.7708344d-10,-2.4760340d-10/
      data fxyz(28, 4,15),fxyz(28, 4,16)/ 1.3457918d-11,-6.8638166d-10/
      data fxyz(28, 4,17),fxyz(28, 4,18)/ 1.8238703d-10,-2.3556180d-10/
      data fxyz(28, 4,19),fxyz(28, 4,20)/-1.0346147d-09, 9.6074600d-10/
      data fxyz(28, 4,21),fxyz(28, 4,22)/ 8.7861525d-10,-7.0609165d-10/
      data fxyz(28, 4,23)/               -1.4675231d-09/
      data fxyz(28, 5, 1),fxyz(28, 5, 2)/-2.4532652d-10,-6.5559089d-11/
      data fxyz(28, 5, 3),fxyz(28, 5, 4)/ 2.9538134d-10, 3.3786345d-10/
      data fxyz(28, 5, 5),fxyz(28, 5, 6)/-2.3548751d-10, 3.9190505d-10/
      data fxyz(28, 5, 7),fxyz(28, 5, 8)/-5.8920651d-10,-4.5571081d-10/
      data fxyz(28, 5, 9),fxyz(28, 5,10)/ 1.8808345d-10, 1.2792449d-10/
      data fxyz(28, 5,11),fxyz(28, 5,12)/ 1.7100491d-10,-4.0660678d-11/
      data fxyz(28, 5,13),fxyz(28, 5,14)/-1.2869941d-10, 5.9387622d-10/
      data fxyz(28, 5,15),fxyz(28, 5,16)/-7.8753394d-10, 6.6550569d-10/
      data fxyz(28, 5,17),fxyz(28, 5,18)/-9.6856085d-10, 2.1895071d-10/
      data fxyz(28, 5,19),fxyz(28, 5,20)/ 4.6115961d-10,-7.5319100d-11/
      data fxyz(28, 5,21),fxyz(28, 5,22)/-5.1937820d-11, 3.6763449d-10/
      data fxyz(28, 5,23)/                5.6966991d-10/
      data fxyz(28, 6, 1),fxyz(28, 6, 2)/ 1.0125984d-09, 5.1963455d-10/
      data fxyz(28, 6, 3),fxyz(28, 6, 4)/-4.7208844d-10,-5.8518759d-10/
      data fxyz(28, 6, 5),fxyz(28, 6, 6)/ 9.7203112d-10,-6.8388878d-10/
      data fxyz(28, 6, 7),fxyz(28, 6, 8)/ 4.4264698d-10, 5.3759598d-10/
      data fxyz(28, 6, 9),fxyz(28, 6,10)/ 1.9848142d-11, 1.6158674d-10/
      data fxyz(28, 6,11),fxyz(28, 6,12)/-4.3648980d-10,-2.5934774d-10/
      data fxyz(28, 6,13),fxyz(28, 6,14)/-4.1105519d-10,-7.1989221d-11/
      data fxyz(28, 6,15),fxyz(28, 6,16)/ 6.8652917d-10,-4.3081272d-10/
      data fxyz(28, 6,17),fxyz(28, 6,18)/ 9.2104303d-10,-2.8285627d-10/
      data fxyz(28, 6,19),fxyz(28, 6,20)/-1.1100490d-10,-1.4448082d-10/
      data fxyz(28, 6,21),fxyz(28, 6,22)/-1.3558176d-10,-1.4660113d-10/
      data fxyz(28, 6,23)/               -1.4937042d-10/
      data fxyz(28, 7, 1),fxyz(28, 7, 2)/-3.2055258d-10,-2.6321710d-10/
      data fxyz(28, 7, 3),fxyz(28, 7, 4)/-1.8288459d-10,-1.0845842d-10/
      data fxyz(28, 7, 5),fxyz(28, 7, 6)/-5.6092179d-10, 7.9584002d-10/
      data fxyz(28, 7, 7),fxyz(28, 7, 8)/ 1.8781555d-10,-3.7184868d-10/
      data fxyz(28, 7, 9),fxyz(28, 7,10)/ 5.1446752d-10,-7.2710503d-10/
      data fxyz(28, 7,11),fxyz(28, 7,12)/ 6.2702238d-10,-4.5522488d-10/
      data fxyz(28, 7,13),fxyz(28, 7,14)/ 3.6374459d-10,-4.1671789d-10/
      data fxyz(28, 7,15),fxyz(28, 7,16)/ 3.9968452d-11, 2.3321448d-10/
      data fxyz(28, 7,17),fxyz(28, 7,18)/-1.7814297d-11, 2.6064576d-10/
      data fxyz(28, 7,19),fxyz(28, 7,20)/ 1.3481928d-10,-2.8099235d-10/
      data fxyz(28, 7,21),fxyz(28, 7,22)/-2.7775411d-10, 1.2186631d-10/
      data fxyz(28, 7,23)/                3.0921938d-10/
      data fxyz(28, 8, 1),fxyz(28, 8, 2)/-2.8609017d-10,-1.0190961d-10/
      data fxyz(28, 8, 3),fxyz(28, 8, 4)/ 3.0787867d-10, 2.8142629d-10/
      data fxyz(28, 8, 5),fxyz(28, 8, 6)/ 3.8998992d-12,-6.8287581d-10/
      data fxyz(28, 8, 7),fxyz(28, 8, 8)/ 1.4359252d-10, 2.0819803d-10/
      data fxyz(28, 8, 9),fxyz(28, 8,10)/-6.1831241d-10, 7.9392029d-10/
      data fxyz(28, 8,11),fxyz(28, 8,12)/-6.9968036d-10, 6.2516198d-10/
      data fxyz(28, 8,13),fxyz(28, 8,14)/-1.3012303d-10, 1.5594128d-10/
      data fxyz(28, 8,15),fxyz(28, 8,16)/-6.0970467d-12,-8.8732658d-11/
      data fxyz(28, 8,17),fxyz(28, 8,18)/-3.2450980d-10, 6.7551561d-11/
      data fxyz(28, 8,19),fxyz(28, 8,20)/ 8.7854826d-11, 2.1629045d-11/
      data fxyz(28, 8,21),fxyz(28, 8,22)/ 2.4059834d-11, 7.8131668d-11/
      data fxyz(28, 8,23)/                1.0401340d-10/
      data fxyz(28, 9, 1),fxyz(28, 9, 2)/-5.0789353d-11,-4.7870293d-11/
      data fxyz(28, 9, 3),fxyz(28, 9, 4)/-8.1491667d-11,-1.1707786d-11/
      data fxyz(28, 9, 5),fxyz(28, 9, 6)/-3.2700582d-10, 9.9596886d-10/
      data fxyz(28, 9, 7),fxyz(28, 9, 8)/-1.0091000d-09, 3.0940686d-10/
      data fxyz(28, 9, 9),fxyz(28, 9,10)/-1.0158727d-10,-7.1121641d-11/
      data fxyz(28, 9,11),fxyz(28, 9,12)/ 2.7598146d-10, 8.9513822d-11/
      data fxyz(28, 9,13),fxyz(28, 9,14)/-5.3173618d-11, 2.7068541d-10/
      data fxyz(28, 9,15),fxyz(28, 9,16)/-5.8439736d-10, 4.0930081d-10/
      data fxyz(28, 9,17),fxyz(28, 9,18)/ 8.2956056d-12, 7.4800613d-12/
      data fxyz(28, 9,19),fxyz(28, 9,20)/-5.9866951d-10, 2.9026675d-10/
      data fxyz(28, 9,21),fxyz(28, 9,22)/ 2.4180220d-10,-4.0481131d-10/
      data fxyz(28, 9,23)/               -7.1948817d-10/
      data fxyz(28,10, 1),fxyz(28,10, 2)/ 4.9343170d-10, 2.7291508d-10/
      data fxyz(28,10, 3),fxyz(28,10, 4)/-1.3391319d-10,-2.4890103d-10/
      data fxyz(28,10, 5),fxyz(28,10, 6)/ 7.3286643d-10,-1.2313859d-09/
      data fxyz(28,10, 7),fxyz(28,10, 8)/ 1.6733356d-09,-1.1471973d-09/
      data fxyz(28,10, 9),fxyz(28,10,10)/ 6.2632677d-10,-3.2972918d-10/
      data fxyz(28,10,11),fxyz(28,10,12)/ 1.5743868d-10,-5.2957816d-10/
      data fxyz(28,10,13),fxyz(28,10,14)/ 2.9450474d-10,-1.8611664d-10/
      data fxyz(28,10,15),fxyz(28,10,16)/ 8.7699220d-10,-8.4739786d-10/
      data fxyz(28,10,17),fxyz(28,10,18)/ 4.7810238d-10,-3.6648859d-10/
      data fxyz(28,10,19),fxyz(28,10,20)/ 3.6580379d-10,-1.6530885d-10/
      data fxyz(28,10,21),fxyz(28,10,22)/-1.1878298d-10, 1.7970032d-10/
      data fxyz(28,10,23)/                3.3139942d-10/
      data fxyz(28,11, 1),fxyz(28,11, 2)/-1.4858900d-10,-8.5773446d-11/
      data fxyz(28,11, 3),fxyz(28,11, 4)/ 3.9828980d-12, 8.2467625d-11/
      data fxyz(28,11, 5),fxyz(28,11, 6)/-3.9971235d-10, 1.0286819d-09/
      data fxyz(28,11, 7),fxyz(28,11, 8)/-2.4044582d-09, 2.8587688d-09/
      data fxyz(28,11, 9),fxyz(28,11,10)/-1.3939336d-09, 3.7161866d-10/
      data fxyz(28,11,11),fxyz(28,11,12)/-3.4740121d-10, 7.0593022d-10/
      data fxyz(28,11,13),fxyz(28,11,14)/-6.6788805d-10, 3.9203866d-10/
      data fxyz(28,11,15),fxyz(28,11,16)/-9.2665302d-10, 1.1109013d-09/
      data fxyz(28,11,17),fxyz(28,11,18)/-9.6233803d-10, 5.7822038d-10/
      data fxyz(28,11,19),fxyz(28,11,20)/-4.2422666d-11, 7.5310342d-12/
      data fxyz(28,11,21),fxyz(28,11,22)/-2.3036439d-11, 7.9847228d-11/
      data fxyz(28,11,23)/                1.1970828d-10/
      data fxyz(28,12, 1),fxyz(28,12, 2)/-4.9778318d-10,-2.8398652d-10/
      data fxyz(28,12, 3),fxyz(28,12, 4)/ 1.8465892d-10, 1.6626689d-10/
      data fxyz(28,12, 5),fxyz(28,12, 6)/-2.1041841d-10,-7.7366361d-10/
      data fxyz(28,12, 7),fxyz(28,12, 8)/ 2.6893196d-09,-3.8569801d-09/
      data fxyz(28,12, 9),fxyz(28,12,10)/ 2.4637863d-09,-7.3148246d-10/
      data fxyz(28,12,11),fxyz(28,12,12)/ 3.2459480d-10,-6.5621926d-10/
      data fxyz(28,12,13),fxyz(28,12,14)/ 1.0249277d-09,-1.0179602d-09/
      data fxyz(28,12,15),fxyz(28,12,16)/ 9.3603822d-10,-1.0341935d-09/
      data fxyz(28,12,17),fxyz(28,12,18)/ 1.0741812d-09,-5.9474194d-10/
      data fxyz(28,12,19),fxyz(28,12,20)/ 4.0369523d-11, 3.7895712d-11/
      data fxyz(28,12,21),fxyz(28,12,22)/ 6.8098207d-11,-8.0440460d-11/
      data fxyz(28,12,23)/               -1.4170451d-10/
      data fxyz(28,13, 1),fxyz(28,13, 2)/ 6.6864343d-10, 3.6839448d-10/
      data fxyz(28,13, 3),fxyz(28,13, 4)/-2.5747574d-10,-2.8813641d-10/
      data fxyz(28,13, 5),fxyz(28,13, 6)/ 4.9103720d-10, 2.0873326d-10/
      data fxyz(28,13, 7),fxyz(28,13, 8)/-1.3646694d-09, 2.5252023d-09/
      data fxyz(28,13, 9),fxyz(28,13,10)/-2.6912326d-09, 1.8543156d-09/
      data fxyz(28,13,11),fxyz(28,13,12)/-4.3093350d-10, 5.4859201d-11/
      data fxyz(28,13,13),fxyz(28,13,14)/-1.0291352d-09, 1.4241350d-09/
      data fxyz(28,13,15),fxyz(28,13,16)/-8.6206701d-10, 6.5946480d-10/
      data fxyz(28,13,17),fxyz(28,13,18)/-7.2516736d-10, 2.9628108d-10/
      data fxyz(28,13,19),fxyz(28,13,20)/ 1.0936086d-10,-6.4349987d-11/
      data fxyz(28,13,21),fxyz(28,13,22)/-6.9374757d-11, 1.2945994d-10/
      data fxyz(28,13,23)/                2.2090953d-10/
      data fxyz(28,14, 1),fxyz(28,14, 2)/-4.5504988d-10,-2.4905953d-10/
      data fxyz(28,14, 3),fxyz(28,14, 4)/ 1.6171855d-10, 2.1532070d-10/
      data fxyz(28,14, 5),fxyz(28,14, 6)/-4.6346813d-10, 3.4898237d-10/
      data fxyz(28,14, 7),fxyz(28,14, 8)/ 5.7581291d-11,-1.0978315d-09/
      data fxyz(28,14, 9),fxyz(28,14,10)/ 2.4428293d-09,-2.8748489d-09/
      data fxyz(28,14,11),fxyz(28,14,12)/ 1.1093123d-09, 1.1640300d-11/
      data fxyz(28,14,13),fxyz(28,14,14)/ 1.5240578d-09,-2.5277885d-09/
      data fxyz(28,14,15),fxyz(28,14,16)/ 1.4929184d-09,-5.2879379d-10/
      data fxyz(28,14,17),fxyz(28,14,18)/ 2.5706419d-10, 1.4772357d-10/
      data fxyz(28,14,19),fxyz(28,14,20)/-3.8247191d-10, 1.2675255d-10/
      data fxyz(28,14,21),fxyz(28,14,22)/ 9.0304757d-11,-2.3668072d-10/
      data fxyz(28,14,23)/               -3.9899336d-10/
      data fxyz(28,15, 1),fxyz(28,15, 2)/-2.3495768d-10,-1.3838024d-10/
      data fxyz(28,15, 3),fxyz(28,15, 4)/ 7.3873660d-11, 6.4594741d-11/
      data fxyz(28,15, 5),fxyz(28,15, 6)/-1.0126456d-10,-3.7414146d-10/
      data fxyz(28,15, 7),fxyz(28,15, 8)/ 3.3724126d-10, 3.2905541d-10/
      data fxyz(28,15, 9),fxyz(28,15,10)/-1.2695561d-09, 1.9809162d-09/
      data fxyz(28,15,11),fxyz(28,15,12)/-1.1517839d-09, 5.6989831d-10/
      data fxyz(28,15,13),fxyz(28,15,14)/-2.1610112d-09, 3.4059430d-09/
      data fxyz(28,15,15),fxyz(28,15,16)/-2.1785385d-09, 6.6797120d-10/
      data fxyz(28,15,17),fxyz(28,15,18)/-7.4518624d-12,-4.5251081d-10/
      data fxyz(28,15,19),fxyz(28,15,20)/ 6.1894919d-10,-2.2458899d-10/
      data fxyz(28,15,21),fxyz(28,15,22)/-1.5504258d-10, 3.4076353d-10/
      data fxyz(28,15,23)/                5.9068542d-10/
      data fxyz(28,16, 1),fxyz(28,16, 2)/ 2.1750040d-10, 1.3631312d-10/
      data fxyz(28,16, 3),fxyz(28,16, 4)/-4.5114211d-11,-3.2068661d-11/
      data fxyz(28,16, 5),fxyz(28,16, 6)/ 8.4130928d-11, 4.1318364d-10/
      data fxyz(28,16, 7),fxyz(28,16, 8)/-7.2402525d-10, 4.6824304d-10/
      data fxyz(28,16, 9),fxyz(28,16,10)/-1.6452043d-10,-4.7676027d-10/
      data fxyz(28,16,11),fxyz(28,16,12)/ 5.6031426d-10,-5.0270508d-10/
      data fxyz(28,16,13),fxyz(28,16,14)/ 1.4681988d-09,-2.0265065d-09/
      data fxyz(28,16,15),fxyz(28,16,16)/ 1.3533527d-09,-5.6241795d-10/
      data fxyz(28,16,17),fxyz(28,16,18)/ 1.1262693d-10, 3.1496379d-10/
      data fxyz(28,16,19),fxyz(28,16,20)/-5.0435568d-10, 1.7112007d-10/
      data fxyz(28,16,21),fxyz(28,16,22)/ 1.1726525d-10,-2.8893641d-10/
      data fxyz(28,16,23)/               -4.9285847d-10/
      data fxyz(28,17, 1),fxyz(28,17, 2)/ 2.4895143d-10, 1.3406344d-10/
      data fxyz(28,17, 3),fxyz(28,17, 4)/-8.3856072d-11,-1.3332688d-10/
      data fxyz(28,17, 5),fxyz(28,17, 6)/ 3.3194666d-10,-4.9311063d-10/
      data fxyz(28,17, 7),fxyz(28,17, 8)/ 6.9400519d-10,-7.3465113d-10/
      data fxyz(28,17, 9),fxyz(28,17,10)/ 5.9297292d-10,-1.3235270d-10/
      data fxyz(28,17,11),fxyz(28,17,12)/-9.8765682d-12,-9.6133121d-11/
      data fxyz(28,17,13),fxyz(28,17,14)/-1.5598553d-10, 2.3304683d-10/
      data fxyz(28,17,15),fxyz(28,17,16)/-9.5678765d-11, 1.5866399d-10/
      data fxyz(28,17,17),fxyz(28,17,18)/-9.3212235d-11,-1.8932555d-10/
      data fxyz(28,17,19),fxyz(28,17,20)/ 2.6248761d-10,-6.5913853d-11/
      data fxyz(28,17,21),fxyz(28,17,22)/-3.7192310d-11, 1.4760144d-10/
      data fxyz(28,17,23)/                2.4149760d-10/
      data fxyz(28,18, 1),fxyz(28,18, 2)/-2.9148839d-11,-1.7861605d-11/
      data fxyz(28,18, 3),fxyz(28,18, 4)/ 5.1958056d-13, 1.0679632d-11/
      data fxyz(28,18, 5),fxyz(28,18, 6)/-5.8501811d-11, 1.2325194d-10/
      data fxyz(28,18, 7),fxyz(28,18, 8)/-1.8125576d-10, 2.6092224d-10/
      data fxyz(28,18, 9),fxyz(28,18,10)/-2.6008203d-10, 1.8225118d-10/
      data fxyz(28,18,11),fxyz(28,18,12)/-2.5599760d-10, 3.2761449d-10/
      data fxyz(28,18,13),fxyz(28,18,14)/-2.3501598d-10, 1.2303274d-10/
      data fxyz(28,18,15),fxyz(28,18,16)/-1.1045890d-10, 4.1267163d-11/
      data fxyz(28,18,17),fxyz(28,18,18)/-6.7823410d-11, 2.3866051d-10/
      data fxyz(28,18,19),fxyz(28,18,20)/-2.1798967d-10, 5.7836203d-11/
      data fxyz(28,18,21),fxyz(28,18,22)/ 3.0049704d-11,-1.0684367d-10/
      data fxyz(28,18,23)/               -1.7813698d-10/
      data fxyz(28,19, 1),fxyz(28,19, 2)/-2.1880588d-10,-1.2702226d-10/
      data fxyz(28,19, 3),fxyz(28,19, 4)/ 4.9718800d-11, 8.4610505d-11/
      data fxyz(28,19, 5),fxyz(28,19, 6)/-2.6658908d-10, 3.0456969d-10/
      data fxyz(28,19, 7),fxyz(28,19, 8)/-4.0129060d-10, 6.2836202d-10/
      data fxyz(28,19, 9),fxyz(28,19,10)/-6.5298032d-10, 5.0537040d-10/
      data fxyz(28,19,11),fxyz(28,19,12)/-5.9471001d-10, 7.4645477d-10/
      data fxyz(28,19,13),fxyz(28,19,14)/-7.5551898d-10, 6.9003793d-10/
      data fxyz(28,19,15),fxyz(28,19,16)/-5.3502514d-10, 1.6343570d-10/
      data fxyz(28,19,17),fxyz(28,19,18)/-1.0849973d-10, 4.0028216d-10/
      data fxyz(28,19,19),fxyz(28,19,20)/-3.4208964d-10, 7.8505123d-11/
      data fxyz(28,19,21),fxyz(28,19,22)/ 3.3948982d-11,-1.6386508d-10/
      data fxyz(28,19,23)/               -2.6805995d-10/
      data fxyz(29, 1, 1),fxyz(29, 1, 2)/-1.4228789d-10,-1.0455532d-10/
      data fxyz(29, 1, 3),fxyz(29, 1, 4)/-2.6025392d-11,-2.1955588d-11/
      data fxyz(29, 1, 5),fxyz(29, 1, 6)/-1.2083453d-10,-8.1240829d-11/
      data fxyz(29, 1, 7),fxyz(29, 1, 8)/-1.5873593d-10, 3.2483056d-11/
      data fxyz(29, 1, 9),fxyz(29, 1,10)/ 2.9109323d-11, 1.2662321d-10/
      data fxyz(29, 1,11),fxyz(29, 1,12)/ 1.1083804d-10, 1.7505123d-10/
      data fxyz(29, 1,13),fxyz(29, 1,14)/ 1.4177835d-10, 1.4361046d-10/
      data fxyz(29, 1,15),fxyz(29, 1,16)/ 4.5585876d-11, 3.7680912d-11/
      data fxyz(29, 1,17),fxyz(29, 1,18)/-1.0624688d-10,-2.1487906d-10/
      data fxyz(29, 1,19),fxyz(29, 1,20)/ 1.4979791d-11,-9.7319509d-11/
      data fxyz(29, 1,21),fxyz(29, 1,22)/-8.3920845d-11,-3.8614865d-11/
      data fxyz(29, 1,23)/               -1.3899097d-11/
      data fxyz(29, 2, 1),fxyz(29, 2, 2)/-6.9659273d-11,-4.5348755d-11/
      data fxyz(29, 2, 3),fxyz(29, 2, 4)/ 4.8837362d-12, 8.1413204d-12/
      data fxyz(29, 2, 5),fxyz(29, 2, 6)/-5.8379092d-11,-2.0795510d-11/
      data fxyz(29, 2, 7),fxyz(29, 2, 8)/-5.9319560d-11, 1.5830621d-11/
      data fxyz(29, 2, 9),fxyz(29, 2,10)/ 9.2549184d-12, 3.8826208d-11/
      data fxyz(29, 2,11),fxyz(29, 2,12)/ 3.0225724d-11, 5.1009159d-11/
      data fxyz(29, 2,13),fxyz(29, 2,14)/ 4.5059851d-11, 4.6094279d-11/
      data fxyz(29, 2,15),fxyz(29, 2,16)/ 1.7987330d-11, 1.9137435d-11/
      data fxyz(29, 2,17),fxyz(29, 2,18)/-3.3597763d-11,-8.9956414d-11/
      data fxyz(29, 2,19),fxyz(29, 2,20)/ 1.5070657d-11,-2.6361143d-11/
      data fxyz(29, 2,21),fxyz(29, 2,22)/-2.0457888d-11,-8.5423638d-12/
      data fxyz(29, 2,23)/               -1.4075844d-12/
      data fxyz(29, 3, 1),fxyz(29, 3, 2)/-1.2228869d-10,-4.9614147d-11/
      data fxyz(29, 3, 3),fxyz(29, 3, 4)/ 9.9762006d-11, 1.1088328d-10/
      data fxyz(29, 3, 5),fxyz(29, 3, 6)/-9.4099230d-11, 4.4530371d-11/
      data fxyz(29, 3, 7),fxyz(29, 3, 8)/ 1.9454253d-10,-2.5411763d-11/
      data fxyz(29, 3, 9),fxyz(29, 3,10)/-1.3469168d-11,-7.4045497d-11/
      data fxyz(29, 3,11),fxyz(29, 3,12)/-1.1535474d-10,-1.6885821d-10/
      data fxyz(29, 3,13),fxyz(29, 3,14)/-1.3877480d-10,-9.7596324d-11/
      data fxyz(29, 3,15),fxyz(29, 3,16)/-1.0785411d-12, 1.6673698d-11/
      data fxyz(29, 3,17),fxyz(29, 3,18)/ 1.3341373d-10, 1.3646981d-10/
      data fxyz(29, 3,19),fxyz(29, 3,20)/-1.3604917d-10, 1.2180365d-10/
      data fxyz(29, 3,21),fxyz(29, 3,22)/ 1.0315569d-10,-6.1457343d-11/
      data fxyz(29, 3,23)/               -1.4324955d-10/
      data fxyz(29, 4, 1),fxyz(29, 4, 2)/ 2.6348503d-10, 1.6827230d-10/
      data fxyz(29, 4, 3),fxyz(29, 4, 4)/-2.9251719d-11,-4.0632436d-11/
      data fxyz(29, 4, 5),fxyz(29, 4, 6)/ 2.1379516d-10, 9.2774287d-11/
      data fxyz(29, 4, 7),fxyz(29, 4, 8)/-9.2155394d-11, 1.9410670d-11/
      data fxyz(29, 4, 9),fxyz(29, 4,10)/-2.6149369d-11,-9.9155757d-11/
      data fxyz(29, 4,11),fxyz(29, 4,12)/-3.3546679d-11,-5.3337032d-11/
      data fxyz(29, 4,13),fxyz(29, 4,14)/-1.7702919d-11,-7.9676454d-11/
      data fxyz(29, 4,15),fxyz(29, 4,16)/-5.0008771d-11,-4.2069127d-11/
      data fxyz(29, 4,17),fxyz(29, 4,18)/-2.9843120d-11, 7.6335094d-12/
      data fxyz(29, 4,19),fxyz(29, 4,20)/ 2.4206843d-10,-2.5404745d-13/
      data fxyz(29, 4,21),fxyz(29, 4,22)/ 1.6242096d-11, 1.7608386d-10/
      data fxyz(29, 4,23)/                2.5507565d-10/
      data fxyz(29, 5, 1),fxyz(29, 5, 2)/-1.5830762d-10,-4.4118668d-11/
      data fxyz(29, 5, 3),fxyz(29, 5, 4)/ 1.9815018d-10, 2.0238827d-10/
      data fxyz(29, 5, 5),fxyz(29, 5, 6)/-6.1071031d-11,-9.4736259d-11/
      data fxyz(29, 5, 7),fxyz(29, 5, 8)/-9.1474783d-11,-6.0054041d-11/
      data fxyz(29, 5, 9),fxyz(29, 5,10)/-1.0930445d-10, 3.6725158d-11/
      data fxyz(29, 5,11),fxyz(29, 5,12)/ 2.5543037d-11, 1.3173822d-10/
      data fxyz(29, 5,13),fxyz(29, 5,14)/ 2.5814749d-13, 5.0590747d-11/
      data fxyz(29, 5,15),fxyz(29, 5,16)/-1.0281177d-10,-4.1159139d-11/
      data fxyz(29, 5,17),fxyz(29, 5,18)/-1.2367622d-10,-4.0143007d-11/
      data fxyz(29, 5,19),fxyz(29, 5,20)/-7.7267444d-11, 1.7139778d-10/
      data fxyz(29, 5,21),fxyz(29, 5,22)/ 1.6412714d-10,-4.8184873d-11/
      data fxyz(29, 5,23)/               -1.4920265d-10/
      data fxyz(29, 6, 1),fxyz(29, 6, 2)/ 8.8639358d-11, 3.5500095d-11/
      data fxyz(29, 6, 3),fxyz(29, 6, 4)/-7.4269534d-11,-8.1444920d-11/
      data fxyz(29, 6, 5),fxyz(29, 6, 6)/ 6.4201641d-11,-1.8991440d-11/
      data fxyz(29, 6, 7),fxyz(29, 6, 8)/ 3.9774839d-11,-6.8927393d-11/
      data fxyz(29, 6, 9),fxyz(29, 6,10)/ 1.1954094d-10, 1.8854663d-11/
      data fxyz(29, 6,11),fxyz(29, 6,12)/ 2.0815768d-11,-8.7153659d-11/
      data fxyz(29, 6,13),fxyz(29, 6,14)/ 3.5328605d-11,-1.0385886d-11/
      data fxyz(29, 6,15),fxyz(29, 6,16)/ 9.2667111d-11,-3.3416377d-11/
      data fxyz(29, 6,17),fxyz(29, 6,18)/ 3.9109337d-11,-7.7940341d-12/
      data fxyz(29, 6,19),fxyz(29, 6,20)/ 4.2486426d-11,-8.5383145d-11/
      data fxyz(29, 6,21),fxyz(29, 6,22)/-8.0163861d-11, 2.1609288d-11/
      data fxyz(29, 6,23)/                7.0495233d-11/
      data fxyz(29, 7, 1),fxyz(29, 7, 2)/ 2.9936754d-11,-1.4530360d-11/
      data fxyz(29, 7, 3),fxyz(29, 7, 4)/-1.1108023d-10,-1.0886963d-10/
      data fxyz(29, 7, 5),fxyz(29, 7, 6)/-2.3372760d-11, 6.3095754d-11/
      data fxyz(29, 7, 7),fxyz(29, 7, 8)/ 1.9103559d-11, 1.3587238d-10/
      data fxyz(29, 7, 9),fxyz(29, 7,10)/-2.0089912d-11, 2.7782954d-11/
      data fxyz(29, 7,11),fxyz(29, 7,12)/-2.3848305d-11,-1.0291166d-11/
      data fxyz(29, 7,13),fxyz(29, 7,14)/-4.1519524d-11, 3.5258563d-11/
      data fxyz(29, 7,15),fxyz(29, 7,16)/-2.6991588d-12, 8.5754107d-11/
      data fxyz(29, 7,17),fxyz(29, 7,18)/ 3.9867314d-11, 3.1902277d-11/
      data fxyz(29, 7,19),fxyz(29, 7,20)/-1.1707196d-11,-9.3990080d-11/
      data fxyz(29, 7,21),fxyz(29, 7,22)/-9.4237428d-11,-1.0717805d-11/
      data fxyz(29, 7,23)/                2.8192060d-11/
      data fxyz(29, 8, 1),fxyz(29, 8, 2)/-7.0057394d-11,-3.9106204d-11/
      data fxyz(29, 8, 3),fxyz(29, 8, 4)/ 2.5636915d-11, 2.8403419d-11/
      data fxyz(29, 8, 5),fxyz(29, 8, 6)/-5.0172224d-11,-2.8559822d-11/
      data fxyz(29, 8, 7),fxyz(29, 8, 8)/ 4.7925901d-11,-3.6930942d-11/
      data fxyz(29, 8, 9),fxyz(29, 8,10)/ 7.9475388d-12,-2.1226719d-11/
      data fxyz(29, 8,11),fxyz(29, 8,12)/ 9.6906893d-12, 5.0539589d-11/
      data fxyz(29, 8,13),fxyz(29, 8,14)/ 3.4231430d-11,-3.5904440d-11/
      data fxyz(29, 8,15),fxyz(29, 8,16)/ 2.9759867d-11,-4.4344852d-11/
      data fxyz(29, 8,17),fxyz(29, 8,18)/ 1.4180714d-11, 8.2471045d-12/
      data fxyz(29, 8,19),fxyz(29, 8,20)/-3.0283562d-11, 2.7133846d-12/
      data fxyz(29, 8,21),fxyz(29, 8,22)/ 1.5345231d-13,-2.0043832d-11/
      data fxyz(29, 8,23)/               -3.0151880d-11/
      data fxyz(29, 9, 1),fxyz(29, 9, 2)/ 2.8117299d-11, 1.9480228d-11/
      data fxyz(29, 9, 3),fxyz(29, 9, 4)/ 8.3365173d-13, 1.0761469d-12/
      data fxyz(29, 9, 5),fxyz(29, 9, 6)/ 1.8510248d-11, 3.1754726d-11/
      data fxyz(29, 9, 7),fxyz(29, 9, 8)/-4.6774412d-11,-4.5352119d-11/
      data fxyz(29, 9, 9),fxyz(29, 9,10)/ 1.1524521d-11,-1.4621962d-11/
      data fxyz(29, 9,11),fxyz(29, 9,12)/ 3.4116475d-11, 6.5979089d-12/
      data fxyz(29, 9,13),fxyz(29, 9,14)/ 2.6916540d-11, 3.3990093d-11/
      data fxyz(29, 9,15),fxyz(29, 9,16)/-4.3370064d-11, 3.4413587d-11/
      data fxyz(29, 9,17),fxyz(29, 9,18)/-4.5015653d-11,-2.6544003d-11/
      data fxyz(29, 9,19),fxyz(29, 9,20)/-1.8787452d-11, 2.7551742d-11/
      data fxyz(29, 9,21),fxyz(29, 9,22)/ 2.6893432d-11,-1.6154210d-11/
      data fxyz(29, 9,23)/               -3.6418659d-11/
      data fxyz(29,10, 1),fxyz(29,10, 2)/ 2.2152695d-11, 9.7651390d-12/
      data fxyz(29,10, 3),fxyz(29,10, 4)/-1.4360046d-11,-1.8594309d-11/
      data fxyz(29,10, 5),fxyz(29,10, 6)/ 2.6702190d-11,-4.1361248d-11/
      data fxyz(29,10, 7),fxyz(29,10, 8)/-3.7484333d-12, 1.3379081d-10/
      data fxyz(29,10, 9),fxyz(29,10,10)/-1.3488580d-10, 1.0254791d-10/
      data fxyz(29,10,11),fxyz(29,10,12)/-7.6367885d-11, 1.1529806d-11/
      data fxyz(29,10,13),fxyz(29,10,14)/ 4.0191519d-12, 3.3615621d-12/
      data fxyz(29,10,15),fxyz(29,10,16)/ 3.9017045d-11,-5.3430815d-11/
      data fxyz(29,10,17),fxyz(29,10,18)/ 5.6551823d-11,-2.6653465d-11/
      data fxyz(29,10,19),fxyz(29,10,20)/-1.1782214d-11,-1.9822251d-12/
      data fxyz(29,10,21),fxyz(29,10,22)/-1.4933996d-12,-1.3737516d-11/
      data fxyz(29,10,23)/               -1.9321083d-11/
      data fxyz(29,11, 1),fxyz(29,11, 2)/-2.9765204d-11,-2.3960913d-11/
      data fxyz(29,11, 3),fxyz(29,11, 4)/-1.1945549d-11,-1.1206348d-11/
      data fxyz(29,11, 5),fxyz(29,11, 6)/-2.6917721d-11,-1.8677177d-11/
      data fxyz(29,11, 7),fxyz(29,11, 8)/ 1.8499655d-10,-3.2845421d-10/
      data fxyz(29,11, 9),fxyz(29,11,10)/ 3.5303711d-10,-1.9732517d-10/
      data fxyz(29,11,11),fxyz(29,11,12)/ 9.1444363d-11, 6.7323251d-13/
      data fxyz(29,11,13),fxyz(29,11,14)/-7.5077432d-11, 2.0553810d-11/
      data fxyz(29,11,15),fxyz(29,11,16)/-4.5636863d-11, 9.4068086d-11/
      data fxyz(29,11,17),fxyz(29,11,18)/-8.1090837d-11, 6.3869319d-11/
      data fxyz(29,11,19),fxyz(29,11,20)/ 3.9736349d-12,-1.4379046d-11/
      data fxyz(29,11,21),fxyz(29,11,22)/-1.6815648d-11, 1.3720046d-11/
      data fxyz(29,11,23)/                2.7320276d-11/
      data fxyz(29,12, 1),fxyz(29,12, 2)/-1.5941278d-11,-1.1210351d-11/
      data fxyz(29,12, 3),fxyz(29,12, 4)/-5.5927309d-12, 2.3174115d-12/
      data fxyz(29,12, 5),fxyz(29,12, 6)/-4.2850921d-11, 1.0271086d-10/
      data fxyz(29,12, 7),fxyz(29,12, 8)/-3.1823304d-10, 5.2754082d-10/
      data fxyz(29,12, 9),fxyz(29,12,10)/-4.3683312d-10, 2.6618519d-10/
      data fxyz(29,12,11),fxyz(29,12,12)/-9.0008626d-11,-6.4320602d-11/
      data fxyz(29,12,13),fxyz(29,12,14)/ 9.3896069d-11,-6.4288915d-11/
      data fxyz(29,12,15),fxyz(29,12,16)/ 4.8679543d-11,-1.0253593d-10/
      data fxyz(29,12,17),fxyz(29,12,18)/ 1.0860854d-10,-6.9762145d-11/
      data fxyz(29,12,19),fxyz(29,12,20)/ 7.2995069d-11,-2.3730156d-11/
      data fxyz(29,12,21),fxyz(29,12,22)/-1.4811058d-11, 3.7318679d-11/
      data fxyz(29,12,23)/                6.4024316d-11/
      data fxyz(29,13, 1),fxyz(29,13, 2)/ 2.2059961d-11, 1.1740206d-11/
      data fxyz(29,13, 3),fxyz(29,13, 4)/-5.4669367d-12,-1.4053517d-11/
      data fxyz(29,13, 5),fxyz(29,13, 6)/ 4.6086528d-11,-1.0673875d-10/
      data fxyz(29,13, 7),fxyz(29,13, 8)/ 2.4294584d-10,-3.9231831d-10/
      data fxyz(29,13, 9),fxyz(29,13,10)/ 4.2628608d-10,-3.9061100d-10/
      data fxyz(29,13,11),fxyz(29,13,12)/ 2.2137473d-10, 9.8824266d-12/
      data fxyz(29,13,13),fxyz(29,13,14)/-5.5981575d-11, 3.5359835d-12/
      data fxyz(29,13,15),fxyz(29,13,16)/-1.4797343d-11, 8.1904632d-11/
      data fxyz(29,13,17),fxyz(29,13,18)/-1.0125415d-10, 8.1300741d-11/
      data fxyz(29,13,19),fxyz(29,13,20)/-6.8801379d-11, 2.5650717d-11/
      data fxyz(29,13,21),fxyz(29,13,22)/ 1.6433323d-11,-3.1931803d-11/
      data fxyz(29,13,23)/               -5.6960167d-11/
      data fxyz(29,14, 1),fxyz(29,14, 2)/-2.4929748d-11,-1.3874756d-11/
      data fxyz(29,14, 3),fxyz(29,14, 4)/ 6.9976035d-12, 1.1927196d-11/
      data fxyz(29,14, 5),fxyz(29,14, 6)/-3.3593124d-11, 4.9014132d-11/
      data fxyz(29,14, 7),fxyz(29,14, 8)/-1.2630052d-10, 1.8532571d-10/
      data fxyz(29,14, 9),fxyz(29,14,10)/-3.6222658d-10, 4.9791630d-10/
      data fxyz(29,14,11),fxyz(29,14,12)/-3.2290988d-10, 1.1335315d-10/
      data fxyz(29,14,13),fxyz(29,14,14)/-8.0191393d-11, 1.6132639d-10/
      data fxyz(29,14,15),fxyz(29,14,16)/-7.7886351d-11,-5.1051213d-11/
      data fxyz(29,14,17),fxyz(29,14,18)/ 7.6255273d-11,-5.8289059d-11/
      data fxyz(29,14,19),fxyz(29,14,20)/ 4.0472982d-11,-1.9646694d-11/
      data fxyz(29,14,21),fxyz(29,14,22)/-1.3626857d-11, 1.6393636d-11/
      data fxyz(29,14,23)/                3.2008489d-11/
      data fxyz(29,15, 1),fxyz(29,15, 2)/-4.4307247d-12,-2.1768408d-12/
      data fxyz(29,15, 3),fxyz(29,15, 4)/ 3.9453928d-12, 1.6835486d-12/
      data fxyz(29,15, 5),fxyz(29,15, 6)/ 6.8705359d-12,-3.8358388d-11/
      data fxyz(29,15, 7),fxyz(29,15, 8)/ 4.0621423d-11,-8.0641856d-11/
      data fxyz(29,15, 9),fxyz(29,15,10)/ 1.9870690d-10,-2.9634086d-10/
      data fxyz(29,15,11),fxyz(29,15,12)/ 2.1926243d-10,-1.1650375d-10/
      data fxyz(29,15,13),fxyz(29,15,14)/ 1.9444719d-10,-2.6006114d-10/
      data fxyz(29,15,15),fxyz(29,15,16)/ 1.6169819d-10, 1.2181599d-11/
      data fxyz(29,15,17),fxyz(29,15,18)/-4.5070807d-11, 2.5731799d-11/
      data fxyz(29,15,19),fxyz(29,15,20)/-4.4940845d-11, 1.3780091d-11/
      data fxyz(29,15,21),fxyz(29,15,22)/ 9.1245965d-12,-2.6318868d-11/
      data fxyz(29,15,23)/               -4.4100616d-11/
      data fxyz(29,16, 1),fxyz(29,16, 2)/-1.5938813d-11,-9.5383848d-12/
      data fxyz(29,16, 3),fxyz(29,16, 4)/ 2.5020933d-12, 5.4328609d-12/
      data fxyz(29,16, 5),fxyz(29,16, 6)/-2.1261455d-11, 2.8022702d-11/
      data fxyz(29,16, 7),fxyz(29,16, 8)/-1.6537608d-11, 1.3153132d-11/
      data fxyz(29,16, 9),fxyz(29,16,10)/-6.9300200d-11, 7.2943592d-11/
      data fxyz(29,16,11),fxyz(29,16,12)/-6.3549280d-11, 6.9334240d-11/
      data fxyz(29,16,13),fxyz(29,16,14)/-1.0823390d-10, 1.7758365d-10/
      data fxyz(29,16,15),fxyz(29,16,16)/-1.1266057d-10, 3.4273059d-11/
      data fxyz(29,16,17),fxyz(29,16,18)/ 1.2497897d-11,-2.7520271d-11/
      data fxyz(29,16,19),fxyz(29,16,20)/ 2.4590650d-11,-1.4413702d-11/
      data fxyz(29,16,21),fxyz(29,16,22)/-1.1076062d-11, 1.1240089d-11/
      data fxyz(29,16,23)/                2.2544331d-11/
      data fxyz(29,17, 1),fxyz(29,17, 2)/ 1.3654487d-11, 9.0200595d-12/
      data fxyz(29,17, 3),fxyz(29,17, 4)/ 3.8840003d-13,-1.8853006d-12/
      data fxyz(29,17, 5),fxyz(29,17, 6)/ 1.8114862d-11,-2.0451022d-11/
      data fxyz(29,17, 7),fxyz(29,17, 8)/ 6.8821358d-12,-2.1963137d-11/
      data fxyz(29,17, 9),fxyz(29,17,10)/ 3.3112730d-11,-3.1645515d-11/
      data fxyz(29,17,11),fxyz(29,17,12)/ 2.9006750d-11,-2.9656159d-11/
      data fxyz(29,17,13),fxyz(29,17,14)/ 2.4450506d-11,-4.8237824d-11/
      data fxyz(29,17,15),fxyz(29,17,16)/ 5.1632127d-11,-2.9554310d-11/
      data fxyz(29,17,17),fxyz(29,17,18)/ 3.8375432d-12, 1.8156971d-11/
      data fxyz(29,17,19),fxyz(29,17,20)/-2.0785114d-11, 1.3358530d-11/
      data fxyz(29,17,21),fxyz(29,17,22)/ 1.0753667d-11,-1.0365661d-11/
      data fxyz(29,17,23)/               -2.0915978d-11/
      data fxyz(29,18, 1),fxyz(29,18, 2)/ 1.6059390d-11, 9.5164918d-12/
      data fxyz(29,18, 3),fxyz(29,18, 4)/-4.0983065d-12,-4.8082789d-12/
      data fxyz(29,18, 5),fxyz(29,18, 6)/ 1.2356381d-11, 5.4098055d-12/
      data fxyz(29,18, 7),fxyz(29,18, 8)/-2.9247816d-12, 9.9582707d-12/
      data fxyz(29,18, 9),fxyz(29,18,10)/-2.0294134d-11, 1.5599752d-11/
      data fxyz(29,18,11),fxyz(29,18,12)/-3.1244063d-11, 1.6287011d-11/
      data fxyz(29,18,13),fxyz(29,18,14)/-1.5028057d-11, 1.3587176d-11/
      data fxyz(29,18,15),fxyz(29,18,16)/-1.9174411d-11, 7.1145412d-12/
      data fxyz(29,18,17),fxyz(29,18,18)/-2.3236639d-12, 1.3712345d-12/
      data fxyz(29,18,19),fxyz(29,18,20)/ 8.5179993d-12, 5.0828363d-12/
      data fxyz(29,18,21),fxyz(29,18,22)/ 5.4981768d-12, 6.8566371d-12/
      data fxyz(29,18,23)/                7.6013428d-12/
      data fxyz(29,19, 1),fxyz(29,19, 2)/ 2.6232407d-11, 1.5173499d-11/
      data fxyz(29,19, 3),fxyz(29,19, 4)/-7.9070093d-12,-8.9870238d-12/
      data fxyz(29,19, 5),fxyz(29,19, 6)/ 1.9493557d-11, 1.0032190d-11/
      data fxyz(29,19, 7),fxyz(29,19, 8)/-3.2383672d-12, 2.2726057d-11/
      data fxyz(29,19, 9),fxyz(29,19,10)/-2.9181058d-11, 1.9463769d-11/
      data fxyz(29,19,11),fxyz(29,19,12)/-4.7835779d-11, 2.0820589d-11/
      data fxyz(29,19,13),fxyz(29,19,14)/-5.3171991d-12,-6.7725311d-12/
      data fxyz(29,19,15),fxyz(29,19,16)/-2.2809740d-11, 1.5070187d-11/
      data fxyz(29,19,17),fxyz(29,19,18)/-9.1989129d-12, 2.4320633d-12/
      data fxyz(29,19,19),fxyz(29,19,20)/ 1.6484291d-11, 7.1065499d-12/
      data fxyz(29,19,21),fxyz(29,19,22)/ 7.9813208d-12, 1.2985207d-11/
      data fxyz(29,19,23)/                1.5553627d-11/
      data fxyz(30, 1, 1),fxyz(30, 1, 2)/ 1.9579836d-10, 2.3555935d-10/
      data fxyz(30, 1, 3),fxyz(30, 1, 4)/ 3.0607591d-10, 3.3177564d-10/
      data fxyz(30, 1, 5),fxyz(30, 1, 6)/ 1.3276042d-10, 5.8129437d-10/
      data fxyz(30, 1, 7),fxyz(30, 1, 8)/-1.1820565d-10,-2.9246001d-10/
      data fxyz(30, 1, 9),fxyz(30, 1,10)/ 3.6218767d-10,-1.0202096d-09/
      data fxyz(30, 1,11),fxyz(30, 1,12)/ 6.3117331d-10,-1.2767550d-09/
      data fxyz(30, 1,13),fxyz(30, 1,14)/-3.0657077d-10,-2.8922604d-10/
      data fxyz(30, 1,15),fxyz(30, 1,16)/ 1.1248968d-10,-5.3726763d-10/
      data fxyz(30, 1,17),fxyz(30, 1,18)/ 4.1322600d-10, 2.5994433d-10/
      data fxyz(30, 1,19),fxyz(30, 1,20)/-8.0244069d-11, 6.3294336d-10/
      data fxyz(30, 1,21),fxyz(30, 1,22)/ 6.0099672d-10, 4.7542489d-11/
      data fxyz(30, 1,23)/               -2.1925526d-10/
      data fxyz(30, 2, 1),fxyz(30, 2, 2)/ 3.6591537d-12, 4.1834287d-11/
      data fxyz(30, 2, 3),fxyz(30, 2, 4)/ 1.1640017d-10, 1.2906663d-10/
      data fxyz(30, 2, 5),fxyz(30, 2, 6)/-8.8315325d-12, 1.9365598d-10/
      data fxyz(30, 2, 7),fxyz(30, 2, 8)/-1.0528277d-10,-1.7472534d-10/
      data fxyz(30, 2, 9),fxyz(30, 2,10)/ 2.0996566d-10,-4.0368118d-10/
      data fxyz(30, 2,11),fxyz(30, 2,12)/ 3.8288103d-10,-4.5369584d-10/
      data fxyz(30, 2,13),fxyz(30, 2,14)/-9.4744765d-11,-7.2432904d-12/
      data fxyz(30, 2,15),fxyz(30, 2,16)/ 4.1170226d-11,-2.1459308d-10/
      data fxyz(30, 2,17),fxyz(30, 2,18)/ 9.1379475d-11, 8.8704403d-11/
      data fxyz(30, 2,19),fxyz(30, 2,20)/-1.0775593d-10, 2.5279334d-10/
      data fxyz(30, 2,21),fxyz(30, 2,22)/ 2.3548084d-10,-3.8505932d-11/
      data fxyz(30, 2,23)/               -1.7098309d-10/
      data fxyz(30, 3, 1),fxyz(30, 3, 2)/-2.8446322d-10,-2.5484411d-10/
      data fxyz(30, 3, 3),fxyz(30, 3, 4)/-1.7775790d-10,-2.0158712d-10/
      data fxyz(30, 3, 5),fxyz(30, 3, 6)/-1.5952721d-10,-6.4190159d-10/
      data fxyz(30, 3, 7),fxyz(30, 3, 8)/-1.2389125d-10, 2.7994933d-10/
      data fxyz(30, 3, 9),fxyz(30, 3,10)/-5.1355574d-10, 9.4191035d-10/
      data fxyz(30, 3,11),fxyz(30, 3,12)/-5.2138423d-10, 1.7734811d-09/
      data fxyz(30, 3,13),fxyz(30, 3,14)/ 2.0192127d-11, 5.7889100d-10/
      data fxyz(30, 3,15),fxyz(30, 3,16)/-2.3921237d-10, 3.5355422d-10/
      data fxyz(30, 3,17),fxyz(30, 3,18)/-6.9478410d-10,-2.9640176d-10/
      data fxyz(30, 3,19),fxyz(30, 3,20)/ 6.3425314d-12,-3.1760470d-10/
      data fxyz(30, 3,21),fxyz(30, 3,22)/-2.9605788d-10,-7.9844747d-11/
      data fxyz(30, 3,23)/                2.6800535d-11/
      data fxyz(30, 4, 1),fxyz(30, 4, 2)/-2.3664453d-10,-1.9118584d-10/
      data fxyz(30, 4, 3),fxyz(30, 4, 4)/-1.0622780d-10,-8.4434297d-11/
      data fxyz(30, 4, 5),fxyz(30, 4, 6)/-2.7835983d-10, 9.0257941d-11/
      data fxyz(30, 4, 7),fxyz(30, 4, 8)/-3.2139985d-11,-4.4466603d-10/
      data fxyz(30, 4, 9),fxyz(30, 4,10)/ 7.6247072d-10,-2.6421896d-10/
      data fxyz(30, 4,11),fxyz(30, 4,12)/ 8.7025594d-10,-9.1375401d-10/
      data fxyz(30, 4,13),fxyz(30, 4,14)/ 4.7424090d-10, 1.0049491d-10/
      data fxyz(30, 4,15),fxyz(30, 4,16)/ 2.1212604d-10, 6.2546889d-11/
      data fxyz(30, 4,17),fxyz(30, 4,18)/ 1.4416199d-10, 6.7023886d-11/
      data fxyz(30, 4,19),fxyz(30, 4,20)/-3.7519514d-10,-2.2213466d-10/
      data fxyz(30, 4,21),fxyz(30, 4,22)/-2.4651665d-10,-2.7766718d-10/
      data fxyz(30, 4,23)/               -2.9870596d-10/
      data fxyz(30, 5, 1),fxyz(30, 5, 2)/ 8.0552976d-10, 3.3058863d-10/
      data fxyz(30, 5, 3),fxyz(30, 5, 4)/-6.5966127d-10,-7.0775317d-10/
      data fxyz(30, 5, 5),fxyz(30, 5, 6)/ 5.2295620d-10, 8.4151366d-11/
      data fxyz(30, 5, 7),fxyz(30, 5, 8)/ 4.4432456d-10, 7.6251335d-10/
      data fxyz(30, 5, 9),fxyz(30, 5,10)/-1.6928610d-10,-3.3718416d-12/
      data fxyz(30, 5,11),fxyz(30, 5,12)/-4.6575980d-10,-3.8144407d-10/
      data fxyz(30, 5,13),fxyz(30, 5,14)/-1.4951971d-10,-3.6368931d-10/
      data fxyz(30, 5,15),fxyz(30, 5,16)/ 5.7039652d-10,-1.9258891d-10/
      data fxyz(30, 5,17),fxyz(30, 5,18)/ 8.5614045d-10,-4.6433933d-12/
      data fxyz(30, 5,19),fxyz(30, 5,20)/ 4.1849426d-11,-3.3998984d-10/
      data fxyz(30, 5,21),fxyz(30, 5,22)/-3.2932443d-10,-8.1218325d-13/
      data fxyz(30, 5,23)/                1.5533764d-10/
      data fxyz(30, 6, 1),fxyz(30, 6, 2)/-9.0438448d-10,-4.8539149d-10/
      data fxyz(30, 6, 3),fxyz(30, 6, 4)/ 3.6009199d-10, 4.5171959d-10/
      data fxyz(30, 6, 5),fxyz(30, 6, 6)/-8.5190188d-10, 4.7002949d-10/
      data fxyz(30, 6, 7),fxyz(30, 6, 8)/ 1.2431496d-10,-5.0416624d-10/
      data fxyz(30, 6, 9),fxyz(30, 6,10)/ 2.1283471d-10,-3.2693972d-10/
      data fxyz(30, 6,11),fxyz(30, 6,12)/ 8.3199857d-11, 3.9109660d-10/
      data fxyz(30, 6,13),fxyz(30, 6,14)/-1.3181806d-10,-1.2737802d-10/
      data fxyz(30, 6,15),fxyz(30, 6,16)/-4.1113087d-10, 4.3821227d-10/
      data fxyz(30, 6,17),fxyz(30, 6,18)/-5.3366126d-10, 2.6820063d-10/
      data fxyz(30, 6,19),fxyz(30, 6,20)/ 1.5457303d-10, 6.5759847d-11/
      data fxyz(30, 6,21),fxyz(30, 6,22)/ 6.2333513d-11, 1.6827837d-10/
      data fxyz(30, 6,23)/                2.1680561d-10/
      data fxyz(30, 7, 1),fxyz(30, 7, 2)/ 1.3184434d-10, 1.9644270d-10/
      data fxyz(30, 7, 3),fxyz(30, 7, 4)/ 3.6280377d-10, 3.1391576d-10/
      data fxyz(30, 7, 5),fxyz(30, 7, 6)/ 3.9199473d-10,-6.0147576d-10/
      data fxyz(30, 7, 7),fxyz(30, 7, 8)/-4.6643496d-10, 4.5505284d-10/
      data fxyz(30, 7, 9),fxyz(30, 7,10)/-9.1077333d-10, 8.4555530d-10/
      data fxyz(30, 7,11),fxyz(30, 7,12)/-4.3273443d-10, 2.3111710d-10/
      data fxyz(30, 7,13),fxyz(30, 7,14)/ 1.0607872d-10, 2.2931967d-10/
      data fxyz(30, 7,15),fxyz(30, 7,16)/-1.5484983d-10,-3.4240399d-10/
      data fxyz(30, 7,17),fxyz(30, 7,18)/-1.4069522d-10,-1.4622931d-10/
      data fxyz(30, 7,19),fxyz(30, 7,20)/-1.1862700d-10, 3.8079118d-10/
      data fxyz(30, 7,21),fxyz(30, 7,22)/ 3.7103835d-10,-7.9615705d-11/
      data fxyz(30, 7,23)/               -2.9252168d-10/
      data fxyz(30, 8, 1),fxyz(30, 8, 2)/ 5.1555959d-10, 2.9155050d-10/
      data fxyz(30, 8, 3),fxyz(30, 8, 4)/-1.8281147d-10,-1.9271214d-10/
      data fxyz(30, 8, 5),fxyz(30, 8, 6)/ 3.3115316d-10, 3.6704959d-10/
      data fxyz(30, 8, 7),fxyz(30, 8, 8)/-2.8649973d-10,-6.0098411d-10/
      data fxyz(30, 8, 9),fxyz(30, 8,10)/ 1.0230549d-09,-9.8898087d-10/
      data fxyz(30, 8,11),fxyz(30, 8,12)/ 6.5709853d-10,-2.2302531d-10/
      data fxyz(30, 8,13),fxyz(30, 8,14)/-3.3756432d-11, 2.1151668d-11/
      data fxyz(30, 8,15),fxyz(30, 8,16)/-7.7463507d-11,-8.9340743d-12/
      data fxyz(30, 8,17),fxyz(30, 8,18)/ 3.0508171d-10,-2.4968120d-10/
      data fxyz(30, 8,19),fxyz(30, 8,20)/-1.5430435d-10, 1.3696640d-10/
      data fxyz(30, 8,21),fxyz(30, 8,22)/ 1.3504158d-10,-1.4660508d-10/
      data fxyz(30, 8,23)/               -2.7855347d-10/
      data fxyz(30, 9, 1),fxyz(30, 9, 2)/-3.3605238d-10,-1.9979235d-10/
      data fxyz(30, 9, 3),fxyz(30, 9, 4)/ 1.0888954d-10, 7.9671365d-11/
      data fxyz(30, 9, 5),fxyz(30, 9, 6)/-8.2919654d-11,-7.7432499d-10/
      data fxyz(30, 9, 7),fxyz(30, 9, 8)/ 1.0726926d-09, 2.1568178d-10/
      data fxyz(30, 9, 9),fxyz(30, 9,10)/-6.5611949d-10, 3.7628797d-10/
      data fxyz(30, 9,11),fxyz(30, 9,12)/-1.0330180d-10,-4.9178876d-10/
      data fxyz(30, 9,13),fxyz(30, 9,14)/ 2.2907363d-10,-2.6835338d-10/
      data fxyz(30, 9,15),fxyz(30, 9,16)/ 4.5737712d-10,-4.2275776d-11/
      data fxyz(30, 9,17),fxyz(30, 9,18)/-3.1048955d-10, 1.7708546d-10/
      data fxyz(30, 9,19),fxyz(30, 9,20)/ 5.7151083d-10,-3.4157700d-10/
      data fxyz(30, 9,21),fxyz(30, 9,22)/-3.0262764d-10, 4.1571342d-10/
      data fxyz(30, 9,23)/                7.6132575d-10/
      data fxyz(30,10, 1),fxyz(30,10, 2)/-1.3434624d-10,-7.6243142d-11/
      data fxyz(30,10, 3),fxyz(30,10, 4)/-7.0500051d-12, 8.9748638d-11/
      data fxyz(30,10, 5),fxyz(30,10, 6)/-4.6343772d-10, 1.3176334d-09/
      data fxyz(30,10, 7),fxyz(30,10, 8)/-1.5218606d-09, 2.6879978d-10/
      data fxyz(30,10, 9),fxyz(30,10,10)/ 4.0981934d-10, 7.8239089d-11/
      data fxyz(30,10,11),fxyz(30,10,12)/-4.9806891d-10, 8.5125603d-10/
      data fxyz(30,10,13),fxyz(30,10,14)/-6.8743796d-10, 3.0501295d-10/
      data fxyz(30,10,15),fxyz(30,10,16)/-5.8959113d-10, 3.0122940d-10/
      data fxyz(30,10,17),fxyz(30,10,18)/ 1.1891314d-10, 8.9012599d-11/
      data fxyz(30,10,19),fxyz(30,10,20)/-3.8803094d-10, 2.1208946d-10/
      data fxyz(30,10,21),fxyz(30,10,22)/ 1.7615118d-10,-2.4427782d-10/
      data fxyz(30,10,23)/               -4.5006157d-10/
      data fxyz(30,11, 1),fxyz(30,11, 2)/ 3.8767369d-11, 3.5852083d-11/
      data fxyz(30,11, 3),fxyz(30,11, 4)/ 6.7266662d-11, 1.3588286d-12/
      data fxyz(30,11, 5),fxyz(30,11, 6)/ 2.9948342d-10,-9.4985014d-10/
      data fxyz(30,11, 7),fxyz(30,11, 8)/ 1.3004229d-09,-4.9088332d-10/
      data fxyz(30,11, 9),fxyz(30,11,10)/-3.8765841d-10,-1.3707729d-10/
      data fxyz(30,11,11),fxyz(30,11,12)/ 6.3836695d-10,-9.1255646d-10/
      data fxyz(30,11,13),fxyz(30,11,14)/ 9.9638981d-10,-5.7774546d-10/
      data fxyz(30,11,15),fxyz(30,11,16)/ 6.4199519d-10,-6.2212268d-10/
      data fxyz(30,11,17),fxyz(30,11,18)/ 4.2265477d-10,-3.6186260d-10/
      data fxyz(30,11,19),fxyz(30,11,20)/ 2.0520016d-10,-6.6495376d-11/
      data fxyz(30,11,21),fxyz(30,11,22)/-3.3559267d-11, 7.3455728d-11/
      data fxyz(30,11,23)/                1.3217902d-10/
      data fxyz(30,12, 1),fxyz(30,12, 2)/ 4.2157145d-10, 2.2673927d-10/
      data fxyz(30,12, 3),fxyz(30,12, 4)/-1.9105927d-10,-1.9053248d-10/
      data fxyz(30,12, 5),fxyz(30,12, 6)/ 2.2463212d-10, 4.2947327d-10/
      data fxyz(30,12, 7),fxyz(30,12, 8)/-6.5415792d-10, 3.2124787d-10/
      data fxyz(30,12, 9),fxyz(30,12,10)/ 1.8837108d-11, 5.7131830d-11/
      data fxyz(30,12,11),fxyz(30,12,12)/-3.6444884d-10, 6.5863865d-10/
      data fxyz(30,12,13),fxyz(30,12,14)/-9.1605416d-10, 8.6922560d-10/
      data fxyz(30,12,15),fxyz(30,12,16)/-5.7143672d-10, 5.7309794d-10/
      data fxyz(30,12,17),fxyz(30,12,18)/-6.9141593d-10, 4.6485830d-10/
      data fxyz(30,12,19),fxyz(30,12,20)/-8.9643557d-11,-2.3164405d-11/
      data fxyz(30,12,21),fxyz(30,12,22)/-5.0958335d-11, 2.1532164d-11/
      data fxyz(30,12,23)/                4.7949349d-11/
      data fxyz(30,13, 1),fxyz(30,13, 2)/-4.6514422d-10,-2.4412566d-10/
      data fxyz(30,13, 3),fxyz(30,13, 4)/ 2.1407851d-10, 2.4104082d-10/
      data fxyz(30,13, 5),fxyz(30,13, 6)/-3.5197489d-10,-6.0709603d-11/
      data fxyz(30,13, 7),fxyz(30,13, 8)/ 5.2595781d-11,-1.3041911d-10/
      data fxyz(30,13, 9),fxyz(30,13,10)/ 2.3488467d-10, 7.1483035d-11/
      data fxyz(30,13,11),fxyz(30,13,12)/-4.1687539d-10, 2.3167587d-10/
      data fxyz(30,13,13),fxyz(30,13,14)/ 4.2623321d-10,-7.2561068d-10/
      data fxyz(30,13,15),fxyz(30,13,16)/ 3.8188736d-10,-2.8930755d-10/
      data fxyz(30,13,17),fxyz(30,13,18)/ 4.6218262d-10,-2.1138049d-10/
      data fxyz(30,13,19),fxyz(30,13,20)/-2.2042396d-10, 1.3061365d-10/
      data fxyz(30,13,21),fxyz(30,13,22)/ 1.2240822d-10,-1.8760225d-10/
      data fxyz(30,13,23)/               -3.3446191d-10/
      data fxyz(30,14, 1),fxyz(30,14, 2)/ 3.2036705d-10, 1.7473349d-10/
      data fxyz(30,14, 3),fxyz(30,14, 4)/-1.1170125d-10,-1.5656633d-10/
      data fxyz(30,14, 5),fxyz(30,14, 6)/ 3.5419377d-10,-3.5260901d-10/
      data fxyz(30,14, 7),fxyz(30,14, 8)/ 2.2562919d-10, 1.5630385d-10/
      data fxyz(30,14, 9),fxyz(30,14,10)/-2.1558525d-10,-9.6896102d-11/
      data fxyz(30,14,11),fxyz(30,14,12)/ 6.7184087d-10,-7.6134257d-10/
      data fxyz(30,14,13),fxyz(30,14,14)/-6.3071275d-11, 5.7055939d-10/
      data fxyz(30,14,15),fxyz(30,14,16)/-3.8634308d-10, 2.3389734d-10/
      data fxyz(30,14,17),fxyz(30,14,18)/-2.4993279d-10,-5.1914465d-11/
      data fxyz(30,14,19),fxyz(30,14,20)/ 4.5691169d-10,-1.8971521d-10/
      data fxyz(30,14,21),fxyz(30,14,22)/-1.5123805d-10, 3.0300307d-10/
      data fxyz(30,14,23)/                5.2524284d-10/
      data fxyz(30,15, 1),fxyz(30,15, 2)/ 1.9353030d-10, 1.0554074d-10/
      data fxyz(30,15, 3),fxyz(30,15, 4)/-9.0842102d-11,-7.7133010d-11/
      data fxyz(30,15, 5),fxyz(30,15, 6)/ 5.0704368d-11, 3.9916668d-10/
      data fxyz(30,15, 7),fxyz(30,15, 8)/-3.2509487d-10, 1.4730537d-11/
      data fxyz(30,15, 9),fxyz(30,15,10)/-5.6580060d-11, 5.6018754d-11/
      data fxyz(30,15,11),fxyz(30,15,12)/-2.6609003d-10, 4.1443729d-10/
      data fxyz(30,15,13),fxyz(30,15,14)/ 5.9750949d-11,-5.2735193d-10/
      data fxyz(30,15,15),fxyz(30,15,16)/ 3.6659751d-10,-8.0048836d-11/
      data fxyz(30,15,17),fxyz(30,15,18)/-5.2844918d-12, 2.0486637d-10/
      data fxyz(30,15,19),fxyz(30,15,20)/-5.4487738d-10, 2.5137794d-10/
      data fxyz(30,15,21),fxyz(30,15,22)/ 1.9815027d-10,-3.3196671d-10/
      data fxyz(30,15,23)/               -5.9354867d-10/
      data fxyz(30,16, 1),fxyz(30,16, 2)/-2.3148460d-10,-1.3775204d-10/
      data fxyz(30,16, 3),fxyz(30,16, 4)/ 7.0384553d-11, 5.7642601d-11/
      data fxyz(30,16, 5),fxyz(30,16, 6)/-8.6784232d-11,-4.2261389d-10/
      data fxyz(30,16, 7),fxyz(30,16, 8)/ 6.0740381d-10,-4.5633643d-10/
      data fxyz(30,16, 9),fxyz(30,16,10)/ 5.2639662d-10,-1.4933864d-10/
      data fxyz(30,16,11),fxyz(30,16,12)/ 1.0728428d-11,-1.4934904d-10/
      data fxyz(30,16,13),fxyz(30,16,14)/-1.6936135d-12, 1.1043928d-10/
      data fxyz(30,16,15),fxyz(30,16,16)/-6.0785323d-11,-1.7013813d-10/
      data fxyz(30,16,17),fxyz(30,16,18)/ 1.3929926d-10,-1.4950182d-10/
      data fxyz(30,16,19),fxyz(30,16,20)/ 4.2305178d-10,-1.8335088d-10/
      data fxyz(30,16,21),fxyz(30,16,22)/-1.4273973d-10, 2.6060719d-10/
      data fxyz(30,16,23)/                4.5966539d-10/
      data fxyz(30,17, 1),fxyz(30,17, 2)/-1.0164325d-10,-6.1743219d-11/
      data fxyz(30,17, 3),fxyz(30,17, 4)/ 9.1315795d-13, 4.0889614d-11/
      data fxyz(30,17, 5),fxyz(30,17, 6)/-2.2164904d-10, 4.9800359d-10/
      data fxyz(30,17, 7),fxyz(30,17, 8)/-5.8650673d-10, 6.1749524d-10/
      data fxyz(30,17, 9),fxyz(30,17,10)/-6.6054132d-10, 3.6445983d-10/
      data fxyz(30,17,11),fxyz(30,17,12)/-2.5170635d-10, 4.4173888d-10/
      data fxyz(30,17,13),fxyz(30,17,14)/-4.4158507d-10, 4.6271858d-10/
      data fxyz(30,17,15),fxyz(30,17,16)/-3.6373906d-10, 2.6235528d-10/
      data fxyz(30,17,17),fxyz(30,17,18)/-1.7180761d-10, 1.3668704d-10/
      data fxyz(30,17,19),fxyz(30,17,20)/-2.2793194d-10, 6.7969313d-11/
      data fxyz(30,17,21),fxyz(30,17,22)/ 4.4106675d-11,-1.3248139d-10/
      data fxyz(30,17,23)/               -2.2125252d-10/
      data fxyz(30,18, 1),fxyz(30,18, 2)/-4.0461965d-11,-1.4003648d-11/
      data fxyz(30,18, 3),fxyz(30,18, 4)/ 4.7932005d-11, 3.8763302d-11/
      data fxyz(30,18, 5),fxyz(30,18, 6)/ 2.2671166d-11,-1.7799252d-10/
      data fxyz(30,18, 7),fxyz(30,18, 8)/ 2.0863349d-10,-2.6866994d-10/
      data fxyz(30,18, 9),fxyz(30,18,10)/ 3.3388087d-10,-3.3424741d-10/
      data fxyz(30,18,11),fxyz(30,18,12)/ 4.3700396d-10,-5.2443396d-10/
      data fxyz(30,18,13),fxyz(30,18,14)/ 4.5255666d-10,-3.7026544d-10/
      data fxyz(30,18,15),fxyz(30,18,16)/ 2.7997032d-10,-1.7532810d-10/
      data fxyz(30,18,17),fxyz(30,18,18)/ 1.5143328d-10,-1.9908296d-10/
      data fxyz(30,18,19),fxyz(30,18,20)/ 1.7381640d-10,-5.2478850d-11/
      data fxyz(30,18,21),fxyz(30,18,22)/-2.9765062d-11, 8.2961246d-11/
      data fxyz(30,18,23)/                1.4162387d-10/
      data fxyz(30,19, 1),fxyz(30,19, 2)/ 4.0336481d-11, 4.1812852d-11/
      data fxyz(30,19, 3),fxyz(30,19, 4)/ 6.1667926d-11, 3.2457939d-11/
      data fxyz(30,19, 5),fxyz(30,19, 6)/ 1.5865280d-10,-3.9781331d-10/
      data fxyz(30,19, 7),fxyz(30,19, 8)/ 4.3547349d-10,-5.9483601d-10/
      data fxyz(30,19, 9),fxyz(30,19,10)/ 7.0505730d-10,-6.8652444d-10/
      data fxyz(30,19,11),fxyz(30,19,12)/ 8.5395853d-10,-1.0456752d-09/
      data fxyz(30,19,13),fxyz(30,19,14)/ 9.6554606d-10,-8.6460280d-10/
      data fxyz(30,19,15),fxyz(30,19,16)/ 6.5320453d-10,-3.6438954d-10/
      data fxyz(30,19,17),fxyz(30,19,18)/ 2.9343196d-10,-3.5715042d-10/
      data fxyz(30,19,19),fxyz(30,19,20)/ 2.7478415d-10,-6.6707483d-11/
      data fxyz(30,19,21),fxyz(30,19,22)/-2.9145900d-11, 1.2453782d-10/
      data fxyz(30,19,23)/                2.0627331d-10/
 
      data x( 1), x( 2) /  3.40000000d+00 ,  3.50000000d+00 /
      data x( 3), x( 4) /  3.60000000d+00 ,  3.70000000d+00 /
      data x( 5), x( 6) /  3.80000000d+00 ,  3.90000000d+00 /
      data x( 7), x( 8) /  4.00000000d+00 ,  4.10000000d+00 /
      data x( 9), x(10) /  4.20000000d+00 ,  4.30000000d+00 /
      data x(11), x(12) /  4.40000000d+00 ,  4.50000000d+00 /
      data x(13), x(14) /  4.60000000d+00 ,  4.70000000d+00 /
      data x(15), x(16) /  4.80000000d+00 ,  4.90000000d+00 /
      data x(17), x(18) /  5.00000000d+00 ,  5.20000000d+00 /
      data x(19), x(20) /  5.50000000d+00 ,  5.80000000d+00 /
      data x(21), x(22) /  6.00000000d+00 ,  6.50000000d+00 /
      data x(23), x(24) /  7.00000000d+00 ,  7.50000000d+00 /
      data x(25), x(26) /  8.50000000d+00 ,  9.00000000d+00 /
      data x(27), x(28) /  1.00000000d+01 ,  1.10000000d+01 /
      data x(29), x(30) /  1.20000000d+01 ,  1.50000000d+01 /
 
      data y( 1), y( 2) /  0.00000000d+00 ,  1.00000000d+01 /
      data y( 3), y( 4) /  2.00000000d+01 ,  3.00000000d+01 /
      data y( 5), y( 6) /  4.00000000d+01 ,  5.00000000d+01 /
      data y( 7), y( 8) /  6.00000000d+01 ,  7.00000000d+01 /
      data y( 9), y(10) /  8.00000000d+01 ,  9.00000000d+01 /
      data y(11), y(12) /  1.00000000d+02 ,  1.10000000d+02 /
      data y(13), y(14) /  1.20000000d+02 ,  1.30000000d+02 /
      data y(15), y(16) /  1.40000000d+02 ,  1.50000000d+02 /
      data y(17), y(18) /  1.60000000d+02 ,  1.70000000d+02 /
      data y(19) /         1.80000000d+02 /
 
      data z( 1), z( 2) / -3.00000000d+01 , -2.00000000d+01 /
      data z( 3), z( 4) / -1.00000000d+01 ,  1.00000000d+01 /
      data z( 5), z( 6) /  2.00000000d+01 ,  3.00000000d+01 /
      data z( 7), z( 8) /  4.00000000d+01 ,  5.00000000d+01 /
      data z( 9), z(10) /  6.00000000d+01 ,  7.00000000d+01 /
      data z(11), z(12) /  8.00000000d+01 ,  9.00000000d+01 /
      data z(13), z(14) /  1.00000000d+02 ,  1.10000000d+02 /
      data z(15), z(16) /  1.20000000d+02 ,  1.30000000d+02 /
      data z(17), z(18) /  1.40000000d+02 ,  1.50000000d+02 /
      data z(19), z(20) /  1.60000000d+02 ,  1.70000000d+02 /
      data z(21), z(22) /  1.90000000d+02 ,  2.00000000d+02 /
      data z(23) /         2.10000000d+02 /
 
      data delx( 1), delx( 2) /  1.00000000d-01 ,  1.00000000d-01 /
      data delx( 3), delx( 4) /  1.00000000d-01 ,  1.00000000d-01 /
      data delx( 5), delx( 6) /  1.00000000d-01 ,  1.00000000d-01 /
      data delx( 7), delx( 8) /  1.00000000d-01 ,  1.00000000d-01 /
      data delx( 9), delx(10) /  1.00000000d-01 ,  1.00000000d-01 /
      data delx(11), delx(12) /  1.00000000d-01 ,  1.00000000d-01 /
      data delx(13), delx(14) /  1.00000000d-01 ,  1.00000000d-01 /
      data delx(15), delx(16) /  1.00000000d-01 ,  1.00000000d-01 /
      data delx(17), delx(18) /  2.00000000d-01 ,  3.00000000d-01 /
      data delx(19), delx(20) /  3.00000000d-01 ,  2.00000000d-01 /
      data delx(21), delx(22) /  5.00000000d-01 ,  5.00000000d-01 /
      data delx(23), delx(24) /  5.00000000d-01 ,  1.00000000d+00 /
      data delx(25), delx(26) /  5.00000000d-01 ,  1.00000000d+00 /
      data delx(27), delx(28) /  1.00000000d+00 ,  1.00000000d+00 /
      data delx(29) /            3.00000000d+00 /
      data dely( 1), dely( 2) /  1.00000000d+01 ,  1.00000000d+01 /
      data dely( 3), dely( 4) /  1.00000000d+01 ,  1.00000000d+01 /
      data dely( 5), dely( 6) /  1.00000000d+01 ,  1.00000000d+01 /
      data dely( 7), dely( 8) /  1.00000000d+01 ,  1.00000000d+01 /
      data dely( 9), dely(10) /  1.00000000d+01 ,  1.00000000d+01 /
      data dely(11), dely(12) /  1.00000000d+01 ,  1.00000000d+01 /
      data dely(13), dely(14) /  1.00000000d+01 ,  1.00000000d+01 /
      data dely(15), dely(16) /  1.00000000d+01 ,  1.00000000d+01 /
      data dely(17), dely(18) /  1.00000000d+01 ,  1.00000000d+01 /
      data delz( 1), delz( 2) /  1.00000000d+01 ,  1.00000000d+01 /
      data delz( 3), delz( 4) /  2.00000000d+01 ,  1.00000000d+01 /
      data delz( 5), delz( 6) /  1.00000000d+01 ,  1.00000000d+01 /
      data delz( 7), delz( 8) /  1.00000000d+01 ,  1.00000000d+01 /
      data delz( 9), delz(10) /  1.00000000d+01 ,  1.00000000d+01 /
      data delz(11), delz(12) /  1.00000000d+01 ,  1.00000000d+01 /
      data delz(13), delz(14) /  1.00000000d+01 ,  1.00000000d+01 /
      data delz(15), delz(16) /  1.00000000d+01 ,  1.00000000d+01 /
      data delz(17), delz(18) /  1.00000000d+01 ,  1.00000000d+01 /
      data delz(19), delz(20) /  1.00000000d+01 ,  2.00000000d+01 /
      data delz(21), delz(22) /  1.00000000d+01 ,  1.00000000d+01 /
      data nptx,npty,nptz /  30 , 19 , 23 /
      data jprint / 0 /
c
      if(xi .le. x(1)) then
        ix=1
      else if( xi .ge. x(nptx)) then
        ix=nptx-1
      else
        call hunt(x,nptx,xi,ix)
      endif
 15   xix=x(ix)
      xixp1=x(ix+1)
      delxi = delx(ix)
      if(jprint .ne. 0)
     x  write(6,'(2x,a,3f10.5)') 'xix, xixp1, delxi', xix,xixp1,delxi
c
      if(yi .le. y(1)) then
        iy=1
      else if( yi .ge. y(npty)) then
        iy=npty-1
      else
        call hunt(y,npty,yi,iy)
      endif
 25   yiy=y(iy)
      yiyp1=y(iy+1)
      delyi = dely(iy)
      if(jprint .ne. 0)
     x  write(6,'(2x,a,3f10.5)') 'yiy, yiyp1, delyi', yiy,yiyp1,delyi
c
      if(zi .le. z(1)) then
        iz=1
      else if( zi .ge. z(nptz)) then
        iz=nptz-1
      else
        call hunt(z,nptz,zi,iz)
      endif
 35   ziz=z(iz)
      zizp1=z(iz+1)
      delzi = delz(iz)
      if(jprint .ne. 0)
     x  write(6,'(2x,a,3f10.5)') 'ziz, zizp1, delzi', ziz,zizp1,delzi

   40 continue
      c(1,1,1) = fxyz(ix+1,iy+1,iz+1)
      c(1,1,2) = fxyz(ix,  iy+1,iz+1)
      c(1,2,1) = fxyz(ix+1,iy,  iz+1)
      c(1,2,2) = fxyz(ix,  iy,  iz+1)
      c(1,3,1) = fpppp(ix+1,iy+1,iz+1,2)
      c(1,3,2) = fpppp(ix,  iy+1,iz+1,2)
      c(1,4,1) = fpppp(ix+1,iy,  iz+1,2)
      c(1,4,2) = fpppp(ix,  iy,  iz+1,2)
      c(1,1,3) = fpppp(ix+1,iy+1,iz+1,3)
      c(1,1,4) = fpppp(ix,  iy+1,iz+1,3)
      c(1,2,3) = fpppp(ix+1,iy,  iz+1,3)
      c(1,2,4) = fpppp(ix,  iy,  iz+1,3)
      c(1,3,3) = fpp(ix+1,iy+1,iz+1,3)
      c(1,3,4) = fpp(ix,  iy+1,iz+1,3)
      c(1,4,3) = fpp(ix+1,iy,  iz+1,3)
      c(1,4,4) = fpp(ix,  iy,  iz+1,3)
c
      c(2,1,1) = fxyz(ix+1,iy+1,iz)
      c(2,1,2) = fxyz(ix,  iy+1,iz)
      c(2,2,1) = fxyz(ix+1,iy,  iz)
      c(2,2,2) = fxyz(ix,  iy,  iz)
      c(2,3,1) = fpppp(ix+1,iy+1,iz, 2)
      c(2,3,2) = fpppp(ix,  iy+1,iz, 2)
      c(2,4,1) = fpppp(ix+1,iy,  iz, 2)
      c(2,4,2) = fpppp(ix,  iy,  iz, 2)
      c(2,1,3) = fpppp(ix+1,iy+1,iz, 3)
      c(2,1,4) = fpppp(ix,  iy+1,iz, 3)
      c(2,2,3) = fpppp(ix+1,iy,  iz, 3)
      c(2,2,4) = fpppp(ix,  iy,  iz, 3)
      c(2,3,3) = fpp(ix+1,iy+1,iz, 3)
      c(2,3,4) = fpp(ix,  iy+1,iz, 3)
      c(2,4,3) = fpp(ix+1,iy,  iz, 3)
      c(2,4,4) = fpp(ix,  iy,  iz, 3)
c
      c(3,1,1) = fpppp(ix+1,iy+1,iz+1,1)
      c(3,1,2) = fpppp(ix  ,iy+1,iz+1,1)
      c(3,2,1) = fpppp(ix+1,iy  ,iz+1,1)
      c(3,2,2) = fpppp(ix,  iy,  iz+1,1)
      c(3,3,1) = fpp(ix+1,iy+1,iz+1,1)
      c(3,3,2) = fpp(ix,  iy+1,iz+1,1)
      c(3,4,1) = fpp(ix+1,iy,  iz+1,1)
      c(3,4,2) = fpp(ix,  iy,  iz+1,1)
      c(3,1,3) = fpp(ix+1,iy+1,iz+1,2)
      c(3,1,4) = fpp(ix,  iy+1,iz+1,2)
      c(3,2,3) = fpp(ix+1,iy,  iz+1,2)
      c(3,2,4) = fpp(ix,  iy,  iz+1,2)
      c(3,3,3) = f(ix+1,iy+1,iz+1)
      c(3,3,4) = f(ix,  iy+1,iz+1)
      c(3,4,3) = f(ix+1,iy,  iz+1)
      c(3,4,4) = f(ix,  iy,  iz+1)
c
      c(4,1,1) = fpppp(ix+1,iy+1,iz,1)
      c(4,1,2) = fpppp(ix  ,iy+1,iz,1)
      c(4,2,1) = fpppp(ix+1,iy  ,iz,1)
      c(4,2,2) = fpppp(ix,  iy,  iz,1)
      c(4,3,1) = fpp(ix+1,iy+1,iz,1)
      c(4,3,2) = fpp(ix,  iy+1,iz,1)
      c(4,4,1) = fpp(ix+1,iy,  iz,1)
      c(4,4,2) = fpp(ix,  iy,  iz,1)
      c(4,1,3) = fpp(ix+1,iy+1,iz,2)
      c(4,1,4) = fpp(ix,  iy+1,iz,2)
      c(4,2,3) = fpp(ix+1,iy,  iz,2)
      c(4,2,4) = fpp(ix,  iy,  iz,2)
      c(4,3,3) = f(ix+1,iy+1,iz)
      c(4,3,4) = f(ix,  iy+1,iz)
      c(4,4,3) = f(ix+1,iy,  iz)
      c(4,4,4) = f(ix,  iy,  iz)

c      if(jprint .ne. 0) then
c       write(6,'(2x,a)') 'c(i,j,1) :'
c       call mwrita(c(1,1,1),4,4,6)
c       write(6,'(2x,a)') 'c(i,j,2) :'
c       call mwrita(c(1,1,2),4,4,6)
c       write(6,'(2x,a)') 'c(i,j,3) :'
c       call mwrita(c(1,1,3),4,4,6)
c       write(6,'(2x,a)') 'c(i,j,4) :'
c       call mwrita(c(1,1,4),4,4,6)
c      endif
c
      px(1)=((xi-xix)**3/(6.0d0*delxi))-(xi-xix)*delxi/6.0d0
      px(2)=(xi-xixp1)*delxi/6.0d0-((xi-xixp1)**3/(6.0d0*delxi))
      px(3)=(xi-xix)/delxi
      px(4)=(xixp1-xi)/delxi
c      if(jprint .ne. 0 ) write(6,'(2x,a,4f10.5)') ' px : ',px
c
      py(1)=((yi-yiy)**3/(6.0d0*delyi))-(yi-yiy)*delyi/6.0d0
      py(2)=(yi-yiyp1)*delyi/6.0d0-((yi-yiyp1)**3/(6.0d0*delyi))
      py(3)=(yi-yiy)/delyi
      py(4)=(yiyp1-yi)/delyi
c      if(jprint .ne. 0 ) write(6,'(2x,a,4f10.5)') ' py : ',py
c
      pz(1)=((zi-ziz)**3/(6.0d0*delzi))-(zi-ziz)*delzi/6.0d0
      pz(2)=(zi-zizp1)*delzi/6.0d0-((zi-zizp1)**3/(6.0d0*delzi))
      pz(3)=(zi-ziz)/delzi
      pz(4)=(zizp1-zi)/delzi
c      if(jprint .ne. 0 ) write(6,'(2x,a,4f10.5)') ' pz : ',pz
c
c      dpx(1)=((xi-xix)**2/(2.0d0*delxi))-(delxi/6.0d0)
c      dpx(2)=(delxi/6.0d0)-((xi-xixp1)**2/(2.0d0*delxi))
c      dpx(3)=1.0d0/delxi
c      dpx(4)=-1.0d0/delxi
c
c      dpy(1)=((yi-yiy)**2/(2.0d0*delyi))-(delyi/6.0d0)
c      dpy(2)=(delyi/6.0d0)-((yi-yiyp1)**2/(2.0d0*delyi))
c      dpy(3)=1.0d0/delyi
c      dpy(4)=-1.0d0/delyi
c
c      dpz(1)=((zi-ziz)**2/(2.0d0*delzi))-(delzi/6.0d0)
c      dpz(2)=(delzi/6.0d0)-((zi-zizp1)**2/(2.0d0*delzi))
c      dpz(3)=1.0d0/delzi
c      dpz(4)=-1.0d0/delzi
c
      call seval(c,px,py,pz,fi)
c      call seval(c,dpx,py,pz,dfx)
c      call seval(c,px,dpy,pz,dfy)
c      call seval(c,px,py,dpz,dfz)
c
      return
      end
