
      real*8 function c2h5_h(r, rpar, ipar)

      implicit double precision (a-h,o-z)
c
c     sample main for calling h+ch3ch2 3d potential
c
c     ch3ch2 geometry: 
c
c                 Hlm           Hi
c                  \           /
c                   Cb---M---Ca      M - CC bond midpoint
c                              \
c                               Hjk
c
c                      r(CC)   = 2.85 au
c                  CH3 r(CH)   = 2.10
c                  CH2 r(CH)   = 2.05
c                  CH3 hch     = 110.0
c                  CH2 hch     = 120.0
c                  Hi-Ca-Cb-Hj =  120.0
c                  Hi-Ca-Cb-Hk = -120.0
c                  Hl-Cb-Ca-Hi =   80.0
c                  Hm-Cb-Ca-Hi =  -80.0
c
c     input coordinates:
c                   r = r(M-Ha)
c                   a = angle between M-Ha and M-Ca
c                   d = dihedral angle Ha-M-Ca plane and M-Ca-Hi plane
c
c     limits:    4.0 < r < 15.0
c                  0 < a < 180
c                  0 < d < 360 
c
c     output:   e = energy relative to h+ch3ch2 in au
c
c     call atz_dci(r,a,d,e,dr,da,dd)

      parameter (nfrag=2, natommx=100, ndim = 3)

      dimension r(nfrag,natommx,ndim)
      dimension r12(ndim),r23(ndim),r34(ndim),tmp1(ndim),tmp2(ndim)
      dimension r25(ndim),r35(ndim),rhp(ndim),r12p(ndim)

      include 'data.fi'

      pi2 = asin(1.0d0)
      pi = 2.0d0*pi2

c
c     read in the initial parameters
c


  100 continue

      pi = 2.0d0*asin(1.0d0)
      r122 = 0.0d0
      r232 = 0.0d0
      r342 = 0.0d0
 
      do 1100 idim = 1 , ndim
 
      r12(idim) = r(1,1,idim) - r(2,1,idim)
      r23(idim) = r(1,2,idim) - r(1,1,idim)
      r34(idim) = r(1,3,idim) - r(1,2,idim)
      r122 = r122 + r12(idim)**2
      r232 = r232 + r23(idim)**2
      r342 = r342 + r34(idim)**2
 
1100  continue
 
      rr = sqrt(r122)
      rmepi = rr
      rcc = sqrt(r232)
      r340 = sqrt(r342)
      ra = sqrt(r122)
      rd = sqrt((r(2,1,1)-r(1,1,1))**2 + (r(2,1,2)-r(1,1,2))**2 +
     $ (r(2,1,3)-r(1,1,3))**2)
      rp = sqrt((r(1,2,1)-r(2,1,1))**2 + (r(1,2,2)-r(2,1,2))**2 +
     $ (r(1,2,3)-r(2,1,3))**2)
      rpp = sqrt((r(1,3,1)-r(1,1,1))**2 + (r(1,3,2)-r(1,1,2))**2 +
     $ (r(1,3,3)-r(1,1,3))**2)
      cthe = (rr**2 + rcc**2 - rp**2)/(2.0d0*rr*rcc)
      cthep = (r342 + rcc**2 - rpp**2)/(2.0d0*r340*rcc)
      if (abs(cthe).gt.1.0d0) write (7,*) 'error in cthe',cthe
      if (abs(cthep).gt.1.0d0) write (7,*) 'error in cthep',cthep
      the = acos(cthe)
      thep = acos(cthep)
      call cross(r12,r23,tmp1)
      call cross(r23,r34,tmp2)
      tdot = 0.0d0
      do 1200 idim = 1 , ndim
      tdot = tdot + tmp1(idim)*tmp2(idim)
1200  continue
      rdenom = r232*sqrt(r122*r342)
      ctau = tdot/(rdenom*sin(acos(cthe))*sin(acos(cthep)))
      if (abs(ctau).gt.1.0d0) write (7,*) 'error in ctau',ctau
      tau = acos(ctau)
      if (rd.lt.4.0) rd = 4.0
      if (rd.gt.15.0) rd = 15.0
      theta = the*180.0d0/pi
      phi = tau*180.0d0/pi
c ipar = 0 => both sides
      if (ipar.eq.0) call atz_dci(rd,theta,phi,vtot,dr,dt,dp)
c ipar = 1 => front side
      if (ipar.eq.1) then
         if (abs(phi).lt.90.0d0) then
            vtot=1.0d20
         else
            if (theta.lt.80.0d0) then
               vtot=1.0d20
            else
               call atz_dci(rd,theta,phi,vtot,dr,dt,dp)
            endif
         endif
      endif
c ipar = 2 => back side
      if (ipar.eq.2) then
         if (abs(phi).gt.90.0d0) then
            vtot=1.0d20
         else
            if (theta.lt.80.0d0) then
               vtot=1.0d20
            else
               call atz_dci(rd,theta,phi,vtot,dr,dt,dp)
            endif
         endif
      endif
c ipar = 3 => abstraction
      if (ipar.eq.3) then
         if (theta.gt.80.0d0) then
            vtot=1.0d20
         else
            call atz_dci(rd,theta,phi,vtot,dr,dt,dp)
         endif
      endif

      c2h5_h = vtot

      return
      end



      SUBROUTINE atz_dci(xi,yi,zi,FI,DFX,DFY,DFZ)
      IMPLICIT REAL*8 (A-H,O-Z)
      dimension fpp(13,19,17,3),f(13,19,17),fpppp(13,19,17,3)
      dimension fxyz(13,19,17)
      dimension delx(12),dely(18),delz(16),x(13),y(19),z(17)
      dimension c(4,4,4),px(4),py(4),pz(4)
      dimension dpx(4),dpy(4),dpz(4)
 
      data f( 1, 1, 1),f( 1, 1, 2) /  7.6423700D-02 ,  7.6423700D-02 /
      data f( 1, 1, 3),f( 1, 1, 4) /  7.6423700D-02 ,  7.6423700D-02 /
      data f( 1, 1, 5),f( 1, 1, 6) /  7.6423700D-02 ,  7.6423700D-02 /
      data f( 1, 1, 7),f( 1, 1, 8) /  7.6423700D-02 ,  7.6423700D-02 /
      data f( 1, 1, 9),f( 1, 1,10) /  7.6423700D-02 ,  7.6423700D-02 /
      data f( 1, 1,11),f( 1, 1,12) /  7.6423700D-02 ,  7.6423700D-02 /
      data f( 1, 1,13),f( 1, 1,14) /  7.6423700D-02 ,  7.6423700D-02 /
      data f( 1, 1,15),f( 1, 1,16) /  7.6423700D-02 ,  7.6423700D-02 /
      data f( 1, 1,17) /              7.6423700D-02 /
      data f( 1, 2, 1),f( 1, 2, 2) /  7.2861200D-02 ,  6.5803600D-02 /
      data f( 1, 2, 3),f( 1, 2, 4) /  6.2638900D-02 ,  6.5803600D-02 /
      data f( 1, 2, 5),f( 1, 2, 6) /  7.2861200D-02 ,  7.8200100D-02 /
      data f( 1, 2, 7),f( 1, 2, 8) /  7.8338400D-02 ,  7.5666200D-02 /
      data f( 1, 2, 9),f( 1, 2,10) /  7.4252300D-02 ,  7.5666200D-02 /
      data f( 1, 2,11),f( 1, 2,12) /  7.8338400D-02 ,  7.8200100D-02 /
      data f( 1, 2,13),f( 1, 2,14) /  7.2861200D-02 ,  6.5803600D-02 /
      data f( 1, 2,15),f( 1, 2,16) /  6.2638900D-02 ,  6.5803600D-02 /
      data f( 1, 2,17) /              7.2861200D-02 /
      data f( 1, 3, 1),f( 1, 3, 2) /  6.8192800D-02 ,  4.9966100D-02 /
      data f( 1, 3, 3),f( 1, 3, 4) /  4.2956500D-02 ,  4.9966100D-02 /
      data f( 1, 3, 5),f( 1, 3, 6) /  6.8192800D-02 ,  8.0364300D-02 /
      data f( 1, 3, 7),f( 1, 3, 8) /  7.7398900D-02 ,  6.8097400D-02 /
      data f( 1, 3, 9),f( 1, 3,10) /  6.4105800D-02 ,  6.8097400D-02 /
      data f( 1, 3,11),f( 1, 3,12) /  7.7398900D-02 ,  8.0364300D-02 /
      data f( 1, 3,13),f( 1, 3,14) /  6.8192800D-02 ,  4.9966100D-02 /
      data f( 1, 3,15),f( 1, 3,16) /  4.2956500D-02 ,  4.9966100D-02 /
      data f( 1, 3,17) /              6.8192800D-02 /
      data f( 1, 4, 1),f( 1, 4, 2) /  6.0983300D-02 ,  3.8211300D-02 /
      data f( 1, 4, 3),f( 1, 4, 4) /  4.3292200D-02 ,  3.8211300D-02 /
      data f( 1, 4, 5),f( 1, 4, 6) /  6.0983300D-02 ,  7.6059000D-02 /
      data f( 1, 4, 7),f( 1, 4, 8) /  8.5909200D-02 ,  6.1423600D-02 /
      data f( 1, 4, 9),f( 1, 4,10) /  5.4277500D-02 ,  6.1423600D-02 /
      data f( 1, 4,11),f( 1, 4,12) /  8.5909200D-02 ,  7.6059000D-02 /
      data f( 1, 4,13),f( 1, 4,14) /  6.0983300D-02 ,  3.8211300D-02 /
      data f( 1, 4,15),f( 1, 4,16) /  4.3292200D-02 ,  3.8211300D-02 /
      data f( 1, 4,17) /              6.0983300D-02 /
      data f( 1, 5, 1),f( 1, 5, 2) /  4.9458900D-02 ,  3.1277600D-02 /
      data f( 1, 5, 3),f( 1, 5, 4) /  7.0892300D-02 ,  3.1277600D-02 /
      data f( 1, 5, 5),f( 1, 5, 6) /  4.9458900D-02 ,  6.3292900D-02 /
      data f( 1, 5, 7),f( 1, 5, 8) /  1.1241180D-01 ,  5.4496000D-02 /
      data f( 1, 5, 9),f( 1, 5,10) /  4.4784700D-02 ,  5.4496000D-02 /
      data f( 1, 5,11),f( 1, 5,12) /  1.1241180D-01 ,  6.3292900D-02 /
      data f( 1, 5,13),f( 1, 5,14) /  4.9458900D-02 ,  3.1277600D-02 /
      data f( 1, 5,15),f( 1, 5,16) /  7.0892300D-02 ,  3.1277600D-02 /
      data f( 1, 5,17) /              4.9458900D-02 /
      data f( 1, 6, 1),f( 1, 6, 2) /  3.6052800D-02 ,  2.5315700D-02 /
      data f( 1, 6, 3),f( 1, 6, 4) /  5.2856000D-02 ,  2.5315700D-02 /
      data f( 1, 6, 5),f( 1, 6, 6) /  3.6052800D-02 ,  4.4515100D-02 /
      data f( 1, 6, 7),f( 1, 6, 8) /  8.5871200D-02 ,  4.3136500D-02 /
      data f( 1, 6, 9),f( 1, 6,10) /  3.5128000D-02 ,  4.3136500D-02 /
      data f( 1, 6,11),f( 1, 6,12) /  8.5871200D-02 ,  4.4515100D-02 /
      data f( 1, 6,13),f( 1, 6,14) /  3.6052800D-02 ,  2.5315700D-02 /
      data f( 1, 6,15),f( 1, 6,16) /  5.2856000D-02 ,  2.5315700D-02 /
      data f( 1, 6,17) /              3.6052800D-02 /
      data f( 1, 7, 1),f( 1, 7, 2) /  2.4361600D-02 ,  2.3183600D-02 /
      data f( 1, 7, 3),f( 1, 7, 4) /  2.4096000D-02 ,  2.3183600D-02 /
      data f( 1, 7, 5),f( 1, 7, 6) /  2.4361600D-02 ,  2.8647800D-02 /
      data f( 1, 7, 7),f( 1, 7, 8) /  4.2529200D-02 ,  3.2268600D-02 /
      data f( 1, 7, 9),f( 1, 7,10) /  2.5672200D-02 ,  3.2268600D-02 /
      data f( 1, 7,11),f( 1, 7,12) /  4.2529200D-02 ,  2.8647800D-02 /
      data f( 1, 7,13),f( 1, 7,14) /  2.4361600D-02 ,  2.3183600D-02 /
      data f( 1, 7,15),f( 1, 7,16) /  2.4096000D-02 ,  2.3183600D-02 /
      data f( 1, 7,17) /              2.4361600D-02 /
      data f( 1, 8, 1),f( 1, 8, 2) /  1.5461200D-02 ,  2.1527400D-02 /
      data f( 1, 8, 3),f( 1, 8, 4) /  2.2771600D-02 ,  2.1527400D-02 /
      data f( 1, 8, 5),f( 1, 8, 6) /  1.5461200D-02 ,  1.8788600D-02 /
      data f( 1, 8, 7),f( 1, 8, 8) /  2.6103700D-02 ,  2.2088100D-02 /
      data f( 1, 8, 9),f( 1, 8,10) /  1.5197800D-02 ,  2.2088100D-02 /
      data f( 1, 8,11),f( 1, 8,12) /  2.6103700D-02 ,  1.8788600D-02 /
      data f( 1, 8,13),f( 1, 8,14) /  1.5461200D-02 ,  2.1527400D-02 /
      data f( 1, 8,15),f( 1, 8,16) /  2.2771600D-02 ,  2.1527400D-02 /
      data f( 1, 8,17) /              1.5461200D-02 /
      data f( 1, 9, 1),f( 1, 9, 2) /  9.0159000D-03 ,  1.4324300D-02 /
      data f( 1, 9, 3),f( 1, 9, 4) /  1.9375900D-02 ,  1.4324300D-02 /
      data f( 1, 9, 5),f( 1, 9, 6) /  9.0159000D-03 ,  1.3617700D-02 /
      data f( 1, 9, 7),f( 1, 9, 8) /  1.7905000D-02 ,  9.7185000D-03 /
      data f( 1, 9, 9),f( 1, 9,10) /  2.0990000D-03 ,  9.7185000D-03 /
      data f( 1, 9,11),f( 1, 9,12) /  1.7905000D-02 ,  1.3617700D-02 /
      data f( 1, 9,13),f( 1, 9,14) /  9.0159000D-03 ,  1.4324300D-02 /
      data f( 1, 9,15),f( 1, 9,16) /  1.9375900D-02 ,  1.4324300D-02 /
      data f( 1, 9,17) /              9.0159000D-03 /
      data f( 1,10, 1),f( 1,10, 2) /  4.6934000D-03 ,  1.8536000D-03 /
      data f( 1,10, 3),f( 1,10, 4) /  3.8399000D-03 ,  1.8536000D-03 /
      data f( 1,10, 5),f( 1,10, 6) /  4.6934000D-03 ,  1.2965400D-02 /
      data f( 1,10, 7),f( 1,10, 8) /  1.0264900D-02 , -5.0943000D-03 /
      data f( 1,10, 9),f( 1,10,10) / -1.3946900D-02 , -5.0943000D-03 /
      data f( 1,10,11),f( 1,10,12) /  1.0264900D-02 ,  1.2965400D-02 /
      data f( 1,10,13),f( 1,10,14) /  4.6934000D-03 ,  1.8536000D-03 /
      data f( 1,10,15),f( 1,10,16) /  3.8399000D-03 ,  1.8536000D-03 /
      data f( 1,10,17) /              4.6934000D-03 /
      data f( 1,11, 1),f( 1,11, 2) /  2.7398000D-03 , -1.2354300D-02 /
      data f( 1,11, 3),f( 1,11, 4) / -1.5973700D-02 , -1.2354300D-02 /
      data f( 1,11, 5),f( 1,11, 6) /  2.7398000D-03 ,  1.7748100D-02 /
      data f( 1,11, 7),f( 1,11, 8) /  3.5169000D-03 , -2.1347800D-02 /
      data f( 1,11, 9),f( 1,11,10) / -3.2149000D-02 , -2.1347800D-02 /
      data f( 1,11,11),f( 1,11,12) /  3.5169000D-03 ,  1.7748100D-02 /
      data f( 1,11,13),f( 1,11,14) /  2.7398000D-03 , -1.2354300D-02 /
      data f( 1,11,15),f( 1,11,16) / -1.5973700D-02 , -1.2354300D-02 /
      data f( 1,11,17) /              2.7398000D-03 /
      data f( 1,12, 1),f( 1,12, 2) /  4.1435000D-03 , -2.5231100D-02 /
      data f( 1,12, 3),f( 1,12, 4) / -3.4444000D-02 , -2.5231100D-02 /
      data f( 1,12, 5),f( 1,12, 6) /  4.1435000D-03 ,  2.9578300D-02 /
      data f( 1,12, 7),f( 1,12, 8) / -1.5321000D-03 , -3.7791800D-02 /
      data f( 1,12, 9),f( 1,12,10) / -5.1198900D-02 , -3.7791800D-02 /
      data f( 1,12,11),f( 1,12,12) / -1.5321000D-03 ,  2.9578300D-02 /
      data f( 1,12,13),f( 1,12,14) /  4.1435000D-03 , -2.5231100D-02 /
      data f( 1,12,15),f( 1,12,16) / -3.4444000D-02 , -2.5231100D-02 /
      data f( 1,12,17) /              4.1435000D-03 /
      data f( 1,13, 1),f( 1,13, 2) /  1.1212100D-02 , -3.4102200D-02 /
      data f( 1,13, 3),f( 1,13, 4) / -4.8503100D-02 , -3.4102200D-02 /
      data f( 1,13, 5),f( 1,13, 6) /  1.1212100D-02 ,  5.1708700D-02 /
      data f( 1,13, 7),f( 1,13, 8) / -4.1827000D-03 , -5.2693300D-02 /
      data f( 1,13, 9),f( 1,13,10) / -6.9089200D-02 , -5.2693300D-02 /
      data f( 1,13,11),f( 1,13,12) / -4.1827000D-03 ,  5.1708700D-02 /
      data f( 1,13,13),f( 1,13,14) /  1.1212100D-02 , -3.4102200D-02 /
      data f( 1,13,15),f( 1,13,16) / -4.8503100D-02 , -3.4102200D-02 /
      data f( 1,13,17) /              1.1212100D-02 /
      data f( 1,14, 1),f( 1,14, 2) /  3.0236200D-02 , -3.5844000D-02 /
      data f( 1,14, 3),f( 1,14, 4) / -5.4850200D-02 , -3.5844000D-02 /
      data f( 1,14, 5),f( 1,14, 6) /  3.0236200D-02 ,  9.4626600D-02 /
      data f( 1,14, 7),f( 1,14, 8) / -3.8517000D-03 , -6.3396500D-02 /
      data f( 1,14, 9),f( 1,14,10) / -8.2628200D-02 , -6.3396500D-02 /
      data f( 1,14,11),f( 1,14,12) / -3.8517000D-03 ,  9.4626600D-02 /
      data f( 1,14,13),f( 1,14,14) /  3.0236200D-02 , -3.5844000D-02 /
      data f( 1,14,15),f( 1,14,16) / -5.4850200D-02 , -3.5844000D-02 /
      data f( 1,14,17) /              3.0236200D-02 /
      data f( 1,15, 1),f( 1,15, 2) /  6.5004000D-02 , -2.6977600D-02 /
      data f( 1,15, 3),f( 1,15, 4) / -4.9235900D-02 , -2.6977600D-02 /
      data f( 1,15, 5),f( 1,15, 6) /  6.5004000D-02 ,  1.3809070D-01 /
      data f( 1,15, 7),f( 1,15, 8) / -7.5500000D-05 , -6.6253300D-02 /
      data f( 1,15, 9),f( 1,15,10) / -8.7259400D-02 , -6.6253300D-02 /
      data f( 1,15,11),f( 1,15,12) / -7.5500000D-05 ,  1.3809070D-01 /
      data f( 1,15,13),f( 1,15,14) /  6.5004000D-02 , -2.6977600D-02 /
      data f( 1,15,15),f( 1,15,16) / -4.9235900D-02 , -2.6977600D-02 /
      data f( 1,15,17) /              6.5004000D-02 /
      data f( 1,16, 1),f( 1,16, 2) /  7.7345200D-02 , -5.7411000D-03 /
      data f( 1,16, 3),f( 1,16, 4) / -2.7629900D-02 , -5.7411000D-03 /
      data f( 1,16, 5),f( 1,16, 6) /  7.7345200D-02 ,  1.2202290D-01 /
      data f( 1,16, 7),f( 1,16, 8) /  5.6039000D-03 , -5.7206800D-02 /
      data f( 1,16, 9),f( 1,16,10) / -7.7631900D-02 , -5.7206800D-02 /
      data f( 1,16,11),f( 1,16,12) /  5.6039000D-03 ,  1.2202290D-01 /
      data f( 1,16,13),f( 1,16,14) /  7.7345200D-02 , -5.7411000D-03 /
      data f( 1,16,15),f( 1,16,16) / -2.7629900D-02 , -5.7411000D-03 /
      data f( 1,16,17) /              7.7345200D-02 /
      data f( 1,17, 1),f( 1,17, 2) /  6.4965600D-02 ,  2.6300700D-02 /
      data f( 1,17, 3),f( 1,17, 4) /  1.0856700D-02 ,  2.6300700D-02 /
      data f( 1,17, 5),f( 1,17, 6) /  6.4965600D-02 ,  6.8066800D-02 /
      data f( 1,17, 7),f( 1,17, 8) /  1.1962000D-02 , -3.3396700D-02 /
      data f( 1,17, 9),f( 1,17,10) / -4.9555300D-02 , -3.3396700D-02 /
      data f( 1,17,11),f( 1,17,12) /  1.1962000D-02 ,  6.8066800D-02 /
      data f( 1,17,13),f( 1,17,14) /  6.4965600D-02 ,  2.6300700D-02 /
      data f( 1,17,15),f( 1,17,16) /  1.0856700D-02 ,  2.6300700D-02 /
      data f( 1,17,17) /              6.4965600D-02 /
      data f( 1,18, 1),f( 1,18, 2) /  6.9069800D-02 ,  6.5621400D-02 /
      data f( 1,18, 3),f( 1,18, 4) /  6.0134400D-02 ,  6.5621400D-02 /
      data f( 1,18, 5),f( 1,18, 6) /  6.9069800D-02 ,  5.2616600D-02 /
      data f( 1,18, 7),f( 1,18, 8) /  2.6502500D-02 ,  4.6934000D-03 /
      data f( 1,18, 9),f( 1,18,10) / -3.6098000D-03 ,  4.6934000D-03 /
      data f( 1,18,11),f( 1,18,12) /  2.6502500D-02 ,  5.2616600D-02 /
      data f( 1,18,13),f( 1,18,14) /  6.9069800D-02 ,  6.5621400D-02 /
      data f( 1,18,15),f( 1,18,16) /  6.0134400D-02 ,  6.5621400D-02 /
      data f( 1,18,17) /              6.9069800D-02 /
      data f( 1,19, 1),f( 1,19, 2) /  5.1285700D-02 ,  5.1285700D-02 /
      data f( 1,19, 3),f( 1,19, 4) /  5.1285700D-02 ,  5.1285700D-02 /
      data f( 1,19, 5),f( 1,19, 6) /  5.1285700D-02 ,  5.1285700D-02 /
      data f( 1,19, 7),f( 1,19, 8) /  5.1285700D-02 ,  5.1285700D-02 /
      data f( 1,19, 9),f( 1,19,10) /  5.1285700D-02 ,  5.1285700D-02 /
      data f( 1,19,11),f( 1,19,12) /  5.1285700D-02 ,  5.1285700D-02 /
      data f( 1,19,13),f( 1,19,14) /  5.1285700D-02 ,  5.1285700D-02 /
      data f( 1,19,15),f( 1,19,16) /  5.1285700D-02 ,  5.1285700D-02 /
      data f( 1,19,17) /              5.1285700D-02 /
      data f( 2, 1, 1),f( 2, 1, 2) /  5.9230200D-02 ,  5.9230200D-02 /
      data f( 2, 1, 3),f( 2, 1, 4) /  5.9230200D-02 ,  5.9230200D-02 /
      data f( 2, 1, 5),f( 2, 1, 6) /  5.9230200D-02 ,  5.9230200D-02 /
      data f( 2, 1, 7),f( 2, 1, 8) /  5.9230200D-02 ,  5.9230200D-02 /
      data f( 2, 1, 9),f( 2, 1,10) /  5.9230200D-02 ,  5.9230200D-02 /
      data f( 2, 1,11),f( 2, 1,12) /  5.9230200D-02 ,  5.9230200D-02 /
      data f( 2, 1,13),f( 2, 1,14) /  5.9230200D-02 ,  5.9230200D-02 /
      data f( 2, 1,15),f( 2, 1,16) /  5.9230200D-02 ,  5.9230200D-02 /
      data f( 2, 1,17) /              5.9230200D-02 /
      data f( 2, 2, 1),f( 2, 2, 2) /  5.6911900D-02 ,  5.1821000D-02 /
      data f( 2, 2, 3),f( 2, 2, 4) /  4.9449300D-02 ,  5.1821000D-02 /
      data f( 2, 2, 5),f( 2, 2, 6) /  5.6911900D-02 ,  6.0590600D-02 /
      data f( 2, 2, 7),f( 2, 2, 8) /  6.0683800D-02 ,  5.8795400D-02 /
      data f( 2, 2, 9),f( 2, 2,10) /  5.7763800D-02 ,  5.8795400D-02 /
      data f( 2, 2,11),f( 2, 2,12) /  6.0683800D-02 ,  6.0590600D-02 /
      data f( 2, 2,13),f( 2, 2,14) /  5.6911900D-02 ,  5.1821000D-02 /
      data f( 2, 2,15),f( 2, 2,16) /  4.9449300D-02 ,  5.1821000D-02 /
      data f( 2, 2,17) /              5.6911900D-02 /
      data f( 2, 3, 1),f( 2, 3, 2) /  5.3526600D-02 ,  3.9454500D-02 /
      data f( 2, 3, 3),f( 2, 3, 4) /  3.3004000D-02 ,  3.9454500D-02 /
      data f( 2, 3, 5),f( 2, 3, 6) /  5.3526600D-02 ,  6.2204700D-02 /
      data f( 2, 3, 7),f( 2, 3, 8) /  6.0238700D-02 ,  5.3431900D-02 /
      data f( 2, 3, 9),f( 2, 3,10) /  5.0272100D-02 ,  5.3431900D-02 /
      data f( 2, 3,11),f( 2, 3,12) /  6.0238700D-02 ,  6.2204700D-02 /
      data f( 2, 3,13),f( 2, 3,14) /  5.3526600D-02 ,  3.9454500D-02 /
      data f( 2, 3,15),f( 2, 3,16) /  3.3004000D-02 ,  3.9454500D-02 /
      data f( 2, 3,17) /              5.3526600D-02 /
      data f( 2, 4, 1),f( 2, 4, 2) /  4.7536900D-02 ,  2.8216800D-02 /
      data f( 2, 4, 3),f( 2, 4, 4) /  2.4502200D-02 ,  2.8216800D-02 /
      data f( 2, 4, 5),f( 2, 4, 6) /  4.7536900D-02 ,  5.8644100D-02 /
      data f( 2, 4, 7),f( 2, 4, 8) /  6.1330800D-02 ,  4.7199100D-02 /
      data f( 2, 4, 9),f( 2, 4,10) /  4.2099200D-02 ,  4.7199100D-02 /
      data f( 2, 4,11),f( 2, 4,12) /  6.1330800D-02 ,  5.8644100D-02 /
      data f( 2, 4,13),f( 2, 4,14) /  4.7536900D-02 ,  2.8216800D-02 /
      data f( 2, 4,15),f( 2, 4,16) /  2.4502200D-02 ,  2.8216800D-02 /
      data f( 2, 4,17) /              4.7536900D-02 /
      data f( 2, 5, 1),f( 2, 5, 2) /  3.8256800D-02 ,  2.0956800D-02 /
      data f( 2, 5, 3),f( 2, 5, 4) /  3.0377700D-02 ,  2.0956800D-02 /
      data f( 2, 5, 5),f( 2, 5, 6) /  3.8256800D-02 ,  4.8172200D-02 /
      data f( 2, 5, 7),f( 2, 5, 8) /  6.7282600D-02 ,  4.0475700D-02 /
      data f( 2, 5, 9),f( 2, 5,10) /  3.4222700D-02 ,  4.0475700D-02 /
      data f( 2, 5,11),f( 2, 5,12) /  6.7282600D-02 ,  4.8172200D-02 /
      data f( 2, 5,13),f( 2, 5,14) /  3.8256800D-02 ,  2.0956800D-02 /
      data f( 2, 5,15),f( 2, 5,16) /  3.0377700D-02 ,  2.0956800D-02 /
      data f( 2, 5,17) /              3.8256800D-02 /
      data f( 2, 6, 1),f( 2, 6, 2) /  2.7812600D-02 ,  1.7054700D-02 /
      data f( 2, 6, 3),f( 2, 6, 4) /  2.2112600D-02 ,  1.7054700D-02 /
      data f( 2, 6, 5),f( 2, 6, 6) /  2.7812600D-02 ,  3.4109800D-02 /
      data f( 2, 6, 7),f( 2, 6, 8) /  5.1616100D-02 ,  3.2326500D-02 /
      data f( 2, 6, 9),f( 2, 6,10) /  2.6780500D-02 ,  3.2326500D-02 /
      data f( 2, 6,11),f( 2, 6,12) /  5.1616100D-02 ,  3.4109800D-02 /
      data f( 2, 6,13),f( 2, 6,14) /  2.7812600D-02 ,  1.7054700D-02 /
      data f( 2, 6,15),f( 2, 6,16) /  2.2112600D-02 ,  1.7054700D-02 /
      data f( 2, 6,17) /              2.7812600D-02 /
      data f( 2, 7, 1),f( 2, 7, 2) /  1.8677100D-02 ,  1.6915700D-02 /
      data f( 2, 7, 3),f( 2, 7, 4) /  1.3058200D-02 ,  1.6915700D-02 /
      data f( 2, 7, 5),f( 2, 7, 6) /  1.8677100D-02 ,  2.2261500D-02 /
      data f( 2, 7, 7),f( 2, 7, 8) /  2.9694700D-02 ,  2.4913300D-02 /
      data f( 2, 7, 9),f( 2, 7,10) /  1.9664900D-02 ,  2.4913300D-02 /
      data f( 2, 7,11),f( 2, 7,12) /  2.9694700D-02 ,  2.2261500D-02 /
      data f( 2, 7,13),f( 2, 7,14) /  1.8677100D-02 ,  1.6915700D-02 /
      data f( 2, 7,15),f( 2, 7,16) /  1.3058200D-02 ,  1.6915700D-02 /
      data f( 2, 7,17) /              1.8677100D-02 /
      data f( 2, 8, 1),f( 2, 8, 2) /  1.1650900D-02 ,  1.6458200D-02 /
      data f( 2, 8, 3),f( 2, 8, 4) /  1.6827900D-02 ,  1.6458200D-02 /
      data f( 2, 8, 5),f( 2, 8, 6) /  1.1650900D-02 ,  1.4438800D-02 /
      data f( 2, 8, 7),f( 2, 8, 8) /  2.0118700D-02 ,  1.7293900D-02 /
      data f( 2, 8, 9),f( 2, 8,10) /  1.1655500D-02 ,  1.7293900D-02 /
      data f( 2, 8,11),f( 2, 8,12) /  2.0118700D-02 ,  1.4438800D-02 /
      data f( 2, 8,13),f( 2, 8,14) /  1.1650900D-02 ,  1.6458200D-02 /
      data f( 2, 8,15),f( 2, 8,16) /  1.6827900D-02 ,  1.6458200D-02 /
      data f( 2, 8,17) /              1.1650900D-02 /
      data f( 2, 9, 1),f( 2, 9, 2) /  6.5537000D-03 ,  1.1117300D-02 /
      data f( 2, 9, 3),f( 2, 9, 4) /  1.5240100D-02 ,  1.1117300D-02 /
      data f( 2, 9, 5),f( 2, 9, 6) /  6.5537000D-03 ,  1.0140800D-02 /
      data f( 2, 9, 7),f( 2, 9, 8) /  1.3835500D-02 ,  7.5455000D-03 /
      data f( 2, 9, 9),f( 2, 9,10) /  1.3841000D-03 ,  7.5455000D-03 /
      data f( 2, 9,11),f( 2, 9,12) /  1.3835500D-02 ,  1.0140800D-02 /
      data f( 2, 9,13),f( 2, 9,14) /  6.5537000D-03 ,  1.1117300D-02 /
      data f( 2, 9,15),f( 2, 9,16) /  1.5240100D-02 ,  1.1117300D-02 /
      data f( 2, 9,17) /              6.5537000D-03 /
      data f( 2,10, 1),f( 2,10, 2) /  3.1745000D-03 ,  1.2938000D-03 /
      data f( 2,10, 3),f( 2,10, 4) /  3.1500000D-03 ,  1.2938000D-03 /
      data f( 2,10, 5),f( 2,10, 6) /  3.1745000D-03 ,  9.5678000D-03 /
      data f( 2,10, 7),f( 2,10, 8) /  7.6805000D-03 , -4.3916000D-03 /
      data f( 2,10, 9),f( 2,10,10) / -1.1599600D-02 , -4.3916000D-03 /
      data f( 2,10,11),f( 2,10,12) /  7.6805000D-03 ,  9.5678000D-03 /
      data f( 2,10,13),f( 2,10,14) /  3.1745000D-03 ,  1.2938000D-03 /
      data f( 2,10,15),f( 2,10,16) /  3.1500000D-03 ,  1.2938000D-03 /
      data f( 2,10,17) /              3.1745000D-03 /
      data f( 2,11, 1),f( 2,11, 2) /  1.7438000D-03 , -1.0325900D-02 /
      data f( 2,11, 3),f( 2,11, 4) / -1.3101400D-02 , -1.0325900D-02 /
      data f( 2,11, 5),f( 2,11, 6) /  1.7438000D-03 ,  1.3547900D-02 /
      data f( 2,11, 7),f( 2,11, 8) /  2.3393000D-03 , -1.7829300D-02 /
      data f( 2,11, 9),f( 2,11,10) / -2.6806600D-02 , -1.7829300D-02 /
      data f( 2,11,11),f( 2,11,12) /  2.3393000D-03 ,  1.3547900D-02 /
      data f( 2,11,13),f( 2,11,14) /  1.7438000D-03 , -1.0325900D-02 /
      data f( 2,11,15),f( 2,11,16) / -1.3101400D-02 , -1.0325900D-02 /
      data f( 2,11,17) /              1.7438000D-03 /
      data f( 2,12, 1),f( 2,12, 2) /  3.1130000D-03 , -2.1195800D-02 /
      data f( 2,12, 3),f( 2,12, 4) / -2.8795600D-02 , -2.1195800D-02 /
      data f( 2,12, 5),f( 2,12, 6) /  3.1130000D-03 ,  2.3388400D-02 /
      data f( 2,12, 7),f( 2,12, 8) / -1.5400000D-03 , -3.1754400D-02 /
      data f( 2,12, 9),f( 2,12,10) / -4.3126700D-02 , -3.1754400D-02 /
      data f( 2,12,11),f( 2,12,12) / -1.5400000D-03 ,  2.3388400D-02 /
      data f( 2,12,13),f( 2,12,14) /  3.1130000D-03 , -2.1195800D-02 /
      data f( 2,12,15),f( 2,12,16) / -2.8795600D-02 , -2.1195800D-02 /
      data f( 2,12,17) /              3.1130000D-03 /
      data f( 2,13, 1),f( 2,13, 2) /  9.0713000D-03 , -2.8837200D-02 /
      data f( 2,13, 3),f( 2,13, 4) / -4.1020900D-02 , -2.8837200D-02 /
      data f( 2,13, 5),f( 2,13, 6) /  9.0713000D-03 ,  4.1038900D-02 /
      data f( 2,13, 7),f( 2,13, 8) / -3.2768000D-03 , -4.4573800D-02 /
      data f( 2,13, 9),f( 2,13,10) / -5.8714700D-02 , -4.4573800D-02 /
      data f( 2,13,11),f( 2,13,12) / -3.2768000D-03 ,  4.1038900D-02 /
      data f( 2,13,13),f( 2,13,14) /  9.0713000D-03 , -2.8837200D-02 /
      data f( 2,13,15),f( 2,13,16) / -4.1020900D-02 , -2.8837200D-02 /
      data f( 2,13,17) /              9.0713000D-03 /
      data f( 2,14, 1),f( 2,14, 2) /  2.3528000D-02 , -3.0313200D-02 /
      data f( 2,14, 3),f( 2,14, 4) / -4.6638700D-02 , -3.0313200D-02 /
      data f( 2,14, 5),f( 2,14, 6) /  2.3528000D-02 ,  7.1081600D-02 /
      data f( 2,14, 7),f( 2,14, 8) / -2.2254000D-03 , -5.3813000D-02 /
      data f( 2,14, 9),f( 2,14,10) / -7.0630600D-02 , -5.3813000D-02 /
      data f( 2,14,11),f( 2,14,12) / -2.2254000D-03 ,  7.1081600D-02 /
      data f( 2,14,13),f( 2,14,14) /  2.3528000D-02 , -3.0313200D-02 /
      data f( 2,14,15),f( 2,14,16) / -4.6638700D-02 , -3.0313200D-02 /
      data f( 2,14,17) /              2.3528000D-02 /
      data f( 2,15, 1),f( 2,15, 2) /  4.7487000D-02 , -2.2374100D-02 /
      data f( 2,15, 3),f( 2,15, 4) / -4.1671200D-02 , -2.2374100D-02 /
      data f( 2,15, 5),f( 2,15, 6) /  4.7487000D-02 ,  1.0695600D-01 /
      data f( 2,15, 7),f( 2,15, 8) /  1.7974000D-03 , -5.6112700D-02 /
      data f( 2,15, 9),f( 2,15,10) / -7.4712500D-02 , -5.6112700D-02 /
      data f( 2,15,11),f( 2,15,12) /  1.7974000D-03 ,  1.0695600D-01 /
      data f( 2,15,13),f( 2,15,14) /  4.7487000D-02 , -2.2374100D-02 /
      data f( 2,15,15),f( 2,15,16) / -4.1671200D-02 , -2.2374100D-02 /
      data f( 2,15,17) /              4.7487000D-02 /
      data f( 2,16, 1),f( 2,16, 2) /  6.1287300D-02 , -2.9781000D-03 /
      data f( 2,16, 3),f( 2,16, 4) / -2.2273200D-02 , -2.9781000D-03 /
      data f( 2,16, 5),f( 2,16, 6) /  6.1287300D-02 ,  9.7286100D-02 /
      data f( 2,16, 7),f( 2,16, 8) /  7.6171000D-03 , -4.7784300D-02 /
      data f( 2,16, 9),f( 2,16,10) / -6.6081600D-02 , -4.7784300D-02 /
      data f( 2,16,11),f( 2,16,12) /  7.6171000D-03 ,  9.7286100D-02 /
      data f( 2,16,13),f( 2,16,14) /  6.1287300D-02 , -2.9781000D-03 /
      data f( 2,16,15),f( 2,16,16) / -2.2273200D-02 , -2.9781000D-03 /
      data f( 2,16,17) /              6.1287300D-02 /
      data f( 2,17, 1),f( 2,17, 2) /  6.6365500D-02 ,  2.7397400D-02 /
      data f( 2,17, 3),f( 2,17, 4) /  1.2801600D-02 ,  2.7397400D-02 /
      data f( 2,17, 5),f( 2,17, 6) /  6.6365500D-02 ,  6.8659500D-02 /
      data f( 2,17, 7),f( 2,17, 8) /  1.5217200D-02 , -2.6112600D-02 /
      data f( 2,17, 9),f( 2,17,10) / -4.0803500D-02 , -2.6112600D-02 /
      data f( 2,17,11),f( 2,17,12) /  1.5217200D-02 ,  6.8659500D-02 /
      data f( 2,17,13),f( 2,17,14) /  6.6365500D-02 ,  2.7397400D-02 /
      data f( 2,17,15),f( 2,17,16) /  1.2801600D-02 ,  2.7397400D-02 /
      data f( 2,17,17) /              6.6365500D-02 /
      data f( 2,18, 1),f( 2,18, 2) /  7.6612700D-02 ,  6.5464800D-02 /
      data f( 2,18, 3),f( 2,18, 4) /  5.8677600D-02 ,  6.5464800D-02 /
      data f( 2,18, 5),f( 2,18, 6) /  7.6612700D-02 ,  5.6347500D-02 /
      data f( 2,18, 7),f( 2,18, 8) /  2.9644700D-02 ,  8.8500000D-03 /
      data f( 2,18, 9),f( 2,18,10) /  1.0789000D-03 ,  8.8500000D-03 /
      data f( 2,18,11),f( 2,18,12) /  2.9644700D-02 ,  5.6347500D-02 /
      data f( 2,18,13),f( 2,18,14) /  7.6612700D-02 ,  6.5464800D-02 /
      data f( 2,18,15),f( 2,18,16) /  5.8677600D-02 ,  6.5464800D-02 /
      data f( 2,18,17) /              7.6612700D-02 /
      data f( 2,19, 1),f( 2,19, 2) /  5.2271500D-02 ,  5.2271500D-02 /
      data f( 2,19, 3),f( 2,19, 4) /  5.2271500D-02 ,  5.2271500D-02 /
      data f( 2,19, 5),f( 2,19, 6) /  5.2271500D-02 ,  5.2271500D-02 /
      data f( 2,19, 7),f( 2,19, 8) /  5.2271500D-02 ,  5.2271500D-02 /
      data f( 2,19, 9),f( 2,19,10) /  5.2271500D-02 ,  5.2271500D-02 /
      data f( 2,19,11),f( 2,19,12) /  5.2271500D-02 ,  5.2271500D-02 /
      data f( 2,19,13),f( 2,19,14) /  5.2271500D-02 ,  5.2271500D-02 /
      data f( 2,19,15),f( 2,19,16) /  5.2271500D-02 ,  5.2271500D-02 /
      data f( 2,19,17) /              5.2271500D-02 /
      data f( 3, 1, 1),f( 3, 1, 2) /  4.5417600D-02 ,  4.5417600D-02 /
      data f( 3, 1, 3),f( 3, 1, 4) /  4.5417600D-02 ,  4.5417600D-02 /
      data f( 3, 1, 5),f( 3, 1, 6) /  4.5417600D-02 ,  4.5417600D-02 /
      data f( 3, 1, 7),f( 3, 1, 8) /  4.5417600D-02 ,  4.5417600D-02 /
      data f( 3, 1, 9),f( 3, 1,10) /  4.5417600D-02 ,  4.5417600D-02 /
      data f( 3, 1,11),f( 3, 1,12) /  4.5417600D-02 ,  4.5417600D-02 /
      data f( 3, 1,13),f( 3, 1,14) /  4.5417600D-02 ,  4.5417600D-02 /
      data f( 3, 1,15),f( 3, 1,16) /  4.5417600D-02 ,  4.5417600D-02 /
      data f( 3, 1,17) /              4.5417600D-02 /
      data f( 3, 2, 1),f( 3, 2, 2) /  4.3791400D-02 ,  3.9961900D-02 /
      data f( 3, 2, 3),f( 3, 2, 4) /  3.8143700D-02 ,  3.9961900D-02 /
      data f( 3, 2, 5),f( 3, 2, 6) /  4.3791400D-02 ,  4.6506000D-02 /
      data f( 3, 2, 7),f( 3, 2, 8) /  4.6574300D-02 ,  4.5154500D-02 /
      data f( 3, 2, 9),f( 3, 2,10) /  4.4364700D-02 ,  4.5154500D-02 /
      data f( 3, 2,11),f( 3, 2,12) /  4.6574300D-02 ,  4.6506000D-02 /
      data f( 3, 2,13),f( 3, 2,14) /  4.3791400D-02 ,  3.9961900D-02 /
      data f( 3, 2,15),f( 3, 2,16) /  3.8143700D-02 ,  3.9961900D-02 /
      data f( 3, 2,17) /              4.3791400D-02 /
      data f( 3, 3, 1),f( 3, 3, 2) /  4.1262800D-02 ,  3.0242200D-02 /
      data f( 3, 3, 3),f( 3, 3, 4) /  2.4689400D-02 ,  3.0242200D-02 /
      data f( 3, 3, 5),f( 3, 3, 6) /  4.1262800D-02 ,  4.7776600D-02 /
      data f( 3, 3, 7),f( 3, 3, 8) /  4.6295000D-02 ,  4.1179300D-02 /
      data f( 3, 3, 9),f( 3, 3,10) /  3.8679400D-02 ,  4.1179300D-02 /
      data f( 3, 3,11),f( 3, 3,12) /  4.6295000D-02 ,  4.7776600D-02 /
      data f( 3, 3,13),f( 3, 3,14) /  4.1262800D-02 ,  3.0242200D-02 /
      data f( 3, 3,15),f( 3, 3,16) /  2.4689400D-02 ,  3.0242200D-02 /
      data f( 3, 3,17) /              4.1262800D-02 /
      data f( 3, 4, 1),f( 3, 4, 2) /  3.6520500D-02 ,  2.0416900D-02 /
      data f( 3, 4, 3),f( 3, 4, 4) /  1.3486100D-02 ,  2.0416900D-02 /
      data f( 3, 4, 5),f( 3, 4, 6) /  3.6520500D-02 ,  4.4975400D-02 /
      data f( 3, 4, 7),f( 3, 4, 8) /  4.4589400D-02 ,  3.5902400D-02 /
      data f( 3, 4, 9),f( 3, 4,10) /  3.2122600D-02 ,  3.5902400D-02 /
      data f( 3, 4,11),f( 3, 4,12) /  4.4589400D-02 ,  4.4975400D-02 /
      data f( 3, 4,13),f( 3, 4,14) /  3.6520500D-02 ,  2.0416900D-02 /
      data f( 3, 4,15),f( 3, 4,16) /  1.3486100D-02 ,  2.0416900D-02 /
      data f( 3, 4,17) /              3.6520500D-02 /
      data f( 3, 5, 1),f( 3, 5, 2) /  2.9288300D-02 ,  1.3856500D-02 /
      data f( 3, 5, 3),f( 3, 5, 4) /  1.0655500D-02 ,  1.3856500D-02 /
      data f( 3, 5, 5),f( 3, 5, 6) /  2.9288300D-02 ,  3.6792500D-02 /
      data f( 3, 5, 7),f( 3, 5, 8) /  4.2899100D-02 ,  3.0194600D-02 /
      data f( 3, 5, 9),f( 3, 5,10) /  2.5870900D-02 ,  3.0194600D-02 /
      data f( 3, 5,11),f( 3, 5,12) /  4.2899100D-02 ,  3.6792500D-02 /
      data f( 3, 5,13),f( 3, 5,14) /  2.9288300D-02 ,  1.3856500D-02 /
      data f( 3, 5,15),f( 3, 5,16) /  1.0655500D-02 ,  1.3856500D-02 /
      data f( 3, 5,17) /              2.9288300D-02 /
      data f( 3, 6, 1),f( 3, 6, 2) /  2.1243300D-02 ,  1.1432700D-02 /
      data f( 3, 6, 3),f( 3, 6, 4) /  6.8221000D-03 ,  1.1432700D-02 /
      data f( 3, 6, 5),f( 3, 6, 6) /  2.1243300D-02 ,  2.6271100D-02 /
      data f( 3, 6, 7),f( 3, 6, 8) /  3.2866300D-02 ,  2.4380600D-02 /
      data f( 3, 6, 9),f( 3, 6,10) /  2.0220900D-02 ,  2.4380600D-02 /
      data f( 3, 6,11),f( 3, 6,12) /  3.2866300D-02 ,  2.6271100D-02 /
      data f( 3, 6,13),f( 3, 6,14) /  2.1243300D-02 ,  1.1432700D-02 /
      data f( 3, 6,15),f( 3, 6,16) /  6.8221000D-03 ,  1.1432700D-02 /
      data f( 3, 6,17) /              2.1243300D-02 /
      data f( 3, 7, 1),f( 3, 7, 2) /  1.4154100D-02 ,  1.2342900D-02 /
      data f( 3, 7, 3),f( 3, 7, 4) /  6.7757000D-03 ,  1.2342900D-02 /
      data f( 3, 7, 5),f( 3, 7, 6) /  1.4154100D-02 ,  1.7277600D-02 /
      data f( 3, 7, 7),f( 3, 7, 8) /  2.1478200D-02 ,  1.9195900D-02 /
      data f( 3, 7, 9),f( 3, 7,10) /  1.4882600D-02 ,  1.9195900D-02 /
      data f( 3, 7,11),f( 3, 7,12) /  2.1478200D-02 ,  1.7277600D-02 /
      data f( 3, 7,13),f( 3, 7,14) /  1.4154100D-02 ,  1.2342900D-02 /
      data f( 3, 7,15),f( 3, 7,16) /  6.7757000D-03 ,  1.2342900D-02 /
      data f( 3, 7,17) /              1.4154100D-02 /
      data f( 3, 8, 1),f( 3, 8, 2) /  8.6520000D-03 ,  1.2474000D-02 /
      data f( 3, 8, 3),f( 3, 8, 4) /  1.2527800D-02 ,  1.2474000D-02 /
      data f( 3, 8, 5),f( 3, 8, 6) /  8.6520000D-03 ,  1.1006400D-02 /
      data f( 3, 8, 7),f( 3, 8, 8) /  1.5562500D-02 ,  1.3388700D-02 /
      data f( 3, 8, 9),f( 3, 8,10) /  8.7868000D-03 ,  1.3388700D-02 /
      data f( 3, 8,11),f( 3, 8,12) /  1.5562500D-02 ,  1.1006400D-02 /
      data f( 3, 8,13),f( 3, 8,14) /  8.6520000D-03 ,  1.2474000D-02 /
      data f( 3, 8,15),f( 3, 8,16) /  1.2527800D-02 ,  1.2474000D-02 /
      data f( 3, 8,17) /              8.6520000D-03 /
      data f( 3, 9, 1),f( 3, 9, 2) /  4.6567000D-03 ,  8.4868000D-03 /
      data f( 3, 9, 3),f( 3, 9, 4) /  1.1827500D-02 ,  8.4868000D-03 /
      data f( 3, 9, 5),f( 3, 9, 6) /  4.6567000D-03 ,  7.4466000D-03 /
      data f( 3, 9, 7),f( 3, 9, 8) /  1.0581400D-02 ,  5.7341000D-03 /
      data f( 3, 9, 9),f( 3, 9,10) /  8.0730000D-04 ,  5.7341000D-03 /
      data f( 3, 9,11),f( 3, 9,12) /  1.0581400D-02 ,  7.4466000D-03 /
      data f( 3, 9,13),f( 3, 9,14) /  4.6567000D-03 ,  8.4868000D-03 /
      data f( 3, 9,15),f( 3, 9,16) /  1.1827500D-02 ,  8.4868000D-03 /
      data f( 3, 9,17) /              4.6567000D-03 /
      data f( 3,10, 1),f( 3,10, 2) /  2.0391000D-03 ,  8.2300000D-04 /
      data f( 3,10, 3),f( 3,10, 4) /  2.4727000D-03 ,  8.2300000D-04 /
      data f( 3,10, 5),f( 3,10, 6) /  2.0391000D-03 ,  6.9495000D-03 /
      data f( 3,10, 7),f( 3,10, 8) /  5.6380000D-03 , -3.7715000D-03 /
      data f( 3,10, 9),f( 3,10,10) / -9.5628000D-03 , -3.7715000D-03 /
      data f( 3,10,11),f( 3,10,12) /  5.6380000D-03 ,  6.9495000D-03 /
      data f( 3,10,13),f( 3,10,14) /  2.0391000D-03 ,  8.2300000D-04 /
      data f( 3,10,15),f( 3,10,16) /  2.4727000D-03 ,  8.2300000D-04 /
      data f( 3,10,17) /              2.0391000D-03 /
      data f( 3,11, 1),f( 3,11, 2) /  1.0075000D-03 , -8.5451000D-03 /
      data f( 3,11, 3),f( 3,11, 4) / -1.0651900D-02 , -8.5451000D-03 /
      data f( 3,11, 5),f( 3,11, 6) /  1.0075000D-03 ,  1.0215600D-02 /
      data f( 3,11, 7),f( 3,11, 8) /  1.4446000D-03 , -1.4727400D-02 /
      data f( 3,11, 9),f( 3,11,10) / -2.2091300D-02 , -1.4727400D-02 /
      data f( 3,11,11),f( 3,11,12) /  1.4446000D-03 ,  1.0215600D-02 /
      data f( 3,11,13),f( 3,11,14) /  1.0075000D-03 , -8.5451000D-03 /
      data f( 3,11,15),f( 3,11,16) / -1.0651900D-02 , -8.5451000D-03 /
      data f( 3,11,17) /              1.0075000D-03 /
      data f( 3,12, 1),f( 3,12, 2) /  2.2847000D-03 , -1.7594200D-02 /
      data f( 3,12, 3),f( 3,12, 4) / -2.3787300D-02 , -1.7594200D-02 /
      data f( 3,12, 5),f( 3,12, 6) /  2.2847000D-03 ,  1.8308800D-02 /
      data f( 3,12, 7),f( 3,12, 8) / -1.5173000D-03 , -2.6367700D-02 /
      data f( 3,12, 9),f( 3,12,10) / -3.5891700D-02 , -2.6367700D-02 /
      data f( 3,12,11),f( 3,12,12) / -1.5173000D-03 ,  1.8308800D-02 /
      data f( 3,12,13),f( 3,12,14) /  2.2847000D-03 , -1.7594200D-02 /
      data f( 3,12,15),f( 3,12,16) / -2.3787300D-02 , -1.7594200D-02 /
      data f( 3,12,17) /              2.2847000D-03 /
      data f( 3,13, 1),f( 3,13, 2) /  7.2319000D-03 , -2.4120700D-02 /
      data f( 3,13, 3),f( 3,13, 4) / -3.4290000D-02 , -2.4120700D-02 /
      data f( 3,13, 5),f( 3,13, 6) /  7.2319000D-03 ,  3.2410300D-02 /
      data f( 3,13, 7),f( 3,13, 8) / -2.6484000D-03 , -3.7278500D-02 /
      data f( 3,13, 9),f( 3,13,10) / -4.9313700D-02 , -3.7278500D-02 /
      data f( 3,13,11),f( 3,13,12) / -2.6484000D-03 ,  3.2410300D-02 /
      data f( 3,13,13),f( 3,13,14) /  7.2319000D-03 , -2.4120700D-02 /
      data f( 3,13,15),f( 3,13,16) / -3.4290000D-02 , -2.4120700D-02 /
      data f( 3,13,17) /              7.2319000D-03 /
      data f( 3,14, 1),f( 3,14, 2) /  1.8319100D-02 , -2.5418300D-02 /
      data f( 3,14, 3),f( 3,14, 4) / -3.9237400D-02 , -2.5418300D-02 /
      data f( 3,14, 5),f( 3,14, 6) /  1.8319100D-02 ,  5.3905500D-02 /
      data f( 3,14, 7),f( 3,14, 8) / -1.3002000D-03 , -4.5192200D-02 /
      data f( 3,14, 9),f( 3,14,10) / -5.9685100D-02 , -4.5192200D-02 /
      data f( 3,14,11),f( 3,14,12) / -1.3002000D-03 ,  5.3905500D-02 /
      data f( 3,14,13),f( 3,14,14) /  1.8319100D-02 , -2.5418300D-02 /
      data f( 3,14,15),f( 3,14,16) / -3.9237400D-02 , -2.5418300D-02 /
      data f( 3,14,17) /              1.8319100D-02 /
      data f( 3,15, 1),f( 3,15, 2) /  3.5915100D-02 , -1.8508500D-02 /
      data f( 3,15, 3),f( 3,15, 4) / -3.4986000D-02 , -1.8508500D-02 /
      data f( 3,15, 5),f( 3,15, 6) /  3.5915100D-02 ,  7.8205100D-02 /
      data f( 3,15, 7),f( 3,15, 8) /  2.7159000D-03 , -4.7040800D-02 /
      data f( 3,15, 9),f( 3,15,10) / -6.3238300D-02 , -4.7040800D-02 /
      data f( 3,15,11),f( 3,15,12) /  2.7159000D-03 ,  7.8205100D-02 /
      data f( 3,15,13),f( 3,15,14) /  3.5915100D-02 , -1.8508500D-02 /
      data f( 3,15,15),f( 3,15,16) / -3.4986000D-02 , -1.8508500D-02 /
      data f( 3,15,17) /              3.5915100D-02 /
      data f( 3,16, 1),f( 3,16, 2) /  4.9988900D-02 , -1.4017000D-03 /
      data f( 3,16, 3),f( 3,16, 4) / -1.8054600D-02 , -1.4017000D-03 /
      data f( 3,16, 5),f( 3,16, 6) /  4.9988900D-02 ,  7.9905100D-02 /
      data f( 3,16, 7),f( 3,16, 8) /  8.5620000D-03 , -3.9507000D-02 /
      data f( 3,16, 9),f( 3,16,10) / -5.5587900D-02 , -3.9507000D-02 /
      data f( 3,16,11),f( 3,16,12) /  8.5620000D-03 ,  7.9905100D-02 /
      data f( 3,16,13),f( 3,16,14) /  4.9988900D-02 , -1.4017000D-03 /
      data f( 3,16,15),f( 3,16,16) / -1.8054600D-02 , -1.4017000D-03 /
      data f( 3,16,17) /              4.9988900D-02 /
      data f( 3,17, 1),f( 3,17, 2) /  5.8942100D-02 ,  2.5233500D-02 /
      data f( 3,17, 3),f( 3,17, 4) /  1.2432200D-02 ,  2.5233500D-02 /
      data f( 3,17, 5),f( 3,17, 6) /  5.8942100D-02 ,  6.3079000D-02 /
      data f( 3,17, 7),f( 3,17, 8) /  1.6279100D-02 , -2.0207600D-02 /
      data f( 3,17, 9),f( 3,17,10) / -3.3221300D-02 , -2.0207600D-02 /
      data f( 3,17,11),f( 3,17,12) /  1.6279100D-02 ,  6.3079000D-02 /
      data f( 3,17,13),f( 3,17,14) /  5.8942100D-02 ,  2.5233500D-02 /
      data f( 3,17,15),f( 3,17,16) /  1.2432200D-02 ,  2.5233500D-02 /
      data f( 3,17,17) /              5.8942100D-02 /
      data f( 3,18, 1),f( 3,18, 2) /  6.0005900D-02 ,  5.3326000D-02 /
      data f( 3,18, 3),f( 3,18, 4) /  4.8710500D-02 ,  5.3326000D-02 /
      data f( 3,18, 5),f( 3,18, 6) /  6.0005900D-02 ,  5.0184900D-02 /
      data f( 3,18, 7),f( 3,18, 8) /  2.8618900D-02 ,  1.0475500D-02 /
      data f( 3,18, 9),f( 3,18,10) /  3.6227000D-03 ,  1.0475500D-02 /
      data f( 3,18,11),f( 3,18,12) /  2.8618900D-02 ,  5.0184900D-02 /
      data f( 3,18,13),f( 3,18,14) /  6.0005900D-02 ,  5.3326000D-02 /
      data f( 3,18,15),f( 3,18,16) /  4.8710500D-02 ,  5.3326000D-02 /
      data f( 3,18,17) /              6.0005900D-02 /
      data f( 3,19, 1),f( 3,19, 2) /  4.5471800D-02 ,  4.5471800D-02 /
      data f( 3,19, 3),f( 3,19, 4) /  4.5471800D-02 ,  4.5471800D-02 /
      data f( 3,19, 5),f( 3,19, 6) /  4.5471800D-02 ,  4.5471800D-02 /
      data f( 3,19, 7),f( 3,19, 8) /  4.5471800D-02 ,  4.5471800D-02 /
      data f( 3,19, 9),f( 3,19,10) /  4.5471800D-02 ,  4.5471800D-02 /
      data f( 3,19,11),f( 3,19,12) /  4.5471800D-02 ,  4.5471800D-02 /
      data f( 3,19,13),f( 3,19,14) /  4.5471800D-02 ,  4.5471800D-02 /
      data f( 3,19,15),f( 3,19,16) /  4.5471800D-02 ,  4.5471800D-02 /
      data f( 3,19,17) /              4.5471800D-02 /
      data f( 4, 1, 1),f( 4, 1, 2) /  3.4467900D-02 ,  3.4467900D-02 /
      data f( 4, 1, 3),f( 4, 1, 4) /  3.4467900D-02 ,  3.4467900D-02 /
      data f( 4, 1, 5),f( 4, 1, 6) /  3.4467900D-02 ,  3.4467900D-02 /
      data f( 4, 1, 7),f( 4, 1, 8) /  3.4467900D-02 ,  3.4467900D-02 /
      data f( 4, 1, 9),f( 4, 1,10) /  3.4467900D-02 ,  3.4467900D-02 /
      data f( 4, 1,11),f( 4, 1,12) /  3.4467900D-02 ,  3.4467900D-02 /
      data f( 4, 1,13),f( 4, 1,14) /  3.4467900D-02 ,  3.4467900D-02 /
      data f( 4, 1,15),f( 4, 1,16) /  3.4467900D-02 ,  3.4467900D-02 /
      data f( 4, 1,17) /              3.4467900D-02 /
      data f( 4, 2, 1),f( 4, 2, 2) /  3.3297700D-02 ,  3.0366800D-02 /
      data f( 4, 2, 3),f( 4, 2, 4) /  2.8962400D-02 ,  3.0366800D-02 /
      data f( 4, 2, 5),f( 4, 2, 6) /  3.3297700D-02 ,  3.5367500D-02 /
      data f( 4, 2, 7),f( 4, 2, 8) /  3.5427400D-02 ,  3.4327200D-02 /
      data f( 4, 2, 9),f( 4, 2,10) /  3.3704700D-02 ,  3.4327200D-02 /
      data f( 4, 2,11),f( 4, 2,12) /  3.5427400D-02 ,  3.5367500D-02 /
      data f( 4, 2,13),f( 4, 2,14) /  3.3297700D-02 ,  3.0366800D-02 /
      data f( 4, 2,15),f( 4, 2,16) /  2.8962400D-02 ,  3.0366800D-02 /
      data f( 4, 2,17) /              3.3297700D-02 /
      data f( 4, 3, 1),f( 4, 3, 2) /  3.1407800D-02 ,  2.2748900D-02 /
      data f( 4, 3, 3),f( 4, 3, 4) /  1.8136700D-02 ,  2.2748900D-02 /
      data f( 4, 3, 5),f( 4, 3, 6) /  3.1407800D-02 ,  3.6451600D-02 /
      data f( 4, 3, 7),f( 4, 3, 8) /  3.5337100D-02 ,  3.1380400D-02 /
      data f( 4, 3, 9),f( 4, 3,10) /  2.9360600D-02 ,  3.1380400D-02 /
      data f( 4, 3,11),f( 4, 3,12) /  3.5337100D-02 ,  3.6451600D-02 /
      data f( 4, 3,13),f( 4, 3,14) /  3.1407800D-02 ,  2.2748900D-02 /
      data f( 4, 3,15),f( 4, 3,16) /  1.8136700D-02 ,  2.2748900D-02 /
      data f( 4, 3,17) /              3.1407800D-02 /
      data f( 4, 4, 1),f( 4, 4, 2) /  2.7748100D-02 ,  1.4583100D-02 /
      data f( 4, 4, 3),f( 4, 4, 4) /  7.1059000D-03 ,  1.4583100D-02 /
      data f( 4, 4, 5),f( 4, 4, 6) /  2.7748100D-02 ,  3.4395800D-02 /
      data f( 4, 4, 7),f( 4, 4, 8) /  3.3035700D-02 ,  2.7179500D-02 /
      data f( 4, 4, 9),f( 4, 4,10) /  2.4208100D-02 ,  2.7179500D-02 /
      data f( 4, 4,11),f( 4, 4,12) /  3.3035700D-02 ,  3.4395800D-02 /
      data f( 4, 4,13),f( 4, 4,14) /  2.7748100D-02 ,  1.4583100D-02 /
      data f( 4, 4,15),f( 4, 4,16) /  7.1059000D-03 ,  1.4583100D-02 /
      data f( 4, 4,17) /              2.7748100D-02 /
      data f( 4, 5, 1),f( 4, 5, 2) /  2.2209900D-02 ,  9.1089000D-03 /
      data f( 4, 5, 3),f( 4, 5, 4) /  1.4320000D-03 ,  9.1089000D-03 /
      data f( 4, 5, 5),f( 4, 5, 6) /  2.2209900D-02 ,  2.8204000D-02 /
      data f( 4, 5, 7),f( 4, 5, 8) /  2.9174500D-02 ,  2.2660200D-02 /
      data f( 4, 5, 9),f( 4, 5,10) /  1.9363300D-02 ,  2.2660200D-02 /
      data f( 4, 5,11),f( 4, 5,12) /  2.9174500D-02 ,  2.8204000D-02 /
      data f( 4, 5,13),f( 4, 5,14) /  2.2209900D-02 ,  9.1089000D-03 /
      data f( 4, 5,15),f( 4, 5,16) /  1.4320000D-03 ,  9.1089000D-03 /
      data f( 4, 5,17) /              2.2209900D-02 /
      data f( 4, 6, 1),f( 4, 6, 2) /  1.6060200D-02 ,  7.6830000D-03 /
      data f( 4, 6, 3),f( 4, 6, 4) / -2.3830000D-04 ,  7.6830000D-03 /
      data f( 4, 6, 5),f( 4, 6, 6) /  1.6060200D-02 ,  2.0299200D-02 /
      data f( 4, 6, 7),f( 4, 6, 8) /  2.2376000D-02 ,  1.8485800D-02 /
      data f( 4, 6, 9),f( 4, 6,10) /  1.5114100D-02 ,  1.8485800D-02 /
      data f( 4, 6,11),f( 4, 6,12) /  2.2376000D-02 ,  2.0299200D-02 /
      data f( 4, 6,13),f( 4, 6,14) /  1.6060200D-02 ,  7.6830000D-03 /
      data f( 4, 6,15),f( 4, 6,16) / -2.3830000D-04 ,  7.6830000D-03 /
      data f( 4, 6,17) /              1.6060200D-02 /
      data f( 4, 7, 1),f( 4, 7, 2) /  1.0593500D-02 ,  8.9993000D-03 /
      data f( 4, 7, 3),f( 4, 7, 4) /  3.4246000D-03 ,  8.9993000D-03 /
      data f( 4, 7, 5),f( 4, 7, 6) /  1.0593500D-02 ,  1.3355400D-02 /
      data f( 4, 7, 7),f( 4, 7, 8) /  1.6073400D-02 ,  1.4727800D-02 /
      data f( 4, 7, 9),f( 4, 7,10) /  1.1122300D-02 ,  1.4727800D-02 /
      data f( 4, 7,11),f( 4, 7,12) /  1.6073400D-02 ,  1.3355400D-02 /
      data f( 4, 7,13),f( 4, 7,14) /  1.0593500D-02 ,  8.9993000D-03 /
      data f( 4, 7,15),f( 4, 7,16) /  3.4246000D-03 ,  8.9993000D-03 /
      data f( 4, 7,17) /              1.0593500D-02 /
      data f( 4, 8, 1),f( 4, 8, 2) /  6.3190000D-03 ,  9.3543000D-03 /
      data f( 4, 8, 3),f( 4, 8, 4) /  9.3672000D-03 ,  9.3543000D-03 /
      data f( 4, 8, 5),f( 4, 8, 6) /  6.3190000D-03 ,  8.2983000D-03 /
      data f( 4, 8, 7),f( 4, 8, 8) /  1.2025000D-02 ,  1.0236400D-02 /
      data f( 4, 8, 9),f( 4, 8,10) /  6.5061000D-03 ,  1.0236400D-02 /
      data f( 4, 8,11),f( 4, 8,12) /  1.2025000D-02 ,  8.2983000D-03 /
      data f( 4, 8,13),f( 4, 8,14) /  6.3190000D-03 ,  9.3543000D-03 /
      data f( 4, 8,15),f( 4, 8,16) /  9.3672000D-03 ,  9.3543000D-03 /
      data f( 4, 8,17) /              6.3190000D-03 /
      data f( 4, 9, 1),f( 4, 9, 2) /  3.2152000D-03 ,  6.3666000D-03 /
      data f( 4, 9, 3),f( 4, 9, 4) /  9.0485000D-03 ,  6.3666000D-03 /
      data f( 4, 9, 5),f( 4, 9, 6) /  3.2152000D-03 ,  5.3738000D-03 /
      data f( 4, 9, 7),f( 4, 9, 8) /  7.9891000D-03 ,  4.2558000D-03 /
      data f( 4, 9, 9),f( 4, 9,10) /  3.5900000D-04 ,  4.2558000D-03 /
      data f( 4, 9,11),f( 4, 9,12) /  7.9891000D-03 ,  5.3738000D-03 /
      data f( 4, 9,13),f( 4, 9,14) /  3.2152000D-03 ,  6.3666000D-03 /
      data f( 4, 9,15),f( 4, 9,16) /  9.0485000D-03 ,  6.3666000D-03 /
      data f( 4, 9,17) /              3.2152000D-03 /
      data f( 4,10, 1),f( 4,10, 2) /  1.2038000D-03 ,  4.3940000D-04 /
      data f( 4,10, 3),f( 4,10, 4) /  1.8521000D-03 ,  4.3940000D-04 /
      data f( 4,10, 5),f( 4,10, 6) /  1.2038000D-03 ,  4.9510000D-03 /
      data f( 4,10, 7),f( 4,10, 8) /  4.0443000D-03 , -3.2321000D-03 /
      data f( 4,10, 9),f( 4,10,10) / -7.8269000D-03 , -3.2321000D-03 /
      data f( 4,10,11),f( 4,10,12) /  4.0443000D-03 ,  4.9510000D-03 /
      data f( 4,10,13),f( 4,10,14) /  1.2038000D-03 ,  4.3940000D-04 /
      data f( 4,10,15),f( 4,10,16) /  1.8521000D-03 ,  4.3940000D-04 /
      data f( 4,10,17) /              1.2038000D-03 /
      data f( 4,11, 1),f( 4,11, 2) /  4.6950000D-04 , -7.0155000D-03 /
      data f( 4,11, 3),f( 4,11, 4) / -8.6005000D-03 , -7.0155000D-03 /
      data f( 4,11, 5),f( 4,11, 6) /  4.6950000D-04 ,  7.5959000D-03 /
      data f( 4,11, 7),f( 4,11, 8) /  7.7840000D-04 , -1.2046900D-02 /
      data f( 4,11, 9),f( 4,11,10) / -1.8010000D-02 , -1.2046900D-02 /
      data f( 4,11,11),f( 4,11,12) /  7.7840000D-04 ,  7.5959000D-03 /
      data f( 4,11,13),f( 4,11,14) /  4.6950000D-04 , -7.0155000D-03 /
      data f( 4,11,15),f( 4,11,16) / -8.6005000D-03 , -7.0155000D-03 /
      data f( 4,11,17) /              4.6950000D-04 /
      data f( 4,12, 1),f( 4,12, 2) /  1.6255000D-03 , -1.4441200D-02 /
      data f( 4,12, 3),f( 4,12, 4) / -1.9429600D-02 , -1.4441200D-02 /
      data f( 4,12, 5),f( 4,12, 6) /  1.6255000D-03 ,  1.4172700D-02 /
      data f( 4,12, 7),f( 4,12, 8) / -1.4669000D-03 , -2.1648500D-02 /
      data f( 4,12, 9),f( 4,12,10) / -2.9524300D-02 , -2.1648500D-02 /
      data f( 4,12,11),f( 4,12,12) / -1.4669000D-03 ,  1.4172700D-02 /
      data f( 4,12,13),f( 4,12,14) /  1.6255000D-03 , -1.4441200D-02 /
      data f( 4,12,15),f( 4,12,16) / -1.9429600D-02 , -1.4441200D-02 /
      data f( 4,12,17) /              1.6255000D-03 /
      data f( 4,13, 1),f( 4,13, 2) /  5.7172000D-03 , -1.9952500D-02 /
      data f( 4,13, 3),f( 4,13, 4) / -2.8334700D-02 , -1.9952500D-02 /
      data f( 4,13, 5),f( 4,13, 6) /  5.7172000D-03 ,  2.5432900D-02 /
      data f( 4,13, 7),f( 4,13, 8) / -2.1927000D-03 , -3.0828900D-02 /
      data f( 4,13, 9),f( 4,13,10) / -4.0939600D-02 , -3.0828900D-02 /
      data f( 4,13,11),f( 4,13,12) / -2.1927000D-03 ,  2.5432900D-02 /
      data f( 4,13,13),f( 4,13,14) /  5.7172000D-03 , -1.9952500D-02 /
      data f( 4,13,15),f( 4,13,16) / -2.8334700D-02 , -1.9952500D-02 /
      data f( 4,13,17) /              5.7172000D-03 /
      data f( 4,14, 1),f( 4,14, 2) /  1.4302200D-02 , -2.1120600D-02 /
      data f( 4,14, 3),f( 4,14, 4) / -3.2660200D-02 , -2.1120600D-02 /
      data f( 4,14, 5),f( 4,14, 6) /  1.4302200D-02 ,  4.1307000D-02 /
      data f( 4,14, 7),f( 4,14, 8) / -8.0800000D-04 , -3.7554200D-02 /
      data f( 4,14, 9),f( 4,14,10) / -4.9869100D-02 , -3.7554200D-02 /
      data f( 4,14,11),f( 4,14,12) / -8.0800000D-04 ,  4.1307000D-02 /
      data f( 4,14,13),f( 4,14,14) /  1.4302200D-02 , -2.1120600D-02 /
      data f( 4,14,15),f( 4,14,16) / -3.2660200D-02 , -2.1120600D-02 /
      data f( 4,14,17) /              1.4302200D-02 /
      data f( 4,15, 1),f( 4,15, 2) /  2.7539000D-02 , -1.5284400D-02 /
      data f( 4,15, 3),f( 4,15, 4) / -2.9140800D-02 , -1.5284400D-02 /
      data f( 4,15, 5),f( 4,15, 6) /  2.7539000D-02 ,  5.7513100D-02 /
      data f( 4,15, 7),f( 4,15, 8) /  2.8962000D-03 , -3.9066400D-02 /
      data f( 4,15, 9),f( 4,15,10) / -5.2945500D-02 , -3.9066400D-02 /
      data f( 4,15,11),f( 4,15,12) /  2.8962000D-03 ,  5.7513100D-02 /
      data f( 4,15,13),f( 4,15,14) /  2.7539000D-02 , -1.5284400D-02 /
      data f( 4,15,15),f( 4,15,16) / -2.9140800D-02 , -1.5284400D-02 /
      data f( 4,15,17) /              2.7539000D-02 /
      data f( 4,16, 1),f( 4,16, 2) /  3.9803700D-02 , -7.1880000D-04 /
      data f( 4,16, 3),f( 4,16, 4) / -1.4762900D-02 , -7.1880000D-04 /
      data f( 4,16, 5),f( 4,16, 6) /  3.9803700D-02 ,  6.0805100D-02 /
      data f( 4,16, 7),f( 4,16, 8) /  8.3195000D-03 , -3.2435900D-02 /
      data f( 4,16, 9),f( 4,16,10) / -4.6293300D-02 , -3.2435900D-02 /
      data f( 4,16,11),f( 4,16,12) /  8.3195000D-03 ,  6.0805100D-02 /
      data f( 4,16,13),f( 4,16,14) /  3.9803700D-02 , -7.1880000D-04 /
      data f( 4,16,15),f( 4,16,16) / -1.4762900D-02 , -7.1880000D-04 /
      data f( 4,16,17) /              3.9803700D-02 /
      data f( 4,17, 1),f( 4,17, 2) /  4.7240300D-02 ,  2.1358400D-02 /
      data f( 4,17, 3),f( 4,17, 4) /  1.0746000D-02 ,  2.1358400D-02 /
      data f( 4,17, 5),f( 4,17, 6) /  4.7240300D-02 ,  5.1032100D-02 /
      data f( 4,17, 7),f( 4,17, 8) /  1.5254200D-02 , -1.5715000D-02 /
      data f( 4,17, 9),f( 4,17,10) / -2.6927500D-02 , -1.5715000D-02 /
      data f( 4,17,11),f( 4,17,12) /  1.5254200D-02 ,  5.1032100D-02 /
      data f( 4,17,13),f( 4,17,14) /  4.7240300D-02 ,  2.1358400D-02 /
      data f( 4,17,15),f( 4,17,16) /  1.0746000D-02 ,  2.1358400D-02 /
      data f( 4,17,17) /              4.7240300D-02 /
      data f( 4,18, 1),f( 4,18, 2) /  4.6461000D-02 ,  4.1735300D-02 /
      data f( 4,18, 3),f( 4,18, 4) /  3.8456100D-02 ,  4.1735300D-02 /
      data f( 4,18, 5),f( 4,18, 6) /  4.6461000D-02 ,  4.0853100D-02 /
      data f( 4,18, 7),f( 4,18, 8) /  2.4905800D-02 ,  1.0110100D-02 /
      data f( 4,18, 9),f( 4,18,10) /  4.3723000D-03 ,  1.0110100D-02 /
      data f( 4,18,11),f( 4,18,12) /  2.4905800D-02 ,  4.0853100D-02 /
      data f( 4,18,13),f( 4,18,14) /  4.6461000D-02 ,  4.1735300D-02 /
      data f( 4,18,15),f( 4,18,16) /  3.8456100D-02 ,  4.1735300D-02 /
      data f( 4,18,17) /              4.6461000D-02 /
      data f( 4,19, 1),f( 4,19, 2) /  3.6784700D-02 ,  3.6784700D-02 /
      data f( 4,19, 3),f( 4,19, 4) /  3.6784700D-02 ,  3.6784700D-02 /
      data f( 4,19, 5),f( 4,19, 6) /  3.6784700D-02 ,  3.6784700D-02 /
      data f( 4,19, 7),f( 4,19, 8) /  3.6784700D-02 ,  3.6784700D-02 /
      data f( 4,19, 9),f( 4,19,10) /  3.6784700D-02 ,  3.6784700D-02 /
      data f( 4,19,11),f( 4,19,12) /  3.6784700D-02 ,  3.6784700D-02 /
      data f( 4,19,13),f( 4,19,14) /  3.6784700D-02 ,  3.6784700D-02 /
      data f( 4,19,15),f( 4,19,16) /  3.6784700D-02 ,  3.6784700D-02 /
      data f( 4,19,17) /              3.6784700D-02 /
      data f( 5, 1, 1),f( 5, 1, 2) /  2.5887300D-02 ,  2.5887300D-02 /
      data f( 5, 1, 3),f( 5, 1, 4) /  2.5887300D-02 ,  2.5887300D-02 /
      data f( 5, 1, 5),f( 5, 1, 6) /  2.5887300D-02 ,  2.5887300D-02 /
      data f( 5, 1, 7),f( 5, 1, 8) /  2.5887300D-02 ,  2.5887300D-02 /
      data f( 5, 1, 9),f( 5, 1,10) /  2.5887300D-02 ,  2.5887300D-02 /
      data f( 5, 1,11),f( 5, 1,12) /  2.5887300D-02 ,  2.5887300D-02 /
      data f( 5, 1,13),f( 5, 1,14) /  2.5887300D-02 ,  2.5887300D-02 /
      data f( 5, 1,15),f( 5, 1,16) /  2.5887300D-02 ,  2.5887300D-02 /
      data f( 5, 1,17) /              2.5887300D-02 /
      data f( 5, 2, 1),f( 5, 2, 2) /  2.5042000D-02 ,  2.2788700D-02 /
      data f( 5, 2, 3),f( 5, 2, 4) /  2.1706000D-02 ,  2.2788700D-02 /
      data f( 5, 2, 5),f( 5, 2, 6) /  2.5042000D-02 ,  2.6643400D-02 /
      data f( 5, 2, 7),f( 5, 2, 8) /  2.6701700D-02 ,  2.5838000D-02 /
      data f( 5, 2, 9),f( 5, 2,10) /  2.5340400D-02 ,  2.5838000D-02 /
      data f( 5, 2,11),f( 5, 2,12) /  2.6701700D-02 ,  2.6643400D-02 /
      data f( 5, 2,13),f( 5, 2,14) /  2.5042000D-02 ,  2.2788700D-02 /
      data f( 5, 2,15),f( 5, 2,16) /  2.1706000D-02 ,  2.2788700D-02 /
      data f( 5, 2,17) /              2.5042000D-02 /
      data f( 5, 3, 1),f( 5, 3, 2) /  2.3647900D-02 ,  1.6880400D-02 /
      data f( 5, 3, 3),f( 5, 3, 4) /  1.3158400D-02 ,  1.6880400D-02 /
      data f( 5, 3, 5),f( 5, 3, 6) /  2.3647900D-02 ,  2.7620500D-02 /
      data f( 5, 3, 7),f( 5, 3, 8) /  2.6820100D-02 ,  2.3694600D-02 /
      data f( 5, 3, 9),f( 5, 3,10) /  2.2032600D-02 ,  2.3694600D-02 /
      data f( 5, 3,11),f( 5, 3,12) /  2.6820100D-02 ,  2.7620500D-02 /
      data f( 5, 3,13),f( 5, 3,14) /  2.3647900D-02 ,  1.6880400D-02 /
      data f( 5, 3,15),f( 5, 3,16) /  1.3158400D-02 ,  1.6880400D-02 /
      data f( 5, 3,17) /              2.3647900D-02 /
      data f( 5, 4, 1),f( 5, 4, 2) /  2.0874300D-02 ,  1.0332400D-02 /
      data f( 5, 4, 3),f( 5, 4, 4) /  3.5081000D-03 ,  1.0332400D-02 /
      data f( 5, 4, 5),f( 5, 4, 6) /  2.0874300D-02 ,  2.6220200D-02 /
      data f( 5, 4, 7),f( 5, 4, 8) /  2.4840300D-02 ,  2.0501800D-02 /
      data f( 5, 4, 9),f( 5, 4,10) /  1.8044400D-02 ,  2.0501800D-02 /
      data f( 5, 4,11),f( 5, 4,12) /  2.4840300D-02 ,  2.6220200D-02 /
      data f( 5, 4,13),f( 5, 4,14) /  2.0874300D-02 ,  1.0332400D-02 /
      data f( 5, 4,15),f( 5, 4,16) /  3.5081000D-03 ,  1.0332400D-02 /
      data f( 5, 4,17) /              2.0874300D-02 /
      data f( 5, 5, 1),f( 5, 5, 2) /  1.6680100D-02 ,  5.9834000D-03 /
      data f( 5, 5, 3),f( 5, 5, 4) / -2.4467000D-03 ,  5.9834000D-03 /
      data f( 5, 5, 5),f( 5, 5, 6) /  1.6680100D-02 ,  2.1638400D-02 /
      data f( 5, 5, 7),f( 5, 5, 8) /  2.0997600D-02 ,  1.7071800D-02 /
      data f( 5, 5, 9),f( 5, 5,10) /  1.4344800D-02 ,  1.7071800D-02 /
      data f( 5, 5,11),f( 5, 5,12) /  2.0997600D-02 ,  2.1638400D-02 /
      data f( 5, 5,13),f( 5, 5,14) /  1.6680100D-02 ,  5.9834000D-03 /
      data f( 5, 5,15),f( 5, 5,16) / -2.4467000D-03 ,  5.9834000D-03 /
      data f( 5, 5,17) /              1.6680100D-02 /
      data f( 5, 6, 1),f( 5, 6, 2) /  1.2007300D-02 ,  5.1864000D-03 /
      data f( 5, 6, 3),f( 5, 6, 4) / -2.9988000D-03 ,  5.1864000D-03 /
      data f( 5, 6, 5),f( 5, 6, 6) /  1.2007300D-02 ,  1.5668500D-02 /
      data f( 5, 6, 7),f( 5, 6, 8) /  1.6207200D-02 ,  1.4035000D-02 /
      data f( 5, 6, 9),f( 5, 6,10) /  1.1170300D-02 ,  1.4035000D-02 /
      data f( 5, 6,11),f( 5, 6,12) /  1.6207200D-02 ,  1.5668500D-02 /
      data f( 5, 6,13),f( 5, 6,14) /  1.2007300D-02 ,  5.1864000D-03 /
      data f( 5, 6,15),f( 5, 6,16) / -2.9988000D-03 ,  5.1864000D-03 /
      data f( 5, 6,17) /              1.2007300D-02 /
      data f( 5, 7, 1),f( 5, 7, 2) /  7.8187000D-03 ,  6.5292000D-03 /
      data f( 5, 7, 3),f( 5, 7, 4) /  1.7340000D-03 ,  6.5292000D-03 /
      data f( 5, 7, 5),f( 5, 7, 6) /  7.8187000D-03 ,  1.0242900D-02 /
      data f( 5, 7, 7),f( 5, 7, 8) /  1.2304300D-02 ,  1.1215200D-02 /
      data f( 5, 7, 9),f( 5, 7,10) /  8.1975000D-03 ,  1.1215200D-02 /
      data f( 5, 7,11),f( 5, 7,12) /  1.2304300D-02 ,  1.0242900D-02 /
      data f( 5, 7,13),f( 5, 7,14) /  7.8187000D-03 ,  6.5292000D-03 /
      data f( 5, 7,15),f( 5, 7,16) /  1.7340000D-03 ,  6.5292000D-03 /
      data f( 5, 7,17) /              7.8187000D-03 /
      data f( 5, 8, 1),f( 5, 8, 2) /  4.5254000D-03 ,  6.9220000D-03 /
      data f( 5, 8, 3),f( 5, 8, 4) /  6.9904000D-03 ,  6.9220000D-03 /
      data f( 5, 8, 5),f( 5, 8, 6) /  4.5254000D-03 ,  6.1674000D-03 /
      data f( 5, 8, 7),f( 5, 8, 8) /  9.2298000D-03 ,  7.7154000D-03 /
      data f( 5, 8, 9),f( 5, 8,10) /  4.7223000D-03 ,  7.7154000D-03 /
      data f( 5, 8,11),f( 5, 8,12) /  9.2298000D-03 ,  6.1674000D-03 /
      data f( 5, 8,13),f( 5, 8,14) /  4.5254000D-03 ,  6.9220000D-03 /
      data f( 5, 8,15),f( 5, 8,16) /  6.9904000D-03 ,  6.9220000D-03 /
      data f( 5, 8,17) /              4.5254000D-03 /
      data f( 5, 9, 1),f( 5, 9, 2) /  2.1357000D-03 ,  4.6847000D-03 /
      data f( 5, 9, 3),f( 5, 9, 4) /  6.8134000D-03 ,  4.6847000D-03 /
      data f( 5, 9, 5),f( 5, 9, 6) /  2.1357000D-03 ,  3.7931000D-03 /
      data f( 5, 9, 7),f( 5, 9, 8) /  5.9369000D-03 ,  3.0730000D-03 /
      data f( 5, 9, 9),f( 5, 9,10) /  2.3900000D-05 ,  3.0730000D-03 /
      data f( 5, 9,11),f( 5, 9,12) /  5.9369000D-03 ,  3.7931000D-03 /
      data f( 5, 9,13),f( 5, 9,14) /  2.1357000D-03 ,  4.6847000D-03 /
      data f( 5, 9,15),f( 5, 9,16) /  6.8134000D-03 ,  4.6847000D-03 /
      data f( 5, 9,17) /              2.1357000D-03 /
      data f( 5,10, 1),f( 5,10, 2) /  6.0070000D-04 ,  1.3720000D-04 /
      data f( 5,10, 3),f( 5,10, 4) /  1.3123000D-03 ,  1.3720000D-04 /
      data f( 5,10, 5),f( 5,10, 6) /  6.0070000D-04 ,  3.4416000D-03 /
      data f( 5,10, 7),f( 5,10, 8) /  2.8174000D-03 , -2.7678000D-03 /
      data f( 5,10, 9),f( 5,10,10) / -6.3711000D-03 , -2.7678000D-03 /
      data f( 5,10,11),f( 5,10,12) /  2.8174000D-03 ,  3.4416000D-03 /
      data f( 5,10,13),f( 5,10,14) /  6.0070000D-04 ,  1.3720000D-04 /
      data f( 5,10,15),f( 5,10,16) /  1.3123000D-03 ,  1.3720000D-04 /
      data f( 5,10,17) /              6.0070000D-04 /
      data f( 5,11, 1),f( 5,11, 2) /  8.1800000D-05 , -5.7272000D-03 /
      data f( 5,11, 3),f( 5,11, 4) / -6.9105000D-03 , -5.7272000D-03 /
      data f( 5,11, 5),f( 5,11, 6) /  8.1800000D-05 ,  5.5569000D-03 /
      data f( 5,11, 7),f( 5,11, 8) /  2.9290000D-04 , -9.7736000D-03 /
      data f( 5,11, 9),f( 5,11,10) / -1.4542300D-02 , -9.7736000D-03 /
      data f( 5,11,11),f( 5,11,12) /  2.9290000D-04 ,  5.5569000D-03 /
      data f( 5,11,13),f( 5,11,14) /  8.1800000D-05 , -5.7272000D-03 /
      data f( 5,11,15),f( 5,11,16) / -6.9105000D-03 , -5.7272000D-03 /
      data f( 5,11,17) /              8.1800000D-05 /
      data f( 5,12, 1),f( 5,12, 2) /  1.0983000D-03 , -1.1735900D-02 /
      data f( 5,12, 3),f( 5,12, 4) / -1.5708800D-02 , -1.1735900D-02 /
      data f( 5,12, 5),f( 5,12, 6) /  1.0983000D-03 ,  1.0834600D-02 /
      data f( 5,12, 7),f( 5,12, 8) / -1.3984000D-03 , -1.7588900D-02 /
      data f( 5,12, 9),f( 5,12,10) / -2.4019800D-02 , -1.7588900D-02 /
      data f( 5,12,11),f( 5,12,12) / -1.3984000D-03 ,  1.0834600D-02 /
      data f( 5,12,13),f( 5,12,14) /  1.0983000D-03 , -1.1735900D-02 /
      data f( 5,12,15),f( 5,12,16) / -1.5708800D-02 , -1.1735900D-02 /
      data f( 5,12,17) /              1.0983000D-03 /
      data f( 5,13, 1),f( 5,13, 2) /  4.4776000D-03 , -1.6326000D-02 /
      data f( 5,13, 3),f( 5,13, 4) / -2.3153500D-02 , -1.6326000D-02 /
      data f( 5,13, 5),f( 5,13, 6) /  4.4776000D-03 ,  1.9791000D-02 /
      data f( 5,13, 7),f( 5,13, 8) / -1.8527000D-03 , -2.5217800D-02 /
      data f( 5,13, 9),f( 5,13,10) / -3.3603300D-02 , -2.5217800D-02 /
      data f( 5,13,11),f( 5,13,12) / -1.8527000D-03 ,  1.9791000D-02 /
      data f( 5,13,13),f( 5,13,14) /  4.4776000D-03 , -1.6326000D-02 /
      data f( 5,13,15),f( 5,13,16) / -2.3153500D-02 , -1.6326000D-02 /
      data f( 5,13,17) /              4.4776000D-03 /
      data f( 5,14, 1),f( 5,14, 2) /  1.1203700D-02 , -1.7379600D-02 /
      data f( 5,14, 3),f( 5,14, 4) / -2.6894700D-02 , -1.7379600D-02 /
      data f( 5,14, 5),f( 5,14, 6) /  1.1203700D-02 ,  3.1801400D-02 /
      data f( 5,14, 7),f( 5,14, 8) / -5.6350000D-04 , -3.0880000D-02 /
      data f( 5,14, 9),f( 5,14,10) / -4.1202900D-02 , -3.0880000D-02 /
      data f( 5,14,11),f( 5,14,12) / -5.6350000D-04 ,  3.1801400D-02 /
      data f( 5,14,13),f( 5,14,14) /  1.1203700D-02 , -1.7379600D-02 /
      data f( 5,14,15),f( 5,14,16) / -2.6894700D-02 , -1.7379600D-02 /
      data f( 5,14,17) /              1.1203700D-02 /
      data f( 5,15, 1),f( 5,15, 2) /  2.1276600D-02 , -1.2577000D-02 /
      data f( 5,15, 3),f( 5,15, 4) / -2.4065000D-02 , -1.2577000D-02 /
      data f( 5,15, 5),f( 5,15, 6) /  2.1276600D-02 ,  4.3158400D-02 /
      data f( 5,15, 7),f( 5,15, 8) /  2.6588000D-03 , -3.2142200D-02 /
      data f( 5,15, 9),f( 5,15,10) / -4.3853800D-02 , -3.2142200D-02 /
      data f( 5,15,11),f( 5,15,12) /  2.6588000D-03 ,  4.3158400D-02 /
      data f( 5,15,13),f( 5,15,14) /  2.1276600D-02 , -1.2577000D-02 /
      data f( 5,15,15),f( 5,15,16) / -2.4065000D-02 , -1.2577000D-02 /
      data f( 5,15,17) /              2.1276600D-02 /
      data f( 5,16, 1),f( 5,16, 2) /  3.1148300D-02 , -5.2650000D-04 /
      data f( 5,16, 3),f( 5,16, 4) / -1.2140600D-02 , -5.2650000D-04 /
      data f( 5,16, 5),f( 5,16, 6) /  3.1148300D-02 ,  4.6086900D-02 /
      data f( 5,16, 7),f( 5,16, 8) /  7.3516000D-03 , -2.6469200D-02 /
      data f( 5,16, 9),f( 5,16,10) / -3.8189800D-02 , -2.6469200D-02 /
      data f( 5,16,11),f( 5,16,12) /  7.3516000D-03 ,  4.6086900D-02 /
      data f( 5,16,13),f( 5,16,14) /  3.1148300D-02 , -5.2650000D-04 /
      data f( 5,16,15),f( 5,16,16) / -1.2140600D-02 , -5.2650000D-04 /
      data f( 5,16,17) /              3.1148300D-02 /
      data f( 5,17, 1),f( 5,17, 2) /  3.6794800D-02 ,  1.7180500D-02 /
      data f( 5,17, 3),f( 5,17, 4) /  8.6397000D-03 ,  1.7180500D-02 /
      data f( 5,17, 5),f( 5,17, 6) /  3.6794800D-02 ,  3.9874600D-02 /
      data f( 5,17, 7),f( 5,17, 8) /  1.3122900D-02 , -1.2357100D-02 /
      data f( 5,17, 9),f( 5,17,10) / -2.1779100D-02 , -1.2357100D-02 /
      data f( 5,17,11),f( 5,17,12) /  1.3122900D-02 ,  3.9874600D-02 /
      data f( 5,17,13),f( 5,17,14) /  3.6794800D-02 ,  1.7180500D-02 /
      data f( 5,17,15),f( 5,17,16) /  8.6397000D-03 ,  1.7180500D-02 /
      data f( 5,17,17) /              3.6794800D-02 /
      data f( 5,18, 1),f( 5,18, 2) /  3.5649900D-02 ,  3.2116300D-02 /
      data f( 5,18, 3),f( 5,18, 4) /  2.9690100D-02 ,  3.2116300D-02 /
      data f( 5,18, 5),f( 5,18, 6) /  3.5649900D-02 ,  3.2092800D-02 /
      data f( 5,18, 7),f( 5,18, 8) /  2.0384800D-02 ,  8.7232000D-03 /
      data f( 5,18, 9),f( 5,18,10) /  4.0801000D-03 ,  8.7232000D-03 /
      data f( 5,18,11),f( 5,18,12) /  2.0384800D-02 ,  3.2092800D-02 /
      data f( 5,18,13),f( 5,18,14) /  3.5649900D-02 ,  3.2116300D-02 /
      data f( 5,18,15),f( 5,18,16) /  2.9690100D-02 ,  3.2116300D-02 /
      data f( 5,18,17) /              3.5649900D-02 /
      data f( 5,19, 1),f( 5,19, 2) /  2.8779600D-02 ,  2.8779600D-02 /
      data f( 5,19, 3),f( 5,19, 4) /  2.8779600D-02 ,  2.8779600D-02 /
      data f( 5,19, 5),f( 5,19, 6) /  2.8779600D-02 ,  2.8779600D-02 /
      data f( 5,19, 7),f( 5,19, 8) /  2.8779600D-02 ,  2.8779600D-02 /
      data f( 5,19, 9),f( 5,19,10) /  2.8779600D-02 ,  2.8779600D-02 /
      data f( 5,19,11),f( 5,19,12) /  2.8779600D-02 ,  2.8779600D-02 /
      data f( 5,19,13),f( 5,19,14) /  2.8779600D-02 ,  2.8779600D-02 /
      data f( 5,19,15),f( 5,19,16) /  2.8779600D-02 ,  2.8779600D-02 /
      data f( 5,19,17) /              2.8779600D-02 /
      data f( 6, 1, 1),f( 6, 1, 2) /  1.9234300D-02 ,  1.9234300D-02 /
      data f( 6, 1, 3),f( 6, 1, 4) /  1.9234300D-02 ,  1.9234300D-02 /
      data f( 6, 1, 5),f( 6, 1, 6) /  1.9234300D-02 ,  1.9234300D-02 /
      data f( 6, 1, 7),f( 6, 1, 8) /  1.9234300D-02 ,  1.9234300D-02 /
      data f( 6, 1, 9),f( 6, 1,10) /  1.9234300D-02 ,  1.9234300D-02 /
      data f( 6, 1,11),f( 6, 1,12) /  1.9234300D-02 ,  1.9234300D-02 /
      data f( 6, 1,13),f( 6, 1,14) /  1.9234300D-02 ,  1.9234300D-02 /
      data f( 6, 1,15),f( 6, 1,16) /  1.9234300D-02 ,  1.9234300D-02 /
      data f( 6, 1,17) /              1.9234300D-02 /
      data f( 6, 2, 1),f( 6, 2, 2) /  1.8627000D-02 ,  1.6896400D-02 /
      data f( 6, 2, 3),f( 6, 2, 4) /  1.6065800D-02 ,  1.6896400D-02 /
      data f( 6, 2, 5),f( 6, 2, 6) /  1.8627000D-02 ,  1.9871100D-02 /
      data f( 6, 2, 7),f( 6, 2, 8) /  1.9927800D-02 ,  1.9248400D-02 /
      data f( 6, 2, 9),f( 6, 2,10) /  1.8850000D-02 ,  1.9248400D-02 /
      data f( 6, 2,11),f( 6, 2,12) /  1.9927800D-02 ,  1.9871100D-02 /
      data f( 6, 2,13),f( 6, 2,14) /  1.8627000D-02 ,  1.6896400D-02 /
      data f( 6, 2,15),f( 6, 2,16) /  1.6065800D-02 ,  1.6896400D-02 /
      data f( 6, 2,17) /              1.8627000D-02 /
      data f( 6, 3, 1),f( 6, 3, 2) /  1.7617400D-02 ,  1.2373900D-02 /
      data f( 6, 3, 3),f( 6, 3, 4) /  9.4452000D-03 ,  1.2373900D-02 /
      data f( 6, 3, 5),f( 6, 3, 6) /  1.7617400D-02 ,  2.0765200D-02 /
      data f( 6, 3, 7),f( 6, 3, 8) /  2.0221500D-02 ,  1.7726700D-02 /
      data f( 6, 3, 9),f( 6, 3,10) /  1.6351000D-02 ,  1.7726700D-02 /
      data f( 6, 3,11),f( 6, 3,12) /  2.0221500D-02 ,  2.0765200D-02 /
      data f( 6, 3,13),f( 6, 3,14) /  1.7617400D-02 ,  1.2373900D-02 /
      data f( 6, 3,15),f( 6, 3,16) /  9.4452000D-03 ,  1.2373900D-02 /
      data f( 6, 3,17) /              1.7617400D-02 /
      data f( 6, 4, 1),f( 6, 4, 2) /  1.5545900D-02 ,  7.2671000D-03 /
      data f( 6, 4, 3),f( 6, 4, 4) /  1.5482000D-03 ,  7.2671000D-03 /
      data f( 6, 4, 5),f( 6, 4, 6) /  1.5545900D-02 ,  1.9885700D-02 /
      data f( 6, 4, 7),f( 6, 4, 8) /  1.8825400D-02 ,  1.5387000D-02 /
      data f( 6, 4, 9),f( 6, 4,10) /  1.3301700D-02 ,  1.5387000D-02 /
      data f( 6, 4,11),f( 6, 4,12) /  1.8825400D-02 ,  1.9885700D-02 /
      data f( 6, 4,13),f( 6, 4,14) /  1.5545900D-02 ,  7.2671000D-03 /
      data f( 6, 4,15),f( 6, 4,16) /  1.5482000D-03 ,  7.2671000D-03 /
      data f( 6, 4,17) /              1.5545900D-02 /
      data f( 6, 5, 1),f( 6, 5, 2) /  1.2395400D-02 ,  3.9223000D-03 /
      data f( 6, 5, 3),f( 6, 5, 4) / -3.6677000D-03 ,  3.9223000D-03 /
      data f( 6, 5, 5),f( 6, 5, 6) /  1.2395400D-02 ,  1.6547100D-02 /
      data f( 6, 5, 7),f( 6, 5, 8) /  1.5719300D-02 ,  1.2853500D-02 /
      data f( 6, 5, 9),f( 6, 5,10) /  1.0505500D-02 ,  1.2853500D-02 /
      data f( 6, 5,11),f( 6, 5,12) /  1.5719300D-02 ,  1.6547100D-02 /
      data f( 6, 5,13),f( 6, 5,14) /  1.2395400D-02 ,  3.9223000D-03 /
      data f( 6, 5,15),f( 6, 5,16) / -3.6677000D-03 ,  3.9223000D-03 /
      data f( 6, 5,17) /              1.2395400D-02 /
      data f( 6, 6, 1),f( 6, 6, 2) /  8.8649000D-03 ,  3.4949000D-03 /
      data f( 6, 6, 3),f( 6, 6, 4) / -3.6480000D-03 ,  3.4949000D-03 /
      data f( 6, 6, 5),f( 6, 6, 6) /  8.8649000D-03 ,  1.2022300D-02 /
      data f( 6, 6, 7),f( 6, 6, 8) /  1.2243600D-02 ,  1.0613000D-02 /
      data f( 6, 6, 9),f( 6, 6,10) /  8.1476000D-03 ,  1.0613000D-02 /
      data f( 6, 6,11),f( 6, 6,12) /  1.2243600D-02 ,  1.2022300D-02 /
      data f( 6, 6,13),f( 6, 6,14) /  8.8649000D-03 ,  3.4949000D-03 /
      data f( 6, 6,15),f( 6, 6,16) / -3.6480000D-03 ,  3.4949000D-03 /
      data f( 6, 6,17) /              8.8649000D-03 /
      data f( 6, 7, 1),f( 6, 7, 2) /  5.6778000D-03 ,  4.6814000D-03 /
      data f( 6, 7, 3),f( 6, 7, 4) /  8.9800000D-04 ,  4.6814000D-03 /
      data f( 6, 7, 5),f( 6, 7, 6) /  5.6778000D-03 ,  7.7633000D-03 /
      data f( 6, 7, 7),f( 6, 7, 8) /  9.4947000D-03 ,  8.4465000D-03 /
      data f( 6, 7, 9),f( 6, 7,10) /  5.9463000D-03 ,  8.4465000D-03 /
      data f( 6, 7,11),f( 6, 7,12) /  9.4947000D-03 ,  7.7633000D-03 /
      data f( 6, 7,13),f( 6, 7,14) /  5.6778000D-03 ,  4.6814000D-03 /
      data f( 6, 7,15),f( 6, 7,16) /  8.9800000D-04 ,  4.6814000D-03 /
      data f( 6, 7,17) /              5.6778000D-03 /
      data f( 6, 8, 1),f( 6, 8, 2) /  3.1633000D-03 ,  5.0375000D-03 /
      data f( 6, 8, 3),f( 6, 8, 4) /  5.1662000D-03 ,  5.0375000D-03 /
      data f( 6, 8, 5),f( 6, 8, 6) /  3.1633000D-03 ,  4.5007000D-03 /
      data f( 6, 8, 7),f( 6, 8, 8) /  7.0004000D-03 ,  5.7207000D-03 /
      data f( 6, 8, 9),f( 6, 8,10) /  3.3483000D-03 ,  5.7207000D-03 /
      data f( 6, 8,11),f( 6, 8,12) /  7.0004000D-03 ,  4.5007000D-03 /
      data f( 6, 8,13),f( 6, 8,14) /  3.1633000D-03 ,  5.0375000D-03 /
      data f( 6, 8,15),f( 6, 8,16) /  5.1662000D-03 ,  5.0375000D-03 /
      data f( 6, 8,17) /              3.1633000D-03 /
      data f( 6, 9, 1),f( 6, 9, 2) /  1.3404000D-03 ,  3.3711000D-03 /
      data f( 6, 9, 3),f( 6, 9, 4) /  5.0393000D-03 ,  3.3711000D-03 /
      data f( 6, 9, 5),f( 6, 9, 6) /  1.3404000D-03 ,  2.6004000D-03 /
      data f( 6, 9, 7),f( 6, 9, 8) /  4.3277000D-03 ,  2.1450000D-03 /
      data f( 6, 9, 9),f( 6, 9,10) / -2.1600000D-04 ,  2.1450000D-03 /
      data f( 6, 9,11),f( 6, 9,12) /  4.3277000D-03 ,  2.6004000D-03 /
      data f( 6, 9,13),f( 6, 9,14) /  1.3404000D-03 ,  3.3711000D-03 /
      data f( 6, 9,15),f( 6, 9,16) /  5.0393000D-03 ,  3.3711000D-03 /
      data f( 6, 9,17) /              1.3404000D-03 /
      data f( 6,10, 1),f( 6,10, 2) /  1.7580000D-04 , -9.1800000D-05 /
      data f( 6,10, 3),f( 6,10, 4) /  8.6290000D-04 , -9.1800000D-05 /
      data f( 6,10, 5),f( 6,10, 6) /  1.7580000D-04 ,  2.3156000D-03 /
      data f( 6,10, 7),f( 6,10, 8) /  1.8869000D-03 , -2.3704000D-03 /
      data f( 6,10, 9),f( 6,10,10) / -5.1660000D-03 , -2.3704000D-03 /
      data f( 6,10,11),f( 6,10,12) /  1.8869000D-03 ,  2.3156000D-03 /
      data f( 6,10,13),f( 6,10,14) /  1.7580000D-04 , -9.1800000D-05 /
      data f( 6,10,15),f( 6,10,16) /  8.6290000D-04 , -9.1800000D-05 /
      data f( 6,10,17) /              1.7580000D-04 /
      data f( 6,11, 1),f( 6,11, 2) / -1.9160000D-04 , -4.6595000D-03 /
      data f( 6,11, 3),f( 6,11, 4) / -5.5374000D-03 , -4.6595000D-03 /
      data f( 6,11, 5),f( 6,11, 6) / -1.9160000D-04 ,  3.9874000D-03 /
      data f( 6,11, 7),f( 6,11, 8) / -5.1200000D-05 , -7.8776000D-03 /
      data f( 6,11, 9),f( 6,11,10) / -1.1646100D-02 , -7.8776000D-03 /
      data f( 6,11,11),f( 6,11,12) / -5.1200000D-05 ,  3.9874000D-03 /
      data f( 6,11,13),f( 6,11,14) / -1.9160000D-04 , -4.6595000D-03 /
      data f( 6,11,15),f( 6,11,16) / -5.5374000D-03 , -4.6595000D-03 /
      data f( 6,11,17) /             -1.9160000D-04 /
      data f( 6,12, 1),f( 6,12, 2) /  6.7550000D-04 , -9.4594000D-03 /
      data f( 6,12, 3),f( 6,12, 4) / -1.2589200D-02 , -9.4594000D-03 /
      data f( 6,12, 5),f( 6,12, 6) /  6.7550000D-04 ,  8.1686000D-03 /
      data f( 6,12, 7),f( 6,12, 8) / -1.3202000D-03 , -1.4158000D-02 /
      data f( 6,12, 9),f( 6,12,10) / -1.9343600D-02 , -1.4158000D-02 /
      data f( 6,12,11),f( 6,12,12) / -1.3202000D-03 ,  8.1686000D-03 /
      data f( 6,12,13),f( 6,12,14) /  6.7550000D-04 , -9.4594000D-03 /
      data f( 6,12,15),f( 6,12,16) / -1.2589200D-02 , -9.4594000D-03 /
      data f( 6,12,17) /              6.7550000D-04 /
      data f( 6,13, 1),f( 6,13, 2) /  3.4510000D-03 , -1.3225900D-02 /
      data f( 6,13, 3),f( 6,13, 4) / -1.8722800D-02 , -1.3225900D-02 /
      data f( 6,13, 5),f( 6,13, 6) /  3.4510000D-03 ,  1.5242600D-02 /
      data f( 6,13, 7),f( 6,13, 8) / -1.5964000D-03 , -2.0415400D-02 /
      data f( 6,13, 9),f( 6,13,10) / -2.7281600D-02 , -2.0415400D-02 /
      data f( 6,13,11),f( 6,13,12) / -1.5964000D-03 ,  1.5242600D-02 /
      data f( 6,13,13),f( 6,13,14) /  3.4510000D-03 , -1.3225900D-02 /
      data f( 6,13,15),f( 6,13,16) / -1.8722800D-02 , -1.3225900D-02 /
      data f( 6,13,17) /              3.4510000D-03 /
      data f( 6,14, 1),f( 6,14, 2) /  8.7741000D-03 , -1.4161400D-02 /
      data f( 6,14, 3),f( 6,14, 4) / -2.1913900D-02 , -1.4161400D-02 /
      data f( 6,14, 5),f( 6,14, 6) /  8.7741000D-03 ,  2.4453300D-02 /
      data f( 6,14, 7),f( 6,14, 8) / -4.6010000D-04 , -2.5129600D-02 /
      data f( 6,14, 9),f( 6,14,10) / -3.3668400D-02 , -2.5129600D-02 /
      data f( 6,14,11),f( 6,14,12) / -4.6010000D-04 ,  2.4453300D-02 /
      data f( 6,14,13),f( 6,14,14) /  8.7741000D-03 , -1.4161400D-02 /
      data f( 6,14,15),f( 6,14,16) / -2.1913900D-02 , -1.4161400D-02 /
      data f( 6,14,17) /              8.7741000D-03 /
      data f( 6,15, 1),f( 6,15, 2) /  1.6504500D-02 , -1.0291100D-02 /
      data f( 6,15, 3),f( 6,15, 4) / -1.9692500D-02 , -1.0291100D-02 /
      data f( 6,15, 5),f( 6,15, 6) /  1.6504500D-02 ,  3.2735400D-02 /
      data f( 6,15, 7),f( 6,15, 8) /  2.2376000D-03 , -2.6195300D-02 /
      data f( 6,15, 9),f( 6,15,10) / -3.5935600D-02 , -2.6195300D-02 /
      data f( 6,15,11),f( 6,15,12) /  2.2376000D-03 ,  3.2735400D-02 /
      data f( 6,15,13),f( 6,15,14) /  1.6504500D-02 , -1.0291100D-02 /
      data f( 6,15,15),f( 6,15,16) / -1.9692500D-02 , -1.0291100D-02 /
      data f( 6,15,17) /              1.6504500D-02 /
      data f( 6,16, 1),f( 6,16, 2) /  2.4162900D-02 , -5.4050000D-04 /
      data f( 6,16, 3),f( 6,16, 4) / -9.9939000D-03 , -5.4050000D-04 /
      data f( 6,16, 5),f( 6,16, 6) /  2.4162900D-02 ,  3.5061200D-02 /
      data f( 6,16, 7),f( 6,16, 8) /  6.1093000D-03 , -2.1461600D-02 /
      data f( 6,16, 9),f( 6,16,10) / -3.1207900D-02 , -2.1461600D-02 /
      data f( 6,16,11),f( 6,16,12) /  6.1093000D-03 ,  3.5061200D-02 /
      data f( 6,16,13),f( 6,16,14) /  2.4162900D-02 , -5.4050000D-04 /
      data f( 6,16,15),f( 6,16,16) / -9.9939000D-03 , -5.4050000D-04 /
      data f( 6,16,17) /              2.4162900D-02 /
      data f( 6,17, 1),f( 6,17, 2) /  2.8290300D-02 ,  1.3379300D-02 /
      data f( 6,17, 3),f( 6,17, 4) /  6.6143000D-03 ,  1.3379300D-02 /
      data f( 6,17, 5),f( 6,17, 6) /  2.8290300D-02 ,  3.0727100D-02 /
      data f( 6,17, 7),f( 6,17, 8) /  1.0694400D-02 , -9.8175000D-03 /
      data f( 6,17, 9),f( 6,17,10) / -1.7570300D-02 , -9.8175000D-03 /
      data f( 6,17,11),f( 6,17,12) /  1.0694400D-02 ,  3.0727100D-02 /
      data f( 6,17,13),f( 6,17,14) /  2.8290300D-02 ,  1.3379300D-02 /
      data f( 6,17,15),f( 6,17,16) /  6.6143000D-03 ,  1.3379300D-02 /
      data f( 6,17,17) /              2.8290300D-02 /
      data f( 6,18, 1),f( 6,18, 2) /  2.7103200D-02 ,  2.4408400D-02 /
      data f( 6,18, 3),f( 6,18, 4) /  2.2578800D-02 ,  2.4408400D-02 /
      data f( 6,18, 5),f( 6,18, 6) /  2.7103200D-02 ,  2.4715600D-02 /
      data f( 6,18, 7),f( 6,18, 8) /  1.6065000D-02 ,  7.0240000D-03 /
      data f( 6,18, 9),f( 6,18,10) /  3.3461000D-03 ,  7.0240000D-03 /
      data f( 6,18,11),f( 6,18,12) /  1.6065000D-02 ,  2.4715600D-02 /
      data f( 6,18,13),f( 6,18,14) /  2.7103200D-02 ,  2.4408400D-02 /
      data f( 6,18,15),f( 6,18,16) /  2.2578800D-02 ,  2.4408400D-02 /
      data f( 6,18,17) /              2.7103200D-02 /
      data f( 6,19, 1),f( 6,19, 2) /  2.2060400D-02 ,  2.2060400D-02 /
      data f( 6,19, 3),f( 6,19, 4) /  2.2060400D-02 ,  2.2060400D-02 /
      data f( 6,19, 5),f( 6,19, 6) /  2.2060400D-02 ,  2.2060400D-02 /
      data f( 6,19, 7),f( 6,19, 8) /  2.2060400D-02 ,  2.2060400D-02 /
      data f( 6,19, 9),f( 6,19,10) /  2.2060400D-02 ,  2.2060400D-02 /
      data f( 6,19,11),f( 6,19,12) /  2.2060400D-02 ,  2.2060400D-02 /
      data f( 6,19,13),f( 6,19,14) /  2.2060400D-02 ,  2.2060400D-02 /
      data f( 6,19,15),f( 6,19,16) /  2.2060400D-02 ,  2.2060400D-02 /
      data f( 6,19,17) /              2.2060400D-02 /
      data f( 7, 1, 1),f( 7, 1, 2) /  8.6759000D-03 ,  8.6759000D-03 /
      data f( 7, 1, 3),f( 7, 1, 4) /  8.6759000D-03 ,  8.6759000D-03 /
      data f( 7, 1, 5),f( 7, 1, 6) /  8.6759000D-03 ,  8.6759000D-03 /
      data f( 7, 1, 7),f( 7, 1, 8) /  8.6759000D-03 ,  8.6759000D-03 /
      data f( 7, 1, 9),f( 7, 1,10) /  8.6759000D-03 ,  8.6759000D-03 /
      data f( 7, 1,11),f( 7, 1,12) /  8.6759000D-03 ,  8.6759000D-03 /
      data f( 7, 1,13),f( 7, 1,14) /  8.6759000D-03 ,  8.6759000D-03 /
      data f( 7, 1,15),f( 7, 1,16) /  8.6759000D-03 ,  8.6759000D-03 /
      data f( 7, 1,17) /              8.6759000D-03 /
      data f( 7, 2, 1),f( 7, 2, 2) /  8.4223000D-03 ,  7.5401000D-03 /
      data f( 7, 2, 3),f( 7, 2, 4) /  7.1213000D-03 ,  7.5401000D-03 /
      data f( 7, 2, 5),f( 7, 2, 6) /  8.4223000D-03 ,  9.0763000D-03 /
      data f( 7, 2, 7),f( 7, 2, 8) /  9.1203000D-03 ,  8.7552000D-03 /
      data f( 7, 2, 9),f( 7, 2,10) /  8.5342000D-03 ,  8.7552000D-03 /
      data f( 7, 2,11),f( 7, 2,12) /  9.1203000D-03 ,  9.0763000D-03 /
      data f( 7, 2,13),f( 7, 2,14) /  8.4223000D-03 ,  7.5401000D-03 /
      data f( 7, 2,15),f( 7, 2,16) /  7.1213000D-03 ,  7.5401000D-03 /
      data f( 7, 2,17) /              8.4223000D-03 /
      data f( 7, 3, 1),f( 7, 3, 2) /  8.0086000D-03 ,  5.3313000D-03 /
      data f( 7, 3, 3),f( 7, 3, 4) /  3.8451000D-03 ,  5.3313000D-03 /
      data f( 7, 3, 5),f( 7, 3, 6) /  8.0086000D-03 ,  9.7388000D-03 /
      data f( 7, 3, 7),f( 7, 3, 8) /  9.5718000D-03 ,  8.1649000D-03 /
      data f( 7, 3, 9),f( 7, 3,10) /  7.3400000D-03 ,  8.1649000D-03 /
      data f( 7, 3,11),f( 7, 3,12) /  9.5718000D-03 ,  9.7388000D-03 /
      data f( 7, 3,13),f( 7, 3,14) /  8.0086000D-03 ,  5.3313000D-03 /
      data f( 7, 3,15),f( 7, 3,16) /  3.8451000D-03 ,  5.3313000D-03 /
      data f( 7, 3,17) /              8.0086000D-03 /
      data f( 7, 4, 1),f( 7, 4, 2) /  7.0593000D-03 ,  2.8035000D-03 /
      data f( 7, 4, 3),f( 7, 4, 4) / -2.2130000D-04 ,  2.8035000D-03 /
      data f( 7, 4, 5),f( 7, 4, 6) /  7.0593000D-03 ,  9.5804000D-03 /
      data f( 7, 4, 7),f( 7, 4, 8) /  9.2843000D-03 ,  7.1944000D-03 /
      data f( 7, 4, 9),f( 7, 4,10) /  5.8457000D-03 ,  7.1944000D-03 /
      data f( 7, 4,11),f( 7, 4,12) /  9.2843000D-03 ,  9.5804000D-03 /
      data f( 7, 4,13),f( 7, 4,14) /  7.0593000D-03 ,  2.8035000D-03 /
      data f( 7, 4,15),f( 7, 4,16) / -2.2130000D-04 ,  2.8035000D-03 /
      data f( 7, 4,17) /              7.0593000D-03 /
      data f( 7, 5, 1),f( 7, 5, 2) /  5.5666000D-03 ,  1.2039000D-03 /
      data f( 7, 5, 3),f( 7, 5, 4) / -2.9697000D-03 ,  1.2039000D-03 /
      data f( 7, 5, 5),f( 7, 5, 6) /  5.5666000D-03 ,  8.1240000D-03 /
      data f( 7, 5, 7),f( 7, 5, 8) /  7.9751000D-03 ,  6.0798000D-03 /
      data f( 7, 5, 9),f( 7, 5,10) /  4.5061000D-03 ,  6.0798000D-03 /
      data f( 7, 5,11),f( 7, 5,12) /  7.9751000D-03 ,  8.1240000D-03 /
      data f( 7, 5,13),f( 7, 5,14) /  5.5666000D-03 ,  1.2039000D-03 /
      data f( 7, 5,15),f( 7, 5,16) / -2.9697000D-03 ,  1.2039000D-03 /
      data f( 7, 5,17) /              5.5666000D-03 /
      data f( 7, 6, 1),f( 7, 6, 2) /  3.8658000D-03 ,  1.1268000D-03 /
      data f( 7, 6, 3),f( 7, 6, 4) / -2.5999000D-03 ,  1.1268000D-03 /
      data f( 7, 6, 5),f( 7, 6, 6) /  3.8658000D-03 ,  5.8708000D-03 /
      data f( 7, 6, 7),f( 7, 6, 8) /  6.3113000D-03 ,  5.0033000D-03 /
      data f( 7, 6, 9),f( 7, 6,10) /  3.4214000D-03 ,  5.0033000D-03 /
      data f( 7, 6,11),f( 7, 6,12) /  6.3113000D-03 ,  5.8708000D-03 /
      data f( 7, 6,13),f( 7, 6,14) /  3.8658000D-03 ,  1.1268000D-03 /
      data f( 7, 6,15),f( 7, 6,16) / -2.5999000D-03 ,  1.1268000D-03 /
      data f( 7, 6,17) /              3.8658000D-03 /
      data f( 7, 7, 1),f( 7, 7, 2) /  2.3163000D-03 ,  1.8103000D-03 /
      data f( 7, 7, 3),f( 7, 7, 4) /  7.1300000D-05 ,  1.8103000D-03 /
      data f( 7, 7, 5),f( 7, 7, 6) /  2.3163000D-03 ,  3.5956000D-03 /
      data f( 7, 7, 7),f( 7, 7, 8) /  4.7717000D-03 ,  3.8710000D-03 /
      data f( 7, 7, 9),f( 7, 7,10) /  2.4248000D-03 ,  3.8710000D-03 /
      data f( 7, 7,11),f( 7, 7,12) /  4.7717000D-03 ,  3.5956000D-03 /
      data f( 7, 7,13),f( 7, 7,14) /  2.3163000D-03 ,  1.8103000D-03 /
      data f( 7, 7,15),f( 7, 7,16) /  7.1300000D-05 ,  1.8103000D-03 /
      data f( 7, 7,17) /              2.3163000D-03 /
      data f( 7, 8, 1),f( 7, 8, 2) /  1.0930000D-03 ,  2.0496000D-03 /
      data f( 7, 8, 3),f( 7, 8, 4) /  2.1986000D-03 ,  2.0496000D-03 /
      data f( 7, 8, 5),f( 7, 8, 6) /  1.0930000D-03 ,  1.8236000D-03 /
      data f( 7, 8, 7),f( 7, 8, 8) /  3.2305000D-03 ,  2.4708000D-03 /
      data f( 7, 8, 9),f( 7, 8,10) /  1.2188000D-03 ,  2.4708000D-03 /
      data f( 7, 8,11),f( 7, 8,12) /  3.2305000D-03 ,  1.8236000D-03 /
      data f( 7, 8,13),f( 7, 8,14) /  1.0930000D-03 ,  2.0496000D-03 /
      data f( 7, 8,15),f( 7, 8,16) /  2.1986000D-03 ,  2.0496000D-03 /
      data f( 7, 8,17) /              1.0930000D-03 /
      data f( 7, 9, 1),f( 7, 9, 2) /  2.0570000D-04 ,  1.2912000D-03 /
      data f( 7, 9, 3),f( 7, 9, 4) /  2.1456000D-03 ,  1.2912000D-03 /
      data f( 7, 9, 5),f( 7, 9, 6) /  2.0570000D-04 ,  8.0650000D-04 /
      data f( 7, 9, 7),f( 7, 9, 8) /  1.7461000D-03 ,  6.8090000D-04 /
      data f( 7, 9, 9),f( 7, 9,10) / -5.1120000D-04 ,  6.8090000D-04 /
      data f( 7, 9,11),f( 7, 9,12) /  1.7461000D-03 ,  8.0650000D-04 /
      data f( 7, 9,13),f( 7, 9,14) /  2.0570000D-04 ,  1.2912000D-03 /
      data f( 7, 9,15),f( 7, 9,16) /  2.1456000D-03 ,  1.2912000D-03 /
      data f( 7, 9,17) /              2.0570000D-04 /
      data f( 7,10, 1),f( 7,10, 2) / -3.6560000D-04 , -4.0760000D-04 /
      data f( 7,10, 3),f( 7,10, 4) /  1.1570000D-04 , -4.0760000D-04 /
      data f( 7,10, 5),f( 7,10, 6) / -3.6560000D-04 ,  6.5810000D-04 /
      data f( 7,10, 7),f( 7,10, 8) /  4.8900000D-04 , -1.6108000D-03 /
      data f( 7,10, 9),f( 7,10,10) / -3.0346000D-03 , -1.6108000D-03 /
      data f( 7,10,11),f( 7,10,12) /  4.8900000D-04 ,  6.5810000D-04 /
      data f( 7,10,13),f( 7,10,14) / -3.6560000D-04 , -4.0760000D-04 /
      data f( 7,10,15),f( 7,10,16) /  1.1570000D-04 , -4.0760000D-04 /
      data f( 7,10,17) /             -3.6560000D-04 /
      data f( 7,11, 1),f( 7,11, 2) / -5.3420000D-04 , -2.7732000D-03 /
      data f( 7,11, 3),f( 7,11, 4) / -3.1811000D-03 , -2.7732000D-03 /
      data f( 7,11, 5),f( 7,11, 6) / -5.3420000D-04 ,  1.5417000D-03 /
      data f( 7,11, 7),f( 7,11, 8) / -4.8620000D-04 , -4.5129000D-03 /
      data f( 7,11, 9),f( 7,11,10) / -6.5109000D-03 , -4.5129000D-03 /
      data f( 7,11,11),f( 7,11,12) / -4.8620000D-04 ,  1.5417000D-03 /
      data f( 7,11,13),f( 7,11,14) / -5.3420000D-04 , -2.7732000D-03 /
      data f( 7,11,15),f( 7,11,16) / -3.1811000D-03 , -2.7732000D-03 /
      data f( 7,11,17) /             -5.3420000D-04 /
      data f( 7,12, 1),f( 7,12, 2) / -2.8200000D-05 , -5.3920000D-03 /
      data f( 7,12, 3),f( 7,12, 4) / -7.0416000D-03 , -5.3920000D-03 /
      data f( 7,12, 5),f( 7,12, 6) / -2.8200000D-05 ,  3.7537000D-03 /
      data f( 7,12, 7),f( 7,12, 8) / -1.1090000D-03 , -7.9769000D-03 /
      data f( 7,12, 9),f( 7,12,10) / -1.0851100D-02 , -7.9769000D-03 /
      data f( 7,12,11),f( 7,12,12) / -1.1090000D-03 ,  3.7537000D-03 /
      data f( 7,12,13),f( 7,12,14) / -2.8200000D-05 , -5.3920000D-03 /
      data f( 7,12,15),f( 7,12,16) / -7.0416000D-03 , -5.3920000D-03 /
      data f( 7,12,17) /             -2.8200000D-05 /
      data f( 7,13, 1),f( 7,13, 2) /  1.5660000D-03 , -7.5579000D-03 /
      data f( 7,13, 3),f( 7,13, 4) / -1.0600800D-02 , -7.5579000D-03 /
      data f( 7,13, 5),f( 7,13, 6) /  1.5660000D-03 ,  7.5056000D-03 /
      data f( 7,13, 7),f( 7,13, 8) / -1.1891000D-03 , -1.1582800D-02 /
      data f( 7,13, 9),f( 7,13,10) / -1.5526300D-02 , -1.1582800D-02 /
      data f( 7,13,11),f( 7,13,12) / -1.1891000D-03 ,  7.5056000D-03 /
      data f( 7,13,13),f( 7,13,14) /  1.5660000D-03 , -7.5579000D-03 /
      data f( 7,13,15),f( 7,13,16) / -1.0600800D-02 , -7.5579000D-03 /
      data f( 7,13,17) /              1.5660000D-03 /
      data f( 7,14, 1),f( 7,14, 2) /  4.5320000D-03 , -8.1851000D-03 /
      data f( 7,14, 3),f( 7,14, 4) / -1.2599900D-02 , -8.1851000D-03 /
      data f( 7,14, 5),f( 7,14, 6) /  4.5320000D-03 ,  1.2274300D-02 /
      data f( 7,14, 7),f( 7,14, 8) / -4.8100000D-04 , -1.4401900D-02 /
      data f( 7,14, 9),f( 7,14,10) / -1.9421400D-02 , -1.4401900D-02 /
      data f( 7,14,11),f( 7,14,12) / -4.8100000D-04 ,  1.2274300D-02 /
      data f( 7,14,13),f( 7,14,14) /  4.5320000D-03 , -8.1851000D-03 /
      data f( 7,14,15),f( 7,14,16) / -1.2599900D-02 , -8.1851000D-03 /
      data f( 7,14,17) /              4.5320000D-03 /
      data f( 7,15, 1),f( 7,15, 2) /  8.5660000D-03 , -6.0738000D-03 /
      data f( 7,15, 3),f( 7,15, 4) / -1.1475500D-02 , -6.0738000D-03 /
      data f( 7,15, 5),f( 7,15, 6) /  8.5660000D-03 ,  1.6325900D-02 /
      data f( 7,15, 7),f( 7,15, 8) /  1.0786000D-03 , -1.5087200D-02 /
      data f( 7,15, 9),f( 7,15,10) / -2.0873100D-02 , -1.5087200D-02 /
      data f( 7,15,11),f( 7,15,12) /  1.0786000D-03 ,  1.6325900D-02 /
      data f( 7,15,13),f( 7,15,14) /  8.5660000D-03 , -6.0738000D-03 /
      data f( 7,15,15),f( 7,15,16) / -1.1475500D-02 , -6.0738000D-03 /
      data f( 7,15,17) /              8.5660000D-03 /
      data f( 7,16, 1),f( 7,16, 2) /  1.2335900D-02 , -7.2310000D-04 /
      data f( 7,16, 3),f( 7,16, 4) / -6.0621000D-03 , -7.2310000D-04 /
      data f( 7,16, 5),f( 7,16, 6) /  1.2335900D-02 ,  1.7471000D-02 /
      data f( 7,16, 7),f( 7,16, 8) /  3.2091000D-03 , -1.2320300D-02 /
      data f( 7,16, 9),f( 7,16,10) / -1.8076500D-02 , -1.2320300D-02 /
      data f( 7,16,11),f( 7,16,12) /  3.2091000D-03 ,  1.7471000D-02 /
      data f( 7,16,13),f( 7,16,14) /  1.2335900D-02 , -7.2310000D-04 /
      data f( 7,16,15),f( 7,16,16) / -6.0621000D-03 , -7.2310000D-04 /
      data f( 7,16,17) /              1.2335900D-02 /
      data f( 7,17, 1),f( 7,17, 2) /  1.4012900D-02 ,  6.4868000D-03 /
      data f( 7,17, 3),f( 7,17, 4) /  2.8761000D-03 ,  6.4868000D-03 /
      data f( 7,17, 5),f( 7,17, 6) /  1.4012900D-02 ,  1.5301700D-02 /
      data f( 7,17, 7),f( 7,17, 8) /  5.5243000D-03 , -5.6588000D-03 /
      data f( 7,17, 9),f( 7,17,10) / -1.0090900D-02 , -5.6588000D-03 /
      data f( 7,17,11),f( 7,17,12) /  5.5243000D-03 ,  1.5301700D-02 /
      data f( 7,17,13),f( 7,17,14) /  1.4012900D-02 ,  6.4868000D-03 /
      data f( 7,17,15),f( 7,17,16) /  2.8761000D-03 ,  6.4868000D-03 /
      data f( 7,17,17) /              1.4012900D-02 /
      data f( 7,18, 1),f( 7,18, 2) /  1.3058200D-02 ,  1.1679500D-02 /
      data f( 7,18, 3),f( 7,18, 4) /  1.0762900D-02 ,  1.1679500D-02 /
      data f( 7,18, 5),f( 7,18, 6) /  1.3058200D-02 ,  1.2075400D-02 /
      data f( 7,18, 7),f( 7,18, 8) /  7.9556000D-03 ,  3.3521000D-03 /
      data f( 7,18, 9),f( 7,18,10) /  1.4128000D-03 ,  3.3521000D-03 /
      data f( 7,18,11),f( 7,18,12) /  7.9556000D-03 ,  1.2075400D-02 /
      data f( 7,18,13),f( 7,18,14) /  1.3058200D-02 ,  1.1679500D-02 /
      data f( 7,18,15),f( 7,18,16) /  1.0762900D-02 ,  1.1679500D-02 /
      data f( 7,18,17) /              1.3058200D-02 /
      data f( 7,19, 1),f( 7,19, 2) /  1.0611900D-02 ,  1.0611900D-02 /
      data f( 7,19, 3),f( 7,19, 4) /  1.0611900D-02 ,  1.0611900D-02 /
      data f( 7,19, 5),f( 7,19, 6) /  1.0611900D-02 ,  1.0611900D-02 /
      data f( 7,19, 7),f( 7,19, 8) /  1.0611900D-02 ,  1.0611900D-02 /
      data f( 7,19, 9),f( 7,19,10) /  1.0611900D-02 ,  1.0611900D-02 /
      data f( 7,19,11),f( 7,19,12) /  1.0611900D-02 ,  1.0611900D-02 /
      data f( 7,19,13),f( 7,19,14) /  1.0611900D-02 ,  1.0611900D-02 /
      data f( 7,19,15),f( 7,19,16) /  1.0611900D-02 ,  1.0611900D-02 /
      data f( 7,19,17) /              1.0611900D-02 /
      data f( 8, 1, 1),f( 8, 1, 2) /  3.5299000D-03 ,  3.5299000D-03 /
      data f( 8, 1, 3),f( 8, 1, 4) /  3.5299000D-03 ,  3.5299000D-03 /
      data f( 8, 1, 5),f( 8, 1, 6) /  3.5299000D-03 ,  3.5299000D-03 /
      data f( 8, 1, 7),f( 8, 1, 8) /  3.5299000D-03 ,  3.5299000D-03 /
      data f( 8, 1, 9),f( 8, 1,10) /  3.5299000D-03 ,  3.5299000D-03 /
      data f( 8, 1,11),f( 8, 1,12) /  3.5299000D-03 ,  3.5299000D-03 /
      data f( 8, 1,13),f( 8, 1,14) /  3.5299000D-03 ,  3.5299000D-03 /
      data f( 8, 1,15),f( 8, 1,16) /  3.5299000D-03 ,  3.5299000D-03 /
      data f( 8, 1,17) /              3.5299000D-03 /
      data f( 8, 2, 1),f( 8, 2, 2) /  3.4275000D-03 ,  2.9873000D-03 /
      data f( 8, 2, 3),f( 8, 2, 4) /  2.7807000D-03 ,  2.9873000D-03 /
      data f( 8, 2, 5),f( 8, 2, 6) /  3.4275000D-03 ,  3.7619000D-03 /
      data f( 8, 2, 7),f( 8, 2, 8) /  3.7896000D-03 ,  3.6015000D-03 /
      data f( 8, 2, 9),f( 8, 2,10) /  3.4854000D-03 ,  3.6015000D-03 /
      data f( 8, 2,11),f( 8, 2,12) /  3.7896000D-03 ,  3.7619000D-03 /
      data f( 8, 2,13),f( 8, 2,14) /  3.4275000D-03 ,  2.9873000D-03 /
      data f( 8, 2,15),f( 8, 2,16) /  2.7807000D-03 ,  2.9873000D-03 /
      data f( 8, 2,17) /              3.4275000D-03 /
      data f( 8, 3, 1),f( 8, 3, 2) /  3.2749000D-03 ,  1.9472000D-03 /
      data f( 8, 3, 3),f( 8, 3, 4) /  1.2291000D-03 ,  1.9472000D-03 /
      data f( 8, 3, 5),f( 8, 3, 6) /  3.2749000D-03 ,  4.1818000D-03 /
      data f( 8, 3, 7),f( 8, 3, 8) /  4.1363000D-03 ,  3.3876000D-03 /
      data f( 8, 3, 9),f( 8, 3,10) /  2.9354000D-03 ,  3.3876000D-03 /
      data f( 8, 3,11),f( 8, 3,12) /  4.1363000D-03 ,  4.1818000D-03 /
      data f( 8, 3,13),f( 8, 3,14) /  3.2749000D-03 ,  1.9472000D-03 /
      data f( 8, 3,15),f( 8, 3,16) /  1.2291000D-03 ,  1.9472000D-03 /
      data f( 8, 3,17) /              3.2749000D-03 /
      data f( 8, 4, 1),f( 8, 4, 2) /  2.8690000D-03 ,  7.6680000D-04 /
      data f( 8, 4, 3),f( 8, 4, 4) / -6.6700000D-04 ,  7.6680000D-04 /
      data f( 8, 4, 5),f( 8, 4, 6) /  2.8690000D-03 ,  4.2291000D-03 /
      data f( 8, 4, 7),f( 8, 4, 8) /  4.1911000D-03 ,  3.0099000D-03 /
      data f( 8, 4, 9),f( 8, 4,10) /  2.2396000D-03 ,  3.0099000D-03 /
      data f( 8, 4,11),f( 8, 4,12) /  4.1911000D-03 ,  4.2291000D-03 /
      data f( 8, 4,13),f( 8, 4,14) /  2.8690000D-03 ,  7.6680000D-04 /
      data f( 8, 4,15),f( 8, 4,16) / -6.6700000D-04 ,  7.6680000D-04 /
      data f( 8, 4,17) /              2.8690000D-03 /
      data f( 8, 5, 1),f( 8, 5, 2) /  2.2008000D-03 ,  4.4100000D-05 /
      data f( 8, 5, 3),f( 8, 5, 4) / -1.8947000D-03 ,  4.4100000D-05 /
      data f( 8, 5, 5),f( 8, 5, 6) /  2.2008000D-03 ,  3.6134000D-03 /
      data f( 8, 5, 7),f( 8, 5, 8) /  3.7176000D-03 ,  2.5423000D-03 /
      data f( 8, 5, 9),f( 8, 5,10) /  1.6356000D-03 ,  2.5423000D-03 /
      data f( 8, 5,11),f( 8, 5,12) /  3.7176000D-03 ,  3.6134000D-03 /
      data f( 8, 5,13),f( 8, 5,14) /  2.2008000D-03 ,  4.4100000D-05 /
      data f( 8, 5,15),f( 8, 5,16) / -1.8947000D-03 ,  4.4100000D-05 /
      data f( 8, 5,17) /              2.2008000D-03 /
      data f( 8, 6, 1),f( 8, 6, 2) /  1.4301000D-03 ,  5.5300000D-05 /
      data f( 8, 6, 3),f( 8, 6, 4) / -1.6273000D-03 ,  5.5300000D-05 /
      data f( 8, 6, 5),f( 8, 6, 6) /  1.4301000D-03 ,  2.5355000D-03 /
      data f( 8, 6, 7),f( 8, 6, 8) /  2.9243000D-03 ,  2.0489000D-03 /
      data f( 8, 6, 9),f( 8, 6,10) /  1.1768000D-03 ,  2.0489000D-03 /
      data f( 8, 6,11),f( 8, 6,12) /  2.9243000D-03 ,  2.5355000D-03 /
      data f( 8, 6,13),f( 8, 6,14) /  1.4301000D-03 ,  5.5300000D-05 /
      data f( 8, 6,15),f( 8, 6,16) / -1.6273000D-03 ,  5.5300000D-05 /
      data f( 8, 6,17) /              1.4301000D-03 /
      data f( 8, 7, 1),f( 8, 7, 2) /  7.3020000D-04 ,  4.3790000D-04 /
      data f( 8, 7, 3),f( 8, 7, 4) / -3.3660000D-04 ,  4.3790000D-04 /
      data f( 8, 7, 5),f( 8, 7, 6) /  7.3020000D-04 ,  1.4043000D-03 /
      data f( 8, 7, 7),f( 8, 7, 8) /  2.0658000D-03 ,  1.5126000D-03 /
      data f( 8, 7, 9),f( 8, 7,10) /  7.7050000D-04 ,  1.5126000D-03 /
      data f( 8, 7,11),f( 8, 7,12) /  2.0658000D-03 ,  1.4043000D-03 /
      data f( 8, 7,13),f( 8, 7,14) /  7.3020000D-04 ,  4.3790000D-04 /
      data f( 8, 7,15),f( 8, 7,16) / -3.3660000D-04 ,  4.3790000D-04 /
      data f( 8, 7,17) /              7.3020000D-04 /
      data f( 8, 8, 1),f( 8, 8, 2) /  1.8120000D-04 ,  6.2140000D-04 /
      data f( 8, 8, 3),f( 8, 8, 4) /  6.8520000D-04 ,  6.2140000D-04 /
      data f( 8, 8, 5),f( 8, 8, 6) /  1.8120000D-04 ,  5.2720000D-04 /
      data f( 8, 8, 7),f( 8, 8, 8) /  1.2345000D-03 ,  8.6010000D-04 /
      data f( 8, 8, 9),f( 8, 8,10) /  2.5340000D-04 ,  8.6010000D-04 /
      data f( 8, 8,11),f( 8, 8,12) /  1.2345000D-03 ,  5.2720000D-04 /
      data f( 8, 8,13),f( 8, 8,14) /  1.8120000D-04 ,  6.2140000D-04 /
      data f( 8, 8,15),f( 8, 8,16) /  6.8520000D-04 ,  6.2140000D-04 /
      data f( 8, 8,17) /              1.8120000D-04 /
      data f( 8, 9, 1),f( 8, 9, 2) / -2.2080000D-04 ,  3.1830000D-04 /
      data f( 8, 9, 3),f( 8, 9, 4) /  7.1690000D-04 ,  3.1830000D-04 /
      data f( 8, 9, 5),f( 8, 9, 6) / -2.2080000D-04 ,  3.7000000D-05 /
      data f( 8, 9, 7),f( 8, 9, 8) /  5.0470000D-04 ,  2.0000000D-05 /
      data f( 8, 9, 9),f( 8, 9,10) / -5.4750000D-04 ,  2.0000000D-05 /
      data f( 8, 9,11),f( 8, 9,12) /  5.0470000D-04 ,  3.7000000D-05 /
      data f( 8, 9,13),f( 8, 9,14) / -2.2080000D-04 ,  3.1830000D-04 /
      data f( 8, 9,15),f( 8, 9,16) /  7.1690000D-04 ,  3.1830000D-04 /
      data f( 8, 9,17) /             -2.2080000D-04 /
      data f( 8,10, 1),f( 8,10, 2) / -4.9330000D-04 , -4.8050000D-04 /
      data f( 8,10, 3),f( 8,10, 4) / -2.1930000D-04 , -4.8050000D-04 /
      data f( 8,10, 5),f( 8,10, 6) / -4.9330000D-04 , -2.4900000D-05 /
      data f( 8,10, 7),f( 8,10, 8) / -9.5100000D-05 , -1.0937000D-03 /
      data f( 8,10, 9),f( 8,10,10) / -1.7861000D-03 , -1.0937000D-03 /
      data f( 8,10,11),f( 8,10,12) / -9.5100000D-05 , -2.4900000D-05 /
      data f( 8,10,13),f( 8,10,14) / -4.9330000D-04 , -4.8050000D-04 /
      data f( 8,10,15),f( 8,10,16) / -2.1930000D-04 , -4.8050000D-04 /
      data f( 8,10,17) /             -4.9330000D-04 /
      data f( 8,11, 1),f( 8,11, 2) / -5.9000000D-04 , -1.6672000D-03 /
      data f( 8,11, 3),f( 8,11, 4) / -1.8529000D-03 , -1.6672000D-03 /
      data f( 8,11, 5),f( 8,11, 6) / -5.9000000D-04 ,  4.1210000D-04 /
      data f( 8,11, 7),f( 8,11, 8) / -5.7150000D-04 , -2.5630000D-03 /
      data f( 8,11, 9),f( 8,11,10) / -3.5692000D-03 , -2.5630000D-03 /
      data f( 8,11,11),f( 8,11,12) / -5.7150000D-04 ,  4.1210000D-04 /
      data f( 8,11,13),f( 8,11,14) / -5.9000000D-04 , -1.6672000D-03 /
      data f( 8,11,15),f( 8,11,16) / -1.8529000D-03 , -1.6672000D-03 /
      data f( 8,11,17) /             -5.9000000D-04 /
      data f( 8,12, 1),f( 8,12, 2) / -3.5340000D-04 , -3.0401000D-03 /
      data f( 8,12, 3),f( 8,12, 4) / -3.8639000D-03 , -3.0401000D-03 /
      data f( 8,12, 5),f( 8,12, 6) / -3.5340000D-04 ,  1.4984000D-03 /
      data f( 8,12, 7),f( 8,12, 8) / -8.9150000D-04 , -4.3801000D-03 /
      data f( 8,12, 9),f( 8,12,10) / -5.8767000D-03 , -4.3801000D-03 /
      data f( 8,12,11),f( 8,12,12) / -8.9150000D-04 ,  1.4984000D-03 /
      data f( 8,12,13),f( 8,12,14) / -3.5340000D-04 , -3.0401000D-03 /
      data f( 8,12,15),f( 8,12,16) / -3.8639000D-03 , -3.0401000D-03 /
      data f( 8,12,17) /             -3.5340000D-04 /
      data f( 8,13, 1),f( 8,13, 2) /  4.5550000D-04 , -4.2197000D-03 /
      data f( 8,13, 3),f( 8,13, 4) / -5.7975000D-03 , -4.2197000D-03 /
      data f( 8,13, 5),f( 8,13, 6) /  4.5550000D-04 ,  3.3486000D-03 /
      data f( 8,13, 7),f( 8,13, 8) / -9.4150000D-04 , -6.3291000D-03 /
      data f( 8,13, 9),f( 8,13,10) / -8.4391000D-03 , -6.3291000D-03 /
      data f( 8,13,11),f( 8,13,12) / -9.4150000D-04 ,  3.3486000D-03 /
      data f( 8,13,13),f( 8,13,14) /  4.5550000D-04 , -4.2197000D-03 /
      data f( 8,13,15),f( 8,13,16) / -5.7975000D-03 , -4.2197000D-03 /
      data f( 8,13,17) /              4.5550000D-04 /
      data f( 8,14, 1),f( 8,14, 2) /  1.9897000D-03 , -4.6031000D-03 /
      data f( 8,14, 3),f( 8,14, 4) / -6.9463000D-03 , -4.6031000D-03 /
      data f( 8,14, 5),f( 8,14, 6) /  1.9897000D-03 ,  5.7060000D-03 /
      data f( 8,14, 7),f( 8,14, 8) / -5.8100000D-04 , -7.8943000D-03 /
      data f( 8,14, 9),f( 8,14,10) / -1.0629200D-02 , -7.8943000D-03 /
      data f( 8,14,11),f( 8,14,12) / -5.8100000D-04 ,  5.7060000D-03 /
      data f( 8,14,13),f( 8,14,14) /  1.9897000D-03 , -4.6031000D-03 /
      data f( 8,14,15),f( 8,14,16) / -6.9463000D-03 , -4.6031000D-03 /
      data f( 8,14,17) /              1.9897000D-03 /
      data f( 8,15, 1),f( 8,15, 2) /  4.0168000D-03 , -3.5370000D-03 /
      data f( 8,15, 3),f( 8,15, 4) / -6.4229000D-03 , -3.5370000D-03 /
      data f( 8,15, 5),f( 8,15, 6) /  4.0168000D-03 ,  7.6781000D-03 /
      data f( 8,15, 7),f( 8,15, 8) /  2.1760000D-04 , -8.3049000D-03 /
      data f( 8,15, 9),f( 8,15,10) / -1.1476800D-02 , -8.3049000D-03 /
      data f( 8,15,11),f( 8,15,12) /  2.1760000D-04 ,  7.6781000D-03 /
      data f( 8,15,13),f( 8,15,14) /  4.0168000D-03 , -3.5370000D-03 /
      data f( 8,15,15),f( 8,15,16) / -6.4229000D-03 , -3.5370000D-03 /
      data f( 8,15,17) /              4.0168000D-03 /
      data f( 8,16, 1),f( 8,16, 2) /  5.7791000D-03 , -8.1390000D-04 /
      data f( 8,16, 3),f( 8,16, 4) / -3.6222000D-03 , -8.1390000D-04 /
      data f( 8,16, 5),f( 8,16, 6) /  5.7791000D-03 ,  8.1954000D-03 /
      data f( 8,16, 7),f( 8,16, 8) /  1.2797000D-03 , -6.8294000D-03 /
      data f( 8,16, 9),f( 8,16,10) / -9.9569000D-03 , -6.8294000D-03 /
      data f( 8,16,11),f( 8,16,12) /  1.2797000D-03 ,  8.1954000D-03 /
      data f( 8,16,13),f( 8,16,14) /  5.7791000D-03 , -8.1390000D-04 /
      data f( 8,16,15),f( 8,16,16) / -3.6222000D-03 , -8.1390000D-04 /
      data f( 8,16,17) /              5.7791000D-03 /
      data f( 8,17, 1),f( 8,17, 2) /  6.4205000D-03 ,  2.7207000D-03 /
      data f( 8,17, 3),f( 8,17, 4) /  8.9290000D-04 ,  2.7207000D-03 /
      data f( 8,17, 5),f( 8,17, 6) /  6.4205000D-03 ,  7.0639000D-03 /
      data f( 8,17, 7),f( 8,17, 8) /  2.3668000D-03 , -3.3292000D-03 /
      data f( 8,17, 9),f( 8,17,10) / -5.6667000D-03 , -3.3292000D-03 /
      data f( 8,17,11),f( 8,17,12) /  2.3668000D-03 ,  7.0639000D-03 /
      data f( 8,17,13),f( 8,17,14) /  6.4205000D-03 ,  2.7207000D-03 /
      data f( 8,17,15),f( 8,17,16) /  8.9290000D-04 ,  2.7207000D-03 /
      data f( 8,17,17) /              6.4205000D-03 /
      data f( 8,18, 1),f( 8,18, 2) /  5.8244000D-03 ,  5.1398000D-03 /
      data f( 8,18, 3),f( 8,18, 4) /  4.6895000D-03 ,  5.1398000D-03 /
      data f( 8,18, 5),f( 8,18, 6) /  5.8244000D-03 ,  5.3943000D-03 /
      data f( 8,18, 7),f( 8,18, 8) /  3.4416000D-03 ,  1.1879000D-03 /
      data f( 8,18, 9),f( 8,18,10) /  2.1980000D-04 ,  1.1879000D-03 /
      data f( 8,18,11),f( 8,18,12) /  3.4416000D-03 ,  5.3943000D-03 /
      data f( 8,18,13),f( 8,18,14) /  5.8244000D-03 ,  5.1398000D-03 /
      data f( 8,18,15),f( 8,18,16) /  4.6895000D-03 ,  5.1398000D-03 /
      data f( 8,18,17) /              5.8244000D-03 /
      data f( 8,19, 1),f( 8,19, 2) /  4.6335000D-03 ,  4.6335000D-03 /
      data f( 8,19, 3),f( 8,19, 4) /  4.6335000D-03 ,  4.6335000D-03 /
      data f( 8,19, 5),f( 8,19, 6) /  4.6335000D-03 ,  4.6335000D-03 /
      data f( 8,19, 7),f( 8,19, 8) /  4.6335000D-03 ,  4.6335000D-03 /
      data f( 8,19, 9),f( 8,19,10) /  4.6335000D-03 ,  4.6335000D-03 /
      data f( 8,19,11),f( 8,19,12) /  4.6335000D-03 ,  4.6335000D-03 /
      data f( 8,19,13),f( 8,19,14) /  4.6335000D-03 ,  4.6335000D-03 /
      data f( 8,19,15),f( 8,19,16) /  4.6335000D-03 ,  4.6335000D-03 /
      data f( 8,19,17) /              4.6335000D-03 /
      data f( 9, 1, 1),f( 9, 1, 2) /  2.1230000D-04 ,  2.1230000D-04 /
      data f( 9, 1, 3),f( 9, 1, 4) /  2.1230000D-04 ,  2.1230000D-04 /
      data f( 9, 1, 5),f( 9, 1, 6) /  2.1230000D-04 ,  2.1230000D-04 /
      data f( 9, 1, 7),f( 9, 1, 8) /  2.1230000D-04 ,  2.1230000D-04 /
      data f( 9, 1, 9),f( 9, 1,10) /  2.1230000D-04 ,  2.1230000D-04 /
      data f( 9, 1,11),f( 9, 1,12) /  2.1230000D-04 ,  2.1230000D-04 /
      data f( 9, 1,13),f( 9, 1,14) /  2.1230000D-04 ,  2.1230000D-04 /
      data f( 9, 1,15),f( 9, 1,16) /  2.1230000D-04 ,  2.1230000D-04 /
      data f( 9, 1,17) /              2.1230000D-04 /
      data f( 9, 2, 1),f( 9, 2, 2) /  1.9270000D-04 ,  8.5100000D-05 /
      data f( 9, 2, 3),f( 9, 2, 4) /  3.4500000D-05 ,  8.5100000D-05 /
      data f( 9, 2, 5),f( 9, 2, 6) /  1.9270000D-04 ,  2.7350000D-04 /
      data f( 9, 2, 7),f( 9, 2, 8) /  2.8020000D-04 ,  2.3590000D-04 /
      data f( 9, 2, 9),f( 9, 2,10) /  2.0880000D-04 ,  2.3590000D-04 /
      data f( 9, 2,11),f( 9, 2,12) /  2.8020000D-04 ,  2.7350000D-04 /
      data f( 9, 2,13),f( 9, 2,14) /  1.9270000D-04 ,  8.5100000D-05 /
      data f( 9, 2,15),f( 9, 2,16) /  3.4500000D-05 ,  8.5100000D-05 /
      data f( 9, 2,17) /              1.9270000D-04 /
      data f( 9, 3, 1),f( 9, 3, 2) /  1.7900000D-04 , -1.4580000D-04 /
      data f( 9, 3, 3),f( 9, 3, 4) / -3.1870000D-04 , -1.4580000D-04 /
      data f( 9, 3, 5),f( 9, 3, 6) /  1.7900000D-04 ,  3.9550000D-04 /
      data f( 9, 3, 7),f( 9, 3, 8) /  3.8150000D-04 ,  2.0360000D-04 /
      data f( 9, 3, 9),f( 9, 3,10) /  9.8400000D-05 ,  2.0360000D-04 /
      data f( 9, 3,11),f( 9, 3,12) /  3.8150000D-04 ,  3.9550000D-04 /
      data f( 9, 3,13),f( 9, 3,14) /  1.7900000D-04 , -1.4580000D-04 /
      data f( 9, 3,15),f( 9, 3,16) / -3.1870000D-04 , -1.4580000D-04 /
      data f( 9, 3,17) /              1.7900000D-04 /
      data f( 9, 4, 1),f( 9, 4, 2) /  1.2600000D-04 , -3.9250000D-04 /
      data f( 9, 4, 3),f( 9, 4, 4) / -7.2520000D-04 , -3.9250000D-04 /
      data f( 9, 4, 5),f( 9, 4, 6) /  1.2600000D-04 ,  4.4800000D-04 /
      data f( 9, 4, 7),f( 9, 4, 8) /  4.3320000D-04 ,  1.4870000D-04 /
      data f( 9, 4, 9),f( 9, 4,10) / -2.8800000D-05 ,  1.4870000D-04 /
      data f( 9, 4,11),f( 9, 4,12) /  4.3320000D-04 ,  4.4800000D-04 /
      data f( 9, 4,13),f( 9, 4,14) /  1.2600000D-04 , -3.9250000D-04 /
      data f( 9, 4,15),f( 9, 4,16) / -7.2520000D-04 , -3.9250000D-04 /
      data f( 9, 4,17) /              1.2600000D-04 /
      data f( 9, 5, 1),f( 9, 5, 2) /  2.8700000D-05 , -5.2080000D-04 /
      data f( 9, 5, 3),f( 9, 5, 4) / -9.6370000D-04 , -5.2080000D-04 /
      data f( 9, 5, 5),f( 9, 5, 6) /  2.8700000D-05 ,  3.5610000D-04 /
      data f( 9, 5, 7),f( 9, 5, 8) /  3.6860000D-04 ,  8.4700000D-05 /
      data f( 9, 5, 9),f( 9, 5,10) / -1.1600000D-04 ,  8.4700000D-05 /
      data f( 9, 5,11),f( 9, 5,12) /  3.6860000D-04 ,  3.5610000D-04 /
      data f( 9, 5,13),f( 9, 5,14) /  2.8700000D-05 , -5.2080000D-04 /
      data f( 9, 5,15),f( 9, 5,16) / -9.6370000D-04 , -5.2080000D-04 /
      data f( 9, 5,17) /              2.8700000D-05 /
      data f( 9, 6, 1),f( 9, 6, 2) / -8.2700000D-05 , -4.6790000D-04 /
      data f( 9, 6, 3),f( 9, 6, 4) / -8.6880000D-04 , -4.6790000D-04 /
      data f( 9, 6, 5),f( 9, 6, 6) / -8.2700000D-05 ,  1.5760000D-04 /
      data f( 9, 6, 7),f( 9, 6, 8) /  2.1860000D-04 ,  2.3700000D-05 /
      data f( 9, 6, 9),f( 9, 6,10) / -1.5390000D-04 ,  2.3700000D-05 /
      data f( 9, 6,11),f( 9, 6,12) /  2.1860000D-04 ,  1.5760000D-04 /
      data f( 9, 6,13),f( 9, 6,14) / -8.2700000D-05 , -4.6790000D-04 /
      data f( 9, 6,15),f( 9, 6,16) / -8.6880000D-04 , -4.6790000D-04 /
      data f( 9, 6,17) /             -8.2700000D-05 /
      data f( 9, 7, 1),f( 9, 7, 2) / -1.7770000D-04 , -3.1200000D-04 /
      data f( 9, 7, 3),f( 9, 7, 4) / -5.3540000D-04 , -3.1200000D-04 /
      data f( 9, 7, 5),f( 9, 7, 6) / -1.7770000D-04 , -5.4900000D-05 /
      data f( 9, 7, 7),f( 9, 7, 8) /  5.3700000D-05 , -3.7600000D-05 /
      data f( 9, 7, 9),f( 9, 7,10) / -1.7440000D-04 , -3.7600000D-05 /
      data f( 9, 7,11),f( 9, 7,12) /  5.3700000D-05 , -5.4900000D-05 /
      data f( 9, 7,13),f( 9, 7,14) / -1.7770000D-04 , -3.1200000D-04 /
      data f( 9, 7,15),f( 9, 7,16) / -5.3540000D-04 , -3.1200000D-04 /
      data f( 9, 7,17) /             -1.7770000D-04 /
      data f( 9, 8, 1),f( 9, 8, 2) / -2.4830000D-04 , -1.9170000D-04 /
      data f( 9, 8, 3),f( 9, 8, 4) / -2.2750000D-04 , -1.9170000D-04 /
      data f( 9, 8, 5),f( 9, 8, 6) / -2.4830000D-04 , -2.1010000D-04 /
      data f( 9, 8, 7),f( 9, 8, 8) / -8.3100000D-05 , -1.2320000D-04 /
      data f( 9, 8, 9),f( 9, 8,10) / -2.3000000D-04 , -1.2320000D-04 /
      data f( 9, 8,11),f( 9, 8,12) / -8.3100000D-05 , -2.1010000D-04 /
      data f( 9, 8,13),f( 9, 8,14) / -2.4830000D-04 , -1.9170000D-04 /
      data f( 9, 8,15),f( 9, 8,16) / -2.2750000D-04 , -1.9170000D-04 /
      data f( 9, 8,17) /             -2.4830000D-04 /
      data f( 9, 9, 1),f( 9, 9, 2) / -3.0600000D-04 , -1.9710000D-04 /
      data f( 9, 9, 3),f( 9, 9, 4) / -1.3590000D-04 , -1.9710000D-04 /
      data f( 9, 9, 5),f( 9, 9, 6) / -3.0600000D-04 , -2.8470000D-04 /
      data f( 9, 9, 7),f( 9, 9, 8) / -1.9230000D-04 , -2.6550000D-04 /
      data f( 9, 9, 9),f( 9, 9,10) / -3.7340000D-04 , -2.6550000D-04 /
      data f( 9, 9,11),f( 9, 9,12) / -1.9230000D-04 , -2.8470000D-04 /
      data f( 9, 9,13),f( 9, 9,14) / -3.0600000D-04 , -1.9710000D-04 /
      data f( 9, 9,15),f( 9, 9,16) / -1.3590000D-04 , -1.9710000D-04 /
      data f( 9, 9,17) /             -3.0600000D-04 /
      data f( 9,10, 1),f( 9,10, 2) / -3.6340000D-04 , -3.5090000D-04 /
      data f( 9,10, 3),f( 9,10, 4) / -2.9850000D-04 , -3.5090000D-04 /
      data f( 9,10, 5),f( 9,10, 6) / -3.6340000D-04 , -2.8140000D-04 /
      data f( 9,10, 7),f( 9,10, 8) / -2.9470000D-04 , -4.9900000D-04 /
      data f( 9,10, 9),f( 9,10,10) / -6.4880000D-04 , -4.9900000D-04 /
      data f( 9,10,11),f( 9,10,12) / -2.9470000D-04 , -2.8140000D-04 /
      data f( 9,10,13),f( 9,10,14) / -3.6340000D-04 , -3.5090000D-04 /
      data f( 9,10,15),f( 9,10,16) / -2.9850000D-04 , -3.5090000D-04 /
      data f( 9,10,17) /             -3.6340000D-04 /
      data f( 9,11, 1),f( 9,11, 2) / -4.1090000D-04 , -6.3510000D-04 /
      data f( 9,11, 3),f( 9,11, 4) / -6.7150000D-04 , -6.3510000D-04 /
      data f( 9,11, 5),f( 9,11, 6) / -4.1090000D-04 , -1.9270000D-04 /
      data f( 9,11, 7),f( 9,11, 8) / -4.0140000D-04 , -8.5000000D-04 /
      data f( 9,11, 9),f( 9,11,10) / -1.0855000D-03 , -8.5000000D-04 /
      data f( 9,11,11),f( 9,11,12) / -4.0140000D-04 , -1.9270000D-04 /
      data f( 9,11,13),f( 9,11,14) / -4.1090000D-04 , -6.3510000D-04 /
      data f( 9,11,15),f( 9,11,16) / -6.7150000D-04 , -6.3510000D-04 /
      data f( 9,11,17) /             -4.1090000D-04 /
      data f( 9,12, 1),f( 9,12, 2) / -4.0380000D-04 , -9.9770000D-04 /
      data f( 9,12, 3),f( 9,12, 4) / -1.1791000D-03 , -9.9770000D-04 /
      data f( 9,12, 5),f( 9,12, 6) / -4.0380000D-04 ,  1.4700000D-05 /
      data f( 9,12, 7),f( 9,12, 8) / -5.0190000D-04 , -1.3159000D-03 /
      data f( 9,12, 9),f( 9,12,10) / -1.6792000D-03 , -1.3159000D-03 /
      data f( 9,12,11),f( 9,12,12) / -5.0190000D-04 ,  1.4700000D-05 /
      data f( 9,12,13),f( 9,12,14) / -4.0380000D-04 , -9.9770000D-04 /
      data f( 9,12,15),f( 9,12,16) / -1.1791000D-03 , -9.9770000D-04 /
      data f( 9,12,17) /             -4.0380000D-04 /
      data f( 9,13, 1),f( 9,13, 2) / -2.7390000D-04 , -1.3346000D-03 /
      data f( 9,13, 3),f( 9,13, 4) / -1.6987000D-03 , -1.3346000D-03 /
      data f( 9,13, 5),f( 9,13, 6) / -2.7390000D-04 ,  3.7030000D-04 /
      data f( 9,13, 7),f( 9,13, 8) / -5.5930000D-04 , -1.8353000D-03 /
      data f( 9,13, 9),f( 9,13,10) / -2.3590000D-03 , -1.8353000D-03 /
      data f( 9,13,11),f( 9,13,12) / -5.5930000D-04 ,  3.7030000D-04 /
      data f( 9,13,13),f( 9,13,14) / -2.7390000D-04 , -1.3346000D-03 /
      data f( 9,13,15),f( 9,13,16) / -1.6987000D-03 , -1.3346000D-03 /
      data f( 9,13,17) /             -2.7390000D-04 /
      data f( 9,14, 1),f( 9,14, 2) /  2.4400000D-05 , -1.4841000D-03 /
      data f( 9,14, 3),f( 9,14, 4) / -2.0393000D-03 , -1.4841000D-03 /
      data f( 9,14, 5),f( 9,14, 6) /  2.4400000D-05 ,  8.3000000D-04 /
      data f( 9,14, 7),f( 9,14, 8) / -5.2800000D-04 , -2.2687000D-03 /
      data f( 9,14, 9),f( 9,14,10) / -2.9559000D-03 , -2.2687000D-03 /
      data f( 9,14,11),f( 9,14,12) / -5.2800000D-04 ,  8.3000000D-04 /
      data f( 9,14,13),f( 9,14,14) /  2.4400000D-05 , -1.4841000D-03 /
      data f( 9,14,15),f( 9,14,16) / -2.0393000D-03 , -1.4841000D-03 /
      data f( 9,14,17) /              2.4400000D-05 /
      data f( 9,15, 1),f( 9,15, 2) /  4.3860000D-04 , -1.2792000D-03 /
      data f( 9,15, 3),f( 9,15, 4) / -1.9662000D-03 , -1.2792000D-03 /
      data f( 9,15, 5),f( 9,15, 6) /  4.3860000D-04 ,  1.2166000D-03 /
      data f( 9,15, 7),f( 9,15, 8) / -3.9100000D-04 , -2.4100000D-03 /
      data f( 9,15, 9),f( 9,15,10) / -3.2051000D-03 , -2.4100000D-03 /
      data f( 9,15,11),f( 9,15,12) / -3.9100000D-04 ,  1.2166000D-03 /
      data f( 9,15,13),f( 9,15,14) /  4.3860000D-04 , -1.2792000D-03 /
      data f( 9,15,15),f( 9,15,16) / -1.9662000D-03 , -1.2792000D-03 /
      data f( 9,15,17) /              4.3860000D-04 /
      data f( 9,16, 1),f( 9,16, 2) /  7.9210000D-04 , -6.8050000D-04 /
      data f( 9,16, 3),f( 9,16, 4) / -1.3362000D-03 , -6.8050000D-04 /
      data f( 9,16, 5),f( 9,16, 6) /  7.9210000D-04 ,  1.3046000D-03 /
      data f( 9,16, 7),f( 9,16, 8) / -1.8280000D-04 , -2.0743000D-03 /
      data f( 9,16, 9),f( 9,16,10) / -2.8417000D-03 , -2.0743000D-03 /
      data f( 9,16,11),f( 9,16,12) / -1.8280000D-04 ,  1.3046000D-03 /
      data f( 9,16,13),f( 9,16,14) /  7.9210000D-04 , -6.8050000D-04 /
      data f( 9,16,15),f( 9,16,16) / -1.3362000D-03 , -6.8050000D-04 /
      data f( 9,16,17) /              7.9210000D-04 /
      data f( 9,17, 1),f( 9,17, 2) /  9.0210000D-04 ,  9.0800000D-05 /
      data f( 9,17, 3),f( 9,17, 4) / -3.2080000D-04 ,  9.0800000D-05 /
      data f( 9,17, 5),f( 9,17, 6) /  9.0210000D-04 ,  1.0454000D-03 /
      data f( 9,17, 7),f( 9,17, 8) /  3.5500000D-05 , -1.2584000D-03 /
      data f( 9,17, 9),f( 9,17,10) / -1.8093000D-03 , -1.2584000D-03 /
      data f( 9,17,11),f( 9,17,12) /  3.5500000D-05 ,  1.0454000D-03 /
      data f( 9,17,13),f( 9,17,14) /  9.0210000D-04 ,  9.0800000D-05 /
      data f( 9,17,15),f( 9,17,16) / -3.2080000D-04 ,  9.0800000D-05 /
      data f( 9,17,17) /              9.0210000D-04 /
      data f( 9,18, 1),f( 9,18, 2) /  7.5390000D-04 ,  6.0250000D-04 /
      data f( 9,18, 3),f( 9,18, 4) /  5.0350000D-04 ,  6.0250000D-04 /
      data f( 9,18, 5),f( 9,18, 6) /  7.5390000D-04 ,  6.6710000D-04 /
      data f( 9,18, 7),f( 9,18, 8) /  2.4870000D-04 , -2.4650000D-04 /
      data f( 9,18, 9),f( 9,18,10) / -4.6280000D-04 , -2.4650000D-04 /
      data f( 9,18,11),f( 9,18,12) /  2.4870000D-04 ,  6.6710000D-04 /
      data f( 9,18,13),f( 9,18,14) /  7.5390000D-04 ,  6.0250000D-04 /
      data f( 9,18,15),f( 9,18,16) /  5.0350000D-04 ,  6.0250000D-04 /
      data f( 9,18,17) /              7.5390000D-04 /
      data f( 9,19, 1),f( 9,19, 2) /  4.9340000D-04 ,  4.9340000D-04 /
      data f( 9,19, 3),f( 9,19, 4) /  4.9340000D-04 ,  4.9340000D-04 /
      data f( 9,19, 5),f( 9,19, 6) /  4.9340000D-04 ,  4.9340000D-04 /
      data f( 9,19, 7),f( 9,19, 8) /  4.9340000D-04 ,  4.9340000D-04 /
      data f( 9,19, 9),f( 9,19,10) /  4.9340000D-04 ,  4.9340000D-04 /
      data f( 9,19,11),f( 9,19,12) /  4.9340000D-04 ,  4.9340000D-04 /
      data f( 9,19,13),f( 9,19,14) /  4.9340000D-04 ,  4.9340000D-04 /
      data f( 9,19,15),f( 9,19,16) /  4.9340000D-04 ,  4.9340000D-04 /
      data f( 9,19,17) /              4.9340000D-04 /
      data f(10, 1, 1),f(10, 1, 2) / -2.1700000D-04 , -2.1700000D-04 /
      data f(10, 1, 3),f(10, 1, 4) / -2.1700000D-04 , -2.1700000D-04 /
      data f(10, 1, 5),f(10, 1, 6) / -2.1700000D-04 , -2.1700000D-04 /
      data f(10, 1, 7),f(10, 1, 8) / -2.1700000D-04 , -2.1700000D-04 /
      data f(10, 1, 9),f(10, 1,10) / -2.1700000D-04 , -2.1700000D-04 /
      data f(10, 1,11),f(10, 1,12) / -2.1700000D-04 , -2.1700000D-04 /
      data f(10, 1,13),f(10, 1,14) / -2.1700000D-04 , -2.1700000D-04 /
      data f(10, 1,15),f(10, 1,16) / -2.1700000D-04 , -2.1700000D-04 /
      data f(10, 1,17) /             -2.1700000D-04 /
      data f(10, 2, 1),f(10, 2, 2) / -2.2210000D-04 , -2.4870000D-04 /
      data f(10, 2, 3),f(10, 2, 4) / -2.6160000D-04 , -2.4870000D-04 /
      data f(10, 2, 5),f(10, 2, 6) / -2.2210000D-04 , -2.0370000D-04 /
      data f(10, 2, 7),f(10, 2, 8) / -2.0290000D-04 , -2.1220000D-04 /
      data f(10, 2, 9),f(10, 2,10) / -2.1750000D-04 , -2.1220000D-04 /
      data f(10, 2,11),f(10, 2,12) / -2.0290000D-04 , -2.0370000D-04 /
      data f(10, 2,13),f(10, 2,14) / -2.2210000D-04 , -2.4870000D-04 /
      data f(10, 2,15),f(10, 2,16) / -2.6160000D-04 , -2.4870000D-04 /
      data f(10, 2,17) /             -2.2210000D-04 /
      data f(10, 3, 1),f(10, 3, 2) / -2.2120000D-04 , -3.0350000D-04 /
      data f(10, 3, 3),f(10, 3, 4) / -3.4930000D-04 , -3.0350000D-04 /
      data f(10, 3, 5),f(10, 3, 6) / -2.2120000D-04 , -1.7570000D-04 /
      data f(10, 3, 7),f(10, 3, 8) / -1.8550000D-04 , -2.2080000D-04 /
      data f(10, 3, 9),f(10, 3,10) / -2.3900000D-04 , -2.2080000D-04 /
      data f(10, 3,11),f(10, 3,12) / -1.8550000D-04 , -1.7570000D-04 /
      data f(10, 3,13),f(10, 3,14) / -2.2120000D-04 , -3.0350000D-04 /
      data f(10, 3,15),f(10, 3,16) / -3.4930000D-04 , -3.0350000D-04 /
      data f(10, 3,17) /             -2.2120000D-04 /
      data f(10, 4, 1),f(10, 4, 2) / -2.1970000D-04 , -3.5520000D-04 /
      data f(10, 4, 3),f(10, 4, 4) / -4.4490000D-04 , -3.5520000D-04 /
      data f(10, 4, 5),f(10, 4, 6) / -2.1970000D-04 , -1.5690000D-04 /
      data f(10, 4, 7),f(10, 4, 8) / -1.7730000D-04 , -2.2840000D-04 /
      data f(10, 4, 9),f(10, 4,10) / -2.5500000D-04 , -2.2840000D-04 /
      data f(10, 4,11),f(10, 4,12) / -1.7730000D-04 , -1.5690000D-04 /
      data f(10, 4,13),f(10, 4,14) / -2.1970000D-04 , -3.5520000D-04 /
      data f(10, 4,15),f(10, 4,16) / -4.4490000D-04 , -3.5520000D-04 /
      data f(10, 4,17) /             -2.1970000D-04 /
      data f(10, 5, 1),f(10, 5, 2) / -2.1740000D-04 , -3.6790000D-04 /
      data f(10, 5, 3),f(10, 5, 4) / -4.9140000D-04 , -3.6790000D-04 /
      data f(10, 5, 5),f(10, 5, 6) / -2.1740000D-04 , -1.5960000D-04 /
      data f(10, 5, 7),f(10, 5, 8) / -1.8490000D-04 , -2.2520000D-04 /
      data f(10, 5, 9),f(10, 5,10) / -2.5100000D-04 , -2.2520000D-04 /
      data f(10, 5,11),f(10, 5,12) / -1.8490000D-04 , -1.5960000D-04 /
      data f(10, 5,13),f(10, 5,14) / -2.1740000D-04 , -3.6790000D-04 /
      data f(10, 5,15),f(10, 5,16) / -4.9140000D-04 , -3.6790000D-04 /
      data f(10, 5,17) /             -2.1740000D-04 /
      data f(10, 6, 1),f(10, 6, 2) / -2.1180000D-04 , -3.2860000D-04 /
      data f(10, 6, 3),f(10, 6, 4) / -4.5200000D-04 , -3.2860000D-04 /
      data f(10, 6, 5),f(10, 6, 6) / -2.1180000D-04 , -1.7820000D-04 /
      data f(10, 6, 7),f(10, 6, 8) / -1.9960000D-04 , -2.1050000D-04 /
      data f(10, 6, 9),f(10, 6,10) / -2.2860000D-04 , -2.1050000D-04 /
      data f(10, 6,11),f(10, 6,12) / -1.9960000D-04 , -1.7820000D-04 /
      data f(10, 6,13),f(10, 6,14) / -2.1180000D-04 , -3.2860000D-04 /
      data f(10, 6,15),f(10, 6,16) / -4.5200000D-04 , -3.2860000D-04 /
      data f(10, 6,17) /             -2.1180000D-04 /
      data f(10, 7, 1),f(10, 7, 2) / -2.0250000D-04 , -2.6040000D-04 /
      data f(10, 7, 3),f(10, 7, 4) / -3.4640000D-04 , -2.6040000D-04 /
      data f(10, 7, 5),f(10, 7, 6) / -2.0250000D-04 , -1.9790000D-04 /
      data f(10, 7, 7),f(10, 7, 8) / -2.0560000D-04 , -1.9230000D-04 /
      data f(10, 7, 9),f(10, 7,10) / -2.0200000D-04 , -1.9230000D-04 /
      data f(10, 7,11),f(10, 7,12) / -2.0560000D-04 , -1.9790000D-04 /
      data f(10, 7,13),f(10, 7,14) / -2.0250000D-04 , -2.6040000D-04 /
      data f(10, 7,15),f(10, 7,16) / -3.4640000D-04 , -2.6040000D-04 /
      data f(10, 7,17) /             -2.0250000D-04 /
      data f(10, 8, 1),f(10, 8, 2) / -1.9290000D-04 , -2.0010000D-04 /
      data f(10, 8, 3),f(10, 8, 4) / -2.3320000D-04 , -2.0010000D-04 /
      data f(10, 8, 5),f(10, 8, 6) / -1.9290000D-04 , -2.0630000D-04 /
      data f(10, 8, 7),f(10, 8, 8) / -1.9720000D-04 , -1.8170000D-04 /
      data f(10, 8, 9),f(10, 8,10) / -1.8870000D-04 , -1.8170000D-04 /
      data f(10, 8,11),f(10, 8,12) / -1.9720000D-04 , -2.0630000D-04 /
      data f(10, 8,13),f(10, 8,14) / -1.9290000D-04 , -2.0010000D-04 /
      data f(10, 8,15),f(10, 8,16) / -2.3320000D-04 , -2.0010000D-04 /
      data f(10, 8,17) /             -1.9290000D-04 /
      data f(10, 9, 1),f(10, 9, 2) / -1.9010000D-04 , -1.7420000D-04 /
      data f(10, 9, 3),f(10, 9, 4) / -1.7280000D-04 , -1.7420000D-04 /
      data f(10, 9, 5),f(10, 9, 6) / -1.9010000D-04 , -2.0200000D-04 /
      data f(10, 9, 7),f(10, 9, 8) / -1.8880000D-04 , -1.8970000D-04 /
      data f(10, 9, 9),f(10, 9,10) / -2.0390000D-04 , -1.8970000D-04 /
      data f(10, 9,11),f(10, 9,12) / -1.8880000D-04 , -2.0200000D-04 /
      data f(10, 9,13),f(10, 9,14) / -1.9010000D-04 , -1.7420000D-04 /
      data f(10, 9,15),f(10, 9,16) / -1.7280000D-04 , -1.7420000D-04 /
      data f(10, 9,17) /             -1.9010000D-04 /
      data f(10,10, 1),f(10,10, 2) / -2.0020000D-04 , -1.9460000D-04 /
      data f(10,10, 3),f(10,10, 4) / -1.8650000D-04 , -1.9460000D-04 /
      data f(10,10, 5),f(10,10, 6) / -2.0020000D-04 , -1.9190000D-04 /
      data f(10,10, 7),f(10,10, 8) / -1.9400000D-04 , -2.2890000D-04 /
      data f(10,10, 9),f(10,10,10) / -2.5840000D-04 , -2.2890000D-04 /
      data f(10,10,11),f(10,10,12) / -1.9400000D-04 , -1.9190000D-04 /
      data f(10,10,13),f(10,10,14) / -2.0020000D-04 , -1.9460000D-04 /
      data f(10,10,15),f(10,10,16) / -1.8650000D-04 , -1.9460000D-04 /
      data f(10,10,17) /             -2.0020000D-04 /
      data f(10,11, 1),f(10,11, 2) / -2.2150000D-04 , -2.5940000D-04 /
      data f(10,11, 3),f(10,11, 4) / -2.6500000D-04 , -2.5940000D-04 /
      data f(10,11, 5),f(10,11, 6) / -2.2150000D-04 , -1.7880000D-04 /
      data f(10,11, 7),f(10,11, 8) / -2.1630000D-04 , -3.0740000D-04 /
      data f(10,11, 9),f(10,11,10) / -3.5920000D-04 , -3.0740000D-04 /
      data f(10,11,11),f(10,11,12) / -2.1630000D-04 , -1.7880000D-04 /
      data f(10,11,13),f(10,11,14) / -2.2150000D-04 , -2.5940000D-04 /
      data f(10,11,15),f(10,11,16) / -2.6500000D-04 , -2.5940000D-04 /
      data f(10,11,17) /             -2.2150000D-04 /
      data f(10,12, 1),f(10,12, 2) / -2.4350000D-04 , -3.5530000D-04 /
      data f(10,12, 3),f(10,12, 4) / -3.8860000D-04 , -3.5530000D-04 /
      data f(10,12, 5),f(10,12, 6) / -2.4350000D-04 , -1.5620000D-04 /
      data f(10,12, 7),f(10,12, 8) / -2.5160000D-04 , -4.2360000D-04 /
      data f(10,12, 9),f(10,12,10) / -5.0480000D-04 , -4.2360000D-04 /
      data f(10,12,11),f(10,12,12) / -2.5160000D-04 , -1.5620000D-04 /
      data f(10,12,13),f(10,12,14) / -2.4350000D-04 , -3.5530000D-04 /
      data f(10,12,15),f(10,12,16) / -3.8860000D-04 , -3.5530000D-04 /
      data f(10,12,17) /             -2.4350000D-04 /
      data f(10,13, 1),f(10,13, 2) / -2.4870000D-04 , -4.5510000D-04 /
      data f(10,13, 3),f(10,13, 4) / -5.2620000D-04 , -4.5510000D-04 /
      data f(10,13, 5),f(10,13, 6) / -2.4870000D-04 , -1.1600000D-04 /
      data f(10,13, 7),f(10,13, 8) / -2.8920000D-04 , -5.6030000D-04 /
      data f(10,13, 9),f(10,13,10) / -6.7700000D-04 , -5.6030000D-04 /
      data f(10,13,11),f(10,13,12) / -2.8920000D-04 , -1.1600000D-04 /
      data f(10,13,13),f(10,13,14) / -2.4870000D-04 , -4.5510000D-04 /
      data f(10,13,15),f(10,13,16) / -5.2620000D-04 , -4.5510000D-04 /
      data f(10,13,17) /             -2.4870000D-04 /
      data f(10,14, 1),f(10,14, 2) / -2.2210000D-04 , -5.1840000D-04 /
      data f(10,14, 3),f(10,14, 4) / -6.2970000D-04 , -5.1840000D-04 /
      data f(10,14, 5),f(10,14, 6) / -2.2210000D-04 , -5.9500000D-05 /
      data f(10,14, 7),f(10,14, 8) / -3.1390000D-04 , -6.8140000D-04 /
      data f(10,14, 9),f(10,14,10) / -8.3350000D-04 , -6.8140000D-04 /
      data f(10,14,11),f(10,14,12) / -3.1390000D-04 , -5.9500000D-05 /
      data f(10,14,13),f(10,14,14) / -2.2210000D-04 , -5.1840000D-04 /
      data f(10,14,15),f(10,14,16) / -6.2970000D-04 , -5.1840000D-04 /
      data f(10,14,17) /             -2.2210000D-04 /
      data f(10,15, 1),f(10,15, 2) / -1.6490000D-04 , -5.0300000D-04 /
      data f(10,15, 3),f(10,15, 4) / -6.4100000D-04 , -5.0300000D-04 /
      data f(10,15, 5),f(10,15, 6) / -1.6490000D-04 , -9.2000000D-06 /
      data f(10,15, 7),f(10,15, 8) / -3.1460000D-04 , -7.3580000D-04 /
      data f(10,15, 9),f(10,15,10) / -9.0930000D-04 , -7.3580000D-04 /
      data f(10,15,11),f(10,15,12) / -3.1460000D-04 , -9.2000000D-06 /
      data f(10,15,13),f(10,15,14) / -1.6490000D-04 , -5.0300000D-04 /
      data f(10,15,15),f(10,15,16) / -6.4100000D-04 , -5.0300000D-04 /
      data f(10,15,17) /             -1.6490000D-04 /
      data f(10,16, 1),f(10,16, 2) / -1.0540000D-04 , -3.9460000D-04 /
      data f(10,16, 3),f(10,16, 4) / -5.2510000D-04 , -3.9460000D-04 /
      data f(10,16, 5),f(10,16, 6) / -1.0540000D-04 , -3.0000000D-06 /
      data f(10,16, 7),f(10,16, 8) / -2.9060000D-04 , -6.7950000D-04 /
      data f(10,16, 9),f(10,16,10) / -8.4270000D-04 , -6.7950000D-04 /
      data f(10,16,11),f(10,16,12) / -2.9060000D-04 , -3.0000000D-06 /
      data f(10,16,13),f(10,16,14) / -1.0540000D-04 , -3.9460000D-04 /
      data f(10,16,15),f(10,16,16) / -5.2510000D-04 , -3.9460000D-04 /
      data f(10,16,17) /             -1.0540000D-04 /
      data f(10,17, 1),f(10,17, 2) / -8.1300000D-05 , -2.4000000D-04 /
      data f(10,17, 3),f(10,17, 4) / -3.2100000D-04 , -2.4000000D-04 /
      data f(10,17, 5),f(10,17, 6) / -8.1300000D-05 , -5.3000000D-05 /
      data f(10,17, 7),f(10,17, 8) / -2.5170000D-04 , -5.1390000D-04 /
      data f(10,17, 9),f(10,17,10) / -6.2760000D-04 , -5.1390000D-04 /
      data f(10,17,11),f(10,17,12) / -2.5170000D-04 , -5.3000000D-05 /
      data f(10,17,13),f(10,17,14) / -8.1300000D-05 , -2.4000000D-04 /
      data f(10,17,15),f(10,17,16) / -3.2100000D-04 , -2.4000000D-04 /
      data f(10,17,17) /             -8.1300000D-05 /
      data f(10,18, 1),f(10,18, 2) / -1.0480000D-04 , -1.3400000D-04 /
      data f(10,18, 3),f(10,18, 4) / -1.5320000D-04 , -1.3400000D-04 /
      data f(10,18, 5),f(10,18, 6) / -1.0480000D-04 , -1.2250000D-04 /
      data f(10,18, 7),f(10,18, 8) / -2.0600000D-04 , -3.0540000D-04 /
      data f(10,18, 9),f(10,18,10) / -3.4900000D-04 , -3.0540000D-04 /
      data f(10,18,11),f(10,18,12) / -2.0600000D-04 , -1.2250000D-04 /
      data f(10,18,13),f(10,18,14) / -1.0480000D-04 , -1.3400000D-04 /
      data f(10,18,15),f(10,18,16) / -1.5320000D-04 , -1.3400000D-04 /
      data f(10,18,17) /             -1.0480000D-04 /
      data f(10,19, 1),f(10,19, 2) / -1.5450000D-04 , -1.5450000D-04 /
      data f(10,19, 3),f(10,19, 4) / -1.5450000D-04 , -1.5450000D-04 /
      data f(10,19, 5),f(10,19, 6) / -1.5450000D-04 , -1.5450000D-04 /
      data f(10,19, 7),f(10,19, 8) / -1.5450000D-04 , -1.5450000D-04 /
      data f(10,19, 9),f(10,19,10) / -1.5450000D-04 , -1.5450000D-04 /
      data f(10,19,11),f(10,19,12) / -1.5450000D-04 , -1.5450000D-04 /
      data f(10,19,13),f(10,19,14) / -1.5450000D-04 , -1.5450000D-04 /
      data f(10,19,15),f(10,19,16) / -1.5450000D-04 , -1.5450000D-04 /
      data f(10,19,17) /             -1.5450000D-04 /
      data f(11, 1, 1),f(11, 1, 2) / -9.5100000D-05 , -9.5100000D-05 /
      data f(11, 1, 3),f(11, 1, 4) / -9.5100000D-05 , -9.5100000D-05 /
      data f(11, 1, 5),f(11, 1, 6) / -9.5100000D-05 , -9.5100000D-05 /
      data f(11, 1, 7),f(11, 1, 8) / -9.5100000D-05 , -9.5100000D-05 /
      data f(11, 1, 9),f(11, 1,10) / -9.5100000D-05 , -9.5100000D-05 /
      data f(11, 1,11),f(11, 1,12) / -9.5100000D-05 , -9.5100000D-05 /
      data f(11, 1,13),f(11, 1,14) / -9.5100000D-05 , -9.5100000D-05 /
      data f(11, 1,15),f(11, 1,16) / -9.5100000D-05 , -9.5100000D-05 /
      data f(11, 1,17) /             -9.5100000D-05 /
      data f(11, 2, 1),f(11, 2, 2) / -9.4700000D-05 , -9.6600000D-05 /
      data f(11, 2, 3),f(11, 2, 4) / -9.7600000D-05 , -9.6600000D-05 /
      data f(11, 2, 5),f(11, 2, 6) / -9.4700000D-05 , -9.3700000D-05 /
      data f(11, 2, 7),f(11, 2, 8) / -9.3600000D-05 , -9.3500000D-05 /
      data f(11, 2, 9),f(11, 2,10) / -9.3400000D-05 , -9.3500000D-05 /
      data f(11, 2,11),f(11, 2,12) / -9.3600000D-05 , -9.3700000D-05 /
      data f(11, 2,13),f(11, 2,14) / -9.4700000D-05 , -9.6600000D-05 /
      data f(11, 2,15),f(11, 2,16) / -9.7600000D-05 , -9.6600000D-05 /
      data f(11, 2,17) /             -9.4700000D-05 /
      data f(11, 3, 1),f(11, 3, 2) / -9.1900000D-05 , -9.8400000D-05 /
      data f(11, 3, 3),f(11, 3, 4) / -1.0260000D-04 , -9.8400000D-05 /
      data f(11, 3, 5),f(11, 3, 6) / -9.1900000D-05 , -9.0700000D-05 /
      data f(11, 3, 7),f(11, 3, 8) / -9.2700000D-05 , -9.2200000D-05 /
      data f(11, 3, 9),f(11, 3,10) / -9.1100000D-05 , -9.2200000D-05 /
      data f(11, 3,11),f(11, 3,12) / -9.2700000D-05 , -9.0700000D-05 /
      data f(11, 3,13),f(11, 3,14) / -9.1900000D-05 , -9.8400000D-05 /
      data f(11, 3,15),f(11, 3,16) / -1.0260000D-04 , -9.8400000D-05 /
      data f(11, 3,17) /             -9.1900000D-05 /
      data f(11, 4, 1),f(11, 4, 2) / -8.6800000D-05 , -9.8800000D-05 /
      data f(11, 4, 3),f(11, 4, 4) / -1.0820000D-04 , -9.8800000D-05 /
      data f(11, 4, 5),f(11, 4, 6) / -8.6800000D-05 , -8.7100000D-05 /
      data f(11, 4, 7),f(11, 4, 8) / -9.2900000D-05 , -9.0300000D-05 /
      data f(11, 4, 9),f(11, 4,10) / -8.7000000D-05 , -9.0300000D-05 /
      data f(11, 4,11),f(11, 4,12) / -9.2900000D-05 , -8.7100000D-05 /
      data f(11, 4,13),f(11, 4,14) / -8.6800000D-05 , -9.8800000D-05 /
      data f(11, 4,15),f(11, 4,16) / -1.0820000D-04 , -9.8800000D-05 /
      data f(11, 4,17) /             -8.6800000D-05 /
      data f(11, 5, 1),f(11, 5, 2) / -7.9800000D-05 , -9.4900000D-05 /
      data f(11, 5, 3),f(11, 5, 4) / -1.0970000D-04 , -9.4900000D-05 /
      data f(11, 5, 5),f(11, 5, 6) / -7.9800000D-05 , -8.3100000D-05 /
      data f(11, 5, 7),f(11, 5, 8) / -9.2700000D-05 , -8.6200000D-05 /
      data f(11, 5, 9),f(11, 5,10) / -8.0000000D-05 , -8.6200000D-05 /
      data f(11, 5,11),f(11, 5,12) / -9.2700000D-05 , -8.3100000D-05 /
      data f(11, 5,13),f(11, 5,14) / -7.9800000D-05 , -9.4900000D-05 /
      data f(11, 5,15),f(11, 5,16) / -1.0970000D-04 , -9.4900000D-05 /
      data f(11, 5,17) /             -7.9800000D-05 /
      data f(11, 6, 1),f(11, 6, 2) / -8.2600000D-05 , -8.6400000D-05 /
      data f(11, 6, 3),f(11, 6, 4) / -1.0440000D-04 , -8.6400000D-05 /
      data f(11, 6, 5),f(11, 6, 6) / -8.2600000D-05 , -7.8900000D-05 /
      data f(11, 6, 7),f(11, 6, 8) / -9.0500000D-05 , -7.9700000D-05 /
      data f(11, 6, 9),f(11, 6,10) / -7.1100000D-05 , -7.9700000D-05 /
      data f(11, 6,11),f(11, 6,12) / -9.0500000D-05 , -7.8900000D-05 /
      data f(11, 6,13),f(11, 6,14) / -8.2600000D-05 , -8.6400000D-05 /
      data f(11, 6,15),f(11, 6,16) / -1.0440000D-04 , -8.6400000D-05 /
      data f(11, 6,17) /             -8.2600000D-05 /
      data f(11, 7, 1),f(11, 7, 2) / -6.4500000D-05 , -7.5400000D-05 /
      data f(11, 7, 3),f(11, 7, 4) / -9.2100000D-05 , -7.5400000D-05 /
      data f(11, 7, 5),f(11, 7, 6) / -6.4500000D-05 , -7.3600000D-05 /
      data f(11, 7, 7),f(11, 7, 8) / -8.3800000D-05 , -7.1800000D-05 /
      data f(11, 7, 9),f(11, 7,10) / -6.2800000D-05 , -7.1800000D-05 /
      data f(11, 7,11),f(11, 7,12) / -8.3800000D-05 , -7.3600000D-05 /
      data f(11, 7,13),f(11, 7,14) / -6.4500000D-05 , -7.5400000D-05 /
      data f(11, 7,15),f(11, 7,16) / -9.2100000D-05 , -7.5400000D-05 /
      data f(11, 7,17) /             -6.4500000D-05 /
      data f(11, 8, 1),f(11, 8, 2) / -5.8400000D-05 , -6.4300000D-05 /
      data f(11, 8, 3),f(11, 8, 4) / -7.5700000D-05 , -6.4300000D-05 /
      data f(11, 8, 5),f(11, 8, 6) / -5.8400000D-05 , -6.6400000D-05 /
      data f(11, 8, 7),f(11, 8, 8) / -7.2600000D-05 , -6.3100000D-05 /
      data f(11, 8, 9),f(11, 8,10) / -5.6700000D-05 , -6.3100000D-05 /
      data f(11, 8,11),f(11, 8,12) / -7.2600000D-05 , -6.6400000D-05 /
      data f(11, 8,13),f(11, 8,14) / -5.8400000D-05 , -6.4300000D-05 /
      data f(11, 8,15),f(11, 8,16) / -7.5700000D-05 , -6.4300000D-05 /
      data f(11, 8,17) /             -5.8400000D-05 /
      data f(11, 9, 1),f(11, 9, 2) / -5.4200000D-05 , -5.6400000D-05 /
      data f(11, 9, 3),f(11, 9, 4) / -6.1500000D-05 , -5.6400000D-05 /
      data f(11, 9, 5),f(11, 9, 6) / -5.4200000D-05 , -5.9300000D-05 /
      data f(11, 9, 7),f(11, 9, 8) / -6.2000000D-05 , -5.6400000D-05 /
      data f(11, 9, 9),f(11, 9,10) / -5.3600000D-05 , -5.6400000D-05 /
      data f(11, 9,11),f(11, 9,12) / -6.2000000D-05 , -5.9300000D-05 /
      data f(11, 9,13),f(11, 9,14) / -5.4200000D-05 , -5.6400000D-05 /
      data f(11, 9,15),f(11, 9,16) / -6.1500000D-05 , -5.6400000D-05 /
      data f(11, 9,17) /             -5.4200000D-05 /
      data f(11,10, 1),f(11,10, 2) / -5.3300000D-05 , -5.3700000D-05 /
      data f(11,10, 3),f(11,10, 4) / -5.4800000D-05 , -5.3700000D-05 /
      data f(11,10, 5),f(11,10, 6) / -5.3300000D-05 , -5.5800000D-05 /
      data f(11,10, 7),f(11,10, 8) / -5.6400000D-05 , -5.4300000D-05 /
      data f(11,10, 9),f(11,10,10) / -5.3900000D-05 , -5.4300000D-05 /
      data f(11,10,11),f(11,10,12) / -5.6400000D-05 , -5.5800000D-05 /
      data f(11,10,13),f(11,10,14) / -5.3300000D-05 , -5.3700000D-05 /
      data f(11,10,15),f(11,10,16) / -5.4800000D-05 , -5.3700000D-05 /
      data f(11,10,17) /             -5.3300000D-05 /
      data f(11,11, 1),f(11,11, 2) / -5.7000000D-05 , -5.6900000D-05 /
      data f(11,11, 3),f(11,11, 4) / -5.6400000D-05 , -5.6900000D-05 /
      data f(11,11, 5),f(11,11, 6) / -5.7000000D-05 , -5.7900000D-05 /
      data f(11,11, 7),f(11,11, 8) / -5.6700000D-05 , -5.8100000D-05 /
      data f(11,11, 9),f(11,11,10) / -5.8600000D-05 , -5.8100000D-05 /
      data f(11,11,11),f(11,11,12) / -5.6700000D-05 , -5.7900000D-05 /
      data f(11,11,13),f(11,11,14) / -5.7000000D-05 , -5.6900000D-05 /
      data f(11,11,15),f(11,11,16) / -5.6400000D-05 , -5.6900000D-05 /
      data f(11,11,17) /             -5.7000000D-05 /
      data f(11,12, 1),f(11,12, 2) / -6.5600000D-05 , -6.5000000D-05 /
      data f(11,12, 3),f(11,12, 4) / -6.4700000D-05 , -6.5000000D-05 /
      data f(11,12, 5),f(11,12, 6) / -6.5600000D-05 , -6.5400000D-05 /
      data f(11,12, 7),f(11,12, 8) / -6.1900000D-05 , -6.6800000D-05 /
      data f(11,12, 9),f(11,12,10) / -6.8300000D-05 , -6.6800000D-05 /
      data f(11,12,11),f(11,12,12) / -6.1900000D-05 , -6.5400000D-05 /
      data f(11,12,13),f(11,12,14) / -6.5600000D-05 , -6.5000000D-05 /
      data f(11,12,15),f(11,12,16) / -6.4700000D-05 , -6.5000000D-05 /
      data f(11,12,17) /             -6.5600000D-05 /
      data f(11,13, 1),f(11,13, 2) / -7.6500000D-05 , -7.5700000D-05 /
      data f(11,13, 3),f(11,13, 4) / -7.6500000D-05 , -7.5700000D-05 /
      data f(11,13, 5),f(11,13, 6) / -7.6500000D-05 , -7.5200000D-05 /
      data f(11,13, 7),f(11,13, 8) / -7.0000000D-05 , -7.8200000D-05 /
      data f(11,13, 9),f(11,13,10) / -8.1700000D-05 , -7.8200000D-05 /
      data f(11,13,11),f(11,13,12) / -7.0000000D-05 , -7.5200000D-05 /
      data f(11,13,13),f(11,13,14) / -7.6500000D-05 , -7.5700000D-05 /
      data f(11,13,15),f(11,13,16) / -7.6500000D-05 , -7.5700000D-05 /
      data f(11,13,17) /             -7.6500000D-05 /
      data f(11,14, 1),f(11,14, 2) / -8.5600000D-05 , -8.6200000D-05 /
      data f(11,14, 3),f(11,14, 4) / -8.8000000D-05 , -8.6200000D-05 /
      data f(11,14, 5),f(11,14, 6) / -8.5600000D-05 , -8.2700000D-05 /
      data f(11,14, 7),f(11,14, 8) / -7.8900000D-05 , -8.9700000D-05 /
      data f(11,14, 9),f(11,14,10) / -9.5700000D-05 , -8.9700000D-05 /
      data f(11,14,11),f(11,14,12) / -7.8900000D-05 , -8.2700000D-05 /
      data f(11,14,13),f(11,14,14) / -8.5600000D-05 , -8.6200000D-05 /
      data f(11,14,15),f(11,14,16) / -8.8000000D-05 , -8.6200000D-05 /
      data f(11,14,17) /             -8.5600000D-05 /
      data f(11,15, 1),f(11,15, 2) / -8.9900000D-05 , -9.3000000D-05 /
      data f(11,15, 3),f(11,15, 4) / -9.5500000D-05 , -9.3000000D-05 /
      data f(11,15, 5),f(11,15, 6) / -8.9900000D-05 , -8.6100000D-05 /
      data f(11,15, 7),f(11,15, 8) / -8.6300000D-05 , -9.8700000D-05 /
      data f(11,15, 9),f(11,15,10) / -1.0600000D-04 , -9.8700000D-05 /
      data f(11,15,11),f(11,15,12) / -8.6300000D-05 , -8.6100000D-05 /
      data f(11,15,13),f(11,15,14) / -8.9900000D-05 , -9.3000000D-05 /
      data f(11,15,15),f(11,15,16) / -9.5500000D-05 , -9.3000000D-05 /
      data f(11,15,17) /             -8.9900000D-05 /
      data f(11,16, 1),f(11,16, 2) / -8.9900000D-05 , -9.4500000D-05 /
      data f(11,16, 3),f(11,16, 4) / -9.6900000D-05 , -9.4500000D-05 /
      data f(11,16, 5),f(11,16, 6) / -8.9900000D-05 , -8.6900000D-05 /
      data f(11,16, 7),f(11,16, 8) / -9.0600000D-05 , -1.0250000D-04 /
      data f(11,16, 9),f(11,16,10) / -1.0920000D-04 , -1.0250000D-04 /
      data f(11,16,11),f(11,16,12) / -9.0600000D-05 , -8.6900000D-05 /
      data f(11,16,13),f(11,16,14) / -8.9900000D-05 , -9.4500000D-05 /
      data f(11,16,15),f(11,16,16) / -9.6900000D-05 , -9.4500000D-05 /
      data f(11,16,17) /             -8.9900000D-05 /
      data f(11,17, 1),f(11,17, 2) / -8.8700000D-05 , -9.1700000D-05 /
      data f(11,17, 3),f(11,17, 4) / -9.3200000D-05 , -9.1700000D-05 /
      data f(11,17, 5),f(11,17, 6) / -8.8700000D-05 , -8.7700000D-05 /
      data f(11,17, 7),f(11,17, 8) / -9.2300000D-05 , -1.0050000D-04 /
      data f(11,17, 9),f(11,17,10) / -1.0480000D-04 , -1.0050000D-04 /
      data f(11,17,11),f(11,17,12) / -9.2300000D-05 , -8.7700000D-05 /
      data f(11,17,13),f(11,17,14) / -8.8700000D-05 , -9.1700000D-05 /
      data f(11,17,15),f(11,17,16) / -9.3200000D-05 , -9.1700000D-05 /
      data f(11,17,17) /             -8.8700000D-05 /
      data f(11,18, 1),f(11,18, 2) / -8.8400000D-05 , -8.8800000D-05 /
      data f(11,18, 3),f(11,18, 4) / -8.9200000D-05 , -8.8800000D-05 /
      data f(11,18, 5),f(11,18, 6) / -8.8400000D-05 , -8.9200000D-05 /
      data f(11,18, 7),f(11,18, 8) / -9.1700000D-05 , -9.4900000D-05 /
      data f(11,18, 9),f(11,18,10) / -9.6400000D-05 , -9.4900000D-05 /
      data f(11,18,11),f(11,18,12) / -9.1700000D-05 , -8.9200000D-05 /
      data f(11,18,13),f(11,18,14) / -8.8400000D-05 , -8.8800000D-05 /
      data f(11,18,15),f(11,18,16) / -8.9200000D-05 , -8.8800000D-05 /
      data f(11,18,17) /             -8.8400000D-05 /
      data f(11,19, 1),f(11,19, 2) / -8.9800000D-05 , -8.9800000D-05 /
      data f(11,19, 3),f(11,19, 4) / -8.9800000D-05 , -8.9800000D-05 /
      data f(11,19, 5),f(11,19, 6) / -8.9800000D-05 , -8.9800000D-05 /
      data f(11,19, 7),f(11,19, 8) / -8.9800000D-05 , -8.9800000D-05 /
      data f(11,19, 9),f(11,19,10) / -8.9800000D-05 , -8.9800000D-05 /
      data f(11,19,11),f(11,19,12) / -8.9800000D-05 , -8.9800000D-05 /
      data f(11,19,13),f(11,19,14) / -8.9800000D-05 , -8.9800000D-05 /
      data f(11,19,15),f(11,19,16) / -8.9800000D-05 , -8.9800000D-05 /
      data f(11,19,17) /             -8.9800000D-05 /
      data f(12, 1, 1),f(12, 1, 2) / -2.7200000D-05 , -2.7200000D-05 /
      data f(12, 1, 3),f(12, 1, 4) / -2.7200000D-05 , -2.7200000D-05 /
      data f(12, 1, 5),f(12, 1, 6) / -2.7200000D-05 , -2.7200000D-05 /
      data f(12, 1, 7),f(12, 1, 8) / -2.7200000D-05 , -2.7200000D-05 /
      data f(12, 1, 9),f(12, 1,10) / -2.7200000D-05 , -2.7200000D-05 /
      data f(12, 1,11),f(12, 1,12) / -2.7200000D-05 , -2.7200000D-05 /
      data f(12, 1,13),f(12, 1,14) / -2.7200000D-05 , -2.7200000D-05 /
      data f(12, 1,15),f(12, 1,16) / -2.7200000D-05 , -2.7200000D-05 /
      data f(12, 1,17) /             -2.7200000D-05 /
      data f(12, 2, 1),f(12, 2, 2) / -2.7200000D-05 , -2.7400000D-05 /
      data f(12, 2, 3),f(12, 2, 4) / -2.7400000D-05 , -2.7400000D-05 /
      data f(12, 2, 5),f(12, 2, 6) / -2.7200000D-05 , -2.7100000D-05 /
      data f(12, 2, 7),f(12, 2, 8) / -2.7000000D-05 , -2.6900000D-05 /
      data f(12, 2, 9),f(12, 2,10) / -2.6800000D-05 , -2.6900000D-05 /
      data f(12, 2,11),f(12, 2,12) / -2.7000000D-05 , -2.7100000D-05 /
      data f(12, 2,13),f(12, 2,14) / -2.7200000D-05 , -2.7400000D-05 /
      data f(12, 2,15),f(12, 2,16) / -2.7400000D-05 , -2.7400000D-05 /
      data f(12, 2,17) /             -2.7200000D-05 /
      data f(12, 3, 1),f(12, 3, 2) / -2.6600000D-05 , -2.7200000D-05 /
      data f(12, 3, 3),f(12, 3, 4) / -2.7700000D-05 , -2.7200000D-05 /
      data f(12, 3, 5),f(12, 3, 6) / -2.6600000D-05 , -2.6500000D-05 /
      data f(12, 3, 7),f(12, 3, 8) / -2.6700000D-05 , -2.6300000D-05 /
      data f(12, 3, 9),f(12, 3,10) / -2.6000000D-05 , -2.6300000D-05 /
      data f(12, 3,11),f(12, 3,12) / -2.6700000D-05 , -2.6500000D-05 /
      data f(12, 3,13),f(12, 3,14) / -2.6600000D-05 , -2.7200000D-05 /
      data f(12, 3,15),f(12, 3,16) / -2.7700000D-05 , -2.7200000D-05 /
      data f(12, 3,17) /             -2.6600000D-05 /
      data f(12, 4, 1),f(12, 4, 2) / -2.5400000D-05 , -2.6800000D-05 /
      data f(12, 4, 3),f(12, 4, 4) / -2.8100000D-05 , -2.6800000D-05 /
      data f(12, 4, 5),f(12, 4, 6) / -2.5400000D-05 , -2.5800000D-05 /
      data f(12, 4, 7),f(12, 4, 8) / -2.6500000D-05 , -2.5600000D-05 /
      data f(12, 4, 9),f(12, 4,10) / -2.4900000D-05 , -2.5600000D-05 /
      data f(12, 4,11),f(12, 4,12) / -2.6500000D-05 , -2.5800000D-05 /
      data f(12, 4,13),f(12, 4,14) / -2.5400000D-05 , -2.6800000D-05 /
      data f(12, 4,15),f(12, 4,16) / -2.8100000D-05 , -2.6800000D-05 /
      data f(12, 4,17) /             -2.5400000D-05 /
      data f(12, 5, 1),f(12, 5, 2) / -2.3700000D-05 , -2.5700000D-05 /
      data f(12, 5, 3),f(12, 5, 4) / -2.8000000D-05 , -2.5700000D-05 /
      data f(12, 5, 5),f(12, 5, 6) / -2.3700000D-05 , -2.4700000D-05 /
      data f(12, 5, 7),f(12, 5, 8) / -2.6100000D-05 , -2.4600000D-05 /
      data f(12, 5, 9),f(12, 5,10) / -2.3400000D-05 , -2.4600000D-05 /
      data f(12, 5,11),f(12, 5,12) / -2.6100000D-05 , -2.4700000D-05 /
      data f(12, 5,13),f(12, 5,14) / -2.3700000D-05 , -2.5700000D-05 /
      data f(12, 5,15),f(12, 5,16) / -2.8000000D-05 , -2.5700000D-05 /
      data f(12, 5,17) /             -2.3700000D-05 /
      data f(12, 6, 1),f(12, 6, 2) / -2.1900000D-05 , -2.3900000D-05 /
      data f(12, 6, 3),f(12, 6, 4) / -2.6700000D-05 , -2.3900000D-05 /
      data f(12, 6, 5),f(12, 6, 6) / -2.1900000D-05 , -2.3300000D-05 /
      data f(12, 6, 7),f(12, 6, 8) / -2.5000000D-05 , -2.3100000D-05 /
      data f(12, 6, 9),f(12, 6,10) / -2.1600000D-05 , -2.3100000D-05 /
      data f(12, 6,11),f(12, 6,12) / -2.5000000D-05 , -2.3300000D-05 /
      data f(12, 6,13),f(12, 6,14) / -2.1900000D-05 , -2.3900000D-05 /
      data f(12, 6,15),f(12, 6,16) / -2.6700000D-05 , -2.3900000D-05 /
      data f(12, 6,17) /             -2.1900000D-05 /
      data f(12, 7, 1),f(12, 7, 2) / -2.0000000D-05 , -2.1600000D-05 /
      data f(12, 7, 3),f(12, 7, 4) / -2.4000000D-05 , -2.1600000D-05 /
      data f(12, 7, 5),f(12, 7, 6) / -2.0000000D-05 , -2.1500000D-05 /
      data f(12, 7, 7),f(12, 7, 8) / -2.2900000D-05 , -2.1200000D-05 /
      data f(12, 7, 9),f(12, 7,10) / -1.9800000D-05 , -2.1200000D-05 /
      data f(12, 7,11),f(12, 7,12) / -2.2900000D-05 , -2.1500000D-05 /
      data f(12, 7,13),f(12, 7,14) / -2.0000000D-05 , -2.1600000D-05 /
      data f(12, 7,15),f(12, 7,16) / -2.4000000D-05 , -2.1600000D-05 /
      data f(12, 7,17) /             -2.0000000D-05 /
      data f(12, 8, 1),f(12, 8, 2) / -1.8300000D-05 , -1.9200000D-05 /
      data f(12, 8, 3),f(12, 8, 4) / -2.0800000D-05 , -1.9200000D-05 /
      data f(12, 8, 5),f(12, 8, 6) / -1.8300000D-05 , -1.9500000D-05 /
      data f(12, 8, 7),f(12, 8, 8) / -2.0300000D-05 , -1.9000000D-05 /
      data f(12, 8, 9),f(12, 8,10) / -1.8000000D-05 , -1.9000000D-05 /
      data f(12, 8,11),f(12, 8,12) / -2.0300000D-05 , -1.9500000D-05 /
      data f(12, 8,13),f(12, 8,14) / -1.8300000D-05 , -1.9200000D-05 /
      data f(12, 8,15),f(12, 8,16) / -2.0800000D-05 , -1.9200000D-05 /
      data f(12, 8,17) /             -1.8300000D-05 /
      data f(12, 9, 1),f(12, 9, 2) / -1.7100000D-05 , -1.7500000D-05 /
      data f(12, 9, 3),f(12, 9, 4) / -1.8300000D-05 , -1.7500000D-05 /
      data f(12, 9, 5),f(12, 9, 6) / -1.7100000D-05 , -1.8000000D-05 /
      data f(12, 9, 7),f(12, 9, 8) / -1.8200000D-05 , -1.7300000D-05 /
      data f(12, 9, 9),f(12, 9,10) / -1.6600000D-05 , -1.7300000D-05 /
      data f(12, 9,11),f(12, 9,12) / -1.8200000D-05 , -1.8000000D-05 /
      data f(12, 9,13),f(12, 9,14) / -1.7100000D-05 , -1.7500000D-05 /
      data f(12, 9,15),f(12, 9,16) / -1.8300000D-05 , -1.7500000D-05 /
      data f(12, 9,17) /             -1.7100000D-05 /
      data f(12,10, 1),f(12,10, 2) / -1.6700000D-05 , -1.6700000D-05 /
      data f(12,10, 3),f(12,10, 4) / -1.7000000D-05 , -1.6700000D-05 /
      data f(12,10, 5),f(12,10, 6) / -1.6700000D-05 , -1.7500000D-05 /
      data f(12,10, 7),f(12,10, 8) / -1.7100000D-05 , -1.6400000D-05 /
      data f(12,10, 9),f(12,10,10) / -1.5900000D-05 , -1.6400000D-05 /
      data f(12,10,11),f(12,10,12) / -1.7100000D-05 , -1.7500000D-05 /
      data f(12,10,13),f(12,10,14) / -1.6700000D-05 , -1.6700000D-05 /
      data f(12,10,15),f(12,10,16) / -1.7000000D-05 , -1.6700000D-05 /
      data f(12,10,17) /             -1.6700000D-05 /
      data f(12,11, 1),f(12,11, 2) / -1.7400000D-05 , -1.6900000D-05 /
      data f(12,11, 3),f(12,11, 4) / -1.6800000D-05 , -1.6900000D-05 /
      data f(12,11, 5),f(12,11, 6) / -1.7400000D-05 , -1.8100000D-05 /
      data f(12,11, 7),f(12,11, 8) / -1.7200000D-05 , -1.6400000D-05 /
      data f(12,11, 9),f(12,11,10) / -1.6100000D-05 , -1.6400000D-05 /
      data f(12,11,11),f(12,11,12) / -1.7200000D-05 , -1.8100000D-05 /
      data f(12,11,13),f(12,11,14) / -1.7400000D-05 , -1.6900000D-05 /
      data f(12,11,15),f(12,11,16) / -1.6800000D-05 , -1.6900000D-05 /
      data f(12,11,17) /             -1.7400000D-05 /
      data f(12,12, 1),f(12,12, 2) / -1.9100000D-05 , -1.8000000D-05 /
      data f(12,12, 3),f(12,12, 4) / -1.7700000D-05 , -1.8000000D-05 /
      data f(12,12, 5),f(12,12, 6) / -1.9100000D-05 , -1.9800000D-05 /
      data f(12,12, 7),f(12,12, 8) / -1.8000000D-05 , -1.7400000D-05 /
      data f(12,12, 9),f(12,12,10) / -1.7100000D-05 , -1.7400000D-05 /
      data f(12,12,11),f(12,12,12) / -1.8000000D-05 , -1.9800000D-05 /
      data f(12,12,13),f(12,12,14) / -1.9100000D-05 , -1.8000000D-05 /
      data f(12,12,15),f(12,12,16) / -1.7700000D-05 , -1.8000000D-05 /
      data f(12,12,17) /             -1.9100000D-05 /
      data f(12,13, 1),f(12,13, 2) / -2.1400000D-05 , -1.9600000D-05 /
      data f(12,13, 3),f(12,13, 4) / -1.9300000D-05 , -1.9600000D-05 /
      data f(12,13, 5),f(12,13, 6) / -2.1400000D-05 , -2.2300000D-05 /
      data f(12,13, 7),f(12,13, 8) / -1.9500000D-05 , -1.8900000D-05 /
      data f(12,13, 9),f(12,13,10) / -1.8800000D-05 , -1.8900000D-05 /
      data f(12,13,11),f(12,13,12) / -1.9500000D-05 , -2.2300000D-05 /
      data f(12,13,13),f(12,13,14) / -2.1400000D-05 , -1.9600000D-05 /
      data f(12,13,15),f(12,13,16) / -1.9300000D-05 , -1.9600000D-05 /
      data f(12,13,17) /             -2.1400000D-05 /
      data f(12,14, 1),f(12,14, 2) / -2.3900000D-05 , -2.1500000D-05 /
      data f(12,14, 3),f(12,14, 4) / -2.1200000D-05 , -2.1500000D-05 /
      data f(12,14, 5),f(12,14, 6) / -2.3900000D-05 , -2.4700000D-05 /
      data f(12,14, 7),f(12,14, 8) / -2.1500000D-05 , -2.0800000D-05 /
      data f(12,14, 9),f(12,14,10) / -2.0800000D-05 , -2.0800000D-05 /
      data f(12,14,11),f(12,14,12) / -2.1500000D-05 , -2.4700000D-05 /
      data f(12,14,13),f(12,14,14) / -2.3900000D-05 , -2.1500000D-05 /
      data f(12,14,15),f(12,14,16) / -2.1200000D-05 , -2.1500000D-05 /
      data f(12,14,17) /             -2.3900000D-05 /
      data f(12,15, 1),f(12,15, 2) / -2.5700000D-05 , -2.3400000D-05 /
      data f(12,15, 3),f(12,15, 4) / -2.3100000D-05 , -2.3400000D-05 /
      data f(12,15, 5),f(12,15, 6) / -2.5700000D-05 , -2.6300000D-05 /
      data f(12,15, 7),f(12,15, 8) / -2.3400000D-05 , -2.2600000D-05 /
      data f(12,15, 9),f(12,15,10) / -2.2600000D-05 , -2.2600000D-05 /
      data f(12,15,11),f(12,15,12) / -2.3400000D-05 , -2.6300000D-05 /
      data f(12,15,13),f(12,15,14) / -2.5700000D-05 , -2.3400000D-05 /
      data f(12,15,15),f(12,15,16) / -2.3100000D-05 , -2.3400000D-05 /
      data f(12,15,17) /             -2.5700000D-05 /
      data f(12,16, 1),f(12,16, 2) / -2.6500000D-05 , -2.4900000D-05 /
      data f(12,16, 3),f(12,16, 4) / -2.4500000D-05 , -2.4900000D-05 /
      data f(12,16, 5),f(12,16, 6) / -2.6500000D-05 , -2.6800000D-05 /
      data f(12,16, 7),f(12,16, 8) / -2.4800000D-05 , -2.4000000D-05 /
      data f(12,16, 9),f(12,16,10) / -2.4100000D-05 , -2.4000000D-05 /
      data f(12,16,11),f(12,16,12) / -2.4800000D-05 , -2.6800000D-05 /
      data f(12,16,13),f(12,16,14) / -2.6500000D-05 , -2.4900000D-05 /
      data f(12,16,15),f(12,16,16) / -2.4500000D-05 , -2.4900000D-05 /
      data f(12,16,17) /             -2.6500000D-05 /
      data f(12,17, 1),f(12,17, 2) / -2.6400000D-05 , -2.5700000D-05 /
      data f(12,17, 3),f(12,17, 4) / -2.5400000D-05 , -2.5700000D-05 /
      data f(12,17, 5),f(12,17, 6) / -2.6400000D-05 , -2.6400000D-05 /
      data f(12,17, 7),f(12,17, 8) / -2.5500000D-05 , -2.5000000D-05 /
      data f(12,17, 9),f(12,17,10) / -2.5000000D-05 , -2.5000000D-05 /
      data f(12,17,11),f(12,17,12) / -2.5500000D-05 , -2.6400000D-05 /
      data f(12,17,13),f(12,17,14) / -2.6400000D-05 , -2.5700000D-05 /
      data f(12,17,15),f(12,17,16) / -2.5400000D-05 , -2.5700000D-05 /
      data f(12,17,17) /             -2.6400000D-05 /
      data f(12,18, 1),f(12,18, 2) / -2.5900000D-05 , -2.5800000D-05 /
      data f(12,18, 3),f(12,18, 4) / -2.5700000D-05 , -2.5800000D-05 /
      data f(12,18, 5),f(12,18, 6) / -2.5900000D-05 , -2.5900000D-05 /
      data f(12,18, 7),f(12,18, 8) / -2.5700000D-05 , -2.5500000D-05 /
      data f(12,18, 9),f(12,18,10) / -2.5500000D-05 , -2.5500000D-05 /
      data f(12,18,11),f(12,18,12) / -2.5700000D-05 , -2.5900000D-05 /
      data f(12,18,13),f(12,18,14) / -2.5900000D-05 , -2.5800000D-05 /
      data f(12,18,15),f(12,18,16) / -2.5700000D-05 , -2.5800000D-05 /
      data f(12,18,17) /             -2.5900000D-05 /
      data f(12,19, 1),f(12,19, 2) / -2.5700000D-05 , -2.5700000D-05 /
      data f(12,19, 3),f(12,19, 4) / -2.5700000D-05 , -2.5700000D-05 /
      data f(12,19, 5),f(12,19, 6) / -2.5700000D-05 , -2.5700000D-05 /
      data f(12,19, 7),f(12,19, 8) / -2.5700000D-05 , -2.5700000D-05 /
      data f(12,19, 9),f(12,19,10) / -2.5700000D-05 , -2.5700000D-05 /
      data f(12,19,11),f(12,19,12) / -2.5700000D-05 , -2.5700000D-05 /
      data f(12,19,13),f(12,19,14) / -2.5700000D-05 , -2.5700000D-05 /
      data f(12,19,15),f(12,19,16) / -2.5700000D-05 , -2.5700000D-05 /
      data f(12,19,17) /             -2.5700000D-05 /
      data f(13, 1, 1),f(13, 1, 2) / -6.2000000D-06 , -6.2000000D-06 /
      data f(13, 1, 3),f(13, 1, 4) / -6.2000000D-06 , -6.2000000D-06 /
      data f(13, 1, 5),f(13, 1, 6) / -6.2000000D-06 , -6.2000000D-06 /
      data f(13, 1, 7),f(13, 1, 8) / -6.2000000D-06 , -6.2000000D-06 /
      data f(13, 1, 9),f(13, 1,10) / -6.2000000D-06 , -6.2000000D-06 /
      data f(13, 1,11),f(13, 1,12) / -6.2000000D-06 , -6.2000000D-06 /
      data f(13, 1,13),f(13, 1,14) / -6.2000000D-06 , -6.2000000D-06 /
      data f(13, 1,15),f(13, 1,16) / -6.2000000D-06 , -6.2000000D-06 /
      data f(13, 1,17) /             -6.2000000D-06 /
      data f(13, 2, 1),f(13, 2, 2) / -6.2000000D-06 , -6.3000000D-06 /
      data f(13, 2, 3),f(13, 2, 4) / -6.3000000D-06 , -6.3000000D-06 /
      data f(13, 2, 5),f(13, 2, 6) / -6.2000000D-06 , -6.1000000D-06 /
      data f(13, 2, 7),f(13, 2, 8) / -6.1000000D-06 , -6.1000000D-06 /
      data f(13, 2, 9),f(13, 2,10) / -6.0000000D-06 , -6.1000000D-06 /
      data f(13, 2,11),f(13, 2,12) / -6.1000000D-06 , -6.1000000D-06 /
      data f(13, 2,13),f(13, 2,14) / -6.2000000D-06 , -6.3000000D-06 /
      data f(13, 2,15),f(13, 2,16) / -6.3000000D-06 , -6.3000000D-06 /
      data f(13, 2,17) /             -6.2000000D-06 /
      data f(13, 3, 1),f(13, 3, 2) / -6.0000000D-06 , -6.1000000D-06 /
      data f(13, 3, 3),f(13, 3, 4) / -6.2000000D-06 , -6.1000000D-06 /
      data f(13, 3, 5),f(13, 3, 6) / -6.0000000D-06 , -5.9000000D-06 /
      data f(13, 3, 7),f(13, 3, 8) / -5.9000000D-06 , -5.8000000D-06 /
      data f(13, 3, 9),f(13, 3,10) / -5.7000000D-06 , -5.8000000D-06 /
      data f(13, 3,11),f(13, 3,12) / -5.9000000D-06 , -5.9000000D-06 /
      data f(13, 3,13),f(13, 3,14) / -6.0000000D-06 , -6.1000000D-06 /
      data f(13, 3,15),f(13, 3,16) / -6.2000000D-06 , -6.1000000D-06 /
      data f(13, 3,17) /             -6.0000000D-06 /
      data f(13, 4, 1),f(13, 4, 2) / -5.6000000D-06 , -5.9000000D-06 /
      data f(13, 4, 3),f(13, 4, 4) / -6.2000000D-06 , -5.9000000D-06 /
      data f(13, 4, 5),f(13, 4, 6) / -5.6000000D-06 , -5.6000000D-06 /
      data f(13, 4, 7),f(13, 4, 8) / -5.6000000D-06 , -5.5000000D-06 /
      data f(13, 4, 9),f(13, 4,10) / -5.4000000D-06 , -5.5000000D-06 /
      data f(13, 4,11),f(13, 4,12) / -5.6000000D-06 , -5.6000000D-06 /
      data f(13, 4,13),f(13, 4,14) / -5.6000000D-06 , -5.9000000D-06 /
      data f(13, 4,15),f(13, 4,16) / -6.2000000D-06 , -5.9000000D-06 /
      data f(13, 4,17) /             -5.6000000D-06 /
      data f(13, 5, 1),f(13, 5, 2) / -5.2000000D-06 , -5.7000000D-06 /
      data f(13, 5, 3),f(13, 5, 4) / -6.1000000D-06 , -5.7000000D-06 /
      data f(13, 5, 5),f(13, 5, 6) / -5.2000000D-06 , -5.2000000D-06 /
      data f(13, 5, 7),f(13, 5, 8) / -5.4000000D-06 , -5.1000000D-06 /
      data f(13, 5, 9),f(13, 5,10) / -5.0000000D-06 , -5.1000000D-06 /
      data f(13, 5,11),f(13, 5,12) / -5.4000000D-06 , -5.2000000D-06 /
      data f(13, 5,13),f(13, 5,14) / -5.2000000D-06 , -5.7000000D-06 /
      data f(13, 5,15),f(13, 5,16) / -6.1000000D-06 , -5.7000000D-06 /
      data f(13, 5,17) /             -5.2000000D-06 /
      data f(13, 6, 1),f(13, 6, 2) / -4.8000000D-06 , -5.3000000D-06 /
      data f(13, 6, 3),f(13, 6, 4) / -5.9000000D-06 , -5.3000000D-06 /
      data f(13, 6, 5),f(13, 6, 6) / -4.8000000D-06 , -4.9000000D-06 /
      data f(13, 6, 7),f(13, 6, 8) / -5.2000000D-06 , -4.9000000D-06 /
      data f(13, 6, 9),f(13, 6,10) / -4.6000000D-06 , -4.9000000D-06 /
      data f(13, 6,11),f(13, 6,12) / -5.2000000D-06 , -4.9000000D-06 /
      data f(13, 6,13),f(13, 6,14) / -4.8000000D-06 , -5.3000000D-06 /
      data f(13, 6,15),f(13, 6,16) / -5.9000000D-06 , -5.3000000D-06 /
      data f(13, 6,17) /             -4.8000000D-06 /
      data f(13, 7, 1),f(13, 7, 2) / -4.4000000D-06 , -4.9000000D-06 /
      data f(13, 7, 3),f(13, 7, 4) / -5.4000000D-06 , -4.9000000D-06 /
      data f(13, 7, 5),f(13, 7, 6) / -4.4000000D-06 , -4.6000000D-06 /
      data f(13, 7, 7),f(13, 7, 8) / -4.9000000D-06 , -4.5000000D-06 /
      data f(13, 7, 9),f(13, 7,10) / -4.2000000D-06 , -4.5000000D-06 /
      data f(13, 7,11),f(13, 7,12) / -4.9000000D-06 , -4.6000000D-06 /
      data f(13, 7,13),f(13, 7,14) / -4.4000000D-06 , -4.9000000D-06 /
      data f(13, 7,15),f(13, 7,16) / -5.4000000D-06 , -4.9000000D-06 /
      data f(13, 7,17) /             -4.4000000D-06 /
      data f(13, 8, 1),f(13, 8, 2) / -4.0000000D-06 , -4.4000000D-06 /
      data f(13, 8, 3),f(13, 8, 4) / -4.9000000D-06 , -4.4000000D-06 /
      data f(13, 8, 5),f(13, 8, 6) / -4.0000000D-06 , -4.3000000D-06 /
      data f(13, 8, 7),f(13, 8, 8) / -4.5000000D-06 , -4.1000000D-06 /
      data f(13, 8, 9),f(13, 8,10) / -3.9000000D-06 , -4.1000000D-06 /
      data f(13, 8,11),f(13, 8,12) / -4.5000000D-06 , -4.3000000D-06 /
      data f(13, 8,13),f(13, 8,14) / -4.0000000D-06 , -4.4000000D-06 /
      data f(13, 8,15),f(13, 8,16) / -4.9000000D-06 , -4.4000000D-06 /
      data f(13, 8,17) /             -4.0000000D-06 /
      data f(13, 9, 1),f(13, 9, 2) / -3.8000000D-06 , -4.0000000D-06 /
      data f(13, 9, 3),f(13, 9, 4) / -4.3000000D-06 , -4.0000000D-06 /
      data f(13, 9, 5),f(13, 9, 6) / -3.8000000D-06 , -4.0000000D-06 /
      data f(13, 9, 7),f(13, 9, 8) / -4.1000000D-06 , -3.8000000D-06 /
      data f(13, 9, 9),f(13, 9,10) / -3.5000000D-06 , -3.8000000D-06 /
      data f(13, 9,11),f(13, 9,12) / -4.1000000D-06 , -4.0000000D-06 /
      data f(13, 9,13),f(13, 9,14) / -3.8000000D-06 , -4.0000000D-06 /
      data f(13, 9,15),f(13, 9,16) / -4.3000000D-06 , -4.0000000D-06 /
      data f(13, 9,17) /             -3.8000000D-06 /
      data f(13,10, 1),f(13,10, 2) / -3.7000000D-06 , -3.7000000D-06 /
      data f(13,10, 3),f(13,10, 4) / -3.9000000D-06 , -3.7000000D-06 /
      data f(13,10, 5),f(13,10, 6) / -3.7000000D-06 , -4.0000000D-06 /
      data f(13,10, 7),f(13,10, 8) / -3.9000000D-06 , -3.5000000D-06 /
      data f(13,10, 9),f(13,10,10) / -3.3000000D-06 , -3.5000000D-06 /
      data f(13,10,11),f(13,10,12) / -3.9000000D-06 , -4.0000000D-06 /
      data f(13,10,13),f(13,10,14) / -3.7000000D-06 , -3.7000000D-06 /
      data f(13,10,15),f(13,10,16) / -3.9000000D-06 , -3.7000000D-06 /
      data f(13,10,17) /             -3.7000000D-06 /
      data f(13,11, 1),f(13,11, 2) / -3.9000000D-06 , -3.7000000D-06 /
      data f(13,11, 3),f(13,11, 4) / -3.7000000D-06 , -3.7000000D-06 /
      data f(13,11, 5),f(13,11, 6) / -3.9000000D-06 , -4.2000000D-06 /
      data f(13,11, 7),f(13,11, 8) / -3.9000000D-06 , -3.5000000D-06 /
      data f(13,11, 9),f(13,11,10) / -3.3000000D-06 , -3.5000000D-06 /
      data f(13,11,11),f(13,11,12) / -3.9000000D-06 , -4.2000000D-06 /
      data f(13,11,13),f(13,11,14) / -3.9000000D-06 , -3.7000000D-06 /
      data f(13,11,15),f(13,11,16) / -3.7000000D-06 , -3.7000000D-06 /
      data f(13,11,17) /             -3.9000000D-06 /
      data f(13,12, 1),f(13,12, 2) / -4.4000000D-06 , -3.9000000D-06 /
      data f(13,12, 3),f(13,12, 4) / -3.7000000D-06 , -3.9000000D-06 /
      data f(13,12, 5),f(13,12, 6) / -4.4000000D-06 , -4.5000000D-06 /
      data f(13,12, 7),f(13,12, 8) / -4.0000000D-06 , -3.6000000D-06 /
      data f(13,12, 9),f(13,12,10) / -3.5000000D-06 , -3.6000000D-06 /
      data f(13,12,11),f(13,12,12) / -4.0000000D-06 , -4.5000000D-06 /
      data f(13,12,13),f(13,12,14) / -4.4000000D-06 , -3.9000000D-06 /
      data f(13,12,15),f(13,12,16) / -3.7000000D-06 , -3.9000000D-06 /
      data f(13,12,17) /             -4.4000000D-06 /
      data f(13,13, 1),f(13,13, 2) / -4.8000000D-06 , -4.2000000D-06 /
      data f(13,13, 3),f(13,13, 4) / -4.0000000D-06 , -4.2000000D-06 /
      data f(13,13, 5),f(13,13, 6) / -4.8000000D-06 , -4.9000000D-06 /
      data f(13,13, 7),f(13,13, 8) / -4.3000000D-06 , -3.9000000D-06 /
      data f(13,13, 9),f(13,13,10) / -3.7000000D-06 , -3.9000000D-06 /
      data f(13,13,11),f(13,13,12) / -4.3000000D-06 , -4.9000000D-06 /
      data f(13,13,13),f(13,13,14) / -4.8000000D-06 , -4.2000000D-06 /
      data f(13,13,15),f(13,13,16) / -4.0000000D-06 , -4.2000000D-06 /
      data f(13,13,17) /             -4.8000000D-06 /
      data f(13,14, 1),f(13,14, 2) / -5.1000000D-06 , -4.5000000D-06 /
      data f(13,14, 3),f(13,14, 4) / -4.3000000D-06 , -4.5000000D-06 /
      data f(13,14, 5),f(13,14, 6) / -5.1000000D-06 , -5.2000000D-06 /
      data f(13,14, 7),f(13,14, 8) / -4.6000000D-06 , -4.2000000D-06 /
      data f(13,14, 9),f(13,14,10) / -4.1000000D-06 , -4.2000000D-06 /
      data f(13,14,11),f(13,14,12) / -4.6000000D-06 , -5.2000000D-06 /
      data f(13,14,13),f(13,14,14) / -5.1000000D-06 , -4.5000000D-06 /
      data f(13,14,15),f(13,14,16) / -4.3000000D-06 , -4.5000000D-06 /
      data f(13,14,17) /             -5.1000000D-06 /
      data f(13,15, 1),f(13,15, 2) / -5.3000000D-06 , -4.8000000D-06 /
      data f(13,15, 3),f(13,15, 4) / -4.7000000D-06 , -4.8000000D-06 /
      data f(13,15, 5),f(13,15, 6) / -5.3000000D-06 , -5.4000000D-06 /
      data f(13,15, 7),f(13,15, 8) / -4.9000000D-06 , -4.6000000D-06 /
      data f(13,15, 9),f(13,15,10) / -4.5000000D-06 , -4.6000000D-06 /
      data f(13,15,11),f(13,15,12) / -4.9000000D-06 , -5.4000000D-06 /
      data f(13,15,13),f(13,15,14) / -5.3000000D-06 , -4.8000000D-06 /
      data f(13,15,15),f(13,15,16) / -4.7000000D-06 , -4.8000000D-06 /
      data f(13,15,17) /             -5.3000000D-06 /
      data f(13,16, 1),f(13,16, 2) / -5.4000000D-06 , -5.1000000D-06 /
      data f(13,16, 3),f(13,16, 4) / -5.0000000D-06 , -5.1000000D-06 /
      data f(13,16, 5),f(13,16, 6) / -5.4000000D-06 , -5.5000000D-06 /
      data f(13,16, 7),f(13,16, 8) / -5.2000000D-06 , -4.9000000D-06 /
      data f(13,16, 9),f(13,16,10) / -4.9000000D-06 , -4.9000000D-06 /
      data f(13,16,11),f(13,16,12) / -5.2000000D-06 , -5.5000000D-06 /
      data f(13,16,13),f(13,16,14) / -5.4000000D-06 , -5.1000000D-06 /
      data f(13,16,15),f(13,16,16) / -5.0000000D-06 , -5.1000000D-06 /
      data f(13,16,17) /             -5.4000000D-06 /
      data f(13,17, 1),f(13,17, 2) / -5.5000000D-06 , -5.4000000D-06 /
      data f(13,17, 3),f(13,17, 4) / -5.3000000D-06 , -5.4000000D-06 /
      data f(13,17, 5),f(13,17, 6) / -5.5000000D-06 , -5.5000000D-06 /
      data f(13,17, 7),f(13,17, 8) / -5.4000000D-06 , -5.2000000D-06 /
      data f(13,17, 9),f(13,17,10) / -5.2000000D-06 , -5.2000000D-06 /
      data f(13,17,11),f(13,17,12) / -5.4000000D-06 , -5.5000000D-06 /
      data f(13,17,13),f(13,17,14) / -5.5000000D-06 , -5.4000000D-06 /
      data f(13,17,15),f(13,17,16) / -5.3000000D-06 , -5.4000000D-06 /
      data f(13,17,17) /             -5.5000000D-06 /
      data f(13,18, 1),f(13,18, 2) / -5.6000000D-06 , -5.5000000D-06 /
      data f(13,18, 3),f(13,18, 4) / -5.5000000D-06 , -5.5000000D-06 /
      data f(13,18, 5),f(13,18, 6) / -5.6000000D-06 , -5.6000000D-06 /
      data f(13,18, 7),f(13,18, 8) / -5.5000000D-06 , -5.5000000D-06 /
      data f(13,18, 9),f(13,18,10) / -5.5000000D-06 , -5.5000000D-06 /
      data f(13,18,11),f(13,18,12) / -5.5000000D-06 , -5.6000000D-06 /
      data f(13,18,13),f(13,18,14) / -5.6000000D-06 , -5.5000000D-06 /
      data f(13,18,15),f(13,18,16) / -5.5000000D-06 , -5.5000000D-06 /
      data f(13,18,17) /             -5.6000000D-06 /
      data f(13,19, 1),f(13,19, 2) / -5.6000000D-06 , -5.6000000D-06 /
      data f(13,19, 3),f(13,19, 4) / -5.6000000D-06 , -5.6000000D-06 /
      data f(13,19, 5),f(13,19, 6) / -5.6000000D-06 , -5.6000000D-06 /
      data f(13,19, 7),f(13,19, 8) / -5.6000000D-06 , -5.6000000D-06 /
      data f(13,19, 9),f(13,19,10) / -5.6000000D-06 , -5.6000000D-06 /
      data f(13,19,11),f(13,19,12) / -5.6000000D-06 , -5.6000000D-06 /
      data f(13,19,13),f(13,19,14) / -5.6000000D-06 , -5.6000000D-06 /
      data f(13,19,15),f(13,19,16) / -5.6000000D-06 , -5.6000000D-06 /
      data f(13,19,17) /             -5.6000000D-06 /
 
      data fpp( 1, 1, 1,1),fpp( 1, 1, 1,2),fpp( 1, 1, 1,3)/
     x 9.7459912D-02, 3.8488514D-06,-1.0044562D-19 /
      data fpp( 1, 1, 2,1),fpp( 1, 1, 2,2),fpp( 1, 1, 2,3)/
     x 9.7459912D-02,-1.4237592D-04, 1.0846814D-19 /
      data fpp( 1, 1, 3,1),fpp( 1, 1, 3,2),fpp( 1, 1, 3,3)/
     x 9.7459912D-02,-3.2232598D-04, 3.2974511D-20 /
      data fpp( 1, 1, 4,1),fpp( 1, 1, 4,2),fpp( 1, 1, 4,3)/
     x 9.7459912D-02,-1.4237592D-04, 5.4294476D-21 /
      data fpp( 1, 1, 5,1),fpp( 1, 1, 5,2),fpp( 1, 1, 5,3)/
     x 9.7459912D-02, 3.8488514D-06, 6.4119695D-21 /
      data fpp( 1, 1, 6,1),fpp( 1, 1, 6,2),fpp( 1, 1, 6,3)/
     x 9.7459912D-02, 7.0698027D-05, 2.6328865D-20 /
      data fpp( 1, 1, 7,1),fpp( 1, 1, 7,2),fpp( 1, 1, 7,3)/
     x 9.7459912D-02,-1.6185614D-04, 1.6864870D-20 /
      data fpp( 1, 1, 8,1),fpp( 1, 1, 8,2),fpp( 1, 1, 8,3)/
     x 9.7459912D-02,-1.4214255D-04,-7.3017207D-20 /
      data fpp( 1, 1, 9,1),fpp( 1, 1, 9,2),fpp( 1, 1, 9,3)/
     x 9.7459912D-02,-1.5934778D-04,-7.6000369D-21 /
      data fpp( 1, 1,10,1),fpp( 1, 1,10,2),fpp( 1, 1,10,3)/
     x 9.7459912D-02,-1.4214255D-04, 4.4160253D-20 /
      data fpp( 1, 1,11,1),fpp( 1, 1,11,2),fpp( 1, 1,11,3)/
     x 9.7459912D-02,-1.6185614D-04,-2.7814824D-20 /
      data fpp( 1, 1,12,1),fpp( 1, 1,12,2),fpp( 1, 1,12,3)/
     x 9.7459912D-02, 7.0698027D-05, 1.3106588D-20 /
      data fpp( 1, 1,13,1),fpp( 1, 1,13,2),fpp( 1, 1,13,3)/
     x 9.7459912D-02, 3.8488514D-06,-1.2787918D-20 /
      data fpp( 1, 1,14,1),fpp( 1, 1,14,2),fpp( 1, 1,14,3)/
     x 9.7459912D-02,-1.4237592D-04,-1.3834624D-20 /
      data fpp( 1, 1,15,1),fpp( 1, 1,15,2),fpp( 1, 1,15,3)/
     x 9.7459912D-02,-3.2232598D-04,-1.2201251D-20 /
      data fpp( 1, 1,16,1),fpp( 1, 1,16,2),fpp( 1, 1,16,3)/
     x 9.7459912D-02,-1.4237592D-04,-1.0565624D-20 /
      data fpp( 1, 1,17,1),fpp( 1, 1,17,2),fpp( 1, 1,17,3)/
     x 9.7459912D-02, 3.8488514D-06,-1.9135471D-20 /
      data fpp( 1, 2, 1,1),fpp( 1, 2, 1,2),fpp( 1, 2, 1,3)/
     x 7.5960391D-02,-1.2170703D-05, 1.8011215D-06 /
      data fpp( 1, 2, 2,1),fpp( 1, 2, 2,2),fpp( 1, 2, 2,3)/
     x 4.9954122D-02,-5.7772151D-05, 3.9596459D-06 /
      data fpp( 1, 2, 3,1),fpp( 1, 2, 3,2),fpp( 1, 2, 3,3)/
     x 4.1519254D-02,-5.0590041D-05, 8.3129616D-06 /
      data fpp( 1, 2, 4,1),fpp( 1, 2, 4,2),fpp( 1, 2, 4,3)/
     x 4.9954122D-02,-5.7772151D-05, 4.9845077D-06 /
      data fpp( 1, 2, 5,1),fpp( 1, 2, 5,2),fpp( 1, 2, 5,3)/
     x 7.5960391D-02,-1.2170703D-05,-2.2983257D-06 /
      data fpp( 1, 2, 6,1),fpp( 1, 2, 6,2),fpp( 1, 2, 6,3)/
     x 1.0256005D-01, 7.3839463D-06,-7.2492048D-06 /
      data fpp( 1, 2, 7,1),fpp( 1, 2, 7,2),fpp( 1, 2, 7,3)/
     x 1.0316428D-01,-7.9937267D-06,-3.3755218D-06 /
      data fpp( 1, 2, 8,1),fpp( 1, 2, 8,2),fpp( 1, 2, 8,3)/
     x 9.1224516D-02,-7.4179894D-05, 2.0146253D-06 /
      data fpp( 1, 2, 9,1),fpp( 1, 2, 9,2),fpp( 1, 2, 9,3)/
     x 8.6093408D-02,-8.6423440D-05, 3.7056874D-06 /
      data fpp( 1, 2,10,1),fpp( 1, 2,10,2),fpp( 1, 2,10,3)/
     x 9.1224516D-02,-7.4179894D-05, 2.0146253D-06 /
      data fpp( 1, 2,11,1),fpp( 1, 2,11,2),fpp( 1, 2,11,3)/
     x 1.0316428D-01,-7.9937267D-06,-3.3755218D-06 /
      data fpp( 1, 2,12,1),fpp( 1, 2,12,2),fpp( 1, 2,12,3)/
     x 1.0256005D-01, 7.3839463D-06,-7.2492048D-06 /
      data fpp( 1, 2,13,1),fpp( 1, 2,13,2),fpp( 1, 2,13,3)/
     x 7.5960391D-02,-1.2170703D-05,-2.2983257D-06 /
      data fpp( 1, 2,14,1),fpp( 1, 2,14,2),fpp( 1, 2,14,3)/
     x 4.9954122D-02,-5.7772151D-05, 4.9845077D-06 /
      data fpp( 1, 2,15,1),fpp( 1, 2,15,2),fpp( 1, 2,15,3)/
     x 4.1519254D-02,-5.0590041D-05, 8.3129616D-06 /
      data fpp( 1, 2,16,1),fpp( 1, 2,16,2),fpp( 1, 2,16,3)/
     x 4.9954122D-02,-5.7772151D-05, 3.9596459D-06 /
      data fpp( 1, 2,17,1),fpp( 1, 2,17,2),fpp( 1, 2,17,3)/
     x 7.5960391D-02,-1.2170703D-05, 1.8011215D-06 /
      data fpp( 1, 3, 1,1),fpp( 1, 3, 1,2),fpp( 1, 3, 1,3)/
     x 6.0217245D-02,-2.1520040D-05, 9.4171034D-06 /
      data fpp( 1, 3, 2,1),fpp( 1, 3, 2,2),fpp( 1, 3, 2,3)/
     x 2.2478709D-02, 6.0420529D-05, 1.2329238D-05 /
      data fpp( 1, 3, 3,1),fpp( 1, 3, 3,2),fpp( 1, 3, 3,3)/
     x 3.8138529D-02, 1.7083015D-04, 1.6046613D-05 /
      data fpp( 1, 3, 4,1),fpp( 1, 3, 4,2),fpp( 1, 3, 4,3)/
     x 2.2478709D-02, 6.0420529D-05, 1.6945645D-05 /
      data fpp( 1, 3, 5,1),fpp( 1, 3, 5,2),fpp( 1, 3, 5,3)/
     x 6.0217245D-02,-2.1520040D-05,-9.0485274D-06 /
      data fpp( 1, 3, 6,1),fpp( 1, 3, 6,2),fpp( 1, 3, 6,3)/
     x 1.0899854D-01,-7.6965812D-05,-2.1119536D-05 /
      data fpp( 1, 3, 7,1),fpp( 1, 3, 7,2),fpp( 1, 3, 7,3)/
     x 8.6507885D-02, 2.2579043D-05,-7.3859968D-06 /
      data fpp( 1, 3, 8,1),fpp( 1, 3, 8,2),fpp( 1, 3, 8,3)/
     x 5.9681802D-02, 3.0184130D-05, 8.4228562D-06 /
      data fpp( 1, 3, 9,1),fpp( 1, 3, 9,2),fpp( 1, 3, 9,3)/
     x 5.5513322D-02, 2.6535540D-05, 9.0939052D-06 /
      data fpp( 1, 3,10,1),fpp( 1, 3,10,2),fpp( 1, 3,10,3)/
     x 5.9681802D-02, 3.0184130D-05, 8.4228562D-06 /
      data fpp( 1, 3,11,1),fpp( 1, 3,11,2),fpp( 1, 3,11,3)/
     x 8.6507885D-02, 2.2579043D-05,-7.3859968D-06 /
      data fpp( 1, 3,12,1),fpp( 1, 3,12,2),fpp( 1, 3,12,3)/
     x 1.0899854D-01,-7.6965812D-05,-2.1119536D-05 /
      data fpp( 1, 3,13,1),fpp( 1, 3,13,2),fpp( 1, 3,13,3)/
     x 6.0217245D-02,-2.1520040D-05,-9.0485274D-06 /
      data fpp( 1, 3,14,1),fpp( 1, 3,14,2),fpp( 1, 3,14,3)/
     x 2.2478709D-02, 6.0420529D-05, 1.6945645D-05 /
      data fpp( 1, 3,15,1),fpp( 1, 3,15,2),fpp( 1, 3,15,3)/
     x 3.8138529D-02, 1.7083015D-04, 1.6046613D-05 /
      data fpp( 1, 3,16,1),fpp( 1, 3,16,2),fpp( 1, 3,16,3)/
     x 2.2478709D-02, 6.0420529D-05, 1.2329238D-05 /
      data fpp( 1, 3,17,1),fpp( 1, 3,17,2),fpp( 1, 3,17,3)/
     x 6.0217245D-02,-2.1520040D-05, 9.4171034D-06 /
      data fpp( 1, 4, 1,1),fpp( 1, 4, 1,2),fpp( 1, 4, 1,3)/
     x 6.5562087D-02,-5.4215137D-05, 6.8599790D-05 /
      data fpp( 1, 4, 2,1),fpp( 1, 4, 2,2),fpp( 1, 4, 2,3)/
     x 6.0732151D-02, 6.1052036D-05, 4.0120531D-05 /
      data fpp( 1, 4, 3,1),fpp( 1, 4, 3,2),fpp( 1, 4, 3,3)/
     x 2.7164082D-01, 5.6835546D-04,-4.3395913D-05 /
      data fpp( 1, 4, 4,1),fpp( 1, 4, 4,2),fpp( 1, 4, 4,3)/
     x 6.0732151D-02, 6.1052036D-05, 6.5717787D-05 /
      data fpp( 1, 4, 5,1),fpp( 1, 4, 5,2),fpp( 1, 4, 5,3)/
     x 6.5562087D-02,-5.4215137D-05,-3.3789234D-05 /
      data fpp( 1, 4, 6,1),fpp( 1, 4, 6,2),fpp( 1, 4, 6,3)/
     x 1.1013901D-01,-8.7690698D-05, 1.8130482D-05 /
      data fpp( 1, 4, 7,1),fpp( 1, 4, 7,2),fpp( 1, 4, 7,3)/
     x 2.6146379D-01, 4.8466555D-04,-7.3569361D-05 /
      data fpp( 1, 4, 8,1),fpp( 1, 4, 8,2),fpp( 1, 4, 8,3)/
     x 8.2234562D-02, 7.1433734D-06, 4.7241627D-05 /
      data fpp( 1, 4, 9,1),fpp( 1, 4, 9,2),fpp( 1, 4, 9,3)/
     x 5.8704704D-02,-6.2671953D-07, 1.9951993D-07 /
      data fpp( 1, 4,10,1),fpp( 1, 4,10,2),fpp( 1, 4,10,3)/
     x 8.2234562D-02, 7.1433734D-06, 4.7241627D-05 /
      data fpp( 1, 4,11,1),fpp( 1, 4,11,2),fpp( 1, 4,11,3)/
     x 2.6146379D-01, 4.8466555D-04,-7.3569361D-05 /
      data fpp( 1, 4,12,1),fpp( 1, 4,12,2),fpp( 1, 4,12,3)/
     x 1.1013901D-01,-8.7690698D-05, 1.8130482D-05 /
      data fpp( 1, 4,13,1),fpp( 1, 4,13,2),fpp( 1, 4,13,3)/
     x 6.5562087D-02,-5.4215137D-05,-3.3789234D-05 /
      data fpp( 1, 4,14,1),fpp( 1, 4,14,2),fpp( 1, 4,14,3)/
     x 6.0732151D-02, 6.1052036D-05, 6.5717787D-05 /
      data fpp( 1, 4,15,1),fpp( 1, 4,15,2),fpp( 1, 4,15,3)/
     x 2.7164082D-01, 5.6835546D-04,-4.3395913D-05 /
      data fpp( 1, 4,16,1),fpp( 1, 4,16,2),fpp( 1, 4,16,3)/
     x 6.0732151D-02, 6.1052036D-05, 4.0120531D-05 /
      data fpp( 1, 4,17,1),fpp( 1, 4,17,2),fpp( 1, 4,17,3)/
     x 6.5562087D-02,-5.4215137D-05, 6.8599790D-05 /
      data fpp( 1, 5, 1,1),fpp( 1, 5, 1,2),fpp( 1, 5, 1,3)/
     x 6.4434184D-02,-2.0513411D-05, 2.0080574D-04 /
      data fpp( 1, 5, 2,1),fpp( 1, 5, 2,2),fpp( 1, 5, 2,3)/
     x 1.0210560D-01,-1.5362674D-05, 9.5542739D-05 /
      data fpp( 1, 5, 3,1),fpp( 1, 5, 3,2),fpp( 1, 5, 3,3)/
     x 7.7243965D-01,-8.0838799D-04,-1.9767003D-04 /
      data fpp( 1, 5, 4,1),fpp( 1, 5, 4,2),fpp( 1, 5, 4,3)/
     x 1.0210560D-01,-1.5362674D-05, 1.6694138D-04 /
      data fpp( 1, 5, 5,1),fpp( 1, 5, 5,2),fpp( 1, 5, 5,3)/
     x 6.4434184D-02,-2.0513411D-05,-8.4788825D-05 /
      data fpp( 1, 5, 6,1),fpp( 1, 5, 6,2),fpp( 1, 5, 6,3)/
     x 1.1713354D-01,-7.9919395D-05, 1.4323192D-04 /
      data fpp( 1, 5, 7,1),fpp( 1, 5, 7,2),fpp( 1, 5, 7,3)/
     x 7.6626352D-01,-8.8170326D-04,-2.5290618D-04 /
      data fpp( 1, 5, 8,1),fpp( 1, 5, 8,2),fpp( 1, 5, 8,3)/
     x 1.1814648D-01,-7.3985624D-05, 1.5482815D-04 /
      data fpp( 1, 5, 9,1),fpp( 1, 5, 9,2),fpp( 1, 5, 9,3)/
     x 6.4404179D-02,-3.8986618D-06,-4.5043074D-05 /
      data fpp( 1, 5,10,1),fpp( 1, 5,10,2),fpp( 1, 5,10,3)/
     x 1.1814648D-01,-7.3985624D-05, 1.5482815D-04 /
      data fpp( 1, 5,11,1),fpp( 1, 5,11,2),fpp( 1, 5,11,3)/
     x 7.6626352D-01,-8.8170326D-04,-2.5290618D-04 /
      data fpp( 1, 5,12,1),fpp( 1, 5,12,2),fpp( 1, 5,12,3)/
     x 1.1713354D-01,-7.9919395D-05, 1.4323192D-04 /
      data fpp( 1, 5,13,1),fpp( 1, 5,13,2),fpp( 1, 5,13,3)/
     x 6.4434184D-02,-2.0513411D-05,-8.4788825D-05 /
      data fpp( 1, 5,14,1),fpp( 1, 5,14,2),fpp( 1, 5,14,3)/
     x 1.0210560D-01,-1.5362674D-05, 1.6694138D-04 /
      data fpp( 1, 5,15,1),fpp( 1, 5,15,2),fpp( 1, 5,15,3)/
     x 7.7243965D-01,-8.0838799D-04,-1.9767003D-04 /
      data fpp( 1, 5,16,1),fpp( 1, 5,16,2),fpp( 1, 5,16,3)/
     x 1.0210560D-01,-1.5362674D-05, 9.5542739D-05 /
      data fpp( 1, 5,17,1),fpp( 1, 5,17,2),fpp( 1, 5,17,3)/
     x 6.4434184D-02,-2.0513411D-05, 2.0080574D-04 /
      data fpp( 1, 6, 1,1),fpp( 1, 6, 1,2),fpp( 1, 6, 1,3)/
     x 4.8868914D-02, 2.3366780D-05, 1.3555770D-04 /
      data fpp( 1, 6, 2,1),fpp( 1, 6, 2,2),fpp( 1, 6, 2,3)/
     x 8.5029575D-02, 5.8706659D-05, 6.3938157D-05 /
      data fpp( 1, 6, 3,1),fpp( 1, 6, 3,2),fpp( 1, 6, 3,3)/
     x 5.6390921D-01,-7.2987501D-05,-1.3612766D-04 /
      data fpp( 1, 6, 4,1),fpp( 1, 6, 4,2),fpp( 1, 6, 4,3)/
     x 8.5029575D-02, 5.8706659D-05, 1.1336849D-04 /
      data fpp( 1, 6, 5,1),fpp( 1, 6, 5,2),fpp( 1, 6, 5,3)/
     x 4.8868914D-02, 2.3366780D-05,-6.2163636D-05 /
      data fpp( 1, 6, 6,1),fpp( 1, 6, 6,2),fpp( 1, 6, 6,3)/
     x 8.1519575D-02, 4.6666278D-05, 1.2012072D-04 /
      data fpp( 1, 6, 7,1),fpp( 1, 6, 7,2),fpp( 1, 6, 7,3)/
     x 5.6579382D-01,-1.4044453D-04,-1.9902725D-04 /
      data fpp( 1, 6, 8,1),fpp( 1, 6, 8,2),fpp( 1, 6, 8,3)/
     x 9.1759669D-02, 2.2885122D-05, 1.1538293D-04 /
      data fpp( 1, 6, 9,1),fpp( 1, 6, 9,2),fpp( 1, 6, 9,3)/
     x 5.3039456D-02, 6.3873665D-06,-3.0996464D-05 /
      data fpp( 1, 6,10,1),fpp( 1, 6,10,2),fpp( 1, 6,10,3)/
     x 9.1759669D-02, 2.2885122D-05, 1.1538293D-04 /
      data fpp( 1, 6,11,1),fpp( 1, 6,11,2),fpp( 1, 6,11,3)/
     x 5.6579382D-01,-1.4044453D-04,-1.9902725D-04 /
      data fpp( 1, 6,12,1),fpp( 1, 6,12,2),fpp( 1, 6,12,3)/
     x 8.1519575D-02, 4.6666278D-05, 1.2012072D-04 /
      data fpp( 1, 6,13,1),fpp( 1, 6,13,2),fpp( 1, 6,13,3)/
     x 4.8868914D-02, 2.3366780D-05,-6.2163636D-05 /
      data fpp( 1, 6,14,1),fpp( 1, 6,14,2),fpp( 1, 6,14,3)/
     x 8.5029575D-02, 5.8706659D-05, 1.1336849D-04 /
      data fpp( 1, 6,15,1),fpp( 1, 6,15,2),fpp( 1, 6,15,3)/
     x 5.6390921D-01,-7.2987501D-05,-1.3612766D-04 /
      data fpp( 1, 6,16,1),fpp( 1, 6,16,2),fpp( 1, 6,16,3)/
     x 8.5029575D-02, 5.8706659D-05, 6.3938157D-05 /
      data fpp( 1, 6,17,1),fpp( 1, 6,17,2),fpp( 1, 6,17,3)/
     x 4.8868914D-02, 2.3366780D-05, 1.3555770D-04 /
      data fpp( 1, 7, 1,1),fpp( 1, 7, 1,2),fpp( 1, 7, 1,3)/
     x 3.3997549D-02, 2.9940292D-05, 6.2071338D-06 /
      data fpp( 1, 7, 2,1),fpp( 1, 7, 2,2),fpp( 1, 7, 2,3)/
     x 5.3935458D-02, 1.0324039D-05, 3.2541769D-06 /
      data fpp( 1, 7, 3,1),fpp( 1, 7, 3,2),fpp( 1, 7, 3,3)/
     x 1.6401728D-01, 4.5691599D-04,-5.2878413D-06 /
      data fpp( 1, 7, 4,1),fpp( 1, 7, 4,2),fpp( 1, 7, 4,3)/
     x 5.3935458D-02, 1.0324039D-05, 5.7318548D-06 /
      data fpp( 1, 7, 5,1),fpp( 1, 7, 5,2),fpp( 1, 7, 5,3)/
     x 3.3997549D-02, 2.9940292D-05,-3.7035780D-06 /
      data fpp( 1, 7, 6,1),fpp( 1, 7, 6,2),fpp( 1, 7, 6,3)/
     x 4.3503541D-02, 6.7884283D-05, 2.9803791D-05 /
      data fpp( 1, 7, 7,1),fpp( 1, 7, 7,2),fpp( 1, 7, 7,3)/
     x 1.6007396D-01, 4.3539738D-04,-5.1543585D-05 /
      data fpp( 1, 7, 8,1),fpp( 1, 7, 8,2),fpp( 1, 7, 8,3)/
     x 5.0583900D-02, 1.1941135D-05, 1.5423881D-05 /
      data fpp( 1, 7, 9,1),fpp( 1, 7, 9,2),fpp( 1, 7, 9,3)/
     x 3.5688771D-02,-9.5968044D-06, 1.4276059D-05 /
      data fpp( 1, 7,10,1),fpp( 1, 7,10,2),fpp( 1, 7,10,3)/
     x 5.0583900D-02, 1.1941135D-05, 1.5423881D-05 /
      data fpp( 1, 7,11,1),fpp( 1, 7,11,2),fpp( 1, 7,11,3)/
     x 1.6007396D-01, 4.3539738D-04,-5.1543585D-05 /
      data fpp( 1, 7,12,1),fpp( 1, 7,12,2),fpp( 1, 7,12,3)/
     x 4.3503541D-02, 6.7884283D-05, 2.9803791D-05 /
      data fpp( 1, 7,13,1),fpp( 1, 7,13,2),fpp( 1, 7,13,3)/
     x 3.3997549D-02, 2.9940292D-05,-3.7035780D-06 /
      data fpp( 1, 7,14,1),fpp( 1, 7,14,2),fpp( 1, 7,14,3)/
     x 5.3935458D-02, 1.0324039D-05, 5.7318548D-06 /
      data fpp( 1, 7,15,1),fpp( 1, 7,15,2),fpp( 1, 7,15,3)/
     x 1.6401728D-01, 4.5691599D-04,-5.2878413D-06 /
      data fpp( 1, 7,16,1),fpp( 1, 7,16,2),fpp( 1, 7,16,3)/
     x 5.3935458D-02, 1.0324039D-05, 3.2541769D-06 /
      data fpp( 1, 7,17,1),fpp( 1, 7,17,2),fpp( 1, 7,17,3)/
     x 3.3997549D-02, 2.9940292D-05, 6.2071338D-06 /
      data fpp( 1, 8, 1,1),fpp( 1, 8, 1,2),fpp( 1, 8, 1,3)/
     x 2.3907245D-02, 2.4320053D-05,-7.4799175D-06 /
      data fpp( 1, 8, 2,1),fpp( 1, 8, 2,2),fpp( 1, 8, 2,3)/
     x 3.2601524D-02,-7.1448814D-05,-6.2992761D-06 /
      data fpp( 1, 8, 3,1),fpp( 1, 8, 3,2),fpp( 1, 8, 3,3)/
     x 5.3568405D-02,-1.0854048D-04, 5.3035529D-07 /
      data fpp( 1, 8, 4,1),fpp( 1, 8, 4,2),fpp( 1, 8, 4,3)/
     x 3.2601524D-02,-7.1448814D-05,-1.2411478D-05 /
      data fpp( 1, 8, 5,1),fpp( 1, 8, 5,2),fpp( 1, 8, 5,3)/
     x 2.3907245D-02, 2.4320053D-05, 1.6968892D-05 /
      data fpp( 1, 8, 6,1),fpp( 1, 8, 6,2),fpp( 1, 8, 6,3)/
     x 2.7723035D-02, 4.2282589D-05, 7.1599122D-06 /
      data fpp( 1, 8, 7,1),fpp( 1, 8, 7,2),fpp( 1, 8, 7,3)/
     x 4.5858086D-02, 1.3845006D-05,-1.9023874D-05 /
      data fpp( 1, 8, 8,1),fpp( 1, 8, 8,2),fpp( 1, 8, 8,3)/
     x 2.5616470D-02,-2.9405661D-05,-6.6024170D-06 /
      data fpp( 1, 8, 9,1),fpp( 1, 8, 9,2),fpp( 1, 8, 9,3)/
     x 1.8986588D-02,-2.9116149D-05, 2.6268875D-05 /
      data fpp( 1, 8,10,1),fpp( 1, 8,10,2),fpp( 1, 8,10,3)/
     x 2.5616470D-02,-2.9405661D-05,-6.6024170D-06 /
      data fpp( 1, 8,11,1),fpp( 1, 8,11,2),fpp( 1, 8,11,3)/
     x 4.5858086D-02, 1.3845006D-05,-1.9023874D-05 /
      data fpp( 1, 8,12,1),fpp( 1, 8,12,2),fpp( 1, 8,12,3)/
     x 2.7723035D-02, 4.2282589D-05, 7.1599122D-06 /
      data fpp( 1, 8,13,1),fpp( 1, 8,13,2),fpp( 1, 8,13,3)/
     x 2.3907245D-02, 2.4320053D-05, 1.6968892D-05 /
      data fpp( 1, 8,14,1),fpp( 1, 8,14,2),fpp( 1, 8,14,3)/
     x 3.2601524D-02,-7.1448814D-05,-1.2411478D-05 /
      data fpp( 1, 8,15,1),fpp( 1, 8,15,2),fpp( 1, 8,15,3)/
     x 5.3568405D-02,-1.0854048D-04, 5.3035529D-07 /
      data fpp( 1, 8,16,1),fpp( 1, 8,16,2),fpp( 1, 8,16,3)/
     x 3.2601524D-02,-7.1448814D-05,-6.2992761D-06 /
      data fpp( 1, 8,17,1),fpp( 1, 8,17,2),fpp( 1, 8,17,3)/
     x 2.3907245D-02, 2.4320053D-05,-7.4799175D-06 /
      data fpp( 1, 9, 1,1),fpp( 1, 9, 1,2),fpp( 1, 9, 1,3)/
     x 1.6859492D-02, 2.0085496D-05, 9.8123792D-06 /
      data fpp( 1, 9, 2,1),fpp( 1, 9, 2,2),fpp( 1, 9, 2,3)/
     x 1.6073985D-02,-5.7342782D-05, 1.4001305D-06 /
      data fpp( 1, 9, 3,1),fpp( 1, 9, 3,2),fpp( 1, 9, 3,3)/
     x 2.0321741D-02,-1.4703209D-04,-1.7124901D-05 /
      data fpp( 1, 9, 4,1),fpp( 1, 9, 4,2),fpp( 1, 9, 4,3)/
     x 1.6073985D-02,-5.7342782D-05,-2.5519254D-07 /
      data fpp( 1, 9, 5,1),fpp( 1, 9, 5,2),fpp( 1, 9, 5,3)/
     x 1.6859492D-02, 2.0085496D-05, 1.6433671D-05 /
      data fpp( 1, 9, 6,1),fpp( 1, 9, 6,2),fpp( 1, 9, 6,3)/
     x 2.3572903D-02, 4.4283362D-05, 5.8850735D-07 /
      data fpp( 1, 9, 7,1),fpp( 1, 9, 7,2),fpp( 1, 9, 7,3)/
     x 2.4197954D-02, 2.8305964D-06,-2.0884367D-05 /
      data fpp( 1, 9, 8,1),fpp( 1, 9, 8,2),fpp( 1, 9, 8,3)/
     x 9.7611840D-03,-2.5664490D-05,-2.0970456D-07 /
      data fpp( 1, 9, 9,1),fpp( 1, 9, 9,2),fpp( 1, 9, 9,3)/
     x 3.6976907D-03,-3.1402600D-05, 2.5503186D-05 /
      data fpp( 1, 9,10,1),fpp( 1, 9,10,2),fpp( 1, 9,10,3)/
     x 9.7611840D-03,-2.5664490D-05,-2.0970456D-07 /
      data fpp( 1, 9,11,1),fpp( 1, 9,11,2),fpp( 1, 9,11,3)/
     x 2.4197954D-02, 2.8305964D-06,-2.0884367D-05 /
      data fpp( 1, 9,12,1),fpp( 1, 9,12,2),fpp( 1, 9,12,3)/
     x 2.3572903D-02, 4.4283362D-05, 5.8850735D-07 /
      data fpp( 1, 9,13,1),fpp( 1, 9,13,2),fpp( 1, 9,13,3)/
     x 1.6859492D-02, 2.0085496D-05, 1.6433671D-05 /
      data fpp( 1, 9,14,1),fpp( 1, 9,14,2),fpp( 1, 9,14,3)/
     x 1.6073985D-02,-5.7342782D-05,-2.5519254D-07 /
      data fpp( 1, 9,15,1),fpp( 1, 9,15,2),fpp( 1, 9,15,3)/
     x 2.0321741D-02,-1.4703209D-04,-1.7124901D-05 /
      data fpp( 1, 9,16,1),fpp( 1, 9,16,2),fpp( 1, 9,16,3)/
     x 1.6073985D-02,-5.7342782D-05, 1.4001305D-06 /
      data fpp( 1, 9,17,1),fpp( 1, 9,17,2),fpp( 1, 9,17,3)/
     x 1.6859492D-02, 2.0085496D-05, 9.8123792D-06 /
      data fpp( 1,10, 1,1),fpp( 1,10, 1,2),fpp( 1,10, 1,3)/
     x 1.1659779D-02, 2.2705964D-05, 1.4291227D-05 /
      data fpp( 1,10, 2,1),fpp( 1,10, 2,2),fpp( 1,10, 2,3)/
     x 2.2735598D-03,-1.5236057D-05, 7.0572125D-06 /
      data fpp( 1,10, 3,1),fpp( 1,10, 3,2),fpp( 1,10, 3,3)/
     x-7.7022656D-04,-3.1749157D-05,-1.0346077D-05 /
      data fpp( 1,10, 4,1),fpp( 1,10, 4,2),fpp( 1,10, 4,3)/
     x 2.2735598D-03,-1.5236057D-05, 7.8430954D-06 /
      data fpp( 1,10, 5,1),fpp( 1,10, 5,2),fpp( 1,10, 5,3)/
     x 1.1659779D-02, 2.2705964D-05, 1.1147695D-05 /
      data fpp( 1,10, 6,1),fpp( 1,10, 6,2),fpp( 1,10, 6,3)/
     x 2.3446195D-02, 5.1699962D-05,-1.6219210D-05 /
      data fpp( 1,10, 7,1),fpp( 1,10, 7,2),fpp( 1,10, 7,3)/
     x 1.5866292D-02, 8.3486088D-06,-1.9420854D-05 /
      data fpp( 1,10, 8,1),fpp( 1,10, 8,2),fpp( 1,10, 8,3)/
     x-2.1157230D-03,-1.4528379D-05, 9.5112915D-06 /
      data fpp( 1,10, 9,1),fpp( 1,10, 9,2),fpp( 1,10, 9,3)/
     x-8.0120305D-03,-2.2099451D-05, 2.4753021D-05 /
      data fpp( 1,10,10,1),fpp( 1,10,10,2),fpp( 1,10,10,3)/
     x-2.1157230D-03,-1.4528379D-05, 9.5112915D-06 /
      data fpp( 1,10,11,1),fpp( 1,10,11,2),fpp( 1,10,11,3)/
     x 1.5866292D-02, 8.3486088D-06,-1.9420854D-05 /
      data fpp( 1,10,12,1),fpp( 1,10,12,2),fpp( 1,10,12,3)/
     x 2.3446195D-02, 5.1699962D-05,-1.6219210D-05 /
      data fpp( 1,10,13,1),fpp( 1,10,13,2),fpp( 1,10,13,3)/
     x 1.1659779D-02, 2.2705964D-05, 1.1147695D-05 /
      data fpp( 1,10,14,1),fpp( 1,10,14,2),fpp( 1,10,14,3)/
     x 2.2735598D-03,-1.5236057D-05, 7.8430954D-06 /
      data fpp( 1,10,15,1),fpp( 1,10,15,2),fpp( 1,10,15,3)/
     x-7.7022656D-04,-3.1749157D-05,-1.0346077D-05 /
      data fpp( 1,10,16,1),fpp( 1,10,16,2),fpp( 1,10,16,3)/
     x 2.2735598D-03,-1.5236057D-05, 7.0572125D-06 /
      data fpp( 1,10,17,1),fpp( 1,10,17,2),fpp( 1,10,17,3)/
     x 1.1659779D-02, 2.2705964D-05, 1.4291227D-05 /
      data fpp( 1,11, 1,1),fpp( 1,11, 1,2),fpp( 1,11, 1,3)/
     x 8.0164518D-03, 3.1224649D-05, 1.6969231D-05 /
      data fpp( 1,11, 2,1),fpp( 1,11, 2,2),fpp( 1,11, 2,3)/
     x-6.1114719D-03, 1.4055011D-05, 1.3723649D-05 /
      data fpp( 1,11, 3,1),fpp( 1,11, 3,2),fpp( 1,11, 3,3)/
     x-1.1198163D-02, 1.7372719D-05, 4.6341716D-06 /
      data fpp( 1,11, 4,1),fpp( 1,11, 4,2),fpp( 1,11, 4,3)/
     x-6.1114719D-03, 1.4055011D-05, 1.5998331D-05 /
      data fpp( 1,11, 5,1),fpp( 1,11, 5,2),fpp( 1,11, 5,3)/
     x 8.0164518D-03, 3.1224649D-05, 7.8705043D-06 /
      data fpp( 1,11, 6,1),fpp( 1,11, 6,2),fpp( 1,11, 6,3)/
     x 2.5560777D-02, 7.5016791D-05,-4.8052348D-05 /
      data fpp( 1,11, 7,1),fpp( 1,11, 7,2),fpp( 1,11, 7,3)/
     x 8.4276689D-03, 1.7300969D-05,-1.0591111D-05 /
      data fpp( 1,11, 8,1),fpp( 1,11, 8,2),fpp( 1,11, 8,3)/
     x-1.0311034D-02,-2.6639945D-06, 1.9526794D-05 /
      data fpp( 1,11, 9,1),fpp( 1,11, 9,2),fpp( 1,11, 9,3)/
     x-1.5528260D-02,-9.5715963D-06, 2.6240603D-05 /
      data fpp( 1,11,10,1),fpp( 1,11,10,2),fpp( 1,11,10,3)/
     x-1.0311034D-02,-2.6639945D-06, 1.9526794D-05 /
      data fpp( 1,11,11,1),fpp( 1,11,11,2),fpp( 1,11,11,3)/
     x 8.4276689D-03, 1.7300969D-05,-1.0591111D-05 /
      data fpp( 1,11,12,1),fpp( 1,11,12,2),fpp( 1,11,12,3)/
     x 2.5560777D-02, 7.5016791D-05,-4.8052348D-05 /
      data fpp( 1,11,13,1),fpp( 1,11,13,2),fpp( 1,11,13,3)/
     x 8.0164518D-03, 3.1224649D-05, 7.8705043D-06 /
      data fpp( 1,11,14,1),fpp( 1,11,14,2),fpp( 1,11,14,3)/
     x-6.1114719D-03, 1.4055011D-05, 1.5998331D-05 /
      data fpp( 1,11,15,1),fpp( 1,11,15,2),fpp( 1,11,15,3)/
     x-1.1198163D-02, 1.7372719D-05, 4.6341716D-06 /
      data fpp( 1,11,16,1),fpp( 1,11,16,2),fpp( 1,11,16,3)/
     x-6.1114719D-03, 1.4055011D-05, 1.3723649D-05 /
      data fpp( 1,11,17,1),fpp( 1,11,17,2),fpp( 1,11,17,3)/
     x 8.0164518D-03, 3.1224649D-05, 1.6969231D-05 /
      data fpp( 1,12, 1,1),fpp( 1,12, 1,2),fpp( 1,12, 1,3)/
     x 5.8887155D-03, 5.3833441D-05, 2.4042423D-05 /
      data fpp( 1,12, 2,1),fpp( 1,12, 2,2),fpp( 1,12, 2,3)/
     x-1.0482270D-02, 3.8882012D-05, 2.2978376D-05 /
      data fpp( 1,12, 3,1),fpp( 1,12, 3,2),fpp( 1,12, 3,3)/
     x-1.5760026D-02, 4.2856280D-05, 1.8455406D-05 /
      data fpp( 1,12, 4,1),fpp( 1,12, 4,2),fpp( 1,12, 4,3)/
     x-1.0482270D-02, 3.8882012D-05, 2.6038665D-05 /
      data fpp( 1,12, 5,1),fpp( 1,12, 5,2),fpp( 1,12, 5,3)/
     x 5.8887155D-03, 5.3833441D-05, 1.1801268D-05 /
      data fpp( 1,12, 6,1),fpp( 1,12, 6,2),fpp( 1,12, 6,3)/
     x 3.1910187D-02, 7.1082875D-05,-9.9509068D-05 /
      data fpp( 1,12, 7,1),fpp( 1,12, 7,2),fpp( 1,12, 7,3)/
     x 8.4460545D-04, 2.4387517D-05, 9.2670056D-06 /
      data fpp( 1,12, 8,1),fpp( 1,12, 8,2),fpp( 1,12, 8,3)/
     x-1.5867738D-02, 1.3754357D-05, 2.8112379D-05 /
      data fpp( 1,12, 9,1),fpp( 1,12, 9,2),fpp( 1,12, 9,3)/
     x-2.0199378D-02, 9.5178360D-06, 3.0634144D-05 /
      data fpp( 1,12,10,1),fpp( 1,12,10,2),fpp( 1,12,10,3)/
     x-1.5867738D-02, 1.3754357D-05, 2.8112379D-05 /
      data fpp( 1,12,11,1),fpp( 1,12,11,2),fpp( 1,12,11,3)/
     x 8.4460545D-04, 2.4387517D-05, 9.2670056D-06 /
      data fpp( 1,12,12,1),fpp( 1,12,12,2),fpp( 1,12,12,3)/
     x 3.1910187D-02, 7.1082875D-05,-9.9509068D-05 /
      data fpp( 1,12,13,1),fpp( 1,12,13,2),fpp( 1,12,13,3)/
     x 5.8887155D-03, 5.3833441D-05, 1.1801268D-05 /
      data fpp( 1,12,14,1),fpp( 1,12,14,2),fpp( 1,12,14,3)/
     x-1.0482270D-02, 3.8882012D-05, 2.6038665D-05 /
      data fpp( 1,12,15,1),fpp( 1,12,15,2),fpp( 1,12,15,3)/
     x-1.5760026D-02, 4.2856280D-05, 1.8455406D-05 /
      data fpp( 1,12,16,1),fpp( 1,12,16,2),fpp( 1,12,16,3)/
     x-1.0482270D-02, 3.8882012D-05, 2.2978376D-05 /
      data fpp( 1,12,17,1),fpp( 1,12,17,2),fpp( 1,12,17,3)/
     x 5.8887155D-03, 5.3833441D-05, 2.4042423D-05 /
      data fpp( 1,13, 1,1),fpp( 1,13, 1,2),fpp( 1,13, 1,3)/
     x 7.0239721D-03, 9.3335586D-05, 3.6407954D-05 /
      data fpp( 1,13, 2,1),fpp( 1,13, 2,2),fpp( 1,13, 2,3)/
     x-1.3722260D-02, 7.0758940D-05, 3.4921204D-05 /
      data fpp( 1,13, 3,1),fpp( 1,13, 3,2),fpp( 1,13, 3,3)/
     x-1.8196555D-02, 7.5874162D-05, 2.9996565D-05 /
      data fpp( 1,13, 4,1),fpp( 1,13, 4,2),fpp( 1,13, 4,3)/
     x-1.3722260D-02, 7.0758940D-05, 3.7104535D-05 /
      data fpp( 1,13, 5,1),fpp( 1,13, 5,2),fpp( 1,13, 5,3)/
     x 7.0239721D-03, 9.3335586D-05, 2.7674626D-05 /
      data fpp( 1,13, 6,1),fpp( 1,13, 6,2),fpp( 1,13, 6,3)/
     x 6.0720654D-02, 2.5866371D-04,-1.7992104D-04 /
      data fpp( 1,13, 7,1),fpp( 1,13, 7,2),fpp( 1,13, 7,3)/
     x-9.5142935D-03, 2.9052963D-05, 4.9422870D-05 /
      data fpp( 1,13, 8,1),fpp( 1,13, 8,2),fpp( 1,13, 8,3)/
     x-2.0091945D-02, 4.0196567D-05, 3.1434894D-05 /
      data fpp( 1,13, 9,1),fpp( 1,13, 9,2),fpp( 1,13, 9,3)/
     x-2.3038456D-02, 4.1076252D-05, 3.8935553D-05 /
      data fpp( 1,13,10,1),fpp( 1,13,10,2),fpp( 1,13,10,3)/
     x-2.0091945D-02, 4.0196567D-05, 3.1434894D-05 /
      data fpp( 1,13,11,1),fpp( 1,13,11,2),fpp( 1,13,11,3)/
     x-9.5142935D-03, 2.9052963D-05, 4.9422870D-05 /
      data fpp( 1,13,12,1),fpp( 1,13,12,2),fpp( 1,13,12,3)/
     x 6.0720654D-02, 2.5866371D-04,-1.7992104D-04 /
      data fpp( 1,13,13,1),fpp( 1,13,13,2),fpp( 1,13,13,3)/
     x 7.0239721D-03, 9.3335586D-05, 2.7674626D-05 /
      data fpp( 1,13,14,1),fpp( 1,13,14,2),fpp( 1,13,14,3)/
     x-1.3722260D-02, 7.0758940D-05, 3.7104535D-05 /
      data fpp( 1,13,15,1),fpp( 1,13,15,2),fpp( 1,13,15,3)/
     x-1.8196555D-02, 7.5874162D-05, 2.9996565D-05 /
      data fpp( 1,13,16,1),fpp( 1,13,16,2),fpp( 1,13,16,3)/
     x-1.3722260D-02, 7.0758940D-05, 3.4921204D-05 /
      data fpp( 1,13,17,1),fpp( 1,13,17,2),fpp( 1,13,17,3)/
     x 7.0239721D-03, 9.3335586D-05, 3.6407954D-05 /
      data fpp( 1,14, 1,1),fpp( 1,14, 1,2),fpp( 1,14, 1,3)/
     x 4.5135033D-02, 2.9015422D-04, 6.1565574D-05 /
      data fpp( 1,14, 2,1),fpp( 1,14, 2,2),fpp( 1,14, 2,3)/
     x-1.6868266D-02, 1.0584023D-04, 5.3919075D-05 /
      data fpp( 1,14, 3,1),fpp( 1,14, 3,2),fpp( 1,14, 3,3)/
     x-1.9931213D-02, 1.1636707D-04, 3.6584794D-05 /
      data fpp( 1,14, 4,1),fpp( 1,14, 4,2),fpp( 1,14, 4,3)/
     x-1.6868266D-02, 1.0584023D-04, 5.3157750D-05 /
      data fpp( 1,14, 5,1),fpp( 1,14, 5,2),fpp( 1,14, 5,3)/
     x 4.5135033D-02, 2.9015422D-04, 6.4610872D-05 /
      data fpp( 1,14, 6,1),fpp( 1,14, 6,2),fpp( 1,14, 6,3)/
     x 2.0381864D-01, 1.4151229D-04,-3.2286657D-04 /
      data fpp( 1,14, 7,1),fpp( 1,14, 7,2),fpp( 1,14, 7,3)/
     x-2.4163184D-02, 3.8296631D-05, 1.4106408D-04 /
      data fpp( 1,14, 8,1),fpp( 1,14, 8,2),fpp( 1,14, 8,3)/
     x-2.3600399D-02, 7.7357376D-05, 1.8166930D-05 /
      data fpp( 1,14, 9,1),fpp( 1,14, 9,2),fpp( 1,14, 9,3)/
     x-2.4417419D-02, 8.7255155D-05, 5.5022201D-05 /
      data fpp( 1,14,10,1),fpp( 1,14,10,2),fpp( 1,14,10,3)/
     x-2.3600399D-02, 7.7357376D-05, 1.8166930D-05 /
      data fpp( 1,14,11,1),fpp( 1,14,11,2),fpp( 1,14,11,3)/
     x-2.4163184D-02, 3.8296631D-05, 1.4106408D-04 /
      data fpp( 1,14,12,1),fpp( 1,14,12,2),fpp( 1,14,12,3)/
     x 2.0381864D-01, 1.4151229D-04,-3.2286657D-04 /
      data fpp( 1,14,13,1),fpp( 1,14,13,2),fpp( 1,14,13,3)/
     x 4.5135033D-02, 2.9015422D-04, 6.4610872D-05 /
      data fpp( 1,14,14,1),fpp( 1,14,14,2),fpp( 1,14,14,3)/
     x-1.6868266D-02, 1.0584023D-04, 5.3157750D-05 /
      data fpp( 1,14,15,1),fpp( 1,14,15,2),fpp( 1,14,15,3)/
     x-1.9931213D-02, 1.1636707D-04, 3.6584794D-05 /
      data fpp( 1,14,16,1),fpp( 1,14,16,2),fpp( 1,14,16,3)/
     x-1.6868266D-02, 1.0584023D-04, 5.3919075D-05 /
      data fpp( 1,14,17,1),fpp( 1,14,17,2),fpp( 1,14,17,3)/
     x 4.5135033D-02, 2.9015422D-04, 6.1565574D-05 /
      data fpp( 1,15, 1,1),fpp( 1,15, 1,2),fpp( 1,15, 1,3)/
     x 2.1575133D-01,-3.0933045D-04, 1.0259124D-04 /
      data fpp( 1,15, 2,1),fpp( 1,15, 2,2),fpp( 1,15, 2,3)/
     x-2.0893010D-02, 1.4237215D-04, 8.3243407D-05 /
      data fpp( 1,15, 3,1),fpp( 1,15, 3,2),fpp( 1,15, 3,3)/
     x-2.3007809D-02, 1.7634155D-04, 2.9257130D-05 /
      data fpp( 1,15, 4,1),fpp( 1,15, 4,2),fpp( 1,15, 4,3)/
     x-2.0893010D-02, 1.4237215D-04, 9.6505408D-05 /
      data fpp( 1,15, 5,1),fpp( 1,15, 5,2),fpp( 1,15, 5,3)/
     x 2.1575133D-01,-3.0933045D-04, 4.9543240D-05 /
      data fpp( 1,15, 6,1),fpp( 1,15, 6,2),fpp( 1,15, 6,3)/
     x-7.4867227D-02,-7.9194086D-04,-4.2064437D-04 /
      data fpp( 1,15, 7,1),fpp( 1,15, 7,2),fpp( 1,15, 7,3)/
     x-2.9391129D-02, 2.4472513D-05, 2.2468156D-04 /
      data fpp( 1,15, 8,1),fpp( 1,15, 8,2),fpp( 1,15, 8,3)/
     x-2.6069634D-02, 1.2115793D-04, 1.8407923D-06 /
      data fpp( 1,15, 9,1),fpp( 1,15, 9,2),fpp( 1,15, 9,3)/
     x-2.4180571D-02, 1.4437113D-04, 6.9099937D-05 /
      data fpp( 1,15,10,1),fpp( 1,15,10,2),fpp( 1,15,10,3)/
     x-2.6069634D-02, 1.2115793D-04, 1.8407923D-06 /
      data fpp( 1,15,11,1),fpp( 1,15,11,2),fpp( 1,15,11,3)/
     x-2.9391129D-02, 2.4472513D-05, 2.2468156D-04 /
      data fpp( 1,15,12,1),fpp( 1,15,12,2),fpp( 1,15,12,3)/
     x-7.4867227D-02,-7.9194086D-04,-4.2064437D-04 /
      data fpp( 1,15,13,1),fpp( 1,15,13,2),fpp( 1,15,13,3)/
     x 2.1575133D-01,-3.0933045D-04, 4.9543240D-05 /
      data fpp( 1,15,14,1),fpp( 1,15,14,2),fpp( 1,15,14,3)/
     x-2.0893010D-02, 1.4237215D-04, 9.6505408D-05 /
      data fpp( 1,15,15,1),fpp( 1,15,15,2),fpp( 1,15,15,3)/
     x-2.3007809D-02, 1.7634155D-04, 2.9257130D-05 /
      data fpp( 1,15,16,1),fpp( 1,15,16,2),fpp( 1,15,16,3)/
     x-2.0893010D-02, 1.4237215D-04, 8.3243407D-05 /
      data fpp( 1,15,17,1),fpp( 1,15,17,2),fpp( 1,15,17,3)/
     x 2.1575133D-01,-3.0933045D-04, 1.0259124D-04 /
      data fpp( 1,16, 1,1),fpp( 1,16, 1,2),fpp( 1,16, 1,3)/
     x 2.0588752D-01,-3.9842843D-04, 8.4733705D-05 /
      data fpp( 1,16, 2,1),fpp( 1,16, 2,2),fpp( 1,16, 2,3)/
     x-3.7131341D-02, 6.6877154D-05, 7.3235145D-05 /
      data fpp( 1,16, 3,1),fpp( 1,16, 3,2),fpp( 1,16, 3,3)/
     x-3.3793911D-02, 1.3776874D-04, 3.0309047D-05 /
      data fpp( 1,16, 4,1),fpp( 1,16, 4,2),fpp( 1,16, 4,3)/
     x-3.7131341D-02, 6.6877154D-05, 9.7379333D-05 /
      data fpp( 1,16, 5,1),fpp( 1,16, 5,2),fpp( 1,16, 5,3)/
     x 2.0588752D-01,-3.9842843D-04,-1.1843044D-05 /
      data fpp( 1,16, 6,1),fpp( 1,16, 6,2),fpp( 1,16, 6,3)/
     x 3.9319902D-01,-5.4566283D-04,-3.0606449D-04 /
      data fpp( 1,16, 7,1),fpp( 1,16, 7,2),fpp( 1,16, 7,3)/
     x-2.4325537D-02,-2.1994684D-05, 1.6212300D-04 /
      data fpp( 1,16, 8,1),fpp( 1,16, 8,2),fpp( 1,16, 8,3)/
     x-2.7261647D-02, 1.5220891D-04, 1.4961142D-05 /
      data fpp( 1,16, 9,1),fpp( 1,16, 9,2),fpp( 1,16, 9,3)/
     x-2.2992775D-02, 1.9078234D-04, 6.0603096D-05 /
      data fpp( 1,16,10,1),fpp( 1,16,10,2),fpp( 1,16,10,3)/
     x-2.7261647D-02, 1.5220891D-04, 1.4961142D-05 /
      data fpp( 1,16,11,1),fpp( 1,16,11,2),fpp( 1,16,11,3)/
     x-2.4325537D-02,-2.1994684D-05, 1.6212300D-04 /
      data fpp( 1,16,12,1),fpp( 1,16,12,2),fpp( 1,16,12,3)/
     x 3.9319902D-01,-5.4566283D-04,-3.0606449D-04 /
      data fpp( 1,16,13,1),fpp( 1,16,13,2),fpp( 1,16,13,3)/
     x 2.0588752D-01,-3.9842843D-04,-1.1843044D-05 /
      data fpp( 1,16,14,1),fpp( 1,16,14,2),fpp( 1,16,14,3)/
     x-3.7131341D-02, 6.6877154D-05, 9.7379333D-05 /
      data fpp( 1,16,15,1),fpp( 1,16,15,2),fpp( 1,16,15,3)/
     x-3.3793911D-02, 1.3776874D-04, 3.0309047D-05 /
      data fpp( 1,16,16,1),fpp( 1,16,16,2),fpp( 1,16,16,3)/
     x-3.7131341D-02, 6.6877154D-05, 7.3235145D-05 /
      data fpp( 1,16,17,1),fpp( 1,16,17,2),fpp( 1,16,17,3)/
     x 2.0588752D-01,-3.9842843D-04, 8.4733705D-05 /
      data fpp( 1,17, 1,1),fpp( 1,17, 1,2),fpp( 1,17, 1,3)/
     x-3.3651119D-01, 4.1979615D-04, 1.7335508D-05 /
      data fpp( 1,17, 2,1),fpp( 1,17, 2,2),fpp( 1,17, 2,3)/
     x-1.2027709D-01, 2.3843723D-04, 2.5693983D-05 /
      data fpp( 1,17, 3,1),fpp( 1,17, 3,2),fpp( 1,17, 3,3)/
     x-8.2782512D-02, 2.8541949D-04, 3.4694559D-05 /
      data fpp( 1,17, 4,1),fpp( 1,17, 4,2),fpp( 1,17, 4,3)/
     x-1.2027709D-01, 2.3843723D-04, 4.1447782D-05 /
      data fpp( 1,17, 5,1),fpp( 1,17, 5,2),fpp( 1,17, 5,3)/
     x-3.3651119D-01, 4.1979615D-04,-4.5679687D-05 /
      data fpp( 1,17, 6,1),fpp( 1,17, 6,2),fpp( 1,17, 6,3)/
     x-1.5656198D-01, 7.0129419D-04,-9.5820366D-05 /
      data fpp( 1,17, 7,1),fpp( 1,17, 7,2),fpp( 1,17, 7,3)/
     x-5.8426827D-02, 1.0422822D-04, 3.4254483D-05 /
      data fpp( 1,17, 8,1),fpp( 1,17, 8,2),fpp( 1,17, 8,3)/
     x-3.3953857D-02, 1.5582245D-04, 3.0443100D-05 /
      data fpp( 1,17, 9,1),fpp( 1,17, 9,2),fpp( 1,17, 9,3)/
     x-2.6523468D-02, 1.9944552D-04, 3.8640450D-05 /
      data fpp( 1,17,10,1),fpp( 1,17,10,2),fpp( 1,17,10,3)/
     x-3.3953857D-02, 1.5582245D-04, 3.0443100D-05 /
      data fpp( 1,17,11,1),fpp( 1,17,11,2),fpp( 1,17,11,3)/
     x-5.8426827D-02, 1.0422822D-04, 3.4254483D-05 /
      data fpp( 1,17,12,1),fpp( 1,17,12,2),fpp( 1,17,12,3)/
     x-1.5656198D-01, 7.0129419D-04,-9.5820366D-05 /
      data fpp( 1,17,13,1),fpp( 1,17,13,2),fpp( 1,17,13,3)/
     x-3.3651119D-01, 4.1979615D-04,-4.5679687D-05 /
      data fpp( 1,17,14,1),fpp( 1,17,14,2),fpp( 1,17,14,3)/
     x-1.2027709D-01, 2.3843723D-04, 4.1447782D-05 /
      data fpp( 1,17,15,1),fpp( 1,17,15,2),fpp( 1,17,15,3)/
     x-8.2782512D-02, 2.8541949D-04, 3.4694559D-05 /
      data fpp( 1,17,16,1),fpp( 1,17,16,2),fpp( 1,17,16,3)/
     x-1.2027709D-01, 2.3843723D-04, 2.5693983D-05 /
      data fpp( 1,17,17,1),fpp( 1,17,17,2),fpp( 1,17,17,3)/
     x-3.3651119D-01, 4.1979615D-04, 1.7335508D-05 /
      data fpp( 1,18, 1,1),fpp( 1,18, 1,2),fpp( 1,18, 1,3)/
     x-1.2555382D+00,-2.9172819D-04,-1.5673562D-05 /
      data fpp( 1,18, 2,1),fpp( 1,18, 2,2),fpp( 1,18, 2,3)/
     x-6.0169968D-01,-5.8389207D-04,-4.3650983D-06 /
      data fpp( 1,18, 3,1),fpp( 1,18, 3,2),fpp( 1,18, 3,3)/
     x-4.1207424D-01,-6.3198071D-04, 1.9543288D-05 /
      data fpp( 1,18, 4,1),fpp( 1,18, 4,2),fpp( 1,18, 4,3)/
     x-6.0169968D-01,-5.8389207D-04,-6.4805505D-07 /
      data fpp( 1,18, 5,1),fpp( 1,18, 5,2),fpp( 1,18, 5,3)/
     x-1.2555382D+00,-2.9172819D-04,-3.0541735D-05 /
      data fpp( 1,18, 6,1),fpp( 1,18, 6,2),fpp( 1,18, 6,3)/
     x-4.1311184D-01, 5.0840090D-05,-9.8623391D-06 /
      data fpp( 1,18, 7,1),fpp( 1,18, 7,2),fpp( 1,18, 7,3)/
     x-1.4183321D-01, 9.6025794D-05, 5.5850913D-06 /
      data fpp( 1,18, 8,1),fpp( 1,18, 8,2),fpp( 1,18, 8,3)/
     x-7.7280828D-02, 8.1301300D-05, 1.6221974D-05 /
      data fpp( 1,18, 9,1),fpp( 1,18, 9,2),fpp( 1,18, 9,3)/
     x-6.2835057D-02, 8.3569564D-05, 1.9566346D-05 /
      data fpp( 1,18,10,1),fpp( 1,18,10,2),fpp( 1,18,10,3)/
     x-7.7280828D-02, 8.1301300D-05, 1.6221974D-05 /
      data fpp( 1,18,11,1),fpp( 1,18,11,2),fpp( 1,18,11,3)/
     x-1.4183321D-01, 9.6025794D-05, 5.5850913D-06 /
      data fpp( 1,18,12,1),fpp( 1,18,12,2),fpp( 1,18,12,3)/
     x-4.1311184D-01, 5.0840090D-05,-9.8623391D-06 /
      data fpp( 1,18,13,1),fpp( 1,18,13,2),fpp( 1,18,13,3)/
     x-1.2555382D+00,-2.9172819D-04,-3.0541735D-05 /
      data fpp( 1,18,14,1),fpp( 1,18,14,2),fpp( 1,18,14,3)/
     x-6.0169968D-01,-5.8389207D-04,-6.4805505D-07 /
      data fpp( 1,18,15,1),fpp( 1,18,15,2),fpp( 1,18,15,3)/
     x-4.1207424D-01,-6.3198071D-04, 1.9543288D-05 /
      data fpp( 1,18,16,1),fpp( 1,18,16,2),fpp( 1,18,16,3)/
     x-6.0169968D-01,-5.8389207D-04,-4.3650983D-06 /
      data fpp( 1,18,17,1),fpp( 1,18,17,2),fpp( 1,18,17,3)/
     x-1.2555382D+00,-2.9172819D-04,-1.5673562D-05 /
      data fpp( 1,19, 1,1),fpp( 1,19, 1,2),fpp( 1,19, 1,3)/
     x-3.3914605D-01,-5.6618141D-04,-1.9610090D-20 /
      data fpp( 1,19, 2,1),fpp( 1,19, 2,2),fpp( 1,19, 2,3)/
     x-3.3914605D-01,-1.1222530D-03, 3.5061838D-20 /
      data fpp( 1,19, 3,1),fpp( 1,19, 3,2),fpp( 1,19, 3,3)/
     x-3.3914605D-01,-1.2450806D-03, 1.4466827D-20 /
      data fpp( 1,19, 4,1),fpp( 1,19, 4,2),fpp( 1,19, 4,3)/
     x-3.3914605D-01,-1.1222530D-03, 2.3111372D-21 /
      data fpp( 1,19, 5,1),fpp( 1,19, 5,2),fpp( 1,19, 5,3)/
     x-3.3914605D-01,-5.6618141D-04, 4.7456337D-21 /
      data fpp( 1,19, 6,1),fpp( 1,19, 6,2),fpp( 1,19, 6,3)/
     x-3.3914605D-01,-5.7496545D-05, 1.4854718D-20 /
      data fpp( 1,19, 7,1),fpp( 1,19, 7,2),fpp( 1,19, 7,3)/
     x-3.3914605D-01, 1.2623060D-04, 1.3621431D-20 /
      data fpp( 1,19, 8,1),fpp( 1,19, 8,2),fpp( 1,19, 8,3)/
     x-3.3914605D-01, 2.9104350D-05,-3.2472941D-20 /
      data fpp( 1,19, 9,1),fpp( 1,19, 9,2),fpp( 1,19, 9,3)/
     x-3.3914605D-01, 3.2762178D-06,-1.9785504D-20 /
      data fpp( 1,19,10,1),fpp( 1,19,10,2),fpp( 1,19,10,3)/
     x-3.3914605D-01, 2.9104350D-05, 3.8865866D-20 /
      data fpp( 1,19,11,1),fpp( 1,19,11,2),fpp( 1,19,11,3)/
     x-3.3914605D-01, 1.2623060D-04,-3.1612536D-20 /
      data fpp( 1,19,12,1),fpp( 1,19,12,2),fpp( 1,19,12,3)/
     x-3.3914605D-01,-5.7496545D-05, 3.3852494D-20 /
      data fpp( 1,19,13,1),fpp( 1,19,13,2),fpp( 1,19,13,3)/
     x-3.3914605D-01,-5.6618141D-04,-1.5191771D-22 /
      data fpp( 1,19,14,1),fpp( 1,19,14,2),fpp( 1,19,14,3)/
     x-3.3914605D-01,-1.1222530D-03,-1.3681509D-20 /
      data fpp( 1,19,15,1),fpp( 1,19,15,2),fpp( 1,19,15,3)/
     x-3.3914605D-01,-1.2450806D-03, 4.7230079D-22 /
      data fpp( 1,19,16,1),fpp( 1,19,16,2),fpp( 1,19,16,3)/
     x-3.3914605D-01,-1.1222530D-03,-6.9276131D-21 /
      data fpp( 1,19,17,1),fpp( 1,19,17,2),fpp( 1,19,17,3)/
     x-3.3914605D-01,-5.6618141D-04, 5.9960717D-20 /
      data fpp( 2, 1, 1,1),fpp( 2, 1, 1,2),fpp( 2, 1, 1,3)/
     x 8.4547675D-02, 4.6418229D-06,-7.3460918D-20 /
      data fpp( 2, 1, 2,1),fpp( 2, 1, 2,2),fpp( 2, 1, 2,3)/
     x 8.4547675D-02,-1.0954015D-04, 9.5609479D-20 /
      data fpp( 2, 1, 3,1),fpp( 2, 1, 3,2),fpp( 2, 1, 3,3)/
     x 8.4547675D-02,-2.1438716D-04, 4.6116528D-20 /
      data fpp( 2, 1, 4,1),fpp( 2, 1, 4,2),fpp( 2, 1, 4,3)/
     x 8.4547675D-02,-1.0954015D-04, 2.0772310D-20 /
      data fpp( 2, 1, 5,1),fpp( 2, 1, 5,2),fpp( 2, 1, 5,3)/
     x 8.4547675D-02, 4.6418229D-06, 1.2641200D-20 /
      data fpp( 2, 1, 6,1),fpp( 2, 1, 6,2),fpp( 2, 1, 6,3)/
     x 8.4547675D-02, 5.5751903D-05, 2.0919454D-20 /
      data fpp( 2, 1, 7,1),fpp( 2, 1, 7,2),fpp( 2, 1, 7,3)/
     x 8.4547675D-02,-5.7766503D-05, 2.3758957D-20 /
      data fpp( 2, 1, 8,1),fpp( 2, 1, 8,2),fpp( 2, 1, 8,3)/
     x 8.4547675D-02,-8.8615082D-05,-3.7467450D-20 /
      data fpp( 2, 1, 9,1),fpp( 2, 1, 9,2),fpp( 2, 1, 9,3)/
     x 8.4547675D-02,-1.1197812D-04,-5.8454266D-21 /
      data fpp( 2, 1,10,1),fpp( 2, 1,10,2),fpp( 2, 1,10,3)/
     x 8.4547675D-02,-8.8615082D-05, 4.7496504D-20 /
      data fpp( 2, 1,11,1),fpp( 2, 1,11,2),fpp( 2, 1,11,3)/
     x 8.4547675D-02,-5.7766503D-05,-4.1794675D-20 /
      data fpp( 2, 1,12,1),fpp( 2, 1,12,2),fpp( 2, 1,12,3)/
     x 8.4547675D-02, 5.5751903D-05, 4.3122779D-21 /
      data fpp( 2, 1,13,1),fpp( 2, 1,13,2),fpp( 2, 1,13,3)/
     x 8.4547675D-02, 4.6418229D-06,-1.3559524D-20 /
      data fpp( 2, 1,14,1),fpp( 2, 1,14,2),fpp( 2, 1,14,3)/
     x 8.4547675D-02,-1.0954015D-04, 7.2627051D-21 /
      data fpp( 2, 1,15,1),fpp( 2, 1,15,2),fpp( 2, 1,15,3)/
     x 8.4547675D-02,-2.1438716D-04,-1.5001309D-20 /
      data fpp( 2, 1,16,1),fpp( 2, 1,16,2),fpp( 2, 1,16,3)/
     x 8.4547675D-02,-1.0954015D-04, 1.7354535D-20 /
      data fpp( 2, 1,17,1),fpp( 2, 1,17,2),fpp( 2, 1,17,3)/
     x 8.4547675D-02, 4.6418229D-06, 1.7513933D-20 /
      data fpp( 2, 2, 1,1),fpp( 2, 2, 1,2),fpp( 2, 2, 1,3)/
     x 7.0339218D-02,-1.0545646D-05, 9.2918489D-07 /
      data fpp( 2, 2, 2,1),fpp( 2, 2, 2,2),fpp( 2, 2, 2,3)/
     x 5.2329256D-02,-5.1360696D-05, 2.7074080D-06 /
      data fpp( 2, 2, 3,1),fpp( 2, 2, 3,2),fpp( 2, 2, 3,3)/
     x 4.6246492D-02,-6.3315686D-05, 6.3691831D-06 /
      data fpp( 2, 2, 4,1),fpp( 2, 2, 4,2),fpp( 2, 2, 4,3)/
     x 5.2329256D-02,-5.1360696D-05, 3.4385263D-06 /
      data fpp( 2, 2, 5,1),fpp( 2, 2, 5,2),fpp( 2, 2, 5,3)/
     x 7.0339218D-02,-1.0545646D-05,-1.9952884D-06 /
      data fpp( 2, 2, 6,1),fpp( 2, 2, 6,2),fpp( 2, 2, 6,3)/
     x 8.8187403D-02, 4.6751941D-06,-4.8720395D-06 /
      data fpp( 2, 2, 7,1),fpp( 2, 2, 7,2),fpp( 2, 2, 7,3)/
     x 8.8678930D-02,-1.0145994D-05,-2.4198868D-06 /
      data fpp( 2, 2, 8,1),fpp( 2, 2, 8,2),fpp( 2, 2, 8,3)/
     x 8.0608469D-02,-5.1818836D-05, 1.3409200D-06 /
      data fpp( 2, 2, 9,1),fpp( 2, 2, 9,2),fpp( 2, 2, 9,3)/
     x 7.7033184D-02,-6.3684769D-05, 2.7682066D-06 /
      data fpp( 2, 2,10,1),fpp( 2, 2,10,2),fpp( 2, 2,10,3)/
     x 8.0608469D-02,-5.1818836D-05, 1.3409200D-06 /
      data fpp( 2, 2,11,1),fpp( 2, 2,11,2),fpp( 2, 2,11,3)/
     x 8.8678930D-02,-1.0145994D-05,-2.4198868D-06 /
      data fpp( 2, 2,12,1),fpp( 2, 2,12,2),fpp( 2, 2,12,3)/
     x 8.8187403D-02, 4.6751941D-06,-4.8720395D-06 /
      data fpp( 2, 2,13,1),fpp( 2, 2,13,2),fpp( 2, 2,13,3)/
     x 7.0339218D-02,-1.0545646D-05,-1.9952884D-06 /
      data fpp( 2, 2,14,1),fpp( 2, 2,14,2),fpp( 2, 2,14,3)/
     x 5.2329256D-02,-5.1360696D-05, 3.4385263D-06 /
      data fpp( 2, 2,15,1),fpp( 2, 2,15,2),fpp( 2, 2,15,3)/
     x 4.6246492D-02,-6.3315686D-05, 6.3691831D-06 /
      data fpp( 2, 2,16,1),fpp( 2, 2,16,2),fpp( 2, 2,16,3)/
     x 5.2329256D-02,-5.1360696D-05, 2.7074080D-06 /
      data fpp( 2, 2,17,1),fpp( 2, 2,17,2),fpp( 2, 2,17,3)/
     x 7.0339218D-02,-1.0545646D-05, 9.2918489D-07 /
      data fpp( 2, 3, 1,1),fpp( 2, 3, 1,2),fpp( 2, 3, 1,3)/
     x 5.9425510D-02,-2.6479240D-05, 2.9764565D-06 /
      data fpp( 2, 3, 2,1),fpp( 2, 3, 2,2),fpp( 2, 3, 2,3)/
     x 3.1505083D-02, 1.7544938D-05, 7.7204204D-06 /
      data fpp( 2, 3, 3,1),fpp( 2, 3, 3,2),fpp( 2, 3, 3,3)/
     x 4.0365442D-02, 6.7785902D-05, 1.6952529D-05 /
      data fpp( 2, 3, 4,1),fpp( 2, 3, 4,2),fpp( 2, 3, 4,3)/
     x 3.1505083D-02, 1.7544938D-05, 1.0476132D-05 /
      data fpp( 2, 3, 5,1),fpp( 2, 3, 5,2),fpp( 2, 3, 5,3)/
     x 5.9425510D-02,-2.6479240D-05,-8.0463889D-06 /
      data fpp( 2, 3, 6,1),fpp( 2, 3, 6,2),fpp( 2, 3, 6,3)/
     x 9.3285415D-02,-5.9230679D-05,-1.4250576D-05 /
      data fpp( 2, 3, 7,1),fpp( 2, 3, 7,2),fpp( 2, 3, 7,3)/
     x 7.9756730D-02,-1.5571521D-05,-5.9119731D-06 /
      data fpp( 2, 3, 8,1),fpp( 2, 3, 8,2),fpp( 2, 3, 8,3)/
     x 5.9563895D-02, 1.6842595D-07, 5.6264685D-06 /
      data fpp( 2, 3, 9,1),fpp( 2, 3, 9,2),fpp( 2, 3, 9,3)/
     x 5.5403356D-02, 5.1991903D-06, 7.7194324D-06 /
      data fpp( 2, 3,10,1),fpp( 2, 3,10,2),fpp( 2, 3,10,3)/
     x 5.9563895D-02, 1.6842595D-07, 5.6264685D-06 /
      data fpp( 2, 3,11,1),fpp( 2, 3,11,2),fpp( 2, 3,11,3)/
     x 7.9756730D-02,-1.5571521D-05,-5.9119731D-06 /
      data fpp( 2, 3,12,1),fpp( 2, 3,12,2),fpp( 2, 3,12,3)/
     x 9.3285415D-02,-5.9230679D-05,-1.4250576D-05 /
      data fpp( 2, 3,13,1),fpp( 2, 3,13,2),fpp( 2, 3,13,3)/
     x 5.9425510D-02,-2.6479240D-05,-8.0463889D-06 /
      data fpp( 2, 3,14,1),fpp( 2, 3,14,2),fpp( 2, 3,14,3)/
     x 3.1505083D-02, 1.7544938D-05, 1.0476132D-05 /
      data fpp( 2, 3,15,1),fpp( 2, 3,15,2),fpp( 2, 3,15,3)/
     x 4.0365442D-02, 6.7785902D-05, 1.6952529D-05 /
      data fpp( 2, 3,16,1),fpp( 2, 3,16,2),fpp( 2, 3,16,3)/
     x 3.1505083D-02, 1.7544938D-05, 7.7204204D-06 /
      data fpp( 2, 3,17,1),fpp( 2, 3,17,2),fpp( 2, 3,17,3)/
     x 5.9425510D-02,-2.6479240D-05, 2.9764565D-06 /
      data fpp( 2, 4, 1,1),fpp( 2, 4, 1,2),fpp( 2, 4, 1,3)/
     x 6.0425825D-02,-3.9801395D-05, 2.5181055D-05 /
      data fpp( 2, 4, 2,1),fpp( 2, 4, 2,2),fpp( 2, 4, 2,3)/
     x 5.4555698D-02, 4.8908946D-05, 1.9825779D-05 /
      data fpp( 2, 4, 3,1),fpp( 2, 4, 3,2),fpp( 2, 4, 3,3)/
     x 1.9666087D-01, 2.6878208D-04,-4.4750317D-07 /
      data fpp( 2, 4, 4,1),fpp( 2, 4, 4,2),fpp( 2, 4, 4,3)/
     x 5.4555698D-02, 4.8908946D-05, 3.1492234D-05 /
      data fpp( 2, 4, 5,1),fpp( 2, 4, 5,2),fpp( 2, 4, 5,3)/
     x 6.0425825D-02,-3.9801395D-05,-2.1484766D-05 /
      data fpp( 2, 4, 6,1),fpp( 2, 4, 6,2),fpp( 2, 4, 6,3)/
     x 9.3541982D-02,-7.8234477D-05,-3.0583586D-07 /
      data fpp( 2, 4, 7,1),fpp( 2, 4, 7,2),fpp( 2, 4, 7,3)/
     x 1.9731242D-01, 1.6466408D-04,-3.3428557D-05 /
      data fpp( 2, 4, 8,1),fpp( 2, 4, 8,2),fpp( 2, 4, 8,3)/
     x 7.2815875D-02,-1.0128678D-06, 2.1897397D-05 /
      data fpp( 2, 4, 9,1),fpp( 2, 4, 9,2),fpp( 2, 4, 9,3)/
     x 5.4698093D-02, 2.0160075D-06, 6.0509680D-06 /
      data fpp( 2, 4,10,1),fpp( 2, 4,10,2),fpp( 2, 4,10,3)/
     x 7.2815875D-02,-1.0128678D-06, 2.1897397D-05 /
      data fpp( 2, 4,11,1),fpp( 2, 4,11,2),fpp( 2, 4,11,3)/
     x 1.9731242D-01, 1.6466408D-04,-3.3428557D-05 /
      data fpp( 2, 4,12,1),fpp( 2, 4,12,2),fpp( 2, 4,12,3)/
     x 9.3541982D-02,-7.8234477D-05,-3.0583586D-07 /
      data fpp( 2, 4,13,1),fpp( 2, 4,13,2),fpp( 2, 4,13,3)/
     x 6.0425825D-02,-3.9801395D-05,-2.1484766D-05 /
      data fpp( 2, 4,14,1),fpp( 2, 4,14,2),fpp( 2, 4,14,3)/
     x 5.4555698D-02, 4.8908946D-05, 3.1492234D-05 /
      data fpp( 2, 4,15,1),fpp( 2, 4,15,2),fpp( 2, 4,15,3)/
     x 1.9666087D-01, 2.6878208D-04,-4.4750317D-07 /
      data fpp( 2, 4,16,1),fpp( 2, 4,16,2),fpp( 2, 4,16,3)/
     x 5.4555698D-02, 4.8908946D-05, 1.9825779D-05 /
      data fpp( 2, 4,17,1),fpp( 2, 4,17,2),fpp( 2, 4,17,3)/
     x 6.0425825D-02,-3.9801395D-05, 2.5181055D-05 /
      data fpp( 2, 5, 1,1),fpp( 2, 5, 1,2),fpp( 2, 5, 1,3)/
     x 5.5826631D-02,-1.1739181D-05, 7.4869367D-05 /
      data fpp( 2, 5, 2,1),fpp( 2, 5, 2,2),fpp( 2, 5, 2,3)/
     x 8.0716304D-02, 2.5481277D-05, 4.0581377D-05 /
      data fpp( 2, 5, 3,1),fpp( 2, 5, 3,2),fpp( 2, 5, 3,3)/
     x 5.2923570D-01,-2.8027621D-04,-5.9055541D-05 /
      data fpp( 2, 5, 4,1),fpp( 2, 5, 4,2),fpp( 2, 5, 4,3)/
     x 8.0716304D-02, 2.5481277D-05, 7.0028787D-05 /
      data fpp( 2, 5, 5,1),fpp( 2, 5, 5,2),fpp( 2, 5, 5,3)/
     x 5.5826631D-02,-1.1739181D-05,-4.2920275D-05 /
      data fpp( 2, 5, 6,1),fpp( 2, 5, 6,2),fpp( 2, 5, 6,3)/
     x 9.3797917D-02,-4.2509412D-05, 5.2421648D-05 /
      data fpp( 2, 5, 7,1),fpp( 2, 5, 7,2),fpp( 2, 5, 7,3)/
     x 5.2774046D-01,-3.5150279D-04,-1.0546632D-04 /
      data fpp( 2, 5, 8,1),fpp( 2, 5, 8,2),fpp( 2, 5, 8,3)/
     x 9.3772048D-02,-2.5552955D-05, 6.3328281D-05 /
      data fpp( 2, 5, 9,1),fpp( 2, 5, 9,2),fpp( 2, 5, 9,3)/
     x 5.5256643D-02, 4.5207797D-06,-1.0820807D-05 /
      data fpp( 2, 5,10,1),fpp( 2, 5,10,2),fpp( 2, 5,10,3)/
     x 9.3772048D-02,-2.5552955D-05, 6.3328281D-05 /
      data fpp( 2, 5,11,1),fpp( 2, 5,11,2),fpp( 2, 5,11,3)/
     x 5.2774046D-01,-3.5150279D-04,-1.0546632D-04 /
      data fpp( 2, 5,12,1),fpp( 2, 5,12,2),fpp( 2, 5,12,3)/
     x 9.3797917D-02,-4.2509412D-05, 5.2421648D-05 /
      data fpp( 2, 5,13,1),fpp( 2, 5,13,2),fpp( 2, 5,13,3)/
     x 5.5826631D-02,-1.1739181D-05,-4.2920275D-05 /
      data fpp( 2, 5,14,1),fpp( 2, 5,14,2),fpp( 2, 5,14,3)/
     x 8.0716304D-02, 2.5481277D-05, 7.0028787D-05 /
      data fpp( 2, 5,15,1),fpp( 2, 5,15,2),fpp( 2, 5,15,3)/
     x 5.2923570D-01,-2.8027621D-04,-5.9055541D-05 /
      data fpp( 2, 5,16,1),fpp( 2, 5,16,2),fpp( 2, 5,16,3)/
     x 8.0716304D-02, 2.5481277D-05, 4.0581377D-05 /
      data fpp( 2, 5,17,1),fpp( 2, 5,17,2),fpp( 2, 5,17,3)/
     x 5.5826631D-02,-1.1739181D-05, 7.4869367D-05 /
      data fpp( 2, 6, 1,1),fpp( 2, 6, 1,2),fpp( 2, 6, 1,3)/
     x 4.1814673D-02, 1.6912120D-05, 4.3224498D-05 /
      data fpp( 2, 6, 2,1),fpp( 2, 6, 2,2),fpp( 2, 6, 2,3)/
     x 6.6200850D-02, 5.0639945D-05, 2.3896114D-05 /
      data fpp( 2, 6, 3,1),fpp( 2, 6, 3,2),fpp( 2, 6, 3,3)/
     x 3.9228908D-01, 3.8867789D-06,-3.3370290D-05 /
      data fpp( 2, 6, 4,1),fpp( 2, 6, 4,2),fpp( 2, 6, 4,3)/
     x 6.6200850D-02, 5.0639945D-05, 4.2146377D-05 /
      data fpp( 2, 6, 5,1),fpp( 2, 6, 5,2),fpp( 2, 6, 5,3)/
     x 4.1814673D-02, 1.6912120D-05,-2.9776552D-05 /
      data fpp( 2, 6, 6,1),fpp( 2, 6, 6,2),fpp( 2, 6, 6,3)/
     x 6.4445850D-02, 3.2842124D-05, 4.7221832D-05 /
      data fpp( 2, 6, 7,1),fpp( 2, 6, 7,2),fpp( 2, 6, 7,3)/
     x 3.9359986D-01,-5.5750928D-05,-8.4383442D-05 /
      data fpp( 2, 6, 8,1),fpp( 2, 6, 8,2),fpp( 2, 6, 8,3)/
     x 7.1938163D-02, 1.7676687D-05, 4.5005936D-05 /
      data fpp( 2, 6, 9,1),fpp( 2, 6, 9,2),fpp( 2, 6, 9,3)/
     x 4.4768589D-02, 5.9588737D-06,-4.0163012D-06 /
      data fpp( 2, 6,10,1),fpp( 2, 6,10,2),fpp( 2, 6,10,3)/
     x 7.1938163D-02, 1.7676687D-05, 4.5005936D-05 /
      data fpp( 2, 6,11,1),fpp( 2, 6,11,2),fpp( 2, 6,11,3)/
     x 3.9359986D-01,-5.5750928D-05,-8.4383442D-05 /
      data fpp( 2, 6,12,1),fpp( 2, 6,12,2),fpp( 2, 6,12,3)/
     x 6.4445850D-02, 3.2842124D-05, 4.7221832D-05 /
      data fpp( 2, 6,13,1),fpp( 2, 6,13,2),fpp( 2, 6,13,3)/
     x 4.1814673D-02, 1.6912120D-05,-2.9776552D-05 /
      data fpp( 2, 6,14,1),fpp( 2, 6,14,2),fpp( 2, 6,14,3)/
     x 6.6200850D-02, 5.0639945D-05, 4.2146377D-05 /
      data fpp( 2, 6,15,1),fpp( 2, 6,15,2),fpp( 2, 6,15,3)/
     x 3.9228908D-01, 3.8867789D-06,-3.3370290D-05 /
      data fpp( 2, 6,16,1),fpp( 2, 6,16,2),fpp( 2, 6,16,3)/
     x 6.6200850D-02, 5.0639945D-05, 2.3896114D-05 /
      data fpp( 2, 6,17,1),fpp( 2, 6,17,2),fpp( 2, 6,17,3)/
     x 4.1814673D-02, 1.6912120D-05, 4.3224498D-05 /
      data fpp( 2, 7, 1,1),fpp( 2, 7, 1,2),fpp( 2, 7, 1,3)/
     x 2.9072402D-02, 2.2612700D-05,-1.2173113D-05 /
      data fpp( 2, 7, 2,1),fpp( 2, 7, 2,2),fpp( 2, 7, 2,3)/
     x 4.2556585D-02,-2.2550582D-06,-4.4432185D-06 /
      data fpp( 2, 7, 3,1),fpp( 2, 7, 3,2),fpp( 2, 7, 3,3)/
     x 1.1980794D-01, 2.1737110D-04, 1.5971987D-05 /
      data fpp( 2, 7, 4,1),fpp( 2, 7, 4,2),fpp( 2, 7, 4,3)/
     x 4.2556585D-02,-2.2550582D-06,-8.0113965D-06 /
      data fpp( 2, 7, 5,1),fpp( 2, 7, 5,2),fpp( 2, 7, 5,3)/
     x 2.9072402D-02, 2.2612700D-05, 2.0995989D-06 /
      data fpp( 2, 7, 6,1),fpp( 2, 7, 6,2),fpp( 2, 7, 6,3)/
     x 3.5207919D-02, 4.3986915D-05, 1.1766334D-05 /
      data fpp( 2, 7, 7,1),fpp( 2, 7, 7,2),fpp( 2, 7, 7,3)/
     x 1.1651708D-01, 1.9921250D-04,-2.3506269D-05 /
      data fpp( 2, 7, 8,1),fpp( 2, 7, 8,2),fpp( 2, 7, 8,3)/
     x 4.1104700D-02,-9.9379172D-07, 8.2807700D-07 /
      data fpp( 2, 7, 9,1),fpp( 2, 7, 9,2),fpp( 2, 7, 9,3)/
     x 3.0647459D-02,-8.7602747D-06, 1.7080628D-05 /
      data fpp( 2, 7,10,1),fpp( 2, 7,10,2),fpp( 2, 7,10,3)/
     x 4.1104700D-02,-9.9379172D-07, 8.2807700D-07 /
      data fpp( 2, 7,11,1),fpp( 2, 7,11,2),fpp( 2, 7,11,3)/
     x 1.1651708D-01, 1.9921250D-04,-2.3506269D-05 /
      data fpp( 2, 7,12,1),fpp( 2, 7,12,2),fpp( 2, 7,12,3)/
     x 3.5207919D-02, 4.3986915D-05, 1.1766334D-05 /
      data fpp( 2, 7,13,1),fpp( 2, 7,13,2),fpp( 2, 7,13,3)/
     x 2.9072402D-02, 2.2612700D-05, 2.0995989D-06 /
      data fpp( 2, 7,14,1),fpp( 2, 7,14,2),fpp( 2, 7,14,3)/
     x 4.2556585D-02,-2.2550582D-06,-8.0113965D-06 /
      data fpp( 2, 7,15,1),fpp( 2, 7,15,2),fpp( 2, 7,15,3)/
     x 1.1980794D-01, 2.1737110D-04, 1.5971987D-05 /
      data fpp( 2, 7,16,1),fpp( 2, 7,16,2),fpp( 2, 7,16,3)/
     x 4.2556585D-02,-2.2550582D-06,-4.4432185D-06 /
      data fpp( 2, 7,17,1),fpp( 2, 7,17,2),fpp( 2, 7,17,3)/
     x 2.9072402D-02, 2.2612700D-05,-1.2173113D-05 /
      data fpp( 2, 8, 1,1),fpp( 2, 8, 1,2),fpp( 2, 8, 1,3)/
     x 2.0315511D-02, 1.9195081D-05,-8.4585924D-06 /
      data fpp( 2, 8, 2,1),fpp( 2, 8, 2,2),fpp( 2, 8, 2,3)/
     x 2.7196953D-02,-6.0729712D-05,-6.0930374D-06 /
      data fpp( 2, 8, 3,1),fpp( 2, 8, 3,2),fpp( 2, 8, 3,3)/
     x 4.1338190D-02,-1.0392517D-04, 3.2467419D-06 /
      data fpp( 2, 8, 4,1),fpp( 2, 8, 4,2),fpp( 2, 8, 4,3)/
     x 2.7196953D-02,-6.0729712D-05,-1.1823264D-05 /
      data fpp( 2, 8, 5,1),fpp( 2, 8, 5,2),fpp( 2, 8, 5,3)/
     x 2.0315511D-02, 1.9195081D-05, 1.4462313D-05 /
      data fpp( 2, 8, 6,1),fpp( 2, 8, 6,2),fpp( 2, 8, 6,3)/
     x 2.3013931D-02, 3.2746214D-05, 4.6086790D-06 /
      data fpp( 2, 8, 7,1),fpp( 2, 8, 7,2),fpp( 2, 8, 7,3)/
     x 3.5948827D-02,-3.7507555D-07,-1.3617029D-05 /
      data fpp( 2, 8, 8,1),fpp( 2, 8, 8,2),fpp( 2, 8, 8,3)/
     x 2.2247061D-02,-2.6073520D-05,-6.8385632D-06 /
      data fpp( 2, 8, 9,1),fpp( 2, 8, 9,2),fpp( 2, 8, 9,3)/
     x 1.6826824D-02,-2.4545775D-05, 2.2213948D-05 /
      data fpp( 2, 8,10,1),fpp( 2, 8,10,2),fpp( 2, 8,10,3)/
     x 2.2247061D-02,-2.6073520D-05,-6.8385632D-06 /
      data fpp( 2, 8,11,1),fpp( 2, 8,11,2),fpp( 2, 8,11,3)/
     x 3.5948827D-02,-3.7507555D-07,-1.3617029D-05 /
      data fpp( 2, 8,12,1),fpp( 2, 8,12,2),fpp( 2, 8,12,3)/
     x 2.3013931D-02, 3.2746214D-05, 4.6086790D-06 /
      data fpp( 2, 8,13,1),fpp( 2, 8,13,2),fpp( 2, 8,13,3)/
     x 2.0315511D-02, 1.9195081D-05, 1.4462313D-05 /
      data fpp( 2, 8,14,1),fpp( 2, 8,14,2),fpp( 2, 8,14,3)/
     x 2.7196953D-02,-6.0729712D-05,-1.1823264D-05 /
      data fpp( 2, 8,15,1),fpp( 2, 8,15,2),fpp( 2, 8,15,3)/
     x 4.1338190D-02,-1.0392517D-04, 3.2467419D-06 /
      data fpp( 2, 8,16,1),fpp( 2, 8,16,2),fpp( 2, 8,16,3)/
     x 2.7196953D-02,-6.0729712D-05,-6.0930374D-06 /
      data fpp( 2, 8,17,1),fpp( 2, 8,17,2),fpp( 2, 8,17,3)/
     x 2.0315511D-02, 1.9195081D-05,-8.4585924D-06 /
      data fpp( 2, 9, 1,1),fpp( 2, 9, 1,2),fpp( 2, 9, 1,3)/
     x 1.4156016D-02, 1.6346975D-05, 7.5219174D-06 /
      data fpp( 2, 9, 2,1),fpp( 2, 9, 2,2),fpp( 2, 9, 2,3)/
     x 1.4399531D-02,-4.7830092D-05, 8.3083194D-07 /
      data fpp( 2, 9, 3,1),fpp( 2, 9, 3,2),fpp( 2, 9, 3,3)/
     x 1.8076517D-02,-1.2312040D-04,-1.3783912D-05 /
      data fpp( 2, 9, 4,1),fpp( 2, 9, 4,2),fpp( 2, 9, 4,3)/
     x 1.4399531D-02,-4.7830092D-05,-6.6585142D-07 /
      data fpp( 2, 9, 5,1),fpp( 2, 9, 5,2),fpp( 2, 9, 5,3)/
     x 1.4156016D-02, 1.6346975D-05, 1.3508651D-05 /
      data fpp( 2, 9, 6,1),fpp( 2, 9, 6,2),fpp( 2, 9, 6,3)/
     x 1.9621695D-02, 3.6510227D-05, 9.6924824D-07 /
      data fpp( 2, 9, 7,1),fpp( 2, 9, 7,2),fpp( 2, 9, 7,3)/
     x 2.0439091D-02,-1.4419882D-07,-1.6668310D-05 /
      data fpp( 2, 9, 8,1),fpp( 2, 9, 8,2),fpp( 2, 9, 8,3)/
     x 9.0226320D-03,-2.2452129D-05,-8.6067321D-07 /
      data fpp( 2, 9, 9,1),fpp( 2, 9, 9,2),fpp( 2, 9, 9,3)/
     x 3.4421187D-03,-2.8776625D-05, 2.0968337D-05 /
      data fpp( 2, 9,10,1),fpp( 2, 9,10,2),fpp( 2, 9,10,3)/
     x 9.0226320D-03,-2.2452129D-05,-8.6067321D-07 /
      data fpp( 2, 9,11,1),fpp( 2, 9,11,2),fpp( 2, 9,11,3)/
     x 2.0439091D-02,-1.4419882D-07,-1.6668310D-05 /
      data fpp( 2, 9,12,1),fpp( 2, 9,12,2),fpp( 2, 9,12,3)/
     x 1.9621695D-02, 3.6510227D-05, 9.6924824D-07 /
      data fpp( 2, 9,13,1),fpp( 2, 9,13,2),fpp( 2, 9,13,3)/
     x 1.4156016D-02, 1.6346975D-05, 1.3508651D-05 /
      data fpp( 2, 9,14,1),fpp( 2, 9,14,2),fpp( 2, 9,14,3)/
     x 1.4399531D-02,-4.7830092D-05,-6.6585142D-07 /
      data fpp( 2, 9,15,1),fpp( 2, 9,15,2),fpp( 2, 9,15,3)/
     x 1.8076517D-02,-1.2312040D-04,-1.3783912D-05 /
      data fpp( 2, 9,16,1),fpp( 2, 9,16,2),fpp( 2, 9,16,3)/
     x 1.4399531D-02,-4.7830092D-05, 8.3083194D-07 /
      data fpp( 2, 9,17,1),fpp( 2, 9,17,2),fpp( 2, 9,17,3)/
     x 1.4156016D-02, 1.6346975D-05, 7.5219174D-06 /
      data fpp( 2,10, 1,1),fpp( 2,10, 1,2),fpp( 2,10, 1,3)/
     x 9.6129427D-03, 1.8497020D-05, 1.1710984D-05 /
      data fpp( 2,10, 2,1),fpp( 2,10, 2,2),fpp( 2,10, 2,3)/
     x 2.2178804D-03,-1.6905918D-05, 5.5883646D-06 /
      data fpp( 2,10, 3,1),fpp( 2,10, 3,2),fpp( 2,10, 3,3)/
     x 2.8045311D-04,-3.3731216D-05,-9.1517761D-06 /
      data fpp( 2,10, 4,1),fpp( 2,10, 4,2),fpp( 2,10, 4,3)/
     x 2.2178804D-03,-1.6905918D-05, 6.2694066D-06 /
      data fpp( 2,10, 5,1),fpp( 2,10, 5,2),fpp( 2,10, 5,3)/
     x 9.6129427D-03, 1.8497020D-05, 8.9868165D-06 /
      data fpp( 2,10, 6,1),fpp( 2,10, 6,2),fpp( 2,10, 6,3)/
     x 1.9530109D-02, 4.4712878D-05,-1.2132672D-05 /
      data fpp( 2,10, 7,1),fpp( 2,10, 7,2),fpp( 2,10, 7,3)/
     x 1.3564916D-02, 8.6438708D-06,-1.5660127D-05 /
      data fpp( 2,10, 8,1),fpp( 2,10, 8,2),fpp( 2,10, 8,3)/
     x-2.0585539D-03,-1.5439963D-05, 6.8745124D-06 /
      data fpp( 2,10, 9,1),fpp( 2,10, 9,2),fpp( 2,10, 9,3)/
     x-7.7434389D-03,-2.3085725D-05, 2.0589410D-05 /
      data fpp( 2,10,10,1),fpp( 2,10,10,2),fpp( 2,10,10,3)/
     x-2.0585539D-03,-1.5439963D-05, 6.8745124D-06 /
      data fpp( 2,10,11,1),fpp( 2,10,11,2),fpp( 2,10,11,3)/
     x 1.3564916D-02, 8.6438708D-06,-1.5660127D-05 /
      data fpp( 2,10,12,1),fpp( 2,10,12,2),fpp( 2,10,12,3)/
     x 1.9530109D-02, 4.4712878D-05,-1.2132672D-05 /
      data fpp( 2,10,13,1),fpp( 2,10,13,2),fpp( 2,10,13,3)/
     x 9.6129427D-03, 1.8497020D-05, 8.9868165D-06 /
      data fpp( 2,10,14,1),fpp( 2,10,14,2),fpp( 2,10,14,3)/
     x 2.2178804D-03,-1.6905918D-05, 6.2694066D-06 /
      data fpp( 2,10,15,1),fpp( 2,10,15,2),fpp( 2,10,15,3)/
     x 2.8045311D-04,-3.3731216D-05,-9.1517761D-06 /
      data fpp( 2,10,16,1),fpp( 2,10,16,2),fpp( 2,10,16,3)/
     x 2.2178804D-03,-1.6905918D-05, 5.5883646D-06 /
      data fpp( 2,10,17,1),fpp( 2,10,17,2),fpp( 2,10,17,3)/
     x 9.6129427D-03, 1.8497020D-05, 1.1710984D-05 /
      data fpp( 2,11, 1,1),fpp( 2,11, 1,2),fpp( 2,11, 1,3)/
     x 6.5145963D-03, 2.6574945D-05, 1.4051110D-05 /
      data fpp( 2,11, 2,1),fpp( 2,11, 2,2),fpp( 2,11, 2,3)/
     x-6.1670561D-03, 7.6817636D-06, 1.1196670D-05 /
      data fpp( 2,11, 3,1),fpp( 2,11, 3,2),fpp( 2,11, 3,3)/
     x-1.0548673D-02, 8.3672682D-06, 3.1235452D-06 /
      data fpp( 2,11, 4,1),fpp( 2,11, 4,2),fpp( 2,11, 4,3)/
     x-6.1670561D-03, 7.6817636D-06, 1.3315816D-05 /
      data fpp( 2,11, 5,1),fpp( 2,11, 5,2),fpp( 2,11, 5,3)/
     x 6.5145963D-03, 2.6574945D-05, 5.5745225D-06 /
      data fpp( 2,11, 6,1),fpp( 2,11, 6,2),fpp( 2,11, 6,3)/
     x 2.1735947D-02, 5.7824261D-05,-3.7384573D-05 /
      data fpp( 2,11, 7,1),fpp( 2,11, 7,2),fpp( 2,11, 7,3)/
     x 7.0821622D-03, 1.4396716D-05,-9.4542303D-06 /
      data fpp( 2,11, 8,1),fpp( 2,11, 8,2),fpp( 2,11, 8,3)/
     x-1.0382932D-02,-5.8240201D-06, 1.5468161D-05 /
      data fpp( 2,11, 9,1),fpp( 2,11, 9,2),fpp( 2,11, 9,3)/
     x-1.5630981D-02,-1.2278474D-05, 2.2190253D-05 /
      data fpp( 2,11,10,1),fpp( 2,11,10,2),fpp( 2,11,10,3)/
     x-1.0382932D-02,-5.8240201D-06, 1.5468161D-05 /
      data fpp( 2,11,11,1),fpp( 2,11,11,2),fpp( 2,11,11,3)/
     x 7.0821622D-03, 1.4396716D-05,-9.4542303D-06 /
      data fpp( 2,11,12,1),fpp( 2,11,12,2),fpp( 2,11,12,3)/
     x 2.1735947D-02, 5.7824261D-05,-3.7384573D-05 /
      data fpp( 2,11,13,1),fpp( 2,11,13,2),fpp( 2,11,13,3)/
     x 6.5145963D-03, 2.6574945D-05, 5.5745225D-06 /
      data fpp( 2,11,14,1),fpp( 2,11,14,2),fpp( 2,11,14,3)/
     x-6.1670561D-03, 7.6817636D-06, 1.3315816D-05 /
      data fpp( 2,11,15,1),fpp( 2,11,15,2),fpp( 2,11,15,3)/
     x-1.0548673D-02, 8.3672682D-06, 3.1235452D-06 /
      data fpp( 2,11,16,1),fpp( 2,11,16,2),fpp( 2,11,16,3)/
     x-6.1670561D-03, 7.6817636D-06, 1.1196670D-05 /
      data fpp( 2,11,17,1),fpp( 2,11,17,2),fpp( 2,11,17,3)/
     x 6.5145963D-03, 2.6574945D-05, 1.4051110D-05 /
      data fpp( 2,12, 1,1),fpp( 2,12, 1,2),fpp( 2,12, 1,3)/
     x 5.0425690D-03, 4.3197198D-05, 1.9970965D-05 /
      data fpp( 2,12, 2,1),fpp( 2,12, 2,2),fpp( 2,12, 2,3)/
     x-1.0817961D-02, 3.1166863D-05, 1.9108958D-05 /
      data fpp( 2,12, 3,1),fpp( 2,12, 3,2),fpp( 2,12, 3,3)/
     x-1.5962449D-02, 3.3694144D-05, 1.4986535D-05 /
      data fpp( 2,12, 4,1),fpp( 2,12, 4,2),fpp( 2,12, 4,3)/
     x-1.0817961D-02, 3.1166863D-05, 2.2275569D-05 /
      data fpp( 2,12, 5,1),fpp( 2,12, 5,2),fpp( 2,12, 5,3)/
     x 5.0425690D-03, 4.3197198D-05, 7.3045225D-06 /
      data fpp( 2,12, 6,1),fpp( 2,12, 6,2),fpp( 2,12, 6,3)/
     x 2.7792127D-02, 7.5614079D-05,-7.8382992D-05 /
      data fpp( 2,12, 7,1),fpp( 2,12, 7,2),fpp( 2,12, 7,3)/
     x 7.5078910D-04, 2.1483267D-05, 4.8687800D-06 /
      data fpp( 2,12, 8,1),fpp( 2,12, 8,2),fpp( 2,12, 8,3)/
     x-1.6227024D-02, 9.4920428D-06, 2.3667872D-05 /
      data fpp( 2,12, 9,1),fpp( 2,12, 9,2),fpp( 2,12, 9,3)/
     x-2.0871244D-02, 5.4136230D-06, 2.6073730D-05 /
      data fpp( 2,12,10,1),fpp( 2,12,10,2),fpp( 2,12,10,3)/
     x-1.6227024D-02, 9.4920428D-06, 2.3667872D-05 /
      data fpp( 2,12,11,1),fpp( 2,12,11,2),fpp( 2,12,11,3)/
     x 7.5078910D-04, 2.1483267D-05, 4.8687800D-06 /
      data fpp( 2,12,12,1),fpp( 2,12,12,2),fpp( 2,12,12,3)/
     x 2.7792127D-02, 7.5614079D-05,-7.8382992D-05 /
      data fpp( 2,12,13,1),fpp( 2,12,13,2),fpp( 2,12,13,3)/
     x 5.0425690D-03, 4.3197198D-05, 7.3045225D-06 /
      data fpp( 2,12,14,1),fpp( 2,12,14,2),fpp( 2,12,14,3)/
     x-1.0817961D-02, 3.1166863D-05, 2.2275569D-05 /
      data fpp( 2,12,15,1),fpp( 2,12,15,2),fpp( 2,12,15,3)/
     x-1.5962449D-02, 3.3694144D-05, 1.4986535D-05 /
      data fpp( 2,12,16,1),fpp( 2,12,16,2),fpp( 2,12,16,3)/
     x-1.0817961D-02, 3.1166863D-05, 1.9108958D-05 /
      data fpp( 2,12,17,1),fpp( 2,12,17,2),fpp( 2,12,17,3)/
     x 5.0425690D-03, 4.3197198D-05, 1.9970965D-05 /
      data fpp( 2,13, 1,1),fpp( 2,13, 1,2),fpp( 2,13, 1,3)/
     x 7.3920558D-03, 7.5982262D-05, 2.9830928D-05 /
      data fpp( 2,13, 2,1),fpp( 2,13, 2,2),fpp( 2,13, 2,3)/
     x-1.3702980D-02, 6.1360783D-05, 2.9103921D-05 /
      data fpp( 2,13, 3,1),fpp( 2,13, 3,2),fpp( 2,13, 3,3)/
     x-1.8739391D-02, 6.4990158D-05, 2.5252054D-05 /
      data fpp( 2,13, 4,1),fpp( 2,13, 4,2),fpp( 2,13, 4,3)/
     x-1.3702980D-02, 6.1360783D-05, 3.2337197D-05 /
      data fpp( 2,13, 5,1),fpp( 2,13, 5,2),fpp( 2,13, 5,3)/
     x 7.3920558D-03, 7.5982262D-05, 1.6897825D-05 /
      data fpp( 2,13, 6,1),fpp( 2,13, 6,2),fpp( 2,13, 6,3)/
     x 5.1148692D-02, 1.0831942D-04,-1.3953450D-04 /
      data fpp( 2,13, 7,1),fpp( 2,13, 7,2),fpp( 2,13, 7,3)/
     x-7.0239131D-03, 2.8220217D-05, 3.2684826D-05 /
      data fpp( 2,13, 8,1),fpp( 2,13, 8,2),fpp( 2,13, 8,3)/
     x-2.0556110D-02, 3.4197849D-05, 2.8919859D-05 /
      data fpp( 2,13, 9,1),fpp( 2,13, 9,2),fpp( 2,13, 9,3)/
     x-2.4265589D-02, 3.4549982D-05, 3.2676404D-05 /
      data fpp( 2,13,10,1),fpp( 2,13,10,2),fpp( 2,13,10,3)/
     x-2.0556110D-02, 3.4197849D-05, 2.8919859D-05 /
      data fpp( 2,13,11,1),fpp( 2,13,11,2),fpp( 2,13,11,3)/
     x-7.0239131D-03, 2.8220217D-05, 3.2684826D-05 /
      data fpp( 2,13,12,1),fpp( 2,13,12,2),fpp( 2,13,12,3)/
     x 5.1148692D-02, 1.0831942D-04,-1.3953450D-04 /
      data fpp( 2,13,13,1),fpp( 2,13,13,2),fpp( 2,13,13,3)/
     x 7.3920558D-03, 7.5982262D-05, 1.6897825D-05 /
      data fpp( 2,13,14,1),fpp( 2,13,14,2),fpp( 2,13,14,3)/
     x-1.3702980D-02, 6.1360783D-05, 3.2337197D-05 /
      data fpp( 2,13,15,1),fpp( 2,13,15,2),fpp( 2,13,15,3)/
     x-1.8739391D-02, 6.4990158D-05, 2.5252054D-05 /
      data fpp( 2,13,16,1),fpp( 2,13,16,2),fpp( 2,13,16,3)/
     x-1.3702980D-02, 6.1360783D-05, 2.9103921D-05 /
      data fpp( 2,13,17,1),fpp( 2,13,17,2),fpp( 2,13,17,3)/
     x 7.3920558D-03, 7.5982262D-05, 2.9830928D-05 /
      data fpp( 2,14, 1,1),fpp( 2,14, 1,2),fpp( 2,14, 1,3)/
     x 3.7542435D-02, 1.6277776D-04, 4.6532469D-05 /
      data fpp( 2,14, 2,1),fpp( 2,14, 2,2),fpp( 2,14, 2,3)/
     x-1.5890968D-02, 9.3314006D-05, 4.2797840D-05 /
      data fpp( 2,14, 3,1),fpp( 2,14, 3,2),fpp( 2,14, 3,3)/
     x-2.0207573D-02, 1.0279523D-04, 3.2380837D-05 /
      data fpp( 2,14, 4,1),fpp( 2,14, 4,2),fpp( 2,14, 4,3)/
     x-1.5890968D-02, 9.3314006D-05, 4.5352145D-05 /
      data fpp( 2,14, 5,1),fpp( 2,14, 5,2),fpp( 2,14, 5,3)/
     x 3.7542435D-02, 1.6277776D-04, 3.6315250D-05 /
      data fpp( 2,14, 6,1),fpp( 2,14, 6,2),fpp( 2,14, 6,3)/
     x 1.5959521D-01, 2.3464023D-04,-2.3253048D-04 /
      data fpp( 2,14, 7,1),fpp( 2,14, 7,2),fpp( 2,14, 7,3)/
     x-1.7661132D-02, 3.2927866D-05, 8.8069334D-05 /
      data fpp( 2,14, 8,1),fpp( 2,14, 8,2),fpp( 2,14, 8,3)/
     x-2.3996701D-02, 6.8528562D-05, 2.5049143D-05 /
      data fpp( 2,14, 9,1),fpp( 2,14, 9,2),fpp( 2,14, 9,3)/
     x-2.6202661D-02, 7.6712447D-05, 4.3534095D-05 /
      data fpp( 2,14,10,1),fpp( 2,14,10,2),fpp( 2,14,10,3)/
     x-2.3996701D-02, 6.8528562D-05, 2.5049143D-05 /
      data fpp( 2,14,11,1),fpp( 2,14,11,2),fpp( 2,14,11,3)/
     x-1.7661132D-02, 3.2927866D-05, 8.8069334D-05 /
      data fpp( 2,14,12,1),fpp( 2,14,12,2),fpp( 2,14,12,3)/
     x 1.5959521D-01, 2.3464023D-04,-2.3253048D-04 /
      data fpp( 2,14,13,1),fpp( 2,14,13,2),fpp( 2,14,13,3)/
     x 3.7542435D-02, 1.6277776D-04, 3.6315250D-05 /
      data fpp( 2,14,14,1),fpp( 2,14,14,2),fpp( 2,14,14,3)/
     x-1.5890968D-02, 9.3314006D-05, 4.5352145D-05 /
      data fpp( 2,14,15,1),fpp( 2,14,15,2),fpp( 2,14,15,3)/
     x-2.0207573D-02, 1.0279523D-04, 3.2380837D-05 /
      data fpp( 2,14,16,1),fpp( 2,14,16,2),fpp( 2,14,16,3)/
     x-1.5890968D-02, 9.3314006D-05, 4.2797840D-05 /
      data fpp( 2,14,17,1),fpp( 2,14,17,2),fpp( 2,14,17,3)/
     x 3.7542435D-02, 1.6277776D-04, 4.6532469D-05 /
      data fpp( 2,15, 1,1),fpp( 2,15, 1,2),fpp( 2,15, 1,3)/
     x 1.5184485D-01,-1.5695528D-04, 6.8165169D-05 /
      data fpp( 2,15, 2,1),fpp( 2,15, 2,2),fpp( 2,15, 2,3)/
     x-1.8376479D-02, 1.3028919D-04, 5.8815883D-05 /
      data fpp( 2,15, 3,1),fpp( 2,15, 3,2),fpp( 2,15, 3,3)/
     x-2.1921882D-02, 1.5894694D-04, 3.3664630D-05 /
      data fpp( 2,15, 4,1),fpp( 2,15, 4,2),fpp( 2,15, 4,3)/
     x-1.8376479D-02, 1.3028919D-04, 6.3820261D-05 /
      data fpp( 2,15, 5,1),fpp( 2,15, 5,2),fpp( 2,15, 5,3)/
     x 1.5184485D-01,-1.5695528D-04, 4.8147657D-05 /
      data fpp( 2,15, 6,1),fpp( 2,15, 6,2),fpp( 2,15, 6,3)/
     x 4.4764453D-02,-6.9697833D-04,-3.2569156D-04 /
      data fpp( 2,15, 7,1),fpp( 2,15, 7,2),fpp( 2,15, 7,3)/
     x-2.3607742D-02, 1.8352321D-05, 1.5710124D-04 /
      data fpp( 2,15, 8,1),fpp( 2,15, 8,2),fpp( 2,15, 8,3)/
     x-2.6573233D-02, 1.0805790D-04, 1.2276598D-05 /
      data fpp( 2,15, 9,1),fpp( 2,15, 9,2),fpp( 2,15, 9,3)/
     x-2.6656359D-02, 1.2864023D-04, 5.5861034D-05 /
      data fpp( 2,15,10,1),fpp( 2,15,10,2),fpp( 2,15,10,3)/
     x-2.6573233D-02, 1.0805790D-04, 1.2276598D-05 /
      data fpp( 2,15,11,1),fpp( 2,15,11,2),fpp( 2,15,11,3)/
     x-2.3607742D-02, 1.8352321D-05, 1.5710124D-04 /
      data fpp( 2,15,12,1),fpp( 2,15,12,2),fpp( 2,15,12,3)/
     x 4.4764453D-02,-6.9697833D-04,-3.2569156D-04 /
      data fpp( 2,15,13,1),fpp( 2,15,13,2),fpp( 2,15,13,3)/
     x 1.5184485D-01,-1.5695528D-04, 4.8147657D-05 /
      data fpp( 2,15,14,1),fpp( 2,15,14,2),fpp( 2,15,14,3)/
     x-1.8376479D-02, 1.3028919D-04, 6.3820261D-05 /
      data fpp( 2,15,15,1),fpp( 2,15,15,2),fpp( 2,15,15,3)/
     x-2.1921882D-02, 1.5894694D-04, 3.3664630D-05 /
      data fpp( 2,15,16,1),fpp( 2,15,16,2),fpp( 2,15,16,3)/
     x-1.8376479D-02, 1.3028919D-04, 5.8815883D-05 /
      data fpp( 2,15,17,1),fpp( 2,15,17,2),fpp( 2,15,17,3)/
     x 1.5184485D-01,-1.5695528D-04, 6.8165169D-05 /
      data fpp( 2,16, 1,1),fpp( 2,16, 1,2),fpp( 2,16, 1,3)/
     x 1.2750246D-01,-1.4447863D-04, 5.5830982D-05 /
      data fpp( 2,16, 2,1),fpp( 2,16, 2,2),fpp( 2,16, 2,3)/
     x-2.9387318D-02, 7.2943216D-05, 5.2417036D-05 /
      data fpp( 2,16, 3,1),fpp( 2,16, 3,2),fpp( 2,16, 3,3)/
     x-2.8329678D-02, 1.2724702D-04, 3.4302875D-05 /
      data fpp( 2,16, 4,1),fpp( 2,16, 4,2),fpp( 2,16, 4,3)/
     x-2.9387318D-02, 7.2943216D-05, 6.7639465D-05 /
      data fpp( 2,16, 5,1),fpp( 2,16, 5,2),fpp( 2,16, 5,3)/
     x 1.2750246D-01,-1.4447863D-04,-5.0587351D-06 /
      data fpp( 2,16, 6,1),fpp( 2,16, 6,2),fpp( 2,16, 6,3)/
     x 2.1902696D-01,-1.7938490D-04,-2.3584852D-04 /
      data fpp( 2,16, 7,1),fpp( 2,16, 7,2),fpp( 2,16, 7,3)/
     x-2.5516426D-02, 1.4768522D-06, 1.1066750D-04 /
      data fpp( 2,16, 8,1),fpp( 2,16, 8,2),fpp( 2,16, 8,3)/
     x-2.8316706D-02, 1.3692583D-04, 2.1629190D-05 /
      data fpp( 2,16, 9,1),fpp( 2,16, 9,2),fpp( 2,16, 9,3)/
     x-2.6134451D-02, 1.7149464D-04, 5.0176405D-05 /
      data fpp( 2,16,10,1),fpp( 2,16,10,2),fpp( 2,16,10,3)/
     x-2.8316706D-02, 1.3692583D-04, 2.1629190D-05 /
      data fpp( 2,16,11,1),fpp( 2,16,11,2),fpp( 2,16,11,3)/
     x-2.5516426D-02, 1.4768522D-06, 1.1066750D-04 /
      data fpp( 2,16,12,1),fpp( 2,16,12,2),fpp( 2,16,12,3)/
     x 2.1902696D-01,-1.7938490D-04,-2.3584852D-04 /
      data fpp( 2,16,13,1),fpp( 2,16,13,2),fpp( 2,16,13,3)/
     x 1.2750246D-01,-1.4447863D-04,-5.0587351D-06 /
      data fpp( 2,16,14,1),fpp( 2,16,14,2),fpp( 2,16,14,3)/
     x-2.9387318D-02, 7.2943216D-05, 6.7639465D-05 /
      data fpp( 2,16,15,1),fpp( 2,16,15,2),fpp( 2,16,15,3)/
     x-2.8329678D-02, 1.2724702D-04, 3.4302875D-05 /
      data fpp( 2,16,16,1),fpp( 2,16,16,2),fpp( 2,16,16,3)/
     x-2.9387318D-02, 7.2943216D-05, 5.2417036D-05 /
      data fpp( 2,16,17,1),fpp( 2,16,17,2),fpp( 2,16,17,3)/
     x 1.2750246D-01,-1.4447863D-04, 5.5830982D-05 /
      data fpp( 2,17, 1,1),fpp( 2,17, 1,2),fpp( 2,17, 1,3)/
     x-2.1597012D-01, 2.1154378D-04, 2.1425795D-05 /
      data fpp( 2,17, 2,1),fpp( 2,17, 2,2),fpp( 2,17, 2,3)/
     x-8.1460812D-02, 2.3670794D-04, 2.7679854D-05 /
      data fpp( 2,17, 3,1),fpp( 2,17, 3,2),fpp( 2,17, 3,3)/
     x-5.7882476D-02, 2.7267300D-04, 3.0336789D-05 /
      data fpp( 2,17, 4,1),fpp( 2,17, 4,2),fpp( 2,17, 4,3)/
     x-8.1460812D-02, 2.3670794D-04, 4.5583658D-05 /
      data fpp( 2,17, 5,1),fpp( 2,17, 5,2),fpp( 2,17, 5,3)/
     x-2.1597012D-01, 2.1154378D-04,-5.0189420D-05 /
      data fpp( 2,17, 6,1),fpp( 2,17, 6,2),fpp( 2,17, 6,3)/
     x-1.3520604D-01, 2.7711593D-04,-8.9319977D-05 /
      data fpp( 2,17, 7,1),fpp( 2,17, 7,2),fpp( 2,17, 7,3)/
     x-5.2968847D-02, 8.2564271D-05, 3.5893994D-05 /
      data fpp( 2,17, 8,1),fpp( 2,17, 8,2),fpp( 2,17, 8,3)/
     x-3.3859786D-02, 1.4483678D-04, 2.6494002D-05 /
      data fpp( 2,17, 9,1),fpp( 2,17, 9,2),fpp( 2,17, 9,3)/
     x-2.8733063D-02, 1.8421321D-04, 3.5722666D-05 /
      data fpp( 2,17,10,1),fpp( 2,17,10,2),fpp( 2,17,10,3)/
     x-3.3859786D-02, 1.4483678D-04, 2.6494002D-05 /
      data fpp( 2,17,11,1),fpp( 2,17,11,2),fpp( 2,17,11,3)/
     x-5.2968847D-02, 8.2564271D-05, 3.5893994D-05 /
      data fpp( 2,17,12,1),fpp( 2,17,12,2),fpp( 2,17,12,3)/
     x-1.3520604D-01, 2.7711593D-04,-8.9319977D-05 /
      data fpp( 2,17,13,1),fpp( 2,17,13,2),fpp( 2,17,13,3)/
     x-2.1597012D-01, 2.1154378D-04,-5.0189420D-05 /
      data fpp( 2,17,14,1),fpp( 2,17,14,2),fpp( 2,17,14,3)/
     x-8.1460812D-02, 2.3670794D-04, 4.5583658D-05 /
      data fpp( 2,17,15,1),fpp( 2,17,15,2),fpp( 2,17,15,3)/
     x-5.7882476D-02, 2.7267300D-04, 3.0336789D-05 /
      data fpp( 2,17,16,1),fpp( 2,17,16,2),fpp( 2,17,16,3)/
     x-8.1460812D-02, 2.3670794D-04, 2.7679854D-05 /
      data fpp( 2,17,17,1),fpp( 2,17,17,2),fpp( 2,17,17,3)/
     x-2.1597012D-01, 2.1154378D-04, 2.1425795D-05 /
      data fpp( 2,18, 1,1),fpp( 2,18, 1,2),fpp( 2,18, 1,3)/
     x-6.6073109D-01,-3.9155651D-04,-5.0823459D-06 /
      data fpp( 2,18, 2,1),fpp( 2,18, 2,2),fpp( 2,18, 2,3)/
     x-3.2178064D-01,-5.5826098D-04, 4.2254696D-06 /
      data fpp( 2,18, 3,1),fpp( 2,18, 3,2),fpp( 2,18, 3,3)/
     x-2.2527402D-01,-5.6986700D-04, 1.7251801D-05 /
      data fpp( 2,18, 4,1),fpp( 2,18, 4,2),fpp( 2,18, 4,3)/
     x-3.2178064D-01,-5.5826098D-04, 1.7263326D-05 /
      data fpp( 2,18, 5,1),fpp( 2,18, 5,2),fpp( 2,18, 5,3)/
     x-6.6073109D-01,-3.9155651D-04,-5.7233773D-05 /
      data fpp( 2,18, 6,1),fpp( 2,18, 6,2),fpp( 2,18, 6,3)/
     x-2.5200382D-01, 4.9797161D-05, 2.2511008D-06 /
      data fpp( 2,18, 7,1),fpp( 2,18, 7,2),fpp( 2,18, 7,3)/
     x-1.0296858D-01, 7.7910066D-05, 5.3120370D-06 /
      data fpp( 2,18, 8,1),fpp( 2,18, 8,2),fpp( 2,18, 8,3)/
     x-6.2280845D-02, 8.1181064D-05, 1.5888085D-05 /
      data fpp( 2,18, 9,1),fpp( 2,18, 9,2),fpp( 2,18, 9,3)/
     x-5.2732385D-02, 8.7910511D-05, 1.7959624D-05 /
      data fpp( 2,18,10,1),fpp( 2,18,10,2),fpp( 2,18,10,3)/
     x-6.2280845D-02, 8.1181064D-05, 1.5888085D-05 /
      data fpp( 2,18,11,1),fpp( 2,18,11,2),fpp( 2,18,11,3)/
     x-1.0296858D-01, 7.7910066D-05, 5.3120370D-06 /
      data fpp( 2,18,12,1),fpp( 2,18,12,2),fpp( 2,18,12,3)/
     x-2.5200382D-01, 4.9797161D-05, 2.2511008D-06 /
      data fpp( 2,18,13,1),fpp( 2,18,13,2),fpp( 2,18,13,3)/
     x-6.6073109D-01,-3.9155651D-04,-5.7233773D-05 /
      data fpp( 2,18,14,1),fpp( 2,18,14,2),fpp( 2,18,14,3)/
     x-3.2178064D-01,-5.5826098D-04, 1.7263326D-05 /
      data fpp( 2,18,15,1),fpp( 2,18,15,2),fpp( 2,18,15,3)/
     x-2.2527402D-01,-5.6986700D-04, 1.7251801D-05 /
      data fpp( 2,18,16,1),fpp( 2,18,16,2),fpp( 2,18,16,3)/
     x-3.2178064D-01,-5.5826098D-04, 4.2254696D-06 /
      data fpp( 2,18,17,1),fpp( 2,18,17,2),fpp( 2,18,17,3)/
     x-6.6073109D-01,-3.9155651D-04,-5.0823459D-06 /
      data fpp( 2,19, 1,1),fpp( 2,19, 1,2),fpp( 2,19, 1,3)/
     x-2.0052539D-01,-7.2062175D-04,-5.3840039D-20 /
      data fpp( 2,19, 2,1),fpp( 2,19, 2,2),fpp( 2,19, 2,3)/
     x-2.0052539D-01,-1.0793060D-03, 7.4152693D-20 /
      data fpp( 2,19, 3,1),fpp( 2,19, 3,2),fpp( 2,19, 3,3)/
     x-2.0052539D-01,-1.1301310D-03, 5.4310321D-20 /
      data fpp( 2,19, 4,1),fpp( 2,19, 4,2),fpp( 2,19, 4,3)/
     x-2.0052539D-01,-1.0793060D-03,-1.0514932D-20 /
      data fpp( 2,19, 5,1),fpp( 2,19, 5,2),fpp( 2,19, 5,3)/
     x-2.0052539D-01,-7.2062175D-04, 3.8300035D-21 /
      data fpp( 2,19, 6,1),fpp( 2,19, 6,2),fpp( 2,19, 6,3)/
     x-2.0052539D-01, 1.7855419D-05, 2.4013136D-20 /
      data fpp( 2,19, 7,1),fpp( 2,19, 7,2),fpp( 2,19, 7,3)/
     x-2.0052539D-01, 9.7753467D-05, 2.8662665D-20 /
      data fpp( 2,19, 8,1),fpp( 2,19, 8,2),fpp( 2,19, 8,3)/
     x-2.0052539D-01, 3.7972968D-05,-2.5125017D-20 /
      data fpp( 2,19, 9,1),fpp( 2,19, 9,2),fpp( 2,19, 9,3)/
     x-2.0052539D-01, 2.2756745D-05,-2.5197347D-20 /
      data fpp( 2,19,10,1),fpp( 2,19,10,2),fpp( 2,19,10,3)/
     x-2.0052539D-01, 3.7972968D-05, 1.5474092D-20 /
      data fpp( 2,19,11,1),fpp( 2,19,11,2),fpp( 2,19,11,3)/
     x-2.0052539D-01, 9.7753467D-05,-1.2421540D-20 /
      data fpp( 2,19,12,1),fpp( 2,19,12,2),fpp( 2,19,12,3)/
     x-2.0052539D-01, 1.7855419D-05, 1.6724446D-20 /
      data fpp( 2,19,13,1),fpp( 2,19,13,2),fpp( 2,19,13,3)/
     x-2.0052539D-01,-7.2062175D-04,-1.6410310D-20 /
      data fpp( 2,19,14,1),fpp( 2,19,14,2),fpp( 2,19,14,3)/
     x-2.0052539D-01,-1.0793060D-03,-7.6169187D-21 /
      data fpp( 2,19,15,1),fpp( 2,19,15,2),fpp( 2,19,15,3)/
     x-2.0052539D-01,-1.1301310D-03,-2.2794301D-20 /
      data fpp( 2,19,16,1),fpp( 2,19,16,2),fpp( 2,19,16,3)/
     x-2.0052539D-01,-1.0793060D-03,-7.8671695D-22 /
      data fpp( 2,19,17,1),fpp( 2,19,17,2),fpp( 2,19,17,3)/
     x-2.0052539D-01,-7.2062175D-04,-3.5716482D-22 /
      data fpp( 3, 1, 1,1),fpp( 3, 1, 1,2),fpp( 3, 1, 1,3)/
     x 7.1484387D-02, 3.8665492D-06,-4.0239417D-20 /
      data fpp( 3, 1, 2,1),fpp( 3, 1, 2,2),fpp( 3, 1, 2,3)/
     x 7.1484387D-02,-8.4151235D-05, 4.5328244D-20 /
      data fpp( 3, 1, 3,1),fpp( 3, 1, 3,2),fpp( 3, 1, 3,3)/
     x 7.1484387D-02,-1.4729048D-04, 3.4558751D-20 /
      data fpp( 3, 1, 4,1),fpp( 3, 1, 4,2),fpp( 3, 1, 4,3)/
     x 7.1484387D-02,-8.4151235D-05, 1.4532185D-21 /
      data fpp( 3, 1, 5,1),fpp( 3, 1, 5,2),fpp( 3, 1, 5,3)/
     x 7.1484387D-02, 3.8665492D-06, 7.7400737D-21 /
      data fpp( 3, 1, 6,1),fpp( 3, 1, 6,2),fpp( 3, 1, 6,3)/
     x 7.1484387D-02, 4.3582049D-05, 2.1742286D-20 /
      data fpp( 3, 1, 7,1),fpp( 3, 1, 7,2),fpp( 3, 1, 7,3)/
     x 7.1484387D-02,-1.6570813D-05, 1.7913425D-20 /
      data fpp( 3, 1, 8,1),fpp( 3, 1, 8,2),fpp( 3, 1, 8,3)/
     x 7.1484387D-02,-6.0674946D-05,-3.2365398D-20 /
      data fpp( 3, 1, 9,1),fpp( 3, 1, 9,2),fpp( 3, 1, 9,3)/
     x 7.1484387D-02,-8.2947873D-05,-1.3470073D-20 /
      data fpp( 3, 1,10,1),fpp( 3, 1,10,2),fpp( 3, 1,10,3)/
     x 7.1484387D-02,-6.0674946D-05, 2.2311318D-20 /
      data fpp( 3, 1,11,1),fpp( 3, 1,11,2),fpp( 3, 1,11,3)/
     x 7.1484387D-02,-1.6570813D-05,-1.8465217D-20 /
      data fpp( 3, 1,12,1),fpp( 3, 1,12,2),fpp( 3, 1,12,3)/
     x 7.1484387D-02, 4.3582049D-05, 3.2329080D-22 /
      data fpp( 3, 1,13,1),fpp( 3, 1,13,2),fpp( 3, 1,13,3)/
     x 7.1484387D-02, 3.8665492D-06,-1.2108805D-20 /
      data fpp( 3, 1,14,1),fpp( 3, 1,14,2),fpp( 3, 1,14,3)/
     x 7.1484387D-02,-8.4151235D-05,-1.8265780D-20 /
      data fpp( 3, 1,15,1),fpp( 3, 1,15,2),fpp( 3, 1,15,3)/
     x 7.1484387D-02,-1.4729048D-04,-4.2663016D-21 /
      data fpp( 3, 1,16,1),fpp( 3, 1,16,2),fpp( 3, 1,16,3)/
     x 7.1484387D-02,-8.4151235D-05,-9.8097924D-21 /
      data fpp( 3, 1,17,1),fpp( 3, 1,17,2),fpp( 3, 1,17,3)/
     x 7.1484387D-02, 3.8665492D-06, 3.4162553D-20 /
      data fpp( 3, 2, 1,1),fpp( 3, 2, 1,2),fpp( 3, 2, 1,3)/
     x 6.7002736D-02,-8.5790985D-06, 5.5711626D-07 /
      data fpp( 3, 2, 2,1),fpp( 3, 2, 2,2),fpp( 3, 2, 2,3)/
     x 5.9253853D-02,-4.2785530D-05, 1.9787675D-06 /
      data fpp( 3, 2, 3,1),fpp( 3, 2, 3,2),fpp( 3, 2, 3,3)/
     x 5.6094780D-02,-5.9459035D-05, 4.9364805D-06 /
      data fpp( 3, 2, 4,1),fpp( 3, 2, 4,2),fpp( 3, 2, 4,3)/
     x 5.9253853D-02,-4.2785530D-05, 2.5179774D-06 /
      data fpp( 3, 2, 5,1),fpp( 3, 2, 5,2),fpp( 3, 2, 5,3)/
     x 6.7002736D-02,-8.5790985D-06,-1.5997232D-06 /
      data fpp( 3, 2, 6,1),fpp( 3, 2, 6,2),fpp( 3, 2, 6,3)/
     x 7.3425340D-02, 3.3819016D-06,-3.5517512D-06 /
      data fpp( 3, 2, 7,1),fpp( 3, 2, 7,2),fpp( 3, 2, 7,3)/
     x 7.3884995D-02,-1.0132375D-05,-1.8352721D-06 /
      data fpp( 3, 2, 8,1),fpp( 3, 2, 8,2),fpp( 3, 2, 8,3)/
     x 7.0826609D-02,-3.8221108D-05, 9.7217299D-07 /
      data fpp( 3, 2, 9,1),fpp( 3, 2, 9,2),fpp( 3, 2, 9,3)/
     x 6.9183857D-02,-4.8294255D-05, 2.1465802D-06 /
      data fpp( 3, 2,10,1),fpp( 3, 2,10,2),fpp( 3, 2,10,3)/
     x 7.0826609D-02,-3.8221108D-05, 9.7217299D-07 /
      data fpp( 3, 2,11,1),fpp( 3, 2,11,2),fpp( 3, 2,11,3)/
     x 7.3884995D-02,-1.0132375D-05,-1.8352721D-06 /
      data fpp( 3, 2,12,1),fpp( 3, 2,12,2),fpp( 3, 2,12,3)/
     x 7.3425340D-02, 3.3819016D-06,-3.5517512D-06 /
      data fpp( 3, 2,13,1),fpp( 3, 2,13,2),fpp( 3, 2,13,3)/
     x 6.7002736D-02,-8.5790985D-06,-1.5997232D-06 /
      data fpp( 3, 2,14,1),fpp( 3, 2,14,2),fpp( 3, 2,14,3)/
     x 5.9253853D-02,-4.2785530D-05, 2.5179774D-06 /
      data fpp( 3, 2,15,1),fpp( 3, 2,15,2),fpp( 3, 2,15,3)/
     x 5.6094780D-02,-5.9459035D-05, 4.9364805D-06 /
      data fpp( 3, 2,16,1),fpp( 3, 2,16,2),fpp( 3, 2,16,3)/
     x 5.9253853D-02,-4.2785530D-05, 1.9787675D-06 /
      data fpp( 3, 2,17,1),fpp( 3, 2,17,2),fpp( 3, 2,17,3)/
     x 6.7002736D-02,-8.5790985D-06, 5.5711626D-07 /
      data fpp( 3, 3, 1,1),fpp( 3, 3, 1,2),fpp( 3, 3, 1,3)/
     x 6.2440715D-02,-2.3694155D-05, 2.6179435D-07 /
      data fpp( 3, 3, 2,1),fpp( 3, 3, 2,2),fpp( 3, 3, 2,3)/
     x 4.6395960D-02,-5.4664589D-07, 5.1739668D-06 /
      data fpp( 3, 3, 3,1),fpp( 3, 3, 3,2),fpp( 3, 3, 3,3)/
     x 4.6084703D-02, 1.4302623D-05, 1.5494338D-05 /
      data fpp( 3, 3, 4,1),fpp( 3, 3, 4,2),fpp( 3, 3, 4,3)/
     x 4.6395960D-02,-5.4664589D-07, 6.8860135D-06 /
      data fpp( 3, 3, 5,1),fpp( 3, 3, 5,2),fpp( 3, 3, 5,3)/
     x 6.2440715D-02,-2.3694155D-05,-6.5863922D-06 /
      data fpp( 3, 3, 6,1),fpp( 3, 3, 6,2),fpp( 3, 3, 6,3)/
     x 7.7584796D-02,-4.6177656D-05,-1.0585778D-05 /
      data fpp( 3, 3, 7,1),fpp( 3, 3, 7,2),fpp( 3, 3, 7,3)/
     x 7.6940195D-02,-2.9059688D-05,-4.3731623D-06 /
      data fpp( 3, 3, 8,1),fpp( 3, 3, 8,2),fpp( 3, 3, 8,3)/
     x 6.3997617D-02,-9.1666223D-06, 3.8510940D-06 /
      data fpp( 3, 3, 9,1),fpp( 3, 3, 9,2),fpp( 3, 3, 9,3)/
     x 5.9023255D-02,-1.8191082D-06, 6.4074530D-06 /
      data fpp( 3, 3,10,1),fpp( 3, 3,10,2),fpp( 3, 3,10,3)/
     x 6.3997617D-02,-9.1666223D-06, 3.8510940D-06 /
      data fpp( 3, 3,11,1),fpp( 3, 3,11,2),fpp( 3, 3,11,3)/
     x 7.6940195D-02,-2.9059688D-05,-4.3731623D-06 /
      data fpp( 3, 3,12,1),fpp( 3, 3,12,2),fpp( 3, 3,12,3)/
     x 7.7584796D-02,-4.6177656D-05,-1.0585778D-05 /
      data fpp( 3, 3,13,1),fpp( 3, 3,13,2),fpp( 3, 3,13,3)/
     x 6.2440715D-02,-2.3694155D-05,-6.5863922D-06 /
      data fpp( 3, 3,14,1),fpp( 3, 3,14,2),fpp( 3, 3,14,3)/
     x 4.6395960D-02,-5.4664589D-07, 6.8860135D-06 /
      data fpp( 3, 3,15,1),fpp( 3, 3,15,2),fpp( 3, 3,15,3)/
     x 4.6084703D-02, 1.4302623D-05, 1.5494338D-05 /
      data fpp( 3, 3,16,1),fpp( 3, 3,16,2),fpp( 3, 3,16,3)/
     x 4.6395960D-02,-5.4664589D-07, 5.1739668D-06 /
      data fpp( 3, 3,17,1),fpp( 3, 3,17,2),fpp( 3, 3,17,3)/
     x 6.2440715D-02,-2.3694155D-05, 2.6179435D-07 /
      data fpp( 3, 4, 1,1),fpp( 3, 4, 1,2),fpp( 3, 4, 1,3)/
     x 5.7234611D-02,-2.9466280D-05, 5.2105999D-06 /
      data fpp( 3, 4, 2,1),fpp( 3, 4, 2,2),fpp( 3, 4, 2,3)/
     x 5.0235059D-02, 3.8636113D-05, 9.7352447D-06 /
      data fpp( 3, 4, 3,1),fpp( 3, 4, 3,2),fpp( 3, 4, 3,3)/
     x 1.0780071D-01, 1.3730854D-04, 1.7000421D-05 /
      data fpp( 3, 4, 4,1),fpp( 3, 4, 4,2),fpp( 3, 4, 4,3)/
     x 5.0235059D-02, 3.8636113D-05, 1.4673737D-05 /
      data fpp( 3, 4, 5,1),fpp( 3, 4, 5,2),fpp( 3, 4, 5,3)/
     x 5.7234611D-02,-2.9466280D-05,-1.4543370D-05 /
      data fpp( 3, 4, 6,1),fpp( 3, 4, 6,2),fpp( 3, 4, 6,3)/
     x 7.7623063D-02,-6.2979279D-05,-7.4915916D-06 /
      data fpp( 3, 4, 7,1),fpp( 3, 4, 7,2),fpp( 3, 4, 7,3)/
     x 1.2483653D-01, 4.0793126D-05,-1.4429597D-05 /
      data fpp( 3, 4, 8,1),fpp( 3, 4, 8,2),fpp( 3, 4, 8,3)/
     x 6.5671936D-02,-3.2144030D-06, 9.8699801D-06 /
      data fpp( 3, 4, 9,1),fpp( 3, 4, 9,2),fpp( 3, 4, 9,3)/
     x 5.2757925D-02, 3.2806876D-06, 7.6643433D-06 /
      data fpp( 3, 4,10,1),fpp( 3, 4,10,2),fpp( 3, 4,10,3)/
     x 6.5671936D-02,-3.2144030D-06, 9.8699801D-06 /
      data fpp( 3, 4,11,1),fpp( 3, 4,11,2),fpp( 3, 4,11,3)/
     x 1.2483653D-01, 4.0793126D-05,-1.4429597D-05 /
      data fpp( 3, 4,12,1),fpp( 3, 4,12,2),fpp( 3, 4,12,3)/
     x 7.7623063D-02,-6.2979279D-05,-7.4915916D-06 /
      data fpp( 3, 4,13,1),fpp( 3, 4,13,2),fpp( 3, 4,13,3)/
     x 5.7234611D-02,-2.9466280D-05,-1.4543370D-05 /
      data fpp( 3, 4,14,1),fpp( 3, 4,14,2),fpp( 3, 4,14,3)/
     x 5.0235059D-02, 3.8636113D-05, 1.4673737D-05 /
      data fpp( 3, 4,15,1),fpp( 3, 4,15,2),fpp( 3, 4,15,3)/
     x 1.0780071D-01, 1.3730854D-04, 1.7000421D-05 /
      data fpp( 3, 4,16,1),fpp( 3, 4,16,2),fpp( 3, 4,16,3)/
     x 5.0235059D-02, 3.8636113D-05, 9.7352447D-06 /
      data fpp( 3, 4,17,1),fpp( 3, 4,17,2),fpp( 3, 4,17,3)/
     x 5.7234611D-02,-2.9466280D-05, 5.2105999D-06 /
      data fpp( 3, 5, 1,1),fpp( 3, 5, 1,2),fpp( 3, 5, 1,3)/
     x 4.7299290D-02,-7.8347241D-06, 1.9086639D-05 /
      data fpp( 3, 5, 2,1),fpp( 3, 5, 2,2),fpp( 3, 5, 2,3)/
     x 5.8104185D-02, 4.1896193D-05, 1.5548944D-05 /
      data fpp( 3, 5, 3,1),fpp( 3, 5, 3,2),fpp( 3, 5, 3,3)/
     x 2.2947757D-01,-6.1174800D-05, 2.5625248D-07 /
      data fpp( 3, 5, 4,1),fpp( 3, 5, 4,2),fpp( 3, 5, 4,3)/
     x 5.8104185D-02, 4.1896193D-05, 2.6106046D-05 /
      data fpp( 3, 5, 5,1),fpp( 3, 5, 5,2),fpp( 3, 5, 5,3)/
     x 4.7299290D-02,-7.8347241D-06,-2.3141771D-05 /
      data fpp( 3, 5, 6,1),fpp( 3, 5, 6,2),fpp( 3, 5, 6,3)/
     x 6.8824791D-02,-2.4807228D-05, 1.3610372D-05 /
      data fpp( 3, 5, 7,1),fpp( 3, 5, 7,2),fpp( 3, 5, 7,3)/
     x 2.3462963D-01,-1.3319482D-04,-4.0617049D-05 /
      data fpp( 3, 5, 8,1),fpp( 3, 5, 8,2),fpp( 3, 5, 8,3)/
     x 6.7645330D-02,-3.8297658D-06, 2.3450490D-05 /
      data fpp( 3, 5, 9,1),fpp( 3, 5, 9,2),fpp( 3, 5, 9,3)/
     x 4.6099251D-02, 7.0023576D-06, 2.6870883D-06 /
      data fpp( 3, 5,10,1),fpp( 3, 5,10,2),fpp( 3, 5,10,3)/
     x 6.7645330D-02,-3.8297658D-06, 2.3450490D-05 /
      data fpp( 3, 5,11,1),fpp( 3, 5,11,2),fpp( 3, 5,11,3)/
     x 2.3462963D-01,-1.3319482D-04,-4.0617049D-05 /
      data fpp( 3, 5,12,1),fpp( 3, 5,12,2),fpp( 3, 5,12,3)/
     x 6.8824791D-02,-2.4807228D-05, 1.3610372D-05 /
      data fpp( 3, 5,13,1),fpp( 3, 5,13,2),fpp( 3, 5,13,3)/
     x 4.7299290D-02,-7.8347241D-06,-2.3141771D-05 /
      data fpp( 3, 5,14,1),fpp( 3, 5,14,2),fpp( 3, 5,14,3)/
     x 5.8104185D-02, 4.1896193D-05, 2.6106046D-05 /
      data fpp( 3, 5,15,1),fpp( 3, 5,15,2),fpp( 3, 5,15,3)/
     x 2.2947757D-01,-6.1174800D-05, 2.5625248D-07 /
      data fpp( 3, 5,16,1),fpp( 3, 5,16,2),fpp( 3, 5,16,3)/
     x 5.8104185D-02, 4.1896193D-05, 1.5548944D-05 /
      data fpp( 3, 5,17,1),fpp( 3, 5,17,2),fpp( 3, 5,17,3)/
     x 4.7299290D-02,-7.8347241D-06, 1.9086639D-05 /
      data fpp( 3, 6, 1,1),fpp( 3, 6, 1,2),fpp( 3, 6, 1,3)/
     x 3.4507395D-02, 1.2037177D-05, 1.5227033D-06 /
      data fpp( 3, 6, 2,1),fpp( 3, 6, 2,2),fpp( 3, 6, 2,3)/
     x 4.6017023D-02, 4.1975116D-05, 5.3519268D-06 /
      data fpp( 3, 6, 3,1),fpp( 3, 6, 3,2),fpp( 3, 6, 3,3)/
     x 1.8486948D-01, 4.7222655D-05, 1.1736256D-05 /
      data fpp( 3, 6, 4,1),fpp( 3, 6, 4,2),fpp( 3, 6, 4,3)/
     x 4.6017023D-02, 4.1975116D-05, 9.1777147D-06 /
      data fpp( 3, 6, 5,1),fpp( 3, 6, 5,2),fpp( 3, 6, 5,3)/
     x 3.4507395D-02, 1.2037177D-05,-1.3780448D-05 /
      data fpp( 3, 6, 6,1),fpp( 3, 6, 6,2),fpp( 3, 6, 6,3)/
     x 4.5687026D-02, 2.1898192D-05, 1.4058746D-05 /
      data fpp( 3, 6, 7,1),fpp( 3, 6, 7,2),fpp( 3, 6, 7,3)/
     x 1.8560175D-01,-8.5638572D-06,-3.2005201D-05 /
      data fpp( 3, 6, 8,1),fpp( 3, 6, 8,2),fpp( 3, 6, 8,3)/
     x 5.0102680D-02, 1.2161466D-05, 1.3422724D-05 /
      data fpp( 3, 6, 9,1),fpp( 3, 6, 9,2),fpp( 3, 6, 9,3)/
     x 3.6071190D-02, 4.8118819D-06, 7.1543047D-06 /
      data fpp( 3, 6,10,1),fpp( 3, 6,10,2),fpp( 3, 6,10,3)/
     x 5.0102680D-02, 1.2161466D-05, 1.3422724D-05 /
      data fpp( 3, 6,11,1),fpp( 3, 6,11,2),fpp( 3, 6,11,3)/
     x 1.8560175D-01,-8.5638572D-06,-3.2005201D-05 /
      data fpp( 3, 6,12,1),fpp( 3, 6,12,2),fpp( 3, 6,12,3)/
     x 4.5687026D-02, 2.1898192D-05, 1.4058746D-05 /
      data fpp( 3, 6,13,1),fpp( 3, 6,13,2),fpp( 3, 6,13,3)/
     x 3.4507395D-02, 1.2037177D-05,-1.3780448D-05 /
      data fpp( 3, 6,14,1),fpp( 3, 6,14,2),fpp( 3, 6,14,3)/
     x 4.6017023D-02, 4.1975116D-05, 9.1777147D-06 /
      data fpp( 3, 6,15,1),fpp( 3, 6,15,2),fpp( 3, 6,15,3)/
     x 1.8486948D-01, 4.7222655D-05, 1.1736256D-05 /
      data fpp( 3, 6,16,1),fpp( 3, 6,16,2),fpp( 3, 6,16,3)/
     x 4.6017023D-02, 4.1975116D-05, 5.3519268D-06 /
      data fpp( 3, 6,17,1),fpp( 3, 6,17,2),fpp( 3, 6,17,3)/
     x 3.4507395D-02, 1.2037177D-05, 1.5227033D-06 /
      data fpp( 3, 7, 1,1),fpp( 3, 7, 1,2),fpp( 3, 7, 1,3)/
     x 2.3937844D-02, 1.7034018D-05,-1.9091310D-05 /
      data fpp( 3, 7, 2,1),fpp( 3, 7, 2,2),fpp( 3, 7, 2,3)/
     x 3.0103203D-02,-9.7566571D-06,-7.4271578D-06 /
      data fpp( 3, 7, 3,1),fpp( 3, 7, 3,2),fpp( 3, 7, 3,3)/
     x 7.0045943D-02, 9.9504181D-05, 2.3759941D-05 /
      data fpp( 3, 7, 4,1),fpp( 3, 7, 4,2),fpp( 3, 7, 4,3)/
     x 3.0103203D-02,-9.7566571D-06,-1.3383273D-05 /
      data fpp( 3, 7, 5,1),fpp( 3, 7, 5,2),fpp( 3, 7, 5,3)/
     x 2.3937844D-02, 1.7034018D-05, 4.7331515D-06 /
      data fpp( 3, 7, 6,1),fpp( 3, 7, 6,2),fpp( 3, 7, 6,3)/
     x 2.6024784D-02, 2.8888461D-05, 3.1993340D-06 /
      data fpp( 3, 7, 7,1),fpp( 3, 7, 7,2),fpp( 3, 7, 7,3)/
     x 6.6557708D-02, 8.6132246D-05,-1.0349821D-05 /
      data fpp( 3, 7, 8,1),fpp( 3, 7, 8,2),fpp( 3, 7, 8,3)/
     x 3.0682299D-02,-7.0580989D-06,-5.0193846D-06 /
      data fpp( 3, 7, 9,1),fpp( 3, 7, 9,2),fpp( 3, 7, 9,3)/
     x 2.5471395D-02,-7.5478852D-06, 1.6887359D-05 /
      data fpp( 3, 7,10,1),fpp( 3, 7,10,2),fpp( 3, 7,10,3)/
     x 3.0682299D-02,-7.0580989D-06,-5.0193846D-06 /
      data fpp( 3, 7,11,1),fpp( 3, 7,11,2),fpp( 3, 7,11,3)/
     x 6.6557708D-02, 8.6132246D-05,-1.0349821D-05 /
      data fpp( 3, 7,12,1),fpp( 3, 7,12,2),fpp( 3, 7,12,3)/
     x 2.6024784D-02, 2.8888461D-05, 3.1993340D-06 /
      data fpp( 3, 7,13,1),fpp( 3, 7,13,2),fpp( 3, 7,13,3)/
     x 2.3937844D-02, 1.7034018D-05, 4.7331515D-06 /
      data fpp( 3, 7,14,1),fpp( 3, 7,14,2),fpp( 3, 7,14,3)/
     x 3.0103203D-02,-9.7566571D-06,-1.3383273D-05 /
      data fpp( 3, 7,15,1),fpp( 3, 7,15,2),fpp( 3, 7,15,3)/
     x 7.0045943D-02, 9.9504181D-05, 2.3759941D-05 /
      data fpp( 3, 7,16,1),fpp( 3, 7,16,2),fpp( 3, 7,16,3)/
     x 3.0103203D-02,-9.7566571D-06,-7.4271578D-06 /
      data fpp( 3, 7,17,1),fpp( 3, 7,17,2),fpp( 3, 7,17,3)/
     x 2.3937844D-02, 1.7034018D-05,-1.9091310D-05 /
      data fpp( 3, 8, 1,1),fpp( 3, 8, 1,2),fpp( 3, 8, 1,3)/
     x 1.6540712D-02, 1.5052752D-05,-7.7097473D-06 /
      data fpp( 3, 8, 2,1),fpp( 3, 8, 2,2),fpp( 3, 8, 2,3)/
     x 2.1360666D-02,-4.9694488D-05,-5.2758388D-06 /
      data fpp( 3, 8, 3,1),fpp( 3, 8, 3,2),fpp( 3, 8, 3,3)/
     x 2.7618834D-02,-9.7329380D-05, 3.6917690D-06 /
      data fpp( 3, 8, 4,1),fpp( 3, 8, 4,2),fpp( 3, 8, 4,3)/
     x 2.1360666D-02,-4.9694488D-05,-1.0208571D-05 /
      data fpp( 3, 8, 5,1),fpp( 3, 8, 5,2),fpp( 3, 8, 5,3)/
     x 1.6540712D-02, 1.5052752D-05, 1.2021181D-05 /
      data fpp( 3, 8, 6,1),fpp( 3, 8, 6,2),fpp( 3, 8, 6,3)/
     x 1.7831242D-02, 2.5885962D-05, 3.2998485D-06 /
      data fpp( 3, 8, 7,1),fpp( 3, 8, 7,2),fpp( 3, 8, 7,3)/
     x 2.4666604D-02,-7.6211274D-06,-1.0542575D-05 /
      data fpp( 3, 8, 8,1),fpp( 3, 8, 8,2),fpp( 3, 8, 8,3)/
     x 1.8745287D-02,-2.1279071D-05,-5.9955501D-06 /
      data fpp( 3, 8, 9,1),fpp( 3, 8, 9,2),fpp( 3, 8, 9,3)/
     x 1.4746117D-02,-2.0070341D-05, 1.8337442D-05 /
      data fpp( 3, 8,10,1),fpp( 3, 8,10,2),fpp( 3, 8,10,3)/
     x 1.8745287D-02,-2.1279071D-05,-5.9955501D-06 /
      data fpp( 3, 8,11,1),fpp( 3, 8,11,2),fpp( 3, 8,11,3)/
     x 2.4666604D-02,-7.6211274D-06,-1.0542575D-05 /
      data fpp( 3, 8,12,1),fpp( 3, 8,12,2),fpp( 3, 8,12,3)/
     x 1.7831242D-02, 2.5885962D-05, 3.2998485D-06 /
      data fpp( 3, 8,13,1),fpp( 3, 8,13,2),fpp( 3, 8,13,3)/
     x 1.6540712D-02, 1.5052752D-05, 1.2021181D-05 /
      data fpp( 3, 8,14,1),fpp( 3, 8,14,2),fpp( 3, 8,14,3)/
     x 2.1360666D-02,-4.9694488D-05,-1.0208571D-05 /
      data fpp( 3, 8,15,1),fpp( 3, 8,15,2),fpp( 3, 8,15,3)/
     x 2.7618834D-02,-9.7329380D-05, 3.6917690D-06 /
      data fpp( 3, 8,16,1),fpp( 3, 8,16,2),fpp( 3, 8,16,3)/
     x 2.1360666D-02,-4.9694488D-05,-5.2758388D-06 /
      data fpp( 3, 8,17,1),fpp( 3, 8,17,2),fpp( 3, 8,17,3)/
     x 1.6540712D-02, 1.5052752D-05,-7.7097473D-06 /
      data fpp( 3, 9, 1,1),fpp( 3, 9, 1,2),fpp( 3, 9, 1,3)/
     x 1.1296443D-02, 1.3162974D-05, 5.8162122D-06 /
      data fpp( 3, 9, 2,1),fpp( 3, 9, 2,2),fpp( 3, 9, 2,3)/
     x 1.2802892D-02,-3.8563393D-05, 4.9624235D-07 /
      data fpp( 3, 9, 3,1),fpp( 3, 9, 3,2),fpp( 3, 9, 3,3)/
     x 1.5852190D-02,-9.7330662D-05,-1.1063848D-05 /
      data fpp( 3, 9, 4,1),fpp( 3, 9, 4,2),fpp( 3, 9, 4,3)/
     x 1.2802892D-02,-3.8563393D-05,-7.8351612D-07 /
      data fpp( 3, 9, 5,1),fpp( 3, 9, 5,2),fpp( 3, 9, 5,3)/
     x 1.1296443D-02, 1.3162974D-05, 1.0935246D-05 /
      data fpp( 3, 9, 6,1),fpp( 3, 9, 6,2),fpp( 3, 9, 6,3)/
     x 1.5345319D-02, 3.0251689D-05, 1.1758653D-06 /
      data fpp( 3, 9, 7,1),fpp( 3, 9, 7,2),fpp( 3, 9, 7,3)/
     x 1.6355680D-02, 4.2826356D-07,-1.3339374D-05 /
      data fpp( 3, 9, 8,1),fpp( 3, 9, 8,2),fpp( 3, 9, 8,3)/
     x 8.3882880D-03,-1.8669618D-05,-1.0323693D-06 /
      data fpp( 3, 9, 9,1),fpp( 3, 9, 9,2),fpp( 3, 9, 9,3)/
     x 3.2488346D-03,-2.5192750D-05, 1.6938851D-05 /
      data fpp( 3, 9,10,1),fpp( 3, 9,10,2),fpp( 3, 9,10,3)/
     x 8.3882880D-03,-1.8669618D-05,-1.0323693D-06 /
      data fpp( 3, 9,11,1),fpp( 3, 9,11,2),fpp( 3, 9,11,3)/
     x 1.6355680D-02, 4.2826356D-07,-1.3339374D-05 /
      data fpp( 3, 9,12,1),fpp( 3, 9,12,2),fpp( 3, 9,12,3)/
     x 1.5345319D-02, 3.0251689D-05, 1.1758653D-06 /
      data fpp( 3, 9,13,1),fpp( 3, 9,13,2),fpp( 3, 9,13,3)/
     x 1.1296443D-02, 1.3162974D-05, 1.0935246D-05 /
      data fpp( 3, 9,14,1),fpp( 3, 9,14,2),fpp( 3, 9,14,3)/
     x 1.2802892D-02,-3.8563393D-05,-7.8351612D-07 /
      data fpp( 3, 9,15,1),fpp( 3, 9,15,2),fpp( 3, 9,15,3)/
     x 1.5852190D-02,-9.7330662D-05,-1.1063848D-05 /
      data fpp( 3, 9,16,1),fpp( 3, 9,16,2),fpp( 3, 9,16,3)/
     x 1.2802892D-02,-3.8563393D-05, 4.9624235D-07 /
      data fpp( 3, 9,17,1),fpp( 3, 9,17,2),fpp( 3, 9,17,3)/
     x 1.1296443D-02, 1.3162974D-05, 5.8162122D-06 /
      data fpp( 3,10, 1,1),fpp( 3,10, 1,2),fpp( 3,10, 1,3)/
     x 7.4134507D-03, 1.4957354D-05, 9.4401042D-06 /
      data fpp( 3,10, 2,1),fpp( 3,10, 2,2),fpp( 3,10, 2,3)/
     x 2.2049185D-03,-1.6647942D-05, 4.3729026D-06 /
      data fpp( 3,10, 3,1),fpp( 3,10, 3,2),fpp( 3,10, 3,3)/
     x 1.5384141D-03,-3.2617971D-05,-7.8263815D-06 /
      data fpp( 3,10, 4,1),fpp( 3,10, 4,2),fpp( 3,10, 4,3)/
     x 2.2049185D-03,-1.6647942D-05, 4.9366233D-06 /
      data fpp( 3,10, 5,1),fpp( 3,10, 5,2),fpp( 3,10, 5,3)/
     x 7.4134507D-03, 1.4957354D-05, 7.1852216D-06 /
      data fpp( 3,10, 6,1),fpp( 3,10, 6,2),fpp( 3,10, 6,3)/
     x 1.5328368D-02, 3.6869282D-05,-9.0488429D-06 /
      data fpp( 3,10, 7,1),fpp( 3,10, 7,2),fpp( 3,10, 7,3)/
     x 1.1159043D-02, 8.1700732D-06,-1.2469183D-05 /
      data fpp( 3,10, 8,1),fpp( 3,10, 8,2),fpp( 3,10, 8,3)/
     x-2.0400612D-03,-1.5102457D-05, 4.9389095D-06 /
      data fpp( 3,10, 9,1),fpp( 3,10, 9,2),fpp( 3,10, 9,3)/
     x-7.5892138D-03,-2.2594659D-05, 1.6834879D-05 /
      data fpp( 3,10,10,1),fpp( 3,10,10,2),fpp( 3,10,10,3)/
     x-2.0400612D-03,-1.5102457D-05, 4.9389095D-06 /
      data fpp( 3,10,11,1),fpp( 3,10,11,2),fpp( 3,10,11,3)/
     x 1.1159043D-02, 8.1700732D-06,-1.2469183D-05 /
      data fpp( 3,10,12,1),fpp( 3,10,12,2),fpp( 3,10,12,3)/
     x 1.5328368D-02, 3.6869282D-05,-9.0488429D-06 /
      data fpp( 3,10,13,1),fpp( 3,10,13,2),fpp( 3,10,13,3)/
     x 7.4134507D-03, 1.4957354D-05, 7.1852216D-06 /
      data fpp( 3,10,14,1),fpp( 3,10,14,2),fpp( 3,10,14,3)/
     x 2.2049185D-03,-1.6647942D-05, 4.9366233D-06 /
      data fpp( 3,10,15,1),fpp( 3,10,15,2),fpp( 3,10,15,3)/
     x 1.5384141D-03,-3.2617971D-05,-7.8263815D-06 /
      data fpp( 3,10,16,1),fpp( 3,10,16,2),fpp( 3,10,16,3)/
     x 2.2049185D-03,-1.6647942D-05, 4.3729026D-06 /
      data fpp( 3,10,17,1),fpp( 3,10,17,2),fpp( 3,10,17,3)/
     x 7.4134507D-03, 1.4957354D-05, 9.4401042D-06 /
      data fpp( 3,11, 1,1),fpp( 3,11, 1,2),fpp( 3,11, 1,3)/
     x 4.8801628D-03, 2.2167612D-05, 1.1486397D-05 /
      data fpp( 3,11, 2,1),fpp( 3,11, 2,2),fpp( 3,11, 2,3)/
     x-6.3603035D-03, 2.8971619D-06, 9.0292066D-06 /
      data fpp( 3,11, 3,1),fpp( 3,11, 3,2),fpp( 3,11, 3,3)/
     x-1.0027144D-02, 1.6145472D-06, 2.0354437D-06 /
      data fpp( 3,11, 4,1),fpp( 3,11, 4,2),fpp( 3,11, 4,3)/
     x-6.3603035D-03, 2.8971619D-06, 1.0919685D-05 /
      data fpp( 3,11, 5,1),fpp( 3,11, 5,2),fpp( 3,11, 5,3)/
     x 4.8801628D-03, 2.2167612D-05, 3.9244821D-06 /
      data fpp( 3,11, 6,1),fpp( 3,11, 6,2),fpp( 3,11, 6,3)/
     x 1.7680436D-02, 4.8063184D-05,-2.8914280D-05 /
      data fpp( 3,11, 7,1),fpp( 3,11, 7,2),fpp( 3,11, 7,3)/
     x 5.6786824D-03, 1.1891444D-05,-8.1280271D-06 /
      data fpp( 3,11, 8,1),fpp( 3,11, 8,2),fpp( 3,11, 8,3)/
     x-1.0647237D-02,-7.9385549D-06, 1.2086389D-05 /
      data fpp( 3,11, 9,1),fpp( 3,11, 9,2),fpp( 3,11, 9,3)/
     x-1.6012817D-02,-1.3932615D-05, 1.8503139D-05 /
      data fpp( 3,11,10,1),fpp( 3,11,10,2),fpp( 3,11,10,3)/
     x-1.0647237D-02,-7.9385549D-06, 1.2086389D-05 /
      data fpp( 3,11,11,1),fpp( 3,11,11,2),fpp( 3,11,11,3)/
     x 5.6786824D-03, 1.1891444D-05,-8.1280271D-06 /
      data fpp( 3,11,12,1),fpp( 3,11,12,2),fpp( 3,11,12,3)/
     x 1.7680436D-02, 4.8063184D-05,-2.8914280D-05 /
      data fpp( 3,11,13,1),fpp( 3,11,13,2),fpp( 3,11,13,3)/
     x 4.8801628D-03, 2.2167612D-05, 3.9244821D-06 /
      data fpp( 3,11,14,1),fpp( 3,11,14,2),fpp( 3,11,14,3)/
     x-6.3603035D-03, 2.8971619D-06, 1.0919685D-05 /
      data fpp( 3,11,15,1),fpp( 3,11,15,2),fpp( 3,11,15,3)/
     x-1.0027144D-02, 1.6145472D-06, 2.0354437D-06 /
      data fpp( 3,11,16,1),fpp( 3,11,16,2),fpp( 3,11,16,3)/
     x-6.3603035D-03, 2.8971619D-06, 9.0292066D-06 /
      data fpp( 3,11,17,1),fpp( 3,11,17,2),fpp( 3,11,17,3)/
     x 4.8801628D-03, 2.2167612D-05, 1.1486397D-05 /
      data fpp( 3,12, 1,1),fpp( 3,12, 1,2),fpp( 3,12, 1,3)/
     x 4.2710085D-03, 3.4900197D-05, 1.6403199D-05 /
      data fpp( 3,12, 2,1),fpp( 3,12, 2,2),fpp( 3,12, 2,3)/
     x-1.1300887D-02, 2.4199295D-05, 1.5700936D-05 /
      data fpp( 3,12, 3,1),fpp( 3,12, 3,2),fpp( 3,12, 3,3)/
     x-1.6405180D-02, 2.5511782D-05, 1.2031724D-05 /
      data fpp( 3,12, 4,1),fpp( 3,12, 4,2),fpp( 3,12, 4,3)/
     x-1.1300887D-02, 2.4199295D-05, 1.8746836D-05 /
      data fpp( 3,12, 5,1),fpp( 3,12, 5,2),fpp( 3,12, 5,3)/
     x 4.2710085D-03, 3.4900197D-05, 4.2195992D-06 /
      data fpp( 3,12, 6,1),fpp( 3,12, 6,2),fpp( 3,12, 6,3)/
     x 2.3466306D-02, 6.0503981D-05,-6.1323899D-05 /
      data fpp( 3,12, 7,1),fpp( 3,12, 7,2),fpp( 3,12, 7,3)/
     x 7.4223816D-04, 1.8154152D-05, 2.0746652D-06 /
      data fpp( 3,12, 8,1),fpp( 3,12, 8,2),fpp( 3,12, 8,3)/
     x-1.6829164D-02, 5.7926764D-06, 1.9529905D-05 /
      data fpp( 3,12, 9,1),fpp( 3,12, 9,2),fpp( 3,12, 9,3)/
     x-2.1895646D-02, 2.0111174D-06, 2.1981714D-05 /
      data fpp( 3,12,10,1),fpp( 3,12,10,2),fpp( 3,12,10,3)/
     x-1.6829164D-02, 5.7926764D-06, 1.9529905D-05 /
      data fpp( 3,12,11,1),fpp( 3,12,11,2),fpp( 3,12,11,3)/
     x 7.4223816D-04, 1.8154152D-05, 2.0746652D-06 /
      data fpp( 3,12,12,1),fpp( 3,12,12,2),fpp( 3,12,12,3)/
     x 2.3466306D-02, 6.0503981D-05,-6.1323899D-05 /
      data fpp( 3,12,13,1),fpp( 3,12,13,2),fpp( 3,12,13,3)/
     x 4.2710085D-03, 3.4900197D-05, 4.2195992D-06 /
      data fpp( 3,12,14,1),fpp( 3,12,14,2),fpp( 3,12,14,3)/
     x-1.1300887D-02, 2.4199295D-05, 1.8746836D-05 /
      data fpp( 3,12,15,1),fpp( 3,12,15,2),fpp( 3,12,15,3)/
     x-1.6405180D-02, 2.5511782D-05, 1.2031724D-05 /
      data fpp( 3,12,16,1),fpp( 3,12,16,2),fpp( 3,12,16,3)/
     x-1.1300887D-02, 2.4199295D-05, 1.5700936D-05 /
      data fpp( 3,12,17,1),fpp( 3,12,17,2),fpp( 3,12,17,3)/
     x 4.2710085D-03, 3.4900197D-05, 1.6403199D-05 /
      data fpp( 3,13, 1,1),fpp( 3,13, 1,2),fpp( 3,13, 1,3)/
     x 8.6178048D-03, 5.8431599D-05, 2.4247530D-05 /
      data fpp( 3,13, 2,1),fpp( 3,13, 2,2),fpp( 3,13, 2,3)/
     x-1.3740822D-02, 5.1661659D-05, 2.3993050D-05 /
      data fpp( 3,13, 3,1),fpp( 3,13, 3,2),fpp( 3,13, 3,3)/
     x-1.9540882D-02, 5.4300323D-05, 2.1002268D-05 /
      data fpp( 3,13, 4,1),fpp( 3,13, 4,2),fpp( 3,13, 4,3)/
     x-1.3740822D-02, 5.1661659D-05, 2.7588545D-05 /
      data fpp( 3,13, 5,1),fpp( 3,13, 5,2),fpp( 3,13, 5,3)/
     x 8.6178048D-03, 5.8431599D-05, 9.8655519D-06 /
      data fpp( 3,13, 6,1),fpp( 3,13, 6,2),fpp( 3,13, 6,3)/
     x 4.0864578D-02, 7.0418891D-05,-1.0821209D-04 /
      data fpp( 3,13, 7,1),fpp( 3,13, 7,2),fpp( 3,13, 7,3)/
     x-4.0150543D-03, 2.5339947D-05, 2.1402126D-05 /
      data fpp( 3,13, 8,1),fpp( 3,13, 8,2),fpp( 3,13, 8,3)/
     x-2.1313613D-02, 2.8537849D-05, 2.5460916D-05 /
      data fpp( 3,13, 9,1),fpp( 3,13, 9,2),fpp( 3,13, 9,3)/
     x-2.5924190D-02, 2.8592145D-05, 2.7386875D-05 /
      data fpp( 3,13,10,1),fpp( 3,13,10,2),fpp( 3,13,10,3)/
     x-2.1313613D-02, 2.8537849D-05, 2.5460916D-05 /
      data fpp( 3,13,11,1),fpp( 3,13,11,2),fpp( 3,13,11,3)/
     x-4.0150543D-03, 2.5339947D-05, 2.1402126D-05 /
      data fpp( 3,13,12,1),fpp( 3,13,12,2),fpp( 3,13,12,3)/
     x 4.0864578D-02, 7.0418891D-05,-1.0821209D-04 /
      data fpp( 3,13,13,1),fpp( 3,13,13,2),fpp( 3,13,13,3)/
     x 8.6178048D-03, 5.8431599D-05, 9.8655519D-06 /
      data fpp( 3,13,14,1),fpp( 3,13,14,2),fpp( 3,13,14,3)/
     x-1.3740822D-02, 5.1661659D-05, 2.7588545D-05 /
      data fpp( 3,13,15,1),fpp( 3,13,15,2),fpp( 3,13,15,3)/
     x-1.9540882D-02, 5.4300323D-05, 2.1002268D-05 /
      data fpp( 3,13,16,1),fpp( 3,13,16,2),fpp( 3,13,16,3)/
     x-1.3740822D-02, 5.1661659D-05, 2.3993050D-05 /
      data fpp( 3,13,17,1),fpp( 3,13,17,2),fpp( 3,13,17,3)/
     x 8.6178048D-03, 5.8431599D-05, 2.4247530D-05 /
      data fpp( 3,14, 1,1),fpp( 3,14, 1,2),fpp( 3,14, 1,3)/
     x 2.9590228D-02, 9.9773406D-05, 3.5397935D-05 /
      data fpp( 3,14, 2,1),fpp( 3,14, 2,2),fpp( 3,14, 2,3)/
     x-1.4952863D-02, 8.2888070D-05, 3.3998685D-05 /
      data fpp( 3,14, 3,1),fpp( 3,14, 3,2),fpp( 3,14, 3,3)/
     x-2.0768493D-02, 9.0604924D-05, 2.8062658D-05 /
      data fpp( 3,14, 4,1),fpp( 3,14, 4,2),fpp( 3,14, 4,3)/
     x-1.4952863D-02, 8.2888070D-05, 3.8005349D-05 /
      data fpp( 3,14, 5,1),fpp( 3,14, 5,2),fpp( 3,14, 5,3)/
     x 2.9590228D-02, 9.9773406D-05, 1.9371277D-05 /
      data fpp( 3,14, 6,1),fpp( 3,14, 6,2),fpp( 3,14, 6,3)/
     x 1.1313550D-01, 1.0144245D-04,-1.6983046D-04 /
      data fpp( 3,14, 7,1),fpp( 3,14, 7,2),fpp( 3,14, 7,3)/
     x-1.0357288D-02, 2.9244059D-05, 5.4669893D-05 /
      data fpp( 3,14, 8,1),fpp( 3,14, 8,2),fpp( 3,14, 8,3)/
     x-2.4817795D-02, 5.9881926D-05, 2.6575554D-05 /
      data fpp( 3,14, 9,1),fpp( 3,14, 9,2),fpp( 3,14, 9,3)/
     x-2.8586936D-02, 6.6656302D-05, 3.5021889D-05 /
      data fpp( 3,14,10,1),fpp( 3,14,10,2),fpp( 3,14,10,3)/
     x-2.4817795D-02, 5.9881926D-05, 2.6575554D-05 /
      data fpp( 3,14,11,1),fpp( 3,14,11,2),fpp( 3,14,11,3)/
     x-1.0357288D-02, 2.9244059D-05, 5.4669893D-05 /
      data fpp( 3,14,12,1),fpp( 3,14,12,2),fpp( 3,14,12,3)/
     x 1.1313550D-01, 1.0144245D-04,-1.6983046D-04 /
      data fpp( 3,14,13,1),fpp( 3,14,13,2),fpp( 3,14,13,3)/
     x 2.9590228D-02, 9.9773406D-05, 1.9371277D-05 /
      data fpp( 3,14,14,1),fpp( 3,14,14,2),fpp( 3,14,14,3)/
     x-1.4952863D-02, 8.2888070D-05, 3.8005349D-05 /
      data fpp( 3,14,15,1),fpp( 3,14,15,2),fpp( 3,14,15,3)/
     x-2.0768493D-02, 9.0604924D-05, 2.8062658D-05 /
      data fpp( 3,14,16,1),fpp( 3,14,16,2),fpp( 3,14,16,3)/
     x-1.4952863D-02, 8.2888070D-05, 3.3998685D-05 /
      data fpp( 3,14,17,1),fpp( 3,14,17,2),fpp( 3,14,17,3)/
     x 2.9590228D-02, 9.9773406D-05, 3.5397935D-05 /
      data fpp( 3,15, 1,1),fpp( 3,15, 1,2),fpp( 3,15, 1,3)/
     x 6.8634283D-02,-6.6997225D-05, 4.7004932D-05 /
      data fpp( 3,15, 2,1),fpp( 3,15, 2,2),fpp( 3,15, 2,3)/
     x-1.6286073D-02, 1.0923006D-04, 4.3568469D-05 /
      data fpp( 3,15, 3,1),fpp( 3,15, 3,2),fpp( 3,15, 3,3)/
     x-2.1229661D-02, 1.3520798D-04, 3.1695191D-05 /
      data fpp( 3,15, 4,1),fpp( 3,15, 4,2),fpp( 3,15, 4,3)/
     x-1.6286073D-02, 1.0923006D-04, 4.9350766D-05 /
      data fpp( 3,15, 5,1),fpp( 3,15, 5,2),fpp( 3,15, 5,3)/
     x 6.8634283D-02,-6.6997225D-05, 2.3875745D-05 /
      data fpp( 3,15, 6,1),fpp( 3,15, 6,2),fpp( 3,15, 6,3)/
     x 2.5337941D-01,-3.0792471D-04,-2.2574441D-04 /
      data fpp( 3,15, 7,1),fpp( 3,15, 7,2),fpp( 3,15, 7,3)/
     x-1.9337903D-02, 1.7757816D-05, 9.3907239D-05 /
      data fpp( 3,15, 8,1),fpp( 3,15, 8,2),fpp( 3,15, 8,3)/
     x-2.7942435D-02, 9.5840445D-05, 2.1665455D-05 /
      data fpp( 3,15, 9,1),fpp( 3,15, 9,2),fpp( 3,15, 9,3)/
     x-3.0098994D-02, 1.1387465D-04, 4.3158939D-05 /
      data fpp( 3,15,10,1),fpp( 3,15,10,2),fpp( 3,15,10,3)/
     x-2.7942435D-02, 9.5840445D-05, 2.1665455D-05 /
      data fpp( 3,15,11,1),fpp( 3,15,11,2),fpp( 3,15,11,3)/
     x-1.9337903D-02, 1.7757816D-05, 9.3907239D-05 /
      data fpp( 3,15,12,1),fpp( 3,15,12,2),fpp( 3,15,12,3)/
     x 2.5337941D-01,-3.0792471D-04,-2.2574441D-04 /
      data fpp( 3,15,13,1),fpp( 3,15,13,2),fpp( 3,15,13,3)/
     x 6.8634283D-02,-6.6997225D-05, 2.3875745D-05 /
      data fpp( 3,15,14,1),fpp( 3,15,14,2),fpp( 3,15,14,3)/
     x-1.6286073D-02, 1.0923006D-04, 4.9350766D-05 /
      data fpp( 3,15,15,1),fpp( 3,15,15,2),fpp( 3,15,15,3)/
     x-2.1229661D-02, 1.3520798D-04, 3.1695191D-05 /
      data fpp( 3,15,16,1),fpp( 3,15,16,2),fpp( 3,15,16,3)/
     x-1.6286073D-02, 1.0923006D-04, 4.3568469D-05 /
      data fpp( 3,15,17,1),fpp( 3,15,17,2),fpp( 3,15,17,3)/
     x 6.8634283D-02,-6.6997225D-05, 4.7004932D-05 /
      data fpp( 3,16, 1,1),fpp( 3,16, 1,2),fpp( 3,16, 1,3)/
     x-1.9723488D-03,-4.3116507D-05, 3.9631271D-05 /
      data fpp( 3,16, 2,1),fpp( 3,16, 2,2),fpp( 3,16, 2,3)/
     x-2.3309388D-02, 9.2011685D-05, 3.9711791D-05 /
      data fpp( 3,16, 3,1),fpp( 3,16, 3,2),fpp( 3,16, 3,3)/
     x-2.3602378D-02, 1.2936316D-04, 3.3106231D-05 /
      data fpp( 3,16, 4,1),fpp( 3,16, 4,2),fpp( 3,16, 4,3)/
     x-2.3309388D-02, 9.2011685D-05, 4.9901952D-05 /
      data fpp( 3,16, 5,1),fpp( 3,16, 5,2),fpp( 3,16, 5,3)/
     x-1.9723488D-03,-4.3116507D-05,-1.1293740D-06 /
      data fpp( 3,16, 6,1),fpp( 3,16, 6,2),fpp( 3,16, 6,3)/
     x-1.6593687D-01,-2.2571962D-04,-1.8854712D-04 /
      data fpp( 3,16, 7,1),fpp( 3,16, 7,2),fpp( 3,16, 7,3)/
     x-3.3853758D-02, 9.5246783D-06, 8.0255866D-05 /
      data fpp( 3,16, 8,1),fpp( 3,16, 8,2),fpp( 3,16, 8,3)/
     x-3.1251530D-02, 1.1970029D-04, 2.2684324D-05 /
      data fpp( 3,16, 9,1),fpp( 3,16, 9,2),fpp( 3,16, 9,3)/
     x-3.0959422D-02, 1.5006112D-04, 4.2260838D-05 /
      data fpp( 3,16,10,1),fpp( 3,16,10,2),fpp( 3,16,10,3)/
     x-3.1251530D-02, 1.1970029D-04, 2.2684324D-05 /
      data fpp( 3,16,11,1),fpp( 3,16,11,2),fpp( 3,16,11,3)/
     x-3.3853758D-02, 9.5246783D-06, 8.0255866D-05 /
      data fpp( 3,16,12,1),fpp( 3,16,12,2),fpp( 3,16,12,3)/
     x-1.6593687D-01,-2.2571962D-04,-1.8854712D-04 /
      data fpp( 3,16,13,1),fpp( 3,16,13,2),fpp( 3,16,13,3)/
     x-1.9723488D-03,-4.3116507D-05,-1.1293740D-06 /
      data fpp( 3,16,14,1),fpp( 3,16,14,2),fpp( 3,16,14,3)/
     x-2.3309388D-02, 9.2011685D-05, 4.9901952D-05 /
      data fpp( 3,16,15,1),fpp( 3,16,15,2),fpp( 3,16,15,3)/
     x-2.3602378D-02, 1.2936316D-04, 3.3106231D-05 /
      data fpp( 3,16,16,1),fpp( 3,16,16,2),fpp( 3,16,16,3)/
     x-2.3309388D-02, 9.2011685D-05, 3.9711791D-05 /
      data fpp( 3,16,17,1),fpp( 3,16,17,2),fpp( 3,16,17,3)/
     x-1.9723488D-03,-4.3116507D-05, 3.9631271D-05 /
      data fpp( 3,17, 1,1),fpp( 3,17, 1,2),fpp( 3,17, 1,3)/
     x-1.2310332D-01,-6.7772748D-05, 1.7868612D-05 /
      data fpp( 3,17, 2,1),fpp( 3,17, 2,2),fpp( 3,17, 2,3)/
     x-4.2969658D-02, 9.4427200D-05, 2.3519776D-05 /
      data fpp( 3,17, 3,1),fpp( 3,17, 3,2),fpp( 3,17, 3,3)/
     x-3.2832585D-02, 1.6066338D-04, 2.7434285D-05 /
      data fpp( 3,17, 4,1),fpp( 3,17, 4,2),fpp( 3,17, 4,3)/
     x-4.2969658D-02, 9.4427200D-05, 3.7427086D-05 /
      data fpp( 3,17, 5,1),fpp( 3,17, 5,2),fpp( 3,17, 5,3)/
     x-1.2310332D-01,-6.7772748D-05,-3.7760628D-05 /
      data fpp( 3,17, 6,1),fpp( 3,17, 6,2),fpp( 3,17, 6,3)/
     x-2.2859387D-01, 9.9237207D-05,-8.3529241D-05 /
      data fpp( 3,17, 7,1),fpp( 3,17, 7,2),fpp( 3,17, 7,3)/
     x-5.8692786D-02, 5.6403471D-05, 3.2298924D-05 /
      data fpp( 3,17, 8,1),fpp( 3,17, 8,2),fpp( 3,17, 8,3)/
     x-3.7471999D-02, 1.3129438D-04, 2.3088212D-05 /
      data fpp( 3,17, 9,1),fpp( 3,17, 9,2),fpp( 3,17, 9,3)/
     x-3.3984279D-02, 1.6885289D-04, 3.1834894D-05 /
      data fpp( 3,17,10,1),fpp( 3,17,10,2),fpp( 3,17,10,3)/
     x-3.7471999D-02, 1.3129438D-04, 2.3088212D-05 /
      data fpp( 3,17,11,1),fpp( 3,17,11,2),fpp( 3,17,11,3)/
     x-5.8692786D-02, 5.6403471D-05, 3.2298924D-05 /
      data fpp( 3,17,12,1),fpp( 3,17,12,2),fpp( 3,17,12,3)/
     x-2.2859387D-01, 9.9237207D-05,-8.3529241D-05 /
      data fpp( 3,17,13,1),fpp( 3,17,13,2),fpp( 3,17,13,3)/
     x-1.2310332D-01,-6.7772748D-05,-3.7760628D-05 /
      data fpp( 3,17,14,1),fpp( 3,17,14,2),fpp( 3,17,14,3)/
     x-4.2969658D-02, 9.4427200D-05, 3.7427086D-05 /
      data fpp( 3,17,15,1),fpp( 3,17,15,2),fpp( 3,17,15,3)/
     x-3.2832585D-02, 1.6066338D-04, 2.7434285D-05 /
      data fpp( 3,17,16,1),fpp( 3,17,16,2),fpp( 3,17,16,3)/
     x-4.2969658D-02, 9.4427200D-05, 2.3519776D-05 /
      data fpp( 3,17,17,1),fpp( 3,17,17,2),fpp( 3,17,17,3)/
     x-1.2310332D-01,-6.7772748D-05, 1.7868612D-05 /
      data fpp( 3,18, 1,1),fpp( 3,18, 1,2),fpp( 3,18, 1,3)/
     x 2.7600757D-01,-1.5915650D-04,-5.2160695D-06 /
      data fpp( 3,18, 2,1),fpp( 3,18, 2,2),fpp( 3,18, 2,3)/
     x 9.1492228D-02,-3.8228249D-04, 1.3876946D-06 /
      data fpp( 3,18, 3,1),fpp( 3,18, 3,2),fpp( 3,18, 3,3)/
     x 3.6625323D-02,-4.2452668D-04, 1.3427958D-05 /
      data fpp( 3,18, 4,1),fpp( 3,18, 4,2),fpp( 3,18, 4,3)/
     x 9.1492228D-02,-3.8228249D-04, 6.4404747D-06 /
      data fpp( 3,18, 5,1),fpp( 3,18, 5,2),fpp( 3,18, 5,3)/
     x 2.7600757D-01,-1.5915650D-04,-2.5427190D-05 /
      data fpp( 3,18, 6,1),fpp( 3,18, 6,2),fpp( 3,18, 6,3)/
     x-6.2897866D-02, 6.4690798D-05,-1.4737715D-05 /
      data fpp( 3,18, 7,1),fpp( 3,18, 7,2),fpp( 3,18, 7,3)/
     x-7.1492470D-02, 4.2223437D-05, 6.0780516D-06 /
      data fpp( 3,18, 8,1),fpp( 3,18, 8,2),fpp( 3,18, 8,3)/
     x-5.3260793D-02, 3.8144176D-05, 1.3242842D-05 /
      data fpp( 3,18, 9,1),fpp( 3,18, 9,2),fpp( 3,18, 9,3)/
     x-4.7970401D-02, 4.3171317D-05, 1.6221245D-05 /
      data fpp( 3,18,10,1),fpp( 3,18,10,2),fpp( 3,18,10,3)/
     x-5.3260793D-02, 3.8144176D-05, 1.3242842D-05 /
      data fpp( 3,18,11,1),fpp( 3,18,11,2),fpp( 3,18,11,3)/
     x-7.1492470D-02, 4.2223437D-05, 6.0780516D-06 /
      data fpp( 3,18,12,1),fpp( 3,18,12,2),fpp( 3,18,12,3)/
     x-6.2897866D-02, 6.4690798D-05,-1.4737715D-05 /
      data fpp( 3,18,13,1),fpp( 3,18,13,2),fpp( 3,18,13,3)/
     x 2.7600757D-01,-1.5915650D-04,-2.5427190D-05 /
      data fpp( 3,18,14,1),fpp( 3,18,14,2),fpp( 3,18,14,3)/
     x 9.1492228D-02,-3.8228249D-04, 6.4404747D-06 /
      data fpp( 3,18,15,1),fpp( 3,18,15,2),fpp( 3,18,15,3)/
     x 3.6625323D-02,-4.2452668D-04, 1.3427958D-05 /
      data fpp( 3,18,16,1),fpp( 3,18,16,2),fpp( 3,18,16,3)/
     x 9.1492228D-02,-3.8228249D-04, 1.3876946D-06 /
      data fpp( 3,18,17,1),fpp( 3,18,17,2),fpp( 3,18,17,3)/
     x 2.7600757D-01,-1.5915650D-04,-5.2160695D-06 /
      data fpp( 3,19, 1,1),fpp( 3,19, 1,2),fpp( 3,19, 1,3)/
     x-2.6577374D-02,-2.3147525D-04,-3.8286291D-20 /
      data fpp( 3,19, 2,1),fpp( 3,19, 2,2),fpp( 3,19, 2,3)/
     x-2.6577374D-02,-7.2209926D-04, 4.7787657D-20 /
      data fpp( 3,19, 3,1),fpp( 3,19, 3,2),fpp( 3,19, 3,3)/
     x-2.6577374D-02,-8.3357666D-04, 2.3621907D-20 /
      data fpp( 3,19, 4,1),fpp( 3,19, 4,2),fpp( 3,19, 4,3)/
     x-2.6577374D-02,-7.2209926D-04, 3.5127203D-21 /
      data fpp( 3,19, 5,1),fpp( 3,19, 5,2),fpp( 3,19, 5,3)/
     x-2.6577374D-02,-2.3147525D-04, 1.1163132D-20 /
      data fpp( 3,19, 6,1),fpp( 3,19, 6,2),fpp( 3,19, 6,3)/
     x-2.6577374D-02, 1.3285960D-04, 1.0823759D-20 /
      data fpp( 3,19, 7,1),fpp( 3,19, 7,2),fpp( 3,19, 7,3)/
     x-2.6577374D-02, 4.5488782D-05, 2.2547397D-20 /
      data fpp( 3,19, 8,1),fpp( 3,19, 8,2),fpp( 3,19, 8,3)/
     x-2.6577374D-02,-2.5079088D-05,-3.5874566D-20 /
      data fpp( 3,19, 9,1),fpp( 3,19, 9,2),fpp( 3,19, 9,3)/
     x-2.6577374D-02,-4.1232158D-05,-2.2036212D-20 /
      data fpp( 3,19,10,1),fpp( 3,19,10,2),fpp( 3,19,10,3)/
     x-2.6577374D-02,-2.5079088D-05, 3.3286051D-20 /
      data fpp( 3,19,11,1),fpp( 3,19,11,2),fpp( 3,19,11,3)/
     x-2.6577374D-02, 4.5488782D-05,-3.5253570D-21 /
      data fpp( 3,19,12,1),fpp( 3,19,12,2),fpp( 3,19,12,3)/
     x-2.6577374D-02, 1.3285960D-04, 7.5294078D-21 /
      data fpp( 3,19,13,1),fpp( 3,19,13,2),fpp( 3,19,13,3)/
     x-2.6577374D-02,-2.3147525D-04,-6.5592446D-21 /
      data fpp( 3,19,14,1),fpp( 3,19,14,2),fpp( 3,19,14,3)/
     x-2.6577374D-02,-7.2209926D-04,-4.4698047D-21 /
      data fpp( 3,19,15,1),fpp( 3,19,15,2),fpp( 3,19,15,3)/
     x-2.6577374D-02,-8.3357666D-04,-9.0966918D-21 /
      data fpp( 3,19,16,1),fpp( 3,19,16,2),fpp( 3,19,16,3)/
     x-2.6577374D-02,-7.2209926D-04,-1.2729562D-20 /
      data fpp( 3,19,17,1),fpp( 3,19,17,2),fpp( 3,19,17,3)/
     x-2.6577374D-02,-2.3147525D-04, 3.3228248D-20 /
      data fpp( 4, 1, 1,1),fpp( 4, 1, 1,2),fpp( 4, 1, 1,3)/
     x 5.8949775D-02, 3.0605654D-06,-7.0850400D-21 /
      data fpp( 4, 1, 2,1),fpp( 4, 1, 2,2),fpp( 4, 1, 2,3)/
     x 5.8949775D-02,-6.5119543D-05, 3.9879308D-20 /
      data fpp( 4, 1, 3,1),fpp( 4, 1, 3,2),fpp( 4, 1, 3,3)/
     x 5.8949775D-02,-1.0540554D-04, 2.6444511D-20 /
      data fpp( 4, 1, 4,1),fpp( 4, 1, 4,2),fpp( 4, 1, 4,3)/
     x 5.8949775D-02,-6.5119543D-05, 8.1587831D-21 /
      data fpp( 4, 1, 5,1),fpp( 4, 1, 5,2),fpp( 4, 1, 5,3)/
     x 5.8949775D-02, 3.0605654D-06,-1.4938682D-21 /
      data fpp( 4, 1, 6,1),fpp( 4, 1, 6,2),fpp( 4, 1, 6,3)/
     x 5.8949775D-02, 3.4483728D-05, 2.1487833D-20 /
      data fpp( 4, 1, 7,1),fpp( 4, 1, 7,2),fpp( 4, 1, 7,3)/
     x 5.8949775D-02,-8.4379568D-09, 2.5265511D-20 /
      data fpp( 4, 1, 8,1),fpp( 4, 1, 8,2),fpp( 4, 1, 8,3)/
     x 5.8949775D-02,-4.3348355D-05,-1.7632251D-20 /
      data fpp( 4, 1, 9,1),fpp( 4, 1, 9,2),fpp( 4, 1, 9,3)/
     x 5.8949775D-02,-6.2924865D-05,-1.1654838D-20 /
      data fpp( 4, 1,10,1),fpp( 4, 1,10,2),fpp( 4, 1,10,3)/
     x 5.8949775D-02,-4.3348355D-05, 2.0992008D-20 /
      data fpp( 4, 1,11,1),fpp( 4, 1,11,2),fpp( 4, 1,11,3)/
     x 5.8949775D-02,-8.4379568D-09,-9.5083172D-21 /
      data fpp( 4, 1,12,1),fpp( 4, 1,12,2),fpp( 4, 1,12,3)/
     x 5.8949775D-02, 3.4483728D-05, 8.2149517D-21 /
      data fpp( 4, 1,13,1),fpp( 4, 1,13,2),fpp( 4, 1,13,3)/
     x 5.8949775D-02, 3.0605654D-06,-2.2671298D-21 /
      data fpp( 4, 1,14,1),fpp( 4, 1,14,2),fpp( 4, 1,14,3)/
     x 5.8949775D-02,-6.5119543D-05, 4.1280650D-21 /
      data fpp( 4, 1,15,1),fpp( 4, 1,15,2),fpp( 4, 1,15,3)/
     x 5.8949775D-02,-1.0540554D-04,-7.3225243D-21 /
      data fpp( 4, 1,16,1),fpp( 4, 1,16,2),fpp( 4, 1,16,3)/
     x 5.8949775D-02,-6.5119543D-05, 5.4689716D-21 /
      data fpp( 4, 1,17,1),fpp( 4, 1,17,2),fpp( 4, 1,17,3)/
     x 5.8949775D-02, 3.0605654D-06, 2.1354743D-20 /
      data fpp( 4, 2, 1,1),fpp( 4, 2, 1,2),fpp( 4, 2, 1,3)/
     x 5.5669839D-02,-6.7101308D-06, 3.7326586D-07 /
      data fpp( 4, 2, 2,1),fpp( 4, 2, 2,2),fpp( 4, 2, 2,3)/
     x 5.0255334D-02,-3.4642914D-05, 1.4922461D-06 /
      data fpp( 4, 2, 3,1),fpp( 4, 2, 3,2),fpp( 4, 2, 3,3)/
     x 4.8019390D-02,-5.1096918D-05, 3.8344165D-06 /
      data fpp( 4, 2, 4,1),fpp( 4, 2, 4,2),fpp( 4, 2, 4,3)/
     x 5.0255334D-02,-3.4642914D-05, 1.8954211D-06 /
      data fpp( 4, 2, 5,1),fpp( 4, 2, 5,2),fpp( 4, 2, 5,3)/
     x 5.5669839D-02,-6.7101308D-06,-1.2394342D-06 /
      data fpp( 4, 2, 6,1),fpp( 4, 2, 6,2),fpp( 4, 2, 6,3)/
     x 6.0026236D-02, 3.0555435D-06,-2.6783510D-06 /
      data fpp( 4, 2, 7,1),fpp( 4, 2, 7,2),fpp( 4, 2, 7,3)/
     x 6.0171091D-02,-8.2511241D-06,-1.4464953D-06 /
      data fpp( 4, 2, 8,1),fpp( 4, 2, 8,2),fpp( 4, 2, 8,3)/
     x 5.8125097D-02,-2.8526291D-05, 7.3033198D-07 /
      data fpp( 4, 2, 9,1),fpp( 4, 2, 9,2),fpp( 4, 2, 9,3)/
     x 5.7096390D-02,-3.7027271D-05, 1.7098340D-06 /
      data fpp( 4, 2,10,1),fpp( 4, 2,10,2),fpp( 4, 2,10,3)/
     x 5.8125097D-02,-2.8526291D-05, 7.3033198D-07 /
      data fpp( 4, 2,11,1),fpp( 4, 2,11,2),fpp( 4, 2,11,3)/
     x 6.0171091D-02,-8.2511241D-06,-1.4464953D-06 /
      data fpp( 4, 2,12,1),fpp( 4, 2,12,2),fpp( 4, 2,12,3)/
     x 6.0026236D-02, 3.0555435D-06,-2.6783510D-06 /
      data fpp( 4, 2,13,1),fpp( 4, 2,13,2),fpp( 4, 2,13,3)/
     x 5.5669839D-02,-6.7101308D-06,-1.2394342D-06 /
      data fpp( 4, 2,14,1),fpp( 4, 2,14,2),fpp( 4, 2,14,3)/
     x 5.0255334D-02,-3.4642914D-05, 1.8954211D-06 /
      data fpp( 4, 2,15,1),fpp( 4, 2,15,2),fpp( 4, 2,15,3)/
     x 4.8019390D-02,-5.1096918D-05, 3.8344165D-06 /
      data fpp( 4, 2,16,1),fpp( 4, 2,16,2),fpp( 4, 2,16,3)/
     x 5.0255334D-02,-3.4642914D-05, 1.4922461D-06 /
      data fpp( 4, 2,17,1),fpp( 4, 2,17,2),fpp( 4, 2,17,3)/
     x 5.5669839D-02,-6.7101308D-06, 3.7326586D-07 /
      data fpp( 4, 3, 1,1),fpp( 4, 3, 1,2),fpp( 4, 3, 1,3)/
     x 5.2131629D-02,-1.9402042D-05,-8.2257078D-07 /
      data fpp( 4, 3, 2,1),fpp( 4, 3, 2,2),fpp( 4, 3, 2,3)/
     x 4.0761075D-02,-7.3168026D-06, 3.6281416D-06 /
      data fpp( 4, 3, 3,1),fpp( 4, 3, 3,2),fpp( 4, 3, 3,3)/
     x 3.9580746D-02,-9.4187856D-06, 1.3288005D-05 /
      data fpp( 4, 3, 4,1),fpp( 4, 3, 4,2),fpp( 4, 3, 4,3)/
     x 4.0761075D-02,-7.3168026D-06, 4.7158404D-06 /
      data fpp( 4, 3, 5,1),fpp( 4, 3, 5,2),fpp( 4, 3, 5,3)/
     x 5.2131629D-02,-1.9402042D-05,-5.1733661D-06 /
      data fpp( 4, 3, 6,1),fpp( 4, 3, 6,2),fpp( 4, 3, 6,3)/
     x 6.1840400D-02,-3.5635902D-05,-8.1230428D-06 /
      data fpp( 4, 3, 7,1),fpp( 4, 3, 7,2),fpp( 4, 3, 7,3)/
     x 6.0352491D-02,-2.9975066D-05,-3.3897962D-06 /
      data fpp( 4, 3, 8,1),fpp( 4, 3, 8,2),fpp( 4, 3, 8,3)/
     x 5.2500637D-02,-1.0912483D-05, 2.7342275D-06 /
      data fpp( 4, 3, 9,1),fpp( 4, 3, 9,2),fpp( 4, 3, 9,3)/
     x 4.9588624D-02,-3.8200516D-06, 5.3655529D-06 /
      data fpp( 4, 3,10,1),fpp( 4, 3,10,2),fpp( 4, 3,10,3)/
     x 5.2500637D-02,-1.0912483D-05, 2.7342275D-06 /
      data fpp( 4, 3,11,1),fpp( 4, 3,11,2),fpp( 4, 3,11,3)/
     x 6.0352491D-02,-2.9975066D-05,-3.3897962D-06 /
      data fpp( 4, 3,12,1),fpp( 4, 3,12,2),fpp( 4, 3,12,3)/
     x 6.1840400D-02,-3.5635902D-05,-8.1230428D-06 /
      data fpp( 4, 3,13,1),fpp( 4, 3,13,2),fpp( 4, 3,13,3)/
     x 5.2131629D-02,-1.9402042D-05,-5.1733661D-06 /
      data fpp( 4, 3,14,1),fpp( 4, 3,14,2),fpp( 4, 3,14,3)/
     x 4.0761075D-02,-7.3168026D-06, 4.7158404D-06 /
      data fpp( 4, 3,15,1),fpp( 4, 3,15,2),fpp( 4, 3,15,3)/
     x 3.9580746D-02,-9.4187856D-06, 1.3288005D-05 /
      data fpp( 4, 3,16,1),fpp( 4, 3,16,2),fpp( 4, 3,16,3)/
     x 4.0761075D-02,-7.3168026D-06, 3.6281416D-06 /
      data fpp( 4, 3,17,1),fpp( 4, 3,17,2),fpp( 4, 3,17,3)/
     x 5.2131629D-02,-1.9402042D-05,-8.2257078D-07 /
      data fpp( 4, 4, 1,1),fpp( 4, 4, 1,2),fpp( 4, 4, 1,3)/
     x 4.7235731D-02,-2.1869701D-05,-3.1912250D-06 /
      data fpp( 4, 4, 2,1),fpp( 4, 4, 2,2),fpp( 4, 4, 2,3)/
     x 3.9419068D-02, 3.1036124D-05, 4.7493389D-06 /
      data fpp( 4, 4, 3,1),fpp( 4, 4, 3,2),fpp( 4, 4, 3,3)/
     x 6.7521284D-02, 7.6466061D-05, 2.2112536D-05 /
      data fpp( 4, 4, 4,1),fpp( 4, 4, 4,2),fpp( 4, 4, 4,3)/
     x 3.9419068D-02, 3.1036124D-05, 6.4965166D-06 /
      data fpp( 4, 4, 5,1),fpp( 4, 4, 5,2),fpp( 4, 4, 5,3)/
     x 4.7235731D-02,-2.1869701D-05,-1.0179936D-05 /
      data fpp( 4, 4, 6,1),fpp( 4, 4, 6,2),fpp( 4, 4, 6,3)/
     x 5.9330766D-02,-4.8905935D-05,-9.2254399D-06 /
      data fpp( 4, 4, 7,1),fpp( 4, 4, 7,2),fpp( 4, 4, 7,3)/
     x 8.1496467D-02,-4.5146131D-06,-6.3036380D-06 /
      data fpp( 4, 4, 8,1),fpp( 4, 4, 8,2),fpp( 4, 4, 8,3)/
     x 5.0566380D-02,-3.0697781D-06, 4.4659918D-06 /
      data fpp( 4, 4, 9,1),fpp( 4, 4, 9,2),fpp( 4, 4, 9,3)/
     x 4.3585206D-02, 3.8034772D-06, 7.6716708D-06 /
      data fpp( 4, 4,10,1),fpp( 4, 4,10,2),fpp( 4, 4,10,3)/
     x 5.0566380D-02,-3.0697781D-06, 4.4659918D-06 /
      data fpp( 4, 4,11,1),fpp( 4, 4,11,2),fpp( 4, 4,11,3)/
     x 8.1496467D-02,-4.5146131D-06,-6.3036380D-06 /
      data fpp( 4, 4,12,1),fpp( 4, 4,12,2),fpp( 4, 4,12,3)/
     x 5.9330766D-02,-4.8905935D-05,-9.2254399D-06 /
      data fpp( 4, 4,13,1),fpp( 4, 4,13,2),fpp( 4, 4,13,3)/
     x 4.7235731D-02,-2.1869701D-05,-1.0179936D-05 /
      data fpp( 4, 4,14,1),fpp( 4, 4,14,2),fpp( 4, 4,14,3)/
     x 3.9419068D-02, 3.1036124D-05, 6.4965166D-06 /
      data fpp( 4, 4,15,1),fpp( 4, 4,15,2),fpp( 4, 4,15,3)/
     x 6.7521284D-02, 7.6466061D-05, 2.2112536D-05 /
      data fpp( 4, 4,16,1),fpp( 4, 4,16,2),fpp( 4, 4,16,3)/
     x 3.9419068D-02, 3.1036124D-05, 4.7493389D-06 /
      data fpp( 4, 4,17,1),fpp( 4, 4,17,2),fpp( 4, 4,17,3)/
     x 4.7235731D-02,-2.1869701D-05,-3.1912250D-06 /
      data fpp( 4, 5, 1,1),fpp( 4, 5, 1,2),fpp( 4, 5, 1,3)/
     x 3.8491207D-02,-5.8291548D-06,-4.1795294D-06 /
      data fpp( 4, 5, 2,1),fpp( 4, 5, 2,2),fpp( 4, 5, 2,3)/
     x 3.9771954D-02, 4.4668307D-05, 4.3733921D-06 /
      data fpp( 4, 5, 3,1),fpp( 4, 5, 3,2),fpp( 4, 5, 3,3)/
     x 1.2765904D-01, 2.4968543D-05, 2.2846628D-05 /
      data fpp( 4, 5, 4,1),fpp( 4, 5, 4,2),fpp( 4, 5, 4,3)/
     x 3.9771954D-02, 4.4668307D-05, 6.5987640D-06 /
      data fpp( 4, 5, 5,1),fpp( 4, 5, 5,2),fpp( 4, 5, 5,3)/
     x 3.8491207D-02,-5.8291548D-06,-1.3081017D-05 /
      data fpp( 4, 5, 6,1),fpp( 4, 5, 6,2),fpp( 4, 5, 6,3)/
     x 4.9582918D-02,-1.6900359D-05,-1.6540298D-06 /
      data fpp( 4, 5, 7,1),fpp( 4, 5, 7,2),fpp( 4, 5, 7,3)/
     x 1.3257601D-01,-4.5554482D-05,-1.3793530D-05 /
      data fpp( 4, 5, 8,1),fpp( 4, 5, 8,2),fpp( 4, 5, 8,3)/
     x 4.7651630D-02, 4.0875953D-06, 6.9294849D-06 /
      data fpp( 4, 5, 9,1),fpp( 4, 5, 9,2),fpp( 4, 5, 9,3)/
     x 3.6976353D-02, 7.0681428D-06, 7.5249242D-06 /
      data fpp( 4, 5,10,1),fpp( 4, 5,10,2),fpp( 4, 5,10,3)/
     x 4.7651630D-02, 4.0875953D-06, 6.9294849D-06 /
      data fpp( 4, 5,11,1),fpp( 4, 5,11,2),fpp( 4, 5,11,3)/
     x 1.3257601D-01,-4.5554482D-05,-1.3793530D-05 /
      data fpp( 4, 5,12,1),fpp( 4, 5,12,2),fpp( 4, 5,12,3)/
     x 4.9582918D-02,-1.6900359D-05,-1.6540298D-06 /
      data fpp( 4, 5,13,1),fpp( 4, 5,13,2),fpp( 4, 5,13,3)/
     x 3.8491207D-02,-5.8291548D-06,-1.3081017D-05 /
      data fpp( 4, 5,14,1),fpp( 4, 5,14,2),fpp( 4, 5,14,3)/
     x 3.9771954D-02, 4.4668307D-05, 6.5987640D-06 /
      data fpp( 4, 5,15,1),fpp( 4, 5,15,2),fpp( 4, 5,15,3)/
     x 1.2765904D-01, 2.4968543D-05, 2.2846628D-05 /
      data fpp( 4, 5,16,1),fpp( 4, 5,16,2),fpp( 4, 5,16,3)/
     x 3.9771954D-02, 4.4668307D-05, 4.3733921D-06 /
      data fpp( 4, 5,17,1),fpp( 4, 5,17,2),fpp( 4, 5,17,3)/
     x 3.8491207D-02,-5.8291548D-06,-4.1795294D-06 /
      data fpp( 4, 6, 1,1),fpp( 4, 6, 1,2),fpp( 4, 6, 1,3)/
     x 2.8085749D-02, 8.4963198D-06,-1.5068346D-05 /
      data fpp( 4, 6, 2,1),fpp( 4, 6, 2,2),fpp( 4, 6, 2,3)/
     x 3.0576056D-02, 3.3188647D-05,-2.5363081D-06 /
      data fpp( 4, 6, 3,1),fpp( 4, 6, 3,2),fpp( 4, 6, 3,3)/
     x 1.0274799D-01, 6.3875769D-05, 2.8252912D-05 /
      data fpp( 4, 6, 4,1),fpp( 4, 6, 4,2),fpp( 4, 6, 4,3)/
     x 3.0576056D-02, 3.3188647D-05,-4.8580055D-06 /
      data fpp( 4, 6, 5,1),fpp( 4, 6, 5,2),fpp( 4, 6, 5,3)/
     x 2.8085749D-02, 8.4963198D-06,-5.7815565D-06 /
      data fpp( 4, 6, 6,1),fpp( 4, 6, 6,2),fpp( 4, 6, 6,3)/
     x 3.2826047D-02, 1.3727371D-05, 3.9623165D-07 /
      data fpp( 4, 6, 7,1),fpp( 4, 6, 7,2),fpp( 4, 6, 7,3)/
     x 1.0291813D-01, 1.0494540D-05,-1.0218037D-05 /
      data fpp( 4, 6, 8,1),fpp( 4, 6, 8,2),fpp( 4, 6, 8,3)/
     x 3.5316116D-02, 7.4133971D-06, 6.9591526D-07 /
      data fpp( 4, 6, 9,1),fpp( 4, 6, 9,2),fpp( 4, 6, 9,3)/
     x 2.8866652D-02, 3.6599516D-06, 1.0891042D-05 /
      data fpp( 4, 6,10,1),fpp( 4, 6,10,2),fpp( 4, 6,10,3)/
     x 3.5316116D-02, 7.4133971D-06, 6.9591526D-07 /
      data fpp( 4, 6,11,1),fpp( 4, 6,11,2),fpp( 4, 6,11,3)/
     x 1.0291813D-01, 1.0494540D-05,-1.0218037D-05 /
      data fpp( 4, 6,12,1),fpp( 4, 6,12,2),fpp( 4, 6,12,3)/
     x 3.2826047D-02, 1.3727371D-05, 3.9623165D-07 /
      data fpp( 4, 6,13,1),fpp( 4, 6,13,2),fpp( 4, 6,13,3)/
     x 2.8085749D-02, 8.4963198D-06,-5.7815565D-06 /
      data fpp( 4, 6,14,1),fpp( 4, 6,14,2),fpp( 4, 6,14,3)/
     x 3.0576056D-02, 3.3188647D-05,-4.8580055D-06 /
      data fpp( 4, 6,15,1),fpp( 4, 6,15,2),fpp( 4, 6,15,3)/
     x 1.0274799D-01, 6.3875769D-05, 2.8252912D-05 /
      data fpp( 4, 6,16,1),fpp( 4, 6,16,2),fpp( 4, 6,16,3)/
     x 3.0576056D-02, 3.3188647D-05,-2.5363081D-06 /
      data fpp( 4, 6,17,1),fpp( 4, 6,17,2),fpp( 4, 6,17,3)/
     x 2.8085749D-02, 8.4963198D-06,-1.5068346D-05 /
      data fpp( 4, 7, 1,1),fpp( 4, 7, 1,2),fpp( 4, 7, 1,3)/
     x 1.9536223D-02, 1.2823875D-05,-1.9571830D-05 /
      data fpp( 4, 7, 2,1),fpp( 4, 7, 2,2),fpp( 4, 7, 2,3)/
     x 2.1410604D-02,-1.2890896D-05,-7.7466741D-06 /
      data fpp( 4, 7, 3,1),fpp( 4, 7, 3,2),fpp( 4, 7, 3,3)/
     x 3.9718284D-02, 3.9520383D-05, 2.4021859D-05 /
      data fpp( 4, 7, 4,1),fpp( 4, 7, 4,2),fpp( 4, 7, 4,3)/
     x 2.1410604D-02,-1.2890896D-05,-1.4011430D-05 /
      data fpp( 4, 7, 5,1),fpp( 4, 7, 5,2),fpp( 4, 7, 5,3)/
     x 1.9536223D-02, 1.2823875D-05, 5.4871954D-06 /
      data fpp( 4, 7, 6,1),fpp( 4, 7, 6,2),fpp( 4, 7, 6,3)/
     x 1.9947945D-02, 1.9650875D-05,-1.5268469D-07 /
      data fpp( 4, 7, 7,1),fpp( 4, 7, 7,2),fpp( 4, 7, 7,3)/
     x 3.9007086D-02, 3.3330320D-05,-5.1691234D-06 /
      data fpp( 4, 7, 8,1),fpp( 4, 7, 8,2),fpp( 4, 7, 8,3)/
     x 2.3561102D-02,-8.7571836D-06,-6.2614886D-06 /
      data fpp( 4, 7, 9,1),fpp( 4, 7, 9,2),fpp( 4, 7, 9,3)/
     x 2.0766962D-02,-6.2639493D-06, 1.5149078D-05 /
      data fpp( 4, 7,10,1),fpp( 4, 7,10,2),fpp( 4, 7,10,3)/
     x 2.3561102D-02,-8.7571836D-06,-6.2614886D-06 /
      data fpp( 4, 7,11,1),fpp( 4, 7,11,2),fpp( 4, 7,11,3)/
     x 3.9007086D-02, 3.3330320D-05,-5.1691234D-06 /
      data fpp( 4, 7,12,1),fpp( 4, 7,12,2),fpp( 4, 7,12,3)/
     x 1.9947945D-02, 1.9650875D-05,-1.5268469D-07 /
      data fpp( 4, 7,13,1),fpp( 4, 7,13,2),fpp( 4, 7,13,3)/
     x 1.9536223D-02, 1.2823875D-05, 5.4871954D-06 /
      data fpp( 4, 7,14,1),fpp( 4, 7,14,2),fpp( 4, 7,14,3)/
     x 2.1410604D-02,-1.2890896D-05,-1.4011430D-05 /
      data fpp( 4, 7,15,1),fpp( 4, 7,15,2),fpp( 4, 7,15,3)/
     x 3.9718284D-02, 3.9520383D-05, 2.4021859D-05 /
      data fpp( 4, 7,16,1),fpp( 4, 7,16,2),fpp( 4, 7,16,3)/
     x 2.1410604D-02,-1.2890896D-05,-7.7466741D-06 /
      data fpp( 4, 7,17,1),fpp( 4, 7,17,2),fpp( 4, 7,17,3)/
     x 1.9536223D-02, 1.2823875D-05,-1.9571830D-05 /
      data fpp( 4, 8, 1,1),fpp( 4, 8, 1,2),fpp( 4, 8, 1,3)/
     x 1.3406641D-02, 1.1740178D-05,-6.2436058D-06 /
      data fpp( 4, 8, 2,1),fpp( 4, 8, 2,2),fpp( 4, 8, 2,3)/
     x 1.7035384D-02,-3.9303062D-05,-4.2465661D-06 /
      data fpp( 4, 8, 3,1),fpp( 4, 8, 3,2),fpp( 4, 8, 3,3)/
     x 1.9111473D-02,-8.5175299D-05, 3.0805368D-06 /
      data fpp( 4, 8, 4,1),fpp( 4, 8, 4,2),fpp( 4, 8, 4,3)/
     x 1.7035384D-02,-3.9303062D-05,-8.2475813D-06 /
      data fpp( 4, 8, 5,1),fpp( 4, 8, 5,2),fpp( 4, 8, 5,3)/
     x 1.3406641D-02, 1.1740178D-05, 9.7604550D-06 /
      data fpp( 4, 8, 6,1),fpp( 4, 8, 6,2),fpp( 4, 8, 6,3)/
     x 1.4306101D-02, 2.0871128D-05, 2.6364279D-06 /
      data fpp( 4, 8, 7,1),fpp( 4, 8, 7,2),fpp( 4, 8, 7,3)/
     x 1.8189755D-02,-8.5638220D-06,-8.6568331D-06 /
      data fpp( 4, 8, 8,1),fpp( 4, 8, 8,2),fpp( 4, 8, 8,3)/
     x 1.5706790D-02,-1.6388663D-05,-4.7777620D-06 /
      data fpp( 4, 8, 9,1),fpp( 4, 8, 9,2),fpp( 4, 8, 9,3)/
     x 1.2388709D-02,-1.6068154D-05, 1.4823214D-05 /
      data fpp( 4, 8,10,1),fpp( 4, 8,10,2),fpp( 4, 8,10,3)/
     x 1.5706790D-02,-1.6388663D-05,-4.7777620D-06 /
      data fpp( 4, 8,11,1),fpp( 4, 8,11,2),fpp( 4, 8,11,3)/
     x 1.8189755D-02,-8.5638220D-06,-8.6568331D-06 /
      data fpp( 4, 8,12,1),fpp( 4, 8,12,2),fpp( 4, 8,12,3)/
     x 1.4306101D-02, 2.0871128D-05, 2.6364279D-06 /
      data fpp( 4, 8,13,1),fpp( 4, 8,13,2),fpp( 4, 8,13,3)/
     x 1.3406641D-02, 1.1740178D-05, 9.7604550D-06 /
      data fpp( 4, 8,14,1),fpp( 4, 8,14,2),fpp( 4, 8,14,3)/
     x 1.7035384D-02,-3.9303062D-05,-8.2475813D-06 /
      data fpp( 4, 8,15,1),fpp( 4, 8,15,2),fpp( 4, 8,15,3)/
     x 1.9111473D-02,-8.5175299D-05, 3.0805368D-06 /
      data fpp( 4, 8,16,1),fpp( 4, 8,16,2),fpp( 4, 8,16,3)/
     x 1.7035384D-02,-3.9303062D-05,-4.2465661D-06 /
      data fpp( 4, 8,17,1),fpp( 4, 8,17,2),fpp( 4, 8,17,3)/
     x 1.3406641D-02, 1.1740178D-05,-6.2436058D-06 /
      data fpp( 4, 9, 1,1),fpp( 4, 9, 1,2),fpp( 4, 9, 1,3)/
     x 8.9832131D-03, 1.0457411D-05, 4.5072521D-06 /
      data fpp( 4, 9, 2,1),fpp( 4, 9, 2,2),fpp( 4, 9, 2,3)/
     x 1.0933902D-02,-3.0458857D-05, 2.9671810D-07 /
      data fpp( 4, 9, 3,1),fpp( 4, 9, 3,2),fpp( 4, 9, 3,3)/
     x 1.3554724D-02,-7.4497186D-05,-8.8241245D-06 /
      data fpp( 4, 9, 4,1),fpp( 4, 9, 4,2),fpp( 4, 9, 4,3)/
     x 1.0933902D-02,-3.0458857D-05,-7.5888696D-07 /
      data fpp( 4, 9, 5,1),fpp( 4, 9, 5,2),fpp( 4, 9, 5,3)/
     x 8.9832131D-03, 1.0457411D-05, 8.7296723D-06 /
      data fpp( 4, 9, 6,1),fpp( 4, 9, 6,2),fpp( 4, 9, 6,3)/
     x 1.2207030D-02, 2.4820613D-05, 1.2401978D-06 /
      data fpp( 4, 9, 7,1),fpp( 4, 9, 7,2),fpp( 4, 9, 7,3)/
     x 1.3408189D-02, 1.6749675D-06,-1.0645797D-05 /
      data fpp( 4, 9, 8,1),fpp( 4, 9, 8,2),fpp( 4, 9, 8,3)/
     x 7.3892161D-03,-1.5040165D-05,-9.8101043D-07 /
      data fpp( 4, 9, 9,1),fpp( 4, 9, 9,2),fpp( 4, 9, 9,3)/
     x 2.8375428D-03,-2.1317433D-05, 1.3479839D-05 /
      data fpp( 4, 9,10,1),fpp( 4, 9,10,2),fpp( 4, 9,10,3)/
     x 7.3892161D-03,-1.5040165D-05,-9.8101043D-07 /
      data fpp( 4, 9,11,1),fpp( 4, 9,11,2),fpp( 4, 9,11,3)/
     x 1.3408189D-02, 1.6749675D-06,-1.0645797D-05 /
      data fpp( 4, 9,12,1),fpp( 4, 9,12,2),fpp( 4, 9,12,3)/
     x 1.2207030D-02, 2.4820613D-05, 1.2401978D-06 /
      data fpp( 4, 9,13,1),fpp( 4, 9,13,2),fpp( 4, 9,13,3)/
     x 8.9832131D-03, 1.0457411D-05, 8.7296723D-06 /
      data fpp( 4, 9,14,1),fpp( 4, 9,14,2),fpp( 4, 9,14,3)/
     x 1.0933902D-02,-3.0458857D-05,-7.5888696D-07 /
      data fpp( 4, 9,15,1),fpp( 4, 9,15,2),fpp( 4, 9,15,3)/
     x 1.3554724D-02,-7.4497186D-05,-8.8241245D-06 /
      data fpp( 4, 9,16,1),fpp( 4, 9,16,2),fpp( 4, 9,16,3)/
     x 1.0933902D-02,-3.0458857D-05, 2.9671810D-07 /
      data fpp( 4, 9,17,1),fpp( 4, 9,17,2),fpp( 4, 9,17,3)/
     x 8.9832131D-03, 1.0457411D-05, 4.5072521D-06 /
      data fpp( 4,10, 1,1),fpp( 4,10, 1,2),fpp( 4,10, 1,3)/
     x 5.7482546D-03, 1.1974178D-05, 7.4953784D-06 /
      data fpp( 4,10, 2,1),fpp( 4,10, 2,2),fpp( 4,10, 2,3)/
     x 2.0424456D-03,-1.5231512D-05, 3.3829099D-06 /
      data fpp( 4,10, 3,1),fpp( 4,10, 3,2),fpp( 4,10, 3,3)/
     x 2.0708904D-03,-2.9497955D-05,-6.5130181D-06 /
      data fpp( 4,10, 4,1),fpp( 4,10, 4,2),fpp( 4,10, 4,3)/
     x 2.0424456D-03,-1.5231512D-05, 3.8331625D-06 /
      data fpp( 4,10, 5,1),fpp( 4,10, 5,2),fpp( 4,10, 5,3)/
     x 5.7482546D-03, 1.1974178D-05, 5.6943681D-06 /
      data fpp( 4,10, 6,1),fpp( 4,10, 6,2),fpp( 4,10, 6,3)/
     x 1.2126418D-02, 2.9948418D-05,-6.7253014D-06 /
      data fpp( 4,10, 7,1),fpp( 4,10, 7,2),fpp( 4,10, 7,3)/
     x 9.1189104D-03, 7.3299520D-06,-9.8191624D-06 /
      data fpp( 4,10, 8,1),fpp( 4,10, 8,2),fpp( 4,10, 8,3)/
     x-1.8862013D-03,-1.3888676D-05, 3.5372845D-06 /
      data fpp( 4,10, 9,1),fpp( 4,10, 9,2),fpp( 4,10, 9,3)/
     x-7.0347057D-03,-2.0990113D-05, 1.3547358D-05 /
      data fpp( 4,10,10,1),fpp( 4,10,10,2),fpp( 4,10,10,3)/
     x-1.8862013D-03,-1.3888676D-05, 3.5372845D-06 /
      data fpp( 4,10,11,1),fpp( 4,10,11,2),fpp( 4,10,11,3)/
     x 9.1189104D-03, 7.3299520D-06,-9.8191624D-06 /
      data fpp( 4,10,12,1),fpp( 4,10,12,2),fpp( 4,10,12,3)/
     x 1.2126418D-02, 2.9948418D-05,-6.7253014D-06 /
      data fpp( 4,10,13,1),fpp( 4,10,13,2),fpp( 4,10,13,3)/
     x 5.7482546D-03, 1.1974178D-05, 5.6943681D-06 /
      data fpp( 4,10,14,1),fpp( 4,10,14,2),fpp( 4,10,14,3)/
     x 2.0424456D-03,-1.5231512D-05, 3.8331625D-06 /
      data fpp( 4,10,15,1),fpp( 4,10,15,2),fpp( 4,10,15,3)/
     x 2.0708904D-03,-2.9497955D-05,-6.5130181D-06 /
      data fpp( 4,10,16,1),fpp( 4,10,16,2),fpp( 4,10,16,3)/
     x 2.0424456D-03,-1.5231512D-05, 3.3829099D-06 /
      data fpp( 4,10,17,1),fpp( 4,10,17,2),fpp( 4,10,17,3)/
     x 5.7482546D-03, 1.1974178D-05, 7.4953784D-06 /
      data fpp( 4,11, 1,1),fpp( 4,11, 1,2),fpp( 4,11, 1,3)/
     x 3.7097525D-03, 1.8271878D-05, 9.2682522D-06 /
      data fpp( 4,11, 2,1),fpp( 4,11, 2,2),fpp( 4,11, 2,3)/
     x-6.0717299D-03,-2.7709583D-07, 7.1968290D-06 /
      data fpp( 4,11, 3,1),fpp( 4,11, 3,2),fpp( 4,11, 3,3)/
     x-9.0577502D-03,-2.8829927D-06, 1.2777653D-06 /
      data fpp( 4,11, 4,1),fpp( 4,11, 4,2),fpp( 4,11, 4,3)/
     x-6.0717299D-03,-2.7709583D-07, 8.8254431D-06 /
      data fpp( 4,11, 5,1),fpp( 4,11, 5,2),fpp( 4,11, 5,3)/
     x 3.7097525D-03, 1.8271878D-05, 2.7537956D-06 /
      data fpp( 4,11, 6,1),fpp( 4,11, 6,2),fpp( 4,11, 6,3)/
     x 1.4432311D-02, 3.9447713D-05,-2.2231292D-05 /
      data fpp( 4,11, 7,1),fpp( 4,11, 7,2),fpp( 4,11, 7,3)/
     x 4.4781084D-03, 9.7392245D-06,-6.7879598D-06 /
      data fpp( 4,11, 8,1),fpp( 4,11, 8,2),fpp( 4,11, 8,3)/
     x-1.0238121D-02,-9.0191321D-06, 9.3311314D-06 /
      data fpp( 4,11, 9,1),fpp( 4,11, 9,2),fpp( 4,11, 9,3)/
     x-1.5417752D-02,-1.4554117D-05, 1.5211434D-05 /
      data fpp( 4,11,10,1),fpp( 4,11,10,2),fpp( 4,11,10,3)/
     x-1.0238121D-02,-9.0191321D-06, 9.3311314D-06 /
      data fpp( 4,11,11,1),fpp( 4,11,11,2),fpp( 4,11,11,3)/
     x 4.4781084D-03, 9.7392245D-06,-6.7879598D-06 /
      data fpp( 4,11,12,1),fpp( 4,11,12,2),fpp( 4,11,12,3)/
     x 1.4432311D-02, 3.9447713D-05,-2.2231292D-05 /
      data fpp( 4,11,13,1),fpp( 4,11,13,2),fpp( 4,11,13,3)/
     x 3.7097525D-03, 1.8271878D-05, 2.7537956D-06 /
      data fpp( 4,11,14,1),fpp( 4,11,14,2),fpp( 4,11,14,3)/
     x-6.0717299D-03,-2.7709583D-07, 8.8254431D-06 /
      data fpp( 4,11,15,1),fpp( 4,11,15,2),fpp( 4,11,15,3)/
     x-9.0577502D-03,-2.8829927D-06, 1.2777653D-06 /
      data fpp( 4,11,16,1),fpp( 4,11,16,2),fpp( 4,11,16,3)/
     x-6.0717299D-03,-2.7709583D-07, 7.1968290D-06 /
      data fpp( 4,11,17,1),fpp( 4,11,17,2),fpp( 4,11,17,3)/
     x 3.7097525D-03, 1.8271878D-05, 9.2682522D-06 /
      data fpp( 4,12, 1,1),fpp( 4,12, 1,2),fpp( 4,12, 1,3)/
     x 3.2383969D-03, 2.8356311D-05, 1.3314846D-05 /
      data fpp( 4,12, 2,1),fpp( 4,12, 2,2),fpp( 4,12, 2,3)/
     x-1.1268490D-02, 1.8091895D-05, 1.2745752D-05 /
      data fpp( 4,12, 3,1),fpp( 4,12, 3,2),fpp( 4,12, 3,3)/
     x-1.6006832D-02, 1.8439926D-05, 9.5574785D-06 /
      data fpp( 4,12, 4,1),fpp( 4,12, 4,2),fpp( 4,12, 4,3)/
     x-1.1268490D-02, 1.8091895D-05, 1.5536334D-05 /
      data fpp( 4,12, 5,1),fpp( 4,12, 5,2),fpp( 4,12, 5,3)/
     x 3.2383969D-03, 2.8356311D-05, 2.1525202D-06 /
      data fpp( 4,12, 6,1),fpp( 4,12, 6,2),fpp( 4,12, 6,3)/
     x 1.9867648D-02, 4.8174731D-05,-4.7609748D-05 /
      data fpp( 4,12, 7,1),fpp( 4,12, 7,2),fpp( 4,12, 7,3)/
     x 4.3525825D-04, 1.4949150D-05, 3.7447053D-07 /
      data fpp( 4,12, 8,1),fpp( 4,12, 8,2),fpp( 4,12, 8,3)/
     x-1.6581318D-02, 2.7572041D-06, 1.5831866D-05 /
      data fpp( 4,12, 9,1),fpp( 4,12, 9,2),fpp( 4,12, 9,3)/
     x-2.1686172D-02,-6.6542140D-07, 1.8336734D-05 /
      data fpp( 4,12,10,1),fpp( 4,12,10,2),fpp( 4,12,10,3)/
     x-1.6581318D-02, 2.7572041D-06, 1.5831866D-05 /
      data fpp( 4,12,11,1),fpp( 4,12,11,2),fpp( 4,12,11,3)/
     x 4.3525825D-04, 1.4949150D-05, 3.7447053D-07 /
      data fpp( 4,12,12,1),fpp( 4,12,12,2),fpp( 4,12,12,3)/
     x 1.9867648D-02, 4.8174731D-05,-4.7609748D-05 /
      data fpp( 4,12,13,1),fpp( 4,12,13,2),fpp( 4,12,13,3)/
     x 3.2383969D-03, 2.8356311D-05, 2.1525202D-06 /
      data fpp( 4,12,14,1),fpp( 4,12,14,2),fpp( 4,12,14,3)/
     x-1.1268490D-02, 1.8091895D-05, 1.5536334D-05 /
      data fpp( 4,12,15,1),fpp( 4,12,15,2),fpp( 4,12,15,3)/
     x-1.6006832D-02, 1.8439926D-05, 9.5574785D-06 /
      data fpp( 4,12,16,1),fpp( 4,12,16,2),fpp( 4,12,16,3)/
     x-1.1268490D-02, 1.8091895D-05, 1.2745752D-05 /
      data fpp( 4,12,17,1),fpp( 4,12,17,2),fpp( 4,12,17,3)/
     x 3.2383969D-03, 2.8356311D-05, 1.3314846D-05 /
      data fpp( 4,13, 1,1),fpp( 4,13, 1,2),fpp( 4,13, 1,3)/
     x 6.8417250D-03, 4.4444877D-05, 1.9591081D-05 /
      data fpp( 4,13, 2,1),fpp( 4,13, 2,2),fpp( 4,13, 2,3)/
     x-1.3578734D-02, 4.2773515D-05, 1.9605282D-05 /
      data fpp( 4,13, 3,1),fpp( 4,13, 3,2),fpp( 4,13, 3,3)/
     x-1.9437082D-02, 4.4563289D-05, 1.7237790D-05 /
      data fpp( 4,13, 4,1),fpp( 4,13, 4,2),fpp( 4,13, 4,3)/
     x-1.3578734D-02, 4.2773515D-05, 2.3206226D-05 /
      data fpp( 4,13, 5,1),fpp( 4,13, 5,2),fpp( 4,13, 5,3)/
     x 6.8417250D-03, 4.4444877D-05, 5.1873059D-06 /
      data fpp( 4,13, 6,1),fpp( 4,13, 6,2),fpp( 4,13, 6,3)/
     x 3.3072997D-02, 4.8857364D-05,-8.3648783D-05 /
      data fpp( 4,13, 7,1),fpp( 4,13, 7,2),fpp( 4,13, 7,3)/
     x-2.8208699D-03, 2.1634176D-05, 1.3799160D-05 /
      data fpp( 4,13, 8,1),fpp( 4,13, 8,2),fpp( 4,13, 8,3)/
     x-2.1044436D-02, 2.3262316D-05, 2.1714812D-05 /
      data fpp( 4,13, 9,1),fpp( 4,13, 9,2),fpp( 4,13, 9,3)/
     x-2.6072653D-02, 2.3155802D-05, 2.2844928D-05 /
      data fpp( 4,13,10,1),fpp( 4,13,10,2),fpp( 4,13,10,3)/
     x-2.1044436D-02, 2.3262316D-05, 2.1714812D-05 /
      data fpp( 4,13,11,1),fpp( 4,13,11,2),fpp( 4,13,11,3)/
     x-2.8208699D-03, 2.1634176D-05, 1.3799160D-05 /
      data fpp( 4,13,12,1),fpp( 4,13,12,2),fpp( 4,13,12,3)/
     x 3.3072997D-02, 4.8857364D-05,-8.3648783D-05 /
      data fpp( 4,13,13,1),fpp( 4,13,13,2),fpp( 4,13,13,3)/
     x 6.8417250D-03, 4.4444877D-05, 5.1873059D-06 /
      data fpp( 4,13,14,1),fpp( 4,13,14,2),fpp( 4,13,14,3)/
     x-1.3578734D-02, 4.2773515D-05, 2.3206226D-05 /
      data fpp( 4,13,15,1),fpp( 4,13,15,2),fpp( 4,13,15,3)/
     x-1.9437082D-02, 4.4563289D-05, 1.7237790D-05 /
      data fpp( 4,13,16,1),fpp( 4,13,16,2),fpp( 4,13,16,3)/
     x-1.3578734D-02, 4.2773515D-05, 1.9605282D-05 /
      data fpp( 4,13,17,1),fpp( 4,13,17,2),fpp( 4,13,17,3)/
     x 6.8417250D-03, 4.4444877D-05, 1.9591081D-05 /
      data fpp( 4,14, 1,1),fpp( 4,14, 1,2),fpp( 4,14, 1,3)/
     x 2.2896651D-02, 6.3462181D-05, 2.7173301D-05 /
      data fpp( 4,14, 2,1),fpp( 4,14, 2,2),fpp( 4,14, 2,3)/
     x-1.3877580D-02, 7.1406045D-05, 2.7050732D-05 /
      data fpp( 4,14, 3,1),fpp( 4,14, 3,2),fpp( 4,14, 3,3)/
     x-2.0333455D-02, 7.8082918D-05, 2.3845105D-05 /
      data fpp( 4,14, 4,1),fpp( 4,14, 4,2),fpp( 4,14, 4,3)/
     x-1.3877580D-02, 7.1406045D-05, 3.1430183D-05 /
      data fpp( 4,14, 5,1),fpp( 4,14, 5,2),fpp( 4,14, 5,3)/
     x 2.2896651D-02, 6.3462181D-05, 9.6554980D-06 /
      data fpp( 4,14, 6,1),fpp( 4,14, 6,2),fpp( 4,14, 6,3)/
     x 7.4502787D-02, 3.3229814D-05,-1.2617217D-04 /
      data fpp( 4,14, 7,1),fpp( 4,14, 7,2),fpp( 4,14, 7,3)/
     x-5.8597147D-03, 2.5144146D-05, 3.4234534D-05 /
      data fpp( 4,14, 8,1),fpp( 4,14, 8,2),fpp( 4,14, 8,3)/
     x-2.4152117D-02, 5.1499533D-05, 2.5026038D-05 /
      data fpp( 4,14, 9,1),fpp( 4,14, 9,2),fpp( 4,14, 9,3)/
     x-2.8874596D-02, 5.7190213D-05, 2.8536648D-05 /
      data fpp( 4,14,10,1),fpp( 4,14,10,2),fpp( 4,14,10,3)/
     x-2.4152117D-02, 5.1499533D-05, 2.5026038D-05 /
      data fpp( 4,14,11,1),fpp( 4,14,11,2),fpp( 4,14,11,3)/
     x-5.8597147D-03, 2.5144146D-05, 3.4234534D-05 /
      data fpp( 4,14,12,1),fpp( 4,14,12,2),fpp( 4,14,12,3)/
     x 7.4502787D-02, 3.3229814D-05,-1.2617217D-04 /
      data fpp( 4,14,13,1),fpp( 4,14,13,2),fpp( 4,14,13,3)/
     x 2.2896651D-02, 6.3462181D-05, 9.6554980D-06 /
      data fpp( 4,14,14,1),fpp( 4,14,14,2),fpp( 4,14,14,3)/
     x-1.3877580D-02, 7.1406045D-05, 3.1430183D-05 /
      data fpp( 4,14,15,1),fpp( 4,14,15,2),fpp( 4,14,15,3)/
     x-2.0333455D-02, 7.8082918D-05, 2.3845105D-05 /
      data fpp( 4,14,16,1),fpp( 4,14,16,2),fpp( 4,14,16,3)/
     x-1.3877580D-02, 7.1406045D-05, 2.7050732D-05 /
      data fpp( 4,14,17,1),fpp( 4,14,17,2),fpp( 4,14,17,3)/
     x 2.2896651D-02, 6.3462181D-05, 2.7173301D-05 /
      data fpp( 4,15, 1,1),fpp( 4,15, 1,2),fpp( 4,15, 1,3)/
     x 5.2988022D-02,-1.9185601D-05, 3.3199227D-05 /
      data fpp( 4,15, 2,1),fpp( 4,15, 2,2),fpp( 4,15, 2,3)/
     x-1.2704227D-02, 9.1860306D-05, 3.2945324D-05 /
      data fpp( 4,15, 3,1),fpp( 4,15, 3,2),fpp( 4,15, 3,3)/
     x-1.9159472D-02, 1.1379904D-04, 2.8132811D-05 /
      data fpp( 4,15, 4,1),fpp( 4,15, 4,2),fpp( 4,15, 4,3)/
     x-1.2704227D-02, 9.1860306D-05, 3.9275432D-05 /
      data fpp( 4,15, 5,1),fpp( 4,15, 5,2),fpp( 4,15, 5,3)/
     x 5.2988022D-02,-1.9185601D-05, 7.8787950D-06 /
      data fpp( 4,15, 6,1),fpp( 4,15, 6,2),fpp( 4,15, 6,3)/
     x 1.5055289D-01,-1.6185662D-04,-1.5645261D-04 /
      data fpp( 4,15, 7,1),fpp( 4,15, 7,2),fpp( 4,15, 7,3)/
     x-9.7706459D-03, 1.6959240D-05, 5.3991652D-05 /
      data fpp( 4,15, 8,1),fpp( 4,15, 8,2),fpp( 4,15, 8,3)/
     x-2.6282027D-02, 8.3525553D-05, 2.4848004D-05 /
      data fpp( 4,15, 9,1),fpp( 4,15, 9,2),fpp( 4,15, 9,3)/
     x-3.0157664D-02, 9.9269346D-05, 3.3839665D-05 /
      data fpp( 4,15,10,1),fpp( 4,15,10,2),fpp( 4,15,10,3)/
     x-2.6282027D-02, 8.3525553D-05, 2.4848004D-05 /
      data fpp( 4,15,11,1),fpp( 4,15,11,2),fpp( 4,15,11,3)/
     x-9.7706459D-03, 1.6959240D-05, 5.3991652D-05 /
      data fpp( 4,15,12,1),fpp( 4,15,12,2),fpp( 4,15,12,3)/
     x 1.5055289D-01,-1.6185662D-04,-1.5645261D-04 /
      data fpp( 4,15,13,1),fpp( 4,15,13,2),fpp( 4,15,13,3)/
     x 5.2988022D-02,-1.9185601D-05, 7.8787950D-06 /
      data fpp( 4,15,14,1),fpp( 4,15,14,2),fpp( 4,15,14,3)/
     x-1.2704227D-02, 9.1860306D-05, 3.9275432D-05 /
      data fpp( 4,15,15,1),fpp( 4,15,15,2),fpp( 4,15,15,3)/
     x-1.9159472D-02, 1.1379904D-04, 2.8132811D-05 /
      data fpp( 4,15,16,1),fpp( 4,15,16,2),fpp( 4,15,16,3)/
     x-1.2704227D-02, 9.1860306D-05, 3.2945324D-05 /
      data fpp( 4,15,17,1),fpp( 4,15,17,2),fpp( 4,15,17,3)/
     x 5.2988022D-02,-1.9185601D-05, 3.3199227D-05 /
      data fpp( 4,16, 1,1),fpp( 4,16, 1,2),fpp( 4,16, 1,3)/
     x 4.7366938D-02,-4.5045777D-05, 2.7397725D-05 /
      data fpp( 4,16, 2,1),fpp( 4,16, 2,2),fpp( 4,16, 2,3)/
     x-1.1400129D-02, 8.4916733D-05, 2.9888550D-05 /
      data fpp( 4,16, 3,1),fpp( 4,16, 3,2),fpp( 4,16, 3,3)/
     x-1.6295811D-02, 1.1823093D-04, 2.9570740D-05 /
      data fpp( 4,16, 4,1),fpp( 4,16, 4,2),fpp( 4,16, 4,3)/
     x-1.1400129D-02, 8.4916733D-05, 3.9083156D-05 /
      data fpp( 4,16, 5,1),fpp( 4,16, 5,2),fpp( 4,16, 5,3)/
     x 4.7366938D-02,-4.5045777D-05,-9.3806964D-06 /
      data fpp( 4,16, 6,1),fpp( 4,16, 6,2),fpp( 4,16, 6,3)/
     x 1.8687051D-01,-1.6064934D-04,-1.3170104D-04 /
      data fpp( 4,16, 7,1),fpp( 4,16, 7,2),fpp( 4,16, 7,3)/
     x-1.7178543D-02, 1.0164894D-05, 4.6271510D-05 /
      data fpp( 4,16, 8,1),fpp( 4,16, 8,2),fpp( 4,16, 8,3)/
     x-2.7607175D-02, 1.0296025D-04, 2.4816331D-05 /
      data fpp( 4,16, 9,1),fpp( 4,16, 9,2),fpp( 4,16, 9,3)/
     x-2.9892860D-02, 1.2944840D-04, 3.3783168D-05 /
      data fpp( 4,16,10,1),fpp( 4,16,10,2),fpp( 4,16,10,3)/
     x-2.7607175D-02, 1.0296025D-04, 2.4816331D-05 /
      data fpp( 4,16,11,1),fpp( 4,16,11,2),fpp( 4,16,11,3)/
     x-1.7178543D-02, 1.0164894D-05, 4.6271510D-05 /
      data fpp( 4,16,12,1),fpp( 4,16,12,2),fpp( 4,16,12,3)/
     x 1.8687051D-01,-1.6064934D-04,-1.3170104D-04 /
      data fpp( 4,16,13,1),fpp( 4,16,13,2),fpp( 4,16,13,3)/
     x 4.7366938D-02,-4.5045777D-05,-9.3806964D-06 /
      data fpp( 4,16,14,1),fpp( 4,16,14,2),fpp( 4,16,14,3)/
     x-1.1400129D-02, 8.4916733D-05, 3.9083156D-05 /
      data fpp( 4,16,15,1),fpp( 4,16,15,2),fpp( 4,16,15,3)/
     x-1.6295811D-02, 1.1823093D-04, 2.9570740D-05 /
      data fpp( 4,16,16,1),fpp( 4,16,16,2),fpp( 4,16,16,3)/
     x-1.1400129D-02, 8.4916733D-05, 2.9888550D-05 /
      data fpp( 4,16,17,1),fpp( 4,16,17,2),fpp( 4,16,17,3)/
     x 4.7366938D-02,-4.5045777D-05, 2.7397725D-05 /
      data fpp( 4,17, 1,1),fpp( 4,17, 1,2),fpp( 4,17, 1,3)/
     x 6.6623418D-02,-9.0317291D-05, 1.0505487D-05 /
      data fpp( 4,17, 2,1),fpp( 4,17, 2,2),fpp( 4,17, 2,3)/
     x-3.3405549D-03, 1.9168764D-05, 1.6653360D-05 /
      data fpp( 4,17, 3,1),fpp( 4,17, 3,2),fpp( 4,17, 3,3)/
     x-8.3071856D-03, 8.1137250D-05, 2.4677740D-05 /
      data fpp( 4,17, 4,1),fpp( 4,17, 4,2),fpp( 4,17, 4,3)/
     x-3.3405549D-03, 1.9168764D-05, 2.6134346D-05 /
      data fpp( 4,17, 5,1),fpp( 4,17, 5,2),fpp( 4,17, 5,3)/
     x 6.6623418D-02,-9.0317291D-05,-2.7418457D-05 /
      data fpp( 4,17, 6,1),fpp( 4,17, 6,2),fpp( 4,17, 6,3)/
     x 7.9621523D-02, 2.0553976D-05,-6.3727850D-05 /
      data fpp( 4,17, 7,1),fpp( 4,17, 7,2),fpp( 4,17, 7,3)/
     x-2.5280008D-02, 3.3065182D-05, 1.8531857D-05 /
      data fpp( 4,17, 8,1),fpp( 4,17, 8,2),fpp( 4,17, 8,3)/
     x-2.8112216D-02, 1.1005743D-04, 2.1658422D-05 /
      data fpp( 4,17, 9,1),fpp( 4,17, 9,2),fpp( 4,17, 9,3)/
     x-2.8589820D-02, 1.4575305D-04, 2.6545789D-05 /
      data fpp( 4,17,10,1),fpp( 4,17,10,2),fpp( 4,17,10,3)/
     x-2.8112216D-02, 1.1005743D-04, 2.1658422D-05 /
      data fpp( 4,17,11,1),fpp( 4,17,11,2),fpp( 4,17,11,3)/
     x-2.5280008D-02, 3.3065182D-05, 1.8531857D-05 /
      data fpp( 4,17,12,1),fpp( 4,17,12,2),fpp( 4,17,12,3)/
     x 7.9621523D-02, 2.0553976D-05,-6.3727850D-05 /
      data fpp( 4,17,13,1),fpp( 4,17,13,2),fpp( 4,17,13,3)/
     x 6.6623418D-02,-9.0317291D-05,-2.7418457D-05 /
      data fpp( 4,17,14,1),fpp( 4,17,14,2),fpp( 4,17,14,3)/
     x-3.3405549D-03, 1.9168764D-05, 2.6134346D-05 /
      data fpp( 4,17,15,1),fpp( 4,17,15,2),fpp( 4,17,15,3)/
     x-8.3071856D-03, 8.1137250D-05, 2.4677740D-05 /
      data fpp( 4,17,16,1),fpp( 4,17,16,2),fpp( 4,17,16,3)/
     x-3.3405549D-03, 1.9168764D-05, 1.6653360D-05 /
      data fpp( 4,17,17,1),fpp( 4,17,17,2),fpp( 4,17,17,3)/
     x 6.6623418D-02,-9.0317291D-05, 1.0505487D-05 /
      data fpp( 4,18, 1,1),fpp( 4,18, 1,2),fpp( 4,18, 1,3)/
     x 1.5985809D-02,-8.6639060D-05,-3.7122576D-06 /
      data fpp( 4,18, 2,1),fpp( 4,18, 2,2),fpp( 4,18, 2,3)/
     x 3.8026726D-02,-2.6360979D-04, 8.8640399D-07 /
      data fpp( 4,18, 3,1),fpp( 4,18, 3,2),fpp( 4,18, 3,3)/
     x 3.5677729D-02,-3.1070793D-04, 9.8099749D-06 /
      data fpp( 4,18, 4,1),fpp( 4,18, 4,2),fpp( 4,18, 4,3)/
     x 3.8026726D-02,-2.6360979D-04, 3.5963630D-06 /
      data fpp( 4,18, 5,1),fpp( 4,18, 5,2),fpp( 4,18, 5,3)/
     x 1.5985809D-02,-8.6639060D-05,-1.4552094D-05 /
      data fpp( 4,18, 6,1),fpp( 4,18, 6,2),fpp( 4,18, 6,3)/
     x 2.8215287D-02, 5.4073435D-05,-1.4278655D-05 /
      data fpp( 4,18, 7,1),fpp( 4,18, 7,2),fpp( 4,18, 7,3)/
     x-1.4156539D-02, 2.0588376D-05, 2.7373816D-06 /
      data fpp( 4,18, 8,1),fpp( 4,18, 8,2),fpp( 4,18, 8,3)/
     x-2.3310985D-02, 3.0620195D-06, 1.1006462D-05 /
      data fpp( 4,18, 9,1),fpp( 4,18, 9,2),fpp( 4,18, 9,3)/
     x-2.4516010D-02, 3.5794155D-06, 1.3622769D-05 /
      data fpp( 4,18,10,1),fpp( 4,18,10,2),fpp( 4,18,10,3)/
     x-2.3310985D-02, 3.0620195D-06, 1.1006462D-05 /
      data fpp( 4,18,11,1),fpp( 4,18,11,2),fpp( 4,18,11,3)/
     x-1.4156539D-02, 2.0588376D-05, 2.7373816D-06 /
      data fpp( 4,18,12,1),fpp( 4,18,12,2),fpp( 4,18,12,3)/
     x 2.8215287D-02, 5.4073435D-05,-1.4278655D-05 /
      data fpp( 4,18,13,1),fpp( 4,18,13,2),fpp( 4,18,13,3)/
     x 1.5985809D-02,-8.6639060D-05,-1.4552094D-05 /
      data fpp( 4,18,14,1),fpp( 4,18,14,2),fpp( 4,18,14,3)/
     x 3.8026726D-02,-2.6360979D-04, 3.5963630D-06 /
      data fpp( 4,18,15,1),fpp( 4,18,15,2),fpp( 4,18,15,3)/
     x 3.5677729D-02,-3.1070793D-04, 9.8099749D-06 /
      data fpp( 4,18,16,1),fpp( 4,18,16,2),fpp( 4,18,16,3)/
     x 3.8026726D-02,-2.6360979D-04, 8.8640399D-07 /
      data fpp( 4,18,17,1),fpp( 4,18,17,2),fpp( 4,18,17,3)/
     x 1.5985809D-02,-8.6639060D-05,-3.7122576D-06 /
      data fpp( 4,19, 1,1),fpp( 4,19, 1,2),fpp( 4,19, 1,3)/
     x 2.3724888D-02,-9.6946470D-05,-1.4549058D-20 /
      data fpp( 4,19, 2,1),fpp( 4,19, 2,2),fpp( 4,19, 2,3)/
     x 2.3724888D-02,-4.8437961D-04, 3.7412531D-20 /
      data fpp( 4,19, 3,1),fpp( 4,19, 3,2),fpp( 4,19, 3,3)/
     x 2.3724888D-02,-6.0119554D-04, 1.7520683D-20 /
      data fpp( 4,19, 4,1),fpp( 4,19, 4,2),fpp( 4,19, 4,3)/
     x 2.3724888D-02,-4.8437961D-04,-1.7424765D-21 /
      data fpp( 4,19, 5,1),fpp( 4,19, 5,2),fpp( 4,19, 5,3)/
     x 2.3724888D-02,-9.6946470D-05, 8.8159242D-21 /
      data fpp( 4,19, 6,1),fpp( 4,19, 6,2),fpp( 4,19, 6,3)/
     x 2.3724888D-02, 1.2978828D-04, 1.4058403D-20 /
      data fpp( 4,19, 7,1),fpp( 4,19, 7,2),fpp( 4,19, 7,3)/
     x 2.3724888D-02, 1.8219312D-05, 2.2202941D-20 /
      data fpp( 4,19, 8,1),fpp( 4,19, 8,2),fpp( 4,19, 8,3)/
     x 2.3724888D-02,-7.1335510D-05,-3.3624762D-20 /
      data fpp( 4,19, 9,1),fpp( 4,19, 9,2),fpp( 4,19, 9,3)/
     x 2.3724888D-02,-9.3314708D-05,-4.7557792D-21 /
      data fpp( 4,19,10,1),fpp( 4,19,10,2),fpp( 4,19,10,3)/
     x 2.3724888D-02,-7.1335510D-05, 2.3361649D-20 /
      data fpp( 4,19,11,1),fpp( 4,19,11,2),fpp( 4,19,11,3)/
     x 2.3724888D-02, 1.8219312D-05,-9.9246627D-21 /
      data fpp( 4,19,12,1),fpp( 4,19,12,2),fpp( 4,19,12,3)/
     x 2.3724888D-02, 1.2978828D-04, 1.0595404D-20 /
      data fpp( 4,19,13,1),fpp( 4,19,13,2),fpp( 4,19,13,3)/
     x 2.3724888D-02,-9.6946470D-05, 1.1825690D-22 /
      data fpp( 4,19,14,1),fpp( 4,19,14,2),fpp( 4,19,14,3)/
     x 2.3724888D-02,-4.8437961D-04,-3.1704854D-21 /
      data fpp( 4,19,15,1),fpp( 4,19,15,2),fpp( 4,19,15,3)/
     x 2.3724888D-02,-6.0119554D-04,-1.7366310D-21 /
      data fpp( 4,19,16,1),fpp( 4,19,16,2),fpp( 4,19,16,3)/
     x 2.3724888D-02,-4.8437961D-04,-1.0202568D-20 /
      data fpp( 4,19,17,1),fpp( 4,19,17,2),fpp( 4,19,17,3)/
     x 2.3724888D-02,-9.6946470D-05, 1.4177322D-20 /
      data fpp( 5, 1, 1,1),fpp( 5, 1, 1,2),fpp( 5, 1, 1,3)/
     x 4.8081511D-02, 2.5966778D-06,-1.9959914D-20 /
      data fpp( 5, 1, 2,1),fpp( 5, 1, 2,2),fpp( 5, 1, 2,3)/
     x 4.8081511D-02,-5.0172254D-05, 2.3346150D-20 /
      data fpp( 5, 1, 3,1),fpp( 5, 1, 3,2),fpp( 5, 1, 3,3)/
     x 4.8081511D-02,-7.7255523D-05, 2.1151693D-20 /
      data fpp( 5, 1, 4,1),fpp( 5, 1, 4,2),fpp( 5, 1, 4,3)/
     x 4.8081511D-02,-5.0172254D-05, 2.6339001D-21 /
      data fpp( 5, 1, 5,1),fpp( 5, 1, 5,2),fpp( 5, 1, 5,3)/
     x 4.8081511D-02, 2.5966778D-06, 5.4953363D-21 /
      data fpp( 5, 1, 6,1),fpp( 5, 1, 6,2),fpp( 5, 1, 6,3)/
     x 4.8081511D-02, 2.7726558D-05, 1.7108943D-22 /
      data fpp( 5, 1, 7,1),fpp( 5, 1, 7,2),fpp( 5, 1, 7,3)/
     x 4.8081511D-02, 6.4191762D-06, 1.1298023D-20 /
      data fpp( 5, 1, 8,1),fpp( 5, 1, 8,2),fpp( 5, 1, 8,3)/
     x 4.8081511D-02,-3.1294261D-05,-1.9766043D-20 /
      data fpp( 5, 1, 9,1),fpp( 5, 1, 9,2),fpp( 5, 1, 9,3)/
     x 4.8081511D-02,-4.8020860D-05,-1.0570178D-20 /
      data fpp( 5, 1,10,1),fpp( 5, 1,10,2),fpp( 5, 1,10,3)/
     x 4.8081511D-02,-3.1294261D-05, 2.1265428D-20 /
      data fpp( 5, 1,11,1),fpp( 5, 1,11,2),fpp( 5, 1,11,3)/
     x 4.8081511D-02, 6.4191762D-06,-3.5958168D-23 /
      data fpp( 5, 1,12,1),fpp( 5, 1,12,2),fpp( 5, 1,12,3)/
     x 4.8081511D-02, 2.7726558D-05, 1.1107485D-21 /
      data fpp( 5, 1,13,1),fpp( 5, 1,13,2),fpp( 5, 1,13,3)/
     x 4.8081511D-02, 2.5966778D-06, 6.5494915D-21 /
      data fpp( 5, 1,14,1),fpp( 5, 1,14,2),fpp( 5, 1,14,3)/
     x 4.8081511D-02,-5.0172254D-05,-4.1258947D-21 /
      data fpp( 5, 1,15,1),fpp( 5, 1,15,2),fpp( 5, 1,15,3)/
     x 4.8081511D-02,-7.7255523D-05,-4.3364555D-21 /
      data fpp( 5, 1,16,1),fpp( 5, 1,16,2),fpp( 5, 1,16,3)/
     x 4.8081511D-02,-5.0172254D-05,-4.8109761D-22 /
      data fpp( 5, 1,17,1),fpp( 5, 1,17,2),fpp( 5, 1,17,3)/
     x 4.8081511D-02, 2.5966778D-06, 1.4522695D-21 /
      data fpp( 5, 2, 1,1),fpp( 5, 2, 1,2),fpp( 5, 2, 1,3)/
     x 4.6017910D-02,-5.0433556D-06, 2.7483301D-07 /
      data fpp( 5, 2, 2,1),fpp( 5, 2, 2,2),fpp( 5, 2, 2,3)/
     x 4.2274813D-02,-2.7346492D-05, 1.1416673D-06 /
      data fpp( 5, 2, 3,1),fpp( 5, 2, 3,2),fpp( 5, 2, 3,3)/
     x 4.0562660D-02,-4.1749954D-05, 2.9624977D-06 /
      data fpp( 5, 2, 4,1),fpp( 5, 2, 4,2),fpp( 5, 2, 4,3)/
     x 4.2274813D-02,-2.7346492D-05, 1.4443418D-06 /
      data fpp( 5, 2, 5,1),fpp( 5, 2, 5,2),fpp( 5, 2, 5,3)/
     x 4.6017910D-02,-5.0433556D-06,-9.3586508D-07 /
      data fpp( 5, 2, 6,1),fpp( 5, 2, 6,2),fpp( 5, 2, 6,3)/
     x 4.8629716D-02, 3.1448830D-06,-2.0468815D-06 /
      data fpp( 5, 2, 7,1),fpp( 5, 2, 7,2),fpp( 5, 2, 7,3)/
     x 4.8610641D-02,-5.6743525D-06,-1.1639422D-06 /
      data fpp( 5, 2, 8,1),fpp( 5, 2, 8,2),fpp( 5, 2, 8,3)/
     x 4.7388005D-02,-2.1128479D-05, 5.5598347D-07 /
      data fpp( 5, 2, 9,1),fpp( 5, 2, 9,2),fpp( 5, 2, 9,3)/
     x 4.6785583D-02,-2.8395280D-05, 1.3806749D-06 /
      data fpp( 5, 2,10,1),fpp( 5, 2,10,2),fpp( 5, 2,10,3)/
     x 4.7388005D-02,-2.1128479D-05, 5.5598347D-07 /
      data fpp( 5, 2,11,1),fpp( 5, 2,11,2),fpp( 5, 2,11,3)/
     x 4.8610641D-02,-5.6743525D-06,-1.1639422D-06 /
      data fpp( 5, 2,12,1),fpp( 5, 2,12,2),fpp( 5, 2,12,3)/
     x 4.8629716D-02, 3.1448830D-06,-2.0468815D-06 /
      data fpp( 5, 2,13,1),fpp( 5, 2,13,2),fpp( 5, 2,13,3)/
     x 4.6017910D-02,-5.0433556D-06,-9.3586508D-07 /
      data fpp( 5, 2,14,1),fpp( 5, 2,14,2),fpp( 5, 2,14,3)/
     x 4.2274813D-02,-2.7346492D-05, 1.4443418D-06 /
      data fpp( 5, 2,15,1),fpp( 5, 2,15,2),fpp( 5, 2,15,3)/
     x 4.0562660D-02,-4.1749954D-05, 2.9624977D-06 /
      data fpp( 5, 2,16,1),fpp( 5, 2,16,2),fpp( 5, 2,16,3)/
     x 4.2274813D-02,-2.7346492D-05, 1.1416673D-06 /
      data fpp( 5, 2,17,1),fpp( 5, 2,17,2),fpp( 5, 2,17,3)/
     x 4.6017910D-02,-5.0433556D-06, 2.7483301D-07 /
      data fpp( 5, 3, 1,1),fpp( 5, 3, 1,2),fpp( 5, 3, 1,3)/
     x 4.3297768D-02,-1.5351255D-05,-1.1251958D-06 /
      data fpp( 5, 3, 2,1),fpp( 5, 3, 2,2),fpp( 5, 3, 2,3)/
     x 3.4279738D-02,-9.0237775D-06, 2.6276139D-06 /
      data fpp( 5, 3, 3,1),fpp( 5, 3, 3,2),fpp( 5, 3, 3,3)/
     x 3.1752312D-02,-1.7722663D-05, 1.0918074D-05 /
      data fpp( 5, 3, 4,1),fpp( 5, 3, 4,2),fpp( 5, 3, 4,3)/
     x 3.4279738D-02,-9.0237775D-06, 3.3267585D-06 /
      data fpp( 5, 3, 5,1),fpp( 5, 3, 5,2),fpp( 5, 3, 5,3)/
     x 4.3297768D-02,-1.5351255D-05,-3.9217741D-06 /
      data fpp( 5, 3, 6,1),fpp( 5, 3, 6,2),fpp( 5, 3, 6,3)/
     x 4.9138602D-02,-2.7046091D-05,-6.2723286D-06 /
      data fpp( 5, 3, 7,1),fpp( 5, 3, 7,2),fpp( 5, 3, 7,3)/
     x 4.7784840D-02,-2.5481766D-05,-2.8089115D-06 /
      data fpp( 5, 3, 8,1),fpp( 5, 3, 8,2),fpp( 5, 3, 8,3)/
     x 4.2964836D-02,-9.8378235D-06, 2.0073081D-06 /
      data fpp( 5, 3, 9,1),fpp( 5, 3, 9,2),fpp( 5, 3, 9,3)/
     x 4.1242250D-02,-4.0520213D-06, 4.5363460D-06 /
      data fpp( 5, 3,10,1),fpp( 5, 3,10,2),fpp( 5, 3,10,3)/
     x 4.2964836D-02,-9.8378235D-06, 2.0073081D-06 /
      data fpp( 5, 3,11,1),fpp( 5, 3,11,2),fpp( 5, 3,11,3)/
     x 4.7784840D-02,-2.5481766D-05,-2.8089115D-06 /
      data fpp( 5, 3,12,1),fpp( 5, 3,12,2),fpp( 5, 3,12,3)/
     x 4.9138602D-02,-2.7046091D-05,-6.2723286D-06 /
      data fpp( 5, 3,13,1),fpp( 5, 3,13,2),fpp( 5, 3,13,3)/
     x 4.3297768D-02,-1.5351255D-05,-3.9217741D-06 /
      data fpp( 5, 3,14,1),fpp( 5, 3,14,2),fpp( 5, 3,14,3)/
     x 3.4279738D-02,-9.0237775D-06, 3.3267585D-06 /
      data fpp( 5, 3,15,1),fpp( 5, 3,15,2),fpp( 5, 3,15,3)/
     x 3.1752312D-02,-1.7722663D-05, 1.0918074D-05 /
      data fpp( 5, 3,16,1),fpp( 5, 3,16,2),fpp( 5, 3,16,3)/
     x 3.4279738D-02,-9.0237775D-06, 2.6276139D-06 /
      data fpp( 5, 3,17,1),fpp( 5, 3,17,2),fpp( 5, 3,17,3)/
     x 4.3297768D-02,-1.5351255D-05,-1.1251958D-06 /
      data fpp( 5, 4, 1,1),fpp( 5, 4, 1,2),fpp( 5, 4, 1,3)/
     x 3.8612467D-02,-1.6321623D-05,-5.9964226D-06 /
      data fpp( 5, 4, 2,1),fpp( 5, 4, 2,2),fpp( 5, 4, 2,3)/
     x 2.9553671D-02, 2.5059602D-05, 2.3159563D-06 /
      data fpp( 5, 4, 3,1),fpp( 5, 4, 3,2),fpp( 5, 4, 3,3)/
     x 3.9474153D-02, 4.6478604D-05, 2.1516597D-05 /
      data fpp( 5, 4, 4,1),fpp( 5, 4, 4,2),fpp( 5, 4, 4,3)/
     x 2.9553671D-02, 2.5059602D-05, 2.6083205D-06 /
      data fpp( 5, 4, 5,1),fpp( 5, 4, 5,2),fpp( 5, 4, 5,3)/
     x 3.8612467D-02,-1.6321623D-05,-7.1658796D-06 /
      data fpp( 5, 4, 6,1),fpp( 5, 4, 6,2),fpp( 5, 4, 6,3)/
     x 4.5653874D-02,-3.7604520D-05,-8.5848020D-06 /
      data fpp( 5, 4, 7,1),fpp( 5, 4, 7,2),fpp( 5, 4, 7,3)/
     x 5.2922603D-02,-1.8290582D-05,-3.3335789D-06 /
      data fpp( 5, 4, 8,1),fpp( 5, 4, 8,2),fpp( 5, 4, 8,3)/
     x 3.8842542D-02,-2.4842268D-06, 2.1951178D-06 /
      data fpp( 5, 4, 9,1),fpp( 5, 4, 9,2),fpp( 5, 4, 9,3)/
     x 3.5521252D-02, 3.7793650D-06, 7.0937744D-06 /
      data fpp( 5, 4,10,1),fpp( 5, 4,10,2),fpp( 5, 4,10,3)/
     x 3.8842542D-02,-2.4842268D-06, 2.1951178D-06 /
      data fpp( 5, 4,11,1),fpp( 5, 4,11,2),fpp( 5, 4,11,3)/
     x 5.2922603D-02,-1.8290582D-05,-3.3335789D-06 /
      data fpp( 5, 4,12,1),fpp( 5, 4,12,2),fpp( 5, 4,12,3)/
     x 4.5653874D-02,-3.7604520D-05,-8.5848020D-06 /
      data fpp( 5, 4,13,1),fpp( 5, 4,13,2),fpp( 5, 4,13,3)/
     x 3.8612467D-02,-1.6321623D-05,-7.1658796D-06 /
      data fpp( 5, 4,14,1),fpp( 5, 4,14,2),fpp( 5, 4,14,3)/
     x 2.9553671D-02, 2.5059602D-05, 2.6083205D-06 /
      data fpp( 5, 4,15,1),fpp( 5, 4,15,2),fpp( 5, 4,15,3)/
     x 3.9474153D-02, 4.6478604D-05, 2.1516597D-05 /
      data fpp( 5, 4,16,1),fpp( 5, 4,16,2),fpp( 5, 4,16,3)/
     x 2.9553671D-02, 2.5059602D-05, 2.3159563D-06 /
      data fpp( 5, 4,17,1),fpp( 5, 4,17,2),fpp( 5, 4,17,3)/
     x 3.8612467D-02,-1.6321623D-05,-5.9964226D-06 /
      data fpp( 5, 5, 1,1),fpp( 5, 5, 1,2),fpp( 5, 5, 1,3)/
     x 3.1025881D-02,-4.5982537D-06,-1.2296455D-05 /
      data fpp( 5, 5, 2,1),fpp( 5, 5, 2,2),fpp( 5, 5, 2,3)/
     x 2.6122999D-02, 4.0725369D-05,-2.8197953D-07 /
      data fpp( 5, 5, 3,1),fpp( 5, 5, 3,2),fpp( 5, 5, 3,3)/
     x 6.1606284D-02, 5.3538247D-05, 2.8535039D-05 /
      data fpp( 5, 5, 4,1),fpp( 5, 5, 4,2),fpp( 5, 5, 4,3)/
     x 2.6122999D-02, 4.0725369D-05,-1.4568450D-06 /
      data fpp( 5, 5, 5,1),fpp( 5, 5, 5,2),fpp( 5, 5, 5,3)/
     x 3.1025881D-02,-4.5982537D-06,-7.5969927D-06 /
      data fpp( 5, 5, 6,1),fpp( 5, 5, 6,2),fpp( 5, 5, 6,3)/
     x 3.6278537D-02,-1.3425828D-05,-6.4111841D-06 /
      data fpp( 5, 5, 7,1),fpp( 5, 5, 7,2),fpp( 5, 5, 7,3)/
     x 6.7221346D-02,-1.3129904D-05,-4.0856043D-06 /
      data fpp( 5, 5, 8,1),fpp( 5, 5, 8,2),fpp( 5, 5, 8,3)/
     x 3.3648149D-02, 5.5427309D-06, 8.5360122D-07 /
      data fpp( 5, 5, 9,1),fpp( 5, 5, 9,2),fpp( 5, 5, 9,3)/
     x 2.9360338D-02, 6.2505614D-06, 8.6631994D-06 /
      data fpp( 5, 5,10,1),fpp( 5, 5,10,2),fpp( 5, 5,10,3)/
     x 3.3648149D-02, 5.5427309D-06, 8.5360122D-07 /
      data fpp( 5, 5,11,1),fpp( 5, 5,11,2),fpp( 5, 5,11,3)/
     x 6.7221346D-02,-1.3129904D-05,-4.0856043D-06 /
      data fpp( 5, 5,12,1),fpp( 5, 5,12,2),fpp( 5, 5,12,3)/
     x 3.6278537D-02,-1.3425828D-05,-6.4111841D-06 /
      data fpp( 5, 5,13,1),fpp( 5, 5,13,2),fpp( 5, 5,13,3)/
     x 3.1025881D-02,-4.5982537D-06,-7.5969927D-06 /
      data fpp( 5, 5,14,1),fpp( 5, 5,14,2),fpp( 5, 5,14,3)/
     x 2.6122999D-02, 4.0725369D-05,-1.4568450D-06 /
      data fpp( 5, 5,15,1),fpp( 5, 5,15,2),fpp( 5, 5,15,3)/
     x 6.1606284D-02, 5.3538247D-05, 2.8535039D-05 /
      data fpp( 5, 5,16,1),fpp( 5, 5,16,2),fpp( 5, 5,16,3)/
     x 2.6122999D-02, 4.0725369D-05,-2.8197953D-07 /
      data fpp( 5, 5,17,1),fpp( 5, 5,17,2),fpp( 5, 5,17,3)/
     x 3.1025881D-02,-4.5982537D-06,-1.2296455D-05 /
      data fpp( 5, 6, 1,1),fpp( 5, 6, 1,2),fpp( 5, 6, 1,3)/
     x 2.2679610D-02, 5.9986376D-06,-1.9396357D-05 /
      data fpp( 5, 6, 2,1),fpp( 5, 6, 2,2),fpp( 5, 6, 2,3)/
     x 1.9643751D-02, 2.5158920D-05,-5.1653966D-06 /
      data fpp( 5, 6, 3,1),fpp( 5, 6, 3,2),fpp( 5, 6, 3,3)/
     x 4.9123540D-02, 6.3530407D-05, 3.0962610D-05 /
      data fpp( 5, 6, 4,1),fpp( 5, 6, 4,2),fpp( 5, 6, 4,3)/
     x 1.9643751D-02, 2.5158920D-05,-9.5490443D-06 /
      data fpp( 5, 6, 5,1),fpp( 5, 6, 5,2),fpp( 5, 6, 5,3)/
     x 2.2679610D-02, 5.9986376D-06,-1.8617662D-06 /
      data fpp( 5, 6, 6,1),fpp( 5, 6, 6,2),fpp( 5, 6, 6,3)/
     x 2.4188787D-02, 8.0218308D-06,-4.0685575D-06 /
      data fpp( 5, 6, 7,1),fpp( 5, 6, 7,2),fpp( 5, 6, 7,3)/
     x 5.0950723D-02, 1.3948200D-05,-2.6806704D-06 /
      data fpp( 5, 6, 8,1),fpp( 5, 6, 8,2),fpp( 5, 6, 8,3)/
     x 2.5232857D-02, 3.9053034D-06,-3.2814275D-06 /
      data fpp( 5, 6, 9,1),fpp( 5, 6, 9,2),fpp( 5, 6, 9,3)/
     x 2.2912201D-02, 2.7243893D-06, 1.1189714D-05 /
      data fpp( 5, 6,10,1),fpp( 5, 6,10,2),fpp( 5, 6,10,3)/
     x 2.5232857D-02, 3.9053034D-06,-3.2814275D-06 /
      data fpp( 5, 6,11,1),fpp( 5, 6,11,2),fpp( 5, 6,11,3)/
     x 5.0950723D-02, 1.3948200D-05,-2.6806704D-06 /
      data fpp( 5, 6,12,1),fpp( 5, 6,12,2),fpp( 5, 6,12,3)/
     x 2.4188787D-02, 8.0218308D-06,-4.0685575D-06 /
      data fpp( 5, 6,13,1),fpp( 5, 6,13,2),fpp( 5, 6,13,3)/
     x 2.2679610D-02, 5.9986376D-06,-1.8617662D-06 /
      data fpp( 5, 6,14,1),fpp( 5, 6,14,2),fpp( 5, 6,14,3)/
     x 1.9643751D-02, 2.5158920D-05,-9.5490443D-06 /
      data fpp( 5, 6,15,1),fpp( 5, 6,15,2),fpp( 5, 6,15,3)/
     x 4.9123540D-02, 6.3530407D-05, 3.0962610D-05 /
      data fpp( 5, 6,16,1),fpp( 5, 6,16,2),fpp( 5, 6,16,3)/
     x 1.9643751D-02, 2.5158920D-05,-5.1653966D-06 /
      data fpp( 5, 6,17,1),fpp( 5, 6,17,2),fpp( 5, 6,17,3)/
     x 2.2679610D-02, 5.9986376D-06,-1.9396357D-05 /
      data fpp( 5, 7, 1,1),fpp( 5, 7, 1,2),fpp( 5, 7, 1,3)/
     x 1.5787263D-02, 9.6557033D-06,-1.7002277D-05 /
      data fpp( 5, 7, 2,1),fpp( 5, 7, 2,2),fpp( 5, 7, 2,3)/
     x 1.5279380D-02,-1.2973051D-05,-6.7835580D-06 /
      data fpp( 5, 7, 3,1),fpp( 5, 7, 3,2),fpp( 5, 7, 3,3)/
     x 2.0155923D-02, 9.4341247D-06, 2.0765175D-05 /
      data fpp( 5, 7, 4,1),fpp( 5, 7, 4,2),fpp( 5, 7, 4,3)/
     x 1.5279380D-02,-1.2973051D-05,-1.2341142D-05 /
      data fpp( 5, 7, 5,1),fpp( 5, 7, 5,2),fpp( 5, 7, 5,3)/
     x 1.5787263D-02, 9.6557033D-06, 5.2280612D-06 /
      data fpp( 5, 7, 6,1),fpp( 5, 7, 6,2),fpp( 5, 7, 6,3)/
     x 1.5638435D-02, 1.3996505D-05,-1.0064356D-06 /
      data fpp( 5, 7, 7,1),fpp( 5, 7, 7,2),fpp( 5, 7, 7,3)/
     x 2.2768950D-02, 1.0587104D-05,-3.6209853D-06 /
      data fpp( 5, 7, 8,1),fpp( 5, 7, 8,2),fpp( 5, 7, 8,3)/
     x 1.8398293D-02,-8.1439444D-06,-5.5129566D-06 /
      data fpp( 5, 7, 9,1),fpp( 5, 7, 9,2),fpp( 5, 7, 9,3)/
     x 1.6785759D-02,-5.0461188D-06, 1.2815478D-05 /
      data fpp( 5, 7,10,1),fpp( 5, 7,10,2),fpp( 5, 7,10,3)/
     x 1.8398293D-02,-8.1439444D-06,-5.5129566D-06 /
      data fpp( 5, 7,11,1),fpp( 5, 7,11,2),fpp( 5, 7,11,3)/
     x 2.2768950D-02, 1.0587104D-05,-3.6209853D-06 /
      data fpp( 5, 7,12,1),fpp( 5, 7,12,2),fpp( 5, 7,12,3)/
     x 1.5638435D-02, 1.3996505D-05,-1.0064356D-06 /
      data fpp( 5, 7,13,1),fpp( 5, 7,13,2),fpp( 5, 7,13,3)/
     x 1.5787263D-02, 9.6557033D-06, 5.2280612D-06 /
      data fpp( 5, 7,14,1),fpp( 5, 7,14,2),fpp( 5, 7,14,3)/
     x 1.5279380D-02,-1.2973051D-05,-1.2341142D-05 /
      data fpp( 5, 7,15,1),fpp( 5, 7,15,2),fpp( 5, 7,15,3)/
     x 2.0155923D-02, 9.4341247D-06, 2.0765175D-05 /
      data fpp( 5, 7,16,1),fpp( 5, 7,16,2),fpp( 5, 7,16,3)/
     x 1.5279380D-02,-1.2973051D-05,-6.7835580D-06 /
      data fpp( 5, 7,17,1),fpp( 5, 7,17,2),fpp( 5, 7,17,3)/
     x 1.5787263D-02, 9.6557033D-06,-1.7002277D-05 /
      data fpp( 5, 8, 1,1),fpp( 5, 8, 1,2),fpp( 5, 8, 1,3)/
     x 1.0742726D-02, 9.0965493D-06,-4.6891994D-06 /
      data fpp( 5, 8, 2,1),fpp( 5, 8, 2,2),fpp( 5, 8, 2,3)/
     x 1.3607797D-02,-3.0266718D-05,-3.2520455D-06 /
      data fpp( 5, 8, 3,1),fpp( 5, 8, 3,2),fpp( 5, 8, 3,3)/
     x 1.3505275D-02,-6.9850906D-05, 2.1760483D-06 /
      data fpp( 5, 8, 4,1),fpp( 5, 8, 4,2),fpp( 5, 8, 4,3)/
     x 1.3607797D-02,-3.0266718D-05,-6.3641477D-06 /
      data fpp( 5, 8, 5,1),fpp( 5, 8, 5,2),fpp( 5, 8, 5,3)/
     x 1.0742726D-02, 9.0965493D-06, 7.7592090D-06 /
      data fpp( 5, 8, 6,1),fpp( 5, 8, 6,2),fpp( 5, 8, 6,3)/
     x 1.1524355D-02, 1.6998151D-05, 2.2513117D-06 /
      data fpp( 5, 8, 7,1),fpp( 5, 8, 7,2),fpp( 5, 8, 7,3)/
     x 1.3919374D-02,-6.5926157D-06,-7.2951224D-06 /
      data fpp( 5, 8, 8,1),fpp( 5, 8, 8,2),fpp( 5, 8, 8,3)/
     x 1.3122552D-02,-1.2129526D-05,-3.5828222D-06 /
      data fpp( 5, 8, 9,1),fpp( 5, 8, 9,2),fpp( 5, 8, 9,3)/
     x 1.0234046D-02,-1.2683914D-05, 1.1768411D-05 /
      data fpp( 5, 8,10,1),fpp( 5, 8,10,2),fpp( 5, 8,10,3)/
     x 1.3122552D-02,-1.2129526D-05,-3.5828222D-06 /
      data fpp( 5, 8,11,1),fpp( 5, 8,11,2),fpp( 5, 8,11,3)/
     x 1.3919374D-02,-6.5926157D-06,-7.2951224D-06 /
      data fpp( 5, 8,12,1),fpp( 5, 8,12,2),fpp( 5, 8,12,3)/
     x 1.1524355D-02, 1.6998151D-05, 2.2513117D-06 /
      data fpp( 5, 8,13,1),fpp( 5, 8,13,2),fpp( 5, 8,13,3)/
     x 1.0742726D-02, 9.0965493D-06, 7.7592090D-06 /
      data fpp( 5, 8,14,1),fpp( 5, 8,14,2),fpp( 5, 8,14,3)/
     x 1.3607797D-02,-3.0266718D-05,-6.3641477D-06 /
      data fpp( 5, 8,15,1),fpp( 5, 8,15,2),fpp( 5, 8,15,3)/
     x 1.3505275D-02,-6.9850906D-05, 2.1760483D-06 /
      data fpp( 5, 8,16,1),fpp( 5, 8,16,2),fpp( 5, 8,16,3)/
     x 1.3607797D-02,-3.0266718D-05,-3.2520455D-06 /
      data fpp( 5, 8,17,1),fpp( 5, 8,17,2),fpp( 5, 8,17,3)/
     x 1.0742726D-02, 9.0965493D-06,-4.6891994D-06 /
      data fpp( 5, 9, 1,1),fpp( 5, 9, 1,2),fpp( 5, 9, 1,3)/
     x 7.0707050D-03, 8.1740996D-06, 3.4766142D-06 /
      data fpp( 5, 9, 2,1),fpp( 5, 9, 2,2),fpp( 5, 9, 2,3)/
     x 9.2065007D-03,-2.3766078D-05, 1.7266050D-07 /
      data fpp( 5, 9, 3,1),fpp( 5, 9, 3,2),fpp( 5, 9, 3,3)/
     x 1.1513914D-02,-5.6034501D-05,-6.9692562D-06 /
      data fpp( 5, 9, 4,1),fpp( 5, 9, 4,2),fpp( 5, 9, 4,3)/
     x 9.2065007D-03,-2.3766078D-05,-6.7830244D-07 /
      data fpp( 5, 9, 5,1),fpp( 5, 9, 5,2),fpp( 5, 9, 5,3)/
     x 7.0707050D-03, 8.1740996D-06, 6.8804659D-06 /
      data fpp( 5, 9, 6,1),fpp( 5, 9, 6,2),fpp( 5, 9, 6,3)/
     x 9.6415600D-03, 2.0082891D-05, 1.1991053D-06 /
      data fpp( 5, 9, 7,1),fpp( 5, 9, 7,2),fpp( 5, 9, 7,3)/
     x 1.1026563D-02, 2.6793590D-06,-8.4342207D-06 /
      data fpp( 5, 9, 8,1),fpp( 5, 9, 8,2),fpp( 5, 9, 8,3)/
     x 6.3798476D-03,-1.1893953D-05,-8.4688933D-07 /
      data fpp( 5, 9, 9,1),fpp( 5, 9, 9,2),fpp( 5, 9, 9,3)/
     x 2.3809941D-03,-1.7610225D-05, 1.0587111D-05 /
      data fpp( 5, 9,10,1),fpp( 5, 9,10,2),fpp( 5, 9,10,3)/
     x 6.3798476D-03,-1.1893953D-05,-8.4688933D-07 /
      data fpp( 5, 9,11,1),fpp( 5, 9,11,2),fpp( 5, 9,11,3)/
     x 1.1026563D-02, 2.6793590D-06,-8.4342207D-06 /
      data fpp( 5, 9,12,1),fpp( 5, 9,12,2),fpp( 5, 9,12,3)/
     x 9.6415600D-03, 2.0082891D-05, 1.1991053D-06 /
      data fpp( 5, 9,13,1),fpp( 5, 9,13,2),fpp( 5, 9,13,3)/
     x 7.0707050D-03, 8.1740996D-06, 6.8804659D-06 /
      data fpp( 5, 9,14,1),fpp( 5, 9,14,2),fpp( 5, 9,14,3)/
     x 9.2065007D-03,-2.3766078D-05,-6.7830244D-07 /
      data fpp( 5, 9,15,1),fpp( 5, 9,15,2),fpp( 5, 9,15,3)/
     x 1.1513914D-02,-5.6034501D-05,-6.9692562D-06 /
      data fpp( 5, 9,16,1),fpp( 5, 9,16,2),fpp( 5, 9,16,3)/
     x 9.2065007D-03,-2.3766078D-05, 1.7266050D-07 /
      data fpp( 5, 9,17,1),fpp( 5, 9,17,2),fpp( 5, 9,17,3)/
     x 7.0707050D-03, 8.1740996D-06, 3.4766142D-06 /
      data fpp( 5,10, 1,1),fpp( 5,10, 1,2),fpp( 5,10, 1,3)/
     x 4.4235311D-03, 9.4890525D-06, 5.8687919D-06 /
      data fpp( 5,10, 2,1),fpp( 5,10, 2,2),fpp( 5,10, 2,3)/
     x 1.8352990D-03,-1.3280969D-05, 2.5884163D-06 /
      data fpp( 5,10, 3,1),fpp( 5,10, 3,2),fpp( 5,10, 3,3)/
     x 2.2980241D-03,-2.5457090D-05,-5.2984570D-06 /
      data fpp( 5,10, 4,1),fpp( 5,10, 4,2),fpp( 5,10, 4,3)/
     x 1.8352990D-03,-1.3280969D-05, 2.9374119D-06 /
      data fpp( 5,10, 5,1),fpp( 5,10, 5,2),fpp( 5,10, 5,3)/
     x 4.4235311D-03, 9.4890525D-06, 4.4728095D-06 /
      data fpp( 5,10, 6,1),fpp( 5,10, 6,2),fpp( 5,10, 6,3)/
     x 9.5309605D-03, 2.4038285D-05,-4.9793166D-06 /
      data fpp( 5,10, 7,1),fpp( 5,10, 7,2),fpp( 5,10, 7,3)/
     x 7.3853152D-03, 6.2791796D-06,-7.6562096D-06 /
      data fpp( 5,10, 8,1),fpp( 5,10, 8,2),fpp( 5,10, 8,3)/
     x-1.6801336D-03,-1.2198662D-05, 2.5308218D-06 /
      data fpp( 5,10, 9,1),fpp( 5,10, 9,2),fpp( 5,10, 9,3)/
     x-6.2869632D-03,-1.8671188D-05, 1.0745589D-05 /
      data fpp( 5,10,10,1),fpp( 5,10,10,2),fpp( 5,10,10,3)/
     x-1.6801336D-03,-1.2198662D-05, 2.5308218D-06 /
      data fpp( 5,10,11,1),fpp( 5,10,11,2),fpp( 5,10,11,3)/
     x 7.3853152D-03, 6.2791796D-06,-7.6562096D-06 /
      data fpp( 5,10,12,1),fpp( 5,10,12,2),fpp( 5,10,12,3)/
     x 9.5309605D-03, 2.4038285D-05,-4.9793166D-06 /
      data fpp( 5,10,13,1),fpp( 5,10,13,2),fpp( 5,10,13,3)/
     x 4.4235311D-03, 9.4890525D-06, 4.4728095D-06 /
      data fpp( 5,10,14,1),fpp( 5,10,14,2),fpp( 5,10,14,3)/
     x 1.8352990D-03,-1.3280969D-05, 2.9374119D-06 /
      data fpp( 5,10,15,1),fpp( 5,10,15,2),fpp( 5,10,15,3)/
     x 2.2980241D-03,-2.5457090D-05,-5.2984570D-06 /
      data fpp( 5,10,16,1),fpp( 5,10,16,2),fpp( 5,10,16,3)/
     x 1.8352990D-03,-1.3280969D-05, 2.5884163D-06 /
      data fpp( 5,10,17,1),fpp( 5,10,17,2),fpp( 5,10,17,3)/
     x 4.4235311D-03, 9.4890525D-06, 5.8687919D-06 /
      data fpp( 5,11, 1,1),fpp( 5,11, 1,2),fpp( 5,11, 1,3)/
     x 2.8258274D-03, 1.4835691D-05, 7.3838374D-06 /
      data fpp( 5,11, 2,1),fpp( 5,11, 2,2),fpp( 5,11, 2,3)/
     x-5.5477770D-03,-2.1240453D-06, 5.6715474D-06 /
      data fpp( 5,11, 3,1),fpp( 5,11, 3,2),fpp( 5,11, 3,3)/
     x-7.9518550D-03,-5.4391394D-06, 7.6797306D-07 /
      data fpp( 5,11, 4,1),fpp( 5,11, 4,2),fpp( 5,11, 4,3)/
     x-5.5477770D-03,-2.1240453D-06, 7.0338937D-06 /
      data fpp( 5,11, 5,1),fpp( 5,11, 5,2),fpp( 5,11, 5,3)/
     x 2.8258274D-03, 1.4835691D-05, 1.9344521D-06 /
      data fpp( 5,11, 6,1),fpp( 5,11, 6,2),fpp( 5,11, 6,3)/
     x 1.1695321D-02, 3.1771970D-05,-1.6997702D-05 /
      data fpp( 5,11, 7,1),fpp( 5,11, 7,2),fpp( 5,11, 7,3)/
     x 3.5138840D-03, 7.9039226D-06,-5.5376444D-06 /
      data fpp( 5,11, 8,1),fpp( 5,11, 8,2),fpp( 5,11, 8,3)/
     x-9.4802780D-03,-9.2113985D-06, 7.1316127D-06 /
      data fpp( 5,11, 9,1),fpp( 5,11, 9,2),fpp( 5,11, 9,3)/
     x-1.4356177D-02,-1.4277025D-05, 1.2329860D-05 /
      data fpp( 5,11,10,1),fpp( 5,11,10,2),fpp( 5,11,10,3)/
     x-9.4802780D-03,-9.2113985D-06, 7.1316127D-06 /
      data fpp( 5,11,11,1),fpp( 5,11,11,2),fpp( 5,11,11,3)/
     x 3.5138840D-03, 7.9039226D-06,-5.5376444D-06 /
      data fpp( 5,11,12,1),fpp( 5,11,12,2),fpp( 5,11,12,3)/
     x 1.1695321D-02, 3.1771970D-05,-1.6997702D-05 /
      data fpp( 5,11,13,1),fpp( 5,11,13,2),fpp( 5,11,13,3)/
     x 2.8258274D-03, 1.4835691D-05, 1.9344521D-06 /
      data fpp( 5,11,14,1),fpp( 5,11,14,2),fpp( 5,11,14,3)/
     x-5.5477770D-03,-2.1240453D-06, 7.0338937D-06 /
      data fpp( 5,11,15,1),fpp( 5,11,15,2),fpp( 5,11,15,3)/
     x-7.9518550D-03,-5.4391394D-06, 7.6797306D-07 /
      data fpp( 5,11,16,1),fpp( 5,11,16,2),fpp( 5,11,16,3)/
     x-5.5477770D-03,-2.1240453D-06, 5.6715474D-06 /
      data fpp( 5,11,17,1),fpp( 5,11,17,2),fpp( 5,11,17,3)/
     x 2.8258274D-03, 1.4835691D-05, 7.3838374D-06 /
      data fpp( 5,12, 1,1),fpp( 5,12, 1,2),fpp( 5,12, 1,3)/
     x 2.5754039D-03, 2.3292185D-05, 1.0675848D-05 /
      data fpp( 5,12, 2,1),fpp( 5,12, 2,2),fpp( 5,12, 2,3)/
     x-1.0780152D-02, 1.3119150D-05, 1.0220414D-05 /
      data fpp( 5,12, 3,1),fpp( 5,12, 3,2),fpp( 5,12, 3,3)/
     x-1.5102492D-02, 1.2683648D-05, 7.5178275D-06 /
      data fpp( 5,12, 4,1),fpp( 5,12, 4,2),fpp( 5,12, 4,3)/
     x-1.0780152D-02, 1.3119150D-05, 1.2680276D-05 /
      data fpp( 5,12, 5,1),fpp( 5,12, 5,2),fpp( 5,12, 5,3)/
     x 2.5754039D-03, 2.3292185D-05, 8.3640311D-07 /
      data fpp( 5,12, 6,1),fpp( 5,12, 6,2),fpp( 5,12, 6,3)/
     x 1.6763100D-02, 3.8617834D-05,-3.6678555D-05 /
      data fpp( 5,12, 7,1),fpp( 5,12, 7,2),fpp( 5,12, 7,3)/
     x 2.3172885D-04, 1.2097130D-05,-5.8418397D-07 /
      data fpp( 5,12, 8,1),fpp( 5,12, 8,2),fpp( 5,12, 8,3)/
     x-1.5785563D-02, 4.7425605D-07, 1.2631957D-05 /
      data fpp( 5,12, 9,1),fpp( 5,12, 9,2),fpp( 5,12, 9,3)/
     x-2.0794667D-02,-2.5987126D-06, 1.5120355D-05 /
      data fpp( 5,12,10,1),fpp( 5,12,10,2),fpp( 5,12,10,3)/
     x-1.5785563D-02, 4.7425605D-07, 1.2631957D-05 /
      data fpp( 5,12,11,1),fpp( 5,12,11,2),fpp( 5,12,11,3)/
     x 2.3172885D-04, 1.2097130D-05,-5.8418397D-07 /
      data fpp( 5,12,12,1),fpp( 5,12,12,2),fpp( 5,12,12,3)/
     x 1.6763100D-02, 3.8617834D-05,-3.6678555D-05 /
      data fpp( 5,12,13,1),fpp( 5,12,13,2),fpp( 5,12,13,3)/
     x 2.5754039D-03, 2.3292185D-05, 8.3640311D-07 /
      data fpp( 5,12,14,1),fpp( 5,12,14,2),fpp( 5,12,14,3)/
     x-1.0780152D-02, 1.3119150D-05, 1.2680276D-05 /
      data fpp( 5,12,15,1),fpp( 5,12,15,2),fpp( 5,12,15,3)/
     x-1.5102492D-02, 1.2683648D-05, 7.5178275D-06 /
      data fpp( 5,12,16,1),fpp( 5,12,16,2),fpp( 5,12,16,3)/
     x-1.0780152D-02, 1.3119150D-05, 1.0220414D-05 /
      data fpp( 5,12,17,1),fpp( 5,12,17,2),fpp( 5,12,17,3)/
     x 2.5754039D-03, 2.3292185D-05, 1.0675848D-05 /
      data fpp( 5,13, 1,1),fpp( 5,13, 1,2),fpp( 5,13, 1,3)/
     x 5.2802953D-03, 3.3763569D-05, 1.5714277D-05 /
      data fpp( 5,13, 2,1),fpp( 5,13, 2,2),fpp( 5,13, 2,3)/
     x-1.3199243D-02, 3.4763444D-05, 1.5872002D-05 /
      data fpp( 5,13, 3,1),fpp( 5,13, 3,2),fpp( 5,13, 3,3)/
     x-1.8825790D-02, 3.5920549D-05, 1.3971714D-05 /
      data fpp( 5,13, 4,1),fpp( 5,13, 4,2),fpp( 5,13, 4,3)/
     x-1.3199243D-02, 3.4763444D-05, 1.9274475D-05 /
      data fpp( 5,13, 5,1),fpp( 5,13, 5,2),fpp( 5,13, 5,3)/
     x 5.2802953D-03, 3.3763569D-05, 2.1043846D-06 /
      data fpp( 5,13, 6,1),fpp( 5,13, 6,2),fpp( 5,13, 6,3)/
     x 2.7168435D-02, 3.4478693D-05,-6.4293347D-05 /
      data fpp( 5,13, 7,1),fpp( 5,13, 7,2),fpp( 5,13, 7,3)/
     x-2.0564663D-03, 1.7927557D-05, 8.6883370D-06 /
      data fpp( 5,13, 8,1),fpp( 5,13, 8,2),fpp( 5,13, 8,3)/
     x-2.0283643D-02, 1.8498374D-05, 1.8063999D-05 /
      data fpp( 5,13, 9,1),fpp( 5,13, 9,2),fpp( 5,13, 9,3)/
     x-2.5455199D-02, 1.8311875D-05, 1.8919667D-05 /
      data fpp( 5,13,10,1),fpp( 5,13,10,2),fpp( 5,13,10,3)/
     x-2.0283643D-02, 1.8498374D-05, 1.8063999D-05 /
      data fpp( 5,13,11,1),fpp( 5,13,11,2),fpp( 5,13,11,3)/
     x-2.0564663D-03, 1.7927557D-05, 8.6883370D-06 /
      data fpp( 5,13,12,1),fpp( 5,13,12,2),fpp( 5,13,12,3)/
     x 2.7168435D-02, 3.4478693D-05,-6.4293347D-05 /
      data fpp( 5,13,13,1),fpp( 5,13,13,2),fpp( 5,13,13,3)/
     x 5.2802953D-03, 3.3763569D-05, 2.1043846D-06 /
      data fpp( 5,13,14,1),fpp( 5,13,14,2),fpp( 5,13,14,3)/
     x-1.3199243D-02, 3.4763444D-05, 1.9274475D-05 /
      data fpp( 5,13,15,1),fpp( 5,13,15,2),fpp( 5,13,15,3)/
     x-1.8825790D-02, 3.5920549D-05, 1.3971714D-05 /
      data fpp( 5,13,16,1),fpp( 5,13,16,2),fpp( 5,13,16,3)/
     x-1.3199243D-02, 3.4763444D-05, 1.5872002D-05 /
      data fpp( 5,13,17,1),fpp( 5,13,17,2),fpp( 5,13,17,3)/
     x 5.2802953D-03, 3.3763569D-05, 1.5714277D-05 /
      data fpp( 5,14, 1,1),fpp( 5,14, 1,2),fpp( 5,14, 1,3)/
     x 1.6583166D-02, 4.2461538D-05, 2.1046853D-05 /
      data fpp( 5,14, 2,1),fpp( 5,14, 2,2),fpp( 5,14, 2,3)/
     x-1.3041819D-02, 6.0017072D-05, 2.1551405D-05 /
      data fpp( 5,14, 3,1),fpp( 5,14, 3,2),fpp( 5,14, 3,3)/
     x-1.9652686D-02, 6.5844157D-05, 1.9868859D-05 /
      data fpp( 5,14, 4,1),fpp( 5,14, 4,2),fpp( 5,14, 4,3)/
     x-1.3041819D-02, 6.0017072D-05, 2.5841157D-05 /
      data fpp( 5,14, 5,1),fpp( 5,14, 5,2),fpp( 5,14, 5,3)/
     x 1.6583166D-02, 4.2461538D-05, 3.8878466D-06 /
      data fpp( 5,14, 6,1),fpp( 5,14, 6,2),fpp( 5,14, 6,3)/
     x 5.2788353D-02, 6.7073939D-06,-9.4629876D-05 /
      data fpp( 5,14, 7,1),fpp( 5,14, 7,2),fpp( 5,14, 7,3)/
     x-3.3588528D-03, 2.0802642D-05, 2.1547659D-05 /
      data fpp( 5,14, 8,1),fpp( 5,14, 8,2),fpp( 5,14, 8,3)/
     x-2.3143737D-02, 4.3534247D-05, 2.2095240D-05 /
      data fpp( 5,14, 9,1),fpp( 5,14, 9,2),fpp( 5,14, 9,3)/
     x-2.8384680D-02, 4.8385211D-05, 2.3362047D-05 /
      data fpp( 5,14,10,1),fpp( 5,14,10,2),fpp( 5,14,10,3)/
     x-2.3143737D-02, 4.3534247D-05, 2.2095240D-05 /
      data fpp( 5,14,11,1),fpp( 5,14,11,2),fpp( 5,14,11,3)/
     x-3.3588528D-03, 2.0802642D-05, 2.1547659D-05 /
      data fpp( 5,14,12,1),fpp( 5,14,12,2),fpp( 5,14,12,3)/
     x 5.2788353D-02, 6.7073939D-06,-9.4629876D-05 /
      data fpp( 5,14,13,1),fpp( 5,14,13,2),fpp( 5,14,13,3)/
     x 1.6583166D-02, 4.2461538D-05, 3.8878466D-06 /
      data fpp( 5,14,14,1),fpp( 5,14,14,2),fpp( 5,14,14,3)/
     x-1.3041819D-02, 6.0017072D-05, 2.5841157D-05 /
      data fpp( 5,14,15,1),fpp( 5,14,15,2),fpp( 5,14,15,3)/
     x-1.9652686D-02, 6.5844157D-05, 1.9868859D-05 /
      data fpp( 5,14,16,1),fpp( 5,14,16,2),fpp( 5,14,16,3)/
     x-1.3041819D-02, 6.0017072D-05, 2.1551405D-05 /
      data fpp( 5,14,17,1),fpp( 5,14,17,2),fpp( 5,14,17,3)/
     x 1.6583166D-02, 4.2461538D-05, 2.1046853D-05 /
      data fpp( 5,15, 1,1),fpp( 5,15, 1,2),fpp( 5,15, 1,3)/
     x 3.6468630D-02,-2.8017215D-06, 2.3981563D-05 /
      data fpp( 5,15, 2,1),fpp( 5,15, 2,2),fpp( 5,15, 2,3)/
     x-1.0402017D-02, 7.6540268D-05, 2.5232430D-05 /
      data fpp( 5,15, 3,1),fpp( 5,15, 3,2),fpp( 5,15, 3,3)/
     x-1.7542449D-02, 9.4956823D-05, 2.4192717D-05 /
      data fpp( 5,15, 4,1),fpp( 5,15, 4,2),fpp( 5,15, 4,3)/
     x-1.0402017D-02, 7.6540268D-05, 3.1170036D-05 /
      data fpp( 5,15, 5,1),fpp( 5,15, 5,2),fpp( 5,15, 5,3)/
     x 3.6468630D-02,-2.8017215D-06, 2.3113757D-07 /
      data fpp( 5,15, 6,1),fpp( 5,15, 6,2),fpp( 5,15, 6,3)/
     x 9.5004028D-02,-1.0051227D-04,-1.1190659D-04 /
      data fpp( 5,15, 7,1),fpp( 5,15, 7,2),fpp( 5,15, 7,3)/
     x-4.2345135D-03, 1.4847875D-05, 3.1519209D-05 /
      data fpp( 5,15, 8,1),fpp( 5,15, 8,2),fpp( 5,15, 8,3)/
     x-2.4459457D-02, 7.1364638D-05, 2.3820416D-05 /
      data fpp( 5,15, 9,1),fpp( 5,15, 9,2),fpp( 5,15, 9,3)/
     x-2.9435349D-02, 8.5069280D-05, 2.7128458D-05 /
      data fpp( 5,15,10,1),fpp( 5,15,10,2),fpp( 5,15,10,3)/
     x-2.4459457D-02, 7.1364638D-05, 2.3820416D-05 /
      data fpp( 5,15,11,1),fpp( 5,15,11,2),fpp( 5,15,11,3)/
     x-4.2345135D-03, 1.4847875D-05, 3.1519209D-05 /
      data fpp( 5,15,12,1),fpp( 5,15,12,2),fpp( 5,15,12,3)/
     x 9.5004028D-02,-1.0051227D-04,-1.1190659D-04 /
      data fpp( 5,15,13,1),fpp( 5,15,13,2),fpp( 5,15,13,3)/
     x 3.6468630D-02,-2.8017215D-06, 2.3113757D-07 /
      data fpp( 5,15,14,1),fpp( 5,15,14,2),fpp( 5,15,14,3)/
     x-1.0402017D-02, 7.6540268D-05, 3.1170036D-05 /
      data fpp( 5,15,15,1),fpp( 5,15,15,2),fpp( 5,15,15,3)/
     x-1.7542449D-02, 9.4956823D-05, 2.4192717D-05 /
      data fpp( 5,15,16,1),fpp( 5,15,16,2),fpp( 5,15,16,3)/
     x-1.0402017D-02, 7.6540268D-05, 2.5232430D-05 /
      data fpp( 5,15,17,1),fpp( 5,15,17,2),fpp( 5,15,17,3)/
     x 3.6468630D-02,-2.8017215D-06, 2.3981563D-05 /
      data fpp( 5,16, 1,1),fpp( 5,16, 1,2),fpp( 5,16, 1,3)/
     x 4.1974596D-02,-4.3326652D-05, 1.8740956D-05 /
      data fpp( 5,16, 2,1),fpp( 5,16, 2,2),fpp( 5,16, 2,3)/
     x-4.6800951D-03, 6.8695856D-05, 2.2348198D-05 /
      data fpp( 5,16, 3,1),fpp( 5,16, 3,2),fpp( 5,16, 3,3)/
     x-1.1624377D-02, 1.0001055D-04, 2.5604250D-05 /
      data fpp( 5,16, 4,1),fpp( 5,16, 4,2),fpp( 5,16, 4,3)/
     x-4.6800951D-03, 6.8695856D-05, 3.0089469D-05 /
      data fpp( 5,16, 5,1),fpp( 5,16, 5,2),fpp( 5,16, 5,3)/
     x 4.1974596D-02,-4.3326652D-05,-1.2224127D-05 /
      data fpp( 5,16, 6,1),fpp( 5,16, 6,2),fpp( 5,16, 6,3)/
     x 7.5724838D-02,-1.1036832D-04,-9.2767629D-05 /
      data fpp( 5,16, 7,1),fpp( 5,16, 7,2),fpp( 5,16, 7,3)/
     x-6.2420701D-03, 8.0358583D-06, 2.5468644D-05 /
      data fpp( 5,16, 8,1),fpp( 5,16, 8,2),fpp( 5,16, 8,3)/
     x-2.3979770D-02, 8.7119200D-05, 2.3656387D-05 /
      data fpp( 5,16, 9,1),fpp( 5,16, 9,2),fpp( 5,16, 9,3)/
     x-2.8134136D-02, 1.1023167D-04, 2.7240473D-05 /
      data fpp( 5,16,10,1),fpp( 5,16,10,2),fpp( 5,16,10,3)/
     x-2.3979770D-02, 8.7119200D-05, 2.3656387D-05 /
      data fpp( 5,16,11,1),fpp( 5,16,11,2),fpp( 5,16,11,3)/
     x-6.2420701D-03, 8.0358583D-06, 2.5468644D-05 /
      data fpp( 5,16,12,1),fpp( 5,16,12,2),fpp( 5,16,12,3)/
     x 7.5724838D-02,-1.1036832D-04,-9.2767629D-05 /
      data fpp( 5,16,13,1),fpp( 5,16,13,2),fpp( 5,16,13,3)/
     x 4.1974596D-02,-4.3326652D-05,-1.2224127D-05 /
      data fpp( 5,16,14,1),fpp( 5,16,14,2),fpp( 5,16,14,3)/
     x-4.6800951D-03, 6.8695856D-05, 3.0089469D-05 /
      data fpp( 5,16,15,1),fpp( 5,16,15,2),fpp( 5,16,15,3)/
     x-1.1624377D-02, 1.0001055D-04, 2.5604250D-05 /
      data fpp( 5,16,16,1),fpp( 5,16,16,2),fpp( 5,16,16,3)/
     x-4.6800951D-03, 6.8695856D-05, 2.2348198D-05 /
      data fpp( 5,16,17,1),fpp( 5,16,17,2),fpp( 5,16,17,3)/
     x 4.1974596D-02,-4.3326652D-05, 1.8740956D-05 /
      data fpp( 5,17, 1,1),fpp( 5,17, 1,2),fpp( 5,17, 1,3)/
     x 4.5054652D-02,-7.7403671D-05, 5.9102943D-06 /
      data fpp( 5,17, 2,1),fpp( 5,17, 2,2),fpp( 5,17, 2,3)/
     x 1.0911878D-02,-1.1933692D-05, 1.1739745D-05 /
      data fpp( 5,17, 3,1),fpp( 5,17, 3,2),fpp( 5,17, 3,3)/
     x 3.0463270D-03, 3.6354967D-05, 2.0954060D-05 /
      data fpp( 5,17, 4,1),fpp( 5,17, 4,2),fpp( 5,17, 4,3)/
     x 1.0911878D-02,-1.1933692D-05, 1.8321348D-05 /
      data fpp( 5,17, 5,1),fpp( 5,17, 5,2),fpp( 5,17, 5,3)/
     x 4.5054652D-02,-7.7403671D-05,-2.0416118D-05 /
      data fpp( 5,17, 6,1),fpp( 5,17, 6,2),fpp( 5,17, 6,3)/
     x 4.3517781D-02,-6.4624524D-06,-4.6886876D-05 /
      data fpp( 5,17, 7,1),fpp( 5,17, 7,2),fpp( 5,17, 7,3)/
     x-6.1471813D-03, 1.7718692D-05, 9.0869537D-06 /
      data fpp( 5,17, 8,1),fpp( 5,17, 8,2),fpp( 5,17, 8,3)/
     x-2.0284135D-02, 8.6504562D-05, 1.9017061D-05 /
      data fpp( 5,17, 9,1),fpp( 5,17, 9,2),fpp( 5,17, 9,3)/
     x-2.3466440D-02, 1.1880605D-04, 2.1898136D-05 /
      data fpp( 5,17,10,1),fpp( 5,17,10,2),fpp( 5,17,10,3)/
     x-2.0284135D-02, 8.6504562D-05, 1.9017061D-05 /
      data fpp( 5,17,11,1),fpp( 5,17,11,2),fpp( 5,17,11,3)/
     x-6.1471813D-03, 1.7718692D-05, 9.0869537D-06 /
      data fpp( 5,17,12,1),fpp( 5,17,12,2),fpp( 5,17,12,3)/
     x 4.3517781D-02,-6.4624524D-06,-4.6886876D-05 /
      data fpp( 5,17,13,1),fpp( 5,17,13,2),fpp( 5,17,13,3)/
     x 4.5054652D-02,-7.7403671D-05,-2.0416118D-05 /
      data fpp( 5,17,14,1),fpp( 5,17,14,2),fpp( 5,17,14,3)/
     x 1.0911878D-02,-1.1933692D-05, 1.8321348D-05 /
      data fpp( 5,17,15,1),fpp( 5,17,15,2),fpp( 5,17,15,3)/
     x 3.0463270D-03, 3.6354967D-05, 2.0954060D-05 /
      data fpp( 5,17,16,1),fpp( 5,17,16,2),fpp( 5,17,16,3)/
     x 1.0911878D-02,-1.1933692D-05, 1.1739745D-05 /
      data fpp( 5,17,17,1),fpp( 5,17,17,2),fpp( 5,17,17,3)/
     x 4.5054652D-02,-7.7403671D-05, 5.9102943D-06 /
      data fpp( 5,18, 1,1),fpp( 5,18, 1,2),fpp( 5,18, 1,3)/
     x 7.0119195D-02,-5.4542666D-05,-2.6560007D-06 /
      data fpp( 5,18, 2,1),fpp( 5,18, 2,2),fpp( 5,18, 2,3)/
     x 5.2155870D-02,-1.8723309D-04, 6.8111252D-07 /
      data fpp( 5,18, 3,1),fpp( 5,18, 3,2),fpp( 5,18, 3,3)/
     x 4.3923760D-02,-2.2922442D-04, 7.3142173D-06 /
      data fpp( 5,18, 4,1),fpp( 5,18, 4,2),fpp( 5,18, 4,3)/
     x 5.2155870D-02,-1.8723309D-04, 2.4113516D-06 /
      data fpp( 5,18, 5,1),fpp( 5,18, 5,2),fpp( 5,18, 5,3)/
     x 7.0119195D-02,-5.4542666D-05,-9.5769570D-06 /
      data fpp( 5,18, 6,1),fpp( 5,18, 6,2),fpp( 5,18, 6,3)/
     x 3.5761717D-02, 4.2048129D-05,-1.1374857D-05 /
      data fpp( 5,18, 7,1),fpp( 5,18, 7,2),fpp( 5,18, 7,3)/
     x 6.9336261D-03, 1.0525374D-05, 7.3705121D-07 /
      data fpp( 5,18, 8,1),fpp( 5,18, 8,2),fpp( 5,18, 8,3)/
     x-6.7202686D-03,-1.5045446D-05, 8.7359854D-06 /
      data fpp( 5,18, 9,1),fpp( 5,18, 9,2),fpp( 5,18, 9,3)/
     x-1.0235560D-02,-1.8545872D-05, 1.1109007D-05 /
      data fpp( 5,18,10,1),fpp( 5,18,10,2),fpp( 5,18,10,3)/
     x-6.7202686D-03,-1.5045446D-05, 8.7359854D-06 /
      data fpp( 5,18,11,1),fpp( 5,18,11,2),fpp( 5,18,11,3)/
     x 6.9336261D-03, 1.0525374D-05, 7.3705121D-07 /
      data fpp( 5,18,12,1),fpp( 5,18,12,2),fpp( 5,18,12,3)/
     x 3.5761717D-02, 4.2048129D-05,-1.1374857D-05 /
      data fpp( 5,18,13,1),fpp( 5,18,13,2),fpp( 5,18,13,3)/
     x 7.0119195D-02,-5.4542666D-05,-9.5769570D-06 /
      data fpp( 5,18,14,1),fpp( 5,18,14,2),fpp( 5,18,14,3)/
     x 5.2155870D-02,-1.8723309D-04, 2.4113516D-06 /
      data fpp( 5,18,15,1),fpp( 5,18,15,2),fpp( 5,18,15,3)/
     x 4.3923760D-02,-2.2922442D-04, 7.3142173D-06 /
      data fpp( 5,18,16,1),fpp( 5,18,16,2),fpp( 5,18,16,3)/
     x 5.2155870D-02,-1.8723309D-04, 6.8111252D-07 /
      data fpp( 5,18,17,1),fpp( 5,18,17,2),fpp( 5,18,17,3)/
     x 7.0119195D-02,-5.4542666D-05,-2.6560007D-06 /
      data fpp( 5,19, 1,1),fpp( 5,19, 1,2),fpp( 5,19, 1,3)/
     x 3.3977820D-02,-4.7949667D-05,-2.1391763D-20 /
      data fpp( 5,19, 2,1),fpp( 5,19, 2,2),fpp( 5,19, 2,3)/
     x 3.3977820D-02,-3.3548396D-04, 3.8113332D-20 /
      data fpp( 5,19, 3,1),fpp( 5,19, 3,2),fpp( 5,19, 3,3)/
     x 3.3977820D-02,-4.3711129D-04, 1.7432041D-20 /
      data fpp( 5,19, 4,1),fpp( 5,19, 4,2),fpp( 5,19, 4,3)/
     x 3.3977820D-02,-3.3548396D-04, 5.2399937D-21 /
      data fpp( 5,19, 5,1),fpp( 5,19, 5,2),fpp( 5,19, 5,3)/
     x 3.3977820D-02,-4.7949667D-05, 3.9821268D-21 /
      data fpp( 5,19, 6,1),fpp( 5,19, 6,2),fpp( 5,19, 6,3)/
     x 3.3977820D-02, 1.0638594D-04, 1.8186078D-20 /
      data fpp( 5,19, 7,1),fpp( 5,19, 7,2),fpp( 5,19, 7,3)/
     x 3.3977820D-02, 8.1538131D-06, 1.4274995D-20 /
      data fpp( 5,19, 8,1),fpp( 5,19, 8,2),fpp( 5,19, 8,3)/
     x 3.3977820D-02,-8.7756777D-05,-2.2951911D-20 /
      data fpp( 5,19, 9,1),fpp( 5,19, 9,2),fpp( 5,19, 9,3)/
     x 3.3977820D-02,-1.1420456D-04,-1.1746240D-21 /
      data fpp( 5,19,10,1),fpp( 5,19,10,2),fpp( 5,19,10,3)/
     x 3.3977820D-02,-8.7756777D-05, 1.8534234D-20 /
      data fpp( 5,19,11,1),fpp( 5,19,11,2),fpp( 5,19,11,3)/
     x 3.3977820D-02, 8.1538131D-06,-9.0326106D-21 /
      data fpp( 5,19,12,1),fpp( 5,19,12,2),fpp( 5,19,12,3)/
     x 3.3977820D-02, 1.0638594D-04, 3.9080301D-23 /
      data fpp( 5,19,13,1),fpp( 5,19,13,2),fpp( 5,19,13,3)/
     x 3.3977820D-02,-4.7949667D-05,-7.8839990D-21 /
      data fpp( 5,19,14,1),fpp( 5,19,14,2),fpp( 5,19,14,3)/
     x 3.3977820D-02,-3.3548396D-04,-2.7244304D-21 /
      data fpp( 5,19,15,1),fpp( 5,19,15,2),fpp( 5,19,15,3)/
     x 3.3977820D-02,-4.3711129D-04,-3.8261905D-21 /
      data fpp( 5,19,16,1),fpp( 5,19,16,2),fpp( 5,19,16,3)/
     x 3.3977820D-02,-3.3548396D-04, 5.0324055D-21 /
      data fpp( 5,19,17,1),fpp( 5,19,17,2),fpp( 5,19,17,3)/
     x 3.3977820D-02,-4.7949667D-05,-4.4113072D-21 /
      data fpp( 6, 1, 1,1),fpp( 6, 1, 1,2),fpp( 6, 1, 1,3)/
     x 3.7864179D-02, 2.3829554D-06,-1.5035323D-20 /
      data fpp( 6, 1, 2,1),fpp( 6, 1, 2,2),fpp( 6, 1, 2,3)/
     x 3.7864179D-02,-3.8228353D-05, 2.0696337D-20 /
      data fpp( 6, 1, 3,1),fpp( 6, 1, 3,2),fpp( 6, 1, 3,3)/
     x 3.7864179D-02,-5.7107089D-05, 1.4933680D-20 /
      data fpp( 6, 1, 4,1),fpp( 6, 1, 4,2),fpp( 6, 1, 4,3)/
     x 3.7864179D-02,-3.8228353D-05, 2.3956101D-21 /
      data fpp( 6, 1, 5,1),fpp( 6, 1, 5,2),fpp( 6, 1, 5,3)/
     x 3.7864179D-02, 2.3829554D-06, 2.0570182D-21 /
      data fpp( 6, 1, 6,1),fpp( 6, 1, 6,2),fpp( 6, 1, 6,3)/
     x 3.7864179D-02, 2.2531453D-05, 4.3370674D-21 /
      data fpp( 6, 1, 7,1),fpp( 6, 1, 7,2),fpp( 6, 1, 7,3)/
     x 3.7864179D-02, 8.5219336D-06, 8.4520214D-21 /
      data fpp( 6, 1, 8,1),fpp( 6, 1, 8,2),fpp( 6, 1, 8,3)/
     x 3.7864179D-02,-2.2495377D-05,-1.3004248D-20 /
      data fpp( 6, 1, 9,1),fpp( 6, 1, 9,2),fpp( 6, 1, 9,3)/
     x 3.7864179D-02,-3.6532393D-05,-1.7516022D-21 /
      data fpp( 6, 1,10,1),fpp( 6, 1,10,2),fpp( 6, 1,10,3)/
     x 3.7864179D-02,-2.2495377D-05, 7.8539177D-21 /
      data fpp( 6, 1,11,1),fpp( 6, 1,11,2),fpp( 6, 1,11,3)/
     x 3.7864179D-02, 8.5219336D-06,-6.4320697D-21 /
      data fpp( 6, 1,12,1),fpp( 6, 1,12,2),fpp( 6, 1,12,3)/
     x 3.7864179D-02, 2.2531453D-05, 5.4384021D-21 /
      data fpp( 6, 1,13,1),fpp( 6, 1,13,2),fpp( 6, 1,13,3)/
     x 3.7864179D-02, 2.3829554D-06,-2.5040120D-21 /
      data fpp( 6, 1,14,1),fpp( 6, 1,14,2),fpp( 6, 1,14,3)/
     x 3.7864179D-02,-3.8228353D-05,-8.7060035D-21 /
      data fpp( 6, 1,15,1),fpp( 6, 1,15,2),fpp( 6, 1,15,3)/
     x 3.7864179D-02,-5.7107089D-05,-4.5675983D-21 /
      data fpp( 6, 1,16,1),fpp( 6, 1,16,2),fpp( 6, 1,16,3)/
     x 3.7864179D-02,-3.8228353D-05,-5.8312522D-22 /
      data fpp( 6, 1,17,1),fpp( 6, 1,17,2),fpp( 6, 1,17,3)/
     x 3.7864179D-02, 2.3829554D-06, 1.6132789D-20 /
      data fpp( 6, 2, 1,1),fpp( 6, 2, 1,2),fpp( 6, 2, 1,3)/
     x 3.6363522D-02,-3.6429107D-06, 2.1522596D-07 /
      data fpp( 6, 2, 2,1),fpp( 6, 2, 2,2),fpp( 6, 2, 2,3)/
     x 3.3515413D-02,-2.1087295D-05, 8.7799253D-07 /
      data fpp( 6, 2, 3,1),fpp( 6, 2, 3,2),fpp( 6, 2, 3,3)/
     x 3.2159970D-02,-3.2862822D-05, 2.2728039D-06 /
      data fpp( 6, 2, 4,1),fpp( 6, 2, 4,2),fpp( 6, 2, 4,3)/
     x 3.3515413D-02,-2.1087295D-05, 1.1054584D-06 /
      data fpp( 6, 2, 5,1),fpp( 6, 2, 5,2),fpp( 6, 2, 5,3)/
     x 3.6363522D-02,-3.6429107D-06,-6.9463757D-07 /
      data fpp( 6, 2, 6,1),fpp( 6, 2, 6,2),fpp( 6, 2, 6,3)/
     x 3.8224902D-02, 3.2740949D-06,-1.5702415D-06 /
      data fpp( 6, 2, 7,1),fpp( 6, 2, 7,2),fpp( 6, 2, 7,3)/
     x 3.8156345D-02,-3.2378672D-06,-9.4039653D-07 /
      data fpp( 6, 2, 8,1),fpp( 6, 2, 8,2),fpp( 6, 2, 8,3)/
     x 3.7262884D-02,-1.5439246D-05, 4.2449425D-07 /
      data fpp( 6, 2, 9,1),fpp( 6, 2, 9,2),fpp( 6, 2, 9,3)/
     x 3.6846276D-02,-2.1664214D-05, 1.1157529D-06 /
      data fpp( 6, 2,10,1),fpp( 6, 2,10,2),fpp( 6, 2,10,3)/
     x 3.7262884D-02,-1.5439246D-05, 4.2449425D-07 /
      data fpp( 6, 2,11,1),fpp( 6, 2,11,2),fpp( 6, 2,11,3)/
     x 3.8156345D-02,-3.2378672D-06,-9.4039653D-07 /
      data fpp( 6, 2,12,1),fpp( 6, 2,12,2),fpp( 6, 2,12,3)/
     x 3.8224902D-02, 3.2740949D-06,-1.5702415D-06 /
      data fpp( 6, 2,13,1),fpp( 6, 2,13,2),fpp( 6, 2,13,3)/
     x 3.6363522D-02,-3.6429107D-06,-6.9463757D-07 /
      data fpp( 6, 2,14,1),fpp( 6, 2,14,2),fpp( 6, 2,14,3)/
     x 3.3515413D-02,-2.1087295D-05, 1.1054584D-06 /
      data fpp( 6, 2,15,1),fpp( 6, 2,15,2),fpp( 6, 2,15,3)/
     x 3.2159970D-02,-3.2862822D-05, 2.2728039D-06 /
      data fpp( 6, 2,16,1),fpp( 6, 2,16,2),fpp( 6, 2,16,3)/
     x 3.3515413D-02,-2.1087295D-05, 8.7799253D-07 /
      data fpp( 6, 2,17,1),fpp( 6, 2,17,2),fpp( 6, 2,17,3)/
     x 3.6363522D-02,-3.6429107D-06, 2.1522596D-07 /
      data fpp( 6, 3, 1,1),fpp( 6, 3, 1,2),fpp( 6, 3, 1,3)/
     x 3.4087299D-02,-1.1949312D-05,-1.0553159D-06 /
      data fpp( 6, 3, 2,1),fpp( 6, 3, 2,2),fpp( 6, 3, 2,3)/
     x 2.6419972D-02,-8.4984689D-06, 1.9541873D-06 /
      data fpp( 6, 3, 3,1),fpp( 6, 3, 3,2),fpp( 6, 3, 3,3)/
     x 2.3175004D-02,-1.8567624D-05, 8.6705668D-06 /
      data fpp( 6, 3, 4,1),fpp( 6, 3, 4,2),fpp( 6, 3, 4,3)/
     x 2.6419972D-02,-8.4984689D-06, 2.4128790D-06 /
      data fpp( 6, 3, 5,1),fpp( 6, 3, 5,2),fpp( 6, 3, 5,3)/
     x 3.4087299D-02,-1.1949312D-05,-2.8900827D-06 /
      data fpp( 6, 3, 6,1),fpp( 6, 3, 6,2),fpp( 6, 3, 6,3)/
     x 3.7975190D-02,-2.0189832D-05,-4.8238816D-06 /
      data fpp( 6, 3, 7,1),fpp( 6, 3, 7,2),fpp( 6, 3, 7,3)/
     x 3.6268149D-02,-1.9558465D-05,-2.4243908D-06 /
      data fpp( 6, 3, 8,1),fpp( 6, 3, 8,2),fpp( 6, 3, 8,3)/
     x 3.3325018D-02,-7.8956395D-06, 1.5141117D-06 /
      data fpp( 6, 3, 9,1),fpp( 6, 3, 9,2),fpp( 6, 3, 9,3)/
     x 3.2402376D-02,-3.6927512D-06, 3.8286108D-06 /
      data fpp( 6, 3,10,1),fpp( 6, 3,10,2),fpp( 6, 3,10,3)/
     x 3.3325018D-02,-7.8956395D-06, 1.5141117D-06 /
      data fpp( 6, 3,11,1),fpp( 6, 3,11,2),fpp( 6, 3,11,3)/
     x 3.6268149D-02,-1.9558465D-05,-2.4243908D-06 /
      data fpp( 6, 3,12,1),fpp( 6, 3,12,2),fpp( 6, 3,12,3)/
     x 3.7975190D-02,-2.0189832D-05,-4.8238816D-06 /
      data fpp( 6, 3,13,1),fpp( 6, 3,13,2),fpp( 6, 3,13,3)/
     x 3.4087299D-02,-1.1949312D-05,-2.8900827D-06 /
      data fpp( 6, 3,14,1),fpp( 6, 3,14,2),fpp( 6, 3,14,3)/
     x 2.6419972D-02,-8.4984689D-06, 2.4128790D-06 /
      data fpp( 6, 3,15,1),fpp( 6, 3,15,2),fpp( 6, 3,15,3)/
     x 2.3175004D-02,-1.8567624D-05, 8.6705668D-06 /
      data fpp( 6, 3,16,1),fpp( 6, 3,16,2),fpp( 6, 3,16,3)/
     x 2.6419972D-02,-8.4984689D-06, 1.9541873D-06 /
      data fpp( 6, 3,17,1),fpp( 6, 3,17,2),fpp( 6, 3,17,3)/
     x 3.4087299D-02,-1.1949312D-05,-1.0553159D-06 /
      data fpp( 6, 4, 1,1),fpp( 6, 4, 1,2),fpp( 6, 4, 1,3)/
     x 3.0124403D-02,-1.2273839D-05,-6.1856711D-06 /
      data fpp( 6, 4, 2,1),fpp( 6, 4, 2,2),fpp( 6, 4, 2,3)/
     x 2.0176248D-02, 2.0023170D-05, 1.1756755D-06 /
      data fpp( 6, 4, 3,1),fpp( 6, 4, 3,2),fpp( 6, 4, 3,3)/
     x 2.0267106D-02, 3.0549318D-05, 1.8548969D-05 /
      data fpp( 6, 4, 4,1),fpp( 6, 4, 4,2),fpp( 6, 4, 4,3)/
     x 2.0176248D-02, 2.0023170D-05, 8.8044794D-07 /
      data fpp( 6, 4, 5,1),fpp( 6, 4, 5,2),fpp( 6, 4, 5,3)/
     x 3.0124403D-02,-1.2273839D-05,-5.0047609D-06 /
      data fpp( 6, 4, 6,1),fpp( 6, 4, 6,2),fpp( 6, 4, 6,3)/
     x 3.4218738D-02,-2.8930766D-05,-7.1214043D-06 /
      data fpp( 6, 4, 7,1),fpp( 6, 4, 7,2),fpp( 6, 4, 7,3)/
     x 3.3888122D-02,-1.9916274D-05,-2.5102886D-06 /
      data fpp( 6, 4, 8,1),fpp( 6, 4, 8,2),fpp( 6, 4, 8,3)/
     x 2.8498450D-02,-2.0581960D-06, 1.3085586D-06 /
      data fpp( 6, 4, 9,1),fpp( 6, 4, 9,2),fpp( 6, 4, 9,3)/
     x 2.7479786D-02, 3.4172188D-06, 6.2967207D-06 /
      data fpp( 6, 4,10,1),fpp( 6, 4,10,2),fpp( 6, 4,10,3)/
     x 2.8498450D-02,-2.0581960D-06, 1.3085586D-06 /
      data fpp( 6, 4,11,1),fpp( 6, 4,11,2),fpp( 6, 4,11,3)/
     x 3.3888122D-02,-1.9916274D-05,-2.5102886D-06 /
      data fpp( 6, 4,12,1),fpp( 6, 4,12,2),fpp( 6, 4,12,3)/
     x 3.4218738D-02,-2.8930766D-05,-7.1214043D-06 /
      data fpp( 6, 4,13,1),fpp( 6, 4,13,2),fpp( 6, 4,13,3)/
     x 3.0124403D-02,-1.2273839D-05,-5.0047609D-06 /
      data fpp( 6, 4,14,1),fpp( 6, 4,14,2),fpp( 6, 4,14,3)/
     x 2.0176248D-02, 2.0023170D-05, 8.8044794D-07 /
      data fpp( 6, 4,15,1),fpp( 6, 4,15,2),fpp( 6, 4,15,3)/
     x 2.0267106D-02, 3.0549318D-05, 1.8548969D-05 /
      data fpp( 6, 4,16,1),fpp( 6, 4,16,2),fpp( 6, 4,16,3)/
     x 2.0176248D-02, 2.0023170D-05, 1.1756755D-06 /
      data fpp( 6, 4,17,1),fpp( 6, 4,17,2),fpp( 6, 4,17,3)/
     x 3.0124403D-02,-1.2273839D-05,-6.1856711D-06 /
      data fpp( 6, 5, 1,1),fpp( 6, 5, 1,2),fpp( 6, 5, 1,3)/
     x 2.4170270D-02,-3.6953299D-06,-1.3486547D-05 /
      data fpp( 6, 5, 2,1),fpp( 6, 5, 2,2),fpp( 6, 5, 2,3)/
     x 1.5396050D-02, 3.4125788D-05,-1.8541283D-06 /
      data fpp( 6, 5, 3,1),fpp( 6, 5, 3,2),fpp( 6, 5, 3,3)/
     x 2.4570826D-02, 5.7236351D-05, 2.6790393D-05 /
      data fpp( 6, 5, 4,1),fpp( 6, 5, 4,2),fpp( 6, 5, 4,3)/
     x 1.5396050D-02, 3.4125788D-05,-4.1074451D-06 /
      data fpp( 6, 5, 5,1),fpp( 6, 5, 5,2),fpp( 6, 5, 5,3)/
     x 2.4170270D-02,-3.6953299D-06,-4.4732794D-06 /
      data fpp( 6, 5, 6,1),fpp( 6, 5, 6,2),fpp( 6, 5, 6,3)/
     x 2.6447934D-02,-1.1633104D-05,-6.8087705D-06 /
      data fpp( 6, 5, 7,1),fpp( 6, 5, 7,2),fpp( 6, 5, 7,3)/
     x 3.3328612D-02,-3.3764407D-06,-1.4883054D-06 /
      data fpp( 6, 5, 8,1),fpp( 6, 5, 8,2),fpp( 6, 5, 8,3)/
     x 2.3270775D-02, 4.5004237D-06,-8.2467465D-07 /
      data fpp( 6, 5, 9,1),fpp( 6, 5, 9,2),fpp( 6, 5, 9,3)/
     x 2.2462297D-02, 5.2098761D-06, 8.2390040D-06 /
      data fpp( 6, 5,10,1),fpp( 6, 5,10,2),fpp( 6, 5,10,3)/
     x 2.3270775D-02, 4.5004237D-06,-8.2467465D-07 /
      data fpp( 6, 5,11,1),fpp( 6, 5,11,2),fpp( 6, 5,11,3)/
     x 3.3328612D-02,-3.3764407D-06,-1.4883054D-06 /
      data fpp( 6, 5,12,1),fpp( 6, 5,12,2),fpp( 6, 5,12,3)/
     x 2.6447934D-02,-1.1633104D-05,-6.8087705D-06 /
      data fpp( 6, 5,13,1),fpp( 6, 5,13,2),fpp( 6, 5,13,3)/
     x 2.4170270D-02,-3.6953299D-06,-4.4732794D-06 /
      data fpp( 6, 5,14,1),fpp( 6, 5,14,2),fpp( 6, 5,14,3)/
     x 1.5396050D-02, 3.4125788D-05,-4.1074451D-06 /
      data fpp( 6, 5,15,1),fpp( 6, 5,15,2),fpp( 6, 5,15,3)/
     x 2.4570826D-02, 5.7236351D-05, 2.6790393D-05 /
      data fpp( 6, 5,16,1),fpp( 6, 5,16,2),fpp( 6, 5,16,3)/
     x 1.5396050D-02, 3.4125788D-05,-1.8541283D-06 /
      data fpp( 6, 5,17,1),fpp( 6, 5,17,2),fpp( 6, 5,17,3)/
     x 2.4170270D-02,-3.6953299D-06,-1.3486547D-05 /
      data fpp( 6, 6, 1,1),fpp( 6, 6, 1,2),fpp( 6, 6, 1,3)/
     x 1.7770813D-02, 4.2551589D-06,-1.8137803D-05 /
      data fpp( 6, 6, 2,1),fpp( 6, 6, 2,2),fpp( 6, 6, 2,3)/
     x 1.1613939D-02, 1.8517678D-05,-5.3200598D-06 /
      data fpp( 6, 6, 3,1),fpp( 6, 6, 3,2),fpp( 6, 6, 3,3)/
     x 1.7452846D-02, 5.4641279D-05, 2.7598709D-05 /
      data fpp( 6, 6, 4,1),fpp( 6, 6, 4,2),fpp( 6, 6, 4,3)/
     x 1.1613939D-02, 1.8517678D-05,-9.8361106D-06 /
      data fpp( 6, 6, 5,1),fpp( 6, 6, 5,2),fpp( 6, 6, 5,3)/
     x 1.7770813D-02, 4.2551589D-06,-7.3600198D-08 /
      data fpp( 6, 6, 6,1),fpp( 6, 6, 6,2),fpp( 6, 6, 6,3)/
     x 1.8093803D-02, 4.2911809D-06,-4.6201553D-06 /
      data fpp( 6, 6, 7,1),fpp( 6, 6, 7,2),fpp( 6, 6, 7,3)/
     x 2.4058978D-02, 1.1246036D-05,-1.0197787D-06 /
      data fpp( 6, 6, 8,1),fpp( 6, 6, 8,2),fpp( 6, 6, 8,3)/
     x 1.8072455D-02, 1.6365012D-06,-3.6467299D-06 /
      data fpp( 6, 6, 9,1),fpp( 6, 6, 9,2),fpp( 6, 6, 9,3)/
     x 1.7649543D-02, 2.0412768D-06, 1.0041365D-05 /
      data fpp( 6, 6,10,1),fpp( 6, 6,10,2),fpp( 6, 6,10,3)/
     x 1.8072455D-02, 1.6365012D-06,-3.6467299D-06 /
      data fpp( 6, 6,11,1),fpp( 6, 6,11,2),fpp( 6, 6,11,3)/
     x 2.4058978D-02, 1.1246036D-05,-1.0197787D-06 /
      data fpp( 6, 6,12,1),fpp( 6, 6,12,2),fpp( 6, 6,12,3)/
     x 1.8093803D-02, 4.2911809D-06,-4.6201553D-06 /
      data fpp( 6, 6,13,1),fpp( 6, 6,13,2),fpp( 6, 6,13,3)/
     x 1.7770813D-02, 4.2551589D-06,-7.3600198D-08 /
      data fpp( 6, 6,14,1),fpp( 6, 6,14,2),fpp( 6, 6,14,3)/
     x 1.1613939D-02, 1.8517678D-05,-9.8361106D-06 /
      data fpp( 6, 6,15,1),fpp( 6, 6,15,2),fpp( 6, 6,15,3)/
     x 1.7452846D-02, 5.4641279D-05, 2.7598709D-05 /
      data fpp( 6, 6,16,1),fpp( 6, 6,16,2),fpp( 6, 6,16,3)/
     x 1.1613939D-02, 1.8517678D-05,-5.3200598D-06 /
      data fpp( 6, 6,17,1),fpp( 6, 6,17,2),fpp( 6, 6,17,3)/
     x 1.7770813D-02, 4.2551589D-06,-1.8137803D-05 /
      data fpp( 6, 7, 1,1),fpp( 6, 7, 1,2),fpp( 6, 7, 1,3)/
     x 1.2399725D-02, 7.2786942D-06,-1.3455139D-05 /
      data fpp( 6, 7, 2,1),fpp( 6, 7, 2,2),fpp( 6, 7, 2,3)/
     x 1.0816877D-02,-1.1362501D-05,-5.3881666D-06 /
      data fpp( 6, 7, 3,1),fpp( 6, 7, 3,2),fpp( 6, 7, 3,3)/
     x 7.8480246D-03,-4.2234651D-06, 1.6427805D-05 /
      data fpp( 6, 7, 4,1),fpp( 6, 7, 4,2),fpp( 6, 7, 4,3)/
     x 1.0816877D-02,-1.1362501D-05,-9.8777208D-06 /
      data fpp( 6, 7, 5,1),fpp( 6, 7, 5,2),fpp( 6, 7, 5,3)/
     x 1.2399725D-02, 7.2786942D-06, 4.5030780D-06 /
      data fpp( 6, 7, 6,1),fpp( 6, 7, 6,2),fpp( 6, 7, 6,3)/
     x 1.2433313D-02, 1.0416380D-05,-8.7392470D-07 /
      data fpp( 6, 7, 7,1),fpp( 6, 7, 7,2),fpp( 6, 7, 7,3)/
     x 1.3842114D-02, 2.0002949D-06,-3.3680459D-06 /
      data fpp( 6, 7, 8,1),fpp( 6, 7, 8,2),fpp( 6, 7, 8,3)/
     x 1.4430726D-02,-6.6064287D-06,-4.1845583D-06 /
      data fpp( 6, 7, 9,1),fpp( 6, 7, 9,2),fpp( 6, 7, 9,3)/
     x 1.3130003D-02,-3.9789834D-06, 1.0426279D-05 /
      data fpp( 6, 7,10,1),fpp( 6, 7,10,2),fpp( 6, 7,10,3)/
     x 1.4430726D-02,-6.6064287D-06,-4.1845583D-06 /
      data fpp( 6, 7,11,1),fpp( 6, 7,11,2),fpp( 6, 7,11,3)/
     x 1.3842114D-02, 2.0002949D-06,-3.3680459D-06 /
      data fpp( 6, 7,12,1),fpp( 6, 7,12,2),fpp( 6, 7,12,3)/
     x 1.2433313D-02, 1.0416380D-05,-8.7392470D-07 /
      data fpp( 6, 7,13,1),fpp( 6, 7,13,2),fpp( 6, 7,13,3)/
     x 1.2399725D-02, 7.2786942D-06, 4.5030780D-06 /
      data fpp( 6, 7,14,1),fpp( 6, 7,14,2),fpp( 6, 7,14,3)/
     x 1.0816877D-02,-1.1362501D-05,-9.8777208D-06 /
      data fpp( 6, 7,15,1),fpp( 6, 7,15,2),fpp( 6, 7,15,3)/
     x 7.8480246D-03,-4.2234651D-06, 1.6427805D-05 /
      data fpp( 6, 7,16,1),fpp( 6, 7,16,2),fpp( 6, 7,16,3)/
     x 1.0816877D-02,-1.1362501D-05,-5.3881666D-06 /
      data fpp( 6, 7,17,1),fpp( 6, 7,17,2),fpp( 6, 7,17,3)/
     x 1.2399725D-02, 7.2786942D-06,-1.3455139D-05 /
      data fpp( 6, 8, 1,1),fpp( 6, 8, 1,2),fpp( 6, 8, 1,3)/
     x 8.3474573D-03, 6.9860643D-06,-3.3570721D-06 /
      data fpp( 6, 8, 2,1),fpp( 6, 8, 2,2),fpp( 6, 8, 2,3)/
     x 1.0703430D-02,-2.2891675D-05,-2.4110781D-06 /
      data fpp( 6, 8, 3,1),fpp( 6, 8, 3,2),fpp( 6, 8, 3,3)/
     x 9.7574276D-03,-5.4415418D-05, 1.3647177D-06 /
      data fpp( 6, 8, 4,1),fpp( 6, 8, 4,2),fpp( 6, 8, 4,3)/
     x 1.0703430D-02,-2.2891675D-05,-4.7637926D-06 /
      data fpp( 6, 8, 5,1),fpp( 6, 8, 5,2),fpp( 6, 8, 5,3)/
     x 8.3474573D-03, 6.9860643D-06, 6.0537860D-06 /
      data fpp( 6, 8, 6,1),fpp( 6, 8, 6,2),fpp( 6, 8, 6,3)/
     x 9.2264794D-03, 1.3827298D-05, 1.9593151D-06 /
      data fpp( 6, 8, 7,1),fpp( 6, 8, 7,2),fpp( 6, 8, 7,3)/
     x 1.1002748D-02,-3.9712162D-06,-6.1423797D-06 /
      data fpp( 6, 8, 8,1),fpp( 6, 8, 8,2),fpp( 6, 8, 8,3)/
     x 1.0748003D-02,-8.7687866D-06,-2.5857963D-06 /
      data fpp( 6, 8, 9,1),fpp( 6, 8, 9,2),fpp( 6, 8, 9,3)/
     x 8.1451067D-03,-9.9273431D-06, 9.2008981D-06 /
      data fpp( 6, 8,10,1),fpp( 6, 8,10,2),fpp( 6, 8,10,3)/
     x 1.0748003D-02,-8.7687866D-06,-2.5857963D-06 /
      data fpp( 6, 8,11,1),fpp( 6, 8,11,2),fpp( 6, 8,11,3)/
     x 1.1002748D-02,-3.9712162D-06,-6.1423797D-06 /
      data fpp( 6, 8,12,1),fpp( 6, 8,12,2),fpp( 6, 8,12,3)/
     x 9.2264794D-03, 1.3827298D-05, 1.9593151D-06 /
      data fpp( 6, 8,13,1),fpp( 6, 8,13,2),fpp( 6, 8,13,3)/
     x 8.3474573D-03, 6.9860643D-06, 6.0537860D-06 /
      data fpp( 6, 8,14,1),fpp( 6, 8,14,2),fpp( 6, 8,14,3)/
     x 1.0703430D-02,-2.2891675D-05,-4.7637926D-06 /
      data fpp( 6, 8,15,1),fpp( 6, 8,15,2),fpp( 6, 8,15,3)/
     x 9.7574276D-03,-5.4415418D-05, 1.3647177D-06 /
      data fpp( 6, 8,16,1),fpp( 6, 8,16,2),fpp( 6, 8,16,3)/
     x 1.0703430D-02,-2.2891675D-05,-2.4110781D-06 /
      data fpp( 6, 8,17,1),fpp( 6, 8,17,2),fpp( 6, 8,17,3)/
     x 8.3474573D-03, 6.9860643D-06,-3.3570721D-06 /
      data fpp( 6, 9, 1,1),fpp( 6, 9, 1,2),fpp( 6, 9, 1,3)/
     x 5.3639670D-03, 6.2730488D-06, 2.6543487D-06 /
      data fpp( 6, 9, 2,1),fpp( 6, 9, 2,2),fpp( 6, 9, 2,3)/
     x 7.4850953D-03,-1.8420801D-05, 9.1635841D-08 /
      data fpp( 6, 9, 3,1),fpp( 6, 9, 3,2),fpp( 6, 9, 3,3)/
     x 9.5396201D-03,-4.1820862D-05,-5.4375588D-06 /
      data fpp( 6, 9, 4,1),fpp( 6, 9, 4,2),fpp( 6, 9, 4,3)/
     x 7.4850953D-03,-1.8420801D-05,-5.8406740D-07 /
      data fpp( 6, 9, 5,1),fpp( 6, 9, 5,2),fpp( 6, 9, 5,3)/
     x 5.3639670D-03, 6.2730488D-06, 5.3571617D-06 /
      data fpp( 6, 9, 6,1),fpp( 6, 9, 6,2),fpp( 6, 9, 6,3)/
     x 7.4267297D-03, 1.6012427D-05, 1.0934206D-06 /
      data fpp( 6, 9, 7,1),fpp( 6, 9, 7,2),fpp( 6, 9, 7,3)/
     x 8.9355584D-03, 3.1805699D-06,-6.6155107D-06 /
      data fpp( 6, 9, 8,1),fpp( 6, 9, 8,2),fpp( 6, 9, 8,3)/
     x 5.3113934D-03,-9.3124249D-06,-6.9804457D-07 /
      data fpp( 6, 9, 9,1),fpp( 6, 9, 9,2),fpp( 6, 9, 9,3)/
     x 1.9184809D-03,-1.4289644D-05, 8.2190223D-06 /
      data fpp( 6, 9,10,1),fpp( 6, 9,10,2),fpp( 6, 9,10,3)/
     x 5.3113934D-03,-9.3124249D-06,-6.9804457D-07 /
      data fpp( 6, 9,11,1),fpp( 6, 9,11,2),fpp( 6, 9,11,3)/
     x 8.9355584D-03, 3.1805699D-06,-6.6155107D-06 /
      data fpp( 6, 9,12,1),fpp( 6, 9,12,2),fpp( 6, 9,12,3)/
     x 7.4267297D-03, 1.6012427D-05, 1.0934206D-06 /
      data fpp( 6, 9,13,1),fpp( 6, 9,13,2),fpp( 6, 9,13,3)/
     x 5.3639670D-03, 6.2730488D-06, 5.3571617D-06 /
      data fpp( 6, 9,14,1),fpp( 6, 9,14,2),fpp( 6, 9,14,3)/
     x 7.4850953D-03,-1.8420801D-05,-5.8406740D-07 /
      data fpp( 6, 9,15,1),fpp( 6, 9,15,2),fpp( 6, 9,15,3)/
     x 9.5396201D-03,-4.1820862D-05,-5.4375588D-06 /
      data fpp( 6, 9,16,1),fpp( 6, 9,16,2),fpp( 6, 9,16,3)/
     x 7.4850953D-03,-1.8420801D-05, 9.1635841D-08 /
      data fpp( 6, 9,17,1),fpp( 6, 9,17,2),fpp( 6, 9,17,3)/
     x 5.3639670D-03, 6.2730488D-06, 2.6543487D-06 /
      data fpp( 6,10, 1,1),fpp( 6,10, 1,2),fpp( 6,10, 1,3)/
     x 3.2876212D-03, 7.4197407D-06, 4.5368237D-06 /
      data fpp( 6,10, 2,1),fpp( 6,10, 2,2),fpp( 6,10, 2,3)/
     x 1.5963584D-03,-1.1215122D-05, 1.9600193D-06 /
      data fpp( 6,10, 3,1),fpp( 6,10, 3,2),fpp( 6,10, 3,3)/
     x 2.2970131D-03,-2.1271135D-05,-4.2282342D-06 /
      data fpp( 6,10, 4,1),fpp( 6,10, 4,2),fpp( 6,10, 4,3)/
     x 1.5963584D-03,-1.1215122D-05, 2.2235841D-06 /
      data fpp( 6,10, 5,1),fpp( 6,10, 5,2),fpp( 6,10, 5,3)/
     x 3.2876212D-03, 7.4197407D-06, 3.4825645D-06 /
      data fpp( 6,10, 6,1),fpp( 6,10, 6,2),fpp( 6,10, 6,3)/
     x 7.2597401D-03, 1.9052993D-05,-3.6725087D-06 /
      data fpp( 6,10, 7,1),fpp( 6,10, 7,2),fpp( 6,10, 7,3)/
     x 5.7998289D-03, 5.1629368D-06,-5.9158630D-06 /
      data fpp( 6,10, 8,1),fpp( 6,10, 8,2),fpp( 6,10, 8,3)/
     x-1.4282643D-03,-1.0363514D-05, 1.8119609D-06 /
      data fpp( 6,10, 9,1),fpp( 6,10, 9,2),fpp( 6,10, 9,3)/
     x-5.4224413D-03,-1.6056080D-05, 8.4126862D-06 /
      data fpp( 6,10,10,1),fpp( 6,10,10,2),fpp( 6,10,10,3)/
     x-1.4282643D-03,-1.0363514D-05, 1.8119609D-06 /
      data fpp( 6,10,11,1),fpp( 6,10,11,2),fpp( 6,10,11,3)/
     x 5.7998289D-03, 5.1629368D-06,-5.9158630D-06 /
      data fpp( 6,10,12,1),fpp( 6,10,12,2),fpp( 6,10,12,3)/
     x 7.2597401D-03, 1.9052993D-05,-3.6725087D-06 /
      data fpp( 6,10,13,1),fpp( 6,10,13,2),fpp( 6,10,13,3)/
     x 3.2876212D-03, 7.4197407D-06, 3.4825645D-06 /
      data fpp( 6,10,14,1),fpp( 6,10,14,2),fpp( 6,10,14,3)/
     x 1.5963584D-03,-1.1215122D-05, 2.2235841D-06 /
      data fpp( 6,10,15,1),fpp( 6,10,15,2),fpp( 6,10,15,3)/
     x 2.2970131D-03,-2.1271135D-05,-4.2282342D-06 /
      data fpp( 6,10,16,1),fpp( 6,10,16,2),fpp( 6,10,16,3)/
     x 1.5963584D-03,-1.1215122D-05, 1.9600193D-06 /
      data fpp( 6,10,17,1),fpp( 6,10,17,2),fpp( 6,10,17,3)/
     x 3.2876212D-03, 7.4197407D-06, 4.5368237D-06 /
      data fpp( 6,11, 1,1),fpp( 6,11, 1,2),fpp( 6,11, 1,3)/
     x 2.1319380D-03, 1.1879989D-05, 5.8107771D-06 /
      data fpp( 6,11, 2,1),fpp( 6,11, 2,2),fpp( 6,11, 2,3)/
     x-4.8271620D-03,-3.0067107D-06, 4.4211125D-06 /
      data fpp( 6,11, 3,1),fpp( 6,11, 3,2),fpp( 6,11, 3,3)/
     x-6.6698297D-03,-6.5285968D-06, 4.3810624D-07 /
      data fpp( 6,11, 4,1),fpp( 6,11, 4,2),fpp( 6,11, 4,3)/
     x-4.8271620D-03,-3.0067107D-06, 5.5317959D-06 /
      data fpp( 6,11, 5,1),fpp( 6,11, 5,2),fpp( 6,11, 5,3)/
     x 2.1319380D-03, 1.1879989D-05, 1.3680437D-06 /
      data fpp( 6,11, 6,1),fpp( 6,11, 6,2),fpp( 6,11, 6,3)/
     x 9.2114066D-03, 2.5171599D-05,-1.2929970D-05 /
      data fpp( 6,11, 7,1),fpp( 6,11, 7,2),fpp( 6,11, 7,3)/
     x 2.6763554D-03, 6.3296831D-06,-4.4321618D-06 /
      data fpp( 6,11, 8,1),fpp( 6,11, 8,2),fpp( 6,11, 8,3)/
     x-8.4357666D-03,-8.7415204D-06, 5.4066177D-06 /
      data fpp( 6,11, 9,1),fpp( 6,11, 9,2),fpp( 6,11, 9,3)/
     x-1.2882541D-02,-1.3292036D-05, 9.8583578D-06 /
      data fpp( 6,11,10,1),fpp( 6,11,10,2),fpp( 6,11,10,3)/
     x-8.4357666D-03,-8.7415204D-06, 5.4066177D-06 /
      data fpp( 6,11,11,1),fpp( 6,11,11,2),fpp( 6,11,11,3)/
     x 2.6763554D-03, 6.3296831D-06,-4.4321618D-06 /
      data fpp( 6,11,12,1),fpp( 6,11,12,2),fpp( 6,11,12,3)/
     x 9.2114066D-03, 2.5171599D-05,-1.2929970D-05 /
      data fpp( 6,11,13,1),fpp( 6,11,13,2),fpp( 6,11,13,3)/
     x 2.1319380D-03, 1.1879989D-05, 1.3680437D-06 /
      data fpp( 6,11,14,1),fpp( 6,11,14,2),fpp( 6,11,14,3)/
     x-4.8271620D-03,-3.0067107D-06, 5.5317959D-06 /
      data fpp( 6,11,15,1),fpp( 6,11,15,2),fpp( 6,11,15,3)/
     x-6.6698297D-03,-6.5285968D-06, 4.3810624D-07 /
      data fpp( 6,11,16,1),fpp( 6,11,16,2),fpp( 6,11,16,3)/
     x-4.8271620D-03,-3.0067107D-06, 4.4211125D-06 /
      data fpp( 6,11,17,1),fpp( 6,11,17,2),fpp( 6,11,17,3)/
     x 2.1319380D-03, 1.1879989D-05, 5.8107771D-06 /
      data fpp( 6,12, 1,1),fpp( 6,12, 1,2),fpp( 6,12, 1,3)/
     x 2.1199874D-03, 1.9130305D-05, 8.4553224D-06 /
      data fpp( 6,12, 2,1),fpp( 6,12, 2,2),fpp( 6,12, 2,3)/
     x-9.9309031D-03, 9.3099648D-06, 8.0963552D-06 /
      data fpp( 6,12, 3,1),fpp( 6,12, 3,2),fpp( 6,12, 3,3)/
     x-1.3763199D-02, 8.2955226D-06, 5.8599233D-06 /
      data fpp( 6,12, 4,1),fpp( 6,12, 4,2),fpp( 6,12, 4,3)/
     x-9.9309031D-03, 9.3099648D-06, 1.0194618D-05 /
      data fpp( 6,12, 5,1),fpp( 6,12, 5,2),fpp( 6,12, 5,3)/
     x 2.1199874D-03, 1.9130305D-05, 6.2270833D-08 /
      data fpp( 6,12, 6,1),fpp( 6,12, 6,2),fpp( 6,12, 6,3)/
     x 1.3894950D-02, 3.0824610D-05,-2.8055701D-05 /
      data fpp( 6,12, 7,1),fpp( 6,12, 7,2),fpp( 6,12, 7,3)/
     x 9.2826355D-05, 9.6643307D-06,-1.0521317D-06 /
      data fpp( 6,12, 8,1),fpp( 6,12, 8,2),fpp( 6,12, 8,3)/
     x-1.4581430D-02,-1.0624046D-06, 9.9375614D-06 /
      data fpp( 6,12, 9,1),fpp( 6,12, 9,2),fpp( 6,12, 9,3)/
     x-1.9380159D-02,-3.8197755D-06, 1.2316553D-05 /
      data fpp( 6,12,10,1),fpp( 6,12,10,2),fpp( 6,12,10,3)/
     x-1.4581430D-02,-1.0624046D-06, 9.9375614D-06 /
      data fpp( 6,12,11,1),fpp( 6,12,11,2),fpp( 6,12,11,3)/
     x 9.2826355D-05, 9.6643307D-06,-1.0521317D-06 /
      data fpp( 6,12,12,1),fpp( 6,12,12,2),fpp( 6,12,12,3)/
     x 1.3894950D-02, 3.0824610D-05,-2.8055701D-05 /
      data fpp( 6,12,13,1),fpp( 6,12,13,2),fpp( 6,12,13,3)/
     x 2.1199874D-03, 1.9130305D-05, 6.2270833D-08 /
      data fpp( 6,12,14,1),fpp( 6,12,14,2),fpp( 6,12,14,3)/
     x-9.9309031D-03, 9.3099648D-06, 1.0194618D-05 /
      data fpp( 6,12,15,1),fpp( 6,12,15,2),fpp( 6,12,15,3)/
     x-1.3763199D-02, 8.2955226D-06, 5.8599233D-06 /
      data fpp( 6,12,16,1),fpp( 6,12,16,2),fpp( 6,12,16,3)/
     x-9.9309031D-03, 9.3099648D-06, 8.0963552D-06 /
      data fpp( 6,12,17,1),fpp( 6,12,17,2),fpp( 6,12,17,3)/
     x 2.1199874D-03, 1.9130305D-05, 8.4553224D-06 /
      data fpp( 6,13, 1,1),fpp( 6,13, 1,2),fpp( 6,13, 1,3)/
     x 3.9870939D-03, 2.6102792D-05, 1.2483731D-05 /
      data fpp( 6,13, 2,1),fpp( 6,13, 2,2),fpp( 6,13, 2,3)/
     x-1.2584293D-02, 2.7770851D-05, 1.2712982D-05 /
      data fpp( 6,13, 3,1),fpp( 6,13, 3,2),fpp( 6,13, 3,3)/
     x-1.7834756D-02, 2.8438507D-05, 1.1197673D-05 /
      data fpp( 6,13, 4,1),fpp( 6,13, 4,2),fpp( 6,13, 4,3)/
     x-1.2584293D-02, 2.7770851D-05, 1.5788326D-05 /
      data fpp( 6,13, 5,1),fpp( 6,13, 5,2),fpp( 6,13, 5,3)/
     x 3.9870939D-03, 2.6102792D-05, 1.8235648D-07 /
      data fpp( 6,13, 6,1),fpp( 6,13, 6,2),fpp( 6,13, 6,3)/
     x 2.2278263D-02, 2.5097962D-05,-4.9086419D-05 /
      data fpp( 6,13, 7,1),fpp( 6,13, 7,2),fpp( 6,13, 7,3)/
     x-1.5082650D-03, 1.4580994D-05, 5.2926512D-06 /
      data fpp( 6,13, 8,1),fpp( 6,13, 8,2),fpp( 6,13, 8,3)/
     x-1.9125993D-02, 1.4371139D-05, 1.4715814D-05 /
      data fpp( 6,13, 9,1),fpp( 6,13, 9,2),fpp( 6,13, 9,3)/
     x-2.4296549D-02, 1.4141138D-05, 1.5529426D-05 /
      data fpp( 6,13,10,1),fpp( 6,13,10,2),fpp( 6,13,10,3)/
     x-1.9125993D-02, 1.4371139D-05, 1.4715814D-05 /
      data fpp( 6,13,11,1),fpp( 6,13,11,2),fpp( 6,13,11,3)/
     x-1.5082650D-03, 1.4580994D-05, 5.2926512D-06 /
      data fpp( 6,13,12,1),fpp( 6,13,12,2),fpp( 6,13,12,3)/
     x 2.2278263D-02, 2.5097962D-05,-4.9086419D-05 /
      data fpp( 6,13,13,1),fpp( 6,13,13,2),fpp( 6,13,13,3)/
     x 3.9870939D-03, 2.6102792D-05, 1.8235648D-07 /
      data fpp( 6,13,14,1),fpp( 6,13,14,2),fpp( 6,13,14,3)/
     x-1.2584293D-02, 2.7770851D-05, 1.5788326D-05 /
      data fpp( 6,13,15,1),fpp( 6,13,15,2),fpp( 6,13,15,3)/
     x-1.7834756D-02, 2.8438507D-05, 1.1197673D-05 /
      data fpp( 6,13,16,1),fpp( 6,13,16,2),fpp( 6,13,16,3)/
     x-1.2584293D-02, 2.7770851D-05, 1.2712982D-05 /
      data fpp( 6,13,17,1),fpp( 6,13,17,2),fpp( 6,13,17,3)/
     x 3.9870939D-03, 2.6102792D-05, 1.2483731D-05 /
      data fpp( 6,14, 1,1),fpp( 6,14, 1,2),fpp( 6,14, 1,3)/
     x 1.1105686D-02, 2.9314527D-05, 1.6375679D-05 /
      data fpp( 6,14, 2,1),fpp( 6,14, 2,2),fpp( 6,14, 2,3)/
     x-1.2375146D-02, 4.9466630D-05, 1.7143087D-05 /
      data fpp( 6,14, 3,1),fpp( 6,14, 3,2),fpp( 6,14, 3,3)/
     x-1.8760800D-02, 5.4500451D-05, 1.6271974D-05 /
      data fpp( 6,14, 4,1),fpp( 6,14, 4,2),fpp( 6,14, 4,3)/
     x-1.2375146D-02, 4.9466630D-05, 2.1135685D-05 /
      data fpp( 6,14, 5,1),fpp( 6,14, 5,2),fpp( 6,14, 5,3)/
     x 1.1105686D-02, 2.9314527D-05, 4.0528505D-07 /
      data fpp( 6,14, 6,1),fpp( 6,14, 6,2),fpp( 6,14, 6,3)/
     x 3.7968800D-02,-3.0144568D-06,-7.1132159D-05 /
      data fpp( 6,14, 7,1),fpp( 6,14, 7,2),fpp( 6,14, 7,3)/
     x-1.8698741D-03, 1.6761694D-05, 1.3506017D-05 /
      data fpp( 6,14, 8,1),fpp( 6,14, 8,2),fpp( 6,14, 8,3)/
     x-2.1842936D-02, 3.6169850D-05, 1.8734090D-05 /
      data fpp( 6,14, 9,1),fpp( 6,14, 9,2),fpp( 6,14, 9,3)/
     x-2.7341686D-02, 4.0327224D-05, 1.9095621D-05 /
      data fpp( 6,14,10,1),fpp( 6,14,10,2),fpp( 6,14,10,3)/
     x-2.1842936D-02, 3.6169850D-05, 1.8734090D-05 /
      data fpp( 6,14,11,1),fpp( 6,14,11,2),fpp( 6,14,11,3)/
     x-1.8698741D-03, 1.6761694D-05, 1.3506017D-05 /
      data fpp( 6,14,12,1),fpp( 6,14,12,2),fpp( 6,14,12,3)/
     x 3.7968800D-02,-3.0144568D-06,-7.1132159D-05 /
      data fpp( 6,14,13,1),fpp( 6,14,13,2),fpp( 6,14,13,3)/
     x 1.1105686D-02, 2.9314527D-05, 4.0528505D-07 /
      data fpp( 6,14,14,1),fpp( 6,14,14,2),fpp( 6,14,14,3)/
     x-1.2375146D-02, 4.9466630D-05, 2.1135685D-05 /
      data fpp( 6,14,15,1),fpp( 6,14,15,2),fpp( 6,14,15,3)/
     x-1.8760800D-02, 5.4500451D-05, 1.6271974D-05 /
      data fpp( 6,14,16,1),fpp( 6,14,16,2),fpp( 6,14,16,3)/
     x-1.2375146D-02, 4.9466630D-05, 1.7143087D-05 /
      data fpp( 6,14,17,1),fpp( 6,14,17,2),fpp( 6,14,17,3)/
     x 1.1105686D-02, 2.9314527D-05, 1.6375679D-05 /
      data fpp( 6,15, 1,1),fpp( 6,15, 1,2),fpp( 6,15, 1,3)/
     x 2.4682458D-02, 1.0770991D-06, 1.7672932D-05 /
      data fpp( 6,15, 2,1),fpp( 6,15, 2,2),fpp( 6,15, 2,3)/
     x-8.9127045D-03, 6.2710630D-05, 1.9504581D-05 /
      data fpp( 6,15, 3,1),fpp( 6,15, 3,2),fpp( 6,15, 3,3)/
     x-1.6165731D-02, 7.8309688D-05, 2.0270076D-05 /
      data fpp( 6,15, 4,1),fpp( 6,15, 4,2),fpp( 6,15, 4,3)/
     x-8.9127045D-03, 6.2710630D-05, 2.4767114D-05 /
      data fpp( 6,15, 5,1),fpp( 6,15, 5,2),fpp( 6,15, 5,3)/
     x 2.4682458D-02, 1.0770991D-06,-3.3771971D-06 /
      data fpp( 6,15, 6,1),fpp( 6,15, 6,2),fpp( 6,15, 6,3)/
     x 5.9185998D-02,-6.8756134D-05,-8.1689659D-05 /
      data fpp( 6,15, 7,1),fpp( 6,15, 7,2),fpp( 6,15, 7,3)/
     x-8.6130024D-04, 1.2056231D-05, 1.8611164D-05 /
      data fpp( 6,15, 8,1),fpp( 6,15, 8,2),fpp( 6,15, 8,3)/
     x-2.2475145D-02, 5.9859463D-05, 2.1011001D-05 /
      data fpp( 6,15, 9,1),fpp( 6,15, 9,2),fpp( 6,15, 9,3)/
     x-2.8125941D-02, 7.1725968D-05, 2.1962166D-05 /
      data fpp( 6,15,10,1),fpp( 6,15,10,2),fpp( 6,15,10,3)/
     x-2.2475145D-02, 5.9859463D-05, 2.1011001D-05 /
      data fpp( 6,15,11,1),fpp( 6,15,11,2),fpp( 6,15,11,3)/
     x-8.6130024D-04, 1.2056231D-05, 1.8611164D-05 /
      data fpp( 6,15,12,1),fpp( 6,15,12,2),fpp( 6,15,12,3)/
     x 5.9185998D-02,-6.8756134D-05,-8.1689659D-05 /
      data fpp( 6,15,13,1),fpp( 6,15,13,2),fpp( 6,15,13,3)/
     x 2.4682458D-02, 1.0770991D-06,-3.3771971D-06 /
      data fpp( 6,15,14,1),fpp( 6,15,14,2),fpp( 6,15,14,3)/
     x-8.9127045D-03, 6.2710630D-05, 2.4767114D-05 /
      data fpp( 6,15,15,1),fpp( 6,15,15,2),fpp( 6,15,15,3)/
     x-1.6165731D-02, 7.8309688D-05, 2.0270076D-05 /
      data fpp( 6,15,16,1),fpp( 6,15,16,2),fpp( 6,15,16,3)/
     x-8.9127045D-03, 6.2710630D-05, 1.9504581D-05 /
      data fpp( 6,15,17,1),fpp( 6,15,17,2),fpp( 6,15,17,3)/
     x 2.4682458D-02, 1.0770991D-06, 1.7672932D-05 /
      data fpp( 6,16, 1,1),fpp( 6,16, 1,2),fpp( 6,16, 1,3)/
     x 3.5234678D-02,-3.7942923D-05, 1.2959380D-05 /
      data fpp( 6,16, 2,1),fpp( 6,16, 2,2),fpp( 6,16, 2,3)/
     x-8.2449044D-04, 5.2508852D-05, 1.6788351D-05 /
      data fpp( 6,16, 3,1),fpp( 6,16, 3,2),fpp( 6,16, 3,3)/
     x-8.5466801D-03, 8.0892795D-05, 2.1553884D-05 /
      data fpp( 6,16, 4,1),fpp( 6,16, 4,2),fpp( 6,16, 4,3)/
     x-8.2449044D-04, 5.2508852D-05, 2.3041448D-05 /
      data fpp( 6,16, 5,1),fpp( 6,16, 5,2),fpp( 6,16, 5,3)/
     x 3.5234678D-02,-3.7942923D-05,-1.2053011D-05 /
      data fpp( 6,16, 6,1),fpp( 6,16, 6,2),fpp( 6,16, 6,3)/
     x 6.4105141D-02,-7.9339005D-05,-6.6863406D-05 /
      data fpp( 6,16, 7,1),fpp( 6,16, 7,2),fpp( 6,16, 7,3)/
     x 9.8682351D-04, 5.4533813D-06, 1.3838635D-05 /
      data fpp( 6,16, 8,1),fpp( 6,16, 8,2),fpp( 6,16, 8,3)/
     x-2.0338745D-02, 7.2356299D-05, 2.0715533D-05 /
      data fpp( 6,16, 9,1),fpp( 6,16, 9,2),fpp( 6,16, 9,3)/
     x-2.5810594D-02, 9.2462906D-05, 2.2129900D-05 /
      data fpp( 6,16,10,1),fpp( 6,16,10,2),fpp( 6,16,10,3)/
     x-2.0338745D-02, 7.2356299D-05, 2.0715533D-05 /
      data fpp( 6,16,11,1),fpp( 6,16,11,2),fpp( 6,16,11,3)/
     x 9.8682351D-04, 5.4533813D-06, 1.3838635D-05 /
      data fpp( 6,16,12,1),fpp( 6,16,12,2),fpp( 6,16,12,3)/
     x 6.4105141D-02,-7.9339005D-05,-6.6863406D-05 /
      data fpp( 6,16,13,1),fpp( 6,16,13,2),fpp( 6,16,13,3)/
     x 3.5234678D-02,-3.7942923D-05,-1.2053011D-05 /
      data fpp( 6,16,14,1),fpp( 6,16,14,2),fpp( 6,16,14,3)/
     x-8.2449044D-04, 5.2508852D-05, 2.3041448D-05 /
      data fpp( 6,16,15,1),fpp( 6,16,15,2),fpp( 6,16,15,3)/
     x-8.5466801D-03, 8.0892795D-05, 2.1553884D-05 /
      data fpp( 6,16,16,1),fpp( 6,16,16,2),fpp( 6,16,16,3)/
     x-8.2449044D-04, 5.2508852D-05, 1.6788351D-05 /
      data fpp( 6,16,17,1),fpp( 6,16,17,2),fpp( 6,16,17,3)/
     x 3.5234678D-02,-3.7942923D-05, 1.2959380D-05 /
      data fpp( 6,17, 1,1),fpp( 6,17, 1,2),fpp( 6,17, 1,3)/
     x 4.4307973D-02,-6.1165405D-05, 3.3714887D-06 /
      data fpp( 6,17, 2,1),fpp( 6,17, 2,2),fpp( 6,17, 2,3)/
     x 1.6198043D-02,-2.2594037D-05, 8.4459114D-06 /
      data fpp( 6,17, 3,1),fpp( 6,17, 3,2),fpp( 6,17, 3,3)/
     x 8.2568777D-03, 1.2695132D-05, 1.7151532D-05 /
      data fpp( 6,17, 4,1),fpp( 6,17, 4,2),fpp( 6,17, 4,3)/
     x 1.6198043D-02,-2.2594037D-05, 1.3147960D-05 /
      data fpp( 6,17, 5,1),fpp( 6,17, 5,2),fpp( 6,17, 5,3)/
     x 4.4307973D-02,-6.1165405D-05,-1.5436704D-05 /
      data fpp( 6,17, 6,1),fpp( 6,17, 6,2),fpp( 6,17, 6,3)/
     x 4.7807355D-02,-1.3481845D-05,-3.4562478D-05 /
      data fpp( 6,17, 7,1),fpp( 6,17, 7,2),fpp( 6,17, 7,3)/
     x 5.2887333D-03, 8.9342435D-06, 3.8899492D-06 /
      data fpp( 6,17, 8,1),fpp( 6,17, 8,2),fpp( 6,17, 8,3)/
     x-1.3496244D-02, 6.5339343D-05, 1.5808015D-05 /
      data fpp( 6,17, 9,1),fpp( 6,17, 9,2),fpp( 6,17, 9,3)/
     x-1.8484420D-02, 9.3016410D-05, 1.7938659D-05 /
      data fpp( 6,17,10,1),fpp( 6,17,10,2),fpp( 6,17,10,3)/
     x-1.3496244D-02, 6.5339343D-05, 1.5808015D-05 /
      data fpp( 6,17,11,1),fpp( 6,17,11,2),fpp( 6,17,11,3)/
     x 5.2887333D-03, 8.9342435D-06, 3.8899492D-06 /
      data fpp( 6,17,12,1),fpp( 6,17,12,2),fpp( 6,17,12,3)/
     x 4.7807355D-02,-1.3481845D-05,-3.4562478D-05 /
      data fpp( 6,17,13,1),fpp( 6,17,13,2),fpp( 6,17,13,3)/
     x 4.4307973D-02,-6.1165405D-05,-1.5436704D-05 /
      data fpp( 6,17,14,1),fpp( 6,17,14,2),fpp( 6,17,14,3)/
     x 1.6198043D-02,-2.2594037D-05, 1.3147960D-05 /
      data fpp( 6,17,15,1),fpp( 6,17,15,2),fpp( 6,17,15,3)/
     x 8.2568777D-03, 1.2695132D-05, 1.7151532D-05 /
      data fpp( 6,17,16,1),fpp( 6,17,16,2),fpp( 6,17,16,3)/
     x 1.6198043D-02,-2.2594037D-05, 8.4459114D-06 /
      data fpp( 6,17,17,1),fpp( 6,17,17,2),fpp( 6,17,17,3)/
     x 4.4307973D-02,-6.1165405D-05, 3.3714887D-06 /
      data fpp( 6,18, 1,1),fpp( 6,18, 1,2),fpp( 6,18, 1,3)/
     x 4.3197413D-02,-3.6265456D-05,-1.9343321D-06 /
      data fpp( 6,18, 2,1),fpp( 6,18, 2,2),fpp( 6,18, 2,3)/
     x 4.0014796D-02,-1.3557470D-04, 5.4377526D-07 /
      data fpp( 6,18, 3,1),fpp( 6,18, 3,2),fpp( 6,18, 3,3)/
     x 3.6832231D-02,-1.7029532D-04, 5.5272311D-06 /
      data fpp( 6,18, 4,1),fpp( 6,18, 4,2),fpp( 6,18, 4,3)/
     x 4.0014796D-02,-1.3557470D-04, 1.7419672D-06 /
      data fpp( 6,18, 5,1),fpp( 6,18, 5,2),fpp( 6,18, 5,3)/
     x 4.3197413D-02,-3.6265456D-05,-6.7270999D-06 /
      data fpp( 6,18, 6,1),fpp( 6,18, 6,2),fpp( 6,18, 6,3)/
     x 3.6202846D-02, 3.2622384D-05,-8.7162344D-06 /
      data fpp( 6,18, 7,1),fpp( 6,18, 7,2),fpp( 6,18, 7,3)/
     x 1.6602035D-02, 5.9396447D-06,-1.6129587D-07 /
      data fpp( 6,18, 8,1),fpp( 6,18, 8,2),fpp( 6,18, 8,3)/
     x 3.3470590D-03,-2.1869669D-05, 6.7587512D-06 /
      data fpp( 6,18, 9,1),fpp( 6,18, 9,2),fpp( 6,18, 9,3)/
     x-8.1174960D-04,-2.7800546D-05, 8.8802911D-06 /
      data fpp( 6,18,10,1),fpp( 6,18,10,2),fpp( 6,18,10,3)/
     x 3.3470590D-03,-2.1869669D-05, 6.7587512D-06 /
      data fpp( 6,18,11,1),fpp( 6,18,11,2),fpp( 6,18,11,3)/
     x 1.6602035D-02, 5.9396447D-06,-1.6129587D-07 /
      data fpp( 6,18,12,1),fpp( 6,18,12,2),fpp( 6,18,12,3)/
     x 3.6202846D-02, 3.2622384D-05,-8.7162344D-06 /
      data fpp( 6,18,13,1),fpp( 6,18,13,2),fpp( 6,18,13,3)/
     x 4.3197413D-02,-3.6265456D-05,-6.7270999D-06 /
      data fpp( 6,18,14,1),fpp( 6,18,14,2),fpp( 6,18,14,3)/
     x 4.0014796D-02,-1.3557470D-04, 1.7419672D-06 /
      data fpp( 6,18,15,1),fpp( 6,18,15,2),fpp( 6,18,15,3)/
     x 3.6832231D-02,-1.7029532D-04, 5.5272311D-06 /
      data fpp( 6,18,16,1),fpp( 6,18,16,2),fpp( 6,18,16,3)/
     x 4.0014796D-02,-1.3557470D-04, 5.4377526D-07 /
      data fpp( 6,18,17,1),fpp( 6,18,17,2),fpp( 6,18,17,3)/
     x 4.3197413D-02,-3.6265456D-05,-1.9343321D-06 /
      data fpp( 6,19, 1,1),fpp( 6,19, 1,2),fpp( 6,19, 1,3)/
     x 3.3248832D-02,-2.5114772D-05,-9.3883973D-21 /
      data fpp( 6,19, 2,1),fpp( 6,19, 2,2),fpp( 6,19, 2,3)/
     x 3.3248832D-02,-2.3773315D-04, 2.2277909D-20 /
      data fpp( 6,19, 3,1),fpp( 6,19, 3,2),fpp( 6,19, 3,3)/
     x 3.3248832D-02,-3.2048784D-04, 9.1227667D-21 /
      data fpp( 6,19, 4,1),fpp( 6,19, 4,2),fpp( 6,19, 4,3)/
     x 3.3248832D-02,-2.3773315D-04, 1.6913982D-21 /
      data fpp( 6,19, 5,1),fpp( 6,19, 5,2),fpp( 6,19, 5,3)/
     x 3.3248832D-02,-2.5114772D-05,-4.9059785D-22 /
      data fpp( 6,19, 6,1),fpp( 6,19, 6,2),fpp( 6,19, 6,3)/
     x 3.3248832D-02, 8.4370308D-05, 5.5181964D-21 /
      data fpp( 6,19, 7,1),fpp( 6,19, 7,2),fpp( 6,19, 7,3)/
     x 3.3248832D-02, 4.7951776D-06, 1.2751896D-20 /
      data fpp( 6,19, 8,1),fpp( 6,19, 8,2),fpp( 6,19, 8,3)/
     x 3.3248832D-02,-8.6166665D-05,-1.9651204D-20 /
      data fpp( 6,19, 9,1),fpp( 6,19, 9,2),fpp( 6,19, 9,3)/
     x 3.3248832D-02,-1.1394023D-04,-5.5372787D-21 /
      data fpp( 6,19,10,1),fpp( 6,19,10,2),fpp( 6,19,10,3)/
     x 3.3248832D-02,-8.6166665D-05, 1.0718156D-20 /
      data fpp( 6,19,11,1),fpp( 6,19,11,2),fpp( 6,19,11,3)/
     x 3.3248832D-02, 4.7951776D-06,-7.3559381D-21 /
      data fpp( 6,19,12,1),fpp( 6,19,12,2),fpp( 6,19,12,3)/
     x 3.3248832D-02, 8.4370308D-05, 4.0175943D-21 /
      data fpp( 6,19,13,1),fpp( 6,19,13,2),fpp( 6,19,13,3)/
     x 3.3248832D-02,-2.5114772D-05,-1.9225850D-21 /
      data fpp( 6,19,14,1),fpp( 6,19,14,2),fpp( 6,19,14,3)/
     x 3.3248832D-02,-2.3773315D-04,-5.5542599D-21 /
      data fpp( 6,19,15,1),fpp( 6,19,15,2),fpp( 6,19,15,3)/
     x 3.3248832D-02,-3.2048784D-04,-5.1079569D-21 /
      data fpp( 6,19,16,1),fpp( 6,19,16,2),fpp( 6,19,16,3)/
     x 3.3248832D-02,-2.3773315D-04,-3.6593393D-21 /
      data fpp( 6,19,17,1),fpp( 6,19,17,2),fpp( 6,19,17,3)/
     x 3.3248832D-02,-2.5114772D-05, 7.6940141D-21 /
      data fpp( 7, 1, 1,1),fpp( 7, 1, 1,2),fpp( 7, 1, 1,3)/
     x 2.0526094D-02, 2.0378263D-06,-2.8368760D-21 /
      data fpp( 7, 1, 2,1),fpp( 7, 1, 2,2),fpp( 7, 1, 2,3)/
     x 2.0526094D-02,-1.8511200D-05, 8.0418132D-21 /
      data fpp( 7, 1, 3,1),fpp( 7, 1, 3,2),fpp( 7, 1, 3,3)/
     x 2.0526094D-02,-2.6991915D-05, 5.9572414D-21 /
      data fpp( 7, 1, 4,1),fpp( 7, 1, 4,2),fpp( 7, 1, 4,3)/
     x 2.0526094D-02,-1.8511200D-05, 3.7142860D-21 /
      data fpp( 7, 1, 5,1),fpp( 7, 1, 5,2),fpp( 7, 1, 5,3)/
     x 2.0526094D-02, 2.0378263D-06, 3.3968678D-21 /
      data fpp( 7, 1, 6,1),fpp( 7, 1, 6,2),fpp( 7, 1, 6,3)/
     x 2.0526094D-02, 1.3298873D-05, 4.2763512D-21 /
      data fpp( 7, 1, 7,1),fpp( 7, 1, 7,2),fpp( 7, 1, 7,3)/
     x 2.0526094D-02, 7.4458769D-06, 8.5945861D-21 /
      data fpp( 7, 1, 8,1),fpp( 7, 1, 8,2),fpp( 7, 1, 8,3)/
     x 2.0526094D-02,-9.5668027D-06,-8.1108440D-21 /
      data fpp( 7, 1, 9,1),fpp( 7, 1, 9,2),fpp( 7, 1, 9,3)/
     x 2.0526094D-02,-1.7958068D-05,-6.0629107D-22 /
      data fpp( 7, 1,10,1),fpp( 7, 1,10,2),fpp( 7, 1,10,3)/
     x 2.0526094D-02,-9.5668027D-06, 5.7206564D-21 /
      data fpp( 7, 1,11,1),fpp( 7, 1,11,2),fpp( 7, 1,11,3)/
     x 2.0526094D-02, 7.4458769D-06, 5.3855436D-22 /
      data fpp( 7, 1,12,1),fpp( 7, 1,12,2),fpp( 7, 1,12,3)/
     x 2.0526094D-02, 1.3298873D-05, 2.8937291D-21 /
      data fpp( 7, 1,13,1),fpp( 7, 1,13,2),fpp( 7, 1,13,3)/
     x 2.0526094D-02, 2.0378263D-06, 7.7504701D-22 /
      data fpp( 7, 1,14,1),fpp( 7, 1,14,2),fpp( 7, 1,14,3)/
     x 2.0526094D-02,-1.8511200D-05,-2.2882899D-21 /
      data fpp( 7, 1,15,1),fpp( 7, 1,15,2),fpp( 7, 1,15,3)/
     x 2.0526094D-02,-2.6991915D-05,-1.7508950D-21 /
      data fpp( 7, 1,16,1),fpp( 7, 1,16,2),fpp( 7, 1,16,3)/
     x 2.0526094D-02,-1.8511200D-05,-6.8644112D-22 /
      data fpp( 7, 1,17,1),fpp( 7, 1,17,2),fpp( 7, 1,17,3)/
     x 2.0526094D-02, 2.0378263D-06, 6.6455177D-21 /
      data fpp( 7, 2, 1,1),fpp( 7, 2, 1,2),fpp( 7, 2, 1,3)/
     x 1.9762175D-02,-1.3686526D-06, 1.2906428D-07 /
      data fpp( 7, 2, 2,1),fpp( 7, 2, 2,2),fpp( 7, 2, 2,3)/
     x 1.8233719D-02,-1.0247600D-05, 4.5498255D-07 /
      data fpp( 7, 2, 3,1),fpp( 7, 2, 3,2),fpp( 7, 2, 3,3)/
     x 1.7471020D-02,-1.6292169D-05, 1.1403389D-06 /
      data fpp( 7, 2, 4,1),fpp( 7, 2, 4,2),fpp( 7, 2, 4,3)/
     x 1.8233719D-02,-1.0247600D-05, 5.6766198D-07 /
      data fpp( 7, 2, 5,1),fpp( 7, 2, 5,2),fpp( 7, 2, 5,3)/
     x 1.9762175D-02,-1.3686526D-06,-3.2165344D-07 /
      data fpp( 7, 2, 6,1),fpp( 7, 2, 6,2),fpp( 7, 2, 6,3)/
     x 2.0781189D-02, 2.9252547D-06,-8.0238155D-07 /
      data fpp( 7, 2, 7,1),fpp( 7, 2, 7,2),fpp( 7, 2, 7,3)/
     x 2.0771977D-02, 2.4324630D-07,-5.3548702D-07 /
      data fpp( 7, 2, 8,1),fpp( 7, 2, 8,2),fpp( 7, 2, 8,3)/
     x 2.0247923D-02,-6.7423945D-06, 2.1699629D-07 /
      data fpp( 7, 2, 9,1),fpp( 7, 2, 9,2),fpp( 7, 2, 9,3)/
     x 1.9960994D-02,-1.0706863D-05, 6.2816852D-07 /
      data fpp( 7, 2,10,1),fpp( 7, 2,10,2),fpp( 7, 2,10,3)/
     x 2.0247923D-02,-6.7423945D-06, 2.1699629D-07 /
      data fpp( 7, 2,11,1),fpp( 7, 2,11,2),fpp( 7, 2,11,3)/
     x 2.0771977D-02, 2.4324630D-07,-5.3548702D-07 /
      data fpp( 7, 2,12,1),fpp( 7, 2,12,2),fpp( 7, 2,12,3)/
     x 2.0781189D-02, 2.9252547D-06,-8.0238155D-07 /
      data fpp( 7, 2,13,1),fpp( 7, 2,13,2),fpp( 7, 2,13,3)/
     x 1.9762175D-02,-1.3686526D-06,-3.2165344D-07 /
      data fpp( 7, 2,14,1),fpp( 7, 2,14,2),fpp( 7, 2,14,3)/
     x 1.8233719D-02,-1.0247600D-05, 5.6766198D-07 /
      data fpp( 7, 2,15,1),fpp( 7, 2,15,2),fpp( 7, 2,15,3)/
     x 1.7471020D-02,-1.6292169D-05, 1.1403389D-06 /
      data fpp( 7, 2,16,1),fpp( 7, 2,16,2),fpp( 7, 2,16,3)/
     x 1.8233719D-02,-1.0247600D-05, 4.5498255D-07 /
      data fpp( 7, 2,17,1),fpp( 7, 2,17,2),fpp( 7, 2,17,3)/
     x 1.9762175D-02,-1.3686526D-06, 1.2906428D-07 /
      data fpp( 7, 3, 1,1),fpp( 7, 3, 1,2),fpp( 7, 3, 1,3)/
     x 1.8455257D-02,-6.1692159D-06,-4.9889439D-07 /
      data fpp( 7, 3, 2,1),fpp( 7, 3, 2,2),fpp( 7, 3, 2,3)/
     x 1.3679784D-02,-4.8783987D-06, 1.0096777D-06 /
      data fpp( 7, 3, 3,1),fpp( 7, 3, 3,2),fpp( 7, 3, 3,3)/
     x 1.0798664D-02,-1.1135407D-05, 4.4008503D-06 /
      data fpp( 7, 3, 4,1),fpp( 7, 3, 4,2),fpp( 7, 3, 4,3)/
     x 1.3679784D-02,-4.8783987D-06, 1.2029209D-06 /
      data fpp( 7, 3, 5,1),fpp( 7, 3, 5,2),fpp( 7, 3, 5,3)/
     x 1.8455257D-02,-6.1692159D-06,-1.2718674D-06 /
      data fpp( 7, 3, 6,1),fpp( 7, 3, 6,2),fpp( 7, 3, 6,3)/
     x 2.0698426D-02,-9.2738916D-06,-2.4294514D-06 /
      data fpp( 7, 3, 7,1),fpp( 7, 3, 7,2),fpp( 7, 3, 7,3)/
     x 1.9658447D-02,-7.9928620D-06,-1.6583272D-06 /
      data fpp( 7, 3, 8,1),fpp( 7, 3, 8,2),fpp( 7, 3, 8,3)/
     x 1.8094814D-02,-3.6396191D-06, 7.9676015D-07 /
      data fpp( 7, 3, 9,1),fpp( 7, 3, 9,2),fpp( 7, 3, 9,3)/
     x 1.7408448D-02,-2.3644786D-06, 2.3512866D-06 /
      data fpp( 7, 3,10,1),fpp( 7, 3,10,2),fpp( 7, 3,10,3)/
     x 1.8094814D-02,-3.6396191D-06, 7.9676015D-07 /
      data fpp( 7, 3,11,1),fpp( 7, 3,11,2),fpp( 7, 3,11,3)/
     x 1.9658447D-02,-7.9928620D-06,-1.6583272D-06 /
      data fpp( 7, 3,12,1),fpp( 7, 3,12,2),fpp( 7, 3,12,3)/
     x 2.0698426D-02,-9.2738916D-06,-2.4294514D-06 /
      data fpp( 7, 3,13,1),fpp( 7, 3,13,2),fpp( 7, 3,13,3)/
     x 1.8455257D-02,-6.1692159D-06,-1.2718674D-06 /
      data fpp( 7, 3,14,1),fpp( 7, 3,14,2),fpp( 7, 3,14,3)/
     x 1.3679784D-02,-4.8783987D-06, 1.2029209D-06 /
      data fpp( 7, 3,15,1),fpp( 7, 3,15,2),fpp( 7, 3,15,3)/
     x 1.0798664D-02,-1.1135407D-05, 4.4008503D-06 /
      data fpp( 7, 3,16,1),fpp( 7, 3,16,2),fpp( 7, 3,16,3)/
     x 1.3679784D-02,-4.8783987D-06, 1.0096777D-06 /
      data fpp( 7, 3,17,1),fpp( 7, 3,17,2),fpp( 7, 3,17,3)/
     x 1.8455257D-02,-6.1692159D-06,-4.9889439D-07 /
      data fpp( 7, 4, 1,1),fpp( 7, 4, 1,2),fpp( 7, 4, 1,3)/
     x 1.6232285D-02,-6.0904840D-06,-3.5241829D-06 /
      data fpp( 7, 4, 2,1),fpp( 7, 4, 2,2),fpp( 7, 4, 2,3)/
     x 8.4766359D-03, 1.0621195D-05, 4.4369911D-07 /
      data fpp( 7, 4, 3,1),fpp( 7, 4, 3,2),fpp( 7, 4, 3,3)/
     x 2.5884419D-03, 1.3421799D-05, 9.9560531D-06 /
      data fpp( 7, 4, 4,1),fpp( 7, 4, 4,2),fpp( 7, 4, 4,3)/
     x 8.4766359D-03, 1.0621195D-05, 6.2755073D-08 /
      data fpp( 7, 4, 5,1),fpp( 7, 4, 5,2),fpp( 7, 4, 5,3)/
     x 1.6232285D-02,-6.0904840D-06,-2.0004067D-06 /
      data fpp( 7, 4, 6,1),fpp( 7, 4, 6,2),fpp( 7, 4, 6,3)/
     x 1.8668783D-02,-1.5083688D-05,-3.6257948D-06 /
      data fpp( 7, 4, 7,1),fpp( 7, 4, 7,2),fpp( 7, 4, 7,3)/
     x 1.5851818D-02,-1.2611798D-05,-2.2777476D-06 /
      data fpp( 7, 4, 8,1),fpp( 7, 4, 8,2),fpp( 7, 4, 8,3)/
     x 1.4932923D-02,-1.5111291D-06, 7.7811835D-07 /
      data fpp( 7, 4, 9,1),fpp( 7, 4, 9,2),fpp( 7, 4, 9,3)/
     x 1.4466098D-02, 2.1587778D-06, 4.1066075D-06 /
      data fpp( 7, 4,10,1),fpp( 7, 4,10,2),fpp( 7, 4,10,3)/
     x 1.4932923D-02,-1.5111291D-06, 7.7811835D-07 /
      data fpp( 7, 4,11,1),fpp( 7, 4,11,2),fpp( 7, 4,11,3)/
     x 1.5851818D-02,-1.2611798D-05,-2.2777476D-06 /
      data fpp( 7, 4,12,1),fpp( 7, 4,12,2),fpp( 7, 4,12,3)/
     x 1.8668783D-02,-1.5083688D-05,-3.6257948D-06 /
      data fpp( 7, 4,13,1),fpp( 7, 4,13,2),fpp( 7, 4,13,3)/
     x 1.6232285D-02,-6.0904840D-06,-2.0004067D-06 /
      data fpp( 7, 4,14,1),fpp( 7, 4,14,2),fpp( 7, 4,14,3)/
     x 8.4766359D-03, 1.0621195D-05, 6.2755073D-08 /
      data fpp( 7, 4,15,1),fpp( 7, 4,15,2),fpp( 7, 4,15,3)/
     x 2.5884419D-03, 1.3421799D-05, 9.9560531D-06 /
      data fpp( 7, 4,16,1),fpp( 7, 4,16,2),fpp( 7, 4,16,3)/
     x 8.4766359D-03, 1.0621195D-05, 4.4369911D-07 /
      data fpp( 7, 4,17,1),fpp( 7, 4,17,2),fpp( 7, 4,17,3)/
     x 1.6232285D-02,-6.0904840D-06,-3.5241829D-06 /
      data fpp( 7, 5, 1,1),fpp( 7, 5, 1,2),fpp( 7, 5, 1,3)/
     x 1.3103690D-02,-2.0728483D-06,-8.0289742D-06 /
      data fpp( 7, 5, 2,1),fpp( 7, 5, 2,2),fpp( 7, 5, 2,3)/
     x 4.8662596D-03, 1.8085618D-05,-1.4408294D-06 /
      data fpp( 7, 5, 3,1),fpp( 7, 5, 3,2),fpp( 7, 5, 3,3)/
     x-3.4288264D-03, 3.6528212D-05, 1.5052958D-05 /
      data fpp( 7, 5, 4,1),fpp( 7, 5, 4,2),fpp( 7, 5, 4,3)/
     x 4.8662596D-03, 1.8085618D-05,-3.1230044D-06 /
      data fpp( 7, 5, 5,1),fpp( 7, 5, 5,2),fpp( 7, 5, 5,3)/
     x 1.3103690D-02,-2.0728483D-06,-1.3002741D-06 /
      data fpp( 7, 5, 6,1),fpp( 7, 5, 6,2),fpp( 7, 5, 6,3)/
     x 1.4757969D-02,-8.2713552D-06,-3.7112324D-06 /
      data fpp( 7, 5, 7,1),fpp( 7, 5, 7,2),fpp( 7, 5, 7,3)/
     x 1.0628547D-02,-2.8619455D-06,-1.8967964D-06 /
      data fpp( 7, 5, 8,1),fpp( 7, 5, 8,2),fpp( 7, 5, 8,3)/
     x 1.1911770D-02, 1.0381354D-06,-3.4424864D-07 /
      data fpp( 7, 5, 9,1),fpp( 7, 5, 9,2),fpp( 7, 5, 9,3)/
     x 1.1733834D-02, 3.0113675D-06, 5.4177910D-06 /
      data fpp( 7, 5,10,1),fpp( 7, 5,10,2),fpp( 7, 5,10,3)/
     x 1.1911770D-02, 1.0381354D-06,-3.4424864D-07 /
      data fpp( 7, 5,11,1),fpp( 7, 5,11,2),fpp( 7, 5,11,3)/
     x 1.0628547D-02,-2.8619455D-06,-1.8967964D-06 /
      data fpp( 7, 5,12,1),fpp( 7, 5,12,2),fpp( 7, 5,12,3)/
     x 1.4757969D-02,-8.2713552D-06,-3.7112324D-06 /
      data fpp( 7, 5,13,1),fpp( 7, 5,13,2),fpp( 7, 5,13,3)/
     x 1.3103690D-02,-2.0728483D-06,-1.3002741D-06 /
      data fpp( 7, 5,14,1),fpp( 7, 5,14,2),fpp( 7, 5,14,3)/
     x 4.8662596D-03, 1.8085618D-05,-3.1230044D-06 /
      data fpp( 7, 5,15,1),fpp( 7, 5,15,2),fpp( 7, 5,15,3)/
     x-3.4288264D-03, 3.6528212D-05, 1.5052958D-05 /
      data fpp( 7, 5,16,1),fpp( 7, 5,16,2),fpp( 7, 5,16,3)/
     x 4.8662596D-03, 1.8085618D-05,-1.4408294D-06 /
      data fpp( 7, 5,17,1),fpp( 7, 5,17,2),fpp( 7, 5,17,3)/
     x 1.3103690D-02,-2.0728483D-06,-8.0289742D-06 /
      data fpp( 7, 6, 1,1),fpp( 7, 6, 1,2),fpp( 7, 6, 1,3)/
     x 9.7354802D-03, 1.8958773D-06,-9.5875726D-06 /
      data fpp( 7, 6, 2,1),fpp( 7, 6, 2,2),fpp( 7, 6, 2,3)/
     x 4.2790709D-03, 8.3863325D-06,-2.8751881D-06 /
      data fpp( 7, 6, 3,1),fpp( 7, 6, 3,2),fpp( 7, 6, 3,3)/
     x-4.4109857D-03, 2.7557354D-05, 1.4503658D-05 /
      data fpp( 7, 6, 4,1),fpp( 7, 6, 4,2),fpp( 7, 6, 4,3)/
     x 4.2790709D-03, 8.3863325D-06,-5.4501123D-06 /
      data fpp( 7, 6, 5,1),fpp( 7, 6, 5,2),fpp( 7, 6, 5,3)/
     x 9.7354802D-03, 1.8958773D-06, 7.1212401D-07 /
      data fpp( 7, 6, 6,1),fpp( 7, 6, 6,2),fpp( 7, 6, 6,3)/
     x 1.0797836D-02, 3.6110917D-07,-2.2917171D-06 /
      data fpp( 7, 6, 7,1),fpp( 7, 6, 7,2),fpp( 7, 6, 7,3)/
     x 7.6953723D-03, 2.7835803D-06,-1.9752557D-06 /
      data fpp( 7, 6, 8,1),fpp( 7, 6, 8,2),fpp( 7, 6, 8,3)/
     x 9.9911836D-03,-3.5541245D-07,-1.4639270D-06 /
      data fpp( 7, 6, 9,1),fpp( 7, 6, 9,2),fpp( 7, 6, 9,3)/
     x 9.3495989D-03, 1.0897521D-06, 6.0049635D-06 /
      data fpp( 7, 6,10,1),fpp( 7, 6,10,2),fpp( 7, 6,10,3)/
     x 9.9911836D-03,-3.5541245D-07,-1.4639270D-06 /
      data fpp( 7, 6,11,1),fpp( 7, 6,11,2),fpp( 7, 6,11,3)/
     x 7.6953723D-03, 2.7835803D-06,-1.9752557D-06 /
      data fpp( 7, 6,12,1),fpp( 7, 6,12,2),fpp( 7, 6,12,3)/
     x 1.0797836D-02, 3.6110917D-07,-2.2917171D-06 /
      data fpp( 7, 6,13,1),fpp( 7, 6,13,2),fpp( 7, 6,13,3)/
     x 9.7354802D-03, 1.8958773D-06, 7.1212401D-07 /
      data fpp( 7, 6,14,1),fpp( 7, 6,14,2),fpp( 7, 6,14,3)/
     x 4.2790709D-03, 8.3863325D-06,-5.4501123D-06 /
      data fpp( 7, 6,15,1),fpp( 7, 6,15,2),fpp( 7, 6,15,3)/
     x-4.4109857D-03, 2.7557354D-05, 1.4503658D-05 /
      data fpp( 7, 6,16,1),fpp( 7, 6,16,2),fpp( 7, 6,16,3)/
     x 4.2790709D-03, 8.3863325D-06,-2.8751881D-06 /
      data fpp( 7, 6,17,1),fpp( 7, 6,17,2),fpp( 7, 6,17,3)/
     x 9.7354802D-03, 1.8958773D-06,-9.5875726D-06 /
      data fpp( 7, 7, 1,1),fpp( 7, 7, 1,2),fpp( 7, 7, 1,3)/
     x 6.7438638D-03, 3.5673392D-06,-6.0796187D-06 /
      data fpp( 7, 7, 2,1),fpp( 7, 7, 2,2),fpp( 7, 7, 2,3)/
     x 5.5625923D-03,-5.9949481D-06,-2.4196515D-06 /
      data fpp( 7, 7, 3,1),fpp( 7, 7, 3,2),fpp( 7, 7, 3,3)/
     x 2.8236185D-04,-8.6736266D-06, 7.5382246D-06 /
      data fpp( 7, 7, 4,1),fpp( 7, 7, 4,2),fpp( 7, 7, 4,3)/
     x 5.5625923D-03,-5.9949481D-06,-4.5465803D-06 /
      data fpp( 7, 7, 5,1),fpp( 7, 7, 5,2),fpp( 7, 7, 5,3)/
     x 6.7438638D-03, 3.5673392D-06, 2.4280966D-06 /
      data fpp( 7, 7, 6,1),fpp( 7, 7, 6,2),fpp( 7, 7, 6,3)/
     x 7.6825483D-03, 5.5069186D-06,-1.0472618D-08 /
      data fpp( 7, 7, 7,1),fpp( 7, 7, 7,2),fpp( 7, 7, 7,3)/
     x 7.3584998D-03,-8.2037554D-07,-3.0742061D-06 /
      data fpp( 7, 7, 8,1),fpp( 7, 7, 8,2),fpp( 7, 7, 8,3)/
     x 8.5446491D-03,-2.9644856D-06,-1.5380364D-06 /
      data fpp( 7, 7, 9,1),fpp( 7, 7, 9,2),fpp( 7, 7, 9,3)/
     x 7.0776892D-03,-2.0843758D-06, 5.5896848D-06 /
      data fpp( 7, 7,10,1),fpp( 7, 7,10,2),fpp( 7, 7,10,3)/
     x 8.5446491D-03,-2.9644856D-06,-1.5380364D-06 /
      data fpp( 7, 7,11,1),fpp( 7, 7,11,2),fpp( 7, 7,11,3)/
     x 7.3584998D-03,-8.2037554D-07,-3.0742061D-06 /
      data fpp( 7, 7,12,1),fpp( 7, 7,12,2),fpp( 7, 7,12,3)/
     x 7.6825483D-03, 5.5069186D-06,-1.0472618D-08 /
      data fpp( 7, 7,13,1),fpp( 7, 7,13,2),fpp( 7, 7,13,3)/
     x 6.7438638D-03, 3.5673392D-06, 2.4280966D-06 /
      data fpp( 7, 7,14,1),fpp( 7, 7,14,2),fpp( 7, 7,14,3)/
     x 5.5625923D-03,-5.9949481D-06,-4.5465803D-06 /
      data fpp( 7, 7,15,1),fpp( 7, 7,15,2),fpp( 7, 7,15,3)/
     x 2.8236185D-04,-8.6736266D-06, 7.5382246D-06 /
      data fpp( 7, 7,16,1),fpp( 7, 7,16,2),fpp( 7, 7,16,3)/
     x 5.5625923D-03,-5.9949481D-06,-2.4196515D-06 /
      data fpp( 7, 7,17,1),fpp( 7, 7,17,2),fpp( 7, 7,17,3)/
     x 6.7438638D-03, 3.5673392D-06,-6.0796187D-06 /
      data fpp( 7, 8, 1,1),fpp( 7, 8, 1,2),fpp( 7, 8, 1,3)/
     x 4.3688295D-03, 3.4067661D-06,-1.3704525D-06 /
      data fpp( 7, 8, 2,1),fpp( 7, 8, 2,2),fpp( 7, 8, 2,3)/
     x 5.9476788D-03,-1.1058540D-05,-1.0835394D-06 /
      data fpp( 7, 8, 3,1),fpp( 7, 8, 3,2),fpp( 7, 8, 3,3)/
     x 5.5066927D-03,-2.5496847D-05, 3.2061016D-07 /
      data fpp( 7, 8, 4,1),fpp( 7, 8, 4,2),fpp( 7, 8, 4,3)/
     x 5.9476788D-03,-1.1058540D-05,-2.1855679D-06 /
      data fpp( 7, 8, 5,1),fpp( 7, 8, 5,2),fpp( 7, 8, 5,3)/
     x 4.3688295D-03, 3.4067661D-06, 3.0376614D-06 /
      data fpp( 7, 8, 6,1),fpp( 7, 8, 6,2),fpp( 7, 8, 6,3)/
     x 5.3077158D-03, 7.8032166D-06, 1.2829224D-06 /
      data fpp( 7, 8, 7,1),fpp( 7, 8, 7,2),fpp( 7, 8, 7,3)/
     x 6.9109558D-03, 4.0192188D-07,-3.6606842D-06 /
      data fpp( 7, 8, 8,1),fpp( 7, 8, 8,2),fpp( 7, 8, 8,3)/
     x 6.3409715D-03,-3.8606453D-06,-1.0841855D-06 /
      data fpp( 7, 8, 9,1),fpp( 7, 8, 9,2),fpp( 7, 8, 9,3)/
     x 4.4320829D-03,-5.3162490D-06, 4.7154261D-06 /
      data fpp( 7, 8,10,1),fpp( 7, 8,10,2),fpp( 7, 8,10,3)/
     x 6.3409715D-03,-3.8606453D-06,-1.0841855D-06 /
      data fpp( 7, 8,11,1),fpp( 7, 8,11,2),fpp( 7, 8,11,3)/
     x 6.9109558D-03, 4.0192188D-07,-3.6606842D-06 /
      data fpp( 7, 8,12,1),fpp( 7, 8,12,2),fpp( 7, 8,12,3)/
     x 5.3077158D-03, 7.8032166D-06, 1.2829224D-06 /
      data fpp( 7, 8,13,1),fpp( 7, 8,13,2),fpp( 7, 8,13,3)/
     x 4.3688295D-03, 3.4067661D-06, 3.0376614D-06 /
      data fpp( 7, 8,14,1),fpp( 7, 8,14,2),fpp( 7, 8,14,3)/
     x 5.9476788D-03,-1.1058540D-05,-2.1855679D-06 /
      data fpp( 7, 8,15,1),fpp( 7, 8,15,2),fpp( 7, 8,15,3)/
     x 5.5066927D-03,-2.5496847D-05, 3.2061016D-07 /
      data fpp( 7, 8,16,1),fpp( 7, 8,16,2),fpp( 7, 8,16,3)/
     x 5.9476788D-03,-1.1058540D-05,-1.0835394D-06 /
      data fpp( 7, 8,17,1),fpp( 7, 8,17,2),fpp( 7, 8,17,3)/
     x 4.3688295D-03, 3.4067661D-06,-1.3704525D-06 /
      data fpp( 7, 9, 1,1),fpp( 7, 9, 1,2),fpp( 7, 9, 1,3)/
     x 2.6378104D-03, 2.9655965D-06, 1.2634538D-06 /
      data fpp( 7, 9, 2,1),fpp( 7, 9, 2,2),fpp( 7, 9, 2,3)/
     x 4.2575329D-03,-9.6328920D-06,-1.3463106D-08 /
      data fpp( 7, 9, 3,1),fpp( 7, 9, 3,2),fpp( 7, 9, 3,3)/
     x 5.6806982D-03,-2.0156984D-05,-2.7502680D-06 /
      data fpp( 7, 9, 4,1),fpp( 7, 9, 4,2),fpp( 7, 9, 4,3)/
     x 4.2575329D-03,-9.6328920D-06,-3.7746482D-07 /
      data fpp( 7, 9, 5,1),fpp( 7, 9, 5,2),fpp( 7, 9, 5,3)/
     x 2.6378104D-03, 2.9655965D-06, 2.7194606D-06 /
      data fpp( 7, 9, 6,1),fpp( 7, 9, 6,2),fpp( 7, 9, 6,3)/
     x 3.8569328D-03, 8.5742150D-06, 7.4162223D-07 /
      data fpp( 7, 9, 7,1),fpp( 7, 9, 7,2),fpp( 7, 9, 7,3)/
     x 5.1634113D-03, 2.6206880D-06,-3.4272829D-06 /
      data fpp( 7, 9, 8,1),fpp( 7, 9, 8,2),fpp( 7, 9, 8,3)/
     x 3.1177595D-03,-4.9749333D-06,-3.9782393D-07 /
      data fpp( 7, 9, 9,1),fpp( 7, 9, 9,2),fpp( 7, 9, 9,3)/
     x 9.8505582D-04,-8.0906283D-06, 4.1725786D-06 /
      data fpp( 7, 9,10,1),fpp( 7, 9,10,2),fpp( 7, 9,10,3)/
     x 3.1177595D-03,-4.9749333D-06,-3.9782393D-07 /
      data fpp( 7, 9,11,1),fpp( 7, 9,11,2),fpp( 7, 9,11,3)/
     x 5.1634113D-03, 2.6206880D-06,-3.4272829D-06 /
      data fpp( 7, 9,12,1),fpp( 7, 9,12,2),fpp( 7, 9,12,3)/
     x 3.8569328D-03, 8.5742150D-06, 7.4162223D-07 /
      data fpp( 7, 9,13,1),fpp( 7, 9,13,2),fpp( 7, 9,13,3)/
     x 2.6378104D-03, 2.9655965D-06, 2.7194606D-06 /
      data fpp( 7, 9,14,1),fpp( 7, 9,14,2),fpp( 7, 9,14,3)/
     x 4.2575329D-03,-9.6328920D-06,-3.7746482D-07 /
      data fpp( 7, 9,15,1),fpp( 7, 9,15,2),fpp( 7, 9,15,3)/
     x 5.6806982D-03,-2.0156984D-05,-2.7502680D-06 /
      data fpp( 7, 9,16,1),fpp( 7, 9,16,2),fpp( 7, 9,16,3)/
     x 4.2575329D-03,-9.6328920D-06,-1.3463106D-08 /
      data fpp( 7, 9,17,1),fpp( 7, 9,17,2),fpp( 7, 9,17,3)/
     x 2.6378104D-03, 2.9655965D-06, 1.2634538D-06 /
      data fpp( 7,10, 1,1),fpp( 7,10, 1,2),fpp( 7,10, 1,3)/
     x 1.5256483D-03, 3.6908479D-06, 2.2649640D-06 /
      data fpp( 7,10, 2,1),fpp( 7,10, 2,2),fpp( 7,10, 2,3)/
     x 9.5687682D-04,-6.8338920D-06, 9.3640536D-07 /
      data fpp( 7,10, 3,1),fpp( 7,10, 3,2),fpp( 7,10, 3,3)/
     x 1.6803537D-03,-1.2489218D-05,-2.2419187D-06 /
      data fpp( 7,10, 4,1),fpp( 7,10, 4,2),fpp( 7,10, 4,3)/
     x 9.5687682D-04,-6.8338920D-06, 1.0539363D-06 /
      data fpp( 7,10, 5,1),fpp( 7,10, 5,2),fpp( 7,10, 5,3)/
     x 1.5256483D-03, 3.6908479D-06, 1.7948403D-06 /
      data fpp( 7,10, 6,1),fpp( 7,10, 6,2),fpp( 7,10, 6,3)/
     x 3.6403435D-03, 1.0021923D-05,-1.6886307D-06 /
      data fpp( 7,10, 7,1),fpp( 7,10, 7,2),fpp( 7,10, 7,3)/
     x 3.0867529D-03, 2.7533261D-06,-2.9923174D-06 /
      data fpp( 7,10, 8,1),fpp( 7,10, 8,2),fpp( 7,10, 8,3)/
     x-9.4240643D-04,-6.3476214D-06, 7.8656687D-07 /
      data fpp( 7,10, 9,1),fpp( 7,10, 9,2),fpp( 7,10, 9,3)/
     x-3.4547791D-03,-9.9252377D-06, 4.3527166D-06 /
      data fpp( 7,10,10,1),fpp( 7,10,10,2),fpp( 7,10,10,3)/
     x-9.4240643D-04,-6.3476214D-06, 7.8656687D-07 /
      data fpp( 7,10,11,1),fpp( 7,10,11,2),fpp( 7,10,11,3)/
     x 3.0867529D-03, 2.7533261D-06,-2.9923174D-06 /
      data fpp( 7,10,12,1),fpp( 7,10,12,2),fpp( 7,10,12,3)/
     x 3.6403435D-03, 1.0021923D-05,-1.6886307D-06 /
      data fpp( 7,10,13,1),fpp( 7,10,13,2),fpp( 7,10,13,3)/
     x 1.5256483D-03, 3.6908479D-06, 1.7948403D-06 /
      data fpp( 7,10,14,1),fpp( 7,10,14,2),fpp( 7,10,14,3)/
     x 9.5687682D-04,-6.8338920D-06, 1.0539363D-06 /
      data fpp( 7,10,15,1),fpp( 7,10,15,2),fpp( 7,10,15,3)/
     x 1.6803537D-03,-1.2489218D-05,-2.2419187D-06 /
      data fpp( 7,10,16,1),fpp( 7,10,16,2),fpp( 7,10,16,3)/
     x 9.5687682D-04,-6.8338920D-06, 9.3640536D-07 /
      data fpp( 7,10,17,1),fpp( 7,10,17,2),fpp( 7,10,17,3)/
     x 1.5256483D-03, 3.6908479D-06, 2.2649640D-06 /
      data fpp( 7,11, 1,1),fpp( 7,11, 1,2),fpp( 7,11, 1,3)/
     x 1.0818426D-03, 6.4330118D-06, 3.0432648D-06 /
      data fpp( 7,11, 2,1),fpp( 7,11, 2,2),fpp( 7,11, 2,3)/
     x-3.0556356D-03,-3.0395399D-06, 2.2733593D-06 /
      data fpp( 7,11, 3,1),fpp( 7,11, 3,2),fpp( 7,11, 3,3)/
     x-3.9785347D-03,-5.9001449D-06, 7.0631276D-08 /
      data fpp( 7,11, 4,1),fpp( 7,11, 4,2),fpp( 7,11, 4,3)/
     x-3.0556356D-03,-3.0395399D-06, 2.8827822D-06 /
      data fpp( 7,11, 5,1),fpp( 7,11, 5,2),fpp( 7,11, 5,3)/
     x 1.0818426D-03, 6.4330118D-06, 6.0557308D-07 /
      data fpp( 7,11, 6,1),fpp( 7,11, 6,2),fpp( 7,11, 6,3)/
     x 5.0031333D-03, 1.3258092D-05,-6.3924079D-06 /
      data fpp( 7,11, 7,1),fpp( 7,11, 7,2),fpp( 7,11, 7,3)/
     x 1.3066512D-03, 3.2800076D-06,-2.3946081D-06 /
      data fpp( 7,11, 8,1),fpp( 7,11, 8,2),fpp( 7,11, 8,3)/
     x-5.5949422D-03,-6.2585812D-06, 2.6455071D-06 /
      data fpp( 7,11, 9,1),fpp( 7,11, 9,2),fpp( 7,11, 9,3)/
     x-8.7136145D-03,-9.3824210D-06, 5.3372465D-06 /
      data fpp( 7,11,10,1),fpp( 7,11,10,2),fpp( 7,11,10,3)/
     x-5.5949422D-03,-6.2585812D-06, 2.6455071D-06 /
      data fpp( 7,11,11,1),fpp( 7,11,11,2),fpp( 7,11,11,3)/
     x 1.3066512D-03, 3.2800076D-06,-2.3946081D-06 /
      data fpp( 7,11,12,1),fpp( 7,11,12,2),fpp( 7,11,12,3)/
     x 5.0031333D-03, 1.3258092D-05,-6.3924079D-06 /
      data fpp( 7,11,13,1),fpp( 7,11,13,2),fpp( 7,11,13,3)/
     x 1.0818426D-03, 6.4330118D-06, 6.0557308D-07 /
      data fpp( 7,11,14,1),fpp( 7,11,14,2),fpp( 7,11,14,3)/
     x-3.0556356D-03,-3.0395399D-06, 2.8827822D-06 /
      data fpp( 7,11,15,1),fpp( 7,11,15,2),fpp( 7,11,15,3)/
     x-3.9785347D-03,-5.9001449D-06, 7.0631276D-08 /
      data fpp( 7,11,16,1),fpp( 7,11,16,2),fpp( 7,11,16,3)/
     x-3.0556356D-03,-3.0395399D-06, 2.2733593D-06 /
      data fpp( 7,11,17,1),fpp( 7,11,17,2),fpp( 7,11,17,3)/
     x 1.0818426D-03, 6.4330118D-06, 3.0432648D-06 /
      data fpp( 7,12, 1,1),fpp( 7,12, 1,2),fpp( 7,12, 1,3)/
     x 1.5130737D-03, 1.1053105D-05, 4.4972012D-06 /
      data fpp( 7,12, 2,1),fpp( 7,12, 2,2),fpp( 7,12, 2,3)/
     x-6.8538107D-03, 3.8000515D-06, 4.3084865D-06 /
      data fpp( 7,12, 3,1),fpp( 7,12, 3,2),fpp( 7,12, 3,3)/
     x-9.4556450D-03, 2.2677973D-06, 3.0301860D-06 /
      data fpp( 7,12, 4,1),fpp( 7,12, 4,2),fpp( 7,12, 4,3)/
     x-6.8538107D-03, 3.8000515D-06, 5.5654360D-06 /
      data fpp( 7,12, 5,1),fpp( 7,12, 5,2),fpp( 7,12, 5,3)/
     x 1.5130737D-03, 1.1053105D-05,-5.3059656D-07 /
      data fpp( 7,12, 6,1),fpp( 7,12, 6,2),fpp( 7,12, 6,3)/
     x 8.3913000D-03, 1.6649710D-05,-1.3989050D-05 /
      data fpp( 7,12, 7,1),fpp( 7,12, 7,2),fpp( 7,12, 7,3)/
     x 2.4194666D-05, 5.2706434D-06,-1.1438712D-06 /
      data fpp( 7,12, 8,1),fpp( 7,12, 8,2),fpp( 7,12, 8,3)/
     x-1.0365370D-02,-2.3320539D-06, 5.1965346D-06 /
      data fpp( 7,12, 9,1),fpp( 7,12, 9,2),fpp( 7,12, 9,3)/
     x-1.4169687D-02,-4.3790785D-06, 6.9823993D-06 /
      data fpp( 7,12,10,1),fpp( 7,12,10,2),fpp( 7,12,10,3)/
     x-1.0365370D-02,-2.3320539D-06, 5.1965346D-06 /
      data fpp( 7,12,11,1),fpp( 7,12,11,2),fpp( 7,12,11,3)/
     x 2.4194666D-05, 5.2706434D-06,-1.1438712D-06 /
      data fpp( 7,12,12,1),fpp( 7,12,12,2),fpp( 7,12,12,3)/
     x 8.3913000D-03, 1.6649710D-05,-1.3989050D-05 /
      data fpp( 7,12,13,1),fpp( 7,12,13,2),fpp( 7,12,13,3)/
     x 1.5130737D-03, 1.1053105D-05,-5.3059656D-07 /
      data fpp( 7,12,14,1),fpp( 7,12,14,2),fpp( 7,12,14,3)/
     x-6.8538107D-03, 3.8000515D-06, 5.5654360D-06 /
      data fpp( 7,12,15,1),fpp( 7,12,15,2),fpp( 7,12,15,3)/
     x-9.4556450D-03, 2.2677973D-06, 3.0301860D-06 /
      data fpp( 7,12,16,1),fpp( 7,12,16,2),fpp( 7,12,16,3)/
     x-6.8538107D-03, 3.8000515D-06, 4.3084865D-06 /
      data fpp( 7,12,17,1),fpp( 7,12,17,2),fpp( 7,12,17,3)/
     x 1.5130737D-03, 1.1053105D-05, 4.4972012D-06 /
      data fpp( 7,13, 1,1),fpp( 7,13, 1,2),fpp( 7,13, 1,3)/
     x 3.0800189D-03, 1.4646568D-05, 6.6670631D-06 /
      data fpp( 7,13, 2,1),fpp( 7,13, 2,2),fpp( 7,13, 2,3)/
     x-9.4582824D-03, 1.5013334D-05, 6.9252072D-06 /
      data fpp( 7,13, 3,1),fpp( 7,13, 3,2),fpp( 7,13, 3,3)/
     x-1.3446367D-02, 1.4906956D-05, 6.1721081D-06 /
      data fpp( 7,13, 4,1),fpp( 7,13, 4,2),fpp( 7,13, 4,3)/
     x-9.4582824D-03, 1.5013334D-05, 8.9583604D-06 /
      data fpp( 7,13, 5,1),fpp( 7,13, 5,2),fpp( 7,13, 5,3)/
     x 3.0800189D-03, 1.4646568D-05,-1.4655496D-06 /
      data fpp( 7,13, 6,1),fpp( 7,13, 6,2),fpp( 7,13, 6,3)/
     x 1.3969489D-02, 1.2537069D-05,-2.4324829D-05 /
      data fpp( 7,13, 7,1),fpp( 7,13, 7,2),fpp( 7,13, 7,3)/
     x-5.5707140D-04, 8.1994186D-06, 1.2028641D-06 /
      data fpp( 7,13, 8,1),fpp( 7,13, 8,2),fpp( 7,13, 8,3)/
     x-1.4495363D-02, 7.0727969D-06, 8.1867055D-06 /
      data fpp( 7,13, 9,1),fpp( 7,13, 9,2),fpp( 7,13, 9,3)/
     x-1.8962382D-02, 6.7987348D-06, 9.0516473D-06 /
      data fpp( 7,13,10,1),fpp( 7,13,10,2),fpp( 7,13,10,3)/
     x-1.4495363D-02, 7.0727969D-06, 8.1867055D-06 /
      data fpp( 7,13,11,1),fpp( 7,13,11,2),fpp( 7,13,11,3)/
     x-5.5707140D-04, 8.1994186D-06, 1.2028641D-06 /
      data fpp( 7,13,12,1),fpp( 7,13,12,2),fpp( 7,13,12,3)/
     x 1.3969489D-02, 1.2537069D-05,-2.4324829D-05 /
      data fpp( 7,13,13,1),fpp( 7,13,13,2),fpp( 7,13,13,3)/
     x 3.0800189D-03, 1.4646568D-05,-1.4655496D-06 /
      data fpp( 7,13,14,1),fpp( 7,13,14,2),fpp( 7,13,14,3)/
     x-9.4582824D-03, 1.5013334D-05, 8.9583604D-06 /
      data fpp( 7,13,15,1),fpp( 7,13,15,2),fpp( 7,13,15,3)/
     x-1.3446367D-02, 1.4906956D-05, 6.1721081D-06 /
      data fpp( 7,13,16,1),fpp( 7,13,16,2),fpp( 7,13,16,3)/
     x-9.4582824D-03, 1.5013334D-05, 6.9252072D-06 /
      data fpp( 7,13,17,1),fpp( 7,13,17,2),fpp( 7,13,17,3)/
     x 3.0800189D-03, 1.4646568D-05, 6.6670631D-06 /
      data fpp( 7,14, 1,1),fpp( 7,14, 1,2),fpp( 7,14, 1,3)/
     x 6.2364123D-03, 1.2668622D-05, 8.5700761D-06 /
      data fpp( 7,14, 2,1),fpp( 7,14, 2,2),fpp( 7,14, 2,3)/
     x-9.7936633D-03, 2.8468613D-05, 9.3624033D-06 /
      data fpp( 7,14, 3,1),fpp( 7,14, 3,2),fpp( 7,14, 3,3)/
     x-1.4920686D-02, 3.1710381D-05, 9.3289772D-06 /
      data fpp( 7,14, 4,1),fpp( 7,14, 4,2),fpp( 7,14, 4,3)/
     x-9.7936633D-03, 2.8468613D-05, 1.2185688D-05 /
      data fpp( 7,14, 5,1),fpp( 7,14, 5,2),fpp( 7,14, 5,3)/
     x 6.2364123D-03, 1.2668622D-05,-2.7230618D-06 /
      data fpp( 7,14, 6,1),fpp( 7,14, 6,2),fpp( 7,14, 6,3)/
     x 2.1162017D-02,-5.7899843D-06,-3.4458774D-05 /
      data fpp( 7,14, 7,1),fpp( 7,14, 7,2),fpp( 7,14, 7,3)/
     x-1.2641143D-04, 9.2236821D-06, 3.9074904D-06 /
      data fpp( 7,14, 8,1),fpp( 7,14, 8,2),fpp( 7,14, 8,3)/
     x-1.7141484D-02, 2.1248866D-05, 1.1058146D-05 /
      data fpp( 7,14, 9,1),fpp( 7,14, 9,2),fpp( 7,14, 9,3)/
     x-2.2231409D-02, 2.3990139D-05, 1.1202594D-05 /
      data fpp( 7,14,10,1),fpp( 7,14,10,2),fpp( 7,14,10,3)/
     x-1.7141484D-02, 2.1248866D-05, 1.1058146D-05 /
      data fpp( 7,14,11,1),fpp( 7,14,11,2),fpp( 7,14,11,3)/
     x-1.2641143D-04, 9.2236821D-06, 3.9074904D-06 /
      data fpp( 7,14,12,1),fpp( 7,14,12,2),fpp( 7,14,12,3)/
     x 2.1162017D-02,-5.7899843D-06,-3.4458774D-05 /
      data fpp( 7,14,13,1),fpp( 7,14,13,2),fpp( 7,14,13,3)/
     x 6.2364123D-03, 1.2668622D-05,-2.7230618D-06 /
      data fpp( 7,14,14,1),fpp( 7,14,14,2),fpp( 7,14,14,3)/
     x-9.7936633D-03, 2.8468613D-05, 1.2185688D-05 /
      data fpp( 7,14,15,1),fpp( 7,14,15,2),fpp( 7,14,15,3)/
     x-1.4920686D-02, 3.1710381D-05, 9.3289772D-06 /
      data fpp( 7,14,16,1),fpp( 7,14,16,2),fpp( 7,14,16,3)/
     x-9.7936633D-03, 2.8468613D-05, 9.3624033D-06 /
      data fpp( 7,14,17,1),fpp( 7,14,17,2),fpp( 7,14,17,3)/
     x 6.2364123D-03, 1.2668622D-05, 8.5700761D-06 /
      data fpp( 7,15, 1,1),fpp( 7,15, 1,2),fpp( 7,15, 1,3)/
     x 1.2103665D-02,-1.2410562D-06, 8.5257558D-06 /
      data fpp( 7,15, 2,1),fpp( 7,15, 2,2),fpp( 7,15, 2,3)/
     x-6.8224207D-03, 3.5422214D-05, 1.0263711D-05 /
      data fpp( 7,15, 3,1),fpp( 7,15, 3,2),fpp( 7,15, 3,3)/
     x-1.2860975D-02, 4.5661522D-05, 1.2006735D-05 /
      data fpp( 7,15, 4,1),fpp( 7,15, 4,2),fpp( 7,15, 4,3)/
     x-6.8224207D-03, 3.5422214D-05, 1.3732016D-05 /
      data fpp( 7,15, 5,1),fpp( 7,15, 5,2),fpp( 7,15, 5,3)/
     x 1.2103665D-02,-1.2410562D-06,-5.3474646D-06 /
      data fpp( 7,15, 6,1),fpp( 7,15, 6,2),fpp( 7,15, 6,3)/
     x 2.7829595D-02,-3.2403131D-05,-3.8208157D-05 /
      data fpp( 7,15, 7,1),fpp( 7,15, 7,2),fpp( 7,15, 7,3)/
     x 1.5614461D-03, 5.9958532D-06, 4.7987603D-06 /
      data fpp( 7,15, 8,1),fpp( 7,15, 8,2),fpp( 7,15, 8,3)/
     x-1.7505412D-02, 3.5959737D-05, 1.2889783D-05 /
      data fpp( 7,15, 9,1),fpp( 7,15, 9,2),fpp( 7,15, 9,3)/
     x-2.3065227D-02, 4.3844709D-05, 1.2841442D-05 /
      data fpp( 7,15,10,1),fpp( 7,15,10,2),fpp( 7,15,10,3)/
     x-1.7505412D-02, 3.5959737D-05, 1.2889783D-05 /
      data fpp( 7,15,11,1),fpp( 7,15,11,2),fpp( 7,15,11,3)/
     x 1.5614461D-03, 5.9958532D-06, 4.7987603D-06 /
      data fpp( 7,15,12,1),fpp( 7,15,12,2),fpp( 7,15,12,3)/
     x 2.7829595D-02,-3.2403131D-05,-3.8208157D-05 /
      data fpp( 7,15,13,1),fpp( 7,15,13,2),fpp( 7,15,13,3)/
     x 1.2103665D-02,-1.2410562D-06,-5.3474646D-06 /
      data fpp( 7,15,14,1),fpp( 7,15,14,2),fpp( 7,15,14,3)/
     x-6.8224207D-03, 3.5422214D-05, 1.3732016D-05 /
      data fpp( 7,15,15,1),fpp( 7,15,15,2),fpp( 7,15,15,3)/
     x-1.2860975D-02, 4.5661522D-05, 1.2006735D-05 /
      data fpp( 7,15,16,1),fpp( 7,15,16,2),fpp( 7,15,16,3)/
     x-6.8224207D-03, 3.5422214D-05, 1.0263711D-05 /
      data fpp( 7,15,17,1),fpp( 7,15,17,2),fpp( 7,15,17,3)/
     x 1.2103665D-02,-1.2410562D-06, 8.5257558D-06 /
      data fpp( 7,16, 1,1),fpp( 7,16, 1,2),fpp( 7,16, 1,3)/
     x 1.9829063D-02,-2.3550397D-05, 5.4205934D-06 /
      data fpp( 7,16, 2,1),fpp( 7,16, 2,2),fpp( 7,16, 2,3)/
     x 6.3821127D-04, 2.4206530D-05, 8.3188132D-06 /
      data fpp( 7,16, 3,1),fpp( 7,16, 3,2),fpp( 7,16, 3,3)/
     x-5.8583447D-03, 4.2983530D-05, 1.2770820D-05 /
      data fpp( 7,16, 4,1),fpp( 7,16, 4,2),fpp( 7,16, 4,3)/
     x 6.3821127D-04, 2.4206530D-05, 1.1784572D-05 /
      data fpp( 7,16, 5,1),fpp( 7,16, 5,2),fpp( 7,16, 5,3)/
     x 1.9829063D-02,-2.3550397D-05,-8.4424405D-06 /
      data fpp( 7,16, 6,1),fpp( 7,16, 6,2),fpp( 7,16, 6,3)/
     x 2.9592871D-02,-3.8987491D-05,-3.0840810D-05 /
      data fpp( 7,16, 7,1),fpp( 7,16, 7,2),fpp( 7,16, 7,3)/
     x 4.6669222D-03, 1.0469053D-06, 2.4923462D-06 /
      data fpp( 7,16, 8,1),fpp( 7,16, 8,2),fpp( 7,16, 8,3)/
     x-1.4524406D-02, 4.2044184D-05, 1.2421425D-05 /
      data fpp( 7,16, 9,1),fpp( 7,16, 9,2),fpp( 7,16, 9,3)/
     x-2.0237082D-02, 5.5529027D-05, 1.2976621D-05 /
      data fpp( 7,16,10,1),fpp( 7,16,10,2),fpp( 7,16,10,3)/
     x-1.4524406D-02, 4.2044184D-05, 1.2421425D-05 /
      data fpp( 7,16,11,1),fpp( 7,16,11,2),fpp( 7,16,11,3)/
     x 4.6669222D-03, 1.0469053D-06, 2.4923462D-06 /
      data fpp( 7,16,12,1),fpp( 7,16,12,2),fpp( 7,16,12,3)/
     x 2.9592871D-02,-3.8987491D-05,-3.0840810D-05 /
      data fpp( 7,16,13,1),fpp( 7,16,13,2),fpp( 7,16,13,3)/
     x 1.9829063D-02,-2.3550397D-05,-8.4424405D-06 /
      data fpp( 7,16,14,1),fpp( 7,16,14,2),fpp( 7,16,14,3)/
     x 6.3821127D-04, 2.4206530D-05, 1.1784572D-05 /
      data fpp( 7,16,15,1),fpp( 7,16,15,2),fpp( 7,16,15,3)/
     x-5.8583447D-03, 4.2983530D-05, 1.2770820D-05 /
      data fpp( 7,16,16,1),fpp( 7,16,16,2),fpp( 7,16,16,3)/
     x 6.3821127D-04, 2.4206530D-05, 8.3188132D-06 /
      data fpp( 7,16,17,1),fpp( 7,16,17,2),fpp( 7,16,17,3)/
     x 1.9829063D-02,-2.3550397D-05, 5.4205934D-06 /
      data fpp( 7,17, 1,1),fpp( 7,17, 1,2),fpp( 7,17, 1,3)/
     x 2.5528215D-02,-3.0131355D-05, 8.9240509D-07 /
      data fpp( 7,17, 2,1),fpp( 7,17, 2,2),fpp( 7,17, 2,3)/
     x 1.2932728D-02,-2.0696335D-05, 3.9198565D-06 /
      data fpp( 7,17, 3,1),fpp( 7,17, 3,2),fpp( 7,17, 3,3)/
     x 7.4694117D-03,-6.1076427D-06, 9.5308356D-06 /
      data fpp( 7,17, 4,1),fpp( 7,17, 4,2),fpp( 7,17, 4,3)/
     x 1.2932728D-02,-2.0696335D-05, 6.0994677D-06 /
      data fpp( 7,17, 5,1),fpp( 7,17, 5,2),fpp( 7,17, 5,3)/
     x 2.5528215D-02,-3.0131355D-05,-7.8260397D-06 /
      data fpp( 7,17, 6,1),fpp( 7,17, 6,2),fpp( 7,17, 6,3)/
     x 2.7372695D-02,-1.0510906D-05,-1.6377309D-05 /
      data fpp( 7,17, 7,1),fpp( 7,17, 7,2),fpp( 7,17, 7,3)/
     x 9.2780192D-03, 8.9852549D-07,-4.3939118D-07 /
      data fpp( 7,17, 8,1),fpp( 7,17, 8,2),fpp( 7,17, 8,3)/
     x-6.6640626D-03, 2.9539527D-05, 8.7635403D-06 /
      data fpp( 7,17, 9,1),fpp( 7,17, 9,2),fpp( 7,17, 9,3)/
     x-1.1879448D-02, 4.5379185D-05, 1.0391896D-05 /
      data fpp( 7,17,10,1),fpp( 7,17,10,2),fpp( 7,17,10,3)/
     x-6.6640626D-03, 2.9539527D-05, 8.7635403D-06 /
      data fpp( 7,17,11,1),fpp( 7,17,11,2),fpp( 7,17,11,3)/
     x 9.2780192D-03, 8.9852549D-07,-4.3939118D-07 /
      data fpp( 7,17,12,1),fpp( 7,17,12,2),fpp( 7,17,12,3)/
     x 2.7372695D-02,-1.0510906D-05,-1.6377309D-05 /
      data fpp( 7,17,13,1),fpp( 7,17,13,2),fpp( 7,17,13,3)/
     x 2.5528215D-02,-3.0131355D-05,-7.8260397D-06 /
      data fpp( 7,17,14,1),fpp( 7,17,14,2),fpp( 7,17,14,3)/
     x 1.2932728D-02,-2.0696335D-05, 6.0994677D-06 /
      data fpp( 7,17,15,1),fpp( 7,17,15,2),fpp( 7,17,15,3)/
     x 7.4694117D-03,-6.1076427D-06, 9.5308356D-06 /
      data fpp( 7,17,16,1),fpp( 7,17,16,2),fpp( 7,17,16,3)/
     x 1.2932728D-02,-2.0696335D-05, 3.9198565D-06 /
      data fpp( 7,17,17,1),fpp( 7,17,17,2),fpp( 7,17,17,3)/
     x 2.5528215D-02,-3.0131355D-05, 8.9240509D-07 /
      data fpp( 7,18, 1,1),fpp( 7,18, 1,2),fpp( 7,18, 1,3)/
     x 2.6721567D-02,-1.3826184D-05,-9.0556825D-07 /
      data fpp( 7,18, 2,1),fpp( 7,18, 2,2),fpp( 7,18, 2,3)/
     x 2.4076624D-02,-6.2453190D-05, 3.0458095D-07 /
      data fpp( 7,18, 3,1),fpp( 7,18, 3,2),fpp( 7,18, 3,3)/
     x 2.2396650D-02,-8.1636959D-05, 2.7679111D-06 /
      data fpp( 7,18, 4,1),fpp( 7,18, 4,2),fpp( 7,18, 4,3)/
     x 2.4076624D-02,-6.2453190D-05, 8.4510795D-07 /
      data fpp( 7,18, 5,1),fpp( 7,18, 5,2),fpp( 7,18, 5,3)/
     x 2.6721567D-02,-1.3826184D-05,-3.0676763D-06 /
      data fpp( 7,18, 6,1),fpp( 7,18, 6,2),fpp( 7,18, 6,3)/
     x 2.3594545D-02, 1.7611116D-05,-4.3177363D-06 /
      data fpp( 7,18, 7,1),fpp( 7,18, 7,2),fpp( 7,18, 7,3)/
     x 1.5303253D-02, 2.3249927D-06,-5.7471203D-07 /
      data fpp( 7,18, 8,1),fpp( 7,18, 8,2),fpp( 7,18, 8,3)/
     x 7.1427423D-03,-1.9238294D-05, 3.3919177D-06 /
      data fpp( 7,18, 9,1),fpp( 7,18, 9,2),fpp( 7,18, 9,3)/
     x 4.0079230D-03,-2.5959767D-05, 4.7683745D-06 /
      data fpp( 7,18,10,1),fpp( 7,18,10,2),fpp( 7,18,10,3)/
     x 7.1427423D-03,-1.9238294D-05, 3.3919177D-06 /
      data fpp( 7,18,11,1),fpp( 7,18,11,2),fpp( 7,18,11,3)/
     x 1.5303253D-02, 2.3249927D-06,-5.7471203D-07 /
      data fpp( 7,18,12,1),fpp( 7,18,12,2),fpp( 7,18,12,3)/
     x 2.3594545D-02, 1.7611116D-05,-4.3177363D-06 /
      data fpp( 7,18,13,1),fpp( 7,18,13,2),fpp( 7,18,13,3)/
     x 2.6721567D-02,-1.3826184D-05,-3.0676763D-06 /
      data fpp( 7,18,14,1),fpp( 7,18,14,2),fpp( 7,18,14,3)/
     x 2.4076624D-02,-6.2453190D-05, 8.4510795D-07 /
      data fpp( 7,18,15,1),fpp( 7,18,15,2),fpp( 7,18,15,3)/
     x 2.2396650D-02,-8.1636959D-05, 2.7679111D-06 /
      data fpp( 7,18,16,1),fpp( 7,18,16,2),fpp( 7,18,16,3)/
     x 2.4076624D-02,-6.2453190D-05, 3.0458095D-07 /
      data fpp( 7,18,17,1),fpp( 7,18,17,2),fpp( 7,18,17,3)/
     x 2.6721567D-02,-1.3826184D-05,-9.0556825D-07 /
      data fpp( 7,19, 1,1),fpp( 7,19, 1,2),fpp( 7,19, 1,3)/
     x 2.1700143D-02,-4.0599078D-06,-1.3547329D-20 /
      data fpp( 7,19, 2,1),fpp( 7,19, 2,2),fpp( 7,19, 2,3)/
     x 2.1700143D-02,-1.0510891D-04, 1.7401162D-20 /
      data fpp( 7,19, 3,1),fpp( 7,19, 3,2),fpp( 7,19, 3,3)/
     x 2.1700143D-02,-1.4961252D-04, 6.2961631D-21 /
      data fpp( 7,19, 4,1),fpp( 7,19, 4,2),fpp( 7,19, 4,3)/
     x 2.1700143D-02,-1.0510891D-04,-1.9312259D-21 /
      data fpp( 7,19, 5,1),fpp( 7,19, 5,2),fpp( 7,19, 5,3)/
     x 2.1700143D-02,-4.0599078D-06, 2.3275112D-21 /
      data fpp( 7,19, 6,1),fpp( 7,19, 6,2),fpp( 7,19, 6,3)/
     x 2.1700143D-02, 4.5834442D-05, 5.9847949D-21 /
      data fpp( 7,19, 7,1),fpp( 7,19, 7,2),fpp( 7,19, 7,3)/
     x 2.1700143D-02, 3.3015036D-06, 4.3475064D-21 /
      data fpp( 7,19, 8,1),fpp( 7,19, 8,2),fpp( 7,19, 8,3)/
     x 2.1700143D-02,-5.7652353D-05,-9.4027088D-21 /
      data fpp( 7,19, 9,1),fpp( 7,19, 9,2),fpp( 7,19, 9,3)/
     x 2.1700143D-02,-7.9816116D-05,-2.0857870D-21 /
      data fpp( 7,19,10,1),fpp( 7,19,10,2),fpp( 7,19,10,3)/
     x 2.1700143D-02,-5.7652353D-05, 7.8408352D-21 /
      data fpp( 7,19,11,1),fpp( 7,19,11,2),fpp( 7,19,11,3)/
     x 2.1700143D-02, 3.3015036D-06,-4.3722517D-21 /
      data fpp( 7,19,12,1),fpp( 7,19,12,2),fpp( 7,19,12,3)/
     x 2.1700143D-02, 4.5834442D-05, 6.7610179D-22 /
      data fpp( 7,19,13,1),fpp( 7,19,13,2),fpp( 7,19,13,3)/
     x 2.1700143D-02,-4.0599078D-06,-3.1273225D-21 /
      data fpp( 7,19,14,1),fpp( 7,19,14,2),fpp( 7,19,14,3)/
     x 2.1700143D-02,-1.0510891D-04, 9.0712258D-22 /
      data fpp( 7,19,15,1),fpp( 7,19,15,2),fpp( 7,19,15,3)/
     x 2.1700143D-02,-1.4961252D-04,-3.5756311D-21 /
      data fpp( 7,19,16,1),fpp( 7,19,16,2),fpp( 7,19,16,3)/
     x 2.1700143D-02,-1.0510891D-04, 1.3445569D-21 /
      data fpp( 7,19,17,1),fpp( 7,19,17,2),fpp( 7,19,17,3)/
     x 2.1700143D-02,-4.0599078D-06, 2.0676941D-21 /
      data fpp( 8, 1, 1,1),fpp( 8, 1, 1,2),fpp( 8, 1, 1,3)/
     x 9.9290465D-03, 1.4663111D-06,-3.6237304D-22 /
      data fpp( 8, 1, 2,1),fpp( 8, 1, 2,2),fpp( 8, 1, 2,3)/
     x 9.9290465D-03,-8.6656695D-06, 4.2237553D-21 /
      data fpp( 8, 1, 3,1),fpp( 8, 1, 3,2),fpp( 8, 1, 3,3)/
     x 9.9290465D-03,-1.2822468D-05, 2.4833122D-21 /
      data fpp( 8, 1, 4,1),fpp( 8, 1, 4,2),fpp( 8, 1, 4,3)/
     x 9.9290465D-03,-8.6656695D-06,-8.8348072D-22 /
      data fpp( 8, 1, 5,1),fpp( 8, 1, 5,2),fpp( 8, 1, 5,3)/
     x 9.9290465D-03, 1.4663111D-06, 6.5732441D-22 /
      data fpp( 8, 1, 6,1),fpp( 8, 1, 6,2),fpp( 8, 1, 6,3)/
     x 9.9290465D-03, 7.4199126D-06, 1.3080061D-21 /
      data fpp( 8, 1, 7,1),fpp( 8, 1, 7,2),fpp( 8, 1, 7,3)/
     x 9.9290465D-03, 4.6466994D-06, 1.2763798D-21 /
      data fpp( 8, 1, 8,1),fpp( 8, 1, 8,2),fpp( 8, 1, 8,3)/
     x 9.9290465D-03,-4.0513170D-06,-2.3676815D-21 /
      data fpp( 8, 1, 9,1),fpp( 8, 1, 9,2),fpp( 8, 1, 9,3)/
     x 9.9290465D-03,-8.6180335D-06,-1.6909855D-21 /
      data fpp( 8, 1,10,1),fpp( 8, 1,10,2),fpp( 8, 1,10,3)/
     x 9.9290465D-03,-4.0513170D-06, 2.5509533D-21 /
      data fpp( 8, 1,11,1),fpp( 8, 1,11,2),fpp( 8, 1,11,3)/
     x 9.9290465D-03, 4.6466994D-06,-1.9504727D-21 /
      data fpp( 8, 1,12,1),fpp( 8, 1,12,2),fpp( 8, 1,12,3)/
     x 9.9290465D-03, 7.4199126D-06, 2.2381863D-21 /
      data fpp( 8, 1,13,1),fpp( 8, 1,13,2),fpp( 8, 1,13,3)/
     x 9.9290465D-03, 1.4663111D-06, 8.9417485D-22 /
      data fpp( 8, 1,14,1),fpp( 8, 1,14,2),fpp( 8, 1,14,3)/
     x 9.9290465D-03,-8.6656695D-06,-1.6507541D-21 /
      data fpp( 8, 1,15,1),fpp( 8, 1,15,2),fpp( 8, 1,15,3)/
     x 9.9290465D-03,-1.2822468D-05,-8.7448280D-22 /
      data fpp( 8, 1,16,1),fpp( 8, 1,16,2),fpp( 8, 1,16,3)/
     x 9.9290465D-03,-8.6656695D-06, 6.3422468D-22 /
      data fpp( 8, 1,17,1),fpp( 8, 1,17,2),fpp( 8, 1,17,3)/
     x 9.9290465D-03, 1.4663111D-06, 1.4239278D-22 /
      data fpp( 8, 2, 1,1),fpp( 8, 2, 1,2),fpp( 8, 2, 1,3)/
     x 9.6253796D-03,-3.7662210D-07, 7.4322213D-08 /
      data fpp( 8, 2, 2,1),fpp( 8, 2, 2,2),fpp( 8, 2, 2,3)/
     x 8.8337103D-03,-4.7376610D-06, 2.3091113D-07 /
      data fpp( 8, 2, 3,1),fpp( 8, 2, 3,2),fpp( 8, 2, 3,3)/
     x 8.4495501D-03,-7.5850639D-06, 5.5936660D-07 /
      data fpp( 8, 2, 4,1),fpp( 8, 2, 4,2),fpp( 8, 2, 4,3)/
     x 8.8337103D-03,-4.7376610D-06, 2.8628914D-07 /
      data fpp( 8, 2, 5,1),fpp( 8, 2, 5,2),fpp( 8, 2, 5,3)/
     x 9.6253796D-03,-3.7662210D-07,-1.4718981D-07 /
      data fpp( 8, 2, 6,1),fpp( 8, 2, 6,2),fpp( 8, 2, 6,3)/
     x 1.0179941D-02, 2.0071748D-06,-4.0286321D-07 /
      data fpp( 8, 2, 7,1),fpp( 8, 2, 7,2),fpp( 8, 2, 7,3)/
     x 1.0198948D-02, 8.9460127D-07,-2.8602401D-07 /
      data fpp( 8, 2, 8,1),fpp( 8, 2, 8,2),fpp( 8, 2, 8,3)/
     x 9.8934252D-03,-2.8963660D-06, 1.0829257D-07 /
      data fpp( 8, 2, 9,1),fpp( 8, 2, 9,2),fpp( 8, 2, 9,3)/
     x 9.7177499D-03,-5.1229330D-06, 3.3285371D-07 /
      data fpp( 8, 2,10,1),fpp( 8, 2,10,2),fpp( 8, 2,10,3)/
     x 9.8934252D-03,-2.8963660D-06, 1.0829257D-07 /
      data fpp( 8, 2,11,1),fpp( 8, 2,11,2),fpp( 8, 2,11,3)/
     x 1.0198948D-02, 8.9460127D-07,-2.8602401D-07 /
      data fpp( 8, 2,12,1),fpp( 8, 2,12,2),fpp( 8, 2,12,3)/
     x 1.0179941D-02, 2.0071748D-06,-4.0286321D-07 /
      data fpp( 8, 2,13,1),fpp( 8, 2,13,2),fpp( 8, 2,13,3)/
     x 9.6253796D-03,-3.7662210D-07,-1.4718981D-07 /
      data fpp( 8, 2,14,1),fpp( 8, 2,14,2),fpp( 8, 2,14,3)/
     x 8.8337103D-03,-4.7376610D-06, 2.8628914D-07 /
      data fpp( 8, 2,15,1),fpp( 8, 2,15,2),fpp( 8, 2,15,3)/
     x 8.4495501D-03,-7.5850639D-06, 5.5936660D-07 /
      data fpp( 8, 2,16,1),fpp( 8, 2,16,2),fpp( 8, 2,16,3)/
     x 8.8337103D-03,-4.7376610D-06, 2.3091113D-07 /
      data fpp( 8, 2,17,1),fpp( 8, 2,17,2),fpp( 8, 2,17,3)/
     x 9.6253796D-03,-3.7662210D-07, 7.4322213D-08 /
      data fpp( 8, 3, 1,1),fpp( 8, 3, 1,2),fpp( 8, 3, 1,3)/
     x 9.0940740D-03,-2.9718226D-06,-1.6862619D-07 /
      data fpp( 8, 3, 2,1),fpp( 8, 3, 2,2),fpp( 8, 3, 2,3)/
     x 6.6648931D-03,-2.2336865D-06, 5.3236350D-07 /
      data fpp( 8, 3, 3,1),fpp( 8, 3, 3,2),fpp( 8, 3, 3,3)/
     x 5.2487406D-03,-4.9812764D-06, 2.1031722D-06 /
      data fpp( 8, 3, 4,1),fpp( 8, 3, 4,2),fpp( 8, 3, 4,3)/
     x 6.6648931D-03,-2.2336865D-06, 6.2961436D-07 /
      data fpp( 8, 3, 5,1),fpp( 8, 3, 5,2),fpp( 8, 3, 5,3)/
     x 9.0940740D-03,-2.9718226D-06,-5.5762963D-07 /
      data fpp( 8, 3, 6,1),fpp( 8, 3, 6,2),fpp( 8, 3, 6,3)/
     x 1.0496704D-02,-4.1746116D-06,-1.2044292D-06 /
      data fpp( 8, 3, 7,1),fpp( 8, 3, 7,2),fpp( 8, 3, 7,3)/
     x 1.0238862D-02,-3.0051044D-06,-9.7398702D-07 /
      data fpp( 8, 3, 8,1),fpp( 8, 3, 8,2),fpp( 8, 3, 8,3)/
     x 9.1237251D-03,-1.4932189D-06, 4.1237724D-07 /
      data fpp( 8, 3, 9,1),fpp( 8, 3, 9,2),fpp( 8, 3, 9,3)/
     x 8.5174320D-03,-1.2202346D-06, 1.3011447D-06 /
      data fpp( 8, 3,10,1),fpp( 8, 3,10,2),fpp( 8, 3,10,3)/
     x 9.1237251D-03,-1.4932189D-06, 4.1237724D-07 /
      data fpp( 8, 3,11,1),fpp( 8, 3,11,2),fpp( 8, 3,11,3)/
     x 1.0238862D-02,-3.0051044D-06,-9.7398702D-07 /
      data fpp( 8, 3,12,1),fpp( 8, 3,12,2),fpp( 8, 3,12,3)/
     x 1.0496704D-02,-4.1746116D-06,-1.2044292D-06 /
      data fpp( 8, 3,13,1),fpp( 8, 3,13,2),fpp( 8, 3,13,3)/
     x 9.0940740D-03,-2.9718226D-06,-5.5762963D-07 /
      data fpp( 8, 3,14,1),fpp( 8, 3,14,2),fpp( 8, 3,14,3)/
     x 6.6648931D-03,-2.2336865D-06, 6.2961436D-07 /
      data fpp( 8, 3,15,1),fpp( 8, 3,15,2),fpp( 8, 3,15,3)/
     x 5.2487406D-03,-4.9812764D-06, 2.1031722D-06 /
      data fpp( 8, 3,16,1),fpp( 8, 3,16,2),fpp( 8, 3,16,3)/
     x 6.6648931D-03,-2.2336865D-06, 5.3236350D-07 /
      data fpp( 8, 3,17,1),fpp( 8, 3,17,2),fpp( 8, 3,17,3)/
     x 9.0940740D-03,-2.9718226D-06,-1.6862619D-07 /
      data fpp( 8, 4, 1,1),fpp( 8, 4, 1,2),fpp( 8, 4, 1,3)/
     x 8.0576562D-03,-2.9340873D-06,-1.4905635D-06 /
      data fpp( 8, 4, 2,1),fpp( 8, 4, 2,2),fpp( 8, 4, 2,3)/
     x 4.1628080D-03, 5.2544069D-06, 3.2201598D-07 /
      data fpp( 8, 4, 3,1),fpp( 8, 4, 3,2),fpp( 8, 4, 3,3)/
     x 1.1503262D-03, 6.8401694D-06, 4.6584996D-06 /
      data fpp( 8, 4, 4,1),fpp( 8, 4, 4,2),fpp( 8, 4, 4,3)/
     x 4.1628080D-03, 5.2544069D-06, 1.6131888D-07 /
      data fpp( 8, 4, 5,1),fpp( 8, 4, 5,2),fpp( 8, 4, 5,3)/
     x 8.0576562D-03,-2.9340873D-06,-8.4777513D-07 /
      data fpp( 8, 4, 6,1),fpp( 8, 4, 6,2),fpp( 8, 4, 6,3)/
     x 1.0002129D-02,-7.6647282D-06,-1.7175517D-06 /
      data fpp( 8, 4, 7,1),fpp( 8, 4, 7,2),fpp( 8, 4, 7,3)/
     x 9.4542080D-03,-6.3881835D-06,-1.6026848D-06 /
      data fpp( 8, 4, 8,1),fpp( 8, 4, 8,2),fpp( 8, 4, 8,3)/
     x 7.9642570D-03,-9.5875837D-07, 5.0695756D-07 /
      data fpp( 8, 4, 9,1),fpp( 8, 4, 9,2),fpp( 8, 4, 9,3)/
     x 7.0534222D-03, 1.2558715D-06, 2.3141879D-06 /
      data fpp( 8, 4,10,1),fpp( 8, 4,10,2),fpp( 8, 4,10,3)/
     x 7.9642570D-03,-9.5875837D-07, 5.0695756D-07 /
      data fpp( 8, 4,11,1),fpp( 8, 4,11,2),fpp( 8, 4,11,3)/
     x 9.4542080D-03,-6.3881835D-06,-1.6026848D-06 /
      data fpp( 8, 4,12,1),fpp( 8, 4,12,2),fpp( 8, 4,12,3)/
     x 1.0002129D-02,-7.6647282D-06,-1.7175517D-06 /
      data fpp( 8, 4,13,1),fpp( 8, 4,13,2),fpp( 8, 4,13,3)/
     x 8.0576562D-03,-2.9340873D-06,-8.4777513D-07 /
      data fpp( 8, 4,14,1),fpp( 8, 4,14,2),fpp( 8, 4,14,3)/
     x 4.1628080D-03, 5.2544069D-06, 1.6131888D-07 /
      data fpp( 8, 4,15,1),fpp( 8, 4,15,2),fpp( 8, 4,15,3)/
     x 1.1503262D-03, 6.8401694D-06, 4.6584996D-06 /
      data fpp( 8, 4,16,1),fpp( 8, 4,16,2),fpp( 8, 4,16,3)/
     x 4.1628080D-03, 5.2544069D-06, 3.2201598D-07 /
      data fpp( 8, 4,17,1),fpp( 8, 4,17,2),fpp( 8, 4,17,3)/
     x 8.0576562D-03,-2.9340873D-06,-1.4905635D-06 /
      data fpp( 8, 5, 1,1),fpp( 8, 5, 1,2),fpp( 8, 5, 1,3)/
     x 6.5269677D-03,-1.0298280D-06,-3.4549146D-06 /
      data fpp( 8, 5, 2,1),fpp( 8, 5, 2,2),fpp( 8, 5, 2,3)/
     x 2.5453115D-03, 8.6780589D-06,-4.9650415D-07 /
      data fpp( 8, 5, 3,1),fpp( 8, 5, 3,2),fpp( 8, 5, 3,3)/
     x-1.8075206D-03, 1.7724599D-05, 6.8935979D-06 /
      data fpp( 8, 5, 4,1),fpp( 8, 5, 4,2),fpp( 8, 5, 4,3)/
     x 2.5453115D-03, 8.6780589D-06,-1.2272206D-06 /
      data fpp( 8, 5, 5,1),fpp( 8, 5, 5,2),fpp( 8, 5, 5,3)/
     x 6.5269677D-03,-1.0298280D-06,-5.3204861D-07 /
      data fpp( 8, 5, 6,1),fpp( 8, 5, 6,2),fpp( 8, 5, 6,3)/
     x 8.4201904D-03,-4.9464756D-06,-1.6052516D-06 /
      data fpp( 8, 5, 7,1),fpp( 8, 5, 7,2),fpp( 8, 5, 7,3)/
     x 7.8379985D-03,-3.1401614D-06,-1.7696118D-06 /
      data fpp( 8, 5, 8,1),fpp( 8, 5, 8,2),fpp( 8, 5, 8,3)/
     x 6.7509433D-03,-6.5747610D-08, 1.5369860D-07 /
      data fpp( 8, 5, 9,1),fpp( 8, 5, 9,2),fpp( 8, 5, 9,3)/
     x 5.6959676D-03, 1.7047487D-06, 2.9454840D-06 /
      data fpp( 8, 5,10,1),fpp( 8, 5,10,2),fpp( 8, 5,10,3)/
     x 6.7509433D-03,-6.5747610D-08, 1.5369860D-07 /
      data fpp( 8, 5,11,1),fpp( 8, 5,11,2),fpp( 8, 5,11,3)/
     x 7.8379985D-03,-3.1401614D-06,-1.7696118D-06 /
      data fpp( 8, 5,12,1),fpp( 8, 5,12,2),fpp( 8, 5,12,3)/
     x 8.4201904D-03,-4.9464756D-06,-1.6052516D-06 /
      data fpp( 8, 5,13,1),fpp( 8, 5,13,2),fpp( 8, 5,13,3)/
     x 6.5269677D-03,-1.0298280D-06,-5.3204861D-07 /
      data fpp( 8, 5,14,1),fpp( 8, 5,14,2),fpp( 8, 5,14,3)/
     x 2.5453115D-03, 8.6780589D-06,-1.2272206D-06 /
      data fpp( 8, 5,15,1),fpp( 8, 5,15,2),fpp( 8, 5,15,3)/
     x-1.8075206D-03, 1.7724599D-05, 6.8935979D-06 /
      data fpp( 8, 5,16,1),fpp( 8, 5,16,2),fpp( 8, 5,16,3)/
     x 2.5453115D-03, 8.6780589D-06,-4.9650415D-07 /
      data fpp( 8, 5,17,1),fpp( 8, 5,17,2),fpp( 8, 5,17,3)/
     x 6.5269677D-03,-1.0298280D-06,-3.4549146D-06 /
      data fpp( 8, 6, 1,1),fpp( 8, 6, 1,2),fpp( 8, 6, 1,3)/
     x 4.8088665D-03, 9.0339951D-07,-4.0377934D-06 /
      data fpp( 8, 6, 2,1),fpp( 8, 6, 2,2),fpp( 8, 6, 2,3)/
     x 2.3881776D-03, 4.0673573D-06,-1.1126354D-06 /
      data fpp( 8, 6, 3,1),fpp( 8, 6, 3,2),fpp( 8, 6, 3,3)/
     x-1.6209036D-03, 1.1967435D-05, 6.4363351D-06 /
      data fpp( 8, 6, 4,1),fpp( 8, 6, 4,2),fpp( 8, 6, 4,3)/
     x 2.3881776D-03, 4.0673573D-06,-2.1980385D-06 /
      data fpp( 8, 6, 5,1),fpp( 8, 6, 5,2),fpp( 8, 6, 5,3)/
     x 4.8088665D-03, 9.0339951D-07, 3.0381878D-07 /
      data fpp( 8, 6, 6,1),fpp( 8, 6, 6,2),fpp( 8, 6, 6,3)/
     x 6.3036543D-03,-2.8136948D-07,-8.1323665D-07 /
      data fpp( 8, 6, 7,1),fpp( 8, 6, 7,2),fpp( 8, 6, 7,3)/
     x 6.2467328D-03,-2.3917076D-07,-1.8282055D-06 /
      data fpp( 8, 6, 8,1),fpp( 8, 6, 8,2),fpp( 8, 6, 8,3)/
     x 5.6900109D-03,-3.2625119D-07,-3.0194128D-07 /
      data fpp( 8, 6, 9,1),fpp( 8, 6, 9,2),fpp( 8, 6, 9,3)/
     x 4.5104612D-03, 6.3713386D-07, 3.0579706D-06 /
      data fpp( 8, 6,10,1),fpp( 8, 6,10,2),fpp( 8, 6,10,3)/
     x 5.6900109D-03,-3.2625119D-07,-3.0194128D-07 /
      data fpp( 8, 6,11,1),fpp( 8, 6,11,2),fpp( 8, 6,11,3)/
     x 6.2467328D-03,-2.3917076D-07,-1.8282055D-06 /
      data fpp( 8, 6,12,1),fpp( 8, 6,12,2),fpp( 8, 6,12,3)/
     x 6.3036543D-03,-2.8136948D-07,-8.1323665D-07 /
      data fpp( 8, 6,13,1),fpp( 8, 6,13,2),fpp( 8, 6,13,3)/
     x 4.8088665D-03, 9.0339951D-07, 3.0381878D-07 /
      data fpp( 8, 6,14,1),fpp( 8, 6,14,2),fpp( 8, 6,14,3)/
     x 2.3881776D-03, 4.0673573D-06,-2.1980385D-06 /
      data fpp( 8, 6,15,1),fpp( 8, 6,15,2),fpp( 8, 6,15,3)/
     x-1.6209036D-03, 1.1967435D-05, 6.4363351D-06 /
      data fpp( 8, 6,16,1),fpp( 8, 6,16,2),fpp( 8, 6,16,3)/
     x 2.3881776D-03, 4.0673573D-06,-1.1126354D-06 /
      data fpp( 8, 6,17,1),fpp( 8, 6,17,2),fpp( 8, 6,17,3)/
     x 4.8088665D-03, 9.0339951D-07,-4.0377934D-06 /
      data fpp( 8, 7, 1,1),fpp( 8, 7, 1,2),fpp( 8, 7, 1,3)/
     x 3.2344194D-03, 1.6642300D-06,-2.5668170D-06 /
      data fpp( 8, 7, 2,1),fpp( 8, 7, 2,2),fpp( 8, 7, 2,3)/
     x 2.9015536D-03,-2.6634883D-06,-9.8747702D-07 /
      data fpp( 8, 7, 3,1),fpp( 8, 7, 3,2),fpp( 8, 7, 3,3)/
     x 1.0737280D-03,-4.1963387D-06, 3.3020585D-06 /
      data fpp( 8, 7, 4,1),fpp( 8, 7, 4,2),fpp( 8, 7, 4,3)/
     x 2.9015536D-03,-2.6634883D-06,-1.8940902D-06 /
      data fpp( 8, 7, 5,1),fpp( 8, 7, 5,2),fpp( 8, 7, 5,3)/
     x 3.2344194D-03, 1.6642300D-06, 1.0596356D-06 /
      data fpp( 8, 7, 6,1),fpp( 8, 7, 6,2),fpp( 8, 7, 6,3)/
     x 4.2700935D-03, 2.8739535D-06, 2.0088118D-07 /
      data fpp( 8, 7, 7,1),fpp( 8, 7, 7,2),fpp( 8, 7, 7,3)/
     x 5.1342863D-03, 1.8484447D-07,-1.9471603D-06 /
      data fpp( 8, 7, 8,1),fpp( 8, 7, 8,2),fpp( 8, 7, 8,3)/
     x 4.6010774D-03,-1.2032476D-06,-5.1023991D-07 /
      data fpp( 8, 7, 9,1),fpp( 8, 7, 9,2),fpp( 8, 7, 9,3)/
     x 3.3720406D-03,-1.1032841D-06, 2.7287866D-06 /
      data fpp( 8, 7,10,1),fpp( 8, 7,10,2),fpp( 8, 7,10,3)/
     x 4.6010774D-03,-1.2032476D-06,-5.1023991D-07 /
      data fpp( 8, 7,11,1),fpp( 8, 7,11,2),fpp( 8, 7,11,3)/
     x 5.1342863D-03, 1.8484447D-07,-1.9471603D-06 /
      data fpp( 8, 7,12,1),fpp( 8, 7,12,2),fpp( 8, 7,12,3)/
     x 4.2700935D-03, 2.8739535D-06, 2.0088118D-07 /
      data fpp( 8, 7,13,1),fpp( 8, 7,13,2),fpp( 8, 7,13,3)/
     x 3.2344194D-03, 1.6642300D-06, 1.0596356D-06 /
      data fpp( 8, 7,14,1),fpp( 8, 7,14,2),fpp( 8, 7,14,3)/
     x 2.9015536D-03,-2.6634883D-06,-1.8940902D-06 /
      data fpp( 8, 7,15,1),fpp( 8, 7,15,2),fpp( 8, 7,15,3)/
     x 1.0737280D-03,-4.1963387D-06, 3.3020585D-06 /
      data fpp( 8, 7,16,1),fpp( 8, 7,16,2),fpp( 8, 7,16,3)/
     x 2.9015536D-03,-2.6634883D-06,-9.8747702D-07 /
      data fpp( 8, 7,17,1),fpp( 8, 7,17,2),fpp( 8, 7,17,3)/
     x 3.2344194D-03, 1.6642300D-06,-2.5668170D-06 /
      data fpp( 8, 8, 1,1),fpp( 8, 8, 1,2),fpp( 8, 8, 1,3)/
     x 1.9812249D-03, 1.4936804D-06,-6.5043997D-07 /
      data fpp( 8, 8, 2,1),fpp( 8, 8, 2,2),fpp( 8, 8, 2,3)/
     x 2.9386554D-03,-5.3594042D-06,-5.0667561D-07 /
      data fpp( 8, 8, 3,1),fpp( 8, 8, 3,2),fpp( 8, 8, 3,3)/
     x 3.1166015D-03,-1.1316080D-05, 1.6780909D-07 /
      data fpp( 8, 8, 4,1),fpp( 8, 8, 4,2),fpp( 8, 8, 4,3)/
     x 2.9386554D-03,-5.3594042D-06,-1.0152274D-06 /
      data fpp( 8, 8, 5,1),fpp( 8, 8, 5,2),fpp( 8, 8, 5,3)/
     x 1.9812249D-03, 1.4936804D-06, 1.3837672D-06 /
      data fpp( 8, 8, 6,1),fpp( 8, 8, 6,2),fpp( 8, 8, 6,3)/
     x 2.6794574D-03, 4.0315554D-06, 7.2149195D-07 /
      data fpp( 8, 8, 7,1),fpp( 8, 8, 7,2),fpp( 8, 8, 7,3)/
     x 3.9270287D-03, 1.1317929D-06,-1.8610683D-06 /
      data fpp( 8, 8, 8,1),fpp( 8, 8, 8,2),fpp( 8, 8, 8,3)/
     x 3.2289111D-03,-1.8327582D-06,-4.8855190D-07 /
      data fpp( 8, 8, 9,1),fpp( 8, 8, 9,2),fpp( 8, 8, 9,3)/
     x 2.0649616D-03,-2.8719974D-06, 2.2666093D-06 /
      data fpp( 8, 8,10,1),fpp( 8, 8,10,2),fpp( 8, 8,10,3)/
     x 3.2289111D-03,-1.8327582D-06,-4.8855190D-07 /
      data fpp( 8, 8,11,1),fpp( 8, 8,11,2),fpp( 8, 8,11,3)/
     x 3.9270287D-03, 1.1317929D-06,-1.8610683D-06 /
      data fpp( 8, 8,12,1),fpp( 8, 8,12,2),fpp( 8, 8,12,3)/
     x 2.6794574D-03, 4.0315554D-06, 7.2149195D-07 /
      data fpp( 8, 8,13,1),fpp( 8, 8,13,2),fpp( 8, 8,13,3)/
     x 1.9812249D-03, 1.4936804D-06, 1.3837672D-06 /
      data fpp( 8, 8,14,1),fpp( 8, 8,14,2),fpp( 8, 8,14,3)/
     x 2.9386554D-03,-5.3594042D-06,-1.0152274D-06 /
      data fpp( 8, 8,15,1),fpp( 8, 8,15,2),fpp( 8, 8,15,3)/
     x 3.1166015D-03,-1.1316080D-05, 1.6780909D-07 /
      data fpp( 8, 8,16,1),fpp( 8, 8,16,2),fpp( 8, 8,16,3)/
     x 2.9386554D-03,-5.3594042D-06,-5.0667561D-07 /
      data fpp( 8, 8,17,1),fpp( 8, 8,17,2),fpp( 8, 8,17,3)/
     x 1.9812249D-03, 1.4936804D-06,-6.5043997D-07 /
      data fpp( 8, 9, 1,1),fpp( 8, 9, 1,2),fpp( 8, 9, 1,3)/
     x 1.0815914D-03, 1.1810482D-06, 5.2063902D-07 /
      data fpp( 8, 9, 2,1),fpp( 8, 9, 2,2),fpp( 8, 9, 2,3)/
     x 2.0527732D-03,-5.0948950D-06,-5.0278044D-08 /
      data fpp( 8, 9, 3,1),fpp( 8, 9, 3,2),fpp( 8, 9, 3,3)/
     x 2.8975870D-03,-9.9453401D-06,-1.2561935D-06 /
      data fpp( 8, 9, 4,1),fpp( 8, 9, 4,2),fpp( 8, 9, 4,3)/
     x 2.0527732D-03,-5.0948950D-06,-2.3961457D-07 /
      data fpp( 8, 9, 5,1),fpp( 8, 9, 5,2),fpp( 8, 9, 5,3)/
     x 1.0815914D-03, 1.1810482D-06, 1.2779851D-06 /
      data fpp( 8, 9, 6,1),fpp( 8, 9, 6,2),fpp( 8, 9, 6,3)/
     x 1.7311390D-03, 4.2138248D-06, 4.4034076D-07 /
      data fpp( 8, 9, 7,1),fpp( 8, 9, 7,2),fpp( 8, 9, 7,3)/
     x 2.5755963D-03, 1.3779840D-06,-1.6400148D-06 /
      data fpp( 8, 9, 8,1),fpp( 8, 9, 8,2),fpp( 8, 9, 8,3)/
     x 1.4943685D-03,-2.7217194D-06,-2.2961481D-07 /
      data fpp( 8, 9, 9,1),fpp( 8, 9, 9,2),fpp( 8, 9, 9,3)/
     x 3.5489581D-04,-4.4367263D-06, 2.0064741D-06 /
      data fpp( 8, 9,10,1),fpp( 8, 9,10,2),fpp( 8, 9,10,3)/
     x 1.4943685D-03,-2.7217194D-06,-2.2961481D-07 /
      data fpp( 8, 9,11,1),fpp( 8, 9,11,2),fpp( 8, 9,11,3)/
     x 2.5755963D-03, 1.3779840D-06,-1.6400148D-06 /
      data fpp( 8, 9,12,1),fpp( 8, 9,12,2),fpp( 8, 9,12,3)/
     x 1.7311390D-03, 4.2138248D-06, 4.4034076D-07 /
      data fpp( 8, 9,13,1),fpp( 8, 9,13,2),fpp( 8, 9,13,3)/
     x 1.0815914D-03, 1.1810482D-06, 1.2779851D-06 /
      data fpp( 8, 9,14,1),fpp( 8, 9,14,2),fpp( 8, 9,14,3)/
     x 2.0527732D-03,-5.0948950D-06,-2.3961457D-07 /
      data fpp( 8, 9,15,1),fpp( 8, 9,15,2),fpp( 8, 9,15,3)/
     x 2.8975870D-03,-9.9453401D-06,-1.2561935D-06 /
      data fpp( 8, 9,16,1),fpp( 8, 9,16,2),fpp( 8, 9,16,3)/
     x 2.0527732D-03,-5.0948950D-06,-5.0278044D-08 /
      data fpp( 8, 9,17,1),fpp( 8, 9,17,2),fpp( 8, 9,17,3)/
     x 1.0815914D-03, 1.1810482D-06, 5.2063902D-07 /
      data fpp( 8,10, 1,1),fpp( 8,10, 1,2),fpp( 8,10, 1,3)/
     x 5.3858547D-04, 1.5521268D-06, 1.0591415D-06 /
      data fpp( 8,10, 2,1),fpp( 8,10, 2,2),fpp( 8,10, 2,3)/
     x 4.0573430D-04,-4.0030158D-06, 4.2260582D-07 /
      data fpp( 8,10, 3,1),fpp( 8,10, 3,2),fpp( 8,10, 3,3)/
     x 8.7437194D-04,-6.9765593D-06,-1.0935648D-06 /
      data fpp( 8,10, 4,1),fpp( 8,10, 4,2),fpp( 8,10, 4,3)/
     x 4.0573430D-04,-4.0030158D-06, 4.6898677D-07 /
      data fpp( 8,10, 5,1),fpp( 8,10, 5,2),fpp( 8,10, 5,3)/
     x 5.3858547D-04, 1.5521268D-06, 8.7361772D-07 /
      data fpp( 8,10, 6,1),fpp( 8,10, 6,2),fpp( 8,10, 6,3)/
     x 1.5668858D-03, 4.8111455D-06,-7.5545767D-07 /
      data fpp( 8,10, 7,1),fpp( 8,10, 7,2),fpp( 8,10, 7,3)/
     x 1.3843594D-03, 1.1562711D-06,-1.4424537D-06 /
      data fpp( 8,10, 8,1),fpp( 8,10, 8,2),fpp( 8,10, 8,3)/
     x-6.2210994D-04,-3.6963640D-06, 3.3593915D-07 /
      data fpp( 8,10, 9,1),fpp( 8,10, 9,2),fpp( 8,10, 9,3)/
     x-1.9480423D-03,-5.6430974D-06, 2.1400304D-06 /
      data fpp( 8,10,10,1),fpp( 8,10,10,2),fpp( 8,10,10,3)/
     x-6.2210994D-04,-3.6963640D-06, 3.3593915D-07 /
      data fpp( 8,10,11,1),fpp( 8,10,11,2),fpp( 8,10,11,3)/
     x 1.3843594D-03, 1.1562711D-06,-1.4424537D-06 /
      data fpp( 8,10,12,1),fpp( 8,10,12,2),fpp( 8,10,12,3)/
     x 1.5668858D-03, 4.8111455D-06,-7.5545767D-07 /
      data fpp( 8,10,13,1),fpp( 8,10,13,2),fpp( 8,10,13,3)/
     x 5.3858547D-04, 1.5521268D-06, 8.7361772D-07 /
      data fpp( 8,10,14,1),fpp( 8,10,14,2),fpp( 8,10,14,3)/
     x 4.0573430D-04,-4.0030158D-06, 4.6898677D-07 /
      data fpp( 8,10,15,1),fpp( 8,10,15,2),fpp( 8,10,15,3)/
     x 8.7437194D-04,-6.9765593D-06,-1.0935648D-06 /
      data fpp( 8,10,16,1),fpp( 8,10,16,2),fpp( 8,10,16,3)/
     x 4.0573430D-04,-4.0030158D-06, 4.2260582D-07 /
      data fpp( 8,10,17,1),fpp( 8,10,17,2),fpp( 8,10,17,3)/
     x 5.3858547D-04, 1.5521268D-06, 1.0591415D-06 /
      data fpp( 8,11, 1,1),fpp( 8,11, 1,2),fpp( 8,11, 1,3)/
     x 4.2389141D-04, 3.1584447D-06, 1.5075964D-06 /
      data fpp( 8,11, 2,1),fpp( 8,11, 2,2),fpp( 8,11, 2,3)/
     x-1.6774957D-03,-2.1670419D-06, 1.1122515D-06 /
      data fpp( 8,11, 3,1),fpp( 8,11, 3,2),fpp( 8,11, 3,3)/
     x-2.0904313D-03,-3.9924226D-06,-1.3269306D-08 /
      data fpp( 8,11, 4,1),fpp( 8,11, 4,2),fpp( 8,11, 4,3)/
     x-1.6774957D-03,-2.1670419D-06, 1.4168257D-06 /
      data fpp( 8,11, 5,1),fpp( 8,11, 5,2),fpp( 8,11, 5,3)/
     x 4.2389141D-04, 3.1584447D-06, 2.8929993D-07 /
      data fpp( 8,11, 6,1),fpp( 8,11, 6,2),fpp( 8,11, 6,3)/
     x 2.3624604D-03, 6.4755933D-06,-3.0746921D-06 /
      data fpp( 8,11, 7,1),fpp( 8,11, 7,2),fpp( 8,11, 7,3)/
     x 4.8983966D-04, 1.4009316D-06,-1.2285316D-06 /
      data fpp( 8,11, 8,1),fpp( 8,11, 8,2),fpp( 8,11, 8,3)/
     x-3.1396645D-03,-3.8288246D-06, 1.2694852D-06 /
      data fpp( 8,11, 9,1),fpp( 8,11, 9,2),fpp( 8,11, 9,3)/
     x-4.9070009D-03,-5.6608840D-06, 2.7192574D-06 /
      data fpp( 8,11,10,1),fpp( 8,11,10,2),fpp( 8,11,10,3)/
     x-3.1396645D-03,-3.8288246D-06, 1.2694852D-06 /
      data fpp( 8,11,11,1),fpp( 8,11,11,2),fpp( 8,11,11,3)/
     x 4.8983966D-04, 1.4009316D-06,-1.2285316D-06 /
      data fpp( 8,11,12,1),fpp( 8,11,12,2),fpp( 8,11,12,3)/
     x 2.3624604D-03, 6.4755933D-06,-3.0746921D-06 /
      data fpp( 8,11,13,1),fpp( 8,11,13,2),fpp( 8,11,13,3)/
     x 4.2389141D-04, 3.1584447D-06, 2.8929993D-07 /
      data fpp( 8,11,14,1),fpp( 8,11,14,2),fpp( 8,11,14,3)/
     x-1.6774957D-03,-2.1670419D-06, 1.4168257D-06 /
      data fpp( 8,11,15,1),fpp( 8,11,15,2),fpp( 8,11,15,3)/
     x-2.0904313D-03,-3.9924226D-06,-1.3269306D-08 /
      data fpp( 8,11,16,1),fpp( 8,11,16,2),fpp( 8,11,16,3)/
     x-1.6774957D-03,-2.1670419D-06, 1.1122515D-06 /
      data fpp( 8,11,17,1),fpp( 8,11,17,2),fpp( 8,11,17,3)/
     x 4.2389141D-04, 3.1584447D-06, 1.5075964D-06 /
      data fpp( 8,12, 1,1),fpp( 8,12, 1,2),fpp( 8,12, 1,3)/
     x 9.1171774D-04, 5.8120946D-06, 2.2613821D-06 /
      data fpp( 8,12, 2,1),fpp( 8,12, 2,2),fpp( 8,12, 2,3)/
     x-3.8258539D-03, 1.4991832D-06, 2.1653470D-06 /
      data fpp( 8,12, 3,1),fpp( 8,12, 3,2),fpp( 8,12, 3,3)/
     x-5.2918206D-03, 3.0224982D-07, 1.4965633D-06 /
      data fpp( 8,12, 4,1),fpp( 8,12, 4,2),fpp( 8,12, 4,3)/
     x-3.8258539D-03, 1.4991832D-06, 2.8323998D-06 /
      data fpp( 8,12, 5,1),fpp( 8,12, 5,2),fpp( 8,12, 5,3)/
     x 9.1171774D-04, 5.8120946D-06,-4.0682903D-07 /
      data fpp( 8,12, 6,1),fpp( 8,12, 6,2),fpp( 8,12, 6,3)/
     x 4.3702501D-03, 8.2444812D-06,-6.7710836D-06 /
      data fpp( 8,12, 7,1),fpp( 8,12, 7,2),fpp( 8,12, 7,3)/
     x-3.8405017D-05, 2.6240023D-06,-7.8683646D-07 /
      data fpp( 8,12, 8,1),fpp( 8,12, 8,2),fpp( 8,12, 8,3)/
     x-5.9802886D-03,-1.8563376D-06, 2.5937628D-06 /
      data fpp( 8,12, 9,1),fpp( 8,12, 9,2),fpp( 8,12, 9,3)/
     x-8.3754935D-03,-3.1773666D-06, 3.6917853D-06 /
      data fpp( 8,12,10,1),fpp( 8,12,10,2),fpp( 8,12,10,3)/
     x-5.9802886D-03,-1.8563376D-06, 2.5937628D-06 /
      data fpp( 8,12,11,1),fpp( 8,12,11,2),fpp( 8,12,11,3)/
     x-3.8405017D-05, 2.6240023D-06,-7.8683646D-07 /
      data fpp( 8,12,12,1),fpp( 8,12,12,2),fpp( 8,12,12,3)/
     x 4.3702501D-03, 8.2444812D-06,-6.7710836D-06 /
      data fpp( 8,12,13,1),fpp( 8,12,13,2),fpp( 8,12,13,3)/
     x 9.1171774D-04, 5.8120946D-06,-4.0682903D-07 /
      data fpp( 8,12,14,1),fpp( 8,12,14,2),fpp( 8,12,14,3)/
     x-3.8258539D-03, 1.4991832D-06, 2.8323998D-06 /
      data fpp( 8,12,15,1),fpp( 8,12,15,2),fpp( 8,12,15,3)/
     x-5.2918206D-03, 3.0224982D-07, 1.4965633D-06 /
      data fpp( 8,12,16,1),fpp( 8,12,16,2),fpp( 8,12,16,3)/
     x-3.8258539D-03, 1.4991832D-06, 2.1653470D-06 /
      data fpp( 8,12,17,1),fpp( 8,12,17,2),fpp( 8,12,17,3)/
     x 9.1171774D-04, 5.8120946D-06, 2.2613821D-06 /
      data fpp( 8,13, 1,1),fpp( 8,13, 1,2),fpp( 8,13, 1,3)/
     x 2.2808304D-03, 7.9311770D-06, 3.3348625D-06 /
      data fpp( 8,13, 2,1),fpp( 8,13, 2,2),fpp( 8,13, 2,3)/
     x-5.4977773D-03, 7.7683089D-06, 3.5256083D-06 /
      data fpp( 8,13, 3,1),fpp( 8,13, 3,2),fpp( 8,13, 3,3)/
     x-8.0285778D-03, 7.4274233D-06, 3.2120377D-06 /
      data fpp( 8,13, 4,1),fpp( 8,13, 4,2),fpp( 8,13, 4,3)/
     x-5.4977773D-03, 7.7683089D-06, 4.6635744D-06 /
      data fpp( 8,13, 5,1),fpp( 8,13, 5,2),fpp( 8,13, 5,3)/
     x 2.2808304D-03, 7.9311770D-06,-1.2170020D-06 /
      data fpp( 8,13, 6,1),fpp( 8,13, 6,2),fpp( 8,13, 6,3)/
     x 7.7637797D-03, 6.3804819D-06,-1.1676233D-05 /
      data fpp( 8,13, 7,1),fpp( 8,13, 7,2),fpp( 8,13, 7,3)/
     x-9.6249353D-05, 4.3030591D-06, 3.3934565D-08 /
      data fpp( 8,13, 8,1),fpp( 8,13, 8,2),fpp( 8,13, 8,3)/
     x-8.7861551D-03, 3.3401752D-06, 4.2238282D-06 /
      data fpp( 8,13, 9,1),fpp( 8,13, 9,2),fpp( 8,13, 9,3)/
     x-1.1888323D-02, 3.0763503D-06, 4.9214192D-06 /
      data fpp( 8,13,10,1),fpp( 8,13,10,2),fpp( 8,13,10,3)/
     x-8.7861551D-03, 3.3401752D-06, 4.2238282D-06 /
      data fpp( 8,13,11,1),fpp( 8,13,11,2),fpp( 8,13,11,3)/
     x-9.6249353D-05, 4.3030591D-06, 3.3934565D-08 /
      data fpp( 8,13,12,1),fpp( 8,13,12,2),fpp( 8,13,12,3)/
     x 7.7637797D-03, 6.3804819D-06,-1.1676233D-05 /
      data fpp( 8,13,13,1),fpp( 8,13,13,2),fpp( 8,13,13,3)/
     x 2.2808304D-03, 7.9311770D-06,-1.2170020D-06 /
      data fpp( 8,13,14,1),fpp( 8,13,14,2),fpp( 8,13,14,3)/
     x-5.4977773D-03, 7.7683089D-06, 4.6635744D-06 /
      data fpp( 8,13,15,1),fpp( 8,13,15,2),fpp( 8,13,15,3)/
     x-8.0285778D-03, 7.4274233D-06, 3.2120377D-06 /
      data fpp( 8,13,16,1),fpp( 8,13,16,2),fpp( 8,13,16,3)/
     x-5.4977773D-03, 7.7683089D-06, 3.5256083D-06 /
      data fpp( 8,13,17,1),fpp( 8,13,17,2),fpp( 8,13,17,3)/
     x 2.2808304D-03, 7.9311770D-06, 3.3348625D-06 /
      data fpp( 8,14, 1,1),fpp( 8,14, 1,2),fpp( 8,14, 1,3)/
     x 4.7438647D-03, 5.9811976D-06, 4.2089171D-06 /
      data fpp( 8,14, 2,1),fpp( 8,14, 2,2),fpp( 8,14, 2,3)/
     x-5.9134005D-03, 1.5199581D-05, 4.7768326D-06 /
      data fpp( 8,14, 3,1),fpp( 8,14, 3,2),fpp( 8,14, 3,3)/
     x-9.4060567D-03, 1.7076057D-05, 5.0144194D-06 /
      data fpp( 8,14, 4,1),fpp( 8,14, 4,2),fpp( 8,14, 4,3)/
     x-5.9134005D-03, 1.5199581D-05, 6.4081566D-06 /
      data fpp( 8,14, 5,1),fpp( 8,14, 5,2),fpp( 8,14, 5,3)/
     x 4.7438647D-03, 5.9811976D-06,-2.3163790D-06 /
      data fpp( 8,14, 6,1),fpp( 8,14, 6,2),fpp( 8,14, 6,3)/
     x 1.2039930D-02,-3.3344089D-06,-1.6319307D-05 /
      data fpp( 8,14, 7,1),fpp( 8,14, 7,2),fpp( 8,14, 7,3)/
     x 4.7711982D-04, 4.7937614D-06, 9.0494172D-07 /
      data fpp( 8,14, 8,1),fpp( 8,14, 8,2),fpp( 8,14, 8,3)/
     x-1.0873528D-02, 1.1523637D-05, 5.8575405D-06 /
      data fpp( 8,14, 9,1),fpp( 8,14, 9,2),fpp( 8,14, 9,3)/
     x-1.4647880D-02, 1.3209965D-05, 6.1875631D-06 /
      data fpp( 8,14,10,1),fpp( 8,14,10,2),fpp( 8,14,10,3)/
     x-1.0873528D-02, 1.1523637D-05, 5.8575405D-06 /
      data fpp( 8,14,11,1),fpp( 8,14,11,2),fpp( 8,14,11,3)/
     x 4.7711982D-04, 4.7937614D-06, 9.0494172D-07 /
      data fpp( 8,14,12,1),fpp( 8,14,12,2),fpp( 8,14,12,3)/
     x 1.2039930D-02,-3.3344089D-06,-1.6319307D-05 /
      data fpp( 8,14,13,1),fpp( 8,14,13,2),fpp( 8,14,13,3)/
     x 4.7438647D-03, 5.9811976D-06,-2.3163790D-06 /
      data fpp( 8,14,14,1),fpp( 8,14,14,2),fpp( 8,14,14,3)/
     x-5.9134005D-03, 1.5199581D-05, 6.4081566D-06 /
      data fpp( 8,14,15,1),fpp( 8,14,15,2),fpp( 8,14,15,3)/
     x-9.4060567D-03, 1.7076057D-05, 5.0144194D-06 /
      data fpp( 8,14,16,1),fpp( 8,14,16,2),fpp( 8,14,16,3)/
     x-5.9134005D-03, 1.5199581D-05, 4.7768326D-06 /
      data fpp( 8,14,17,1),fpp( 8,14,17,2),fpp( 8,14,17,3)/
     x 4.7438647D-03, 5.9811976D-06, 4.2089171D-06 /
      data fpp( 8,15, 1,1),fpp( 8,15, 1,2),fpp( 8,15, 1,3)/
     x 8.2460826D-03,-2.2819673D-06, 3.9811221D-06 /
      data fpp( 8,15, 2,1),fpp( 8,15, 2,2),fpp( 8,15, 2,3)/
     x-4.1296128D-03, 1.8403366D-05, 5.1443114D-06 /
      data fpp( 8,15, 3,1),fpp( 8,15, 3,2),fpp( 8,15, 3,3)/
     x-8.3359701D-03, 2.4600349D-05, 6.5609656D-06 /
      data fpp( 8,15, 4,1),fpp( 8,15, 4,2),fpp( 8,15, 4,3)/
     x-4.1296128D-03, 1.8403366D-05, 7.0904928D-06 /
      data fpp( 8,15, 5,1),fpp( 8,15, 5,2),fpp( 8,15, 5,3)/
     x 8.2460826D-03,-2.2819673D-06,-3.8036035D-06 /
      data fpp( 8,15, 6,1),fpp( 8,15, 6,2),fpp( 8,15, 6,3)/
     x 1.5776421D-02,-1.6160846D-05,-1.7826079D-05 /
      data fpp( 8,15, 7,1),fpp( 8,15, 7,2),fpp( 8,15, 7,3)/
     x 1.7675160D-03, 2.8078954D-06, 9.6258531D-07 /
      data fpp( 8,15, 8,1),fpp( 8,15, 8,2),fpp( 8,15, 8,3)/
     x-1.1322407D-02, 1.9841277D-05, 6.8957375D-06 /
      data fpp( 8,15, 9,1),fpp( 8,15, 9,2),fpp( 8,15, 9,3)/
     x-1.5601952D-02, 2.4633788D-05, 7.1251312D-06 /
      data fpp( 8,15,10,1),fpp( 8,15,10,2),fpp( 8,15,10,3)/
     x-1.1322407D-02, 1.9841277D-05, 6.8957375D-06 /
      data fpp( 8,15,11,1),fpp( 8,15,11,2),fpp( 8,15,11,3)/
     x 1.7675160D-03, 2.8078954D-06, 9.6258531D-07 /
      data fpp( 8,15,12,1),fpp( 8,15,12,2),fpp( 8,15,12,3)/
     x 1.5776421D-02,-1.6160846D-05,-1.7826079D-05 /
      data fpp( 8,15,13,1),fpp( 8,15,13,2),fpp( 8,15,13,3)/
     x 8.2460826D-03,-2.2819673D-06,-3.8036035D-06 /
      data fpp( 8,15,14,1),fpp( 8,15,14,2),fpp( 8,15,14,3)/
     x-4.1296128D-03, 1.8403366D-05, 7.0904928D-06 /
      data fpp( 8,15,15,1),fpp( 8,15,15,2),fpp( 8,15,15,3)/
     x-8.3359701D-03, 2.4600349D-05, 6.5609656D-06 /
      data fpp( 8,15,16,1),fpp( 8,15,16,2),fpp( 8,15,16,3)/
     x-4.1296128D-03, 1.8403366D-05, 5.1443114D-06 /
      data fpp( 8,15,17,1),fpp( 8,15,17,2),fpp( 8,15,17,3)/
     x 8.2460826D-03,-2.2819673D-06, 3.9811221D-06 /
      data fpp( 8,16, 1,1),fpp( 8,16, 1,2),fpp( 8,16, 1,3)/
     x 1.1933871D-02,-1.2741328D-05, 2.2655607D-06 /
      data fpp( 8,16, 2,1),fpp( 8,16, 2,2),fpp( 8,16, 2,3)/
     x 4.7484537D-04, 1.0606953D-05, 4.0136565D-06 /
      data fpp( 8,16, 3,1),fpp( 8,16, 3,2),fpp( 8,16, 3,3)/
     x-3.8255409D-03, 2.1160546D-05, 6.9111468D-06 /
      data fpp( 8,16, 4,1),fpp( 8,16, 4,2),fpp( 8,16, 4,3)/
     x 4.7484537D-04, 1.0606953D-05, 5.7857564D-06 /
      data fpp( 8,16, 5,1),fpp( 8,16, 5,2),fpp( 8,16, 5,3)/
     x 1.1933871D-02,-1.2741328D-05,-4.8228390D-06 /
      data fpp( 8,16, 6,1),fpp( 8,16, 6,2),fpp( 8,16, 6,3)/
     x 1.7073775D-02,-1.9310206D-05,-1.4339067D-05 /
      data fpp( 8,16, 7,1),fpp( 8,16, 7,2),fpp( 8,16, 7,3)/
     x 3.6446877D-03,-2.1534311D-07,-3.4225492D-08 /
      data fpp( 8,16, 8,1),fpp( 8,16, 8,2),fpp( 8,16, 8,3)/
     x-9.1732299D-03, 2.2277256D-05, 6.5199692D-06 /
      data fpp( 8,16, 9,1),fpp( 8,16, 9,2),fpp( 8,16, 9,3)/
     x-1.3524280D-02, 3.0304881D-05, 7.1650154D-06 /
      data fpp( 8,16,10,1),fpp( 8,16,10,2),fpp( 8,16,10,3)/
     x-9.1732299D-03, 2.2277256D-05, 6.5199692D-06 /
      data fpp( 8,16,11,1),fpp( 8,16,11,2),fpp( 8,16,11,3)/
     x 3.6446877D-03,-2.1534311D-07,-3.4225492D-08 /
      data fpp( 8,16,12,1),fpp( 8,16,12,2),fpp( 8,16,12,3)/
     x 1.7073775D-02,-1.9310206D-05,-1.4339067D-05 /
      data fpp( 8,16,13,1),fpp( 8,16,13,2),fpp( 8,16,13,3)/
     x 1.1933871D-02,-1.2741328D-05,-4.8228390D-06 /
      data fpp( 8,16,14,1),fpp( 8,16,14,2),fpp( 8,16,14,3)/
     x 4.7484537D-04, 1.0606953D-05, 5.7857564D-06 /
      data fpp( 8,16,15,1),fpp( 8,16,15,2),fpp( 8,16,15,3)/
     x-3.8255409D-03, 2.1160546D-05, 6.9111468D-06 /
      data fpp( 8,16,16,1),fpp( 8,16,16,2),fpp( 8,16,16,3)/
     x 4.7484537D-04, 1.0606953D-05, 4.0136565D-06 /
      data fpp( 8,16,17,1),fpp( 8,16,17,2),fpp( 8,16,17,3)/
     x 1.1933871D-02,-1.2741328D-05, 2.2655607D-06 /
      data fpp( 8,17, 1,1),fpp( 8,17, 1,2),fpp( 8,17, 1,3)/
     x 1.4019165D-02,-1.4006719D-05, 2.2067098D-07 /
      data fpp( 8,17, 2,1),fpp( 8,17, 2,2),fpp( 8,17, 2,3)/
     x 7.1046453D-03,-1.2141180D-05, 1.8351025D-06 /
      data fpp( 8,17, 3,1),fpp( 8,17, 3,2),fpp( 8,17, 3,3)/
     x 3.9854755D-03,-6.3785315D-06, 4.9189191D-06 /
      data fpp( 8,17, 4,1),fpp( 8,17, 4,2),fpp( 8,17, 4,3)/
     x 7.1046453D-03,-1.2141180D-05, 2.8598880D-06 /
      data fpp( 8,17, 5,1),fpp( 8,17, 5,2),fpp( 8,17, 5,3)/
     x 1.4019165D-02,-1.4006719D-05,-3.8784709D-06 /
      data fpp( 8,17, 6,1),fpp( 8,17, 6,2),fpp( 8,17, 6,3)/
     x 1.5204265D-02,-5.5263291D-06,-7.7220044D-06 /
      data fpp( 8,17, 7,1),fpp( 8,17, 7,2),fpp( 8,17, 7,3)/
     x 5.9015899D-03,-4.4652301D-07,-8.3684498D-07 /
      data fpp( 8,17, 8,1),fpp( 8,17, 8,2),fpp( 8,17, 8,3)/
     x-3.7459054D-03, 1.2531700D-05, 4.4100509D-06 /
      data fpp( 8,17, 9,1),fpp( 8,17, 9,2),fpp( 8,17, 9,3)/
     x-7.3225886D-03, 2.0364686D-05, 5.5866412D-06 /
      data fpp( 8,17,10,1),fpp( 8,17,10,2),fpp( 8,17,10,3)/
     x-3.7459054D-03, 1.2531700D-05, 4.4100509D-06 /
      data fpp( 8,17,11,1),fpp( 8,17,11,2),fpp( 8,17,11,3)/
     x 5.9015899D-03,-4.4652301D-07,-8.3684498D-07 /
      data fpp( 8,17,12,1),fpp( 8,17,12,2),fpp( 8,17,12,3)/
     x 1.5204265D-02,-5.5263291D-06,-7.7220044D-06 /
      data fpp( 8,17,13,1),fpp( 8,17,13,2),fpp( 8,17,13,3)/
     x 1.4019165D-02,-1.4006719D-05,-3.8784709D-06 /
      data fpp( 8,17,14,1),fpp( 8,17,14,2),fpp( 8,17,14,3)/
     x 7.1046453D-03,-1.2141180D-05, 2.8598880D-06 /
      data fpp( 8,17,15,1),fpp( 8,17,15,2),fpp( 8,17,15,3)/
     x 3.9854755D-03,-6.3785315D-06, 4.9189191D-06 /
      data fpp( 8,17,16,1),fpp( 8,17,16,2),fpp( 8,17,16,3)/
     x 7.1046453D-03,-1.2141180D-05, 1.8351025D-06 /
      data fpp( 8,17,17,1),fpp( 8,17,17,2),fpp( 8,17,17,3)/
     x 1.4019165D-02,-1.4006719D-05, 2.2067098D-07 /
      data fpp( 8,18, 1,1),fpp( 8,18, 1,2),fpp( 8,18, 1,3)/
     x 1.3385120D-02,-5.4817945D-06,-4.2884535D-07 /
      data fpp( 8,18, 2,1),fpp( 8,18, 2,2),fpp( 8,18, 2,3)/
     x 1.2219509D-02,-2.8972234D-05, 1.5802403D-07 /
      data fpp( 8,18, 3,1),fpp( 8,18, 3,2),fpp( 8,18, 3,3)/
     x 1.1401168D-02,-3.8756420D-05, 1.3587492D-06 /
      data fpp( 8,18, 4,1),fpp( 8,18, 4,2),fpp( 8,18, 4,3)/
     x 1.2219509D-02,-2.8972234D-05, 4.1097912D-07 /
      data fpp( 8,18, 5,1),fpp( 8,18, 5,2),fpp( 8,18, 5,3)/
     x 1.3385120D-02,-5.4817945D-06,-1.4406657D-06 /
      data fpp( 8,18, 6,1),fpp( 8,18, 6,2),fpp( 8,18, 6,3)/
     x 1.2437376D-02, 9.1295226D-06,-2.0796498D-06 /
      data fpp( 8,18, 7,1),fpp( 8,18, 7,2),fpp( 8,18, 7,3)/
     x 8.4745547D-03, 1.2634351D-06,-3.9140199D-07 /
      data fpp( 8,18, 8,1),fpp( 8,18, 8,2),fpp( 8,18, 8,3)/
     x 4.2667719D-03,-1.1390057D-05, 1.6385910D-06 /
      data fpp( 8,18, 9,1),fpp( 8,18, 9,2),fpp( 8,18, 9,3)/
     x 2.5472578D-03,-1.5985625D-05, 2.4077045D-06 /
      data fpp( 8,18,10,1),fpp( 8,18,10,2),fpp( 8,18,10,3)/
     x 4.2667719D-03,-1.1390057D-05, 1.6385910D-06 /
      data fpp( 8,18,11,1),fpp( 8,18,11,2),fpp( 8,18,11,3)/
     x 8.4745547D-03, 1.2634351D-06,-3.9140199D-07 /
      data fpp( 8,18,12,1),fpp( 8,18,12,2),fpp( 8,18,12,3)/
     x 1.2437376D-02, 9.1295226D-06,-2.0796498D-06 /
      data fpp( 8,18,13,1),fpp( 8,18,13,2),fpp( 8,18,13,3)/
     x 1.3385120D-02,-5.4817945D-06,-1.4406657D-06 /
      data fpp( 8,18,14,1),fpp( 8,18,14,2),fpp( 8,18,14,3)/
     x 1.2219509D-02,-2.8972234D-05, 4.1097912D-07 /
      data fpp( 8,18,15,1),fpp( 8,18,15,2),fpp( 8,18,15,3)/
     x 1.1401168D-02,-3.8756420D-05, 1.3587492D-06 /
      data fpp( 8,18,16,1),fpp( 8,18,16,2),fpp( 8,18,16,3)/
     x 1.2219509D-02,-2.8972234D-05, 1.5802403D-07 /
      data fpp( 8,18,17,1),fpp( 8,18,17,2),fpp( 8,18,17,3)/
     x 1.3385120D-02,-5.4817945D-06,-4.2884535D-07 /
      data fpp( 8,19, 1,1),fpp( 8,19, 1,2),fpp( 8,19, 1,3)/
     x 1.1232996D-02, 2.4589724D-07,-1.1521980D-21 /
      data fpp( 8,19, 2,1),fpp( 8,19, 2,2),fpp( 8,19, 2,3)/
     x 1.1232996D-02,-4.7493883D-05, 5.5109094D-21 /
      data fpp( 8,19, 3,1),fpp( 8,19, 3,2),fpp( 8,19, 3,3)/
     x 1.1232996D-02,-6.9751790D-05, 2.1271269D-21 /
      data fpp( 8,19, 4,1),fpp( 8,19, 4,2),fpp( 8,19, 4,3)/
     x 1.1232996D-02,-4.7493883D-05,-2.8040452D-22 /
      data fpp( 8,19, 5,1),fpp( 8,19, 5,2),fpp( 8,19, 5,3)/
     x 1.1232996D-02, 2.4589724D-07,-3.6223388D-22 /
      data fpp( 8,19, 6,1),fpp( 8,19, 6,2),fpp( 8,19, 6,3)/
     x 1.1232996D-02, 2.3536239D-05, 2.0394933D-21 /
      data fpp( 8,19, 7,1),fpp( 8,19, 7,2),fpp( 8,19, 7,3)/
     x 1.1232996D-02, 2.4187824D-06, 2.2879365D-21 /
      data fpp( 8,19, 8,1),fpp( 8,19, 8,2),fpp( 8,19, 8,3)/
     x 1.1232996D-02,-3.1261471D-05,-3.7329787D-21 /
      data fpp( 8,19, 9,1),fpp( 8,19, 9,2),fpp( 8,19, 9,3)/
     x 1.1232996D-02,-4.4790188D-05,-9.6711279D-22 /
      data fpp( 8,19,10,1),fpp( 8,19,10,2),fpp( 8,19,10,3)/
     x 1.1232996D-02,-3.1261471D-05, 2.9228086D-21 /
      data fpp( 8,19,11,1),fpp( 8,19,11,2),fpp( 8,19,11,3)/
     x 1.1232996D-02, 2.4187824D-06,-1.0694817D-21 /
      data fpp( 8,19,12,1),fpp( 8,19,12,2),fpp( 8,19,12,3)/
     x 1.1232996D-02, 2.3536239D-05, 7.3917661D-22 /
      data fpp( 8,19,13,1),fpp( 8,19,13,2),fpp( 8,19,13,3)/
     x 1.1232996D-02, 2.4589724D-07,-6.1736145D-22 /
      data fpp( 8,19,14,1),fpp( 8,19,14,2),fpp( 8,19,14,3)/
     x 1.1232996D-02,-4.7493883D-05,-2.1955324D-22 /
      data fpp( 8,19,15,1),fpp( 8,19,15,2),fpp( 8,19,15,3)/
     x 1.1232996D-02,-6.9751790D-05,-2.9268494D-22 /
      data fpp( 8,19,16,1),fpp( 8,19,16,2),fpp( 8,19,16,3)/
     x 1.1232996D-02,-4.7493883D-05, 7.7248750D-22 /
      data fpp( 8,19,17,1),fpp( 8,19,17,2),fpp( 8,19,17,3)/
     x 1.1232996D-02, 2.4589724D-07, 1.7557747D-21 /
      data fpp( 9, 1, 1,1),fpp( 9, 1, 1,2),fpp( 9, 1, 1,3)/
     x 1.7962137D-03, 4.9809645D-07,-9.3247946D-24 /
      data fpp( 9, 1, 2,1),fpp( 9, 1, 2,2),fpp( 9, 1, 2,3)/
     x 1.7962137D-03,-1.9394783D-06, 1.6557398D-22 /
      data fpp( 9, 1, 3,1),fpp( 9, 1, 3,2),fpp( 9, 1, 3,3)/
     x 1.7962137D-03,-3.0160112D-06, 8.2674411D-23 /
      data fpp( 9, 1, 4,1),fpp( 9, 1, 4,2),fpp( 9, 1, 4,3)/
     x 1.7962137D-03,-1.9394783D-06,-2.3393542D-23 /
      data fpp( 9, 1, 5,1),fpp( 9, 1, 5,2),fpp( 9, 1, 5,3)/
     x 1.7962137D-03, 4.9809645D-07, 8.3663061D-24 /
      data fpp( 9, 1, 6,1),fpp( 9, 1, 6,2),fpp( 9, 1, 6,3)/
     x 1.7962137D-03, 1.8988396D-06, 1.3624608D-22 /
      data fpp( 9, 1, 7,1),fpp( 9, 1, 7,2),fpp( 9, 1, 7,3)/
     x 1.7962137D-03, 1.1667664D-06, 1.2109285D-22 /
      data fpp( 9, 1, 8,1),fpp( 9, 1, 8,2),fpp( 9, 1, 8,3)/
     x 1.7962137D-03,-8.8363857D-07,-1.3947450D-22 /
      data fpp( 9, 1, 9,1),fpp( 9, 1, 9,2),fpp( 9, 1, 9,3)/
     x 1.7962137D-03,-1.9604066D-06,-7.0591505D-24 /
      data fpp( 9, 1,10,1),fpp( 9, 1,10,2),fpp( 9, 1,10,3)/
     x 1.7962137D-03,-8.8363857D-07, 1.2400329D-22 /
      data fpp( 9, 1,11,1),fpp( 9, 1,11,2),fpp( 9, 1,11,3)/
     x 1.7962137D-03, 1.1667664D-06,-6.3000955D-23 /
      data fpp( 9, 1,12,1),fpp( 9, 1,12,2),fpp( 9, 1,12,3)/
     x 1.7962137D-03, 1.8988396D-06, 2.3038506D-23 /
      data fpp( 9, 1,13,1),fpp( 9, 1,13,2),fpp( 9, 1,13,3)/
     x 1.7962137D-03, 4.9809645D-07,-8.0222433D-23 /
      data fpp( 9, 1,14,1),fpp( 9, 1,14,2),fpp( 9, 1,14,3)/
     x 1.7962137D-03,-1.9394783D-06,-3.5646302D-23 /
      data fpp( 9, 1,15,1),fpp( 9, 1,15,2),fpp( 9, 1,15,3)/
     x 1.7962137D-03,-3.0160112D-06,-5.2823403D-23 /
      data fpp( 9, 1,16,1),fpp( 9, 1,16,2),fpp( 9, 1,16,3)/
     x 1.7962137D-03,-1.9394783D-06,-5.2281928D-23 /
      data fpp( 9, 1,17,1),fpp( 9, 1,17,2),fpp( 9, 1,17,3)/
     x 1.7962137D-03, 4.9809645D-07, 1.5370846D-22 /
      data fpp( 9, 2, 1,1),fpp( 9, 2, 1,2),fpp( 9, 2, 1,3)/
     x 1.7715738D-03, 8.4807091D-08, 1.7735082D-08 /
      data fpp( 9, 2, 2,1),fpp( 9, 2, 2,2),fpp( 9, 2, 2,3)/
     x 1.6024094D-03,-9.9004345D-07, 5.6307615D-08 /
      data fpp( 9, 2, 3,1),fpp( 9, 2, 3,2),fpp( 9, 2, 3,3)/
     x 1.5258398D-03,-1.6719776D-06, 1.3703446D-07 /
      data fpp( 9, 2, 4,1),fpp( 9, 2, 4,2),fpp( 9, 2, 4,3)/
     x 1.6024094D-03,-9.9004345D-07, 7.0221213D-08 /
      data fpp( 9, 2, 5,1),fpp( 9, 2, 5,2),fpp( 9, 2, 5,3)/
     x 1.7715738D-03, 8.4807091D-08,-3.7919312D-08 /
      data fpp( 9, 2, 6,1),fpp( 9, 2, 6,2),fpp( 9, 2, 6,3)/
     x 1.9119824D-03, 6.3232087D-07,-9.7210631D-08 /
      data fpp( 9, 2, 7,1),fpp( 9, 2, 7,2),fpp( 9, 2, 7,3)/
     x 1.9291683D-03, 3.2846718D-07,-6.7238163D-08 /
      data fpp( 9, 2, 8,1),fpp( 9, 2, 8,2),fpp( 9, 2, 8,3)/
     x 1.8465629D-03,-5.7572287D-07, 2.6163285D-08 /
      data fpp( 9, 2, 9,1),fpp( 9, 2, 9,2),fpp( 9, 2, 9,3)/
     x 1.7922536D-03,-1.0881868D-06, 7.7251691D-08 /
      data fpp( 9, 2,10,1),fpp( 9, 2,10,2),fpp( 9, 2,10,3)/
     x 1.8465629D-03,-5.7572287D-07, 2.6163285D-08 /
      data fpp( 9, 2,11,1),fpp( 9, 2,11,2),fpp( 9, 2,11,3)/
     x 1.9291683D-03, 3.2846718D-07,-6.7238163D-08 /
      data fpp( 9, 2,12,1),fpp( 9, 2,12,2),fpp( 9, 2,12,3)/
     x 1.9119824D-03, 6.3232087D-07,-9.7210631D-08 /
      data fpp( 9, 2,13,1),fpp( 9, 2,13,2),fpp( 9, 2,13,3)/
     x 1.7715738D-03, 8.4807091D-08,-3.7919312D-08 /
      data fpp( 9, 2,14,1),fpp( 9, 2,14,2),fpp( 9, 2,14,3)/
     x 1.6024094D-03,-9.9004345D-07, 7.0221213D-08 /
      data fpp( 9, 2,15,1),fpp( 9, 2,15,2),fpp( 9, 2,15,3)/
     x 1.5258398D-03,-1.6719776D-06, 1.3703446D-07 /
      data fpp( 9, 2,16,1),fpp( 9, 2,16,2),fpp( 9, 2,16,3)/
     x 1.6024094D-03,-9.9004345D-07, 5.6307615D-08 /
      data fpp( 9, 2,17,1),fpp( 9, 2,17,2),fpp( 9, 2,17,3)/
     x 1.7715738D-03, 8.4807091D-08, 1.7735082D-08 /
      data fpp( 9, 3, 1,1),fpp( 9, 3, 1,2),fpp( 9, 3, 1,3)/
     x 1.7191497D-03,-4.8332482D-07,-2.9955344D-08 /
      data fpp( 9, 3, 2,1),fpp( 9, 3, 2,2),fpp( 9, 3, 2,3)/
     x 1.2166287D-03,-3.2234792D-07, 1.3535513D-07 /
      data fpp( 9, 3, 3,1),fpp( 9, 3, 3,2),fpp( 9, 3, 3,3)/
     x 9.5964627D-04,-8.2007832D-07, 5.0120148D-07 /
      data fpp( 9, 3, 4,1),fpp( 9, 3, 4,2),fpp( 9, 3, 4,3)/
     x 1.2166287D-03,-3.2234792D-07, 1.6517226D-07 /
      data fpp( 9, 3, 5,1),fpp( 9, 3, 5,2),fpp( 9, 3, 5,3)/
     x 1.7191497D-03,-4.8332482D-07,-1.4922388D-07 /
      data fpp( 9, 3, 6,1),fpp( 9, 3, 6,2),fpp( 9, 3, 6,3)/
     x 2.1268734D-03,-7.8012304D-07,-2.9027676D-07 /
      data fpp( 9, 3, 7,1),fpp( 9, 3, 7,2),fpp( 9, 3, 7,3)/
     x 2.1513890D-03,-4.7663513D-07,-2.2633574D-07 /
      data fpp( 9, 3, 8,1),fpp( 9, 3, 8,2),fpp( 9, 3, 8,3)/
     x 1.8050177D-03,-1.6746996D-07, 1.0295307D-07 /
      data fpp( 9, 3, 9,1),fpp( 9, 3, 9,2),fpp( 9, 3, 9,3)/
     x 1.5766799D-03,-1.0084611D-07, 2.9919013D-07 /
      data fpp( 9, 3,10,1),fpp( 9, 3,10,2),fpp( 9, 3,10,3)/
     x 1.8050177D-03,-1.6746996D-07, 1.0295307D-07 /
      data fpp( 9, 3,11,1),fpp( 9, 3,11,2),fpp( 9, 3,11,3)/
     x 2.1513890D-03,-4.7663513D-07,-2.2633574D-07 /
      data fpp( 9, 3,12,1),fpp( 9, 3,12,2),fpp( 9, 3,12,3)/
     x 2.1268734D-03,-7.8012304D-07,-2.9027676D-07 /
      data fpp( 9, 3,13,1),fpp( 9, 3,13,2),fpp( 9, 3,13,3)/
     x 1.7191497D-03,-4.8332482D-07,-1.4922388D-07 /
      data fpp( 9, 3,14,1),fpp( 9, 3,14,2),fpp( 9, 3,14,3)/
     x 1.2166287D-03,-3.2234792D-07, 1.6517226D-07 /
      data fpp( 9, 3,15,1),fpp( 9, 3,15,2),fpp( 9, 3,15,3)/
     x 9.5964627D-04,-8.2007832D-07, 5.0120148D-07 /
      data fpp( 9, 3,16,1),fpp( 9, 3,16,2),fpp( 9, 3,16,3)/
     x 1.2166287D-03,-3.2234792D-07, 1.3535513D-07 /
      data fpp( 9, 3,17,1),fpp( 9, 3,17,2),fpp( 9, 3,17,3)/
     x 1.7191497D-03,-4.8332482D-07,-2.9955344D-08 /
      data fpp( 9, 4, 1,1),fpp( 9, 4, 1,2),fpp( 9, 4, 1,3)/
     x 1.5364888D-03,-5.0950781D-07,-2.8175578D-07 /
      data fpp( 9, 4, 2,1),fpp( 9, 4, 2,2),fpp( 9, 4, 2,3)/
     x 7.5785805D-04, 1.3314351D-06, 1.1706712D-07 /
      data fpp( 9, 4, 3,1),fpp( 9, 4, 3,2),fpp( 9, 4, 3,3)/
     x 2.5400044D-04, 1.7542909D-06, 1.0521540D-06 /
      data fpp( 9, 4, 4,1),fpp( 9, 4, 4,2),fpp( 9, 4, 4,3)/
     x 7.5785805D-04, 1.3314351D-06, 1.1031700D-07 /
      data fpp( 9, 4, 5,1),fpp( 9, 4, 5,2),fpp( 9, 4, 5,3)/
     x 1.5364888D-03,-5.0950781D-07,-2.5475529D-07 /
      data fpp( 9, 4, 6,1),fpp( 9, 4, 6,2),fpp( 9, 4, 6,3)/
     x 2.1882218D-03,-1.6818287D-06,-4.0129583D-07 /
      data fpp( 9, 4, 7,1),fpp( 9, 4, 7,2),fpp( 9, 4, 7,3)/
     x 2.2824671D-03,-1.3979267D-06,-3.8539471D-07 /
      data fpp( 9, 4, 8,1),fpp( 9, 4, 8,2),fpp( 9, 4, 8,3)/
     x 1.6875674D-03,-1.1039727D-07, 1.4487468D-07 /
      data fpp( 9, 4, 9,1),fpp( 9, 4, 9,2),fpp( 9, 4, 9,3)/
     x 1.2694844D-03, 4.8357125D-07, 5.1922933D-07 /
      data fpp( 9, 4,10,1),fpp( 9, 4,10,2),fpp( 9, 4,10,3)/
     x 1.6875674D-03,-1.1039727D-07, 1.4487468D-07 /
      data fpp( 9, 4,11,1),fpp( 9, 4,11,2),fpp( 9, 4,11,3)/
     x 2.2824671D-03,-1.3979267D-06,-3.8539471D-07 /
      data fpp( 9, 4,12,1),fpp( 9, 4,12,2),fpp( 9, 4,12,3)/
     x 2.1882218D-03,-1.6818287D-06,-4.0129583D-07 /
      data fpp( 9, 4,13,1),fpp( 9, 4,13,2),fpp( 9, 4,13,3)/
     x 1.5364888D-03,-5.0950781D-07,-2.5475529D-07 /
      data fpp( 9, 4,14,1),fpp( 9, 4,14,2),fpp( 9, 4,14,3)/
     x 7.5785805D-04, 1.3314351D-06, 1.1031700D-07 /
      data fpp( 9, 4,15,1),fpp( 9, 4,15,2),fpp( 9, 4,15,3)/
     x 2.5400044D-04, 1.7542909D-06, 1.0521540D-06 /
      data fpp( 9, 4,16,1),fpp( 9, 4,16,2),fpp( 9, 4,16,3)/
     x 7.5785805D-04, 1.3314351D-06, 1.1706712D-07 /
      data fpp( 9, 4,17,1),fpp( 9, 4,17,2),fpp( 9, 4,17,3)/
     x 1.5364888D-03,-5.0950781D-07,-2.8175578D-07 /
      data fpp( 9, 5, 1,1),fpp( 9, 5, 1,2),fpp( 9, 5, 1,3)/
     x 1.2242517D-03,-1.3664394D-07,-6.7075835D-07 /
      data fpp( 9, 5, 2,1),fpp( 9, 5, 2,2),fpp( 9, 5, 2,3)/
     x 4.5913584D-04, 2.1006075D-06,-3.4705517D-08 /
      data fpp( 9, 5, 3,1),fpp( 9, 5, 3,2),fpp( 9, 5, 3,3)/
     x-1.7702517D-04, 3.8829147D-06, 1.5202471D-06 /
      data fpp( 9, 5, 4,1),fpp( 9, 5, 4,2),fpp( 9, 5, 4,3)/
     x 4.5913584D-04, 2.1006075D-06,-1.4094950D-07 /
      data fpp( 9, 5, 5,1),fpp( 9, 5, 5,2),fpp( 9, 5, 5,3)/
     x 1.2242517D-03,-1.3664394D-07,-2.4578241D-07 /
      data fpp( 9, 5, 6,1),fpp( 9, 5, 6,2),fpp( 9, 5, 6,3)/
     x 1.9438445D-03,-1.1565621D-06,-3.5658753D-07 /
      data fpp( 9, 5, 7,1),fpp( 9, 5, 7,2),fpp( 9, 5, 7,3)/
     x 2.1677310D-03,-9.0965819D-07,-4.2720079D-07 /
      data fpp( 9, 5, 8,1),fpp( 9, 5, 8,2),fpp( 9, 5, 8,3)/
     x 1.4956848D-03, 6.3059057D-08, 8.9390703D-08 /
      data fpp( 9, 5, 9,1),fpp( 9, 5, 9,2),fpp( 9, 5, 9,3)/
     x 9.8158012D-04, 5.6656110D-07, 6.2430465D-07 /
      data fpp( 9, 5,10,1),fpp( 9, 5,10,2),fpp( 9, 5,10,3)/
     x 1.4956848D-03, 6.3059057D-08, 8.9390703D-08 /
      data fpp( 9, 5,11,1),fpp( 9, 5,11,2),fpp( 9, 5,11,3)/
     x 2.1677310D-03,-9.0965819D-07,-4.2720079D-07 /
      data fpp( 9, 5,12,1),fpp( 9, 5,12,2),fpp( 9, 5,12,3)/
     x 1.9438445D-03,-1.1565621D-06,-3.5658753D-07 /
      data fpp( 9, 5,13,1),fpp( 9, 5,13,2),fpp( 9, 5,13,3)/
     x 1.2242517D-03,-1.3664394D-07,-2.4578241D-07 /
      data fpp( 9, 5,14,1),fpp( 9, 5,14,2),fpp( 9, 5,14,3)/
     x 4.5913584D-04, 2.1006075D-06,-1.4094950D-07 /
      data fpp( 9, 5,15,1),fpp( 9, 5,15,2),fpp( 9, 5,15,3)/
     x-1.7702517D-04, 3.8829147D-06, 1.5202471D-06 /
      data fpp( 9, 5,16,1),fpp( 9, 5,16,2),fpp( 9, 5,16,3)/
     x 4.5913584D-04, 2.1006075D-06,-3.4705517D-08 /
      data fpp( 9, 5,17,1),fpp( 9, 5,17,2),fpp( 9, 5,17,3)/
     x 1.2242517D-03,-1.3664394D-07,-6.7075835D-07 /
      data fpp( 9, 6, 1,1),fpp( 9, 6, 1,2),fpp( 9, 6, 1,3)/
     x 8.5726045D-04, 2.1008356D-07,-8.4239755D-07 /
      data fpp( 9, 6, 2,1),fpp( 9, 6, 2,2),fpp( 9, 6, 2,3)/
     x 4.1473170D-04, 1.1381351D-06,-1.8420490D-07 /
      data fpp( 9, 6, 3,1),fpp( 9, 6, 3,2),fpp( 9, 6, 3,3)/
     x-5.1996286D-05, 2.7180503D-06, 1.4745505D-06 /
      data fpp( 9, 6, 4,1),fpp( 9, 6, 4,2),fpp( 9, 6, 4,3)/
     x 4.1473170D-04, 1.1381351D-06,-3.6866366D-07 /
      data fpp( 9, 6, 5,1),fpp( 9, 6, 5,2),fpp( 9, 6, 5,3)/
     x 8.5726045D-04, 2.1008356D-07,-1.0456250D-07 /
      data fpp( 9, 6, 6,1),fpp( 9, 6, 6,2),fpp( 9, 6, 6,3)/
     x 1.4463193D-03,-8.7922858D-08,-1.7908634D-07 /
      data fpp( 9, 6, 7,1),fpp( 9, 6, 7,2),fpp( 9, 6, 7,3)/
     x 1.8219153D-03,-8.7440564D-08,-3.7442547D-07 /
      data fpp( 9, 6, 8,1),fpp( 9, 6, 8,2),fpp( 9, 6, 8,3)/
     x 1.2359755D-03, 3.8161045D-08,-2.9211770D-08 /
      data fpp( 9, 6, 9,1),fpp( 9, 6, 9,2),fpp( 9, 6, 9,3)/
     x 7.4481690D-04, 2.0818435D-07, 6.0660588D-07 /
      data fpp( 9, 6,10,1),fpp( 9, 6,10,2),fpp( 9, 6,10,3)/
     x 1.2359755D-03, 3.8161045D-08,-2.9211770D-08 /
      data fpp( 9, 6,11,1),fpp( 9, 6,11,2),fpp( 9, 6,11,3)/
     x 1.8219153D-03,-8.7440564D-08,-3.7442547D-07 /
      data fpp( 9, 6,12,1),fpp( 9, 6,12,2),fpp( 9, 6,12,3)/
     x 1.4463193D-03,-8.7922858D-08,-1.7908634D-07 /
      data fpp( 9, 6,13,1),fpp( 9, 6,13,2),fpp( 9, 6,13,3)/
     x 8.5726045D-04, 2.1008356D-07,-1.0456250D-07 /
      data fpp( 9, 6,14,1),fpp( 9, 6,14,2),fpp( 9, 6,14,3)/
     x 4.1473170D-04, 1.1381351D-06,-3.6866366D-07 /
      data fpp( 9, 6,15,1),fpp( 9, 6,15,2),fpp( 9, 6,15,3)/
     x-5.1996286D-05, 2.7180503D-06, 1.4745505D-06 /
      data fpp( 9, 6,16,1),fpp( 9, 6,16,2),fpp( 9, 6,16,3)/
     x 4.1473170D-04, 1.1381351D-06,-1.8420490D-07 /
      data fpp( 9, 6,17,1),fpp( 9, 6,17,2),fpp( 9, 6,17,3)/
     x 8.5726045D-04, 2.1008356D-07,-8.4239755D-07 /
      data fpp( 9, 7, 1,1),fpp( 9, 7, 1,2),fpp( 9, 7, 1,3)/
     x 5.1060988D-04, 2.8030969D-07,-6.3746428D-07 /
      data fpp( 9, 7, 2,1),fpp( 9, 7, 2,2),fpp( 9, 7, 2,3)/
     x 4.8344299D-04,-4.7314767D-07,-2.1296032D-07 /
      data fpp( 9, 7, 3,1),fpp( 9, 7, 3,2),fpp( 9, 7, 3,3)/
     x 3.3963515D-04,-4.4511582D-07, 8.9530558D-07 /
      data fpp( 9, 7, 4,1),fpp( 9, 7, 4,2),fpp( 9, 7, 4,3)/
     x 4.8344299D-04,-4.7314767D-07,-3.8959533D-07 /
      data fpp( 9, 7, 5,1),fpp( 9, 7, 5,2),fpp( 9, 7, 5,3)/
     x 5.1060988D-04, 2.8030969D-07, 6.9075728D-08 /
      data fpp( 9, 7, 6,1),fpp( 9, 7, 6,2),fpp( 9, 7, 6,3)/
     x 8.8884548D-04, 6.6825354D-07, 3.6625750D-08 /
      data fpp( 9, 7, 7,1),fpp( 9, 7, 7,2),fpp( 9, 7, 7,3)/
     x 1.3160912D-03, 3.6542045D-07,-3.1024539D-07 /
      data fpp( 9, 7, 8,1),fpp( 9, 7, 8,2),fpp( 9, 7, 8,3)/
     x 9.2404336D-04,-2.3370324D-07,-1.2831084D-07 /
      data fpp( 9, 7, 9,1),fpp( 9, 7, 9,2),fpp( 9, 7, 9,3)/
     x 5.2723354D-04,-3.5529850D-07, 5.2015542D-07 /
      data fpp( 9, 7,10,1),fpp( 9, 7,10,2),fpp( 9, 7,10,3)/
     x 9.2404336D-04,-2.3370324D-07,-1.2831084D-07 /
      data fpp( 9, 7,11,1),fpp( 9, 7,11,2),fpp( 9, 7,11,3)/
     x 1.3160912D-03, 3.6542045D-07,-3.1024539D-07 /
      data fpp( 9, 7,12,1),fpp( 9, 7,12,2),fpp( 9, 7,12,3)/
     x 8.8884548D-04, 6.6825354D-07, 3.6625750D-08 /
      data fpp( 9, 7,13,1),fpp( 9, 7,13,2),fpp( 9, 7,13,3)/
     x 5.1060988D-04, 2.8030969D-07, 6.9075728D-08 /
      data fpp( 9, 7,14,1),fpp( 9, 7,14,2),fpp( 9, 7,14,3)/
     x 4.8344299D-04,-4.7314767D-07,-3.8959533D-07 /
      data fpp( 9, 7,15,1),fpp( 9, 7,15,2),fpp( 9, 7,15,3)/
     x 3.3963515D-04,-4.4511582D-07, 8.9530558D-07 /
      data fpp( 9, 7,16,1),fpp( 9, 7,16,2),fpp( 9, 7,16,3)/
     x 4.8344299D-04,-4.7314767D-07,-2.1296032D-07 /
      data fpp( 9, 7,17,1),fpp( 9, 7,17,2),fpp( 9, 7,17,3)/
     x 5.1060988D-04, 2.8030969D-07,-6.3746428D-07 /
      data fpp( 9, 8, 1,1),fpp( 9, 8, 1,2),fpp( 9, 8, 1,3)/
     x 2.3651053D-04, 1.3267766D-07,-2.6509359D-07 /
      data fpp( 9, 8, 2,1),fpp( 9, 8, 2,2),fpp( 9, 8, 2,3)/
     x 4.6999447D-04,-1.3815444D-06,-1.4225725D-07 /
      data fpp( 9, 8, 3,1),fpp( 9, 8, 3,2),fpp( 9, 8, 3,3)/
     x 5.8144915D-04,-2.4675870D-06, 2.1812261D-07 /
      data fpp( 9, 8, 4,1),fpp( 9, 8, 4,2),fpp( 9, 8, 4,3)/
     x 4.6999447D-04,-1.3815444D-06,-2.5289987D-07 /
      data fpp( 9, 8, 5,1),fpp( 9, 8, 5,2),fpp( 9, 8, 5,3)/
     x 2.3651053D-04, 1.3267766D-07, 1.7747685D-07 /
      data fpp( 9, 8, 6,1),fpp( 9, 8, 6,2),fpp( 9, 8, 6,3)/
     x 4.4076986D-04, 8.5290870D-07, 1.7499246D-07 /
      data fpp( 9, 8, 7,1),fpp( 9, 8, 7,2),fpp( 9, 8, 7,3)/
     x 8.0983599D-04, 3.1175877D-07,-2.8544669D-07 /
      data fpp( 9, 8, 8,1),fpp( 9, 8, 8,2),fpp( 9, 8, 8,3)/
     x 5.7138101D-04,-5.6134809D-07,-1.4720571D-07 /
      data fpp( 9, 8, 9,1),fpp( 9, 8, 9,2),fpp( 9, 8, 9,3)/
     x 2.7347382D-04,-8.9299037D-07, 4.2960285D-07 /
      data fpp( 9, 8,10,1),fpp( 9, 8,10,2),fpp( 9, 8,10,3)/
     x 5.7138101D-04,-5.6134809D-07,-1.4720571D-07 /
      data fpp( 9, 8,11,1),fpp( 9, 8,11,2),fpp( 9, 8,11,3)/
     x 8.0983599D-04, 3.1175877D-07,-2.8544669D-07 /
      data fpp( 9, 8,12,1),fpp( 9, 8,12,2),fpp( 9, 8,12,3)/
     x 4.4076986D-04, 8.5290870D-07, 1.7499246D-07 /
      data fpp( 9, 8,13,1),fpp( 9, 8,13,2),fpp( 9, 8,13,3)/
     x 2.3651053D-04, 1.3267766D-07, 1.7747685D-07 /
      data fpp( 9, 8,14,1),fpp( 9, 8,14,2),fpp( 9, 8,14,3)/
     x 4.6999447D-04,-1.3815444D-06,-2.5289987D-07 /
      data fpp( 9, 8,15,1),fpp( 9, 8,15,2),fpp( 9, 8,15,3)/
     x 5.8144915D-04,-2.4675870D-06, 2.1812261D-07 /
      data fpp( 9, 8,16,1),fpp( 9, 8,16,2),fpp( 9, 8,16,3)/
     x 4.6999447D-04,-1.3815444D-06,-1.4225725D-07 /
      data fpp( 9, 8,17,1),fpp( 9, 8,17,2),fpp( 9, 8,17,3)/
     x 2.3651053D-04, 1.3267766D-07,-2.6509359D-07 /
      data fpp( 9, 9, 1,1),fpp( 9, 9, 1,2),fpp( 9, 9, 1,3)/
     x 4.3120616D-05,-3.7020340D-08, 2.4947871D-08 /
      data fpp( 9, 9, 2,1),fpp( 9, 9, 2,2),fpp( 9, 9, 2,3)/
     x 2.9531389D-04,-1.5426748D-06,-4.2895741D-08 /
      data fpp( 9, 9, 3,1),fpp( 9, 9, 3,2),fpp( 9, 9, 3,3)/
     x 4.9448993D-04,-2.6625362D-06,-1.7136491D-07 /
      data fpp( 9, 9, 4,1),fpp( 9, 9, 4,2),fpp( 9, 9, 4,3)/
     x 2.9531389D-04,-1.5426748D-06,-8.7644637D-08 /
      data fpp( 9, 9, 5,1),fpp( 9, 9, 5,2),fpp( 9, 9, 5,3)/
     x 4.3120616D-05,-3.7020340D-08, 2.0394345D-07 /
      data fpp( 9, 9, 6,1),fpp( 9, 9, 6,2),fpp( 9, 9, 6,3)/
     x 1.8191662D-04, 7.5611165D-07, 1.3987083D-07 /
      data fpp( 9, 9, 7,1),fpp( 9, 9, 7,2),fpp( 9, 9, 7,3)/
     x 4.0630537D-04, 4.3544461D-08,-2.8942676D-07 /
      data fpp( 9, 9, 8,1),fpp( 9, 9, 8,2),fpp( 9, 9, 8,3)/
     x 1.7581487D-04,-9.2290439D-07,-8.6163783D-08 /
      data fpp( 9, 9, 9,1),fpp( 9, 9, 9,2),fpp( 9, 9, 9,3)/
     x-7.7015345D-05,-1.3407400D-06, 4.0274856D-07 /
      data fpp( 9, 9,10,1),fpp( 9, 9,10,2),fpp( 9, 9,10,3)/
     x 1.7581487D-04,-9.2290439D-07,-8.6163783D-08 /
      data fpp( 9, 9,11,1),fpp( 9, 9,11,2),fpp( 9, 9,11,3)/
     x 4.0630537D-04, 4.3544461D-08,-2.8942676D-07 /
      data fpp( 9, 9,12,1),fpp( 9, 9,12,2),fpp( 9, 9,12,3)/
     x 1.8191662D-04, 7.5611165D-07, 1.3987083D-07 /
      data fpp( 9, 9,13,1),fpp( 9, 9,13,2),fpp( 9, 9,13,3)/
     x 4.3120616D-05,-3.7020340D-08, 2.0394345D-07 /
      data fpp( 9, 9,14,1),fpp( 9, 9,14,2),fpp( 9, 9,14,3)/
     x 2.9531389D-04,-1.5426748D-06,-8.7644637D-08 /
      data fpp( 9, 9,15,1),fpp( 9, 9,15,2),fpp( 9, 9,15,3)/
     x 4.9448993D-04,-2.6625362D-06,-1.7136491D-07 /
      data fpp( 9, 9,16,1),fpp( 9, 9,16,2),fpp( 9, 9,16,3)/
     x 2.9531389D-04,-1.5426748D-06,-4.2895741D-08 /
      data fpp( 9, 9,17,1),fpp( 9, 9,17,2),fpp( 9, 9,17,3)/
     x 4.3120616D-05,-3.7020340D-08, 2.4947871D-08 /
      data fpp( 9,10, 1,1),fpp( 9,10, 1,2),fpp( 9,10, 1,3)/
     x-6.6780590D-05, 3.3403700D-08, 1.9148860D-07 /
      data fpp( 9,10, 2,1),fpp( 9,10, 2,2),fpp( 9,10, 2,3)/
     x-4.3241316D-05,-1.3517563D-06, 7.1578349D-08 /
      data fpp( 9,10, 3,1),fpp( 9,10, 3,2),fpp( 9,10, 3,3)/
     x 8.1507305D-05,-2.1342683D-06,-2.1180200D-07 /
      data fpp( 9,10, 4,1),fpp( 9,10, 4,2),fpp( 9,10, 4,3)/
     x-4.3241316D-05,-1.3517563D-06, 7.6962983D-08 /
      data fpp( 9,10, 5,1),fpp( 9,10, 5,2),fpp( 9,10, 5,3)/
     x-6.6780590D-05, 3.3403700D-08, 1.6995007D-07 /
      data fpp( 9,10, 6,1),fpp( 9,10, 6,2),fpp( 9,10, 6,3)/
     x 1.3617073D-04, 7.9664471D-07,-1.2676325D-07 /
      data fpp( 9,10, 7,1),fpp( 9,10, 7,2),fpp( 9,10, 7,3)/
     x 1.1514540D-04,-7.7936618D-08,-2.9823041D-07 /
      data fpp( 9,10, 8,1),fpp( 9,10, 8,2),fpp( 9,10, 8,3)/
     x-2.9946695D-04,-1.2190343D-06, 4.6351545D-08 /
      data fpp( 9,10, 9,1),fpp( 9,10, 9,2),fpp( 9,10, 9,3)/
     x-5.8668369D-04,-1.6640495D-06, 4.7615756D-07 /
      data fpp( 9,10,10,1),fpp( 9,10,10,2),fpp( 9,10,10,3)/
     x-2.9946695D-04,-1.2190343D-06, 4.6351545D-08 /
      data fpp( 9,10,11,1),fpp( 9,10,11,2),fpp( 9,10,11,3)/
     x 1.1514540D-04,-7.7936618D-08,-2.9823041D-07 /
      data fpp( 9,10,12,1),fpp( 9,10,12,2),fpp( 9,10,12,3)/
     x 1.3617073D-04, 7.9664471D-07,-1.2676325D-07 /
      data fpp( 9,10,13,1),fpp( 9,10,13,2),fpp( 9,10,13,3)/
     x-6.6780590D-05, 3.3403700D-08, 1.6995007D-07 /
      data fpp( 9,10,14,1),fpp( 9,10,14,2),fpp( 9,10,14,3)/
     x-4.3241316D-05,-1.3517563D-06, 7.6962983D-08 /
      data fpp( 9,10,15,1),fpp( 9,10,15,2),fpp( 9,10,15,3)/
     x 8.1507305D-05,-2.1342683D-06,-2.1180200D-07 /
      data fpp( 9,10,16,1),fpp( 9,10,16,2),fpp( 9,10,16,3)/
     x-4.3241316D-05,-1.3517563D-06, 7.1578349D-08 /
      data fpp( 9,10,17,1),fpp( 9,10,17,2),fpp( 9,10,17,3)/
     x-6.6780590D-05, 3.3403700D-08, 1.9148860D-07 /
      data fpp( 9,11, 1,1),fpp( 9,11, 1,2),fpp( 9,11, 1,3)/
     x-6.8395566D-05, 4.9740554D-07, 3.2326208D-07 /
      data fpp( 9,11, 2,1),fpp( 9,11, 2,2),fpp( 9,11, 2,3)/
     x-5.1909508D-04,-8.7429985D-07, 2.3503141D-07 /
      data fpp( 9,11, 3,1),fpp( 9,11, 3,2),fpp( 9,11, 3,3)/
     x-5.8943871D-04,-1.4243905D-06,-1.1387696D-08 /
      data fpp( 9,11, 4,1),fpp( 9,11, 4,2),fpp( 9,11, 4,3)/
     x-5.1909508D-04,-8.7429985D-07, 2.9585271D-07 /
      data fpp( 9,11, 5,1),fpp( 9,11, 5,2),fpp( 9,11, 5,3)/
     x-6.8395566D-05, 4.9740554D-07, 7.9976852D-08 /
      data fpp( 9,11, 6,1),fpp( 9,11, 6,2),fpp( 9,11, 6,3)/
     x 3.3745226D-04, 1.1813095D-06,-6.5576012D-07 /
      data fpp( 9,11, 7,1),fpp( 9,11, 7,2),fpp( 9,11, 7,3)/
     x-7.8644610D-05, 1.0202010D-08,-3.0293638D-07 /
      data fpp( 9,11, 8,1),fpp( 9,11, 8,2),fpp( 9,11, 8,3)/
     x-9.0433533D-04,-1.2509582D-06, 2.6817230D-07 /
      data fpp( 9,11, 9,1),fpp( 9,11, 9,2),fpp( 9,11, 9,3)/
     x-1.3203901D-03,-1.6810621D-06, 6.5091385D-07 /
      data fpp( 9,11,10,1),fpp( 9,11,10,2),fpp( 9,11,10,3)/
     x-9.0433533D-04,-1.2509582D-06, 2.6817230D-07 /
      data fpp( 9,11,11,1),fpp( 9,11,11,2),fpp( 9,11,11,3)/
     x-7.8644610D-05, 1.0202010D-08,-3.0293638D-07 /
      data fpp( 9,11,12,1),fpp( 9,11,12,2),fpp( 9,11,12,3)/
     x 3.3745226D-04, 1.1813095D-06,-6.5576012D-07 /
      data fpp( 9,11,13,1),fpp( 9,11,13,2),fpp( 9,11,13,3)/
     x-6.8395566D-05, 4.9740554D-07, 7.9976852D-08 /
      data fpp( 9,11,14,1),fpp( 9,11,14,2),fpp( 9,11,14,3)/
     x-5.1909508D-04,-8.7429985D-07, 2.9585271D-07 /
      data fpp( 9,11,15,1),fpp( 9,11,15,2),fpp( 9,11,15,3)/
     x-5.8943871D-04,-1.4243905D-06,-1.1387696D-08 /
      data fpp( 9,11,16,1),fpp( 9,11,16,2),fpp( 9,11,16,3)/
     x-5.1909508D-04,-8.7429985D-07, 2.3503141D-07 /
      data fpp( 9,11,17,1),fpp( 9,11,17,2),fpp( 9,11,17,3)/
     x-6.8395566D-05, 4.9740554D-07, 3.2326208D-07 /
      data fpp( 9,12, 1,1),fpp( 9,12, 1,2),fpp( 9,12, 1,3)/
     x 1.0830992D-04, 1.2529741D-06, 5.0286633D-07 /
      data fpp( 9,12, 2,1),fpp( 9,12, 2,2),fpp( 9,12, 2,3)/
     x-1.0639328D-03, 1.4495572D-07, 4.7971178D-07 /
      data fpp( 9,12, 3,1),fpp( 9,12, 3,2),fpp( 9,12, 3,3)/
     x-1.4203158D-03,-2.4416969D-07, 3.2828654D-07 /
      data fpp( 9,12, 4,1),fpp( 9,12, 4,2),fpp( 9,12, 4,3)/
     x-1.0639328D-03, 1.4495572D-07, 6.2580874D-07 /
      data fpp( 9,12, 5,1),fpp( 9,12, 5,2),fpp( 9,12, 5,3)/
     x 1.0830992D-04, 1.2529741D-06,-8.1521495D-08 /
      data fpp( 9,12, 6,1),fpp( 9,12, 6,2),fpp( 9,12, 6,3)/
     x 8.5499977D-04, 1.6001172D-06,-1.4690561D-06 /
      data fpp( 9,12, 7,1),fpp( 9,12, 7,2),fpp( 9,12, 7,3)/
     x-1.6928228D-04, 4.0912858D-07,-2.7625413D-07 /
      data fpp( 9,12, 8,1),fpp( 9,12, 8,2),fpp( 9,12, 8,3)/
     x-1.6528491D-03,-6.7113273D-07, 5.9140594D-07 /
      data fpp( 9,12, 9,1),fpp( 9,12, 9,2),fpp( 9,12, 9,3)/
     x-2.2964760D-03,-1.0317022D-06, 9.1529703D-07 /
      data fpp( 9,12,10,1),fpp( 9,12,10,2),fpp( 9,12,10,3)/
     x-1.6528491D-03,-6.7113273D-07, 5.9140594D-07 /
      data fpp( 9,12,11,1),fpp( 9,12,11,2),fpp( 9,12,11,3)/
     x-1.6928228D-04, 4.0912858D-07,-2.7625413D-07 /
      data fpp( 9,12,12,1),fpp( 9,12,12,2),fpp( 9,12,12,3)/
     x 8.5499977D-04, 1.6001172D-06,-1.4690561D-06 /
      data fpp( 9,12,13,1),fpp( 9,12,13,2),fpp( 9,12,13,3)/
     x 1.0830992D-04, 1.2529741D-06,-8.1521495D-08 /
      data fpp( 9,12,14,1),fpp( 9,12,14,2),fpp( 9,12,14,3)/
     x-1.0639328D-03, 1.4495572D-07, 6.2580874D-07 /
      data fpp( 9,12,15,1),fpp( 9,12,15,2),fpp( 9,12,15,3)/
     x-1.4203158D-03,-2.4416969D-07, 3.2828654D-07 /
      data fpp( 9,12,16,1),fpp( 9,12,16,2),fpp( 9,12,16,3)/
     x-1.0639328D-03, 1.4495572D-07, 4.7971178D-07 /
      data fpp( 9,12,17,1),fpp( 9,12,17,2),fpp( 9,12,17,3)/
     x 1.0830992D-04, 1.2529741D-06, 5.0286633D-07 /
      data fpp( 9,13, 1,1),fpp( 9,13, 1,2),fpp( 9,13, 1,3)/
     x 5.6709933D-04, 1.8586979D-06, 7.3069869D-07 /
      data fpp( 9,13, 2,1),fpp( 9,13, 2,2),fpp( 9,13, 2,3)/
     x-1.5253269D-03, 1.8364770D-06, 7.9038039D-07 /
      data fpp( 9,13, 3,1),fpp( 9,13, 3,2),fpp( 9,13, 3,3)/
     x-2.2378833D-03, 1.6810693D-06, 7.5177973D-07 /
      data fpp( 9,13, 4,1),fpp( 9,13, 4,2),fpp( 9,13, 4,3)/
     x-1.5253269D-03, 1.8364770D-06, 1.0571673D-06 /
      data fpp( 9,13, 5,1),fpp( 9,13, 5,2),fpp( 9,13, 5,3)/
     x 5.6709933D-04, 1.8586979D-06,-3.3644907D-07 /
      data fpp( 9,13, 6,1),fpp( 9,13, 6,2),fpp( 9,13, 6,3)/
     x 1.7381162D-03, 1.3102217D-06,-2.4880377D-06 /
      data fpp( 9,13, 7,1),fpp( 9,13, 7,2),fpp( 9,13, 7,3)/
     x-1.1071624D-04, 9.3928368D-07,-2.0340011D-07 /
      data fpp( 9,13, 8,1),fpp( 9,13, 8,2),fpp( 9,13, 8,3)/
     x-2.4754531D-03, 7.2548916D-07, 9.9230479D-07 /
      data fpp( 9,13, 9,1),fpp( 9,13, 9,2),fpp( 9,13, 9,3)/
     x-3.4196406D-03, 6.4187081D-07, 1.2495143D-06 /
      data fpp( 9,13,10,1),fpp( 9,13,10,2),fpp( 9,13,10,3)/
     x-2.4754531D-03, 7.2548916D-07, 9.9230479D-07 /
      data fpp( 9,13,11,1),fpp( 9,13,11,2),fpp( 9,13,11,3)/
     x-1.1071624D-04, 9.3928368D-07,-2.0340011D-07 /
      data fpp( 9,13,12,1),fpp( 9,13,12,2),fpp( 9,13,12,3)/
     x 1.7381162D-03, 1.3102217D-06,-2.4880377D-06 /
      data fpp( 9,13,13,1),fpp( 9,13,13,2),fpp( 9,13,13,3)/
     x 5.6709933D-04, 1.8586979D-06,-3.3644907D-07 /
      data fpp( 9,13,14,1),fpp( 9,13,14,2),fpp( 9,13,14,3)/
     x-1.5253269D-03, 1.8364770D-06, 1.0571673D-06 /
      data fpp( 9,13,15,1),fpp( 9,13,15,2),fpp( 9,13,15,3)/
     x-2.2378833D-03, 1.6810693D-06, 7.5177973D-07 /
      data fpp( 9,13,16,1),fpp( 9,13,16,2),fpp( 9,13,16,3)/
     x-1.5253269D-03, 1.8364770D-06, 7.9038039D-07 /
      data fpp( 9,13,17,1),fpp( 9,13,17,2),fpp( 9,13,17,3)/
     x 5.6709933D-04, 1.8586979D-06, 7.3069869D-07 /
      data fpp( 9,14, 1,1),fpp( 9,14, 1,2),fpp( 9,14, 1,3)/
     x 1.3659997D-03, 1.4162342D-06, 8.8288134D-07 /
      data fpp( 9,14, 2,1),fpp( 9,14, 2,2),fpp( 9,14, 2,3)/
     x-1.6329668D-03, 3.7531364D-06, 1.0627929D-06 /
      data fpp( 9,14, 3,1),fpp( 9,14, 3,2),fpp( 9,14, 3,3)/
     x-2.7226871D-03, 4.2598926D-06, 1.2212805D-06 /
      data fpp( 9,14, 4,1),fpp( 9,14, 4,2),fpp( 9,14, 4,3)/
     x-1.6329668D-03, 3.7531364D-06, 1.4547519D-06 /
      data fpp( 9,14, 5,1),fpp( 9,14, 5,2),fpp( 9,14, 5,3)/
     x 1.3659997D-03, 1.4162342D-06,-6.8495470D-07 /
      data fpp( 9,14, 6,1),fpp( 9,14, 6,2),fpp( 9,14, 6,3)/
     x 2.8628020D-03,-5.9500388D-07,-3.4009331D-06 /
      data fpp( 9,14, 7,1),fpp( 9,14, 7,2),fpp( 9,14, 7,3)/
     x 1.4984627D-04, 1.1557367D-06,-1.3531288D-07 /
      data fpp( 9,14, 8,1),fpp( 9,14, 8,2),fpp( 9,14, 8,3)/
     x-3.1462753D-03, 2.9291761D-06, 1.3908513D-06 /
      data fpp( 9,14, 9,1),fpp( 9,14, 9,2),fpp( 9,14, 9,3)/
     x-4.4072556D-03, 3.4382189D-06, 1.5952410D-06 /
      data fpp( 9,14,10,1),fpp( 9,14,10,2),fpp( 9,14,10,3)/
     x-3.1462753D-03, 2.9291761D-06, 1.3908513D-06 /
      data fpp( 9,14,11,1),fpp( 9,14,11,2),fpp( 9,14,11,3)/
     x 1.4984627D-04, 1.1557367D-06,-1.3531288D-07 /
      data fpp( 9,14,12,1),fpp( 9,14,12,2),fpp( 9,14,12,3)/
     x 2.8628020D-03,-5.9500388D-07,-3.4009331D-06 /
      data fpp( 9,14,13,1),fpp( 9,14,13,2),fpp( 9,14,13,3)/
     x 1.3659997D-03, 1.4162342D-06,-6.8495470D-07 /
      data fpp( 9,14,14,1),fpp( 9,14,14,2),fpp( 9,14,14,3)/
     x-1.6329668D-03, 3.7531364D-06, 1.4547519D-06 /
      data fpp( 9,14,15,1),fpp( 9,14,15,2),fpp( 9,14,15,3)/
     x-2.7226871D-03, 4.2598926D-06, 1.2212805D-06 /
      data fpp( 9,14,16,1),fpp( 9,14,16,2),fpp( 9,14,16,3)/
     x-1.6329668D-03, 3.7531364D-06, 1.0627929D-06 /
      data fpp( 9,14,17,1),fpp( 9,14,17,2),fpp( 9,14,17,3)/
     x 1.3659997D-03, 1.4162342D-06, 8.8288134D-07 /
      data fpp( 9,15, 1,1),fpp( 9,15, 1,2),fpp( 9,15, 1,3)/
     x 2.3311197D-03,-5.6963457D-07, 7.7683282D-07 /
      data fpp( 9,15, 2,1),fpp( 9,15, 2,2),fpp( 9,15, 2,3)/
     x-1.0947512D-03, 4.4149773D-06, 1.1196677D-06 /
      data fpp( 9,15, 3,1),fpp( 9,15, 3,2),fpp( 9,15, 3,3)/
     x-2.4526022D-03, 6.1013603D-06, 1.6164964D-06 /
      data fpp( 9,15, 4,1),fpp( 9,15, 4,2),fpp( 9,15, 4,3)/
     x-1.0947512D-03, 4.4149773D-06, 1.5743466D-06 /
      data fpp( 9,15, 5,1),fpp( 9,15, 5,2),fpp( 9,15, 5,3)/
     x 2.3311197D-03,-5.6963457D-07,-1.0418829D-06 /
      data fpp( 9,15, 6,1),fpp( 9,15, 6,2),fpp( 9,15, 6,3)/
     x 3.7605388D-03,-3.3162061D-06,-3.6721482D-06 /
      data fpp( 9,15, 7,1),fpp( 9,15, 7,2),fpp( 9,15, 7,3)/
     x 5.9712903D-04, 7.7976944D-07,-1.7352420D-07 /
      data fpp( 9,15, 8,1),fpp( 9,15, 8,2),fpp( 9,15, 8,3)/
     x-3.2982725D-03, 5.0838064D-06, 1.6235783D-06 /
      data fpp( 9,15, 9,1),fpp( 9,15, 9,2),fpp( 9,15, 9,3)/
     x-4.7869298D-03, 6.4672535D-06, 1.8385442D-06 /
      data fpp( 9,15,10,1),fpp( 9,15,10,2),fpp( 9,15,10,3)/
     x-3.2982725D-03, 5.0838064D-06, 1.6235783D-06 /
      data fpp( 9,15,11,1),fpp( 9,15,11,2),fpp( 9,15,11,3)/
     x 5.9712903D-04, 7.7976944D-07,-1.7352420D-07 /
      data fpp( 9,15,12,1),fpp( 9,15,12,2),fpp( 9,15,12,3)/
     x 3.7605388D-03,-3.3162061D-06,-3.6721482D-06 /
      data fpp( 9,15,13,1),fpp( 9,15,13,2),fpp( 9,15,13,3)/
     x 2.3311197D-03,-5.6963457D-07,-1.0418829D-06 /
      data fpp( 9,15,14,1),fpp( 9,15,14,2),fpp( 9,15,14,3)/
     x-1.0947512D-03, 4.4149773D-06, 1.5743466D-06 /
      data fpp( 9,15,15,1),fpp( 9,15,15,2),fpp( 9,15,15,3)/
     x-2.4526022D-03, 6.1013603D-06, 1.6164964D-06 /
      data fpp( 9,15,16,1),fpp( 9,15,16,2),fpp( 9,15,16,3)/
     x-1.0947512D-03, 4.4149773D-06, 1.1196677D-06 /
      data fpp( 9,15,17,1),fpp( 9,15,17,2),fpp( 9,15,17,3)/
     x 2.3311197D-03,-5.6963457D-07, 7.7683282D-07 /
      data fpp( 9,16, 1,1),fpp( 9,16, 1,2),fpp( 9,16, 1,3)/
     x 3.0434547D-03,-2.7796959D-06, 3.8779799D-07 /
      data fpp( 9,16, 2,1),fpp( 9,16, 2,2),fpp( 9,16, 2,3)/
     x 1.4635827D-04, 2.2149546D-06, 8.4851513D-07 /
      data fpp( 9,16, 3,1),fpp( 9,16, 3,2),fpp( 9,16, 3,3)/
     x-1.1570050D-03, 4.7486663D-06, 1.6641415D-06 /
      data fpp( 9,16, 4,1),fpp( 9,16, 4,2),fpp( 9,16, 4,3)/
     x 1.4635827D-04, 2.2149546D-06, 1.2375856D-06 /
      data fpp( 9,16, 5,1),fpp( 9,16, 5,2),fpp( 9,16, 5,3)/
     x 3.0434547D-03,-2.7796959D-06,-1.1684838D-06 /
      data fpp( 9,16, 6,1),fpp( 9,16, 6,2),fpp( 9,16, 6,3)/
     x 3.9446391D-03,-4.0561715D-06,-2.9643171D-06 /
      data fpp( 9,16, 7,1),fpp( 9,16, 7,2),fpp( 9,16, 7,3)/
     x 1.1102759D-03,-2.8144897D-09,-3.0691464D-07 /
      data fpp( 9,16, 8,1),fpp( 9,16, 8,2),fpp( 9,16, 8,3)/
     x-2.5783070D-03, 5.3555983D-06, 1.4979756D-06 /
      data fpp( 9,16, 9,1),fpp( 9,16, 9,2),fpp( 9,16, 9,3)/
     x-4.0526205D-03, 7.4487671D-06, 1.8090122D-06 /
      data fpp( 9,16,10,1),fpp( 9,16,10,2),fpp( 9,16,10,3)/
     x-2.5783070D-03, 5.3555983D-06, 1.4979756D-06 /
      data fpp( 9,16,11,1),fpp( 9,16,11,2),fpp( 9,16,11,3)/
     x 1.1102759D-03,-2.8144897D-09,-3.0691464D-07 /
      data fpp( 9,16,12,1),fpp( 9,16,12,2),fpp( 9,16,12,3)/
     x 3.9446391D-03,-4.0561715D-06,-2.9643171D-06 /
      data fpp( 9,16,13,1),fpp( 9,16,13,2),fpp( 9,16,13,3)/
     x 3.0434547D-03,-2.7796959D-06,-1.1684838D-06 /
      data fpp( 9,16,14,1),fpp( 9,16,14,2),fpp( 9,16,14,3)/
     x 1.4635827D-04, 2.2149546D-06, 1.2375856D-06 /
      data fpp( 9,16,15,1),fpp( 9,16,15,2),fpp( 9,16,15,3)/
     x-1.1570050D-03, 4.7486663D-06, 1.6641415D-06 /
      data fpp( 9,16,16,1),fpp( 9,16,16,2),fpp( 9,16,16,3)/
     x 1.4635827D-04, 2.2149546D-06, 8.4851513D-07 /
      data fpp( 9,16,17,1),fpp( 9,16,17,2),fpp( 9,16,17,3)/
     x 3.0434547D-03,-2.7796959D-06, 3.8779799D-07 /
      data fpp( 9,17, 1,1),fpp( 9,17, 1,2),fpp( 9,17, 1,3)/
     x 3.1767963D-03,-2.9215819D-06, 3.8195024D-09 /
      data fpp( 9,17, 2,1),fpp( 9,17, 2,2),fpp( 9,17, 2,3)/
     x 1.6335003D-03,-2.9187955D-06, 3.8358322D-07 /
      data fpp( 9,17, 3,1),fpp( 9,17, 3,2),fpp( 9,17, 3,3)/
     x 8.2506778D-04,-1.9720255D-06, 1.1265143D-06 /
      data fpp( 9,17, 4,1),fpp( 9,17, 4,2),fpp( 9,17, 4,3)/
     x 1.6335003D-03,-2.9187955D-06, 5.9835960D-07 /
      data fpp( 9,17, 5,1),fpp( 9,17, 5,2),fpp( 9,17, 5,3)/
     x 3.1767963D-03,-2.9215819D-06,-8.5528604D-07 /
      data fpp( 9,17, 6,1),fpp( 9,17, 6,2),fpp( 9,17, 6,3)/
     x 3.4434561D-03,-1.2911077D-06,-1.6305488D-06 /
      data fpp( 9,17, 7,1),fpp( 9,17, 7,2),fpp( 9,17, 7,3)/
     x 1.5584208D-03,-1.6251148D-07,-3.1051892D-07 /
      data fpp( 9,17, 8,1),fpp( 9,17, 8,2),fpp( 9,17, 8,3)/
     x-9.6065237D-04, 2.3058005D-06, 9.7929112D-07 /
      data fpp( 9,17, 9,1),fpp( 9,17, 9,2),fpp( 9,17, 9,3)/
     x-2.0385102D-03, 3.8776781D-06, 1.3466878D-06 /
      data fpp( 9,17,10,1),fpp( 9,17,10,2),fpp( 9,17,10,3)/
     x-9.6065237D-04, 2.3058005D-06, 9.7929112D-07 /
      data fpp( 9,17,11,1),fpp( 9,17,11,2),fpp( 9,17,11,3)/
     x 1.5584208D-03,-1.6251148D-07,-3.1051892D-07 /
      data fpp( 9,17,12,1),fpp( 9,17,12,2),fpp( 9,17,12,3)/
     x 3.4434561D-03,-1.2911077D-06,-1.6305488D-06 /
      data fpp( 9,17,13,1),fpp( 9,17,13,2),fpp( 9,17,13,3)/
     x 3.1767963D-03,-2.9215819D-06,-8.5528604D-07 /
      data fpp( 9,17,14,1),fpp( 9,17,14,2),fpp( 9,17,14,3)/
     x 1.6335003D-03,-2.9187955D-06, 5.9835960D-07 /
      data fpp( 9,17,15,1),fpp( 9,17,15,2),fpp( 9,17,15,3)/
     x 8.2506778D-04,-1.9720255D-06, 1.1265143D-06 /
      data fpp( 9,17,16,1),fpp( 9,17,16,2),fpp( 9,17,16,3)/
     x 1.6335003D-03,-2.9187955D-06, 3.8358322D-07 /
      data fpp( 9,17,17,1),fpp( 9,17,17,2),fpp( 9,17,17,3)/
     x 3.1767963D-03,-2.9215819D-06, 3.8195024D-09 /
      data fpp( 9,18, 1,1),fpp( 9,18, 1,2),fpp( 9,18, 1,3)/
     x 2.8664572D-03,-1.0259766D-06,-9.2309122D-08 /
      data fpp( 9,18, 2,1),fpp( 9,18, 2,2),fpp( 9,18, 2,3)/
     x 2.5557607D-03,-6.1157727D-06, 3.5729354D-08 /
      data fpp( 9,18, 3,1),fpp( 9,18, 3,2),fpp( 9,18, 3,3)/
     x 2.3629701D-03,-8.3265641D-06, 2.9872504D-07 /
      data fpp( 9,18, 4,1),fpp( 9,18, 4,2),fpp( 9,18, 4,3)/
     x 2.5557607D-03,-6.1157727D-06, 8.9370493D-08 /
      data fpp( 9,18, 5,1),fpp( 9,18, 5,2),fpp( 9,18, 5,3)/
     x 2.8664572D-03,-1.0259766D-06,-3.0687368D-07 /
      data fpp( 9,18, 6,1),fpp( 9,18, 6,2),fpp( 9,18, 6,3)/
     x 2.7006004D-03, 2.0746022D-06,-4.4987578D-07 /
      data fpp( 9,18, 7,1),fpp( 9,18, 7,2),fpp( 9,18, 7,3)/
     x 1.9353096D-03, 3.4686042D-07,-1.0428985D-07 /
      data fpp( 9,18, 8,1),fpp( 9,18, 8,2),fpp( 9,18, 8,3)/
     x 9.9231322D-04,-2.8188001D-06, 3.5503520D-07 /
      data fpp( 9,18, 9,1),fpp( 9,18, 9,2),fpp( 9,18, 9,3)/
     x 5.7466515D-04,-4.1134795D-06, 5.4348240D-07 /
      data fpp( 9,18,10,1),fpp( 9,18,10,2),fpp( 9,18,10,3)/
     x 9.9231322D-04,-2.8188001D-06, 3.5503520D-07 /
      data fpp( 9,18,11,1),fpp( 9,18,11,2),fpp( 9,18,11,3)/
     x 1.9353096D-03, 3.4686042D-07,-1.0428985D-07 /
      data fpp( 9,18,12,1),fpp( 9,18,12,2),fpp( 9,18,12,3)/
     x 2.7006004D-03, 2.0746022D-06,-4.4987578D-07 /
      data fpp( 9,18,13,1),fpp( 9,18,13,2),fpp( 9,18,13,3)/
     x 2.8664572D-03,-1.0259766D-06,-3.0687368D-07 /
      data fpp( 9,18,14,1),fpp( 9,18,14,2),fpp( 9,18,14,3)/
     x 2.5557607D-03,-6.1157727D-06, 8.9370493D-08 /
      data fpp( 9,18,15,1),fpp( 9,18,15,2),fpp( 9,18,15,3)/
     x 2.3629701D-03,-8.3265641D-06, 2.9872504D-07 /
      data fpp( 9,18,16,1),fpp( 9,18,16,2),fpp( 9,18,16,3)/
     x 2.5557607D-03,-6.1157727D-06, 3.5729354D-08 /
      data fpp( 9,18,17,1),fpp( 9,18,17,2),fpp( 9,18,17,3)/
     x 2.8664572D-03,-1.0259766D-06,-9.2309122D-08 /
      data fpp( 9,19, 1,1),fpp( 9,19, 1,2),fpp( 9,19, 1,3)/
     x 2.3511393D-03, 2.8748830D-07,-7.9073601D-23 /
      data fpp( 9,19, 2,1),fpp( 9,19, 2,2),fpp( 9,19, 2,3)/
     x 2.3511393D-03,-9.8661136D-06, 7.1136343D-22 /
      data fpp( 9,19, 3,1),fpp( 9,19, 3,2),fpp( 9,19, 3,3)/
     x 2.3511393D-03,-1.4785718D-05, 8.9734119D-23 /
      data fpp( 9,19, 4,1),fpp( 9,19, 4,2),fpp( 9,19, 4,3)/
     x 2.3511393D-03,-9.8661136D-06, 4.1657253D-23 /
      data fpp( 9,19, 5,1),fpp( 9,19, 5,2),fpp( 9,19, 5,3)/
     x 2.3511393D-03, 2.8748830D-07, 5.7289757D-23 /
      data fpp( 9,19, 6,1),fpp( 9,19, 6,2),fpp( 9,19, 6,3)/
     x 2.3511393D-03, 5.2686989D-06, 1.9808992D-22 /
      data fpp( 9,19, 7,1),fpp( 9,19, 7,2),fpp( 9,19, 7,3)/
     x 2.3511393D-03, 6.6506979D-07, 2.3095333D-22 /
      data fpp( 9,19, 8,1),fpp( 9,19, 8,2),fpp( 9,19, 8,3)/
     x 2.3511393D-03,-7.3505999D-06,-2.4941828D-22 /
      data fpp( 9,19, 9,1),fpp( 9,19, 9,2),fpp( 9,19, 9,3)/
     x 2.3511393D-03,-1.0841760D-05,-2.0315387D-22 /
      data fpp( 9,19,10,1),fpp( 9,19,10,2),fpp( 9,19,10,3)/
     x 2.3511393D-03,-7.3505999D-06, 3.2082872D-22 /
      data fpp( 9,19,11,1),fpp( 9,19,11,2),fpp( 9,19,11,3)/
     x 2.3511393D-03, 6.6506979D-07,-2.7800991D-22 /
      data fpp( 9,19,12,1),fpp( 9,19,12,2),fpp( 9,19,12,3)/
     x 2.3511393D-03, 5.2686989D-06, 2.6898212D-23 /
      data fpp( 9,19,13,1),fpp( 9,19,13,2),fpp( 9,19,13,3)/
     x 2.3511393D-03, 2.8748830D-07,-4.9134351D-23 /
      data fpp( 9,19,14,1),fpp( 9,19,14,2),fpp( 9,19,14,3)/
     x 2.3511393D-03,-9.8661136D-06,-1.4949644D-22 /
      data fpp( 9,19,15,1),fpp( 9,19,15,2),fpp( 9,19,15,3)/
     x 2.3511393D-03,-1.4785718D-05,-1.4045991D-22 /
      data fpp( 9,19,16,1),fpp( 9,19,16,2),fpp( 9,19,16,3)/
     x 2.3511393D-03,-9.8661136D-06,-1.2010335D-22 /
      data fpp( 9,19,17,1),fpp( 9,19,17,2),fpp( 9,19,17,3)/
     x 2.3511393D-03, 2.8748830D-07, 2.1441879D-22 /
      data fpp(10, 1, 1,1),fpp(10, 1, 1,2),fpp(10, 1, 1,3)/
     x 2.1589884D-04, 1.1197392D-07, 3.0507830D-22 /
      data fpp(10, 1, 2,1),fpp(10, 1, 2,2),fpp(10, 1, 2,3)/
     x 2.1589884D-04,-4.9861463D-07,-3.3457759D-22 /
      data fpp(10, 1, 3,1),fpp(10, 1, 3,2),fpp(10, 1, 3,3)/
     x 2.1589884D-04,-7.9288695D-07,-1.2281186D-22 /
      data fpp(10, 1, 4,1),fpp(10, 1, 4,2),fpp(10, 1, 4,3)/
     x 2.1589884D-04,-4.9861463D-07,-5.6149456D-23 /
      data fpp(10, 1, 5,1),fpp(10, 1, 5,2),fpp(10, 1, 5,3)/
     x 2.1589884D-04, 1.1197392D-07,-4.0843847D-23 /
      data fpp(10, 1, 6,1),fpp(10, 1, 6,2),fpp(10, 1, 6,3)/
     x 2.1589884D-04, 3.8290527D-07,-6.6864025D-23 /
      data fpp(10, 1, 7,1),fpp(10, 1, 7,2),fpp(10, 1, 7,3)/
     x 2.1589884D-04, 1.5700398D-07,-1.1494465D-22 /
      data fpp(10, 1, 8,1),fpp(10, 1, 8,2),fpp(10, 1, 8,3)/
     x 2.1589884D-04,-2.7687130D-07, 2.2332000D-22 /
      data fpp(10, 1, 9,1),fpp(10, 1, 9,2),fpp(10, 1, 9,3)/
     x 2.1589884D-04,-4.7146808D-07, 2.5715636D-23 /
      data fpp(10, 1,10,1),fpp(10, 1,10,2),fpp(10, 1,10,3)/
     x 2.1589884D-04,-2.7687130D-07,-9.6941135D-23 /
      data fpp(10, 1,11,1),fpp(10, 1,11,2),fpp(10, 1,11,3)/
     x 2.1589884D-04, 1.5700398D-07, 6.7740608D-23 /
      data fpp(10, 1,12,1),fpp(10, 1,12,2),fpp(10, 1,12,3)/
     x 2.1589884D-04, 3.8290527D-07,-3.8248784D-23 /
      data fpp(10, 1,13,1),fpp(10, 1,13,2),fpp(10, 1,13,3)/
     x 2.1589884D-04, 1.1197392D-07,-4.7473319D-23 /
      data fpp(10, 1,14,1),fpp(10, 1,14,2),fpp(10, 1,14,3)/
     x 2.1589884D-04,-4.9861463D-07, 5.5675324D-23 /
      data fpp(10, 1,15,1),fpp(10, 1,15,2),fpp(10, 1,15,3)/
     x 2.1589884D-04,-7.9288695D-07,-4.0122094D-23 /
      data fpp(10, 1,16,1),fpp(10, 1,16,2),fpp(10, 1,16,3)/
     x 2.1589884D-04,-4.9861463D-07,-8.7821722D-23 /
      data fpp(10, 1,17,1),fpp(10, 1,17,2),fpp(10, 1,17,3)/
     x 2.1589884D-04, 1.1197392D-07, 1.0208290D-22 /
      data fpp(10, 2, 1,1),fpp(10, 2, 1,2),fpp(10, 2, 1,3)/
     x 2.0832518D-04, 6.4052164D-08, 2.7432124D-09 /
      data fpp(10, 2, 2,1),fpp(10, 2, 2,2),fpp(10, 2, 2,3)/
     x 1.6705225D-04,-2.1977075D-07, 1.3291353D-08 /
      data fpp(10, 2, 3,1),fpp(10, 2, 3,2),fpp(10, 2, 3,3)/
     x 1.4769079D-04,-4.1122610D-07, 3.5424709D-08 /
      data fpp(10, 2, 4,1),fpp(10, 2, 4,2),fpp(10, 2, 4,3)/
     x 1.6705225D-04,-2.1977075D-07, 1.7009812D-08 /
      data fpp(10, 2, 5,1),fpp(10, 2, 5,2),fpp(10, 2, 5,3)/
     x 2.0832518D-04, 6.4052164D-08,-1.2130622D-08 /
      data fpp(10, 2, 6,1),fpp(10, 2, 6,2),fpp(10, 2, 6,3)/
     x 2.3932926D-04, 1.5318947D-07,-2.3153991D-08 /
      data fpp(10, 2, 7,1),fpp(10, 2, 7,2),fpp(10, 2, 7,3)/
     x 2.4217917D-04, 3.4992049D-08,-1.2586746D-08 /
      data fpp(10, 2, 8,1),fpp(10, 2, 8,2),fpp(10, 2, 8,3)/
     x 2.2532299D-04,-1.3625740D-07, 6.1676417D-09 /
      data fpp(10, 2, 9,1),fpp(10, 2, 9,2),fpp(10, 2, 9,3)/
     x 2.1503568D-04,-2.1706383D-07, 1.4582846D-08 /
      data fpp(10, 2,10,1),fpp(10, 2,10,2),fpp(10, 2,10,3)/
     x 2.2532299D-04,-1.3625740D-07, 6.1676417D-09 /
      data fpp(10, 2,11,1),fpp(10, 2,11,2),fpp(10, 2,11,3)/
     x 2.4217917D-04, 3.4992049D-08,-1.2586746D-08 /
      data fpp(10, 2,12,1),fpp(10, 2,12,2),fpp(10, 2,12,3)/
     x 2.3932926D-04, 1.5318947D-07,-2.3153991D-08 /
      data fpp(10, 2,13,1),fpp(10, 2,13,2),fpp(10, 2,13,3)/
     x 2.0832518D-04, 6.4052164D-08,-1.2130622D-08 /
      data fpp(10, 2,14,1),fpp(10, 2,14,2),fpp(10, 2,14,3)/
     x 1.6705225D-04,-2.1977075D-07, 1.7009812D-08 /
      data fpp(10, 2,15,1),fpp(10, 2,15,2),fpp(10, 2,15,3)/
     x 1.4769079D-04,-4.1122610D-07, 3.5424709D-08 /
      data fpp(10, 2,16,1),fpp(10, 2,16,2),fpp(10, 2,16,3)/
     x 1.6705225D-04,-2.1977075D-07, 1.3291353D-08 /
      data fpp(10, 2,17,1),fpp(10, 2,17,2),fpp(10, 2,17,3)/
     x 2.0832518D-04, 6.4052164D-08, 2.7432124D-09 /
      data fpp(10, 3, 1,1),fpp(10, 3, 1,2),fpp(10, 3, 1,3)/
     x 2.0352727D-04,-8.1825751D-09,-1.5958112D-08 /
      data fpp(10, 3, 2,1),fpp(10, 3, 2,2),fpp(10, 3, 2,3)/
     x 8.0392191D-05,-8.3023837D-09, 3.1138446D-08 /
      data fpp(10, 3, 3,1),fpp(10, 3, 3,2),fpp(10, 3, 3,3)/
     x 1.5874306D-05,-1.4820864D-07, 1.3473766D-07 /
      data fpp(10, 3, 4,1),fpp(10, 3, 4,2),fpp(10, 3, 4,3)/
     x 8.0392191D-05,-8.3023837D-09, 4.0577572D-08 /
      data fpp(10, 3, 5,1),fpp(10, 3, 5,2),fpp(10, 3, 5,3)/
     x 2.0352727D-04,-8.1825751D-09,-5.3714616D-08 /
      data fpp(10, 3, 6,1),fpp(10, 3, 6,2),fpp(10, 3, 6,3)/
     x 2.8640199D-04,-1.1366314D-07,-7.1052440D-08 /
      data fpp(10, 3, 7,1),fpp(10, 3, 7,2),fpp(10, 3, 7,3)/
     x 2.8238142D-04,-9.8972171D-08,-3.0742292D-08 /
      data fpp(10, 3, 8,1),fpp(10, 3, 8,2),fpp(10, 3, 8,3)/
     x 2.1380395D-04, 1.7900911D-08, 2.4021607D-08 /
      data fpp(10, 3, 9,1),fpp(10, 3, 9,2),fpp(10, 3, 9,3)/
     x 1.7344853D-04, 7.9723407D-08, 4.8655863D-08 /
      data fpp(10, 3,10,1),fpp(10, 3,10,2),fpp(10, 3,10,3)/
     x 2.1380395D-04, 1.7900911D-08, 2.4021607D-08 /
      data fpp(10, 3,11,1),fpp(10, 3,11,2),fpp(10, 3,11,3)/
     x 2.8238142D-04,-9.8972171D-08,-3.0742292D-08 /
      data fpp(10, 3,12,1),fpp(10, 3,12,2),fpp(10, 3,12,3)/
     x 2.8640199D-04,-1.1366314D-07,-7.1052440D-08 /
      data fpp(10, 3,13,1),fpp(10, 3,13,2),fpp(10, 3,13,3)/
     x 2.0352727D-04,-8.1825751D-09,-5.3714616D-08 /
      data fpp(10, 3,14,1),fpp(10, 3,14,2),fpp(10, 3,14,3)/
     x 8.0392191D-05,-8.3023837D-09, 4.0577572D-08 /
      data fpp(10, 3,15,1),fpp(10, 3,15,2),fpp(10, 3,15,3)/
     x 1.5874306D-05,-1.4820864D-07, 1.3473766D-07 /
      data fpp(10, 3,16,1),fpp(10, 3,16,2),fpp(10, 3,16,3)/
     x 8.0392191D-05,-8.3023837D-09, 3.1138446D-08 /
      data fpp(10, 3,17,1),fpp(10, 3,17,2),fpp(10, 3,17,3)/
     x 2.0352727D-04,-8.1825751D-09,-1.5958112D-08 /
      data fpp(10, 4, 1,1),fpp(10, 4, 1,2),fpp(10, 4, 1,3)/
     x 1.8018874D-04, 4.6781361D-09,-8.5365373D-08 /
      data fpp(10, 4, 2,1),fpp(10, 4, 2,2),fpp(10, 4, 2,3)/
     x-1.4640215D-05, 4.3898028D-07, 2.6508523D-08 /
      data fpp(10, 4, 3,1),fpp(10, 4, 3,2),fpp(10, 4, 3,3)/
     x-1.3532796D-04, 5.3006065D-07, 2.8466461D-07 /
      data fpp(10, 4, 4,1),fpp(10, 4, 4,2),fpp(10, 4, 4,3)/
     x-1.4640215D-05, 4.3898028D-07, 3.0833020D-08 /
      data fpp(10, 4, 5,1),fpp(10, 4, 5,2),fpp(10, 4, 5,3)/
     x 1.8018874D-04, 4.6781361D-09,-1.0266336D-07 /
      data fpp(10, 4, 6,1),fpp(10, 4, 6,2),fpp(10, 4, 6,3)/
     x 3.0218395D-04,-2.5053692D-07,-1.0484625D-07 /
      data fpp(10, 4, 7,1),fpp(10, 4, 7,2),fpp(10, 4, 7,3)/
     x 3.0032355D-04,-1.9110336D-07,-3.2618318D-08 /
      data fpp(10, 4, 8,1),fpp(10, 4, 8,2),fpp(10, 4, 8,3)/
     x 1.9007359D-04, 1.2465376D-07, 3.0652853D-08 /
      data fpp(10, 4, 9,1),fpp(10, 4, 9,2),fpp(10, 4, 9,3)/
     x 1.2184036D-04, 2.2817020D-07, 7.3340240D-08 /
      data fpp(10, 4,10,1),fpp(10, 4,10,2),fpp(10, 4,10,3)/
     x 1.9007359D-04, 1.2465376D-07, 3.0652853D-08 /
      data fpp(10, 4,11,1),fpp(10, 4,11,2),fpp(10, 4,11,3)/
     x 3.0032355D-04,-1.9110336D-07,-3.2618318D-08 /
      data fpp(10, 4,12,1),fpp(10, 4,12,2),fpp(10, 4,12,3)/
     x 3.0218395D-04,-2.5053692D-07,-1.0484625D-07 /
      data fpp(10, 4,13,1),fpp(10, 4,13,2),fpp(10, 4,13,3)/
     x 1.8018874D-04, 4.6781361D-09,-1.0266336D-07 /
      data fpp(10, 4,14,1),fpp(10, 4,14,2),fpp(10, 4,14,3)/
     x-1.4640215D-05, 4.3898028D-07, 3.0833020D-08 /
      data fpp(10, 4,15,1),fpp(10, 4,15,2),fpp(10, 4,15,3)/
     x-1.3532796D-04, 5.3006065D-07, 2.8466461D-07 /
      data fpp(10, 4,16,1),fpp(10, 4,16,2),fpp(10, 4,16,3)/
     x-1.4640215D-05, 4.3898028D-07, 2.6508523D-08 /
      data fpp(10, 4,17,1),fpp(10, 4,17,2),fpp(10, 4,17,3)/
     x 1.8018874D-04, 4.6781361D-09,-8.5365373D-08 /
      data fpp(10, 5, 1,1),fpp(10, 5, 1,2),fpp(10, 5, 1,3)/
     x 1.3202551D-04, 3.7470031D-08,-1.9330599D-07 /
      data fpp(10, 5, 2,1),fpp(10, 5, 2,2),fpp(10, 5, 2,3)/
     x-7.5054823D-05, 5.9238126D-07,-1.2276905D-08 /
      data fpp(10, 5, 3,1),fpp(10, 5, 3,2),fpp(10, 5, 3,3)/
     x-2.3657878D-04, 9.7396604D-07, 4.2241361D-07 /
      data fpp(10, 5, 4,1),fpp(10, 5, 4,2),fpp(10, 5, 4,3)/
     x-7.5054823D-05, 5.9238126D-07,-3.0710877D-08 /
      data fpp(10, 5, 5,1),fpp(10, 5, 5,2),fpp(10, 5, 5,3)/
     x 1.3202551D-04, 3.7470031D-08,-1.1957011D-07 /
      data fpp(10, 5, 6,1),fpp(10, 5, 6,2),fpp(10, 5, 6,3)/
     x 2.5403159D-04,-1.7418919D-07,-1.0900870D-07 /
      data fpp(10, 5, 7,1),fpp(10, 5, 7,2),fpp(10, 5, 7,3)/
     x 2.6407767D-04,-8.4614371D-08, 1.6049065D-09 /
      data fpp(10, 5, 8,1),fpp(10, 5, 8,2),fpp(10, 5, 8,3)/
     x 1.5251748D-04, 1.3148405D-07, 2.5890743D-09 /
      data fpp(10, 5, 9,1),fpp(10, 5, 9,2),fpp(10, 5, 9,3)/
     x 7.7311880D-05, 2.0759578D-07, 8.4705463D-08 /
      data fpp(10, 5,10,1),fpp(10, 5,10,2),fpp(10, 5,10,3)/
     x 1.5251748D-04, 1.3148405D-07, 2.5890743D-09 /
      data fpp(10, 5,11,1),fpp(10, 5,11,2),fpp(10, 5,11,3)/
     x 2.6407767D-04,-8.4614371D-08, 1.6049065D-09 /
      data fpp(10, 5,12,1),fpp(10, 5,12,2),fpp(10, 5,12,3)/
     x 2.5403159D-04,-1.7418919D-07,-1.0900870D-07 /
      data fpp(10, 5,13,1),fpp(10, 5,13,2),fpp(10, 5,13,3)/
     x 1.3202551D-04, 3.7470031D-08,-1.1957011D-07 /
      data fpp(10, 5,14,1),fpp(10, 5,14,2),fpp(10, 5,14,3)/
     x-7.5054823D-05, 5.9238126D-07,-3.0710877D-08 /
      data fpp(10, 5,15,1),fpp(10, 5,15,2),fpp(10, 5,15,3)/
     x-2.3657878D-04, 9.7396604D-07, 4.2241361D-07 /
      data fpp(10, 5,16,1),fpp(10, 5,16,2),fpp(10, 5,16,3)/
     x-7.5054823D-05, 5.9238126D-07,-1.2276905D-08 /
      data fpp(10, 5,17,1),fpp(10, 5,17,2),fpp(10, 5,17,3)/
     x 1.3202551D-04, 3.7470031D-08,-1.9330599D-07 /
      data fpp(10, 6, 1,1),fpp(10, 6, 1,2),fpp(10, 6, 1,3)/
     x 6.4291727D-05, 4.3441742D-08,-2.6365296D-07 /
      data fpp(10, 6, 2,1),fpp(10, 6, 2,2),fpp(10, 6, 2,3)/
     x-7.2104421D-05, 3.1149470D-07,-5.7805201D-08 /
      data fpp(10, 6, 3,1),fpp(10, 6, 3,2),fpp(10, 6, 3,3)/
     x-2.2131123D-04, 7.2807519D-07, 4.5087376D-07 /
      data fpp(10, 6, 4,1),fpp(10, 6, 4,2),fpp(10, 6, 4,3)/
     x-7.2104421D-05, 3.1149470D-07,-1.0035650D-07 /
      data fpp(10, 6, 5,1),fpp(10, 6, 5,2),fpp(10, 6, 5,3)/
     x 6.4291727D-05, 4.3441742D-08,-9.3447751D-08 /
      data fpp(10, 6, 6,1),fpp(10, 6, 6,2),fpp(10, 6, 6,3)/
     x 1.6366866D-04,-6.7063184D-09,-8.0519159D-08 /
      data fpp(10, 6, 7,1),fpp(10, 6, 7,2),fpp(10, 6, 7,3)/
     x 1.9060583D-04, 1.0356085D-07, 4.8857722D-08 /
      data fpp(10, 6, 8,1),fpp(10, 6, 8,2),fpp(10, 6, 8,3)/
     x 1.1208712D-04, 3.9410029D-08,-4.4911730D-08 /
      data fpp(10, 6, 9,1),fpp(10, 6, 9,2),fpp(10, 6, 9,3)/
     x 4.6271196D-05, 4.5446683D-08, 8.2789198D-08 /
      data fpp(10, 6,10,1),fpp(10, 6,10,2),fpp(10, 6,10,3)/
     x 1.1208712D-04, 3.9410029D-08,-4.4911730D-08 /
      data fpp(10, 6,11,1),fpp(10, 6,11,2),fpp(10, 6,11,3)/
     x 1.9060583D-04, 1.0356085D-07, 4.8857722D-08 /
      data fpp(10, 6,12,1),fpp(10, 6,12,2),fpp(10, 6,12,3)/
     x 1.6366866D-04,-6.7063184D-09,-8.0519159D-08 /
      data fpp(10, 6,13,1),fpp(10, 6,13,2),fpp(10, 6,13,3)/
     x 6.4291727D-05, 4.3441742D-08,-9.3447751D-08 /
      data fpp(10, 6,14,1),fpp(10, 6,14,2),fpp(10, 6,14,3)/
     x-7.2104421D-05, 3.1149470D-07,-1.0035650D-07 /
      data fpp(10, 6,15,1),fpp(10, 6,15,2),fpp(10, 6,15,3)/
     x-2.2131123D-04, 7.2807519D-07, 4.5087376D-07 /
      data fpp(10, 6,16,1),fpp(10, 6,16,2),fpp(10, 6,16,3)/
     x-7.2104421D-05, 3.1149470D-07,-5.7805201D-08 /
      data fpp(10, 6,17,1),fpp(10, 6,17,2),fpp(10, 6,17,3)/
     x 6.4291727D-05, 4.3441742D-08,-2.6365296D-07 /
      data fpp(10, 7, 1,1),fpp(10, 7, 1,2),fpp(10, 7, 1,3)/
     x 2.1741079D-05, 1.0763003D-08,-2.3316477D-07 /
      data fpp(10, 7, 2,1),fpp(10, 7, 2,2),fpp(10, 7, 2,3)/
     x-2.6325575D-05,-1.0436005D-07,-7.2003784D-08 /
      data fpp(10, 7, 3,1),fpp(10, 7, 3,2),fpp(10, 7, 3,3)/
     x-1.0546857D-04, 8.5733216D-08, 3.3384658D-07 /
      data fpp(10, 7, 4,1),fpp(10, 7, 4,2),fpp(10, 7, 4,3)/
     x-2.6325575D-05,-1.0436005D-07,-1.1671586D-07 /
      data fpp(10, 7, 5,1),fpp(10, 7, 5,2),fpp(10, 7, 5,3)/
     x 2.1741079D-05, 1.0763003D-08,-5.4316468D-08 /
      data fpp(10, 7, 6,1),fpp(10, 7, 6,2),fpp(10, 7, 6,3)/
     x 7.1724623D-05, 1.3501446D-07,-2.1351600D-08 /
      data fpp(10, 7, 7,1),fpp(10, 7, 7,2),fpp(10, 7, 7,3)/
     x 1.1814884D-04, 1.9237097D-07, 5.7722867D-08 /
      data fpp(10, 7, 8,1),fpp(10, 7, 8,2),fpp(10, 7, 8,3)/
     x 7.5749177D-05,-7.9124169D-08,-6.9539867D-08 /
      data fpp(10, 7, 9,1),fpp(10, 7, 9,2),fpp(10, 7, 9,3)/
     x 2.2825222D-05,-1.3738251D-07, 6.7103267D-08 /
      data fpp(10, 7,10,1),fpp(10, 7,10,2),fpp(10, 7,10,3)/
     x 7.5749177D-05,-7.9124169D-08,-6.9539867D-08 /
      data fpp(10, 7,11,1),fpp(10, 7,11,2),fpp(10, 7,11,3)/
     x 1.1814884D-04, 1.9237097D-07, 5.7722867D-08 /
      data fpp(10, 7,12,1),fpp(10, 7,12,2),fpp(10, 7,12,3)/
     x 7.1724623D-05, 1.3501446D-07,-2.1351600D-08 /
      data fpp(10, 7,13,1),fpp(10, 7,13,2),fpp(10, 7,13,3)/
     x 2.1741079D-05, 1.0763003D-08,-5.4316468D-08 /
      data fpp(10, 7,14,1),fpp(10, 7,14,2),fpp(10, 7,14,3)/
     x-2.6325575D-05,-1.0436005D-07,-1.1671586D-07 /
      data fpp(10, 7,15,1),fpp(10, 7,15,2),fpp(10, 7,15,3)/
     x-1.0546857D-04, 8.5733216D-08, 3.3384658D-07 /
      data fpp(10, 7,16,1),fpp(10, 7,16,2),fpp(10, 7,16,3)/
     x-2.6325575D-05,-1.0436005D-07,-7.2003784D-08 /
      data fpp(10, 7,17,1),fpp(10, 7,17,2),fpp(10, 7,17,3)/
     x 2.1741079D-05, 1.0763003D-08,-2.3316477D-07 /
      data fpp(10, 8, 1,1),fpp(10, 8, 1,2),fpp(10, 8, 1,3)/
     x-1.7867036D-05,-6.8493755D-08,-1.2159398D-07 /
      data fpp(10, 8, 2,1),fpp(10, 8, 2,2),fpp(10, 8, 2,3)/
     x 9.5667376D-06,-3.6805451D-07,-4.7812040D-08 /
      data fpp(10, 8, 3,1),fpp(10, 8, 3,2),fpp(10, 8, 3,3)/
     x-3.9810631D-07,-6.1500805D-07, 1.4017547D-07 /
      data fpp(10, 8, 4,1),fpp(10, 8, 4,2),fpp(10, 8, 4,3)/
     x 9.5667376D-06,-3.6805451D-07,-7.1556517D-08 /
      data fpp(10, 8, 5,1),fpp(10, 8, 5,2),fpp(10, 8, 5,3)/
     x-1.7867036D-05,-6.8493755D-08,-2.6616071D-08 /
      data fpp(10, 8, 6,1),fpp(10, 8, 6,2),fpp(10, 8, 6,3)/
     x 4.0631524D-06, 1.4464846D-07, 4.0687469D-08 /
      data fpp(10, 8, 7,1),fpp(10, 8, 7,2),fpp(10, 8, 7,3)/
     x 5.4627324D-05,-9.0447372D-09, 1.3866194D-08 /
      data fpp(10, 8, 8,1),fpp(10, 8, 8,2),fpp(10, 8, 8,3)/
     x 3.4364880D-05,-1.7891335D-07,-5.3485579D-08 /
      data fpp(10, 8, 9,1),fpp(10, 8, 9,2),fpp(10, 8, 9,3)/
     x-1.0656841D-05,-2.9391665D-07, 5.0076123D-08 /
      data fpp(10, 8,10,1),fpp(10, 8,10,2),fpp(10, 8,10,3)/
     x 3.4364880D-05,-1.7891335D-07,-5.3485579D-08 /
      data fpp(10, 8,11,1),fpp(10, 8,11,2),fpp(10, 8,11,3)/
     x 5.4627324D-05,-9.0447372D-09, 1.3866194D-08 /
      data fpp(10, 8,12,1),fpp(10, 8,12,2),fpp(10, 8,12,3)/
     x 4.0631524D-06, 1.4464846D-07, 4.0687469D-08 /
      data fpp(10, 8,13,1),fpp(10, 8,13,2),fpp(10, 8,13,3)/
     x-1.7867036D-05,-6.8493755D-08,-2.6616071D-08 /
      data fpp(10, 8,14,1),fpp(10, 8,14,2),fpp(10, 8,14,3)/
     x 9.5667376D-06,-3.6805451D-07,-7.1556517D-08 /
      data fpp(10, 8,15,1),fpp(10, 8,15,2),fpp(10, 8,15,3)/
     x-3.9810631D-07,-6.1500805D-07, 1.4017547D-07 /
      data fpp(10, 8,16,1),fpp(10, 8,16,2),fpp(10, 8,16,3)/
     x 9.5667376D-06,-3.6805451D-07,-4.7812040D-08 /
      data fpp(10, 8,17,1),fpp(10, 8,17,2),fpp(10, 8,17,3)/
     x-1.7867036D-05,-6.8493755D-08,-1.2159398D-07 /
      data fpp(10, 9, 1,1),fpp(10, 9, 1,2),fpp(10, 9, 1,3)/
     x-4.7473860D-05,-1.4478798D-07,-2.7728042D-08 /
      data fpp(10, 9, 2,1),fpp(10, 9, 2,2),fpp(10, 9, 2,3)/
     x-4.2287719D-06,-4.8742190D-07,-1.8877250D-08 /
      data fpp(10, 9, 3,1),fpp(10, 9, 3,2),fpp(10, 9, 3,3)/
     x 1.9853307D-05,-7.9370102D-07, 6.5703751D-09 /
      data fpp(10, 9, 4,1),fpp(10, 9, 4,2),fpp(10, 9, 4,3)/
     x-4.2287719D-06,-4.8742190D-07,-2.6070917D-08 /
      data fpp(10, 9, 5,1),fpp(10, 9, 5,2),fpp(10, 9, 5,3)/
     x-4.7473860D-05,-1.4478798D-07, 1.0466270D-09 /
      data fpp(10, 9, 6,1),fpp(10, 9, 6,2),fpp(10, 9, 6,3)/
     x-3.2405463D-05, 4.8391693D-08, 4.8551076D-08 /
      data fpp(10, 9, 7,1),fpp(10, 9, 7,2),fpp(10, 9, 7,3)/
     x 2.1821933D-06,-1.5619202D-07,-2.7917597D-08 /
      data fpp(10, 9, 8,1),fpp(10, 9, 8,2),fpp(10, 9, 8,3)/
     x-2.9827936D-05,-3.2122242D-07,-3.0880686D-08 /
      data fpp(10, 9, 9,1),fpp(10, 9, 9,2),fpp(10, 9, 9,3)/
     x-7.4434431D-05,-3.9695091D-07, 6.2773677D-08 /
      data fpp(10, 9,10,1),fpp(10, 9,10,2),fpp(10, 9,10,3)/
     x-2.9827936D-05,-3.2122242D-07,-3.0880686D-08 /
      data fpp(10, 9,11,1),fpp(10, 9,11,2),fpp(10, 9,11,3)/
     x 2.1821933D-06,-1.5619202D-07,-2.7917597D-08 /
      data fpp(10, 9,12,1),fpp(10, 9,12,2),fpp(10, 9,12,3)/
     x-3.2405463D-05, 4.8391693D-08, 4.8551076D-08 /
      data fpp(10, 9,13,1),fpp(10, 9,13,2),fpp(10, 9,13,3)/
     x-4.7473860D-05,-1.4478798D-07, 1.0466270D-09 /
      data fpp(10, 9,14,1),fpp(10, 9,14,2),fpp(10, 9,14,3)/
     x-4.2287719D-06,-4.8742190D-07,-2.6070917D-08 /
      data fpp(10, 9,15,1),fpp(10, 9,15,2),fpp(10, 9,15,3)/
     x 1.9853307D-05,-7.9370102D-07, 6.5703751D-09 /
      data fpp(10, 9,16,1),fpp(10, 9,16,2),fpp(10, 9,16,3)/
     x-4.2287719D-06,-4.8742190D-07,-1.8877250D-08 /
      data fpp(10, 9,17,1),fpp(10, 9,17,2),fpp(10, 9,17,3)/
     x-4.7473860D-05,-1.4478798D-07,-2.7728042D-08 /
      data fpp(10,10, 1,1),fpp(10,10, 1,2),fpp(10,10, 1,3)/
     x-7.1663113D-05,-1.2635431D-07, 2.1851064D-08 /
      data fpp(10,10, 2,1),fpp(10,10, 2,2),fpp(10,10, 2,3)/
     x-7.2569037D-05,-4.6025789D-07, 6.1867602D-09 /
      data fpp(10,10, 3,1),fpp(10,10, 3,2),fpp(10,10, 3,3)/
     x-5.3201160D-05,-6.5618787D-07,-2.9931439D-08 /
      data fpp(10,10, 4,1),fpp(10,10, 4,2),fpp(10,10, 4,3)/
     x-7.2569037D-05,-4.6025789D-07, 5.5389939D-09 /
      data fpp(10,10, 5,1),fpp(10,10, 5,2),fpp(10,10, 5,3)/
     x-7.1663113D-05,-1.2635431D-07, 2.4442130D-08 /
      data fpp(10,10, 6,1),fpp(10,10, 6,2),fpp(10,10, 6,3)/
     x-3.5568745D-05, 9.7847659D-09,-1.0640846D-08 /
      data fpp(10,10, 7,1),fpp(10,10, 7,2),fpp(10,10, 7,3)/
     x-4.3140975D-05,-1.8218717D-07,-5.1212080D-08 /
      data fpp(10,10, 8,1),fpp(10,10, 8,2),fpp(10,10, 8,3)/
     x-1.2762224D-04,-4.0819697D-07,-3.1775010D-09 /
      data fpp(10,10, 9,1),fpp(10,10, 9,2),fpp(10,10, 9,3)/
     x-1.8662299D-04,-4.7627972D-07, 9.9922084D-08 /
      data fpp(10,10,10,1),fpp(10,10,10,2),fpp(10,10,10,3)/
     x-1.2762224D-04,-4.0819697D-07,-3.1775010D-09 /
      data fpp(10,10,11,1),fpp(10,10,11,2),fpp(10,10,11,3)/
     x-4.3140975D-05,-1.8218717D-07,-5.1212080D-08 /
      data fpp(10,10,12,1),fpp(10,10,12,2),fpp(10,10,12,3)/
     x-3.5568745D-05, 9.7847659D-09,-1.0640846D-08 /
      data fpp(10,10,13,1),fpp(10,10,13,2),fpp(10,10,13,3)/
     x-7.1663113D-05,-1.2635431D-07, 2.4442130D-08 /
      data fpp(10,10,14,1),fpp(10,10,14,2),fpp(10,10,14,3)/
     x-7.2569037D-05,-4.6025789D-07, 5.5389939D-09 /
      data fpp(10,10,15,1),fpp(10,10,15,2),fpp(10,10,15,3)/
     x-5.3201160D-05,-6.5618787D-07,-2.9931439D-08 /
      data fpp(10,10,16,1),fpp(10,10,16,2),fpp(10,10,16,3)/
     x-7.2569037D-05,-4.6025789D-07, 6.1867602D-09 /
      data fpp(10,10,17,1),fpp(10,10,17,2),fpp(10,10,17,3)/
     x-7.1663113D-05,-1.2635431D-07, 2.1851064D-08 /
      data fpp(10,11, 1,1),fpp(10,11, 1,2),fpp(10,11, 1,3)/
     x-8.8509150D-05,-2.1794791D-08, 5.7063407D-08 /
      data fpp(10,11, 2,1),fpp(10,11, 2,2),fpp(10,11, 2,3)/
     x-1.8452396D-04,-3.3554655D-07, 4.0428742D-08 /
      data fpp(10,11, 3,1),fpp(10,11, 3,2),fpp(10,11, 3,3)/
     x-2.0121384D-04,-4.6954752D-07,-3.4450410D-09 /
      data fpp(10,11, 4,1),fpp(10,11, 4,2),fpp(10,11, 4,3)/
     x-1.8452396D-04,-3.3554655D-07, 4.8018089D-08 /
      data fpp(10,11, 5,1),fpp(10,11, 5,2),fpp(10,11, 5,3)/
     x-8.8509150D-05,-2.1794791D-08, 2.6706019D-08 /
      data fpp(10,11, 6,1),fpp(10,11, 6,2),fpp(10,11, 6,3)/
     x-6.9396200D-08, 9.2469243D-08,-1.2284216D-07 /
      data fpp(10,11, 7,1),fpp(10,11, 7,2),fpp(10,11, 7,3)/
     x-8.5261227D-05,-1.4105929D-07,-7.0004033D-08 /
      data fpp(10,11, 8,1),fpp(10,11, 8,2),fpp(10,11, 8,3)/
     x-2.6539414D-04,-4.0398971D-07, 4.5524962D-08 /
      data fpp(10,11, 9,1),fpp(10,11, 9,2),fpp(10,11, 9,3)/
     x-3.5583862D-04,-4.7593022D-07, 1.4990419D-07 /
      data fpp(10,11,10,1),fpp(10,11,10,2),fpp(10,11,10,3)/
     x-2.6539414D-04,-4.0398971D-07, 4.5524962D-08 /
      data fpp(10,11,11,1),fpp(10,11,11,2),fpp(10,11,11,3)/
     x-8.5261227D-05,-1.4105929D-07,-7.0004033D-08 /
      data fpp(10,11,12,1),fpp(10,11,12,2),fpp(10,11,12,3)/
     x-6.9396200D-08, 9.2469243D-08,-1.2284216D-07 /
      data fpp(10,11,13,1),fpp(10,11,13,2),fpp(10,11,13,3)/
     x-8.8509150D-05,-2.1794791D-08, 2.6706019D-08 /
      data fpp(10,11,14,1),fpp(10,11,14,2),fpp(10,11,14,3)/
     x-1.8452396D-04,-3.3554655D-07, 4.8018089D-08 /
      data fpp(10,11,15,1),fpp(10,11,15,2),fpp(10,11,15,3)/
     x-2.0121384D-04,-4.6954752D-07,-3.4450410D-09 /
      data fpp(10,11,16,1),fpp(10,11,16,2),fpp(10,11,16,3)/
     x-1.8452396D-04,-3.3554655D-07, 4.0428742D-08 /
      data fpp(10,11,17,1),fpp(10,11,17,2),fpp(10,11,17,3)/
     x-8.8509150D-05,-2.1794791D-08, 5.7063407D-08 /
      data fpp(10,12, 1,1),fpp(10,12, 1,2),fpp(10,12, 1,3)/
     x-8.0757431D-05, 1.7153347D-07, 9.8328366D-08 /
      data fpp(10,12, 2,1),fpp(10,12, 2,2),fpp(10,12, 2,3)/
     x-3.1841483D-04,-6.3555895D-08, 9.1454379D-08 /
      data fpp(10,12, 3,1),fpp(10,12, 3,2),fpp(10,12, 3,3)/
     x-3.9271619D-04,-1.7162207D-07, 5.9187452D-08 /
      data fpp(10,12, 4,1),fpp(10,12, 4,2),fpp(10,12, 4,3)/
     x-3.1841483D-04,-6.3555895D-08, 1.1579581D-07 /
      data fpp(10,12, 5,1),fpp(10,12, 5,2),fpp(10,12, 5,3)/
     x-8.0757431D-05, 1.7153347D-07, 9.6263228D-10 /
      data fpp(10,12, 6,1),fpp(10,12, 6,2),fpp(10,12, 6,3)/
     x 8.6550851D-05, 1.9033826D-07,-2.8297967D-07 /
      data fpp(10,12, 7,1),fpp(10,12, 7,2),fpp(10,12, 7,3)/
     x-1.2026586D-04,-3.3575652D-08,-8.7043934D-08 /
      data fpp(10,12, 8,1),fpp(10,12, 8,2),fpp(10,12, 8,3)/
     x-4.3971496D-04,-2.3784418D-07, 1.2048874D-07 /
      data fpp(10,12, 9,1),fpp(10,12, 9,2),fpp(10,12, 9,3)/
     x-5.7720251D-04,-3.0799941D-07, 2.1042230D-07 /
      data fpp(10,12,10,1),fpp(10,12,10,2),fpp(10,12,10,3)/
     x-4.3971496D-04,-2.3784418D-07, 1.2048874D-07 /
      data fpp(10,12,11,1),fpp(10,12,11,2),fpp(10,12,11,3)/
     x-1.2026586D-04,-3.3575652D-08,-8.7043934D-08 /
      data fpp(10,12,12,1),fpp(10,12,12,2),fpp(10,12,12,3)/
     x 8.6550851D-05, 1.9033826D-07,-2.8297967D-07 /
      data fpp(10,12,13,1),fpp(10,12,13,2),fpp(10,12,13,3)/
     x-8.0757431D-05, 1.7153347D-07, 9.6263228D-10 /
      data fpp(10,12,14,1),fpp(10,12,14,2),fpp(10,12,14,3)/
     x-3.1841483D-04,-6.3555895D-08, 1.1579581D-07 /
      data fpp(10,12,15,1),fpp(10,12,15,2),fpp(10,12,15,3)/
     x-3.9271619D-04,-1.7162207D-07, 5.9187452D-08 /
      data fpp(10,12,16,1),fpp(10,12,16,2),fpp(10,12,16,3)/
     x-3.1841483D-04,-6.3555895D-08, 9.1454379D-08 /
      data fpp(10,12,17,1),fpp(10,12,17,2),fpp(10,12,17,3)/
     x-8.0757431D-05, 1.7153347D-07, 9.8328366D-08 /
      data fpp(10,13, 1,1),fpp(10,13, 1,2),fpp(10,13, 1,3)/
     x-2.1627718D-05, 3.4366090D-07, 1.4125533D-07 /
      data fpp(10,13, 2,1),fpp(10,13, 2,2),fpp(10,13, 2,3)/
     x-4.3451514D-04, 3.5577013D-07, 1.5315601D-07 /
      data fpp(10,13, 3,1),fpp(10,13, 3,2),fpp(10,13, 3,3)/
     x-5.7768891D-04, 3.1603578D-07, 1.4812063D-07 /
      data fpp(10,13, 4,1),fpp(10,13, 4,2),fpp(10,13, 4,3)/
     x-4.3451514D-04, 3.5577013D-07, 2.0236146D-07 /
      data fpp(10,13, 5,1),fpp(10,13, 5,2),fpp(10,13, 5,3)/
     x-2.1627718D-05, 3.4366090D-07,-5.5566468D-08 /
      data fpp(10,13, 6,1),fpp(10,13, 6,2),fpp(10,13, 6,3)/
     x 2.3575553D-04, 2.0217771D-07,-4.7142892D-07 /
      data fpp(10,13, 7,1),fpp(10,13, 7,2),fpp(10,13, 7,3)/
     x-1.3348569D-04, 1.3736190D-07,-9.8051188D-08 /
      data fpp(10,13, 8,1),fpp(10,13, 8,2),fpp(10,13, 8,3)/
     x-6.2483243D-04, 1.2536642D-07, 2.1096701D-07 /
      data fpp(10,13, 9,1),fpp(10,13, 9,2),fpp(10,13, 9,3)/
     x-8.2171495D-04, 1.1192785D-07, 2.8351650D-07 /
      data fpp(10,13,10,1),fpp(10,13,10,2),fpp(10,13,10,3)/
     x-6.2483243D-04, 1.2536642D-07, 2.1096701D-07 /
      data fpp(10,13,11,1),fpp(10,13,11,2),fpp(10,13,11,3)/
     x-1.3348569D-04, 1.3736190D-07,-9.8051188D-08 /
      data fpp(10,13,12,1),fpp(10,13,12,2),fpp(10,13,12,3)/
     x 2.3575553D-04, 2.0217771D-07,-4.7142892D-07 /
      data fpp(10,13,13,1),fpp(10,13,13,2),fpp(10,13,13,3)/
     x-2.1627718D-05, 3.4366090D-07,-5.5566468D-08 /
      data fpp(10,13,14,1),fpp(10,13,14,2),fpp(10,13,14,3)/
     x-4.3451514D-04, 3.5577013D-07, 2.0236146D-07 /
      data fpp(10,13,15,1),fpp(10,13,15,2),fpp(10,13,15,3)/
     x-5.7768891D-04, 3.1603578D-07, 1.4812063D-07 /
      data fpp(10,13,16,1),fpp(10,13,16,2),fpp(10,13,16,3)/
     x-4.3451514D-04, 3.5577013D-07, 1.5315601D-07 /
      data fpp(10,13,17,1),fpp(10,13,17,2),fpp(10,13,17,3)/
     x-2.1627718D-05, 3.4366090D-07, 1.4125533D-07 /
      data fpp(10,14, 1,1),fpp(10,14, 1,2),fpp(10,14, 1,3)/
     x 1.0493663D-04, 3.6182291D-07, 1.6415645D-07 /
      data fpp(10,14, 2,1),fpp(10,14, 2,2),fpp(10,14, 2,3)/
     x-4.7453236D-04, 8.3047536D-07, 2.0479821D-07 /
      data fpp(10,14, 3,1),fpp(10,14, 3,2),fpp(10,14, 3,3)/
     x-6.8759506D-04, 9.5347894D-07, 2.4998406D-07 /
      data fpp(10,14, 4,1),fpp(10,14, 4,2),fpp(10,14, 4,3)/
     x-4.7453236D-04, 8.3047536D-07, 2.7926556D-07 /
      data fpp(10,14, 5,1),fpp(10,14, 5,2),fpp(10,14, 5,3)/
     x 1.0493663D-04, 3.6182291D-07,-1.3371296D-07 /
      data fpp(10,14, 6,1),fpp(10,14, 6,2),fpp(10,14, 6,3)/
     x 4.2786225D-04,-2.1049097D-08,-6.3574704D-07 /
      data fpp(10,14, 7,1),fpp(10,14, 7,2),fpp(10,14, 7,3)/
     x-1.0990488D-04, 2.5812805D-07,-1.0329887D-07 /
      data fpp(10,14, 8,1),fpp(10,14, 8,2),fpp(10,14, 8,3)/
     x-7.7117112D-04, 6.7237850D-07, 2.9494254D-07 /
      data fpp(10,14, 9,1),fpp(10,14, 9,2),fpp(10,14, 9,3)/
     x-1.0284976D-03, 8.0228802D-07, 3.5952873D-07 /
      data fpp(10,14,10,1),fpp(10,14,10,2),fpp(10,14,10,3)/
     x-7.7117112D-04, 6.7237850D-07, 2.9494254D-07 /
      data fpp(10,14,11,1),fpp(10,14,11,2),fpp(10,14,11,3)/
     x-1.0990488D-04, 2.5812805D-07,-1.0329887D-07 /
      data fpp(10,14,12,1),fpp(10,14,12,2),fpp(10,14,12,3)/
     x 4.2786225D-04,-2.1049097D-08,-6.3574704D-07 /
      data fpp(10,14,13,1),fpp(10,14,13,2),fpp(10,14,13,3)/
     x 1.0493663D-04, 3.6182291D-07,-1.3371296D-07 /
      data fpp(10,14,14,1),fpp(10,14,14,2),fpp(10,14,14,3)/
     x-4.7453236D-04, 8.3047536D-07, 2.7926556D-07 /
      data fpp(10,14,15,1),fpp(10,14,15,2),fpp(10,14,15,3)/
     x-6.8759506D-04, 9.5347894D-07, 2.4998406D-07 /
      data fpp(10,14,16,1),fpp(10,14,16,2),fpp(10,14,16,3)/
     x-4.7453236D-04, 8.3047536D-07, 2.0479821D-07 /
      data fpp(10,14,17,1),fpp(10,14,17,2),fpp(10,14,17,3)/
     x 1.0493663D-04, 3.6182291D-07, 1.6415645D-07 /
      data fpp(10,15, 1,1),fpp(10,15, 1,2),fpp(10,15, 1,3)/
     x 2.7763857D-04, 4.5047452D-08, 1.4139864D-07 /
      data fpp(10,15, 2,1),fpp(10,15, 2,2),fpp(10,15, 2,3)/
     x-3.8098246D-04, 1.0443284D-06, 2.1553606D-07 /
      data fpp(10,15, 3,1),fpp(10,15, 3,2),fpp(10,15, 3,3)/
     x-6.4262093D-04, 1.4020485D-06, 3.3045712D-07 /
      data fpp(10,15, 4,1),fpp(10,15, 4,2),fpp(10,15, 4,3)/
     x-3.8098246D-04, 1.0443284D-06, 3.0263547D-07 /
      data fpp(10,15, 5,1),fpp(10,15, 5,2),fpp(10,15, 5,3)/
     x 2.7763857D-04, 4.5047452D-08,-2.0699901D-07 /
      data fpp(10,15, 6,1),fpp(10,15, 6,2),fpp(10,15, 6,3)/
     x 5.9562364D-04,-4.8998132D-07,-6.9063944D-07 /
      data fpp(10,15, 7,1),fpp(10,15, 7,2),fpp(10,15, 7,3)/
     x-4.6032092D-05, 2.7012591D-07,-1.0444323D-07 /
      data fpp(10,15, 8,1),fpp(10,15, 8,2),fpp(10,15, 8,3)/
     x-8.0870282D-04, 1.1871196D-06, 3.3641235D-07 /
      data fpp(10,15, 9,1),fpp(10,15, 9,2),fpp(10,15, 9,3)/
     x-1.1057284D-03, 1.5209201D-06, 4.1012716D-07 /
      data fpp(10,15,10,1),fpp(10,15,10,2),fpp(10,15,10,3)/
     x-8.0870282D-04, 1.1871196D-06, 3.3641235D-07 /
      data fpp(10,15,11,1),fpp(10,15,11,2),fpp(10,15,11,3)/
     x-4.6032092D-05, 2.7012591D-07,-1.0444323D-07 /
      data fpp(10,15,12,1),fpp(10,15,12,2),fpp(10,15,12,3)/
     x 5.9562364D-04,-4.8998132D-07,-6.9063944D-07 /
      data fpp(10,15,13,1),fpp(10,15,13,2),fpp(10,15,13,3)/
     x 2.7763857D-04, 4.5047452D-08,-2.0699901D-07 /
      data fpp(10,15,14,1),fpp(10,15,14,2),fpp(10,15,14,3)/
     x-3.8098246D-04, 1.0443284D-06, 3.0263547D-07 /
      data fpp(10,15,15,1),fpp(10,15,15,2),fpp(10,15,15,3)/
     x-6.4262093D-04, 1.4020485D-06, 3.3045712D-07 /
      data fpp(10,15,16,1),fpp(10,15,16,2),fpp(10,15,16,3)/
     x-3.8098246D-04, 1.0443284D-06, 2.1553606D-07 /
      data fpp(10,15,17,1),fpp(10,15,17,2),fpp(10,15,17,3)/
     x 2.7763857D-04, 4.5047452D-08, 1.4139864D-07 /
      data fpp(10,16, 1,1),fpp(10,16, 1,2),fpp(10,16, 1,3)/
     x 4.2930977D-04,-4.0401272D-07, 6.9033004D-08 /
      data fpp(10,16, 2,1),fpp(10,16, 2,2),fpp(10,16, 2,3)/
     x-1.4527844D-04, 5.7221094D-07, 1.6360066D-07 /
      data fpp(10,16, 3,1),fpp(10,16, 3,2),fpp(10,16, 3,3)/
     x-3.9583926D-04, 1.0703272D-06, 3.3456436D-07 /
      data fpp(10,16, 4,1),fpp(10,16, 4,2),fpp(10,16, 4,3)/
     x-1.4527844D-04, 5.7221094D-07, 2.3814190D-07 /
      data fpp(10,16, 5,1),fpp(10,16, 5,2),fpp(10,16, 5,3)/
     x 4.2930977D-04,-4.0401272D-07,-2.2913194D-07 /
      data fpp(10,16, 6,1),fpp(10,16, 6,2),fpp(10,16, 6,3)/
     x 6.4686865D-04,-6.6502563D-07,-5.6694745D-07 /
      data fpp(10,16, 7,1),fpp(10,16, 7,2),fpp(10,16, 7,3)/
     x 4.2408639D-05, 1.4336831D-07,-1.0307825D-07 /
      data fpp(10,16, 8,1),fpp(10,16, 8,2),fpp(10,16, 8,3)/
     x-6.7534199D-04, 1.2211432D-06, 3.0392712D-07 /
      data fpp(10,16, 9,1),fpp(10,16, 9,2),fpp(10,16, 9,3)/
     x-9.6243839D-04, 1.6580317D-06, 3.9203644D-07 /
      data fpp(10,16,10,1),fpp(10,16,10,2),fpp(10,16,10,3)/
     x-6.7534199D-04, 1.2211432D-06, 3.0392712D-07 /
      data fpp(10,16,11,1),fpp(10,16,11,2),fpp(10,16,11,3)/
     x 4.2408639D-05, 1.4336831D-07,-1.0307825D-07 /
      data fpp(10,16,12,1),fpp(10,16,12,2),fpp(10,16,12,3)/
     x 6.4686865D-04,-6.6502563D-07,-5.6694745D-07 /
      data fpp(10,16,13,1),fpp(10,16,13,2),fpp(10,16,13,3)/
     x 4.2930977D-04,-4.0401272D-07,-2.2913194D-07 /
      data fpp(10,16,14,1),fpp(10,16,14,2),fpp(10,16,14,3)/
     x-1.4527844D-04, 5.7221094D-07, 2.3814190D-07 /
      data fpp(10,16,15,1),fpp(10,16,15,2),fpp(10,16,15,3)/
     x-3.9583926D-04, 1.0703272D-06, 3.3456436D-07 /
      data fpp(10,16,16,1),fpp(10,16,16,2),fpp(10,16,16,3)/
     x-1.4527844D-04, 5.7221094D-07, 1.6360066D-07 /
      data fpp(10,16,17,1),fpp(10,16,17,2),fpp(10,16,17,3)/
     x 4.2930977D-04,-4.0401272D-07, 6.9033004D-08 /
      data fpp(10,17, 1,1),fpp(10,17, 1,2),fpp(10,17, 1,3)/
     x 4.8364932D-04,-5.5299658D-07,-1.2519739D-09 /
      data fpp(10,17, 2,1),fpp(10,17, 2,2),fpp(10,17, 2,3)/
     x 1.5595354D-04,-5.6117218D-07, 7.4170614D-08 /
      data fpp(10,17, 3,1),fpp(10,17, 3,2),fpp(10,17, 3,3)/
     x-4.7465651D-06,-3.9135733D-07, 2.2256952D-07 /
      data fpp(10,17, 4,1),fpp(10,17, 4,2),fpp(10,17, 4,3)/
     x 1.5595354D-04,-5.6117218D-07, 1.1555132D-07 /
      data fpp(10,17, 5,1),fpp(10,17, 5,2),fpp(10,17, 5,3)/
     x 4.8364932D-04,-5.5299658D-07,-1.6677480D-07 /
      data fpp(10,17, 6,1),fpp(10,17, 6,2),fpp(10,17, 6,3)/
     x 5.4251000D-04,-2.2191618D-07,-3.1778545D-07 /
      data fpp(10,17, 7,1),fpp(10,17, 7,2),fpp(10,17, 7,3)/
     x 1.2932679D-04, 5.0400839D-08,-7.5416738D-08 /
      data fpp(10,17, 8,1),fpp(10,17, 8,2),fpp(10,17, 8,3)/
     x-3.6928507D-04, 4.8630760D-07, 1.9611907D-07 /
      data fpp(10,17, 9,1),fpp(10,17, 9,2),fpp(10,17, 9,3)/
     x-5.7757045D-04, 7.5695299D-07, 2.8094047D-07 /
      data fpp(10,17,10,1),fpp(10,17,10,2),fpp(10,17,10,3)/
     x-3.6928507D-04, 4.8630760D-07, 1.9611907D-07 /
      data fpp(10,17,11,1),fpp(10,17,11,2),fpp(10,17,11,3)/
     x 1.2932679D-04, 5.0400839D-08,-7.5416738D-08 /
      data fpp(10,17,12,1),fpp(10,17,12,2),fpp(10,17,12,3)/
     x 5.4251000D-04,-2.2191618D-07,-3.1778545D-07 /
      data fpp(10,17,13,1),fpp(10,17,13,2),fpp(10,17,13,3)/
     x 4.8364932D-04,-5.5299658D-07,-1.6677480D-07 /
      data fpp(10,17,14,1),fpp(10,17,14,2),fpp(10,17,14,3)/
     x 1.5595354D-04,-5.6117218D-07, 1.1555132D-07 /
      data fpp(10,17,15,1),fpp(10,17,15,2),fpp(10,17,15,3)/
     x-4.7465651D-06,-3.9135733D-07, 2.2256952D-07 /
      data fpp(10,17,16,1),fpp(10,17,16,2),fpp(10,17,16,3)/
     x 1.5595354D-04,-5.6117218D-07, 7.4170614D-08 /
      data fpp(10,17,17,1),fpp(10,17,17,2),fpp(10,17,17,3)/
     x 4.8364932D-04,-5.5299658D-07,-1.2519739D-09 /
      data fpp(10,18, 1,1),fpp(10,18, 1,2),fpp(10,18, 1,3)/
     x 4.1985147D-04,-2.4000098D-07,-1.8251650D-08 /
      data fpp(10,18, 2,1),fpp(10,18, 2,2),fpp(10,18, 2,3)/
     x 3.6224803D-04,-1.2435222D-06, 6.7255223D-09 /
      data fpp(10,18, 3,1),fpp(10,18, 3,2),fpp(10,18, 3,3)/
     x 3.2275138D-04,-1.6828979D-06, 5.8016228D-08 /
      data fpp(10,18, 4,1),fpp(10,18, 4,2),fpp(10,18, 4,3)/
     x 3.6224803D-04,-1.2435222D-06, 1.7209567D-08 /
      data fpp(10,18, 5,1),fpp(10,18, 5,2),fpp(10,18, 5,3)/
     x 4.1985147D-04,-2.4000098D-07,-6.0187831D-08 /
      data fpp(10,18, 6,1),fpp(10,18, 6,2),fpp(10,18, 6,3)/
     x 3.8582267D-04, 3.8269034D-07,-8.9124911D-08 /
      data fpp(10,18, 7,1),fpp(10,18, 7,2),fpp(10,18, 7,3)/
     x 2.1340698D-04, 6.3028332D-08,-2.1979191D-08 /
      data fpp(10,18, 8,1),fpp(10,18, 8,2),fpp(10,18, 8,3)/
     x 1.6975227D-05,-5.9237360D-07, 7.1041673D-08 /
      data fpp(10,18, 9,1),fpp(10,18, 9,2),fpp(10,18, 9,3)/
     x-6.7518391D-05,-8.7584371D-07, 1.0981250D-07 /
      data fpp(10,18,10,1),fpp(10,18,10,2),fpp(10,18,10,3)/
     x 1.6975227D-05,-5.9237360D-07, 7.1041673D-08 /
      data fpp(10,18,11,1),fpp(10,18,11,2),fpp(10,18,11,3)/
     x 2.1340698D-04, 6.3028332D-08,-2.1979191D-08 /
      data fpp(10,18,12,1),fpp(10,18,12,2),fpp(10,18,12,3)/
     x 3.8582267D-04, 3.8269034D-07,-8.9124911D-08 /
      data fpp(10,18,13,1),fpp(10,18,13,2),fpp(10,18,13,3)/
     x 4.1985147D-04,-2.4000098D-07,-6.0187831D-08 /
      data fpp(10,18,14,1),fpp(10,18,14,2),fpp(10,18,14,3)/
     x 3.6224803D-04,-1.2435222D-06, 1.7209567D-08 /
      data fpp(10,18,15,1),fpp(10,18,15,2),fpp(10,18,15,3)/
     x 3.2275138D-04,-1.6828979D-06, 5.8016228D-08 /
      data fpp(10,18,16,1),fpp(10,18,16,2),fpp(10,18,16,3)/
     x 3.6224803D-04,-1.2435222D-06, 6.7255223D-09 /
      data fpp(10,18,17,1),fpp(10,18,17,2),fpp(10,18,17,3)/
     x 4.1985147D-04,-2.4000098D-07,-1.8251650D-08 /
      data fpp(10,19, 1,1),fpp(10,19, 1,2),fpp(10,19, 1,3)/
     x 3.1564642D-04,-5.8999511D-08, 1.1950638D-23 /
      data fpp(10,19, 2,1),fpp(10,19, 2,2),fpp(10,19, 2,3)/
     x 3.1564642D-04,-2.0547389D-06,-1.8416689D-22 /
      data fpp(10,19, 3,1),fpp(10,19, 3,2),fpp(10,19, 3,3)/
     x 3.1564642D-04,-3.0230510D-06,-7.7761983D-23 /
      data fpp(10,19, 4,1),fpp(10,19, 4,2),fpp(10,19, 4,3)/
     x 3.1564642D-04,-2.0547389D-06, 9.3686735D-24 /
      data fpp(10,19, 5,1),fpp(10,19, 5,2),fpp(10,19, 5,3)/
     x 3.1564642D-04,-5.8999511D-08,-2.1126062D-23 /
      data fpp(10,19, 6,1),fpp(10,19, 6,2),fpp(10,19, 6,3)/
     x 3.1564642D-04, 9.4115483D-07,-4.3289467D-23 /
      data fpp(10,19, 7,1),fpp(10,19, 7,2),fpp(10,19, 7,3)/
     x 3.1564642D-04, 4.5485834D-08,-1.0104502D-22 /
      data fpp(10,19, 8,1),fpp(10,19, 8,2),fpp(10,19, 8,3)/
     x 3.1564642D-04,-1.5728132D-06, 8.3803631D-23 /
      data fpp(10,19, 9,1),fpp(10,19, 9,2),fpp(10,19, 9,3)/
     x 3.1564642D-04,-2.2995781D-06, 1.3900300D-23 /
      data fpp(10,19,10,1),fpp(10,19,10,2),fpp(10,19,10,3)/
     x 3.1564642D-04,-1.5728132D-06,-9.3379759D-23 /
      data fpp(10,19,11,1),fpp(10,19,11,2),fpp(10,19,11,3)/
     x 3.1564642D-04, 4.5485834D-08, 2.3506642D-23 /
      data fpp(10,19,12,1),fpp(10,19,12,2),fpp(10,19,12,3)/
     x 3.1564642D-04, 9.4115483D-07,-5.0498175D-23 /
      data fpp(10,19,13,1),fpp(10,19,13,2),fpp(10,19,13,3)/
     x 3.1564642D-04,-5.8999511D-08, 2.9491705D-23 /
      data fpp(10,19,14,1),fpp(10,19,14,2),fpp(10,19,14,3)/
     x 3.1564642D-04,-2.0547389D-06,-1.0423110D-24 /
      data fpp(10,19,15,1),fpp(10,19,15,2),fpp(10,19,15,3)/
     x 3.1564642D-04,-3.0230510D-06,-1.8872941D-23 /
      data fpp(10,19,16,1),fpp(10,19,16,2),fpp(10,19,16,3)/
     x 3.1564642D-04,-2.0547389D-06,-2.1127131D-23 /
      data fpp(10,19,17,1),fpp(10,19,17,2),fpp(10,19,17,3)/
     x 3.1564642D-04,-5.8999511D-08,-2.4381550D-23 /
      data fpp(11, 1, 1,1),fpp(11, 1, 1,2),fpp(11, 1, 1,3)/
     x-7.5053353D-05, 2.2001751D-08, 2.8774807D-23 /
      data fpp(11, 1, 2,1),fpp(11, 1, 2,2),fpp(11, 1, 2,3)/
     x-7.5053353D-05,-2.0714646D-08,-1.1763768D-22 /
      data fpp(11, 1, 3,1),fpp(11, 1, 3,2),fpp(11, 1, 3,3)/
     x-7.5053353D-05,-4.5325881D-08,-6.5906646D-23 /
      data fpp(11, 1, 4,1),fpp(11, 1, 4,2),fpp(11, 1, 4,3)/
     x-7.5053353D-05,-2.0714646D-08, 3.7547949D-24 /
      data fpp(11, 1, 5,1),fpp(11, 1, 5,2),fpp(11, 1, 5,3)/
     x-7.5053353D-05, 2.2001751D-08,-1.6712504D-24 /
      data fpp(11, 1, 6,1),fpp(11, 1, 6,2),fpp(11, 1, 6,3)/
     x-7.5053353D-05, 2.5639809D-08,-3.1833755D-23 /
      data fpp(11, 1, 7,1),fpp(11, 1, 7,2),fpp(11, 1, 7,3)/
     x-7.5053353D-05,-1.8538234D-09,-3.5002022D-23 /
      data fpp(11, 1, 8,1),fpp(11, 1, 8,2),fpp(11, 1, 8,3)/
     x-7.5053353D-05,-1.2402060D-08, 9.6225016D-23 /
      data fpp(11, 1, 9,1),fpp(11, 1, 9,2),fpp(11, 1, 9,3)/
     x-7.5053353D-05,-6.1413649D-09, 1.8365790D-24 /
      data fpp(11, 1,10,1),fpp(11, 1,10,2),fpp(11, 1,10,3)/
     x-7.5053353D-05,-1.2402060D-08,-6.4920758D-23 /
      data fpp(11, 1,11,1),fpp(11, 1,11,2),fpp(11, 1,11,3)/
     x-7.5053353D-05,-1.8538234D-09, 2.2190676D-23 /
      data fpp(11, 1,12,1),fpp(11, 1,12,2),fpp(11, 1,12,3)/
     x-7.5053353D-05, 2.5639809D-08,-1.3167650D-23 /
      data fpp(11, 1,13,1),fpp(11, 1,13,2),fpp(11, 1,13,3)/
     x-7.5053353D-05, 2.2001751D-08, 3.8267219D-23 /
      data fpp(11, 1,14,1),fpp(11, 1,14,2),fpp(11, 1,14,3)/
     x-7.5053353D-05,-2.0714646D-08,-9.2114601D-24 /
      data fpp(11, 1,15,1),fpp(11, 1,15,2),fpp(11, 1,15,3)/
     x-7.5053353D-05,-4.5325881D-08, 1.2919599D-23 /
      data fpp(11, 1,16,1),fpp(11, 1,16,2),fpp(11, 1,16,3)/
     x-7.5053353D-05,-2.0714646D-08,-1.0187059D-23 /
      data fpp(11, 1,17,1),fpp(11, 1,17,2),fpp(11, 1,17,3)/
     x-7.5053353D-05, 2.2001751D-08,-2.8543933D-23 /
      data fpp(11, 2, 1,1),fpp(11, 2, 1,2),fpp(11, 2, 1,3)/
     x-7.5262436D-05, 2.9996497D-08,-1.3449449D-10 /
      data fpp(11, 2, 2,1),fpp(11, 2, 2,2),fpp(11, 2, 2,3)/
     x-7.2811436D-05,-1.5707077D-09, 8.2454454D-10 /
      data fpp(11, 2, 3,1),fpp(11, 2, 3,2),fpp(11, 2, 3,3)/
     x-7.1692264D-05,-2.2348238D-08, 2.8363163D-09 /
      data fpp(11, 2, 4,1),fpp(11, 2, 4,2),fpp(11, 2, 4,3)/
     x-7.2811436D-05,-1.5707077D-09, 1.1635234D-09 /
      data fpp(11, 2, 5,1),fpp(11, 2, 5,2),fpp(11, 2, 5,3)/
     x-7.5262436D-05, 2.9996497D-08,-1.4904101D-09 /
      data fpp(11, 2, 6,1),fpp(11, 2, 6,2),fpp(11, 2, 6,3)/
     x-7.7379000D-05, 1.6720383D-08,-1.2018832D-09 /
      data fpp(11, 2, 7,1),fpp(11, 2, 7,2),fpp(11, 2, 7,3)/
     x-7.7871644D-05,-4.2923532D-09, 2.9794292D-10 /
      data fpp(11, 2, 8,1),fpp(11, 2, 8,2),fpp(11, 2, 8,3)/
     x-7.6900449D-05,-2.1958810D-09, 1.0111547D-11 /
      data fpp(11, 2, 9,1),fpp(11, 2, 9,2),fpp(11, 2, 9,3)/
     x-7.6183841D-05, 6.2827299D-09,-3.3838911D-10 /
      data fpp(11, 2,10,1),fpp(11, 2,10,2),fpp(11, 2,10,3)/
     x-7.6900449D-05,-2.1958810D-09, 1.0111547D-11 /
      data fpp(11, 2,11,1),fpp(11, 2,11,2),fpp(11, 2,11,3)/
     x-7.7871644D-05,-4.2923532D-09, 2.9794292D-10 /
      data fpp(11, 2,12,1),fpp(11, 2,12,2),fpp(11, 2,12,3)/
     x-7.7379000D-05, 1.6720383D-08,-1.2018832D-09 /
      data fpp(11, 2,13,1),fpp(11, 2,13,2),fpp(11, 2,13,3)/
     x-7.5262436D-05, 2.9996497D-08,-1.4904101D-09 /
      data fpp(11, 2,14,1),fpp(11, 2,14,2),fpp(11, 2,14,3)/
     x-7.2811436D-05,-1.5707077D-09, 1.1635234D-09 /
      data fpp(11, 2,15,1),fpp(11, 2,15,2),fpp(11, 2,15,3)/
     x-7.1692264D-05,-2.2348238D-08, 2.8363163D-09 /
      data fpp(11, 2,16,1),fpp(11, 2,16,2),fpp(11, 2,16,3)/
     x-7.2811436D-05,-1.5707077D-09, 8.2454454D-10 /
      data fpp(11, 2,17,1),fpp(11, 2,17,2),fpp(11, 2,17,3)/
     x-7.5262436D-05, 2.9996497D-08,-1.3449449D-10 /
      data fpp(11, 3, 1,1),fpp(11, 3, 1,2),fpp(11, 3, 1,3)/
     x-7.5606664D-05, 2.0122602D-09,-3.7060594D-09 /
      data fpp(11, 3, 2,1),fpp(11, 3, 2,2),fpp(11, 3, 2,3)/
     x-6.8740906D-05, 8.9974771D-09, 1.5232300D-09 /
      data fpp(11, 3, 3,1),fpp(11, 3, 3,2),fpp(11, 3, 3,3)/
     x-6.5596054D-05,-1.5281167D-08, 1.2946473D-08 /
      data fpp(11, 3, 4,1),fpp(11, 3, 4,2),fpp(11, 3, 4,3)/
     x-6.8740906D-05, 8.9974771D-09, 2.6908785D-09 /
      data fpp(11, 3, 5,1),fpp(11, 3, 5,2),fpp(11, 3, 5,3)/
     x-7.5606664D-05, 2.0122602D-09,-8.3766534D-09 /
      data fpp(11, 3, 6,1),fpp(11, 3, 6,2),fpp(11, 3, 6,3)/
     x-8.1542673D-05, 3.4786612D-09,-4.5175980D-09 /
      data fpp(11, 3, 7,1),fpp(11, 3, 7,2),fpp(11, 3, 7,3)/
     x-8.2638770D-05,-1.6976764D-08, 5.1137123D-09 /
      data fpp(11, 3, 8,1),fpp(11, 3, 8,2),fpp(11, 3, 8,3)/
     x-7.7820726D-05, 3.1855834D-09, 7.2941553D-10 /
      data fpp(11, 3, 9,1),fpp(11, 3, 9,2),fpp(11, 3, 9,3)/
     x-7.4635525D-05, 1.7010445D-08,-4.0313744D-09 /
      data fpp(11, 3,10,1),fpp(11, 3,10,2),fpp(11, 3,10,3)/
     x-7.7820726D-05, 3.1855834D-09, 7.2941553D-10 /
      data fpp(11, 3,11,1),fpp(11, 3,11,2),fpp(11, 3,11,3)/
     x-8.2638770D-05,-1.6976764D-08, 5.1137123D-09 /
      data fpp(11, 3,12,1),fpp(11, 3,12,2),fpp(11, 3,12,3)/
     x-8.1542673D-05, 3.4786612D-09,-4.5175980D-09 /
      data fpp(11, 3,13,1),fpp(11, 3,13,2),fpp(11, 3,13,3)/
     x-7.5606664D-05, 2.0122602D-09,-8.3766534D-09 /
      data fpp(11, 3,14,1),fpp(11, 3,14,2),fpp(11, 3,14,3)/
     x-6.8740906D-05, 8.9974771D-09, 2.6908785D-09 /
      data fpp(11, 3,15,1),fpp(11, 3,15,2),fpp(11, 3,15,3)/
     x-6.5596054D-05,-1.5281167D-08, 1.2946473D-08 /
      data fpp(11, 3,16,1),fpp(11, 3,16,2),fpp(11, 3,16,3)/
     x-6.8740906D-05, 8.9974771D-09, 1.5232300D-09 /
      data fpp(11, 3,17,1),fpp(11, 3,17,2),fpp(11, 3,17,3)/
     x-7.5606664D-05, 2.0122602D-09,-3.7060594D-09 /
      data fpp(11, 4, 1,1),fpp(11, 4, 1,2),fpp(11, 4, 1,3)/
     x-7.2360615D-05, 9.9954462D-08,-1.3663333D-08 /
      data fpp(11, 4, 2,1),fpp(11, 4, 2,2),fpp(11, 4, 2,3)/
     x-6.2308380D-05, 4.9580799D-08,-6.6683031D-12 /
      data fpp(11, 4, 3,1),fpp(11, 4, 3,2),fpp(11, 4, 3,3)/
     x-5.6866346D-05, 4.7472906D-08, 3.1023339D-08 /
      data fpp(11, 4, 4,1),fpp(11, 4, 4,2),fpp(11, 4, 4,3)/
     x-6.2308380D-05, 4.9580799D-08, 1.2466454D-09 /
      data fpp(11, 4, 5,1),fpp(11, 4, 5,2),fpp(11, 4, 5,3)/
     x-7.2360615D-05, 9.9954462D-08,-1.8676587D-08 /
      data fpp(11, 4, 6,1),fpp(11, 4, 6,2),fpp(11, 4, 6,3)/
     x-8.1262758D-05, 5.3649726D-09,-8.5402962D-09 /
      data fpp(11, 4, 7,1),fpp(11, 4, 7,2),fpp(11, 4, 7,3)/
     x-8.4104202D-05, 6.1994080D-09, 1.6171105D-08 /
      data fpp(11, 4, 8,1),fpp(11, 4, 8,2),fpp(11, 4, 8,3)/
     x-7.5554435D-05, 2.5453547D-08,-1.4412535D-10 /
      data fpp(11, 4, 9,1),fpp(11, 4, 9,2),fpp(11, 4, 9,3)/
     x-6.9663254D-05, 3.3675488D-08,-1.0927937D-08 /
      data fpp(11, 4,10,1),fpp(11, 4,10,2),fpp(11, 4,10,3)/
     x-7.5554435D-05, 2.5453547D-08,-1.4412535D-10 /
      data fpp(11, 4,11,1),fpp(11, 4,11,2),fpp(11, 4,11,3)/
     x-8.4104202D-05, 6.1994080D-09, 1.6171105D-08 /
      data fpp(11, 4,12,1),fpp(11, 4,12,2),fpp(11, 4,12,3)/
     x-8.1262758D-05, 5.3649726D-09,-8.5402962D-09 /
      data fpp(11, 4,13,1),fpp(11, 4,13,2),fpp(11, 4,13,3)/
     x-7.2360615D-05, 9.9954462D-08,-1.8676587D-08 /
      data fpp(11, 4,14,1),fpp(11, 4,14,2),fpp(11, 4,14,3)/
     x-6.2308380D-05, 4.9580799D-08, 1.2466454D-09 /
      data fpp(11, 4,15,1),fpp(11, 4,15,2),fpp(11, 4,15,3)/
     x-5.6866346D-05, 4.7472906D-08, 3.1023339D-08 /
      data fpp(11, 4,16,1),fpp(11, 4,16,2),fpp(11, 4,16,3)/
     x-6.2308380D-05, 4.9580799D-08,-6.6683031D-12 /
      data fpp(11, 4,17,1),fpp(11, 4,17,2),fpp(11, 4,17,3)/
     x-7.2360615D-05, 9.9954462D-08,-1.3663333D-08 /
      data fpp(11, 5, 1,1),fpp(11, 5, 1,2),fpp(11, 5, 1,3)/
     x-6.3502391D-05,-2.8783011D-07,-2.9476010D-08 /
      data fpp(11, 5, 2,1),fpp(11, 5, 2,2),fpp(11, 5, 2,3)/
     x-5.3603451D-05, 5.0679326D-08,-5.1590915D-09 /
      data fpp(11, 5, 3,1),fpp(11, 5, 3,2),fpp(11, 5, 3,3)/
     x-4.6101084D-05, 7.1389543D-08, 5.2112376D-08 /
      data fpp(11, 5, 4,1),fpp(11, 5, 4,2),fpp(11, 5, 4,3)/
     x-5.3603451D-05, 5.0679326D-08,-5.9570788D-09 /
      data fpp(11, 5, 5,1),fpp(11, 5, 5,2),fpp(11, 5, 5,3)/
     x-6.3502391D-05,-2.8783011D-07,-2.6284061D-08 /
      data fpp(11, 5, 6,1),fpp(11, 5, 6,2),fpp(11, 5, 6,3)/
     x-7.2167018D-05,-9.3855166D-10,-1.1573345D-08 /
      data fpp(11, 5, 7,1),fpp(11, 5, 7,2),fpp(11, 5, 7,3)/
     x-7.7298488D-05, 1.6179132D-08, 3.0577439D-08 /
      data fpp(11, 5, 8,1),fpp(11, 5, 8,2),fpp(11, 5, 8,3)/
     x-6.7194845D-05, 2.7000227D-08,-3.4030778D-09 /
      data fpp(11, 5, 9,1),fpp(11, 5, 9,2),fpp(11, 5, 9,3)/
     x-6.1225700D-05, 2.2287601D-08,-1.8965128D-08 /
      data fpp(11, 5,10,1),fpp(11, 5,10,2),fpp(11, 5,10,3)/
     x-6.7194845D-05, 2.7000227D-08,-3.4030778D-09 /
      data fpp(11, 5,11,1),fpp(11, 5,11,2),fpp(11, 5,11,3)/
     x-7.7298488D-05, 1.6179132D-08, 3.0577439D-08 /
      data fpp(11, 5,12,1),fpp(11, 5,12,2),fpp(11, 5,12,3)/
     x-7.2167018D-05,-9.3855166D-10,-1.1573345D-08 /
      data fpp(11, 5,13,1),fpp(11, 5,13,2),fpp(11, 5,13,3)/
     x-6.3502391D-05,-2.8783011D-07,-2.6284061D-08 /
      data fpp(11, 5,14,1),fpp(11, 5,14,2),fpp(11, 5,14,3)/
     x-5.3603451D-05, 5.0679326D-08,-5.9570788D-09 /
      data fpp(11, 5,15,1),fpp(11, 5,15,2),fpp(11, 5,15,3)/
     x-4.6101084D-05, 7.1389543D-08, 5.2112376D-08 /
      data fpp(11, 5,16,1),fpp(11, 5,16,2),fpp(11, 5,16,3)/
     x-5.3603451D-05, 5.0679326D-08,-5.1590915D-09 /
      data fpp(11, 5,17,1),fpp(11, 5,17,2),fpp(11, 5,17,3)/
     x-6.3502391D-05,-2.8783011D-07,-2.9476010D-08 /
      data fpp(11, 6, 1,1),fpp(11, 6, 1,2),fpp(11, 6, 1,3)/
     x-4.0405403D-05, 4.6336597D-07,-6.5979041D-08 /
      data fpp(11, 6, 2,1),fpp(11, 6, 2,2),fpp(11, 6, 2,3)/
     x-4.5652587D-05, 2.3701898D-08,-2.6930808D-08 /
      data fpp(11, 6, 3,1),fpp(11, 6, 3,2),fpp(11, 6, 3,3)/
     x-3.9068167D-05, 7.4968920D-08, 7.9035605D-08 /
      data fpp(11, 6, 4,1),fpp(11, 6, 4,2),fpp(11, 6, 4,3)/
     x-4.5652587D-05, 2.3701898D-08,-4.9211613D-08 /
      data fpp(11, 6, 5,1),fpp(11, 6, 5,2),fpp(11, 6, 5,3)/
     x-4.0405403D-05, 4.6336597D-07, 2.3144180D-08 /
      data fpp(11, 6, 6,1),fpp(11, 6, 6,2),fpp(11, 6, 6,3)/
     x-5.7815616D-05, 1.0389234D-08,-4.4031773D-08 /
      data fpp(11, 6, 7,1),fpp(11, 6, 7,2),fpp(11, 6, 7,3)/
     x-6.4525166D-05, 4.9084065D-08, 5.0982913D-08 /
      data fpp(11, 6, 8,1),fpp(11, 6, 8,2),fpp(11, 6, 8,3)/
     x-5.5449101D-05, 1.0545543D-08,-1.0566547D-08 /
      data fpp(11, 6, 9,1),fpp(11, 6, 9,2),fpp(11, 6, 9,3)/
     x-5.0872036D-05,-8.8258912D-09,-2.3383393D-08 /
      data fpp(11, 6,10,1),fpp(11, 6,10,2),fpp(11, 6,10,3)/
     x-5.5449101D-05, 1.0545543D-08,-1.0566547D-08 /
      data fpp(11, 6,11,1),fpp(11, 6,11,2),fpp(11, 6,11,3)/
     x-6.4525166D-05, 4.9084065D-08, 5.0982913D-08 /
      data fpp(11, 6,12,1),fpp(11, 6,12,2),fpp(11, 6,12,3)/
     x-5.7815616D-05, 1.0389234D-08,-4.4031773D-08 /
      data fpp(11, 6,13,1),fpp(11, 6,13,2),fpp(11, 6,13,3)/
     x-4.0405403D-05, 4.6336597D-07, 2.3144180D-08 /
      data fpp(11, 6,14,1),fpp(11, 6,14,2),fpp(11, 6,14,3)/
     x-4.5652587D-05, 2.3701898D-08,-4.9211613D-08 /
      data fpp(11, 6,15,1),fpp(11, 6,15,2),fpp(11, 6,15,3)/
     x-3.9068167D-05, 7.4968920D-08, 7.9035605D-08 /
      data fpp(11, 6,16,1),fpp(11, 6,16,2),fpp(11, 6,16,3)/
     x-4.5652587D-05, 2.3701898D-08,-2.6930808D-08 /
      data fpp(11, 6,17,1),fpp(11, 6,17,2),fpp(11, 6,17,3)/
     x-4.0405403D-05, 4.6336597D-07,-6.5979041D-08 /
      data fpp(11, 7, 1,1),fpp(11, 7, 1,2),fpp(11, 7, 1,3)/
     x-3.9128177D-05,-3.1163377D-07,-4.6174351D-08 /
      data fpp(11, 7, 2,1),fpp(11, 7, 2,2),fpp(11, 7, 2,3)/
     x-4.0044769D-05, 4.5130835D-09,-1.4095743D-08 /
      data fpp(11, 7, 3,1),fpp(11, 7, 3,2),fpp(11, 7, 3,3)/
     x-3.8961852D-05, 4.8734776D-08, 6.3890655D-08 /
      data fpp(11, 7, 4,1),fpp(11, 7, 4,2),fpp(11, 7, 4,3)/
     x-4.0044769D-05, 4.5130835D-09,-1.8800210D-08 /
      data fpp(11, 7, 5,1),fpp(11, 7, 5,2),fpp(11, 7, 5,3)/
     x-3.9128177D-05,-3.1163377D-07,-2.7356481D-08 /
      data fpp(11, 7, 6,1),fpp(11, 7, 6,2),fpp(11, 7, 6,3)/
     x-4.4146607D-05, 2.5381616D-08,-5.1071974D-09 /
      data fpp(11, 7, 7,1),fpp(11, 7, 7,2),fpp(11, 7, 7,3)/
     x-5.1892137D-05, 5.7484610D-08, 4.0451938D-08 /
      data fpp(11, 7, 8,1),fpp(11, 7, 8,2),fpp(11, 7, 8,3)/
     x-4.4419212D-05, 1.4817600D-08,-8.7005536D-09 /
      data fpp(11, 7, 9,1),fpp(11, 7, 9,2),fpp(11, 7, 9,3)/
     x-4.0492436D-05,-2.2984036D-08,-2.5649723D-08 /
      data fpp(11, 7,10,1),fpp(11, 7,10,2),fpp(11, 7,10,3)/
     x-4.4419212D-05, 1.4817600D-08,-8.7005536D-09 /
      data fpp(11, 7,11,1),fpp(11, 7,11,2),fpp(11, 7,11,3)/
     x-5.1892137D-05, 5.7484610D-08, 4.0451938D-08 /
      data fpp(11, 7,12,1),fpp(11, 7,12,2),fpp(11, 7,12,3)/
     x-4.4146607D-05, 2.5381616D-08,-5.1071974D-09 /
      data fpp(11, 7,13,1),fpp(11, 7,13,2),fpp(11, 7,13,3)/
     x-3.9128177D-05,-3.1163377D-07,-2.7356481D-08 /
      data fpp(11, 7,14,1),fpp(11, 7,14,2),fpp(11, 7,14,3)/
     x-4.0044769D-05, 4.5130835D-09,-1.8800210D-08 /
      data fpp(11, 7,15,1),fpp(11, 7,15,2),fpp(11, 7,15,3)/
     x-3.8961852D-05, 4.8734776D-08, 6.3890655D-08 /
      data fpp(11, 7,16,1),fpp(11, 7,16,2),fpp(11, 7,16,3)/
     x-4.0044769D-05, 4.5130835D-09,-1.4095743D-08 /
      data fpp(11, 7,17,1),fpp(11, 7,17,2),fpp(11, 7,17,3)/
     x-3.9128177D-05,-3.1163377D-07,-4.6174351D-08 /
      data fpp(11, 8, 1,1),fpp(11, 8, 1,2),fpp(11, 8, 1,3)/
     x-2.9104158D-05, 6.3169123D-08,-3.4776302D-08 /
      data fpp(11, 8, 2,1),fpp(11, 8, 2,2),fpp(11, 8, 2,3)/
     x-3.4797448D-05,-3.5754232D-08,-1.1669619D-08 /
      data fpp(11, 8, 3,1),fpp(11, 8, 3,2),fpp(11, 8, 3,3)/
     x-3.6180257D-05,-2.3908023D-08, 4.4788111D-08 /
      data fpp(11, 8, 4,1),fpp(11, 8, 4,2),fpp(11, 8, 4,3)/
     x-3.4797448D-05,-3.5754232D-08,-1.5482825D-08 /
      data fpp(11, 8, 5,1),fpp(11, 8, 5,2),fpp(11, 8, 5,3)/
     x-2.9104158D-05, 6.3169123D-08,-1.9523479D-08 /
      data fpp(11, 8, 6,1),fpp(11, 8, 6,2),fpp(11, 8, 6,3)/
     x-3.4124386D-05, 2.0843037D-09, 9.1007336D-10 /
      data fpp(11, 8, 7,1),fpp(11, 8, 7,2),fpp(11, 8, 7,3)/
     x-3.9599970D-05,-9.0225031D-09, 2.7883185D-08 /
      data fpp(11, 8, 8,1),fpp(11, 8, 8,2),fpp(11, 8, 8,3)/
     x-3.5385147D-05,-2.1815944D-08,-7.7761482D-09 /
      data fpp(11, 8, 9,1),fpp(11, 8, 9,2),fpp(11, 8, 9,3)/
     x-3.0666386D-05,-3.1237966D-08,-1.7445259D-08 /
      data fpp(11, 8,10,1),fpp(11, 8,10,2),fpp(11, 8,10,3)/
     x-3.5385147D-05,-2.1815944D-08,-7.7761482D-09 /
      data fpp(11, 8,11,1),fpp(11, 8,11,2),fpp(11, 8,11,3)/
     x-3.9599970D-05,-9.0225031D-09, 2.7883185D-08 /
      data fpp(11, 8,12,1),fpp(11, 8,12,2),fpp(11, 8,12,3)/
     x-3.4124386D-05, 2.0843037D-09, 9.1007336D-10 /
      data fpp(11, 8,13,1),fpp(11, 8,13,2),fpp(11, 8,13,3)/
     x-2.9104158D-05, 6.3169123D-08,-1.9523479D-08 /
      data fpp(11, 8,14,1),fpp(11, 8,14,2),fpp(11, 8,14,3)/
     x-3.4797448D-05,-3.5754232D-08,-1.5482825D-08 /
      data fpp(11, 8,15,1),fpp(11, 8,15,2),fpp(11, 8,15,3)/
     x-3.6180257D-05,-2.3908023D-08, 4.4788111D-08 /
      data fpp(11, 8,16,1),fpp(11, 8,16,2),fpp(11, 8,16,3)/
     x-3.4797448D-05,-3.5754232D-08,-1.1669619D-08 /
      data fpp(11, 8,17,1),fpp(11, 8,17,2),fpp(11, 8,17,3)/
     x-2.9104158D-05, 6.3169123D-08,-3.4776302D-08 /
      data fpp(11, 9, 1,1),fpp(11, 9, 1,2),fpp(11, 9, 1,3)/
     x-2.2988729D-05,-5.5042717D-08,-1.6509167D-08 /
      data fpp(11, 9, 2,1),fpp(11, 9, 2,2),fpp(11, 9, 2,3)/
     x-2.6970628D-05,-5.3496157D-08,-5.7594434D-09 /
      data fpp(11, 9, 3,1),fpp(11, 9, 3,2),fpp(11, 9, 3,3)/
     x-2.9154885D-05,-8.5102685D-08, 2.0213607D-08 /
      data fpp(11, 9, 4,1),fpp(11, 9, 4,2),fpp(11, 9, 4,3)/
     x-2.6970628D-05,-5.3496157D-08,-7.0949858D-09 /
      data fpp(11, 9, 5,1),fpp(11, 9, 5,2),fpp(11, 9, 5,3)/
     x-2.2988729D-05,-5.5042717D-08,-1.1166997D-08 /
      data fpp(11, 9, 6,1),fpp(11, 9, 6,2),fpp(11, 9, 6,3)/
     x-2.7791919D-05,-3.9718830D-08, 3.0963086D-09 /
      data fpp(11, 9, 7,1),fpp(11, 9, 7,2),fpp(11, 9, 7,3)/
     x-2.9999266D-05,-5.7394597D-08, 1.4781763D-08 /
      data fpp(11, 9, 8,1),fpp(11, 9, 8,2),fpp(11, 9, 8,3)/
     x-2.5873629D-05,-4.7553824D-08,-6.8900275D-09 /
      data fpp(11, 9, 9,1),fpp(11, 9, 9,2),fpp(11, 9, 9,3)/
     x-2.1239035D-05,-3.2064102D-08,-5.8883196D-09 /
      data fpp(11, 9,10,1),fpp(11, 9,10,2),fpp(11, 9,10,3)/
     x-2.5873629D-05,-4.7553824D-08,-6.8900275D-09 /
      data fpp(11, 9,11,1),fpp(11, 9,11,2),fpp(11, 9,11,3)/
     x-2.9999266D-05,-5.7394597D-08, 1.4781763D-08 /
      data fpp(11, 9,12,1),fpp(11, 9,12,2),fpp(11, 9,12,3)/
     x-2.7791919D-05,-3.9718830D-08, 3.0963086D-09 /
      data fpp(11, 9,13,1),fpp(11, 9,13,2),fpp(11, 9,13,3)/
     x-2.2988729D-05,-5.5042717D-08,-1.1166997D-08 /
      data fpp(11, 9,14,1),fpp(11, 9,14,2),fpp(11, 9,14,3)/
     x-2.6970628D-05,-5.3496157D-08,-7.0949858D-09 /
      data fpp(11, 9,15,1),fpp(11, 9,15,2),fpp(11, 9,15,3)/
     x-2.9154885D-05,-8.5102685D-08, 2.0213607D-08 /
      data fpp(11, 9,16,1),fpp(11, 9,16,2),fpp(11, 9,16,3)/
     x-2.6970628D-05,-5.3496157D-08,-5.7594434D-09 /
      data fpp(11, 9,17,1),fpp(11, 9,17,2),fpp(11, 9,17,3)/
     x-2.2988729D-05,-5.5042717D-08,-1.6509167D-08 /
      data fpp(11,10, 1,1),fpp(11,10, 1,2),fpp(11,10, 1,3)/
     x-2.0870367D-05,-4.0998253D-08,-3.7492875D-09 /
      data fpp(11,10, 2,1),fpp(11,10, 2,2),fpp(11,10, 2,3)/
     x-1.8222231D-05,-6.2261142D-08,-1.2792028D-09 /
      data fpp(11,10, 3,1),fpp(11,10, 3,2),fpp(11,10, 3,3)/
     x-1.9600172D-05,-8.5681239D-08, 4.1994320D-09 /
      data fpp(11,10, 4,1),fpp(11,10, 4,2),fpp(11,10, 4,3)/
     x-1.8222231D-05,-6.2261142D-08,-8.5185867D-10 /
      data fpp(11,10, 5,1),fpp(11,10, 5,2),fpp(11,10, 5,3)/
     x-2.0870367D-05,-4.0998253D-08,-5.4586640D-09 /
      data fpp(11,10, 6,1),fpp(11,10, 6,2),fpp(11,10, 6,3)/
     x-2.5729128D-05,-5.9208982D-08, 3.3531814D-09 /
      data fpp(11,10, 7,1),fpp(11,10, 7,2),fpp(11,10, 7,3)/
     x-2.3849775D-05,-6.1399108D-08, 4.7126050D-09 /
      data fpp(11,10, 8,1),fpp(11,10, 8,2),fpp(11,10, 8,3)/
     x-1.5799795D-05,-6.3968759D-08,-4.2036014D-09 /
      data fpp(11,10, 9,1),fpp(11,10, 9,2),fpp(11,10, 9,3)/
     x-1.1239171D-05,-4.4505627D-08, 7.6846738D-10 /
      data fpp(11,10,10,1),fpp(11,10,10,2),fpp(11,10,10,3)/
     x-1.5799795D-05,-6.3968759D-08,-4.2036014D-09 /
      data fpp(11,10,11,1),fpp(11,10,11,2),fpp(11,10,11,3)/
     x-2.3849775D-05,-6.1399108D-08, 4.7126050D-09 /
      data fpp(11,10,12,1),fpp(11,10,12,2),fpp(11,10,12,3)/
     x-2.5729128D-05,-5.9208982D-08, 3.3531814D-09 /
      data fpp(11,10,13,1),fpp(11,10,13,2),fpp(11,10,13,3)/
     x-2.0870367D-05,-4.0998253D-08,-5.4586640D-09 /
      data fpp(11,10,14,1),fpp(11,10,14,2),fpp(11,10,14,3)/
     x-1.8222231D-05,-6.2261142D-08,-8.5185867D-10 /
      data fpp(11,10,15,1),fpp(11,10,15,2),fpp(11,10,15,3)/
     x-1.9600172D-05,-8.5681239D-08, 4.1994320D-09 /
      data fpp(11,10,16,1),fpp(11,10,16,2),fpp(11,10,16,3)/
     x-1.8222231D-05,-6.2261142D-08,-1.2792028D-09 /
      data fpp(11,10,17,1),fpp(11,10,17,2),fpp(11,10,17,3)/
     x-2.0870367D-05,-4.0998253D-08,-3.7492875D-09 /
      data fpp(11,11, 1,1),fpp(11,11, 1,2),fpp(11,11, 1,3)/
     x-2.1724768D-05,-5.6964271D-08, 1.8164717D-09 /
      data fpp(11,11, 2,1),fpp(11,11, 2,2),fpp(11,11, 2,3)/
     x-1.0230565D-05,-5.1459276D-08, 8.1150112D-10 /
      data fpp(11,11, 3,1),fpp(11,11, 3,2),fpp(11,11, 3,3)/
     x-8.2391130D-06,-7.0172360D-08,-2.3958095D-09 /
      data fpp(11,11, 4,1),fpp(11,11, 4,2),fpp(11,11, 4,3)/
     x-1.0230565D-05,-5.1459276D-08, 2.1050701D-09 /
      data fpp(11,11, 5,1),fpp(11,11, 5,2),fpp(11,11, 5,3)/
     x-2.1724768D-05,-5.6964271D-08,-3.3578042D-09 /
      data fpp(11,11, 6,1),fpp(11,11, 6,2),fpp(11,11, 6,3)/
     x-2.8867939D-05,-5.9445242D-08, 5.9928135D-09 /
      data fpp(11,11, 7,1),fpp(11,11, 7,2),fpp(11,11, 7,3)/
     x-2.0794016D-05,-5.1008971D-08,-6.6134498D-09 /
      data fpp(11,11, 8,1),fpp(11,11, 8,2),fpp(11,11, 8,3)/
     x-5.4999040D-06,-5.0571140D-08, 3.1276523D-09 /
      data fpp(11,11, 9,1),fpp(11,11, 9,2),fpp(11,11, 9,3)/
     x-2.8908382D-07,-5.3913388D-08, 1.0284051D-10 /
      data fpp(11,11,10,1),fpp(11,11,10,2),fpp(11,11,10,3)/
     x-5.4999040D-06,-5.0571140D-08, 3.1276523D-09 /
      data fpp(11,11,11,1),fpp(11,11,11,2),fpp(11,11,11,3)/
     x-2.0794016D-05,-5.1008971D-08,-6.6134498D-09 /
      data fpp(11,11,12,1),fpp(11,11,12,2),fpp(11,11,12,3)/
     x-2.8867939D-05,-5.9445242D-08, 5.9928135D-09 /
      data fpp(11,11,13,1),fpp(11,11,13,2),fpp(11,11,13,3)/
     x-2.1724768D-05,-5.6964271D-08,-3.3578042D-09 /
      data fpp(11,11,14,1),fpp(11,11,14,2),fpp(11,11,14,3)/
     x-1.0230565D-05,-5.1459276D-08, 2.1050701D-09 /
      data fpp(11,11,15,1),fpp(11,11,15,2),fpp(11,11,15,3)/
     x-8.2391130D-06,-7.0172360D-08,-2.3958095D-09 /
      data fpp(11,11,16,1),fpp(11,11,16,2),fpp(11,11,16,3)/
     x-1.0230565D-05,-5.1459276D-08, 8.1150112D-10 /
      data fpp(11,11,17,1),fpp(11,11,17,2),fpp(11,11,17,3)/
     x-2.1724768D-05,-5.6964271D-08, 1.8164717D-09 /
      data fpp(11,12, 1,1),fpp(11,12, 1,2),fpp(11,12, 1,3)/
     x-2.5932669D-05,-2.5144664D-08,-4.1431435D-11 /
      data fpp(11,12, 2,1),fpp(11,12, 2,2),fpp(11,12, 2,3)/
     x-4.5391078D-06,-2.5901755D-08,-2.5047046D-10 /
      data fpp(11,12, 3,1),fpp(11,12, 3,2),fpp(11,12, 3,3)/
     x 2.6564768D-06,-3.5629323D-08,-9.5668671D-10 /
      data fpp(11,12, 4,1),fpp(11,12, 4,2),fpp(11,12, 4,3)/
     x-4.5391078D-06,-2.5901755D-08, 7.7217313D-11 /
      data fpp(11,12, 5,1),fpp(11,12, 5,2),fpp(11,12, 5,3)/
     x-2.5932669D-05,-2.5144664D-08,-1.3521825D-09 /
      data fpp(11,12, 6,1),fpp(11,12, 6,2),fpp(11,12, 6,3)/
     x-3.8252436D-05,-2.7010049D-08, 1.0664846D-08 /
      data fpp(11,12, 7,1),fpp(11,12, 7,2),fpp(11,12, 7,3)/
     x-2.0911278D-05,-2.8565009D-08,-1.9307202D-08 /
      data fpp(11,12, 8,1),fpp(11,12, 8,2),fpp(11,12, 8,3)/
     x 3.8694430D-06,-2.7746682D-08, 1.0563963D-08 /
      data fpp(11,12, 9,1),fpp(11,12, 9,2),fpp(11,12, 9,3)/
     x 1.1395521D-05,-3.9840819D-08,-2.8198126D-10 /
      data fpp(11,12,10,1),fpp(11,12,10,2),fpp(11,12,10,3)/
     x 3.8694430D-06,-2.7746682D-08, 1.0563963D-08 /
      data fpp(11,12,11,1),fpp(11,12,11,2),fpp(11,12,11,3)/
     x-2.0911278D-05,-2.8565009D-08,-1.9307202D-08 /
      data fpp(11,12,12,1),fpp(11,12,12,2),fpp(11,12,12,3)/
     x-3.8252436D-05,-2.7010049D-08, 1.0664846D-08 /
      data fpp(11,12,13,1),fpp(11,12,13,2),fpp(11,12,13,3)/
     x-2.5932669D-05,-2.5144664D-08,-1.3521825D-09 /
      data fpp(11,12,14,1),fpp(11,12,14,2),fpp(11,12,14,3)/
     x-4.5391078D-06,-2.5901755D-08, 7.7217313D-11 /
      data fpp(11,12,15,1),fpp(11,12,15,2),fpp(11,12,15,3)/
     x 2.6564768D-06,-3.5629323D-08,-9.5668671D-10 /
      data fpp(11,12,16,1),fpp(11,12,16,2),fpp(11,12,16,3)/
     x-4.5391078D-06,-2.5901755D-08,-2.5047046D-10 /
      data fpp(11,12,17,1),fpp(11,12,17,2),fpp(11,12,17,3)/
     x-2.5932669D-05,-2.5144664D-08,-4.1431435D-11 /
      data fpp(11,13, 1,1),fpp(11,13, 1,2),fpp(11,13, 1,3)/
     x-3.5966510D-05, 1.9542928D-08,-4.9735041D-09 /
      data fpp(11,13, 2,1),fpp(11,13, 2,2),fpp(11,13, 2,3)/
     x-3.1911224D-06,-9.3370258D-10,-2.4974363D-09 /
      data fpp(11,13, 3,1),fpp(11,13, 3,2),fpp(11,13, 3,3)/
     x 9.0583816D-06, 2.6896499D-09, 4.2965827D-09 /
      data fpp(11,13, 4,1),fpp(11,13, 4,2),fpp(11,13, 4,3)/
     x-3.1911224D-06,-9.3370258D-10,-4.0222277D-09 /
      data fpp(11,13, 5,1),fpp(11,13, 5,2),fpp(11,13, 5,3)/
     x-3.5966510D-05, 1.9542928D-08, 1.1256614D-09 /
      data fpp(11,13, 6,1),fpp(11,13, 6,2),fpp(11,13, 6,3)/
     x-5.6224695D-05, 2.9485438D-08, 1.3519582D-08 /
      data fpp(11,13, 7,1),fpp(11,13, 7,2),fpp(11,13, 7,3)/
     x-2.5684817D-05,-8.7309943D-09,-2.9203990D-08 /
      data fpp(11,13, 8,1),fpp(11,13, 8,2),fpp(11,13, 8,3)/
     x 1.0373837D-05,-4.4213264D-10, 1.3963045D-08 /
      data fpp(11,13, 9,1),fpp(11,13, 9,2),fpp(11,13, 9,3)/
     x 2.1915132D-05,-8.7233346D-09, 4.6851443D-09 /
      data fpp(11,13,10,1),fpp(11,13,10,2),fpp(11,13,10,3)/
     x 1.0373837D-05,-4.4213264D-10, 1.3963045D-08 /
      data fpp(11,13,11,1),fpp(11,13,11,2),fpp(11,13,11,3)/
     x-2.5684817D-05,-8.7309943D-09,-2.9203990D-08 /
      data fpp(11,13,12,1),fpp(11,13,12,2),fpp(11,13,12,3)/
     x-5.6224695D-05, 2.9485438D-08, 1.3519582D-08 /
      data fpp(11,13,13,1),fpp(11,13,13,2),fpp(11,13,13,3)/
     x-3.5966510D-05, 1.9542928D-08, 1.1256614D-09 /
      data fpp(11,13,14,1),fpp(11,13,14,2),fpp(11,13,14,3)/
     x-3.1911224D-06,-9.3370258D-10,-4.0222277D-09 /
      data fpp(11,13,15,1),fpp(11,13,15,2),fpp(11,13,15,3)/
     x 9.0583816D-06, 2.6896499D-09, 4.2965827D-09 /
      data fpp(11,13,16,1),fpp(11,13,16,2),fpp(11,13,16,3)/
     x-3.1911224D-06,-9.3370258D-10,-2.4974363D-09 /
      data fpp(11,13,17,1),fpp(11,13,17,2),fpp(11,13,17,3)/
     x-3.5966510D-05, 1.9542928D-08,-4.9735041D-09 /
      data fpp(11,14, 1,1),fpp(11,14, 1,2),fpp(11,14, 1,3)/
     x-5.3559731D-05, 5.4972953D-08,-6.1272910D-09 /
      data fpp(11,14, 2,1),fpp(11,14, 2,2),fpp(11,14, 2,3)/
     x-8.7195170D-06, 4.1636566D-08,-2.4120848D-09 /
      data fpp(11,14, 3,1),fpp(11,14, 3,2),fpp(11,14, 3,3)/
     x 7.8787220D-06, 4.2870723D-08, 7.7756300D-09 /
      data fpp(11,14, 4,1),fpp(11,14, 4,2),fpp(11,14, 4,3)/
     x-8.7195170D-06, 4.1636566D-08,-4.6904353D-09 /
      data fpp(11,14, 5,1),fpp(11,14, 5,2),fpp(11,14, 5,3)/
     x-5.3559731D-05, 5.4972953D-08, 2.9861111D-09 /
      data fpp(11,14, 6,1),fpp(11,14, 6,2),fpp(11,14, 6,3)/
     x-8.1287740D-05, 4.7068299D-08, 8.0793242D-09 /
      data fpp(11,14, 7,1),fpp(11,14, 7,2),fpp(11,14, 7,3)/
     x-3.5008479D-05, 1.5488986D-08,-2.9303408D-08 /
      data fpp(11,14, 8,1),fpp(11,14, 8,2),fpp(11,14, 8,3)/
     x 1.2301035D-05, 2.3515212D-08, 1.1800974D-08 /
      data fpp(11,14, 9,1),fpp(11,14, 9,2),fpp(11,14, 9,3)/
     x 2.8620602D-05, 3.8734158D-08, 1.4099513D-08 /
      data fpp(11,14,10,1),fpp(11,14,10,2),fpp(11,14,10,3)/
     x 1.2301035D-05, 2.3515212D-08, 1.1800974D-08 /
      data fpp(11,14,11,1),fpp(11,14,11,2),fpp(11,14,11,3)/
     x-3.5008479D-05, 1.5488986D-08,-2.9303408D-08 /
      data fpp(11,14,12,1),fpp(11,14,12,2),fpp(11,14,12,3)/
     x-8.1287740D-05, 4.7068299D-08, 8.0793242D-09 /
      data fpp(11,14,13,1),fpp(11,14,13,2),fpp(11,14,13,3)/
     x-5.3559731D-05, 5.4972953D-08, 2.9861111D-09 /
      data fpp(11,14,14,1),fpp(11,14,14,2),fpp(11,14,14,3)/
     x-8.7195170D-06, 4.1636566D-08,-4.6904353D-09 /
      data fpp(11,14,15,1),fpp(11,14,15,2),fpp(11,14,15,3)/
     x 7.8787220D-06, 4.2870723D-08, 7.7756300D-09 /
      data fpp(11,14,16,1),fpp(11,14,16,2),fpp(11,14,16,3)/
     x-8.7195170D-06, 4.1636566D-08,-2.4120848D-09 /
      data fpp(11,14,17,1),fpp(11,14,17,2),fpp(11,14,17,3)/
     x-5.3559731D-05, 5.4972953D-08,-6.1272910D-09 /
      data fpp(11,15, 1,1),fpp(11,15, 1,2),fpp(11,15, 1,3)/
     x-7.5475558D-05, 4.8565258D-08,-3.7549024D-09 /
      data fpp(11,15, 2,1),fpp(11,15, 2,2),fpp(11,15, 2,3)/
     x-2.3277025D-05, 5.6387440D-08,-2.6797305D-10 /
      data fpp(11,15, 3,1),fpp(11,15, 3,2),fpp(11,15, 3,3)/
     x-3.1860801D-06, 6.5827458D-08, 8.8267946D-09 /
      data fpp(11,15, 4,1),fpp(11,15, 4,2),fpp(11,15, 4,3)/
     x-2.3277025D-05, 5.6387440D-08,-1.7058719D-09 /
      data fpp(11,15, 5,1),fpp(11,15, 5,2),fpp(11,15, 5,3)/
     x-7.5475558D-05, 4.8565258D-08, 1.9966931D-09 /
      data fpp(11,15, 6,1),fpp(11,15, 6,2),fpp(11,15, 6,3)/
     x-1.0509031D-04, 2.8241367D-08,-1.6142339D-09 /
      data fpp(11,15, 7,1),fpp(11,15, 7,2),fpp(11,15, 7,3)/
     x-4.7218239D-05, 3.6775051D-08,-2.2206424D-08 /
      data fpp(11,15, 8,1),fpp(11,15, 8,2),fpp(11,15, 8,3)/
     x 8.2946987D-06, 5.6381283D-08, 9.1065974D-09 /
      data fpp(11,15, 9,1),fpp(11,15, 9,2),fpp(11,15, 9,3)/
     x 2.8199999D-05, 7.5786704D-08, 1.9780035D-08 /
      data fpp(11,15,10,1),fpp(11,15,10,2),fpp(11,15,10,3)/
     x 8.2946987D-06, 5.6381283D-08, 9.1065974D-09 /
      data fpp(11,15,11,1),fpp(11,15,11,2),fpp(11,15,11,3)/
     x-4.7218239D-05, 3.6775051D-08,-2.2206424D-08 /
      data fpp(11,15,12,1),fpp(11,15,12,2),fpp(11,15,12,3)/
     x-1.0509031D-04, 2.8241367D-08,-1.6142339D-09 /
      data fpp(11,15,13,1),fpp(11,15,13,2),fpp(11,15,13,3)/
     x-7.5475558D-05, 4.8565258D-08, 1.9966931D-09 /
      data fpp(11,15,14,1),fpp(11,15,14,2),fpp(11,15,14,3)/
     x-2.3277025D-05, 5.6387440D-08,-1.7058719D-09 /
      data fpp(11,15,15,1),fpp(11,15,15,2),fpp(11,15,15,3)/
     x-3.1860801D-06, 6.5827458D-08, 8.8267946D-09 /
      data fpp(11,15,16,1),fpp(11,15,16,2),fpp(11,15,16,3)/
     x-2.3277025D-05, 5.6387440D-08,-2.6797305D-10 /
      data fpp(11,15,17,1),fpp(11,15,17,2),fpp(11,15,17,3)/
     x-7.5475558D-05, 4.8565258D-08,-3.7549024D-09 /
      data fpp(11,16, 1,1),fpp(11,16, 1,2),fpp(11,16, 1,3)/
     x-9.3906668D-05, 8.7660132D-09,-2.1589483D-10 /
      data fpp(11,16, 2,1),fpp(11,16, 2,2),fpp(11,16, 2,3)/
     x-4.4893819D-05, 5.0813676D-08, 1.9873452D-09 /
      data fpp(11,16, 3,1),fpp(11,16, 3,2),fpp(11,16, 3,3)/
     x-2.4979727D-05, 5.9819444D-08, 6.9331806D-09 /
      data fpp(11,16, 4,1),fpp(11,16, 4,2),fpp(11,16, 4,3)/
     x-4.4893819D-05, 5.0813676D-08, 2.2799324D-09 /
      data fpp(11,16, 5,1),fpp(11,16, 5,2),fpp(11,16, 5,3)/
     x-9.3906668D-05, 8.7660132D-09,-1.3862434D-09 /
      data fpp(11,16, 6,1),fpp(11,16, 6,2),fpp(11,16, 6,3)/
     x-1.1597547D-04,-4.0337686D-09,-7.4016255D-09 /
      data fpp(11,16, 7,1),fpp(11,16, 7,2),fpp(11,16, 7,3)/
     x-5.8963880D-05, 2.3410811D-08,-1.3673921D-08 /
      data fpp(11,16, 8,1),fpp(11,16, 8,2),fpp(11,16, 8,3)/
     x-3.7205081D-06, 6.2959656D-08, 7.4306442D-09 /
      data fpp(11,16, 9,1),fpp(11,16, 9,2),fpp(11,16, 9,3)/
     x 1.6875420D-05, 8.4119028D-08, 1.8618011D-08 /
      data fpp(11,16,10,1),fpp(11,16,10,2),fpp(11,16,10,3)/
     x-3.7205081D-06, 6.2959656D-08, 7.4306442D-09 /
      data fpp(11,16,11,1),fpp(11,16,11,2),fpp(11,16,11,3)/
     x-5.8963880D-05, 2.3410811D-08,-1.3673921D-08 /
      data fpp(11,16,12,1),fpp(11,16,12,2),fpp(11,16,12,3)/
     x-1.1597547D-04,-4.0337686D-09,-7.4016255D-09 /
      data fpp(11,16,13,1),fpp(11,16,13,2),fpp(11,16,13,3)/
     x-9.3906668D-05, 8.7660132D-09,-1.3862434D-09 /
      data fpp(11,16,14,1),fpp(11,16,14,2),fpp(11,16,14,3)/
     x-4.4893819D-05, 5.0813676D-08, 2.2799324D-09 /
      data fpp(11,16,15,1),fpp(11,16,15,2),fpp(11,16,15,3)/
     x-2.4979727D-05, 5.9819444D-08, 6.9331806D-09 /
      data fpp(11,16,16,1),fpp(11,16,16,2),fpp(11,16,16,3)/
     x-4.4893819D-05, 5.0813676D-08, 1.9873452D-09 /
      data fpp(11,16,17,1),fpp(11,16,17,2),fpp(11,16,17,3)/
     x-9.3906668D-05, 8.7660132D-09,-2.1589483D-10 /
      data fpp(11,17, 1,1),fpp(11,17, 1,2),fpp(11,17, 1,3)/
     x-1.0024612D-04,-1.1629311D-08, 1.1744191D-10 /
      data fpp(11,17, 2,1),fpp(11,17, 2,2),fpp(11,17, 2,3)/
     x-6.9760773D-05,-1.6421435D-09, 1.4317829D-09 /
      data fpp(11,17, 3,1),fpp(11,17, 3,2),fpp(11,17, 3,3)/
     x-5.5994194D-05, 8.9476503D-10, 4.1554267D-09 /
      data fpp(11,17, 4,1),fpp(11,17, 4,2),fpp(11,17, 4,3)/
     x-6.9760773D-05,-1.6421435D-09, 1.9465104D-09 /
      data fpp(11,17, 5,1),fpp(11,17, 5,2),fpp(11,17, 5,3)/
     x-1.0024612D-04,-1.1629311D-08,-1.9414683D-09 /
      data fpp(11,17, 6,1),fpp(11,17, 6,2),fpp(11,17, 6,3)/
     x-1.0610806D-04,-1.2106293D-08,-7.5139707D-09 /
      data fpp(11,17, 7,1),fpp(11,17, 7,2),fpp(11,17, 7,3)/
     x-6.6490800D-05, 2.5581705D-08,-5.3359822D-09 /
      data fpp(11,17, 8,1),fpp(11,17, 8,2),fpp(11,17, 8,3)/
     x-2.5218597D-05, 3.9780093D-08, 4.8578997D-09 /
      data fpp(11,17, 9,1),fpp(11,17, 9,2),fpp(11,17, 9,3)/
     x-8.9335420D-06, 4.3737185D-08, 1.1904383D-08 /
      data fpp(11,17,10,1),fpp(11,17,10,2),fpp(11,17,10,3)/
     x-2.5218597D-05, 3.9780093D-08, 4.8578997D-09 /
      data fpp(11,17,11,1),fpp(11,17,11,2),fpp(11,17,11,3)/
     x-6.6490800D-05, 2.5581705D-08,-5.3359822D-09 /
      data fpp(11,17,12,1),fpp(11,17,12,2),fpp(11,17,12,3)/
     x-1.0610806D-04,-1.2106293D-08,-7.5139707D-09 /
      data fpp(11,17,13,1),fpp(11,17,13,2),fpp(11,17,13,3)/
     x-1.0024612D-04,-1.1629311D-08,-1.9414683D-09 /
      data fpp(11,17,14,1),fpp(11,17,14,2),fpp(11,17,14,3)/
     x-6.9760773D-05,-1.6421435D-09, 1.9465104D-09 /
      data fpp(11,17,15,1),fpp(11,17,15,2),fpp(11,17,15,3)/
     x-5.5994194D-05, 8.9476503D-10, 4.1554267D-09 /
      data fpp(11,17,16,1),fpp(11,17,16,2),fpp(11,17,16,3)/
     x-6.9760773D-05,-1.6421435D-09, 1.4317829D-09 /
      data fpp(11,17,17,1),fpp(11,17,17,2),fpp(11,17,17,3)/
     x-1.0024612D-04,-1.1629311D-08, 1.1744191D-10 /
      data fpp(11,18, 1,1),fpp(11,18, 1,2),fpp(11,18, 1,3)/
     x-9.2082990D-05,-1.6248768D-08,-8.2148312D-10 /
      data fpp(11,18, 2,1),fpp(11,18, 2,2),fpp(11,18, 2,3)/
     x-8.7324431D-05,-3.8245102D-08,-1.3481154D-10 /
      data fpp(11,18, 3,1),fpp(11,18, 3,2),fpp(11,18, 3,3)/
     x-8.3639196D-05,-4.5398504D-08, 1.3607293D-09 /
      data fpp(11,18, 4,1),fpp(11,18, 4,2),fpp(11,18, 4,3)/
     x-8.7324431D-05,-3.8245102D-08, 2.5227731D-11 /
      data fpp(11,18, 5,1),fpp(11,18, 5,2),fpp(11,18, 5,3)/
     x-9.2082990D-05,-1.6248768D-08,-1.4616402D-09 /
      data fpp(11,18, 6,1),fpp(11,18, 6,2),fpp(11,18, 6,3)/
     x-8.9018210D-05, 1.0458941D-08,-2.1786669D-09 /
      data fpp(11,18, 7,1),fpp(11,18, 7,2),fpp(11,18, 7,3)/
     x-7.2325726D-05, 1.2262370D-08,-1.1570256D-09 /
      data fpp(11,18, 8,1),fpp(11,18, 8,2),fpp(11,18, 8,3)/
     x-5.4632292D-05,-6.0800265D-09, 2.1401025D-09 /
      data fpp(11,18, 9,1),fpp(11,18, 9,2),fpp(11,18, 9,3)/
     x-4.7277403D-05,-1.9067767D-08, 3.9299487D-09 /
      data fpp(11,18,10,1),fpp(11,18,10,2),fpp(11,18,10,3)/
     x-5.4632292D-05,-6.0800265D-09, 2.1401025D-09 /
      data fpp(11,18,11,1),fpp(11,18,11,2),fpp(11,18,11,3)/
     x-7.2325726D-05, 1.2262370D-08,-1.1570256D-09 /
      data fpp(11,18,12,1),fpp(11,18,12,2),fpp(11,18,12,3)/
     x-8.9018210D-05, 1.0458941D-08,-2.1786669D-09 /
      data fpp(11,18,13,1),fpp(11,18,13,2),fpp(11,18,13,3)/
     x-9.2082990D-05,-1.6248768D-08,-1.4616402D-09 /
      data fpp(11,18,14,1),fpp(11,18,14,2),fpp(11,18,14,3)/
     x-8.7324431D-05,-3.8245102D-08, 2.5227731D-11 /
      data fpp(11,18,15,1),fpp(11,18,15,2),fpp(11,18,15,3)/
     x-8.3639196D-05,-4.5398504D-08, 1.3607293D-09 /
      data fpp(11,18,16,1),fpp(11,18,16,2),fpp(11,18,16,3)/
     x-8.7324431D-05,-3.8245102D-08,-1.3481154D-10 /
      data fpp(11,18,17,1),fpp(11,18,17,2),fpp(11,18,17,3)/
     x-9.2082990D-05,-1.6248768D-08,-8.2148312D-10 /
      data fpp(11,19, 1,1),fpp(11,19, 1,2),fpp(11,19, 1,3)/
     x-8.1758916D-05,-2.5375616D-08, 6.3576982D-23 /
      data fpp(11,19, 2,1),fpp(11,19, 2,2),fpp(11,19, 2,3)/
     x-8.1758916D-05,-7.9377449D-08,-1.1478999D-22 /
      data fpp(11,19, 3,1),fpp(11,19, 3,2),fpp(11,19, 3,3)/
     x-8.1758916D-05,-9.5300748D-08,-3.5468754D-23 /
      data fpp(11,19, 4,1),fpp(11,19, 4,2),fpp(11,19, 4,3)/
     x-8.1758916D-05,-7.9377449D-08,-1.2685352D-23 /
      data fpp(11,19, 5,1),fpp(11,19, 5,2),fpp(11,19, 5,3)/
     x-8.1758916D-05,-2.5375616D-08,-1.4278982D-23 /
      data fpp(11,19, 6,1),fpp(11,19, 6,2),fpp(11,19, 6,3)/
     x-8.1758916D-05, 2.4270530D-08,-4.1195459D-23 /
      data fpp(11,19, 7,1),fpp(11,19, 7,2),fpp(11,19, 7,3)/
     x-8.1758916D-05, 3.3688150D-09,-3.6140089D-23 /
      data fpp(11,19, 8,1),fpp(11,19, 8,2),fpp(11,19, 8,3)/
     x-8.1758916D-05,-4.5459987D-08, 6.4274128D-23 /
      data fpp(11,19, 9,1),fpp(11,19, 9,2),fpp(11,19, 9,3)/
     x-8.1758916D-05,-7.5466116D-08, 1.3071822D-23 /
      data fpp(11,19,10,1),fpp(11,19,10,2),fpp(11,19,10,3)/
     x-8.1758916D-05,-4.5459987D-08,-5.0385594D-23 /
      data fpp(11,19,11,1),fpp(11,19,11,2),fpp(11,19,11,3)/
     x-8.1758916D-05, 3.3688150D-09, 2.3369582D-23 /
      data fpp(11,19,12,1),fpp(11,19,12,2),fpp(11,19,12,3)/
     x-8.1758916D-05, 2.4270530D-08,-3.6849363D-23 /
      data fpp(11,19,13,1),fpp(11,19,13,2),fpp(11,19,13,3)/
     x-8.1758916D-05,-2.5375616D-08, 1.8868955D-23 /
      data fpp(11,19,14,1),fpp(11,19,14,2),fpp(11,19,14,3)/
     x-8.1758916D-05,-7.9377449D-08,-1.0138675D-23 /
      data fpp(11,19,15,1),fpp(11,19,15,2),fpp(11,19,15,3)/
     x-8.1758916D-05,-9.5300748D-08, 3.1783079D-23 /
      data fpp(11,19,16,1),fpp(11,19,16,2),fpp(11,19,16,3)/
     x-8.1758916D-05,-7.9377449D-08,-2.9332039D-23 /
      data fpp(11,19,17,1),fpp(11,19,17,2),fpp(11,19,17,3)/
     x-8.1758916D-05,-2.5375616D-08, 2.4861465D-23 /
      data fpp(12, 1, 1,1),fpp(12, 1, 1,2),fpp(12, 1, 1,3)/
     x 3.3145704D-06, 5.9938467D-09, 3.0453165D-23 /
      data fpp(12, 1, 2,1),fpp(12, 1, 2,2),fpp(12, 1, 2,3)/
     x 3.3145704D-06, 5.6598463D-09,-3.8452202D-23 /
      data fpp(12, 1, 3,1),fpp(12, 1, 3,2),fpp(12, 1, 3,3)/
     x 3.3145704D-06,-1.2305543D-09,-2.2630449D-23 /
      data fpp(12, 1, 4,1),fpp(12, 1, 4,2),fpp(12, 1, 4,3)/
     x 3.3145704D-06, 5.6598463D-09, 2.1884100D-24 /
      data fpp(12, 1, 5,1),fpp(12, 1, 5,2),fpp(12, 1, 5,3)/
     x 3.3145704D-06, 5.9938467D-09,-9.1888133D-24 /
      data fpp(12, 1, 6,1),fpp(12, 1, 6,2),fpp(12, 1, 6,3)/
     x 3.3145704D-06, 8.6581884D-09,-3.8768824D-24 /
      data fpp(12, 1, 7,1),fpp(12, 1, 7,2),fpp(12, 1, 7,3)/
     x 3.3145704D-06, 2.8158704D-09,-1.6095888D-23 /
      data fpp(12, 1, 8,1),fpp(12, 1, 8,2),fpp(12, 1, 8,3)/
     x 3.3145704D-06, 4.8448640D-09, 2.1826745D-23 /
      data fpp(12, 1, 9,1),fpp(12, 1, 9,2),fpp(12, 1, 9,3)/
     x 3.3145704D-06, 4.9041364D-09, 5.7097184D-24 /
      data fpp(12, 1,10,1),fpp(12, 1,10,2),fpp(12, 1,10,3)/
     x 3.3145704D-06, 4.8448640D-09,-2.1867762D-23 /
      data fpp(12, 1,11,1),fpp(12, 1,11,2),fpp(12, 1,11,3)/
     x 3.3145704D-06, 2.8158704D-09, 6.1858829D-24 /
      data fpp(12, 1,12,1),fpp(12, 1,12,2),fpp(12, 1,12,3)/
     x 3.3145704D-06, 8.6581884D-09,-8.3027376D-24 /
      data fpp(12, 1,13,1),fpp(12, 1,13,2),fpp(12, 1,13,3)/
     x 3.3145704D-06, 5.9938467D-09, 2.7432177D-25 /
      data fpp(12, 1,14,1),fpp(12, 1,14,2),fpp(12, 1,14,3)/
     x 3.3145704D-06, 5.6598463D-09, 4.1012891D-24 /
      data fpp(12, 1,15,1),fpp(12, 1,15,2),fpp(12, 1,15,3)/
     x 3.3145704D-06,-1.2305543D-09, 7.6549074D-24 /
      data fpp(12, 1,16,1),fpp(12, 1,16,2),fpp(12, 1,16,3)/
     x 3.3145704D-06, 5.6598463D-09, 2.3765408D-24 /
      data fpp(12, 1,17,1),fpp(12, 1,17,2),fpp(12, 1,17,3)/
     x 3.3145704D-06, 5.9938467D-09,-1.4672387D-23 /
      data fpp(12, 2, 1,1),fpp(12, 2, 1,2),fpp(12, 2, 1,3)/
     x 2.8745648D-06, 6.0123065D-09, 4.1841897D-10 /
      data fpp(12, 2, 2,1),fpp(12, 2, 2,2),fpp(12, 2, 2,3)/
     x-1.5651096D-07, 4.6803074D-09, 2.7427317D-10 /
      data fpp(12, 2, 3,1),fpp(12, 2, 3,2),fpp(12, 2, 3,3)/
     x-1.6217363D-06,-5.3889146D-10,-1.8217831D-10 /
      data fpp(12, 2, 4,1),fpp(12, 2, 4,2),fpp(12, 2, 4,3)/
     x-1.5651096D-07, 4.6803074D-09, 4.5444008D-10 /
      data fpp(12, 2, 5,1),fpp(12, 2, 5,2),fpp(12, 2, 5,3)/
     x 2.8745648D-06, 6.0123065D-09,-3.0224868D-10 /
      data fpp(12, 2, 6,1),fpp(12, 2, 6,2),fpp(12, 2, 6,3)/
     x 5.0867394D-06, 5.6836231D-09, 8.7887962D-11 /
      data fpp(12, 2, 7,1),fpp(12, 2, 7,2),fpp(12, 2, 7,3)/
     x 5.2574036D-06, 1.3682593D-09,-4.9303169D-11 /
      data fpp(12, 2, 8,1),fpp(12, 2, 8,2),fpp(12, 2, 8,3)/
     x 4.1288031D-06, 3.3102720D-09, 1.0932471D-10 /
      data fpp(12, 2, 9,1),fpp(12, 2, 9,2),fpp(12, 2, 9,3)/
     x 3.4496853D-06, 4.1917271D-09,-3.8799569D-10 /
      data fpp(12, 2,10,1),fpp(12, 2,10,2),fpp(12, 2,10,3)/
     x 4.1288031D-06, 3.3102720D-09, 1.0932471D-10 /
      data fpp(12, 2,11,1),fpp(12, 2,11,2),fpp(12, 2,11,3)/
     x 5.2574036D-06, 1.3682593D-09,-4.9303169D-11 /
      data fpp(12, 2,12,1),fpp(12, 2,12,2),fpp(12, 2,12,3)/
     x 5.0867394D-06, 5.6836231D-09, 8.7887962D-11 /
      data fpp(12, 2,13,1),fpp(12, 2,13,2),fpp(12, 2,13,3)/
     x 2.8745648D-06, 6.0123065D-09,-3.0224868D-10 /
      data fpp(12, 2,14,1),fpp(12, 2,14,2),fpp(12, 2,14,3)/
     x-1.5651096D-07, 4.6803074D-09, 4.5444008D-10 /
      data fpp(12, 2,15,1),fpp(12, 2,15,2),fpp(12, 2,15,3)/
     x-1.6217363D-06,-5.3889146D-10,-1.8217831D-10 /
      data fpp(12, 2,16,1),fpp(12, 2,16,2),fpp(12, 2,16,3)/
     x-1.5651096D-07, 4.6803074D-09, 2.7427317D-10 /
      data fpp(12, 2,17,1),fpp(12, 2,17,2),fpp(12, 2,17,3)/
     x 2.8745648D-06, 6.0123065D-09, 4.1841897D-10 /
      data fpp(12, 3, 1,1),fpp(12, 3, 1,2),fpp(12, 3, 1,3)/
     x 2.8993831D-06, 5.9569271D-09,-8.0392939D-10 /
      data fpp(12, 3, 2,1),fpp(12, 3, 2,2),fpp(12, 3, 2,3)/
     x-6.2785684D-06,-3.8107590D-10,-5.8807887D-11 /
      data fpp(12, 3, 3,1),fpp(12, 3, 3,2),fpp(12, 3, 3,3)/
     x-1.1190088D-05,-2.6138799D-09, 1.7058276D-09 /
      data fpp(12, 3, 4,1),fpp(12, 3, 4,2),fpp(12, 3, 4,3)/
     x-6.2785684D-06,-3.8107590D-10,-9.7835870D-11 /
      data fpp(12, 3, 5,1),fpp(12, 3, 5,2),fpp(12, 3, 5,3)/
     x 2.8993831D-06, 5.9569271D-09,-6.4781746D-10 /
      data fpp(12, 3, 6,1),fpp(12, 3, 6,2),fpp(12, 3, 6,3)/
     x 8.5686961D-06,-1.3926809D-09,-6.4422762D-10 /
      data fpp(12, 3, 7,1),fpp(12, 3, 7,2),fpp(12, 3, 7,3)/
     x 7.9736601D-06,-2.2889074D-09, 1.2247279D-09 /
      data fpp(12, 3, 8,1),fpp(12, 3, 8,2),fpp(12, 3, 8,3)/
     x 3.4289523D-06,-8.5952118D-11,-2.5468418D-10 /
      data fpp(12, 3, 9,1),fpp(12, 3, 9,2),fpp(12, 3, 9,3)/
     x 8.9356897D-07, 2.3289551D-09,-8.7265791D-10 /
      data fpp(12, 3,10,1),fpp(12, 3,10,2),fpp(12, 3,10,3)/
     x 3.4289523D-06,-8.5952118D-11,-2.5468418D-10 /
      data fpp(12, 3,11,1),fpp(12, 3,11,2),fpp(12, 3,11,3)/
     x 7.9736601D-06,-2.2889074D-09, 1.2247279D-09 /
      data fpp(12, 3,12,1),fpp(12, 3,12,2),fpp(12, 3,12,3)/
     x 8.5686961D-06,-1.3926809D-09,-6.4422762D-10 /
      data fpp(12, 3,13,1),fpp(12, 3,13,2),fpp(12, 3,13,3)/
     x 2.8993831D-06, 5.9569271D-09,-6.4781746D-10 /
      data fpp(12, 3,14,1),fpp(12, 3,14,2),fpp(12, 3,14,3)/
     x-6.2785684D-06,-3.8107590D-10,-9.7835870D-11 /
      data fpp(12, 3,15,1),fpp(12, 3,15,2),fpp(12, 3,15,3)/
     x-1.1190088D-05,-2.6138799D-09, 1.7058276D-09 /
      data fpp(12, 3,16,1),fpp(12, 3,16,2),fpp(12, 3,16,3)/
     x-6.2785684D-06,-3.8107590D-10,-5.8807887D-11 /
      data fpp(12, 3,17,1),fpp(12, 3,17,2),fpp(12, 3,17,3)/
     x 2.8993831D-06, 5.9569271D-09,-8.0392939D-10 /
      data fpp(12, 4, 1,1),fpp(12, 4, 1,2),fpp(12, 4, 1,3)/
     x 2.0037162D-06, 6.1599849D-09,-2.4389796D-09 /
      data fpp(12, 4, 2,1),fpp(12, 4, 2,2),fpp(12, 4, 2,3)/
     x-1.2726263D-05, 8.8439962D-09,-3.4426308D-10 /
      data fpp(12, 4, 3,1),fpp(12, 4, 3,2),fpp(12, 4, 3,3)/
     x-2.2106658D-05, 4.9944110D-09, 4.4826985D-09 /
      data fpp(12, 4, 4,1),fpp(12, 4, 4,2),fpp(12, 4, 4,3)/
     x-1.2726263D-05, 8.8439962D-09,-2.5319779D-10 /
      data fpp(12, 4, 5,1),fpp(12, 4, 5,2),fpp(12, 4, 5,3)/
     x 2.0037162D-06, 6.1599849D-09,-2.8032407D-09 /
      data fpp(12, 4, 6,1),fpp(12, 4, 6,2),fpp(12, 4, 6,3)/
     x 1.0117077D-05, 5.8871006D-09,-5.3383925D-10 /
      data fpp(12, 4, 7,1),fpp(12, 4, 7,2),fpp(12, 4, 7,3)/
     x 9.0932576D-06, 1.7873704D-09, 2.9385977D-09 /
      data fpp(12, 4, 8,1),fpp(12, 4, 8,2),fpp(12, 4, 8,3)/
     x 2.0441527D-06, 3.0335364D-09,-5.5388507D-10 /
      data fpp(12, 4, 9,1),fpp(12, 4, 9,2),fpp(12, 4, 9,3)/
     x-2.0373436D-06, 4.4924525D-09,-2.0563908D-09 /
      data fpp(12, 4,10,1),fpp(12, 4,10,2),fpp(12, 4,10,3)/
     x 2.0441527D-06, 3.0335364D-09,-5.5388507D-10 /
      data fpp(12, 4,11,1),fpp(12, 4,11,2),fpp(12, 4,11,3)/
     x 9.0932576D-06, 1.7873704D-09, 2.9385977D-09 /
      data fpp(12, 4,12,1),fpp(12, 4,12,2),fpp(12, 4,12,3)/
     x 1.0117077D-05, 5.8871006D-09,-5.3383925D-10 /
      data fpp(12, 4,13,1),fpp(12, 4,13,2),fpp(12, 4,13,3)/
     x 2.0037162D-06, 6.1599849D-09,-2.8032407D-09 /
      data fpp(12, 4,14,1),fpp(12, 4,14,2),fpp(12, 4,14,3)/
     x-1.2726263D-05, 8.8439962D-09,-2.5319779D-10 /
      data fpp(12, 4,15,1),fpp(12, 4,15,2),fpp(12, 4,15,3)/
     x-2.2106658D-05, 4.9944110D-09, 4.4826985D-09 /
      data fpp(12, 4,16,1),fpp(12, 4,16,2),fpp(12, 4,16,3)/
     x-1.2726263D-05, 8.8439962D-09,-3.4426308D-10 /
      data fpp(12, 4,17,1),fpp(12, 4,17,2),fpp(12, 4,17,3)/
     x 2.0037162D-06, 6.1599849D-09,-2.4389796D-09 /
      data fpp(12, 5, 1,1),fpp(12, 5, 1,2),fpp(12, 5, 1,3)/
     x-2.6595003D-07,-5.9686668D-10,-5.3146137D-09 /
      data fpp(12, 5, 2,1),fpp(12, 5, 2,2),fpp(12, 5, 2,3)/
     x-1.6231373D-05, 7.0050912D-09,-1.2596615D-09 /
      data fpp(12, 5, 3,1),fpp(12, 5, 3,2),fpp(12, 5, 3,3)/
     x-2.9016888D-05, 1.2636236D-08, 8.3532598D-09 /
      data fpp(12, 5, 4,1),fpp(12, 5, 4,2),fpp(12, 5, 4,3)/
     x-1.6231373D-05, 7.0050912D-09,-1.4867111D-09 /
      data fpp(12, 5, 5,1),fpp(12, 5, 5,2),fpp(12, 5, 5,3)/
     x-2.6595003D-07,-5.9686668D-10,-4.4064153D-09 /
      data fpp(12, 5, 6,1),fpp(12, 5, 6,2),fpp(12, 5, 6,3)/
     x 7.4864831D-06, 1.8442786D-09,-8.8762750D-10 /
      data fpp(12, 5, 7,1),fpp(12, 5, 7,2),fpp(12, 5, 7,3)/
     x 6.7162828D-06, 7.1394257D-09, 5.2902587D-09 /
      data fpp(12, 5, 8,1),fpp(12, 5, 8,2),fpp(12, 5, 8,3)/
     x 1.6189621D-07, 5.9518064D-09,-9.4007391D-10 /
      data fpp(12, 5, 9,1),fpp(12, 5, 9,2),fpp(12, 5, 9,3)/
     x-4.0090789D-06, 3.7012351D-09,-3.5299630D-09 /
      data fpp(12, 5,10,1),fpp(12, 5,10,2),fpp(12, 5,10,3)/
     x 1.6189621D-07, 5.9518064D-09,-9.4007391D-10 /
      data fpp(12, 5,11,1),fpp(12, 5,11,2),fpp(12, 5,11,3)/
     x 6.7162828D-06, 7.1394257D-09, 5.2902587D-09 /
      data fpp(12, 5,12,1),fpp(12, 5,12,2),fpp(12, 5,12,3)/
     x 7.4864831D-06, 1.8442786D-09,-8.8762750D-10 /
      data fpp(12, 5,13,1),fpp(12, 5,13,2),fpp(12, 5,13,3)/
     x-2.6595003D-07,-5.9686668D-10,-4.4064153D-09 /
      data fpp(12, 5,14,1),fpp(12, 5,14,2),fpp(12, 5,14,3)/
     x-1.6231373D-05, 7.0050912D-09,-1.4867111D-09 /
      data fpp(12, 5,15,1),fpp(12, 5,15,2),fpp(12, 5,15,3)/
     x-2.9016888D-05, 1.2636236D-08, 8.3532598D-09 /
      data fpp(12, 5,16,1),fpp(12, 5,16,2),fpp(12, 5,16,3)/
     x-1.6231373D-05, 7.0050912D-09,-1.2596615D-09 /
      data fpp(12, 5,17,1),fpp(12, 5,17,2),fpp(12, 5,17,3)/
     x-2.6595003D-07,-5.9686668D-10,-5.3146137D-09 /
      data fpp(12, 6, 1,1),fpp(12, 6, 1,2),fpp(12, 6, 1,3)/
     x-5.4201153D-06, 2.2274818D-09,-7.3798137D-09 /
      data fpp(12, 6, 2,1),fpp(12, 6, 2,2),fpp(12, 6, 2,3)/
     x-1.4835232D-05, 5.1356392D-09,-2.1292614D-09 /
      data fpp(12, 6, 3,1),fpp(12, 6, 3,2),fpp(12, 6, 3,3)/
     x-2.7266104D-05, 1.6460646D-08, 1.0563526D-08 /
      data fpp(12, 6, 4,1),fpp(12, 6, 4,2),fpp(12, 6, 4,3)/
     x-1.4835232D-05, 5.1356392D-09,-2.7915098D-09 /
      data fpp(12, 6, 5,1),fpp(12, 6, 5,2),fpp(12, 6, 5,3)/
     x-5.4201153D-06, 2.2274818D-09,-4.7308201D-09 /
      data fpp(12, 6, 6,1),fpp(12, 6, 6,2),fpp(12, 6, 6,3)/
     x 2.0438004D-06, 4.7357852D-09,-9.5187640D-10 /
      data fpp(12, 6, 7,1),fpp(12, 6, 7,2),fpp(12, 6, 7,3)/
     x 2.0948289D-06, 1.1654927D-08, 6.5383257D-09 /
      data fpp(12, 6, 8,1),fpp(12, 6, 8,2),fpp(12, 6, 8,3)/
     x-1.5907158D-06, 3.1592381D-09,-1.2014264D-09 /
      data fpp(12, 6, 9,1),fpp(12, 6, 9,2),fpp(12, 6, 9,3)/
     x-4.7830503D-06,-1.2973927D-09,-4.3992868D-09 /
      data fpp(12, 6,10,1),fpp(12, 6,10,2),fpp(12, 6,10,3)/
     x-1.5907158D-06, 3.1592381D-09,-1.2014264D-09 /
      data fpp(12, 6,11,1),fpp(12, 6,11,2),fpp(12, 6,11,3)/
     x 2.0948289D-06, 1.1654927D-08, 6.5383257D-09 /
      data fpp(12, 6,12,1),fpp(12, 6,12,2),fpp(12, 6,12,3)/
     x 2.0438004D-06, 4.7357852D-09,-9.5187640D-10 /
      data fpp(12, 6,13,1),fpp(12, 6,13,2),fpp(12, 6,13,3)/
     x-5.4201153D-06, 2.2274818D-09,-4.7308201D-09 /
      data fpp(12, 6,14,1),fpp(12, 6,14,2),fpp(12, 6,14,3)/
     x-1.4835232D-05, 5.1356392D-09,-2.7915098D-09 /
      data fpp(12, 6,15,1),fpp(12, 6,15,2),fpp(12, 6,15,3)/
     x-2.7266104D-05, 1.6460646D-08, 1.0563526D-08 /
      data fpp(12, 6,16,1),fpp(12, 6,16,2),fpp(12, 6,16,3)/
     x-1.4835232D-05, 5.1356392D-09,-2.1292614D-09 /
      data fpp(12, 6,17,1),fpp(12, 6,17,2),fpp(12, 6,17,3)/
     x-5.4201153D-06, 2.2274818D-09,-7.3798137D-09 /
      data fpp(12, 7, 1,1),fpp(12, 7, 1,2),fpp(12, 7, 1,3)/
     x-5.4783700D-06,-2.3130607D-09,-6.5714013D-09 /
      data fpp(12, 7, 2,1),fpp(12, 7, 2,2),fpp(12, 7, 2,3)/
     x-1.0295348D-05, 2.4523522D-09,-1.9683085D-09 /
      data fpp(12, 7, 3,1),fpp(12, 7, 3,2),fpp(12, 7, 3,3)/
     x-1.7984018D-05, 5.5211819D-09, 9.1113020D-09 /
      data fpp(12, 7, 4,1),fpp(12, 7, 4,2),fpp(12, 7, 4,3)/
     x-1.0295348D-05, 2.4523522D-09,-2.4768996D-09 /
      data fpp(12, 7, 5,1),fpp(12, 7, 5,2),fpp(12, 7, 5,3)/
     x-5.4783700D-06,-2.3130607D-09,-4.5370370D-09 /
      data fpp(12, 7, 6,1),fpp(12, 7, 6,2),fpp(12, 7, 6,3)/
     x-3.4381932D-06, 3.2125808D-09,-4.1618939D-11 /
      data fpp(12, 7, 7,1),fpp(12, 7, 7,2),fpp(12, 7, 7,3)/
     x-1.9302955D-06, 6.2408669D-09, 5.3701795D-09 /
      data fpp(12, 7, 8,1),fpp(12, 7, 8,2),fpp(12, 7, 8,3)/
     x-2.9223282D-06, 5.4112412D-09,-7.7243223D-10 /
      data fpp(12, 7, 9,1),fpp(12, 7, 9,2),fpp(12, 7, 9,3)/
     x-5.1554772D-06, 1.4883359D-09,-4.2804506D-09 /
      data fpp(12, 7,10,1),fpp(12, 7,10,2),fpp(12, 7,10,3)/
     x-2.9223282D-06, 5.4112412D-09,-7.7243223D-10 /
      data fpp(12, 7,11,1),fpp(12, 7,11,2),fpp(12, 7,11,3)/
     x-1.9302955D-06, 6.2408669D-09, 5.3701795D-09 /
      data fpp(12, 7,12,1),fpp(12, 7,12,2),fpp(12, 7,12,3)/
     x-3.4381932D-06, 3.2125808D-09,-4.1618939D-11 /
      data fpp(12, 7,13,1),fpp(12, 7,13,2),fpp(12, 7,13,3)/
     x-5.4783700D-06,-2.3130607D-09,-4.5370370D-09 /
      data fpp(12, 7,14,1),fpp(12, 7,14,2),fpp(12, 7,14,3)/
     x-1.0295348D-05, 2.4523522D-09,-2.4768996D-09 /
      data fpp(12, 7,15,1),fpp(12, 7,15,2),fpp(12, 7,15,3)/
     x-1.7984018D-05, 5.5211819D-09, 9.1113020D-09 /
      data fpp(12, 7,16,1),fpp(12, 7,16,2),fpp(12, 7,16,3)/
     x-1.0295348D-05, 2.4523522D-09,-1.9683085D-09 /
      data fpp(12, 7,17,1),fpp(12, 7,17,2),fpp(12, 7,17,3)/
     x-5.4783700D-06,-2.3130607D-09,-6.5714013D-09 /
      data fpp(12, 8, 1,1),fpp(12, 8, 1,2),fpp(12, 8, 1,3)/
     x-7.3163326D-06,-4.9752390D-09,-4.7336463D-09 /
      data fpp(12, 8, 2,1),fpp(12, 8, 2,2),fpp(12, 8, 2,3)/
     x-6.4269450D-06,-8.9450478D-09,-1.5327074D-09 /
      data fpp(12, 8, 3,1),fpp(12, 8, 3,2),fpp(12, 8, 3,3)/
     x-8.7808638D-06,-8.5453731D-09, 6.1978093D-09 /
      data fpp(12, 8, 4,1),fpp(12, 8, 4,2),fpp(12, 8, 4,3)/
     x-6.4269450D-06,-8.9450478D-09,-1.9251964D-09 /
      data fpp(12, 8, 5,1),fpp(12, 8, 5,2),fpp(12, 8, 5,3)/
     x-7.3163326D-06,-4.9752390D-09,-3.1636905D-09 /
      data fpp(12, 8, 6,1),fpp(12, 8, 6,2),fpp(12, 8, 6,3)/
     x-7.0656065D-06,-5.5861082D-09, 5.7995827D-10 /
      data fpp(12, 8, 7,1),fpp(12, 8, 7,2),fpp(12, 8, 7,3)/
     x-4.6774440D-06,-6.6183943D-09, 3.5105241D-09 /
      data fpp(12, 8, 8,1),fpp(12, 8, 8,2),fpp(12, 8, 8,3)/
     x-4.5742932D-06,-6.8042029D-09,-6.2205449D-10 /
      data fpp(12, 8, 9,1),fpp(12, 8, 9,2),fpp(12, 8, 9,3)/
     x-6.6276151D-06,-4.6559507D-09,-3.0223061D-09 /
      data fpp(12, 8,10,1),fpp(12, 8,10,2),fpp(12, 8,10,3)/
     x-4.5742932D-06,-6.8042029D-09,-6.2205449D-10 /
      data fpp(12, 8,11,1),fpp(12, 8,11,2),fpp(12, 8,11,3)/
     x-4.6774440D-06,-6.6183943D-09, 3.5105241D-09 /
      data fpp(12, 8,12,1),fpp(12, 8,12,2),fpp(12, 8,12,3)/
     x-7.0656065D-06,-5.5861082D-09, 5.7995827D-10 /
      data fpp(12, 8,13,1),fpp(12, 8,13,2),fpp(12, 8,13,3)/
     x-7.3163326D-06,-4.9752390D-09,-3.1636905D-09 /
      data fpp(12, 8,14,1),fpp(12, 8,14,2),fpp(12, 8,14,3)/
     x-6.4269450D-06,-8.9450478D-09,-1.9251964D-09 /
      data fpp(12, 8,15,1),fpp(12, 8,15,2),fpp(12, 8,15,3)/
     x-8.7808638D-06,-8.5453731D-09, 6.1978093D-09 /
      data fpp(12, 8,16,1),fpp(12, 8,16,2),fpp(12, 8,16,3)/
     x-6.4269450D-06,-8.9450478D-09,-1.5327074D-09 /
      data fpp(12, 8,17,1),fpp(12, 8,17,2),fpp(12, 8,17,3)/
     x-7.3163326D-06,-4.9752390D-09,-4.7336463D-09 /
      data fpp(12, 9, 1,1),fpp(12, 9, 1,2),fpp(12, 9, 1,3)/
     x-8.7712234D-06,-7.7859833D-09,-2.4794974D-09 /
      data fpp(12, 9, 2,1),fpp(12, 9, 2,2),fpp(12, 9, 2,3)/
     x-6.2387179D-06,-8.6721608D-09,-8.1878307D-10 /
      data fpp(12, 9, 3,1),fpp(12, 9, 3,2),fpp(12, 9, 3,3)/
     x-5.3837665D-06,-1.3339690D-08, 3.0879630D-09 /
      data fpp(12, 9, 4,1),fpp(12, 9, 4,2),fpp(12, 9, 4,3)/
     x-6.2387179D-06,-8.6721608D-09,-8.6640212D-10 /
      data fpp(12, 9, 5,1),fpp(12, 9, 5,2),fpp(12, 9, 5,3)/
     x-8.7712234D-06,-7.7859833D-09,-2.2890212D-09 /
      data fpp(12, 9, 6,1),fpp(12, 9, 6,2),fpp(12, 9, 6,3)/
     x-8.5268593D-06,-1.0868148D-08, 1.3558201D-09 /
      data fpp(12, 9, 7,1),fpp(12, 9, 7,2),fpp(12, 9, 7,3)/
     x-6.6851308D-06,-9.7672897D-09, 1.5324074D-09 /
      data fpp(12, 9, 8,1),fpp(12, 9, 8,2),fpp(12, 9, 8,3)/
     x-7.9775495D-06,-8.1944296D-09,-1.5211640D-10 /
      data fpp(12, 9, 9,1),fpp(12, 9, 9,2),fpp(12, 9, 9,3)/
     x-1.0559429D-05,-6.8645331D-09,-2.2572751D-09 /
      data fpp(12, 9,10,1),fpp(12, 9,10,2),fpp(12, 9,10,3)/
     x-7.9775495D-06,-8.1944296D-09,-1.5211640D-10 /
      data fpp(12, 9,11,1),fpp(12, 9,11,2),fpp(12, 9,11,3)/
     x-6.6851308D-06,-9.7672897D-09, 1.5324074D-09 /
      data fpp(12, 9,12,1),fpp(12, 9,12,2),fpp(12, 9,12,3)/
     x-8.5268593D-06,-1.0868148D-08, 1.3558201D-09 /
      data fpp(12, 9,13,1),fpp(12, 9,13,2),fpp(12, 9,13,3)/
     x-8.7712234D-06,-7.7859833D-09,-2.2890212D-09 /
      data fpp(12, 9,14,1),fpp(12, 9,14,2),fpp(12, 9,14,3)/
     x-6.2387179D-06,-8.6721608D-09,-8.6640212D-10 /
      data fpp(12, 9,15,1),fpp(12, 9,15,2),fpp(12, 9,15,3)/
     x-5.3837665D-06,-1.3339690D-08, 3.0879630D-09 /
      data fpp(12, 9,16,1),fpp(12, 9,16,2),fpp(12, 9,16,3)/
     x-6.2387179D-06,-8.6721608D-09,-8.1878307D-10 /
      data fpp(12, 9,17,1),fpp(12, 9,17,2),fpp(12, 9,17,3)/
     x-8.7712234D-06,-7.7859833D-09,-2.4794974D-09 /
      data fpp(12,10, 1,1),fpp(12,10, 1,2),fpp(12,10, 1,3)/
     x-1.0305418D-05,-1.1880828D-08,-1.2564740D-09 /
      data fpp(12,10, 2,1),fpp(12,10, 2,2),fpp(12,10, 2,3)/
     x-1.0392038D-05,-1.0366309D-08,-4.8705204D-10 /
      data fpp(12,10, 3,1),fpp(12,10, 3,2),fpp(12,10, 3,3)/
     x-9.2481529D-06,-1.0095869D-08, 1.2046821D-09 /
      data fpp(12,10, 4,1),fpp(12,10, 4,2),fpp(12,10, 4,3)/
     x-1.0392038D-05,-1.0366309D-08,-3.3167649D-10 /
      data fpp(12,10, 5,1),fpp(12,10, 5,2),fpp(12,10, 5,3)/
     x-1.0305418D-05,-1.1880828D-08,-1.8779762D-09 /
      data fpp(12,10, 6,1),fpp(12,10, 6,2),fpp(12,10, 6,3)/
     x-8.2147430D-06,-1.0941300D-08, 2.5102479D-09 /
      data fpp(12,10, 7,1),fpp(12,10, 7,2),fpp(12,10, 7,3)/
     x-8.9099270D-06,-1.4312447D-08,-1.6301546D-10 /
      data fpp(12,10, 8,1),fpp(12,10, 8,2),fpp(12,10, 8,3)/
     x-1.4228578D-05,-8.4180787D-09, 1.4181394D-10 /
      data fpp(12,10, 9,1),fpp(12,10, 9,2),fpp(12,10, 9,3)/
     x-1.8170321D-05,-9.8859169D-09,-1.7375736D-09 /
      data fpp(12,10,10,1),fpp(12,10,10,2),fpp(12,10,10,3)/
     x-1.4228578D-05,-8.4180787D-09, 1.4181394D-10 /
      data fpp(12,10,11,1),fpp(12,10,11,2),fpp(12,10,11,3)/
     x-8.9099270D-06,-1.4312447D-08,-1.6301546D-10 /
      data fpp(12,10,12,1),fpp(12,10,12,2),fpp(12,10,12,3)/
     x-8.2147430D-06,-1.0941300D-08, 2.5102479D-09 /
      data fpp(12,10,13,1),fpp(12,10,13,2),fpp(12,10,13,3)/
     x-1.0305418D-05,-1.1880828D-08,-1.8779762D-09 /
      data fpp(12,10,14,1),fpp(12,10,14,2),fpp(12,10,14,3)/
     x-1.0392038D-05,-1.0366309D-08,-3.3167649D-10 /
      data fpp(12,10,15,1),fpp(12,10,15,2),fpp(12,10,15,3)/
     x-9.2481529D-06,-1.0095869D-08, 1.2046821D-09 /
      data fpp(12,10,16,1),fpp(12,10,16,2),fpp(12,10,16,3)/
     x-1.0392038D-05,-1.0366309D-08,-4.8705204D-10 /
      data fpp(12,10,17,1),fpp(12,10,17,2),fpp(12,10,17,3)/
     x-1.0305418D-05,-1.1880828D-08,-1.2564740D-09 /
      data fpp(12,11, 1,1),fpp(12,11, 1,2),fpp(12,11, 1,3)/
     x-1.1941777D-05,-1.0690705D-08,-6.5199367D-10 /
      data fpp(12,11, 2,1),fpp(12,11, 2,2),fpp(12,11, 2,3)/
     x-1.8303775D-05,-9.8626031D-09,-4.7379043D-10 /
      data fpp(12,11, 3,1),fpp(12,11, 3,2),fpp(12,11, 3,3)/
     x-1.9329705D-05,-1.2276835D-08,-1.1951126D-10 /
      data fpp(12,11, 4,1),fpp(12,11, 4,2),fpp(12,11, 4,3)/
     x-1.8303775D-05,-9.8626031D-09,-3.8149785D-10 /
      data fpp(12,11, 5,1),fpp(12,11, 5,2),fpp(12,11, 5,3)/
     x-1.1941777D-05,-1.0690705D-08,-1.0211640D-09 /
      data fpp(12,11, 6,1),fpp(12,11, 6,2),fpp(12,11, 6,3)/
     x-6.1088462D-06,-1.1366653D-08, 3.1328206D-09 /
      data fpp(12,11, 7,1),fpp(12,11, 7,2),fpp(12,11, 7,3)/
     x-1.1712711D-05,-4.9829220D-09,-8.4345170D-10 /
      data fpp(12,11, 8,1),fpp(12,11, 8,2),fpp(12,11, 8,3)/
     x-2.4006241D-05,-1.2133256D-08,-4.2568047D-10 /
      data fpp(12,11, 9,1),fpp(12,11, 9,2),fpp(12,11, 9,3)/
     x-3.0155048D-05,-7.5917994D-09,-7.8715977D-10 /
      data fpp(12,11,10,1),fpp(12,11,10,2),fpp(12,11,10,3)/
     x-2.4006241D-05,-1.2133256D-08,-4.2568047D-10 /
      data fpp(12,11,11,1),fpp(12,11,11,2),fpp(12,11,11,3)/
     x-1.1712711D-05,-4.9829220D-09,-8.4345170D-10 /
      data fpp(12,11,12,1),fpp(12,11,12,2),fpp(12,11,12,3)/
     x-6.1088462D-06,-1.1366653D-08, 3.1328206D-09 /
      data fpp(12,11,13,1),fpp(12,11,13,2),fpp(12,11,13,3)/
     x-1.1941777D-05,-1.0690705D-08,-1.0211640D-09 /
      data fpp(12,11,14,1),fpp(12,11,14,2),fpp(12,11,14,3)/
     x-1.8303775D-05,-9.8626031D-09,-3.8149785D-10 /
      data fpp(12,11,15,1),fpp(12,11,15,2),fpp(12,11,15,3)/
     x-1.9329705D-05,-1.2276835D-08,-1.1951126D-10 /
      data fpp(12,11,16,1),fpp(12,11,16,2),fpp(12,11,16,3)/
     x-1.8303775D-05,-9.8626031D-09,-4.7379043D-10 /
      data fpp(12,11,17,1),fpp(12,11,17,2),fpp(12,11,17,3)/
     x-1.1941777D-05,-1.0690705D-08,-6.5199367D-10 /
      data fpp(12,12, 1,1),fpp(12,12, 1,2),fpp(12,12, 1,3)/
     x-1.2611893D-05,-5.3563514D-09,-1.0847174D-09 /
      data fpp(12,12, 2,1),fpp(12,12, 2,2),fpp(12,12, 2,3)/
     x-2.8378739D-05,-4.1832787D-09,-9.4167621D-10 /
      data fpp(12,12, 3,1),fpp(12,12, 3,2),fpp(12,12, 3,3)/
     x-3.3259717D-05,-6.7967899D-09,-4.8191103D-10 /
      data fpp(12,12, 4,1),fpp(12,12, 4,2),fpp(12,12, 4,3)/
     x-2.8378739D-05,-4.1832787D-09,-1.1306796D-09 /
      data fpp(12,12, 5,1),fpp(12,12, 5,2),fpp(12,12, 5,3)/
     x-1.2611893D-05,-5.3563514D-09,-3.2870370D-10 /
      data fpp(12,12, 6,1),fpp(12,12, 6,2),fpp(12,12, 6,3)/
     x-1.3411076D-06,-9.5920889D-09, 5.1121611D-09 /
      data fpp(12,12, 7,1),fpp(12,12, 7,2),fpp(12,12, 7,3)/
     x-1.4789027D-05,-7.7558648D-09,-3.4532742D-09 /
      data fpp(12,12, 8,1),fpp(12,12, 8,2),fpp(12,12, 8,3)/
     x-3.6862810D-05,-3.0488986D-09, 7.0093547D-10 /
      data fpp(12,12, 9,1),fpp(12,12, 9,2),fpp(12,12, 9,3)/
     x-4.6329576D-05,-7.7468857D-09,-1.3504677D-09 /
      data fpp(12,12,10,1),fpp(12,12,10,2),fpp(12,12,10,3)/
     x-3.6862810D-05,-3.0488986D-09, 7.0093547D-10 /
      data fpp(12,12,11,1),fpp(12,12,11,2),fpp(12,12,11,3)/
     x-1.4789027D-05,-7.7558648D-09,-3.4532742D-09 /
      data fpp(12,12,12,1),fpp(12,12,12,2),fpp(12,12,12,3)/
     x-1.3411076D-06,-9.5920889D-09, 5.1121611D-09 /
      data fpp(12,12,13,1),fpp(12,12,13,2),fpp(12,12,13,3)/
     x-1.2611893D-05,-5.3563514D-09,-3.2870370D-10 /
      data fpp(12,12,14,1),fpp(12,12,14,2),fpp(12,12,14,3)/
     x-2.8378739D-05,-4.1832787D-09,-1.1306796D-09 /
      data fpp(12,12,15,1),fpp(12,12,15,2),fpp(12,12,15,3)/
     x-3.3259717D-05,-6.7967899D-09,-4.8191103D-10 /
      data fpp(12,12,16,1),fpp(12,12,16,2),fpp(12,12,16,3)/
     x-2.8378739D-05,-4.1832787D-09,-9.4167621D-10 /
      data fpp(12,12,17,1),fpp(12,12,17,2),fpp(12,12,17,3)/
     x-1.2611893D-05,-5.3563514D-09,-1.0847174D-09 /
      data fpp(12,13, 1,1),fpp(12,13, 1,2),fpp(12,13, 1,3)/
     x-1.0156241D-05,-3.8838892D-09,-2.5539703D-09 /
      data fpp(12,13, 2,1),fpp(12,13, 2,2),fpp(12,13, 2,3)/
     x-3.7670366D-05,-3.4042821D-09,-1.8920594D-09 /
      data fpp(12,13, 3,1),fpp(12,13, 3,2),fpp(12,13, 3,3)/
     x-4.7294619D-05,-2.5360049D-09, 1.2220790D-10 /
      data fpp(12,13, 4,1),fpp(12,13, 4,2),fpp(12,13, 4,3)/
     x-3.7670366D-05,-3.4042821D-09,-2.5967722D-09 /
      data fpp(12,13, 5,1),fpp(12,13, 5,2),fpp(12,13, 5,3)/
     x-1.0156241D-05,-3.8838892D-09, 2.6488095D-10 /
      data fpp(12,13, 6,1),fpp(12,13, 6,2),fpp(12,13, 6,3)/
     x 7.2932477D-06, 1.7350083D-09, 7.5372484D-09 /
      data fpp(12,13, 7,1),fpp(12,13, 7,2),fpp(12,13, 7,3)/
     x-1.6825043D-05,-5.9936189D-09,-5.7472079D-09 /
      data fpp(12,13, 8,1),fpp(12,13, 8,2),fpp(12,13, 8,3)/
     x-5.0862920D-05,-5.6711499D-09, 7.8491654D-10 /
      data fpp(12,13, 9,1),fpp(12,13, 9,2),fpp(12,13, 9,3)/
     x-6.4545577D-05,-3.4206580D-09,-7.2579161D-10 /
      data fpp(12,13,10,1),fpp(12,13,10,2),fpp(12,13,10,3)/
     x-5.0862920D-05,-5.6711499D-09, 7.8491654D-10 /
      data fpp(12,13,11,1),fpp(12,13,11,2),fpp(12,13,11,3)/
     x-1.6825043D-05,-5.9936189D-09,-5.7472079D-09 /
      data fpp(12,13,12,1),fpp(12,13,12,2),fpp(12,13,12,3)/
     x 7.2932477D-06, 1.7350083D-09, 7.5372484D-09 /
      data fpp(12,13,13,1),fpp(12,13,13,2),fpp(12,13,13,3)/
     x-1.0156241D-05,-3.8838892D-09, 2.6488095D-10 /
      data fpp(12,13,14,1),fpp(12,13,14,2),fpp(12,13,14,3)/
     x-3.7670366D-05,-3.4042821D-09,-2.5967722D-09 /
      data fpp(12,13,15,1),fpp(12,13,15,2),fpp(12,13,15,3)/
     x-4.7294619D-05,-2.5360049D-09, 1.2220790D-10 /
      data fpp(12,13,16,1),fpp(12,13,16,2),fpp(12,13,16,3)/
     x-3.7670366D-05,-3.4042821D-09,-1.8920594D-09 /
      data fpp(12,13,17,1),fpp(12,13,17,2),fpp(12,13,17,3)/
     x-1.0156241D-05,-3.8838892D-09,-2.5539703D-09 /
      data fpp(12,14, 1,1),fpp(12,14, 1,2),fpp(12,14, 1,3)/
     x-2.8977104D-06, 8.8919081D-09,-3.8032748D-09 /
      data fpp(12,14, 2,1),fpp(12,14, 2,2),fpp(12,14, 2,3)/
     x-4.1839567D-05,-1.9959280D-10,-2.7267837D-09 /
      data fpp(12,14, 3,1),fpp(12,14, 3,2),fpp(12,14, 3,3)/
     x-5.6269825D-05,-1.0591904D-09, 7.1040951D-10 /
      data fpp(12,14, 4,1),fpp(12,14, 4,2),fpp(12,14, 4,3)/
     x-4.1839567D-05,-1.9959280D-10,-4.1148544D-09 /
      data fpp(12,14, 5,1),fpp(12,14, 5,2),fpp(12,14, 5,3)/
     x-2.8977104D-06, 8.8919081D-09, 1.7490079D-09 /
      data fpp(12,14, 6,1),fpp(12,14, 6,2),fpp(12,14, 6,3)/
     x 1.9088712D-05, 8.6520555D-09, 7.7854893D-09 /
      data fpp(12,14, 7,1),fpp(12,14, 7,2),fpp(12,14, 7,3)/
     x-1.6461198D-05, 1.7303405D-09,-6.2242984D-09 /
      data fpp(12,14, 8,1),fpp(12,14, 8,2),fpp(12,14, 8,3)/
     x-6.2233017D-05, 1.7334984D-09, 4.4503764D-10 /
      data fpp(12,14, 9,1),fpp(12,14, 9,2),fpp(12,14, 9,3)/
     x-8.0334805D-05, 3.4295175D-09,-2.2251882D-10 /
      data fpp(12,14,10,1),fpp(12,14,10,2),fpp(12,14,10,3)/
     x-6.2233017D-05, 1.7334984D-09, 4.4503764D-10 /
      data fpp(12,14,11,1),fpp(12,14,11,2),fpp(12,14,11,3)/
     x-1.6461198D-05, 1.7303405D-09,-6.2242984D-09 /
      data fpp(12,14,12,1),fpp(12,14,12,2),fpp(12,14,12,3)/
     x 1.9088712D-05, 8.6520555D-09, 7.7854893D-09 /
      data fpp(12,14,13,1),fpp(12,14,13,2),fpp(12,14,13,3)/
     x-2.8977104D-06, 8.8919081D-09, 1.7490079D-09 /
      data fpp(12,14,14,1),fpp(12,14,14,2),fpp(12,14,14,3)/
     x-4.1839567D-05,-1.9959280D-10,-4.1148544D-09 /
      data fpp(12,14,15,1),fpp(12,14,15,2),fpp(12,14,15,3)/
     x-5.6269825D-05,-1.0591904D-09, 7.1040951D-10 /
      data fpp(12,14,16,1),fpp(12,14,16,2),fpp(12,14,16,3)/
     x-4.1839567D-05,-1.9959280D-10,-2.7267837D-09 /
      data fpp(12,14,17,1),fpp(12,14,17,2),fpp(12,14,17,3)/
     x-2.8977104D-06, 8.8919081D-09,-3.8032748D-09 /
      data fpp(12,15, 1,1),fpp(12,15, 1,2),fpp(12,15, 1,3)/
     x 8.0636606D-06, 1.0316257D-08,-3.5878061D-09 /
      data fpp(12,15, 2,1),fpp(12,15, 2,2),fpp(12,15, 2,3)/
     x-3.6509440D-05, 4.2026533D-09,-2.6021655D-09 /
      data fpp(12,15, 3,1),fpp(12,15, 3,2),fpp(12,15, 3,3)/
     x-5.4284746D-05, 6.7727665D-09, 6.6313478D-10 /
      data fpp(12,15, 4,1),fpp(12,15, 4,2),fpp(12,15, 4,3)/
     x-3.6509440D-05, 4.2026533D-09,-4.0503736D-09 /
      data fpp(12,15, 5,1),fpp(12,15, 5,2),fpp(12,15, 5,3)/
     x 8.0636606D-06, 1.0316257D-08, 2.2050265D-09 /
      data fpp(12,15, 6,1),fpp(12,15, 6,2),fpp(12,15, 6,3)/
     x 2.9787593D-05, 1.1656770D-08, 6.5636012D-09 /
      data fpp(12,15, 7,1),fpp(12,15, 7,2),fpp(12,15, 7,3)/
     x-1.3194952D-05, 5.0722568D-09,-5.1260977D-09 /
      data fpp(12,15, 8,1),fpp(12,15, 8,2),fpp(12,15, 8,3)/
     x-6.5975980D-05, 4.7371565D-09,-5.9210167D-11 /
      data fpp(12,15, 9,1),fpp(12,15, 9,2),fpp(12,15, 9,3)/
     x-8.6921638D-05, 1.7025878D-09, 2.9605084D-11 /
      data fpp(12,15,10,1),fpp(12,15,10,2),fpp(12,15,10,3)/
     x-6.5975980D-05, 4.7371565D-09,-5.9210167D-11 /
      data fpp(12,15,11,1),fpp(12,15,11,2),fpp(12,15,11,3)/
     x-1.3194952D-05, 5.0722568D-09,-5.1260977D-09 /
      data fpp(12,15,12,1),fpp(12,15,12,2),fpp(12,15,12,3)/
     x 2.9787593D-05, 1.1656770D-08, 6.5636012D-09 /
      data fpp(12,15,13,1),fpp(12,15,13,2),fpp(12,15,13,3)/
     x 8.0636606D-06, 1.0316257D-08, 2.2050265D-09 /
      data fpp(12,15,14,1),fpp(12,15,14,2),fpp(12,15,14,3)/
     x-3.6509440D-05, 4.2026533D-09,-4.0503736D-09 /
      data fpp(12,15,15,1),fpp(12,15,15,2),fpp(12,15,15,3)/
     x-5.4284746D-05, 6.7727665D-09, 6.6313478D-10 /
      data fpp(12,15,16,1),fpp(12,15,16,2),fpp(12,15,16,3)/
     x-3.6509440D-05, 4.2026533D-09,-2.6021655D-09 /
      data fpp(12,15,17,1),fpp(12,15,17,2),fpp(12,15,17,3)/
     x 8.0636606D-06, 1.0316257D-08,-3.5878061D-09 /
      data fpp(12,16, 1,1),fpp(12,16, 1,2),fpp(12,16, 1,3)/
     x 1.8166905D-05, 9.8430652D-09,-1.7049855D-09 /
      data fpp(12,16, 2,1),fpp(12,16, 2,2),fpp(12,16, 2,3)/
     x-2.0896286D-05, 7.3889795D-09,-1.4789178D-09 /
      data fpp(12,16, 3,1),fpp(12,16, 3,2),fpp(12,16, 3,3)/
     x-3.7941829D-05, 3.9681244D-09,-3.7934326D-10 /
      data fpp(12,16, 4,1),fpp(12,16, 4,2),fpp(12,16, 4,3)/
     x-2.0896286D-05, 7.3889795D-09,-2.3370425D-09 /
      data fpp(12,16, 5,1),fpp(12,16, 5,2),fpp(12,16, 5,3)/
     x 1.8166905D-05, 9.8430652D-09, 1.7275132D-09 /
      data fpp(12,16, 6,1),fpp(12,16, 6,2),fpp(12,16, 6,3)/
     x 3.3033219D-05, 1.0720866D-08, 4.0936562D-09 /
      data fpp(12,16, 7,1),fpp(12,16, 7,2),fpp(12,16, 7,3)/
     x-7.8531208D-06, 7.9806322D-09,-2.7688049D-09 /
      data fpp(12,16, 8,1),fpp(12,16, 8,2),fpp(12,16, 8,3)/
     x-5.7525973D-05, 3.3178756D-09,-1.0184367D-09 /
      data fpp(12,16, 9,1),fpp(12,16, 9,2),fpp(12,16, 9,3)/
     x-7.7663292D-05, 7.7601311D-09, 8.4255168D-10 /
      data fpp(12,16,10,1),fpp(12,16,10,2),fpp(12,16,10,3)/
     x-5.7525973D-05, 3.3178756D-09,-1.0184367D-09 /
      data fpp(12,16,11,1),fpp(12,16,11,2),fpp(12,16,11,3)/
     x-7.8531208D-06, 7.9806322D-09,-2.7688049D-09 /
      data fpp(12,16,12,1),fpp(12,16,12,2),fpp(12,16,12,3)/
     x 3.3033219D-05, 1.0720866D-08, 4.0936562D-09 /
      data fpp(12,16,13,1),fpp(12,16,13,2),fpp(12,16,13,3)/
     x 1.8166905D-05, 9.8430652D-09, 1.7275132D-09 /
      data fpp(12,16,14,1),fpp(12,16,14,2),fpp(12,16,14,3)/
     x-2.0896286D-05, 7.3889795D-09,-2.3370425D-09 /
      data fpp(12,16,15,1),fpp(12,16,15,2),fpp(12,16,15,3)/
     x-3.7941829D-05, 3.9681244D-09,-3.7934326D-10 /
      data fpp(12,16,16,1),fpp(12,16,16,2),fpp(12,16,16,3)/
     x-2.0896286D-05, 7.3889795D-09,-1.4789178D-09 /
      data fpp(12,16,17,1),fpp(12,16,17,2),fpp(12,16,17,3)/
     x 1.8166905D-05, 9.8430652D-09,-1.7049855D-09 /
      data fpp(12,17, 1,1),fpp(12,17, 1,2),fpp(12,17, 1,3)/
     x 2.1885181D-05, 4.3114824D-09,-2.2812006D-10 /
      data fpp(12,17, 2,1),fpp(12,17, 2,2),fpp(12,17, 2,3)/
     x-3.6044835D-07, 8.2414286D-09,-4.3264878D-10 /
      data fpp(12,17, 3,1),fpp(12,17, 3,2),fpp(12,17, 3,3)/
     x-1.1276660D-05, 7.3547357D-09,-7.0795151D-10 /
      data fpp(12,17, 4,1),fpp(12,17, 4,2),fpp(12,17, 4,3)/
     x-3.6044835D-07, 8.2414286D-09,-7.3554519D-10 /
      data fpp(12,17, 5,1),fpp(12,17, 5,2),fpp(12,17, 5,3)/
     x 2.1885181D-05, 4.3114824D-09, 9.8346561D-10 /
      data fpp(12,17, 6,1),fpp(12,17, 6,2),fpp(12,17, 6,3)/
     x 2.5922232D-05,-5.4023312D-10, 1.4683494D-09 /
      data fpp(12,17, 7,1),fpp(12,17, 7,2),fpp(12,17, 7,3)/
     x-2.2635933D-06, 5.0052144D-09,-8.5686331D-10 /
      data fpp(12,17, 8,1),fpp(12,17, 8,2),fpp(12,17, 8,3)/
     x-3.6690540D-05, 5.9913412D-09,-7.0756286D-10 /
      data fpp(12,17, 9,1),fpp(12,17, 9,2),fpp(12,17, 9,3)/
     x-5.1195385D-05, 3.2568878D-09, 3.5378143D-10 /
      data fpp(12,17,10,1),fpp(12,17,10,2),fpp(12,17,10,3)/
     x-3.6690540D-05, 5.9913412D-09,-7.0756286D-10 /
      data fpp(12,17,11,1),fpp(12,17,11,2),fpp(12,17,11,3)/
     x-2.2635933D-06, 5.0052144D-09,-8.5686331D-10 /
      data fpp(12,17,12,1),fpp(12,17,12,2),fpp(12,17,12,3)/
     x 2.5922232D-05,-5.4023312D-10, 1.4683494D-09 /
      data fpp(12,17,13,1),fpp(12,17,13,2),fpp(12,17,13,3)/
     x 2.1885181D-05, 4.3114824D-09, 9.8346561D-10 /
      data fpp(12,17,14,1),fpp(12,17,14,2),fpp(12,17,14,3)/
     x-3.6044835D-07, 8.2414286D-09,-7.3554519D-10 /
      data fpp(12,17,15,1),fpp(12,17,15,2),fpp(12,17,15,3)/
     x-1.1276660D-05, 7.3547357D-09,-7.0795151D-10 /
      data fpp(12,17,16,1),fpp(12,17,16,2),fpp(12,17,16,3)/
     x-3.6044835D-07, 8.2414286D-09,-4.3264878D-10 /
      data fpp(12,17,17,1),fpp(12,17,17,2),fpp(12,17,17,3)/
     x 2.1885181D-05, 4.3114824D-09,-2.2812006D-10 /
      data fpp(12,18, 1,1),fpp(12,18, 1,2),fpp(12,18, 1,3)/
     x 1.7630493D-05,-3.0889950D-09, 2.0233322D-10 /
      data fpp(12,18, 2,1),fpp(12,18, 2,2),fpp(12,18, 2,3)/
     x 1.3749698D-05, 1.6453061D-09, 3.9777996D-11 /
      data fpp(12,18, 3,1),fpp(12,18, 3,2),fpp(12,18, 3,3)/
     x 1.1055399D-05, 2.6129326D-09,-3.6144521D-10 /
      data fpp(12,18, 4,1),fpp(12,18, 4,2),fpp(12,18, 4,3)/
     x 1.3749698D-05, 1.6453061D-09, 7.2669503D-11 /
      data fpp(12,18, 5,1),fpp(12,18, 5,2),fpp(12,18, 5,3)/
     x 1.7630493D-05,-3.0889950D-09, 7.0767196D-11 /
      data fpp(12,18, 6,1),fpp(12,18, 6,2),fpp(12,18, 6,3)/
     x 1.5250167D-05,-2.5599334D-09, 3.1092838D-10 /
      data fpp(12,18, 7,1),fpp(12,18, 7,2),fpp(12,18, 7,3)/
     x 3.4459272D-06, 1.9985102D-09, 1.8852616D-11 /
      data fpp(12,18, 8,1),fpp(12,18, 8,2),fpp(12,18, 8,3)/
     x-1.0096057D-05, 2.7167597D-09,-3.8633884D-10 /
      data fpp(12,18, 9,1),fpp(12,18, 9,2),fpp(12,18, 9,3)/
     x-1.5921998D-05, 3.2123178D-09, 1.9316942D-10 /
      data fpp(12,18,10,1),fpp(12,18,10,2),fpp(12,18,10,3)/
     x-1.0096057D-05, 2.7167597D-09,-3.8633884D-10 /
      data fpp(12,18,11,1),fpp(12,18,11,2),fpp(12,18,11,3)/
     x 3.4459272D-06, 1.9985102D-09, 1.8852616D-11 /
      data fpp(12,18,12,1),fpp(12,18,12,2),fpp(12,18,12,3)/
     x 1.5250167D-05,-2.5599334D-09, 3.1092838D-10 /
      data fpp(12,18,13,1),fpp(12,18,13,2),fpp(12,18,13,3)/
     x 1.7630493D-05,-3.0889950D-09, 7.0767196D-11 /
      data fpp(12,18,14,1),fpp(12,18,14,2),fpp(12,18,14,3)/
     x 1.3749698D-05, 1.6453061D-09, 7.2669503D-11 /
      data fpp(12,18,15,1),fpp(12,18,15,2),fpp(12,18,15,3)/
     x 1.1055399D-05, 2.6129326D-09,-3.6144521D-10 /
      data fpp(12,18,16,1),fpp(12,18,16,2),fpp(12,18,16,3)/
     x 1.3749698D-05, 1.6453061D-09, 3.9777996D-11 /
      data fpp(12,18,17,1),fpp(12,18,17,2),fpp(12,18,17,3)/
     x 1.7630493D-05,-3.0889950D-09, 2.0233322D-10 /
      data fpp(12,19, 1,1),fpp(12,19, 1,2),fpp(12,19, 1,3)/
     x 1.0489241D-05,-9.9555025D-09,-7.3558262D-24 /
      data fpp(12,19, 2,1),fpp(12,19, 2,2),fpp(12,19, 2,3)/
     x 1.0489241D-05,-2.8226531D-09,-2.3752906D-23 /
      data fpp(12,19, 3,1),fpp(12,19, 3,2),fpp(12,19, 3,3)/
     x 1.0489241D-05, 1.9353368D-10,-1.0395539D-23 /
      data fpp(12,19, 4,1),fpp(12,19, 4,2),fpp(12,19, 4,3)/
     x 1.0489241D-05,-2.8226531D-09, 4.4045772D-24 /
      data fpp(12,19, 5,1),fpp(12,19, 5,2),fpp(12,19, 5,3)/
     x 1.0489241D-05,-9.9555025D-09,-7.8043030D-24 /
      data fpp(12,19, 6,1),fpp(12,19, 6,2),fpp(12,19, 6,3)/
     x 1.0489241D-05,-7.2200333D-09,-1.1028536D-23 /
      data fpp(12,19, 7,1),fpp(12,19, 7,2),fpp(12,19, 7,3)/
     x 1.0489241D-05,-9.9925508D-10,-5.7818000D-24 /
      data fpp(12,19, 8,1),fpp(12,19, 8,2),fpp(12,19, 8,3)/
     x 1.0489241D-05, 1.1416202D-09, 1.9028832D-23 /
      data fpp(12,19, 9,1),fpp(12,19, 9,2),fpp(12,19, 9,3)/
     x 1.0489241D-05, 1.8938411D-09, 3.2407261D-24 /
      data fpp(12,19,10,1),fpp(12,19,10,2),fpp(12,19,10,3)/
     x 1.0489241D-05, 1.1416202D-09,-1.3658011D-23 /
      data fpp(12,19,11,1),fpp(12,19,11,2),fpp(12,19,11,3)/
     x 1.0489241D-05,-9.9925508D-10, 1.1482660D-23 /
      data fpp(12,19,12,1),fpp(12,19,12,2),fpp(12,19,12,3)/
     x 1.0489241D-05,-7.2200333D-09,-1.4867486D-23 /
      data fpp(12,19,13,1),fpp(12,19,13,2),fpp(12,19,13,3)/
     x 1.0489241D-05,-9.9555025D-09, 1.1079208D-25 /
      data fpp(12,19,14,1),fpp(12,19,14,2),fpp(12,19,14,3)/
     x 1.0489241D-05,-2.8226531D-09, 8.7104217D-25 /
      data fpp(12,19,15,1),fpp(12,19,15,2),fpp(12,19,15,3)/
     x 1.0489241D-05, 1.9353368D-10, 7.0604516D-24 /
      data fpp(12,19,16,1),fpp(12,19,16,2),fpp(12,19,16,3)/
     x 1.0489241D-05,-2.8226531D-09, 2.0583448D-24 /
      data fpp(12,19,17,1),fpp(12,19,17,2),fpp(12,19,17,3)/
     x 1.0489241D-05,-9.9555025D-09,-1.5270499D-23 /
      data fpp(13, 1, 1,1),fpp(13, 1, 1,2),fpp(13, 1, 1,3)/
     x-1.4912999D-05, 2.1057655D-09, 7.6207252D-24 /
      data fpp(13, 1, 2,1),fpp(13, 1, 2,2),fpp(13, 1, 2,3)/
     x-1.4912999D-05, 5.9129538D-09,-8.0886403D-24 /
      data fpp(13, 1, 3,1),fpp(13, 1, 3,2),fpp(13, 1, 3,3)/
     x-1.4912999D-05, 4.7594601D-09,-5.4423608D-24 /
      data fpp(13, 1, 4,1),fpp(13, 1, 4,2),fpp(13, 1, 4,3)/
     x-1.4912999D-05, 5.9129538D-09,-8.9304713D-25 /
      data fpp(13, 1, 5,1),fpp(13, 1, 5,2),fpp(13, 1, 5,3)/
     x-1.4912999D-05, 2.1057655D-09,-1.6208831D-24 /
      data fpp(13, 1, 6,1),fpp(13, 1, 6,2),fpp(13, 1, 6,3)/
     x-1.4912999D-05, 9.6782894D-10,-1.1673303D-24 /
      data fpp(13, 1, 7,1),fpp(13, 1, 7,2),fpp(13, 1, 7,3)/
     x-1.4912999D-05, 1.1155604D-09,-3.0237931D-24 /
      data fpp(13, 1, 8,1),fpp(13, 1, 8,2),fpp(13, 1, 8,3)/
     x-1.4912999D-05, 3.8055862D-09, 6.8290255D-24 /
      data fpp(13, 1, 9,1),fpp(13, 1, 9,2),fpp(13, 1, 9,3)/
     x-1.4912999D-05, 1.8901316D-09, 1.7656440D-24 /
      data fpp(13, 1,10,1),fpp(13, 1,10,2),fpp(13, 1,10,3)/
     x-1.4912999D-05, 3.8055862D-09,-4.0996985D-24 /
      data fpp(13, 1,11,1),fpp(13, 1,11,2),fpp(13, 1,11,3)/
     x-1.4912999D-05, 1.1155604D-09, 1.3247274D-24 /
      data fpp(13, 1,12,1),fpp(13, 1,12,2),fpp(13, 1,12,3)/
     x-1.4912999D-05, 9.6782894D-10, 6.6398952D-26 /
      data fpp(13, 1,13,1),fpp(13, 1,13,2),fpp(13, 1,13,3)/
     x-1.4912999D-05, 2.1057655D-09,-7.4498145D-25 /
      data fpp(13, 1,14,1),fpp(13, 1,14,2),fpp(13, 1,14,3)/
     x-1.4912999D-05, 5.9129538D-09, 2.3884270D-24 /
      data fpp(13, 1,15,1),fpp(13, 1,15,2),fpp(13, 1,15,3)/
     x-1.4912999D-05, 4.7594601D-09, 2.3291540D-24 /
      data fpp(13, 1,16,1),fpp(13, 1,16,2),fpp(13, 1,16,3)/
     x-1.4912999D-05, 5.9129538D-09,-9.1343546D-25 /
      data fpp(13, 1,17,1),fpp(13, 1,17,2),fpp(13, 1,17,3)/
     x-1.4912999D-05, 2.1057655D-09,-1.2760783D-24 /
      data fpp(13, 2, 1,1),fpp(13, 2, 1,2),fpp(13, 2, 1,3)/
     x-1.2906925D-05, 1.7884689D-09, 2.1068224D-10 /
      data fpp(13, 2, 2,1),fpp(13, 2, 2,2),fpp(13, 2, 2,3)/
     x-6.0706731D-06, 3.1740925D-09, 1.3419108D-10 /
      data fpp(13, 2, 3,1),fpp(13, 2, 3,2),fpp(13, 2, 3,3)/
     x-2.9327033D-06, 2.4810799D-09,-8.0779878D-11 /
      data fpp(13, 2, 4,1),fpp(13, 2, 4,2),fpp(13, 2, 4,3)/
     x-6.0706731D-06, 3.1740925D-09, 1.8892844D-10 /
      data fpp(13, 2, 5,1),fpp(13, 2, 5,2),fpp(13, 2, 5,3)/
     x-1.2906925D-05, 1.7884689D-09,-8.2671958D-12 /
      data fpp(13, 2, 6,1),fpp(13, 2, 6,2),fpp(13, 2, 6,3)/
     x-1.7969798D-05, 1.0643421D-09,-1.5585965D-10 /
      data fpp(13, 2, 7,1),fpp(13, 2, 7,2),fpp(13, 2, 7,3)/
     x-1.8276916D-05, 7.6887918D-10,-3.4960863D-11 /
      data fpp(13, 2, 8,1),fpp(13, 2, 8,2),fpp(13, 2, 8,3)/
     x-1.5229044D-05, 2.3888277D-09, 2.9570310D-10 /
      data fpp(13, 2, 9,1),fpp(13, 2, 9,2),fpp(13, 2, 9,3)/
     x-1.3443057D-05, 1.2197368D-09,-4.8118489D-10 /
      data fpp(13, 2,10,1),fpp(13, 2,10,2),fpp(13, 2,10,3)/
     x-1.5229044D-05, 2.3888277D-09, 2.9570310D-10 /
      data fpp(13, 2,11,1),fpp(13, 2,11,2),fpp(13, 2,11,3)/
     x-1.8276916D-05, 7.6887918D-10,-3.4960863D-11 /
      data fpp(13, 2,12,1),fpp(13, 2,12,2),fpp(13, 2,12,3)/
     x-1.7969798D-05, 1.0643421D-09,-1.5585965D-10 /
      data fpp(13, 2,13,1),fpp(13, 2,13,2),fpp(13, 2,13,3)/
     x-1.2906925D-05, 1.7884689D-09,-8.2671958D-12 /
      data fpp(13, 2,14,1),fpp(13, 2,14,2),fpp(13, 2,14,3)/
     x-6.0706731D-06, 3.1740925D-09, 1.8892844D-10 /
      data fpp(13, 2,15,1),fpp(13, 2,15,2),fpp(13, 2,15,3)/
     x-2.9327033D-06, 2.4810799D-09,-8.0779878D-11 /
      data fpp(13, 2,16,1),fpp(13, 2,16,2),fpp(13, 2,16,3)/
     x-6.0706731D-06, 3.1740925D-09, 1.3419108D-10 /
      data fpp(13, 2,17,1),fpp(13, 2,17,2),fpp(13, 2,17,3)/
     x-1.2906925D-05, 1.7884689D-09, 2.1068224D-10 /
      data fpp(13, 3, 1,1),fpp(13, 3, 1,2),fpp(13, 3, 1,3)/
     x-1.0826834D-05, 2.7403588D-09,-2.0067638D-10 /
      data fpp(13, 3, 2,1),fpp(13, 3, 2,2),fpp(13, 3, 2,3)/
     x 9.6224985D-06,-6.0932366D-10,-4.3091693D-11 /
      data fpp(13, 3, 3,1),fpp(13, 3, 3,2),fpp(13, 3, 3,3)/
     x 2.0464330D-05,-2.6837795D-09, 3.7304315D-10 /
      data fpp(13, 3, 4,1),fpp(13, 3, 4,2),fpp(13, 3, 4,3)/
     x 9.6224985D-06,-6.0932366D-10,-1.1574756D-10 /
      data fpp(13, 3, 5,1),fpp(13, 3, 5,2),fpp(13, 3, 5,3)/
     x-1.0826834D-05, 2.7403588D-09, 8.9947090D-11 /
      data fpp(13, 3, 6,1),fpp(13, 3, 6,2),fpp(13, 3, 6,3)/
     x-2.4667205D-05, 7.7480258D-10,-2.4404080D-10 /
      data fpp(13, 3, 7,1),fpp(13, 3, 7,2),fpp(13, 3, 7,3)/
     x-2.3619687D-05, 1.8089229D-09, 2.1954945D-10 /
      data fpp(13, 3, 8,1),fpp(13, 3, 8,2),fpp(13, 3, 8,3)/
     x-1.1782690D-05,-1.3608969D-09, 3.2509682D-11 /
      data fpp(13, 3, 9,1),fpp(13, 3, 9,2),fpp(13, 3, 9,3)/
     x-4.7882131D-06,-7.6907877D-10,-3.4958817D-10 /
      data fpp(13, 3,10,1),fpp(13, 3,10,2),fpp(13, 3,10,3)/
     x-1.1782690D-05,-1.3608969D-09, 3.2509682D-11 /
      data fpp(13, 3,11,1),fpp(13, 3,11,2),fpp(13, 3,11,3)/
     x-2.3619687D-05, 1.8089229D-09, 2.1954945D-10 /
      data fpp(13, 3,12,1),fpp(13, 3,12,2),fpp(13, 3,12,3)/
     x-2.4667205D-05, 7.7480258D-10,-2.4404080D-10 /
      data fpp(13, 3,13,1),fpp(13, 3,13,2),fpp(13, 3,13,3)/
     x-1.0826834D-05, 2.7403588D-09, 8.9947090D-11 /
      data fpp(13, 3,14,1),fpp(13, 3,14,2),fpp(13, 3,14,3)/
     x 9.6224985D-06,-6.0932366D-10,-1.1574756D-10 /
      data fpp(13, 3,15,1),fpp(13, 3,15,2),fpp(13, 3,15,3)/
     x 2.0464330D-05,-2.6837795D-09, 3.7304315D-10 /
      data fpp(13, 3,16,1),fpp(13, 3,16,2),fpp(13, 3,16,3)/
     x 9.6224985D-06,-6.0932366D-10,-4.3091693D-11 /
      data fpp(13, 3,17,1),fpp(13, 3,17,2),fpp(13, 3,17,3)/
     x-1.0826834D-05, 2.7403588D-09,-2.0067638D-10 /
      data fpp(13, 4, 1,1),fpp(13, 4, 1,2),fpp(13, 4, 1,3)/
     x-6.6386438D-06,-7.4990416D-10,-6.0982245D-10 /
      data fpp(13, 4, 2,1),fpp(13, 4, 2,2),fpp(13, 4, 2,3)/
     x 2.5893132D-05,-7.3679782D-10,-1.1368843D-10 /
      data fpp(13, 4, 3,1),fpp(13, 4, 3,2),fpp(13, 4, 3,3)/
     x 4.6099758D-05, 2.2540383D-09, 1.0645762D-09 /
      data fpp(13, 4, 4,1),fpp(13, 4, 4,2),fpp(13, 4, 4,3)/
     x 2.5893132D-05,-7.3679782D-10,-1.4461627D-10 /
      data fpp(13, 4, 5,1),fpp(13, 4, 5,2),fpp(13, 4, 5,3)/
     x-6.6386438D-06,-7.4990416D-10,-4.8611111D-10 /
      data fpp(13, 4, 6,1),fpp(13, 4, 6,2),fpp(13, 4, 6,3)/
     x-2.7381753D-05, 1.8364476D-09, 8.9060710D-11 /
      data fpp(13, 4, 7,1),fpp(13, 4, 7,2),fpp(13, 4, 7,3)/
     x-2.6708057D-05,-2.0045706D-09, 1.2986827D-10 /
      data fpp(13, 4, 8,1),fpp(13, 4, 8,2),fpp(13, 4, 8,3)/
     x-7.7442192D-06, 3.0547601D-09, 5.8132875D-11 /
      data fpp(13, 4, 9,1),fpp(13, 4, 9,2),fpp(13, 4, 9,3)/
     x 4.1333147D-06, 1.8565783D-09,-3.6239977D-10 /
      data fpp(13, 4,10,1),fpp(13, 4,10,2),fpp(13, 4,10,3)/
     x-7.7442192D-06, 3.0547601D-09, 5.8132875D-11 /
      data fpp(13, 4,11,1),fpp(13, 4,11,2),fpp(13, 4,11,3)/
     x-2.6708057D-05,-2.0045706D-09, 1.2986827D-10 /
      data fpp(13, 4,12,1),fpp(13, 4,12,2),fpp(13, 4,12,3)/
     x-2.7381753D-05, 1.8364476D-09, 8.9060710D-11 /
      data fpp(13, 4,13,1),fpp(13, 4,13,2),fpp(13, 4,13,3)/
     x-6.6386438D-06,-7.4990416D-10,-4.8611111D-10 /
      data fpp(13, 4,14,1),fpp(13, 4,14,2),fpp(13, 4,14,3)/
     x 2.5893132D-05,-7.3679782D-10,-1.4461627D-10 /
      data fpp(13, 4,15,1),fpp(13, 4,15,2),fpp(13, 4,15,3)/
     x 4.6099758D-05, 2.2540383D-09, 1.0645762D-09 /
      data fpp(13, 4,16,1),fpp(13, 4,16,2),fpp(13, 4,16,3)/
     x 2.5893132D-05,-7.3679782D-10,-1.1368843D-10 /
      data fpp(13, 4,17,1),fpp(13, 4,17,2),fpp(13, 4,17,3)/
     x-6.6386438D-06,-7.4990416D-10,-6.0982245D-10 /
      data fpp(13, 5, 1,1),fpp(13, 5, 1,2),fpp(13, 5, 1,3)/
     x-5.4523927D-07, 2.5925782D-10,-6.0319165D-10 /
      data fpp(13, 5, 2,1),fpp(13, 5, 2,2),fpp(13, 5, 2,3)/
     x 3.3973544D-05, 3.5565149D-09,-1.5838924D-11 /
      data fpp(13, 5, 3,1),fpp(13, 5, 3,2),fpp(13, 5, 3,3)/
     x 6.0357015D-05,-3.3237358D-10, 1.3332140D-09 /
      data fpp(13, 5, 4,1),fpp(13, 5, 4,2),fpp(13, 5, 4,3)/
     x 3.3973544D-05, 3.5565149D-09, 1.6316206D-11 /
      data fpp(13, 5, 5,1),fpp(13, 5, 5,2),fpp(13, 5, 5,3)/
     x-5.4523927D-07, 2.5925782D-10,-7.3181217D-10 /
      data fpp(13, 5, 6,1),fpp(13, 5, 6,2),fpp(13, 5, 6,3)/
     x-2.2243599D-05,-2.1205929D-09,-4.2240086D-10 /
      data fpp(13, 5, 7,1),fpp(13, 5, 7,2),fpp(13, 5, 7,3)/
     x-2.3655284D-05, 2.0935956D-10, 1.0880823D-09 /
      data fpp(13, 5, 8,1),fpp(13, 5, 8,2),fpp(13, 5, 8,3)/
     x-4.3430910D-06,-4.8581434D-09,-5.9659494D-10 /
      data fpp(13, 5, 9,1),fpp(13, 5, 9,2),fpp(13, 5, 9,3)/
     x 9.8473966D-06,-6.5723443D-10,-3.5035864D-11 /
      data fpp(13, 5,10,1),fpp(13, 5,10,2),fpp(13, 5,10,3)/
     x-4.3430910D-06,-4.8581434D-09,-5.9659494D-10 /
      data fpp(13, 5,11,1),fpp(13, 5,11,2),fpp(13, 5,11,3)/
     x-2.3655284D-05, 2.0935956D-10, 1.0880823D-09 /
      data fpp(13, 5,12,1),fpp(13, 5,12,2),fpp(13, 5,12,3)/
     x-2.2243599D-05,-2.1205929D-09,-4.2240086D-10 /
      data fpp(13, 5,13,1),fpp(13, 5,13,2),fpp(13, 5,13,3)/
     x-5.4523927D-07, 2.5925782D-10,-7.3181217D-10 /
      data fpp(13, 5,14,1),fpp(13, 5,14,2),fpp(13, 5,14,3)/
     x 3.3973544D-05, 3.5565149D-09, 1.6316206D-11 /
      data fpp(13, 5,15,1),fpp(13, 5,15,2),fpp(13, 5,15,3)/
     x 6.0357015D-05,-3.3237358D-10, 1.3332140D-09 /
      data fpp(13, 5,16,1),fpp(13, 5,16,2),fpp(13, 5,16,3)/
     x 3.3973544D-05, 3.5565149D-09,-1.5838924D-11 /
      data fpp(13, 5,17,1),fpp(13, 5,17,2),fpp(13, 5,17,3)/
     x-5.4523927D-07, 2.5925782D-10,-6.0319165D-10 /
      data fpp(13, 6, 1,1),fpp(13, 6, 1,2),fpp(13, 6, 1,3)/
     x-4.2960138D-06,-2.8712711D-10,-1.4282407D-09 /
      data fpp(13, 6, 2,1),fpp(13, 6, 2,2),fpp(13, 6, 2,3)/
     x 2.9785830D-05,-1.4892619D-09,-3.6574074D-10 /
      data fpp(13, 6, 3,1),fpp(13, 6, 3,2),fpp(13, 6, 3,3)/
     x 5.3099123D-05, 5.0754560D-09, 2.2245370D-09 /
      data fpp(13, 6, 4,1),fpp(13, 6, 4,2),fpp(13, 6, 4,3)/
     x 2.9785830D-05,-1.4892619D-09,-5.3240741D-10 /
      data fpp(13, 6, 5,1),fpp(13, 6, 5,2),fpp(13, 6, 5,3)/
     x-4.2960138D-06,-2.8712711D-10,-7.6157407D-10 /
      data fpp(13, 6, 6,1),fpp(13, 6, 6,2),fpp(13, 6, 6,3)/
     x-1.1602257D-05, 6.4592391D-10,-4.2129630D-10 /
      data fpp(13, 6, 7,1),fpp(13, 6, 7,2),fpp(13, 6, 7,3)/
     x-1.6265986D-05, 1.1671324D-09, 1.1134259D-09 /
      data fpp(13, 6, 8,1),fpp(13, 6, 8,2),fpp(13, 6, 8,3)/
     x-2.1982135D-06, 4.3778133D-09,-3.2407407D-11 /
      data fpp(13, 6, 9,1),fpp(13, 6, 9,2),fpp(13, 6, 9,3)/
     x 1.1691525D-05, 7.7235943D-10,-9.8379630D-10 /
      data fpp(13, 6,10,1),fpp(13, 6,10,2),fpp(13, 6,10,3)/
     x-2.1982135D-06, 4.3778133D-09,-3.2407407D-11 /
      data fpp(13, 6,11,1),fpp(13, 6,11,2),fpp(13, 6,11,3)/
     x-1.6265986D-05, 1.1671324D-09, 1.1134259D-09 /
      data fpp(13, 6,12,1),fpp(13, 6,12,2),fpp(13, 6,12,3)/
     x-1.1602257D-05, 6.4592391D-10,-4.2129630D-10 /
      data fpp(13, 6,13,1),fpp(13, 6,13,2),fpp(13, 6,13,3)/
     x-4.2960138D-06,-2.8712711D-10,-7.6157407D-10 /
      data fpp(13, 6,14,1),fpp(13, 6,14,2),fpp(13, 6,14,3)/
     x 2.9785830D-05,-1.4892619D-09,-5.3240741D-10 /
      data fpp(13, 6,15,1),fpp(13, 6,15,2),fpp(13, 6,15,3)/
     x 5.3099123D-05, 5.0754560D-09, 2.2245370D-09 /
      data fpp(13, 6,16,1),fpp(13, 6,16,2),fpp(13, 6,16,3)/
     x 2.9785830D-05,-1.4892619D-09,-3.6574074D-10 /
      data fpp(13, 6,17,1),fpp(13, 6,17,2),fpp(13, 6,17,3)/
     x-4.2960138D-06,-2.8712711D-10,-1.4282407D-09 /
      data fpp(13, 7, 1,1),fpp(13, 7, 1,2),fpp(13, 7, 1,3)/
     x 1.0246685D-05, 8.8925064D-10,-1.0190299D-09 /
      data fpp(13, 7, 2,1),fpp(13, 7, 2,2),fpp(13, 7, 2,3)/
     x 1.8347674D-05, 2.4005328D-09,-1.8416244D-10 /
      data fpp(13, 7, 3,1),fpp(13, 7, 3,2),fpp(13, 7, 3,3)/
     x 3.0221295D-05,-1.9694506D-09, 1.7556796D-09 /
      data fpp(13, 7, 4,1),fpp(13, 7, 4,2),fpp(13, 7, 4,3)/
     x 1.8347674D-05, 2.4005328D-09,-1.7188949D-10 /
      data fpp(13, 7, 5,1),fpp(13, 7, 5,2),fpp(13, 7, 5,3)/
     x 1.0246685D-05, 8.8925064D-10,-1.0681217D-09 /
      data fpp(13, 7, 6,1),fpp(13, 7, 6,2),fpp(13, 7, 6,3)/
     x 5.8382331D-08,-4.6310277D-10,-2.2229041D-10 /
      data fpp(13, 7, 7,1),fpp(13, 7, 7,2),fpp(13, 7, 7,3)/
     x-7.8709237D-06, 1.1221110D-09, 1.2906166D-09 /
      data fpp(13, 7, 8,1),fpp(13, 7, 8,2),fpp(13, 7, 8,3)/
     x-1.1276445D-07,-6.5310999D-10,-2.7350952D-10 /
      data fpp(13, 7, 9,1),fpp(13, 7, 9,2),fpp(13, 7, 9,3)/
     x 1.1579881D-05,-2.4322033D-09,-8.6324524D-10 /
      data fpp(13, 7,10,1),fpp(13, 7,10,2),fpp(13, 7,10,3)/
     x-1.1276445D-07,-6.5310999D-10,-2.7350952D-10 /
      data fpp(13, 7,11,1),fpp(13, 7,11,2),fpp(13, 7,11,3)/
     x-7.8709237D-06, 1.1221110D-09, 1.2906166D-09 /
      data fpp(13, 7,12,1),fpp(13, 7,12,2),fpp(13, 7,12,3)/
     x 5.8382331D-08,-4.6310277D-10,-2.2229041D-10 /
      data fpp(13, 7,13,1),fpp(13, 7,13,2),fpp(13, 7,13,3)/
     x 1.0246685D-05, 8.8925064D-10,-1.0681217D-09 /
      data fpp(13, 7,14,1),fpp(13, 7,14,2),fpp(13, 7,14,3)/
     x 1.8347674D-05, 2.4005328D-09,-1.7188949D-10 /
      data fpp(13, 7,15,1),fpp(13, 7,15,2),fpp(13, 7,15,3)/
     x 3.0221295D-05,-1.9694506D-09, 1.7556796D-09 /
      data fpp(13, 7,16,1),fpp(13, 7,16,2),fpp(13, 7,16,3)/
     x 1.8347674D-05, 2.4005328D-09,-1.8416244D-10 /
      data fpp(13, 7,17,1),fpp(13, 7,17,2),fpp(13, 7,17,3)/
     x 1.0246685D-05, 8.8925064D-10,-1.0190299D-09 /
      data fpp(13, 8, 1,1),fpp(13, 8, 1,2),fpp(13, 8, 1,3)/
     x 1.3223881D-05,-3.2698755D-09,-1.2303871D-09 /
      data fpp(13, 8, 2,1),fpp(13, 8, 2,2),fpp(13, 8, 2,3)/
     x 9.3881153D-06,-2.1128692D-09,-3.1700349D-10 /
      data fpp(13, 8, 3,1),fpp(13, 8, 3,2),fpp(13, 8, 3,3)/
     x 9.0897176D-06, 2.8023464D-09, 1.8317344D-09 /
      data fpp(13, 8, 4,1),fpp(13, 8, 4,2),fpp(13, 8, 4,3)/
     x 9.3881153D-06,-2.1128692D-09,-3.4326760D-10 /
      data fpp(13, 8, 5,1),fpp(13, 8, 5,2),fpp(13, 8, 5,3)/
     x 1.3223881D-05,-3.2698755D-09,-1.1253307D-09 /
      data fpp(13, 8, 6,1),fpp(13, 8, 6,2),fpp(13, 8, 6,3)/
     x 9.5349461D-06, 1.2064872D-09, 1.7792369D-10 /
      data fpp(13, 8, 7,1),fpp(13, 8, 7,2),fpp(13, 8, 7,3)/
     x 2.2479343D-07, 3.4442368D-10, 1.0803026D-09 /
      data fpp(13, 8, 8,1),fpp(13, 8, 8,2),fpp(13, 8, 8,3)/
     x 4.6710752D-06,-1.7653734D-09,-4.9913408D-10 /
      data fpp(13, 8, 9,1),fpp(13, 8, 9,2),fpp(13, 8, 9,3)/
     x 1.3236308D-05, 2.9564537D-09,-4.1709963D-10 /
      data fpp(13, 8,10,1),fpp(13, 8,10,2),fpp(13, 8,10,3)/
     x 4.6710752D-06,-1.7653734D-09,-4.9913408D-10 /
      data fpp(13, 8,11,1),fpp(13, 8,11,2),fpp(13, 8,11,3)/
     x 2.2479343D-07, 3.4442368D-10, 1.0803026D-09 /
      data fpp(13, 8,12,1),fpp(13, 8,12,2),fpp(13, 8,12,3)/
     x 9.5349461D-06, 1.2064872D-09, 1.7792369D-10 /
      data fpp(13, 8,13,1),fpp(13, 8,13,2),fpp(13, 8,13,3)/
     x 1.3223881D-05,-3.2698755D-09,-1.1253307D-09 /
      data fpp(13, 8,14,1),fpp(13, 8,14,2),fpp(13, 8,14,3)/
     x 9.3881153D-06,-2.1128692D-09,-3.4326760D-10 /
      data fpp(13, 8,15,1),fpp(13, 8,15,2),fpp(13, 8,15,3)/
     x 9.0897176D-06, 2.8023464D-09, 1.8317344D-09 /
      data fpp(13, 8,16,1),fpp(13, 8,16,2),fpp(13, 8,16,3)/
     x 9.3881153D-06,-2.1128692D-09,-3.1700349D-10 /
      data fpp(13, 8,17,1),fpp(13, 8,17,2),fpp(13, 8,17,3)/
     x 1.3223881D-05,-3.2698755D-09,-1.2303871D-09 /
      data fpp(13, 9, 1,1),fpp(13, 9, 1,2),fpp(13, 9, 1,3)/
     x 1.6329897D-05, 1.9025116D-10,-8.2216154D-10 /
      data fpp(13, 9, 2,1),fpp(13, 9, 2,2),fpp(13, 9, 2,3)/
     x 8.8761447D-06, 5.0944112D-11,-2.4456581D-10 /
      data fpp(13, 9, 3,1),fpp(13, 9, 3,2),fpp(13, 9, 3,3)/
     x 3.5158118D-06,-3.2399348D-09, 1.1337581D-09 /
      data fpp(13, 9, 4,1),fpp(13, 9, 4,2),fpp(13, 9, 4,3)/
     x 8.8761447D-06, 5.0944112D-11,-2.9046664D-10 /
      data fpp(13, 9, 5,1),fpp(13, 9, 5,2),fpp(13, 9, 5,3)/
     x 1.6329897D-05, 1.9025116D-10,-6.3855820D-10 /
      data fpp(13, 9, 6,1),fpp(13, 9, 6,2),fpp(13, 9, 6,3)/
     x 1.4984144D-05,-4.3628459D-09, 1.7803278D-10 /
      data fpp(13, 9, 7,1),fpp(13, 9, 7,2),fpp(13, 9, 7,3)/
     x 7.8832797D-06,-2.4998057D-09, 5.9309374D-10 /
      data fpp(13, 9, 8,1),fpp(13, 9, 8,2),fpp(13, 9, 8,3)/
     x 1.3740918D-05, 1.7146035D-09, 1.1625893D-10 /
      data fpp(13, 9, 9,1),fpp(13, 9, 9,2),fpp(13, 9, 9,3)/
     x 2.1090786D-05,-3.3936115D-09,-1.0581295D-09 /
      data fpp(13, 9,10,1),fpp(13, 9,10,2),fpp(13, 9,10,3)/
     x 1.3740918D-05, 1.7146035D-09, 1.1625893D-10 /
      data fpp(13, 9,11,1),fpp(13, 9,11,2),fpp(13, 9,11,3)/
     x 7.8832797D-06,-2.4998057D-09, 5.9309374D-10 /
      data fpp(13, 9,12,1),fpp(13, 9,12,2),fpp(13, 9,12,3)/
     x 1.4984144D-05,-4.3628459D-09, 1.7803278D-10 /
      data fpp(13, 9,13,1),fpp(13, 9,13,2),fpp(13, 9,13,3)/
     x 1.6329897D-05, 1.9025116D-10,-6.3855820D-10 /
      data fpp(13, 9,14,1),fpp(13, 9,14,2),fpp(13, 9,14,3)/
     x 8.8761447D-06, 5.0944112D-11,-2.9046664D-10 /
      data fpp(13, 9,15,1),fpp(13, 9,15,2),fpp(13, 9,15,3)/
     x 3.5158118D-06,-3.2399348D-09, 1.1337581D-09 /
      data fpp(13, 9,16,1),fpp(13, 9,16,2),fpp(13, 9,16,3)/
     x 8.8761447D-06, 5.0944112D-11,-2.4456581D-10 /
      data fpp(13, 9,17,1),fpp(13, 9,17,2),fpp(13, 9,17,3)/
     x 1.6329897D-05, 1.9025116D-10,-8.2216154D-10 /
      data fpp(13,10, 1,1),fpp(13,10, 1,2),fpp(13,10, 1,3)/
     x 2.0331637D-05,-3.4911292D-09,-8.3069465D-10 /
      data fpp(13,10, 2,1),fpp(13,10, 2,2),fpp(13,10, 2,3)/
     x 1.8454948D-05,-4.0909072D-09,-3.3861070D-10 /
      data fpp(13,10, 3,1),fpp(13,10, 3,2),fpp(13,10, 3,3)/
     x 1.4827291D-05,-1.8426070D-09, 8.5180412D-10 /
      data fpp(13,10, 4,1),fpp(13,10, 4,2),fpp(13,10, 4,3)/
     x 1.8454948D-05,-4.0909072D-09,-4.0193913D-10 /
      data fpp(13,10, 5,1),fpp(13,10, 5,2),fpp(13,10, 5,3)/
     x 2.0331637D-05,-3.4911292D-09,-5.7738095D-10 /
      data fpp(13,10, 6,1),fpp(13,10, 6,2),fpp(13,10, 6,3)/
     x 1.5235229D-05,-1.7551034D-09, 7.1146294D-10 /
      data fpp(13,10, 7,1),fpp(13,10, 7,2),fpp(13,10, 7,3)/
     x 1.5099606D-05,-2.3452008D-09, 3.9819588D-10 /
      data fpp(13,10, 8,1),fpp(13,10, 8,2),fpp(13,10, 8,3)/
     x 2.8661789D-05,-5.0930407D-09,-3.0424644D-10 /
      data fpp(13,10, 9,1),fpp(13,10, 9,2),fpp(13,10, 9,3)/
     x 3.8460518D-05,-1.3820076D-09,-5.1454345D-10 /
      data fpp(13,10,10,1),fpp(13,10,10,2),fpp(13,10,10,3)/
     x 2.8661789D-05,-5.0930407D-09,-3.0424644D-10 /
      data fpp(13,10,11,1),fpp(13,10,11,2),fpp(13,10,11,3)/
     x 1.5099606D-05,-2.3452008D-09, 3.9819588D-10 /
      data fpp(13,10,12,1),fpp(13,10,12,2),fpp(13,10,12,3)/
     x 1.5235229D-05,-1.7551034D-09, 7.1146294D-10 /
      data fpp(13,10,13,1),fpp(13,10,13,2),fpp(13,10,13,3)/
     x 2.0331637D-05,-3.4911292D-09,-5.7738095D-10 /
      data fpp(13,10,14,1),fpp(13,10,14,2),fpp(13,10,14,3)/
     x 1.8454948D-05,-4.0909072D-09,-4.0193913D-10 /
      data fpp(13,10,15,1),fpp(13,10,15,2),fpp(13,10,15,3)/
     x 1.4827291D-05,-1.8426070D-09, 8.5180412D-10 /
      data fpp(13,10,16,1),fpp(13,10,16,2),fpp(13,10,16,3)/
     x 1.8454948D-05,-4.0909072D-09,-3.3861070D-10 /
      data fpp(13,10,17,1),fpp(13,10,17,2),fpp(13,10,17,3)/
     x 2.0331637D-05,-3.4911292D-09,-8.3069465D-10 /
      data fpp(13,11, 1,1),fpp(13,11, 1,2),fpp(13,11, 1,3)/
     x 2.3689103D-05,-4.2257344D-09,-4.2541455D-10 /
      data fpp(13,11, 2,1),fpp(13,11, 2,2),fpp(13,11, 2,3)/
     x 3.6632959D-05,-1.6873152D-09,-2.6028201D-10 /
      data fpp(13,11, 3,1),fpp(13,11, 3,2),fpp(13,11, 3,3)/
     x 3.9058424D-05,-1.3896372D-09, 1.3320924D-10 /
      data fpp(13,11, 4,1),fpp(13,11, 4,2),fpp(13,11, 4,3)/
     x 3.6632959D-05,-1.6873152D-09,-2.7255496D-10 /
      data fpp(13,11, 5,1),fpp(13,11, 5,2),fpp(13,11, 5,3)/
     x 2.3689103D-05,-4.2257344D-09,-3.7632275D-10 /
      data fpp(13,11, 6,1),fpp(13,11, 6,2),fpp(13,11, 6,3)/
     x 9.0747802D-06,-6.1674052D-10, 1.1111793D-09 /
      data fpp(13,11, 7,1),fpp(13,11, 7,2),fpp(13,11, 7,3)/
     x 2.2271712D-05,-1.1939106D-10,-6.8394425D-11 /
      data fpp(13,11, 8,1),fpp(13,11, 8,2),fpp(13,11, 8,3)/
     x 5.0587406D-05, 6.5755911D-10,-1.7093493D-10 /
      data fpp(13,11, 9,1),fpp(13,11, 9,2),fpp(13,11, 9,3)/
     x 6.6742881D-05,-3.0783579D-09,-5.8119920D-10 /
      data fpp(13,11,10,1),fpp(13,11,10,2),fpp(13,11,10,3)/
     x 5.0587406D-05, 6.5755911D-10,-1.7093493D-10 /
      data fpp(13,11,11,1),fpp(13,11,11,2),fpp(13,11,11,3)/
     x 2.2271712D-05,-1.1939106D-10,-6.8394425D-11 /
      data fpp(13,11,12,1),fpp(13,11,12,2),fpp(13,11,12,3)/
     x 9.0747802D-06,-6.1674052D-10, 1.1111793D-09 /
      data fpp(13,11,13,1),fpp(13,11,13,2),fpp(13,11,13,3)/
     x 2.3689103D-05,-4.2257344D-09,-3.7632275D-10 /
      data fpp(13,11,14,1),fpp(13,11,14,2),fpp(13,11,14,3)/
     x 3.6632959D-05,-1.6873152D-09,-2.7255496D-10 /
      data fpp(13,11,15,1),fpp(13,11,15,2),fpp(13,11,15,3)/
     x 3.9058424D-05,-1.3896372D-09, 1.3320924D-10 /
      data fpp(13,11,16,1),fpp(13,11,16,2),fpp(13,11,16,3)/
     x 3.6632959D-05,-1.6873152D-09,-2.6028201D-10 /
      data fpp(13,11,17,1),fpp(13,11,17,2),fpp(13,11,17,3)/
     x 2.3689103D-05,-4.2257344D-09,-4.2541455D-10 /
      data fpp(13,12, 1,1),fpp(13,12, 1,2),fpp(13,12, 1,3)/
     x 2.2628089D-05, 2.3940667D-09,-2.2326883D-10 /
      data fpp(13,12, 2,1),fpp(13,12, 2,2),fpp(13,12, 2,3)/
     x 6.0021870D-05,-1.1598319D-09,-3.3124011D-10 /
      data fpp(13,12, 3,1),fpp(13,12, 3,2),fpp(13,12, 3,3)/
     x 7.1428073D-05,-4.5988441D-09,-4.5177071D-10 /
      data fpp(13,12, 4,1),fpp(13,12, 4,2),fpp(13,12, 4,3)/
     x 6.0021870D-05,-1.1598319D-09,-5.2834370D-10 /
      data fpp(13,12, 5,1),fpp(13,12, 5,2),fpp(13,12, 5,3)/
     x 2.2628089D-05, 2.3940667D-09, 5.6514550D-10 /
      data fpp(13,12, 6,1),fpp(13,12, 6,2),fpp(13,12, 6,3)/
     x-5.4280177D-06,-1.7779345D-09, 9.3442835D-10 /
      data fpp(13,12, 7,1),fpp(13,12, 7,2),fpp(13,12, 7,3)/
     x 2.8670942D-05,-3.1772350D-09,-3.0285892D-10 /
      data fpp(13,12, 8,1),fpp(13,12, 8,2),fpp(13,12, 8,3)/
     x 8.0096405D-05,-3.5371958D-09,-3.8965936D-10 /
      data fpp(13,12, 9,1),fpp(13,12, 9,2),fpp(13,12, 9,3)/
     x 1.0470157D-04, 1.6954393D-09,-1.3850365D-10 /
      data fpp(13,12,10,1),fpp(13,12,10,2),fpp(13,12,10,3)/
     x 8.0096405D-05,-3.5371958D-09,-3.8965936D-10 /
      data fpp(13,12,11,1),fpp(13,12,11,2),fpp(13,12,11,3)/
     x 2.8670942D-05,-3.1772350D-09,-3.0285892D-10 /
      data fpp(13,12,12,1),fpp(13,12,12,2),fpp(13,12,12,3)/
     x-5.4280177D-06,-1.7779345D-09, 9.3442835D-10 /
      data fpp(13,12,13,1),fpp(13,12,13,2),fpp(13,12,13,3)/
     x 2.2628089D-05, 2.3940667D-09, 5.6514550D-10 /
      data fpp(13,12,14,1),fpp(13,12,14,2),fpp(13,12,14,3)/
     x 6.0021870D-05,-1.1598319D-09,-5.2834370D-10 /
      data fpp(13,12,15,1),fpp(13,12,15,2),fpp(13,12,15,3)/
     x 7.1428073D-05,-4.5988441D-09,-4.5177071D-10 /
      data fpp(13,12,16,1),fpp(13,12,16,2),fpp(13,12,16,3)/
     x 6.0021870D-05,-1.1598319D-09,-3.3124011D-10 /
      data fpp(13,12,17,1),fpp(13,12,17,2),fpp(13,12,17,3)/
     x 2.2628089D-05, 2.3940667D-09,-2.2326883D-10 /
      data fpp(13,13, 1,1),fpp(13,13, 1,2),fpp(13,13, 1,3)/
     x 1.3798478D-05, 6.4946766D-10,-4.3223286D-10 /
      data fpp(13,13, 2,1),fpp(13,13, 2,2),fpp(13,13, 2,3)/
     x 8.1861969D-05, 3.2664278D-10,-4.6886762D-10 /
      data fpp(13,13, 3,1),fpp(13,13, 3,2),fpp(13,13, 3,3)/
     x 1.0460981D-04, 1.7850136D-09,-3.5896334D-10 /
      data fpp(13,13, 4,1),fpp(13,13, 4,2),fpp(13,13, 4,3)/
     x 8.1861969D-05, 3.2664278D-10,-7.6194567D-10 /
      data fpp(13,13, 5,1),fpp(13,13, 5,2),fpp(13,13, 5,3)/
     x 1.3798478D-05, 6.4946766D-10, 7.4007937D-10 /
      data fpp(13,13, 6,1),fpp(13,13, 6,2),fpp(13,13, 6,3)/
     x-2.8127695D-05, 1.7284787D-09, 1.1349615D-09 /
      data fpp(13,13, 7,1),fpp(13,13, 7,2),fpp(13,13, 7,3)/
     x 3.2840021D-05, 8.2833091D-10,-6.1325888D-10 /
      data fpp(13,13, 8,1),fpp(13,13, 8,2),fpp(13,13, 8,3)/
     x 1.1332717D-04, 1.4912240D-09,-1.5259368D-11 /
      data fpp(13,13, 9,1),fpp(13,13, 9,2),fpp(13,13, 9,3)/
     x 1.4770850D-04,-3.7033991D-09,-6.5903698D-10 /
      data fpp(13,13,10,1),fpp(13,13,10,2),fpp(13,13,10,3)/
     x 1.1332717D-04, 1.4912240D-09,-1.5259368D-11 /
      data fpp(13,13,11,1),fpp(13,13,11,2),fpp(13,13,11,3)/
     x 3.2840021D-05, 8.2833091D-10,-6.1325888D-10 /
      data fpp(13,13,12,1),fpp(13,13,12,2),fpp(13,13,12,3)/
     x-2.8127695D-05, 1.7284787D-09, 1.1349615D-09 /
      data fpp(13,13,13,1),fpp(13,13,13,2),fpp(13,13,13,3)/
     x 1.3798478D-05, 6.4946766D-10, 7.4007937D-10 /
      data fpp(13,13,14,1),fpp(13,13,14,2),fpp(13,13,14,3)/
     x 8.1861969D-05, 3.2664278D-10,-7.6194567D-10 /
      data fpp(13,13,15,1),fpp(13,13,15,2),fpp(13,13,15,3)/
     x 1.0460981D-04, 1.7850136D-09,-3.5896334D-10 /
      data fpp(13,13,16,1),fpp(13,13,16,2),fpp(13,13,16,3)/
     x 8.1861969D-05, 3.2664278D-10,-4.6886762D-10 /
      data fpp(13,13,17,1),fpp(13,13,17,2),fpp(13,13,17,3)/
     x 1.3798478D-05, 6.4946766D-10,-4.3223286D-10 /
      data fpp(13,14, 1,1),fpp(13,14, 1,2),fpp(13,14, 1,3)/
     x-3.8011448D-06, 1.0080627D-09,-4.3217149D-10 /
      data fpp(13,14, 2,1),fpp(13,14, 2,2),fpp(13,14, 2,3)/
     x 9.1911569D-05,-1.4673922D-10,-4.6899035D-10 /
      data fpp(13,14, 3,1),fpp(13,14, 3,2),fpp(13,14, 3,3)/
     x 1.2678027D-04,-2.5412101D-09,-3.5853379D-10 /
      data fpp(13,14, 4,1),fpp(13,14, 4,2),fpp(13,14, 4,3)/
     x 9.1911569D-05,-1.4673922D-10,-7.6354116D-10 /
      data fpp(13,14, 5,1),fpp(13,14, 5,2),fpp(13,14, 5,3)/
     x-3.8011448D-06, 1.0080627D-09, 7.4603175D-10 /
      data fpp(13,14, 6,1),fpp(13,14, 6,2),fpp(13,14, 6,3)/
     x-5.4437213D-05, 8.6401977D-10, 1.1127475D-09 /
      data fpp(13,14, 7,1),fpp(13,14, 7,2),fpp(13,14, 7,3)/
     x 3.2076313D-05,-1.3608867D-10,-5.3035510D-10 /
      data fpp(13,14, 8,1),fpp(13,14, 8,2),fpp(13,14, 8,3)/
     x 1.4140937D-04,-2.4277003D-09,-3.2466045D-10 /
      data fpp(13,14, 9,1),fpp(13,14, 9,2),fpp(13,14, 9,3)/
     x 1.8493562D-04, 1.1181573D-09,-1.7100311D-10 /
      data fpp(13,14,10,1),fpp(13,14,10,2),fpp(13,14,10,3)/
     x 1.4140937D-04,-2.4277003D-09,-3.2466045D-10 /
      data fpp(13,14,11,1),fpp(13,14,11,2),fpp(13,14,11,3)/
     x 3.2076313D-05,-1.3608867D-10,-5.3035510D-10 /
      data fpp(13,14,12,1),fpp(13,14,12,2),fpp(13,14,12,3)/
     x-5.4437213D-05, 8.6401977D-10, 1.1127475D-09 /
      data fpp(13,14,13,1),fpp(13,14,13,2),fpp(13,14,13,3)/
     x-3.8011448D-06, 1.0080627D-09, 7.4603175D-10 /
      data fpp(13,14,14,1),fpp(13,14,14,2),fpp(13,14,14,3)/
     x 9.1911569D-05,-1.4673922D-10,-7.6354116D-10 /
      data fpp(13,14,15,1),fpp(13,14,15,2),fpp(13,14,15,3)/
     x 1.2678027D-04,-2.5412101D-09,-3.5853379D-10 /
      data fpp(13,14,16,1),fpp(13,14,16,2),fpp(13,14,16,3)/
     x 9.1911569D-05,-1.4673922D-10,-4.6899035D-10 /
      data fpp(13,14,17,1),fpp(13,14,17,2),fpp(13,14,17,3)/
     x-3.8011448D-06, 1.0080627D-09,-4.3217149D-10 /
      data fpp(13,15, 1,1),fpp(13,15, 1,2),fpp(13,15, 1,3)/
     x-2.7161830D-05, 1.3182815D-09,-6.3499564D-10 /
      data fpp(13,15, 2,1),fpp(13,15, 2,2),fpp(13,15, 2,3)/
     x 8.0016148D-05, 2.6031410D-10,-5.0778651D-10 /
      data fpp(13,15, 3,1),fpp(13,15, 3,2),fpp(13,15, 3,3)/
     x 1.2293987D-04, 2.3798270D-09,-5.2500955D-13 /
      data fpp(13,15, 4,1),fpp(13,15, 4,2),fpp(13,15, 4,3)/
     x 8.0016148D-05, 2.6031410D-10,-8.2344679D-10 /
      data fpp(13,15, 5,1),fpp(13,15, 5,2),fpp(13,15, 5,3)/
     x-2.7161830D-05, 1.3182815D-09, 6.2764550D-10 /
      data fpp(13,15, 6,1),fpp(13,15, 6,2),fpp(13,15, 6,3)/
     x-7.5098440D-05, 8.1544222D-10, 9.7953145D-10 /
      data fpp(13,15, 7,1),fpp(13,15, 7,2),fpp(13,15, 7,3)/
     x 2.4895333D-05,-2.8397624D-10,-5.4577129D-10 /
      data fpp(13,15, 8,1),fpp(13,15, 8,2),fpp(13,15, 8,3)/
     x 1.5029013D-04, 2.2195772D-09,-1.2977963D-10 /
      data fpp(13,15, 9,1),fpp(13,15, 9,2),fpp(13,15, 9,3)/
     x 1.9960546D-04,-7.6922999D-10,-2.6844352D-10 /
      data fpp(13,15,10,1),fpp(13,15,10,2),fpp(13,15,10,3)/
     x 1.5029013D-04, 2.2195772D-09,-1.2977963D-10 /
      data fpp(13,15,11,1),fpp(13,15,11,2),fpp(13,15,11,3)/
     x 2.4895333D-05,-2.8397624D-10,-5.4577129D-10 /
      data fpp(13,15,12,1),fpp(13,15,12,2),fpp(13,15,12,3)/
     x-7.5098440D-05, 8.1544222D-10, 9.7953145D-10 /
      data fpp(13,15,13,1),fpp(13,15,13,2),fpp(13,15,13,3)/
     x-2.7161830D-05, 1.3182815D-09, 6.2764550D-10 /
      data fpp(13,15,14,1),fpp(13,15,14,2),fpp(13,15,14,3)/
     x 8.0016148D-05, 2.6031410D-10,-8.2344679D-10 /
      data fpp(13,15,15,1),fpp(13,15,15,2),fpp(13,15,15,3)/
     x 1.2293987D-04, 2.3798270D-09,-5.2500955D-13 /
      data fpp(13,15,16,1),fpp(13,15,16,2),fpp(13,15,16,3)/
     x 8.0016148D-05, 2.6031410D-10,-5.0778651D-10 /
      data fpp(13,15,17,1),fpp(13,15,17,2),fpp(13,15,17,3)/
     x-2.7161830D-05, 1.3182815D-09,-6.3499564D-10 /
      data fpp(13,16, 1,1),fpp(13,16, 1,2),fpp(13,16, 1,3)/
     x-4.7285238D-05,-2.8118887D-10,-2.1712895D-10 /
      data fpp(13,16, 2,1),fpp(13,16, 2,2),fpp(13,16, 2,3)/
     x 4.3183500D-05,-8.9451718D-10,-2.3240877D-10 /
      data fpp(13,16, 3,1),fpp(13,16, 3,2),fpp(13,16, 3,3)/
     x 8.3725915D-05,-9.7809797D-10,-1.8656930D-10 /
      data fpp(13,16, 4,1),fpp(13,16, 4,2),fpp(13,16, 4,3)/
     x 4.3183500D-05,-8.9451718D-10,-3.5464736D-10 /
      data fpp(13,16, 5,1),fpp(13,16, 5,2),fpp(13,16, 5,3)/
     x-4.7285238D-05,-2.8118887D-10, 2.7182540D-10 /
      data fpp(13,16, 6,1),fpp(13,16, 6,2),fpp(13,16, 6,3)/
     x-7.8693752D-05, 1.8742114D-09, 6.0067910D-10 /
      data fpp(13,16, 7,1),fpp(13,16, 7,2),fpp(13,16, 7,3)/
     x 1.2752989D-05, 1.2719936D-09,-7.8751432D-12 /
      data fpp(13,16, 8,1),fpp(13,16, 8,2),fpp(13,16, 8,3)/
     x 1.2846692D-04,-4.5060831D-10,-5.6917853D-10 /
      data fpp(13,16, 9,1),fpp(13,16, 9,2),fpp(13,16, 9,3)/
     x 1.7532736D-04, 1.9587627D-09, 2.8458927D-10 /
      data fpp(13,16,10,1),fpp(13,16,10,2),fpp(13,16,10,3)/
     x 1.2846692D-04,-4.5060831D-10,-5.6917853D-10 /
      data fpp(13,16,11,1),fpp(13,16,11,2),fpp(13,16,11,3)/
     x 1.2752989D-05, 1.2719936D-09,-7.8751432D-12 /
      data fpp(13,16,12,1),fpp(13,16,12,2),fpp(13,16,12,3)/
     x-7.8693752D-05, 1.8742114D-09, 6.0067910D-10 /
      data fpp(13,16,13,1),fpp(13,16,13,2),fpp(13,16,13,3)/
     x-4.7285238D-05,-2.8118887D-10, 2.7182540D-10 /
      data fpp(13,16,14,1),fpp(13,16,14,2),fpp(13,16,14,3)/
     x 4.3183500D-05,-8.9451718D-10,-3.5464736D-10 /
      data fpp(13,16,15,1),fpp(13,16,15,2),fpp(13,16,15,3)/
     x 8.3725915D-05,-9.7809797D-10,-1.8656930D-10 /
      data fpp(13,16,16,1),fpp(13,16,16,2),fpp(13,16,16,3)/
     x 4.3183500D-05,-8.9451718D-10,-2.3240877D-10 /
      data fpp(13,16,17,1),fpp(13,16,17,2),fpp(13,16,17,3)/
     x-4.7285238D-05,-2.8118887D-10,-2.1712895D-10 /
      data fpp(13,17, 1,1),fpp(13,17, 1,2),fpp(13,17, 1,3)/
     x-5.4486519D-05,-1.9352607D-10, 2.0300824D-10 /
      data fpp(13,17, 2,1),fpp(13,17, 2,2),fpp(13,17, 2,3)/
     x-4.7579901D-06, 3.3177546D-09, 3.8427971D-11 /
      data fpp(13,17, 3,1),fpp(13,17, 3,2),fpp(13,17, 3,3)/
     x 2.0518330D-05, 1.5325648D-09,-3.5672012D-10 /
      data fpp(13,17, 4,1),fpp(13,17, 4,2),fpp(13,17, 4,3)/
     x-4.7579901D-06, 3.3177546D-09, 5.5119184D-11 /
      data fpp(13,17, 5,1),fpp(13,17, 5,2),fpp(13,17, 5,3)/
     x-5.4486519D-05,-1.9352607D-10, 1.3624339D-10 /
      data fpp(13,17, 6,1),fpp(13,17, 6,2),fpp(13,17, 6,3)/
     x-6.3035402D-05,-2.3122877D-09, 6.6573938D-11 /
      data fpp(13,17, 7,1),fpp(13,17, 7,2),fpp(13,17, 7,3)/
     x-1.5274891D-06, 1.1960017D-09, 2.6412753D-10 /
      data fpp(13,17, 8,1),fpp(13,17, 8,2),fpp(13,17, 8,3)/
     x 7.6814199D-05,-4.1714392D-10,-4.5641739D-10 /
      data fpp(13,17, 9,1),fpp(13,17, 9,2),fpp(13,17, 9,3)/
     x 1.1000698D-04,-1.0658207D-09, 2.2820869D-10 /
      data fpp(13,17,10,1),fpp(13,17,10,2),fpp(13,17,10,3)/
     x 7.6814199D-05,-4.1714392D-10,-4.5641739D-10 /
      data fpp(13,17,11,1),fpp(13,17,11,2),fpp(13,17,11,3)/
     x-1.5274891D-06, 1.1960017D-09, 2.6412753D-10 /
      data fpp(13,17,12,1),fpp(13,17,12,2),fpp(13,17,12,3)/
     x-6.3035402D-05,-2.3122877D-09, 6.6573938D-11 /
      data fpp(13,17,13,1),fpp(13,17,13,2),fpp(13,17,13,3)/
     x-5.4486519D-05,-1.9352607D-10, 1.3624339D-10 /
      data fpp(13,17,14,1),fpp(13,17,14,2),fpp(13,17,14,3)/
     x-4.7579901D-06, 3.3177546D-09, 5.5119184D-11 /
      data fpp(13,17,15,1),fpp(13,17,15,2),fpp(13,17,15,3)/
     x 2.0518330D-05, 1.5325648D-09,-3.5672012D-10 /
      data fpp(13,17,16,1),fpp(13,17,16,2),fpp(13,17,16,3)/
     x-4.7579901D-06, 3.3177546D-09, 3.8427971D-11 /
      data fpp(13,17,17,1),fpp(13,17,17,2),fpp(13,17,17,3)/
     x-5.4486519D-05,-1.9352607D-10, 2.0300824D-10 /
      data fpp(13,18, 1,1),fpp(13,18, 1,2),fpp(13,18, 1,3)/
     x-4.6346318D-05, 1.0552932D-09,-2.0890266D-10 /
      data fpp(13,18, 2,1),fpp(13,18, 2,2),fpp(13,18, 2,3)/
     x-3.7082706D-05,-3.7650132D-10,-1.3775023D-10 /
      data fpp(13,18, 3,1),fpp(13,18, 3,2),fpp(13,18, 3,3)/
     x-3.1125199D-05, 8.4783862D-10, 9.3236922D-11 /
      data fpp(13,18, 4,1),fpp(13,18, 4,2),fpp(13,18, 4,3)/
     x-3.7082706D-05,-3.7650132D-10,-2.3519746D-10 /
      data fpp(13,18, 5,1),fpp(13,18, 5,2),fpp(13,18, 5,3)/
     x-4.6346318D-05, 1.0552932D-09, 1.8088624D-10 /
      data fpp(13,18, 6,1),fpp(13,18, 6,2),fpp(13,18, 6,3)/
     x-4.1255083D-05, 1.3749393D-09, 1.7831915D-10 /
      data fpp(13,18, 7,1),fpp(13,18, 7,2),fpp(13,18, 7,3)/
     x-1.5802606D-05,-5.6000490D-11,-2.2749618D-10 /
      data fpp(13,18, 8,1),fpp(13,18, 8,2),fpp(13,18, 8,3)/
     x 1.4008386D-05, 2.1191840D-09, 6.4998909D-11 /
      data fpp(13,18, 9,1),fpp(13,18, 9,2),fpp(13,18, 9,3)/
     x 2.7024927D-05, 2.3045202D-09,-3.2499455D-11 /
      data fpp(13,18,10,1),fpp(13,18,10,2),fpp(13,18,10,3)/
     x 1.4008386D-05, 2.1191840D-09, 6.4998909D-11 /
      data fpp(13,18,11,1),fpp(13,18,11,2),fpp(13,18,11,3)/
     x-1.5802606D-05,-5.6000490D-11,-2.2749618D-10 /
      data fpp(13,18,12,1),fpp(13,18,12,2),fpp(13,18,12,3)/
     x-4.1255083D-05, 1.3749393D-09, 1.7831915D-10 /
      data fpp(13,18,13,1),fpp(13,18,13,2),fpp(13,18,13,3)/
     x-4.6346318D-05, 1.0552932D-09, 1.8088624D-10 /
      data fpp(13,18,14,1),fpp(13,18,14,2),fpp(13,18,14,3)/
     x-3.7082706D-05,-3.7650132D-10,-2.3519746D-10 /
      data fpp(13,18,15,1),fpp(13,18,15,2),fpp(13,18,15,3)/
     x-3.1125199D-05, 8.4783862D-10, 9.3236922D-11 /
      data fpp(13,18,16,1),fpp(13,18,16,2),fpp(13,18,16,3)/
     x-3.7082706D-05,-3.7650132D-10,-1.3775023D-10 /
      data fpp(13,18,17,1),fpp(13,18,17,2),fpp(13,18,17,3)/
     x-4.6346318D-05, 1.0552932D-09,-2.0890266D-10 /
      data fpp(13,19, 1,1),fpp(13,19, 1,2),fpp(13,19, 1,3)/
     x-3.1158192D-05, 1.9723534D-09, 5.7701290D-24 /
      data fpp(13,19, 2,1),fpp(13,19, 2,2),fpp(13,19, 2,3)/
     x-3.1158192D-05,-1.8117493D-09,-4.4802561D-24 /
      data fpp(13,19, 3,1),fpp(13,19, 3,2),fpp(13,19, 3,3)/
     x-3.1158192D-05, 1.0760807D-09,-3.4590244D-24 /
      data fpp(13,19, 4,1),fpp(13,19, 4,2),fpp(13,19, 4,3)/
     x-3.1158192D-05,-1.8117493D-09,-7.4378063D-25 /
      data fpp(13,19, 5,1),fpp(13,19, 5,2),fpp(13,19, 5,3)/
     x-3.1158192D-05, 1.9723534D-09,-4.8164725D-25 /
      data fpp(13,19, 6,1),fpp(13,19, 6,2),fpp(13,19, 6,3)/
     x-3.1158192D-05, 2.8125303D-09,-2.2462439D-24 /
      data fpp(13,19, 7,1),fpp(13,19, 7,2),fpp(13,19, 7,3)/
     x-3.1158192D-05,-9.7199976D-10,-3.2153907D-24 /
      data fpp(13,19, 8,1),fpp(13,19, 8,2),fpp(13,19, 8,3)/
     x-3.1158192D-05, 3.9404080D-09, 3.4941565D-24 /
      data fpp(13,19, 9,1),fpp(13,19, 9,2),fpp(13,19, 9,3)/
     x-3.1158192D-05, 3.8477399D-09, 1.6876439D-24 /
      data fpp(13,19,10,1),fpp(13,19,10,2),fpp(13,19,10,3)/
     x-3.1158192D-05, 3.9404080D-09,-4.5934223D-24 /
      data fpp(13,19,11,1),fpp(13,19,11,2),fpp(13,19,11,3)/
     x-3.1158192D-05,-9.7199976D-10, 8.4998663D-25 /
      data fpp(13,19,12,1),fpp(13,19,12,2),fpp(13,19,12,3)/
     x-3.1158192D-05, 2.8125303D-09,-1.5093498D-24 /
      data fpp(13,19,13,1),fpp(13,19,13,2),fpp(13,19,13,3)/
     x-3.1158192D-05, 1.9723534D-09,-7.9466257D-26 /
      data fpp(13,19,14,1),fpp(13,19,14,2),fpp(13,19,14,3)/
     x-3.1158192D-05,-1.8117493D-09,-2.9517623D-25 /
      data fpp(13,19,15,1),fpp(13,19,15,2),fpp(13,19,15,3)/
     x-3.1158192D-05, 1.0760807D-09, 7.0192816D-25 /
      data fpp(13,19,16,1),fpp(13,19,16,2),fpp(13,19,16,3)/
     x-3.1158192D-05,-1.8117493D-09,-7.5023935D-25 /
      data fpp(13,19,17,1),fpp(13,19,17,2),fpp(13,19,17,3)/
     x-3.1158192D-05, 1.9723534D-09, 6.1142916D-25 /
 
      data fpppp( 1, 1, 1,1),fpppp( 1, 1, 1,2),fpppp( 1, 1, 1,3)/
     x-7.6558996D-05, 3.9105268D-19,-4.3279240D-07 /
      data fpppp( 1, 1, 2,1),fpppp( 1, 1, 2,2),fpppp( 1, 1, 2,3)/
     x-2.1492738D-04,-2.8231778D-18,-1.2155587D-07 /
      data fpppp( 1, 1, 3,1),fpppp( 1, 1, 3,2),fpppp( 1, 1, 3,3)/
     x-1.4089068D-03,-1.2926288D-18, 6.9418071D-07 /
      data fpppp( 1, 1, 4,1),fpppp( 1, 1, 4,2),fpppp( 1, 1, 4,3)/
     x-2.1492738D-04,-2.2641421D-18,-2.5583288D-07 /
      data fpppp( 1, 1, 5,1),fpppp( 1, 1, 5,2),fpppp( 1, 1, 5,3)/
     x-7.6558996D-05,-4.7862725D-19, 1.0431564D-07 /
      data fpppp( 1, 1, 6,1),fpppp( 1, 1, 6,2),fpppp( 1, 1, 6,3)/
     x 6.3066719D-05, 3.7585572D-19,-6.9060034D-07 /
      data fpppp( 1, 1, 7,1),fpppp( 1, 1, 7,2),fpppp( 1, 1, 7,3)/
     x-2.5064336D-03,-8.8272368D-19, 6.6206344D-07 /
      data fpppp( 1, 1, 8,1),fpppp( 1, 1, 8,2),fpppp( 1, 1, 8,3)/
     x-1.0048954D-03,-1.6767615D-18,-2.7586846D-07 /
      data fpppp( 1, 1, 9,1),fpppp( 1, 1, 9,2),fpppp( 1, 1, 9,3)/
     x-6.8669935D-04,-6.6795267D-19, 1.9528499D-07 /
      data fpppp( 1, 1,10,1),fpppp( 1, 1,10,2),fpppp( 1, 1,10,3)/
     x-1.0048954D-03,-1.9465323D-18,-2.7586846D-07 /
      data fpppp( 1, 1,11,1),fpppp( 1, 1,11,2),fpppp( 1, 1,11,3)/
     x-2.5064336D-03, 2.1439356D-18, 6.6206344D-07 /
      data fpppp( 1, 1,12,1),fpppp( 1, 1,12,2),fpppp( 1, 1,12,3)/
     x 6.3066719D-05,-3.5643168D-21,-6.9060034D-07 /
      data fpppp( 1, 1,13,1),fpppp( 1, 1,13,2),fpppp( 1, 1,13,3)/
     x-7.6558996D-05,-8.8002782D-20, 1.0431564D-07 /
      data fpppp( 1, 1,14,1),fpppp( 1, 1,14,2),fpppp( 1, 1,14,3)/
     x-2.1492738D-04,-3.3164457D-18,-2.5583288D-07 /
      data fpppp( 1, 1,15,1),fpppp( 1, 1,15,2),fpppp( 1, 1,15,3)/
     x-1.4089068D-03, 9.6356757D-19, 6.9418071D-07 /
      data fpppp( 1, 1,16,1),fpppp( 1, 1,16,2),fpppp( 1, 1,16,3)/
     x-2.1492738D-04,-3.6206861D-18,-1.2155587D-07 /
      data fpppp( 1, 1,17,1),fpppp( 1, 1,17,2),fpppp( 1, 1,17,3)/
     x-7.6558996D-05,-2.8407934D-19,-4.3279240D-07 /
      data fpppp( 1, 2, 1,1),fpppp( 1, 2, 1,2),fpppp( 1, 2, 1,3)/
     x 1.9177026D-05, 2.0085485D-05, 1.2499373D-07 /
      data fpppp( 1, 2, 2,1),fpppp( 1, 2, 2,2),fpppp( 1, 2, 2,3)/
     x 1.1679653D-04, 1.9959626D-05, 7.5175019D-08 /
      data fpppp( 1, 2, 3,1),fpppp( 1, 2, 3,2),fpppp( 1, 2, 3,3)/
     x 7.0814999D-04, 1.7218686D-05,-7.3803419D-08 /
      data fpppp( 1, 2, 4,1),fpppp( 1, 2, 4,2),fpppp( 1, 2, 4,3)/
     x 1.1679653D-04, 2.3630532D-05, 1.2427720D-07 /
      data fpppp( 1, 2, 5,1),fpppp( 1, 2, 5,2),fpppp( 1, 2, 5,3)/
     x 1.9177026D-05, 5.4018632D-06,-7.1414982D-08 /
      data fpppp( 1, 2, 6,1),fpppp( 1, 2, 6,2),fpppp( 1, 2, 6,3)/
     x 4.6744979D-05,-4.1282060D-05,-1.2262597D-08 /
      data fpppp( 1, 2, 7,1),fpppp( 1, 2, 7,2),fpppp( 1, 2, 7,3)/
     x 6.2582393D-05,-1.3576434D-05,-1.1241678D-07 /
      data fpppp( 1, 2, 8,1),fpppp( 1, 2, 8,2),fpppp( 1, 2, 8,3)/
     x-3.3748447D-04, 1.1961092D-05, 1.2320641D-07 /
      data fpppp( 1, 2, 9,1),fpppp( 1, 2, 9,2),fpppp( 1, 2, 9,3)/
     x-2.6270973D-04, 1.1123145D-05,-2.0791387D-08 /
      data fpppp( 1, 2,10,1),fpppp( 1, 2,10,2),fpppp( 1, 2,10,3)/
     x-3.3748447D-04, 1.1961092D-05, 1.2320641D-07 /
      data fpppp( 1, 2,11,1),fpppp( 1, 2,11,2),fpppp( 1, 2,11,3)/
     x 6.2582393D-05,-1.3576434D-05,-1.1241678D-07 /
      data fpppp( 1, 2,12,1),fpppp( 1, 2,12,2),fpppp( 1, 2,12,3)/
     x 4.6744979D-05,-4.1282060D-05,-1.2262597D-08 /
      data fpppp( 1, 2,13,1),fpppp( 1, 2,13,2),fpppp( 1, 2,13,3)/
     x 1.9177026D-05, 5.4018632D-06,-7.1414982D-08 /
      data fpppp( 1, 2,14,1),fpppp( 1, 2,14,2),fpppp( 1, 2,14,3)/
     x 1.1679653D-04, 2.3630532D-05, 1.2427720D-07 /
      data fpppp( 1, 2,15,1),fpppp( 1, 2,15,2),fpppp( 1, 2,15,3)/
     x 7.0814999D-04, 1.7218686D-05,-7.3803419D-08 /
      data fpppp( 1, 2,16,1),fpppp( 1, 2,16,2),fpppp( 1, 2,16,3)/
     x 1.1679653D-04, 1.9959626D-05, 7.5175019D-08 /
      data fpppp( 1, 2,17,1),fpppp( 1, 2,17,2),fpppp( 1, 2,17,3)/
     x 1.9177026D-05, 2.0085485D-05, 1.2499373D-07 /
      data fpppp( 1, 3, 1,1),fpppp( 1, 3, 1,2),fpppp( 1, 3, 1,3)/
     x 3.4523345D-04, 1.4436122D-04, 2.8170912D-07 /
      data fpppp( 1, 3, 2,1),fpppp( 1, 3, 2,2),fpppp( 1, 3, 2,3)/
     x 9.4956392D-04, 7.7534301D-05, 8.5452550D-08 /
      data fpppp( 1, 3, 3,1),fpppp( 1, 3, 3,2),fpppp( 1, 3, 3,3)/
     x 1.7299028D-03,-9.8509377D-05,-4.3372567D-07 /
      data fpppp( 1, 3, 4,1),fpppp( 1, 3, 4,2),fpppp( 1, 3, 4,3)/
     x 9.4956392D-04, 1.0770560D-04, 1.7732190D-07 /
      data fpppp( 1, 3, 5,1),fpppp( 1, 3, 5,2),fpppp( 1, 3, 5,3)/
     x 3.4523345D-04, 2.3676011D-05,-8.5768270D-08 /
      data fpppp( 1, 3, 6,1),fpppp( 1, 3, 6,2),fpppp( 1, 3, 6,3)/
     x-1.6974518D-04,-1.2879124D-04, 3.4238316D-07 /
      data fpppp( 1, 3, 7,1),fpppp( 1, 3, 7,2),fpppp( 1, 3, 7,3)/
     x 9.1445763D-04, 1.6342591D-05,-2.5049353D-07 /
      data fpppp( 1, 3, 8,1),fpppp( 1, 3, 8,2),fpppp( 1, 3, 8,3)/
     x 8.3639432D-04, 3.4518045D-05, 4.6659156D-08 /
      data fpppp( 1, 3, 9,1),fpppp( 1, 3, 9,2),fpppp( 1, 3, 9,3)/
     x 5.8472337D-04,-3.3640882D-06,-1.1167610D-08 /
      data fpppp( 1, 3,10,1),fpppp( 1, 3,10,2),fpppp( 1, 3,10,3)/
     x 8.3639432D-04, 3.4518045D-05, 4.6659156D-08 /
      data fpppp( 1, 3,11,1),fpppp( 1, 3,11,2),fpppp( 1, 3,11,3)/
     x 9.1445763D-04, 1.6342591D-05,-2.5049353D-07 /
      data fpppp( 1, 3,12,1),fpppp( 1, 3,12,2),fpppp( 1, 3,12,3)/
     x-1.6974518D-04,-1.2879124D-04, 3.4238316D-07 /
      data fpppp( 1, 3,13,1),fpppp( 1, 3,13,2),fpppp( 1, 3,13,3)/
     x 3.4523345D-04, 2.3676011D-05,-8.5768270D-08 /
      data fpppp( 1, 3,14,1),fpppp( 1, 3,14,2),fpppp( 1, 3,14,3)/
     x 9.4956392D-04, 1.0770560D-04, 1.7732190D-07 /
      data fpppp( 1, 3,15,1),fpppp( 1, 3,15,2),fpppp( 1, 3,15,3)/
     x 1.7299028D-03,-9.8509377D-05,-4.3372567D-07 /
      data fpppp( 1, 3,16,1),fpppp( 1, 3,16,2),fpppp( 1, 3,16,3)/
     x 9.4956392D-04, 7.7534301D-05, 8.5452550D-08 /
      data fpppp( 1, 3,17,1),fpppp( 1, 3,17,2),fpppp( 1, 3,17,3)/
     x 3.4523345D-04, 1.4436122D-04, 2.8170912D-07 /
      data fpppp( 1, 4, 1,1),fpppp( 1, 4, 1,2),fpppp( 1, 4, 1,3)/
     x-1.3483153D-04, 8.7782106D-04, 1.8421721D-06 /
      data fpppp( 1, 4, 2,1),fpppp( 1, 4, 2,2),fpppp( 1, 4, 2,3)/
     x 2.8679134D-05, 3.8027751D-04, 7.4831685D-07 /
      data fpppp( 1, 4, 3,1),fpppp( 1, 4, 3,2),fpppp( 1, 4, 3,3)/
     x 6.5852195D-03,-9.6067375D-04,-2.2218645D-06 /
      data fpppp( 1, 4, 4,1),fpppp( 1, 4, 4,2),fpppp( 1, 4, 4,3)/
     x 2.8679134D-05, 6.5030196D-04, 1.3750954D-06 /
      data fpppp( 1, 4, 5,1),fpppp( 1, 4, 5,2),fpppp( 1, 4, 5,3)/
     x-1.3483153D-04,-2.0227674D-04,-6.6494221D-07 /
      data fpppp( 1, 4, 6,1),fpppp( 1, 4, 6,2),fpppp( 1, 4, 6,3)/
     x 3.1435413D-04, 4.2378492D-04, 1.8299508D-06 /
      data fpppp( 1, 4, 7,1),fpppp( 1, 4, 7,2),fpppp( 1, 4, 7,3)/
     x 7.7763254D-03,-7.8121054D-04,-2.6159824D-06 /
      data fpppp( 1, 4, 8,1),fpppp( 1, 4, 8,2),fpppp( 1, 4, 8,3)/
     x 2.3763558D-04, 4.9736385D-04, 1.6347893D-06 /
      data fpppp( 1, 4, 9,1),fpppp( 1, 4, 9,2),fpppp( 1, 4, 9,3)/
     x-4.9895702D-05,-1.7024906D-04,-7.9149436D-07 /
      data fpppp( 1, 4,10,1),fpppp( 1, 4,10,2),fpppp( 1, 4,10,3)/
     x 2.3763558D-04, 4.9736385D-04, 1.6347893D-06 /
      data fpppp( 1, 4,11,1),fpppp( 1, 4,11,2),fpppp( 1, 4,11,3)/
     x 7.7763254D-03,-7.8121054D-04,-2.6159824D-06 /
      data fpppp( 1, 4,12,1),fpppp( 1, 4,12,2),fpppp( 1, 4,12,3)/
     x 3.1435413D-04, 4.2378492D-04, 1.8299508D-06 /
      data fpppp( 1, 4,13,1),fpppp( 1, 4,13,2),fpppp( 1, 4,13,3)/
     x-1.3483153D-04,-2.0227674D-04,-6.6494221D-07 /
      data fpppp( 1, 4,14,1),fpppp( 1, 4,14,2),fpppp( 1, 4,14,3)/
     x 2.8679134D-05, 6.5030196D-04, 1.3750954D-06 /
      data fpppp( 1, 4,15,1),fpppp( 1, 4,15,2),fpppp( 1, 4,15,3)/
     x 6.5852195D-03,-9.6067375D-04,-2.2218645D-06 /
      data fpppp( 1, 4,16,1),fpppp( 1, 4,16,2),fpppp( 1, 4,16,3)/
     x 2.8679134D-05, 3.8027751D-04, 7.4831685D-07 /
      data fpppp( 1, 4,17,1),fpppp( 1, 4,17,2),fpppp( 1, 4,17,3)/
     x-1.3483153D-04, 8.7782106D-04, 1.8421721D-06 /
      data fpppp( 1, 5, 1,1),fpppp( 1, 5, 1,2),fpppp( 1, 5, 1,3)/
     x-1.9427204D-04, 2.6760527D-03,-3.2690017D-06 /
      data fpppp( 1, 5, 2,1),fpppp( 1, 5, 2,2),fpppp( 1, 5, 2,3)/
     x-8.7708021D-04, 1.1419496D-03,-1.4208650D-06 /
      data fpppp( 1, 5, 3,1),fpppp( 1, 5, 3,2),fpppp( 1, 5, 3,3)/
     x-1.2032988D-02,-3.0261002D-03, 3.6312881D-06 /
      data fpppp( 1, 5, 4,1),fpppp( 1, 5, 4,2),fpppp( 1, 5, 4,3)/
     x-8.7708021D-04, 2.0246636D-03,-2.5306165D-06 /
      data fpppp( 1, 5, 5,1),fpppp( 1, 5, 5,2),fpppp( 1, 5, 5,3)/
     x-1.9427204D-04,-8.5480338D-04, 1.1700041D-06 /
      data fpppp( 1, 5, 6,1),fpppp( 1, 5, 6,2),fpppp( 1, 5, 6,3)/
     x-7.3642739D-04, 1.9970217D-03,-2.5111014D-06 /
      data fpppp( 1, 5, 7,1),fpppp( 1, 5, 7,2),fpppp( 1, 5, 7,3)/
     x-1.2229130D-02,-3.1570793D-03, 3.9252157D-06 /
      data fpppp( 1, 5, 8,1),fpppp( 1, 5, 8,2),fpppp( 1, 5, 8,3)/
     x-9.8538741D-04, 1.9829819D-03,-2.4597515D-06 /
      data fpppp( 1, 5, 9,1),fpppp( 1, 5, 9,2),fpppp( 1, 5, 9,3)/
     x-2.3465494D-04,-8.1234995D-04, 9.9625255D-07 /
      data fpppp( 1, 5,10,1),fpppp( 1, 5,10,2),fpppp( 1, 5,10,3)/
     x-9.8538741D-04, 1.9829819D-03,-2.4597515D-06 /
      data fpppp( 1, 5,11,1),fpppp( 1, 5,11,2),fpppp( 1, 5,11,3)/
     x-1.2229130D-02,-3.1570793D-03, 3.9252157D-06 /
      data fpppp( 1, 5,12,1),fpppp( 1, 5,12,2),fpppp( 1, 5,12,3)/
     x-7.3642739D-04, 1.9970217D-03,-2.5111014D-06 /
      data fpppp( 1, 5,13,1),fpppp( 1, 5,13,2),fpppp( 1, 5,13,3)/
     x-1.9427204D-04,-8.5480338D-04, 1.1700041D-06 /
      data fpppp( 1, 5,14,1),fpppp( 1, 5,14,2),fpppp( 1, 5,14,3)/
     x-8.7708021D-04, 2.0246636D-03,-2.5306165D-06 /
      data fpppp( 1, 5,15,1),fpppp( 1, 5,15,2),fpppp( 1, 5,15,3)/
     x-1.2032988D-02,-3.0261002D-03, 3.6312881D-06 /
      data fpppp( 1, 5,16,1),fpppp( 1, 5,16,2),fpppp( 1, 5,16,3)/
     x-8.7708021D-04, 1.1419496D-03,-1.4208650D-06 /
      data fpppp( 1, 5,17,1),fpppp( 1, 5,17,2),fpppp( 1, 5,17,3)/
     x-1.9427204D-04, 2.6760527D-03,-3.2690017D-06 /
      data fpppp( 1, 6, 1,1),fpppp( 1, 6, 1,2),fpppp( 1, 6, 1,3)/
     x 4.5677627D-05, 1.8922014D-03,-6.1340508D-07 /
      data fpppp( 1, 6, 2,1),fpppp( 1, 6, 2,2),fpppp( 1, 6, 2,3)/
     x-2.7326473D-05, 8.0350101D-04,-2.8646409D-07 /
      data fpppp( 1, 6, 3,1),fpppp( 1, 6, 3,2),fpppp( 1, 6, 3,3)/
     x-1.0130246D-03,-2.1547456D-03, 6.4570119D-07 /
      data fpppp( 1, 6, 4,1),fpppp( 1, 6, 4,2),fpppp( 1, 6, 4,3)/
     x-2.7326473D-05, 1.4304196D-03,-5.4041856D-07 /
      data fpppp( 1, 6, 5,1),fpppp( 1, 6, 5,2),fpppp( 1, 6, 5,3)/
     x 4.5677627D-05,-6.1547306D-04, 4.0241277D-07 /
      data fpppp( 1, 6, 6,1),fpppp( 1, 6, 6,2),fpppp( 1, 6, 6,3)/
     x 7.4845478D-05, 1.4902147D-03,-6.7830334D-07 /
      data fpppp( 1, 6, 7,1),fpppp( 1, 6, 7,2),fpppp( 1, 6, 7,3)/
     x-1.1759726D-03,-2.3345620D-03, 9.0806521D-07 /
      data fpppp( 1, 6, 8,1),fpppp( 1, 6, 8,2),fpppp( 1, 6, 8,3)/
     x-3.4009177D-05, 1.4593107D-03,-6.1768775D-07 /
      data fpppp( 1, 6, 9,1),fpppp( 1, 6, 9,2),fpppp( 1, 6, 9,3)/
     x-3.5336428D-05,-6.0058799D-04, 3.6383639D-07 /
      data fpppp( 1, 6,10,1),fpppp( 1, 6,10,2),fpppp( 1, 6,10,3)/
     x-3.4009177D-05, 1.4593107D-03,-6.1768775D-07 /
      data fpppp( 1, 6,11,1),fpppp( 1, 6,11,2),fpppp( 1, 6,11,3)/
     x-1.1759726D-03,-2.3345620D-03, 9.0806521D-07 /
      data fpppp( 1, 6,12,1),fpppp( 1, 6,12,2),fpppp( 1, 6,12,3)/
     x 7.4845478D-05, 1.4902147D-03,-6.7830334D-07 /
      data fpppp( 1, 6,13,1),fpppp( 1, 6,13,2),fpppp( 1, 6,13,3)/
     x 4.5677627D-05,-6.1547306D-04, 4.0241277D-07 /
      data fpppp( 1, 6,14,1),fpppp( 1, 6,14,2),fpppp( 1, 6,14,3)/
     x-2.7326473D-05, 1.4304196D-03,-5.4041856D-07 /
      data fpppp( 1, 6,15,1),fpppp( 1, 6,15,2),fpppp( 1, 6,15,3)/
     x-1.0130246D-03,-2.1547456D-03, 6.4570119D-07 /
      data fpppp( 1, 6,16,1),fpppp( 1, 6,16,2),fpppp( 1, 6,16,3)/
     x-2.7326473D-05, 8.0350101D-04,-2.8646409D-07 /
      data fpppp( 1, 6,17,1),fpppp( 1, 6,17,2),fpppp( 1, 6,17,3)/
     x 4.5677627D-05, 1.8922014D-03,-6.1340508D-07 /
      data fpppp( 1, 7, 1,1),fpppp( 1, 7, 1,2),fpppp( 1, 7, 1,3)/
     x 5.3195921D-05, 4.1077734D-04, 1.8764707D-06 /
      data fpppp( 1, 7, 2,1),fpppp( 1, 7, 2,2),fpppp( 1, 7, 2,3)/
     x 1.4530046D-04, 1.6849735D-04, 8.2195743D-07 /
      data fpppp( 1, 7, 3,1),fpppp( 1, 7, 3,2),fpppp( 1, 7, 3,3)/
     x 4.6033967D-03,-4.8380735D-04,-2.0562457D-06 /
      data fpppp( 1, 7, 4,1),fpppp( 1, 7, 4,2),fpppp( 1, 7, 4,3)/
     x 1.4530046D-04, 2.9897444D-04, 1.4484658D-06 /
      data fpppp( 1, 7, 5,1),fpppp( 1, 7, 5,2),fpppp( 1, 7, 5,3)/
     x 5.3195921D-05,-1.1113099D-04,-6.2956295D-07 /
      data fpppp( 1, 7, 6,1),fpppp( 1, 7, 6,2),fpppp( 1, 7, 6,3)/
     x 2.9292139D-04, 3.4184220D-04, 1.1919709D-06 /
      data fpppp( 1, 7, 7,1),fpppp( 1, 7, 7,2),fpppp( 1, 7, 7,3)/
     x 4.6180099D-03,-5.4247497D-04,-1.9411932D-06 /
      data fpppp( 1, 7, 8,1),fpppp( 1, 7, 8,2),fpppp( 1, 7, 8,3)/
     x 2.3408642D-04, 3.2098783D-04, 1.2996730D-06 /
      data fpppp( 1, 7, 9,1),fpppp( 1, 7, 9,2),fpppp( 1, 7, 9,3)/
     x 1.6842936D-05,-1.1084348D-04,-5.7804336D-07 /
      data fpppp( 1, 7,10,1),fpppp( 1, 7,10,2),fpppp( 1, 7,10,3)/
     x 2.3408642D-04, 3.2098783D-04, 1.2996730D-06 /
      data fpppp( 1, 7,11,1),fpppp( 1, 7,11,2),fpppp( 1, 7,11,3)/
     x 4.6180099D-03,-5.4247497D-04,-1.9411932D-06 /
      data fpppp( 1, 7,12,1),fpppp( 1, 7,12,2),fpppp( 1, 7,12,3)/
     x 2.9292139D-04, 3.4184220D-04, 1.1919709D-06 /
      data fpppp( 1, 7,13,1),fpppp( 1, 7,13,2),fpppp( 1, 7,13,3)/
     x 5.3195921D-05,-1.1113099D-04,-6.2956295D-07 /
      data fpppp( 1, 7,14,1),fpppp( 1, 7,14,2),fpppp( 1, 7,14,3)/
     x 1.4530046D-04, 2.9897444D-04, 1.4484658D-06 /
      data fpppp( 1, 7,15,1),fpppp( 1, 7,15,2),fpppp( 1, 7,15,3)/
     x 4.6033967D-03,-4.8380735D-04,-2.0562457D-06 /
      data fpppp( 1, 7,16,1),fpppp( 1, 7,16,2),fpppp( 1, 7,16,3)/
     x 1.4530046D-04, 1.6849735D-04, 8.2195743D-07 /
      data fpppp( 1, 7,17,1),fpppp( 1, 7,17,2),fpppp( 1, 7,17,3)/
     x 5.3195921D-05, 4.1077734D-04, 1.8764707D-06 /
      data fpppp( 1, 8, 1,1),fpppp( 1, 8, 1,2),fpppp( 1, 8, 1,3)/
     x 2.8402281D-05, 6.8124173D-05, 4.7333320D-08 /
      data fpppp( 1, 8, 2,1),fpppp( 1, 8, 2,2),fpppp( 1, 8, 2,3)/
     x 3.1735634D-05, 2.5118916D-05, 6.6466009D-08 /
      data fpppp( 1, 8, 3,1),fpppp( 1, 8, 3,2),fpppp( 1, 8, 3,3)/
     x-3.3978459D-05,-8.6782491D-05, 7.7984016D-08 /
      data fpppp( 1, 8, 4,1),fpppp( 1, 8, 4,2),fpppp( 1, 8, 4,3)/
     x 3.1735634D-05, 4.2452631D-05, 1.1615341D-07 /
      data fpppp( 1, 8, 5,1),fpppp( 1, 8, 5,2),fpppp( 1, 8, 5,3)/
     x 2.8402281D-05,-1.2106841D-06,-1.5141629D-07 /
      data fpppp( 1, 8, 6,1),fpppp( 1, 8, 6,2),fpppp( 1, 8, 6,3)/
     x 8.7600665D-05, 4.5790566D-05,-2.9197119D-08 /
      data fpppp( 1, 8, 7,1),fpppp( 1, 8, 7,2),fpppp( 1, 8, 7,3)/
     x 1.9417249D-04,-8.6489837D-05,-4.1129354D-08 /
      data fpppp( 1, 8, 8,1),fpppp( 1, 8, 8,2),fpppp( 1, 8, 8,3)/
     x 7.0163794D-05, 4.4324324D-05, 9.4960644D-08 /
      data fpppp( 1, 8, 9,1),fpppp( 1, 8, 9,2),fpppp( 1, 8, 9,3)/
     x 6.8748249D-06,-6.2556870D-08,-4.8445363D-08 /
      data fpppp( 1, 8,10,1),fpppp( 1, 8,10,2),fpppp( 1, 8,10,3)/
     x 7.0163794D-05, 4.4324324D-05, 9.4960644D-08 /
      data fpppp( 1, 8,11,1),fpppp( 1, 8,11,2),fpppp( 1, 8,11,3)/
     x 1.9417249D-04,-8.6489837D-05,-4.1129354D-08 /
      data fpppp( 1, 8,12,1),fpppp( 1, 8,12,2),fpppp( 1, 8,12,3)/
     x 8.7600665D-05, 4.5790566D-05,-2.9197119D-08 /
      data fpppp( 1, 8,13,1),fpppp( 1, 8,13,2),fpppp( 1, 8,13,3)/
     x 2.8402281D-05,-1.2106841D-06,-1.5141629D-07 /
      data fpppp( 1, 8,14,1),fpppp( 1, 8,14,2),fpppp( 1, 8,14,3)/
     x 3.1735634D-05, 4.2452631D-05, 1.1615341D-07 /
      data fpppp( 1, 8,15,1),fpppp( 1, 8,15,2),fpppp( 1, 8,15,3)/
     x-3.3978459D-05,-8.6782491D-05, 7.7984016D-08 /
      data fpppp( 1, 8,16,1),fpppp( 1, 8,16,2),fpppp( 1, 8,16,3)/
     x 3.1735634D-05, 2.5118916D-05, 6.6466009D-08 /
      data fpppp( 1, 8,17,1),fpppp( 1, 8,17,2),fpppp( 1, 8,17,3)/
     x 2.8402281D-05, 6.8124173D-05, 4.7333320D-08 /
      data fpppp( 1, 9, 1,1),fpppp( 1, 9, 1,2),fpppp( 1, 9, 1,3)/
     x 1.5748056D-05, 1.9258808D-05,-2.0704305D-07 /
      data fpppp( 1, 9, 2,1),fpppp( 1, 9, 2,2),fpppp( 1, 9, 2,3)/
     x 1.6140685D-05, 8.3238822D-06,-5.2649897D-08 /
      data fpppp( 1, 9, 3,1),fpppp( 1, 9, 3,2),fpppp( 1, 9, 3,3)/
     x 1.6464970D-04,-1.8999243D-05, 3.3590243D-07 /
      data fpppp( 1, 9, 4,1),fpppp( 1, 9, 4,2),fpppp( 1, 9, 4,3)/
     x 1.6140685D-05, 1.1036330D-05,-9.5102343D-08 /
      data fpppp( 1, 9, 5,1),fpppp( 1, 9, 5,2),fpppp( 1, 9, 5,3)/
     x 1.5748056D-05, 8.4090161D-06,-3.7233268D-08 /
      data fpppp( 1, 9, 6,1),fpppp( 1, 9, 6,2),fpppp( 1, 9, 6,3)/
     x 5.4498392D-05,-5.1530372D-06,-1.1083399D-07 /
      data fpppp( 1, 9, 7,1),fpppp( 1, 9, 7,2),fpppp( 1, 9, 7,3)/
     x 1.5864454D-04,-2.8385929D-05, 4.2898361D-08 /
      data fpppp( 1, 9, 8,1),fpppp( 1, 9, 8,2),fpppp( 1, 9, 8,3)/
     x 3.1987084D-05, 1.8284609D-05, 2.5625080D-08 /
      data fpppp( 1, 9, 9,1),fpppp( 1, 9, 9,2),fpppp( 1, 9, 9,3)/
     x 4.0454874D-05, 1.1069340D-05, 6.3144934D-09 /
      data fpppp( 1, 9,10,1),fpppp( 1, 9,10,2),fpppp( 1, 9,10,3)/
     x 3.1987084D-05, 1.8284609D-05, 2.5625080D-08 /
      data fpppp( 1, 9,11,1),fpppp( 1, 9,11,2),fpppp( 1, 9,11,3)/
     x 1.5864454D-04,-2.8385929D-05, 4.2898361D-08 /
      data fpppp( 1, 9,12,1),fpppp( 1, 9,12,2),fpppp( 1, 9,12,3)/
     x 5.4498392D-05,-5.1530372D-06,-1.1083399D-07 /
      data fpppp( 1, 9,13,1),fpppp( 1, 9,13,2),fpppp( 1, 9,13,3)/
     x 1.5748056D-05, 8.4090161D-06,-3.7233268D-08 /
      data fpppp( 1, 9,14,1),fpppp( 1, 9,14,2),fpppp( 1, 9,14,3)/
     x 1.6140685D-05, 1.1036330D-05,-9.5102343D-08 /
      data fpppp( 1, 9,15,1),fpppp( 1, 9,15,2),fpppp( 1, 9,15,3)/
     x 1.6464970D-04,-1.8999243D-05, 3.3590243D-07 /
      data fpppp( 1, 9,16,1),fpppp( 1, 9,16,2),fpppp( 1, 9,16,3)/
     x 1.6140685D-05, 8.3238822D-06,-5.2649897D-08 /
      data fpppp( 1, 9,17,1),fpppp( 1, 9,17,2),fpppp( 1, 9,17,3)/
     x 1.5748056D-05, 1.9258808D-05,-2.0704305D-07 /
      data fpppp( 1,10, 1,1),fpppp( 1,10, 1,2),fpppp( 1,10, 1,3)/
     x 1.9487872D-05, 7.3364428D-06, 1.2031955D-08 /
      data fpppp( 1,10, 2,1),fpppp( 1,10, 2,2),fpppp( 1,10, 2,3)/
     x 6.7328486D-05, 7.0349115D-06, 2.1594101D-08 /
      data fpppp( 1,10, 3,1),fpppp( 1,10, 3,2),fpppp( 1,10, 3,3)/
     x 1.0466141D-04, 6.8067948D-06, 4.4451119D-08 /
      data fpppp( 1,10, 4,1),fpppp( 1,10, 4,2),fpppp( 1,10, 4,3)/
     x 6.7328486D-05, 6.3217270D-06, 2.0776083D-08 /
      data fpppp( 1,10, 5,1),fpppp( 1,10, 5,2),fpppp( 1,10, 5,3)/
     x 1.9487872D-05, 1.0189181D-05, 1.5304027D-08 /
      data fpppp( 1,10, 6,1),fpppp( 1,10, 6,2),fpppp( 1,10, 6,3)/
     x-6.4188752D-05,-3.1077130D-05,-1.4164568D-07 /
      data fpppp( 1,10, 7,1),fpppp( 1,10, 7,2),fpppp( 1,10, 7,3)/
     x-2.9042482D-05,-1.4989462D-05, 6.8976349D-08 /
      data fpppp( 1,10, 8,1),fpppp( 1,10, 8,2),fpppp( 1,10, 8,3)/
     x 4.0590584D-05, 2.1687567D-05, 2.2360519D-09 /
      data fpppp( 1,10, 9,1),fpppp( 1,10, 9,2),fpppp( 1,10, 9,3)/
     x 4.6056252D-05, 8.8105747D-06, 2.4118881D-08 /
      data fpppp( 1,10,10,1),fpppp( 1,10,10,2),fpppp( 1,10,10,3)/
     x 4.0590584D-05, 2.1687567D-05, 2.2360519D-09 /
      data fpppp( 1,10,11,1),fpppp( 1,10,11,2),fpppp( 1,10,11,3)/
     x-2.9042482D-05,-1.4989462D-05, 6.8976349D-08 /
      data fpppp( 1,10,12,1),fpppp( 1,10,12,2),fpppp( 1,10,12,3)/
     x-6.4188752D-05,-3.1077130D-05,-1.4164568D-07 /
      data fpppp( 1,10,13,1),fpppp( 1,10,13,2),fpppp( 1,10,13,3)/
     x 1.9487872D-05, 1.0189181D-05, 1.5304027D-08 /
      data fpppp( 1,10,14,1),fpppp( 1,10,14,2),fpppp( 1,10,14,3)/
     x 6.7328486D-05, 6.3217270D-06, 2.0776083D-08 /
      data fpppp( 1,10,15,1),fpppp( 1,10,15,2),fpppp( 1,10,15,3)/
     x 1.0466141D-04, 6.8067948D-06, 4.4451119D-08 /
      data fpppp( 1,10,16,1),fpppp( 1,10,16,2),fpppp( 1,10,16,3)/
     x 6.7328486D-05, 7.0349115D-06, 2.1594101D-08 /
      data fpppp( 1,10,17,1),fpppp( 1,10,17,2),fpppp( 1,10,17,3)/
     x 1.9487872D-05, 7.3364428D-06, 1.2031955D-08 /
      data fpppp( 1,11, 1,1),fpppp( 1,11, 1,2),fpppp( 1,11, 1,3)/
     x-3.1636836D-07, 9.0100980D-06, 5.0864582D-08 /
      data fpppp( 1,11, 2,1),fpppp( 1,11, 2,2),fpppp( 1,11, 2,3)/
     x 3.9468953D-05, 9.6013542D-06, 2.6834791D-08 /
      data fpppp( 1,11, 3,1),fpppp( 1,11, 3,2),fpppp( 1,11, 3,3)/
     x 5.6546527D-05, 1.2859367D-05,-2.1621443D-08 /
      data fpppp( 1,11, 4,1),fpppp( 1,11, 4,2),fpppp( 1,11, 4,3)/
     x 3.9468953D-05, 6.7837316D-06, 1.5414875D-08 /
      data fpppp( 1,11, 5,1),fpppp( 1,11, 5,2),fpppp( 1,11, 5,3)/
     x-3.1636836D-07, 2.0280588D-05, 9.6544245D-08 /
      data fpppp( 1,11, 6,1),fpppp( 1,11, 6,2),fpppp( 1,11, 6,3)/
     x 3.3673391D-04,-6.5130078D-05,-2.2410849D-07 /
      data fpppp( 1,11, 7,1),fpppp( 1,11, 7,2),fpppp( 1,11, 7,3)/
     x 1.1107744D-05, 9.0568432D-06, 1.2316995D-07 /
      data fpppp( 1,11, 8,1),fpppp( 1,11, 8,2),fpppp( 1,11, 8,3)/
     x 2.6546356D-05, 1.8198738D-05,-1.6898919D-08 /
      data fpppp( 1,11, 9,1),fpppp( 1,11, 9,2),fpppp( 1,11, 9,3)/
     x 2.6929650D-05, 8.2913834D-06, 3.1474798D-08 /
      data fpppp( 1,11,10,1),fpppp( 1,11,10,2),fpppp( 1,11,10,3)/
     x 2.6546356D-05, 1.8198738D-05,-1.6898919D-08 /
      data fpppp( 1,11,11,1),fpppp( 1,11,11,2),fpppp( 1,11,11,3)/
     x 1.1107744D-05, 9.0568432D-06, 1.2316995D-07 /
      data fpppp( 1,11,12,1),fpppp( 1,11,12,2),fpppp( 1,11,12,3)/
     x 3.3673391D-04,-6.5130078D-05,-2.2410849D-07 /
      data fpppp( 1,11,13,1),fpppp( 1,11,13,2),fpppp( 1,11,13,3)/
     x-3.1636836D-07, 2.0280588D-05, 9.6544245D-08 /
      data fpppp( 1,11,14,1),fpppp( 1,11,14,2),fpppp( 1,11,14,3)/
     x 3.9468953D-05, 6.7837316D-06, 1.5414875D-08 /
      data fpppp( 1,11,15,1),fpppp( 1,11,15,2),fpppp( 1,11,15,3)/
     x 5.6546527D-05, 1.2859367D-05,-2.1621443D-08 /
      data fpppp( 1,11,16,1),fpppp( 1,11,16,2),fpppp( 1,11,16,3)/
     x 3.9468953D-05, 9.6013542D-06, 2.6834791D-08 /
      data fpppp( 1,11,17,1),fpppp( 1,11,17,2),fpppp( 1,11,17,3)/
     x-3.1636836D-07, 9.0100980D-06, 5.0864582D-08 /
      data fpppp( 1,12, 1,1),fpppp( 1,12, 1,2),fpppp( 1,12, 1,3)/
     x 7.2713032D-05, 1.3204974D-05, 4.8221031D-08 /
      data fpppp( 1,12, 2,1),fpppp( 1,12, 2,2),fpppp( 1,12, 2,3)/
     x 1.5649745D-05, 1.1762409D-05, 2.6364111D-08 /
      data fpppp( 1,12, 3,1),fpppp( 1,12, 3,2),fpppp( 1,12, 3,3)/
     x 2.1116963D-05, 1.3700250D-05,-2.7506163D-08 /
      data fpppp( 1,12, 4,1),fpppp( 1,12, 4,2),fpppp( 1,12, 4,3)/
     x 1.5649745D-05, 3.8066712D-06, 3.0670305D-08 /
      data fpppp( 1,12, 5,1),fpppp( 1,12, 5,2),fpppp( 1,12, 5,3)/
     x 7.2713032D-05, 4.5027925D-05, 3.0996256D-08 /
      data fpppp( 1,12, 6,1),fpppp( 1,12, 6,2),fpppp( 1,12, 6,3)/
     x-1.0286571D-03,-1.1958180D-04,-1.3933530D-07 /
      data fpppp( 1,12, 7,1),fpppp( 1,12, 7,2),fpppp( 1,12, 7,3)/
     x-2.4054922D-05, 5.2718920D-05, 1.0004633D-07 /
      data fpppp( 1,12, 8,1),fpppp( 1,12, 8,2),fpppp( 1,12, 8,3)/
     x 1.1540401D-05, 4.3943711D-06,-2.0435373D-08 /
      data fpppp( 1,12, 9,1),fpppp( 1,12, 9,2),fpppp( 1,12, 9,3)/
     x 1.6931782D-05, 1.2241615D-05, 2.4339423D-08 /
      data fpppp( 1,12,10,1),fpppp( 1,12,10,2),fpppp( 1,12,10,3)/
     x 1.1540401D-05, 4.3943711D-06,-2.0435373D-08 /
      data fpppp( 1,12,11,1),fpppp( 1,12,11,2),fpppp( 1,12,11,3)/
     x-2.4054922D-05, 5.2718920D-05, 1.0004633D-07 /
      data fpppp( 1,12,12,1),fpppp( 1,12,12,2),fpppp( 1,12,12,3)/
     x-1.0286571D-03,-1.1958180D-04,-1.3933530D-07 /
      data fpppp( 1,12,13,1),fpppp( 1,12,13,2),fpppp( 1,12,13,3)/
     x 7.2713032D-05, 4.5027925D-05, 3.0996256D-08 /
      data fpppp( 1,12,14,1),fpppp( 1,12,14,2),fpppp( 1,12,14,3)/
     x 1.5649745D-05, 3.8066712D-06, 3.0670305D-08 /
      data fpppp( 1,12,15,1),fpppp( 1,12,15,2),fpppp( 1,12,15,3)/
     x 2.1116963D-05, 1.3700250D-05,-2.7506163D-08 /
      data fpppp( 1,12,16,1),fpppp( 1,12,16,2),fpppp( 1,12,16,3)/
     x 1.5649745D-05, 1.1762409D-05, 2.6364111D-08 /
      data fpppp( 1,12,17,1),fpppp( 1,12,17,2),fpppp( 1,12,17,3)/
     x 7.2713032D-05, 1.3204974D-05, 4.8221031D-08 /
      data fpppp( 1,13, 1,1),fpppp( 1,13, 1,2),fpppp( 1,13, 1,3)/
     x-9.4756184D-05, 2.6593174D-05, 7.3791595D-08 /
      data fpppp( 1,13, 2,1),fpppp( 1,13, 2,2),fpppp( 1,13, 2,3)/
     x-3.4219510D-05, 1.7327555D-05, 2.8994831D-08 /
      data fpppp( 1,13, 3,1),fpppp( 1,13, 3,2),fpppp( 1,13, 3,3)/
     x-1.3494374D-05, 1.2576192D-05,-5.1584742D-09 /
      data fpppp( 1,13, 4,1),fpppp( 1,13, 4,2),fpppp( 1,13, 4,3)/
     x-3.4219510D-05,-7.9750649D-06,-7.6563887D-08 /
      data fpppp( 1,13, 5,1),fpppp( 1,13, 5,2),fpppp( 1,13, 5,3)/
     x-9.4756184D-05, 1.2780365D-04, 4.9602647D-07 /
      data fpppp( 1,13, 6,1),fpppp( 1,13, 6,2),fpppp( 1,13, 6,3)/
     x 5.1255581D-03,-2.8356989D-04,-9.5586546D-07 /
      data fpppp( 1,13, 7,1),fpppp( 1,13, 7,2),fpppp( 1,13, 7,3)/
     x-8.1438185D-05, 1.8026505D-04, 6.9450957D-07 /
      data fpppp( 1,13, 8,1),fpppp( 1,13, 8,2),fpppp( 1,13, 8,3)/
     x 7.2418582D-06,-3.9774995D-05,-2.1714383D-07 /
      data fpppp( 1,13, 9,1),fpppp( 1,13, 9,2),fpppp( 1,13, 9,3)/
     x 1.5265670D-05, 2.9709200D-05, 1.0563963D-07 /
      data fpppp( 1,13,10,1),fpppp( 1,13,10,2),fpppp( 1,13,10,3)/
     x 7.2418582D-06,-3.9774995D-05,-2.1714383D-07 /
      data fpppp( 1,13,11,1),fpppp( 1,13,11,2),fpppp( 1,13,11,3)/
     x-8.1438185D-05, 1.8026505D-04, 6.9450957D-07 /
      data fpppp( 1,13,12,1),fpppp( 1,13,12,2),fpppp( 1,13,12,3)/
     x 5.1255581D-03,-2.8356989D-04,-9.5586546D-07 /
      data fpppp( 1,13,13,1),fpppp( 1,13,13,2),fpppp( 1,13,13,3)/
     x-9.4756184D-05, 1.2780365D-04, 4.9602647D-07 /
      data fpppp( 1,13,14,1),fpppp( 1,13,14,2),fpppp( 1,13,14,3)/
     x-3.4219510D-05,-7.9750649D-06,-7.6563887D-08 /
      data fpppp( 1,13,15,1),fpppp( 1,13,15,2),fpppp( 1,13,15,3)/
     x-1.3494374D-05, 1.2576192D-05,-5.1584742D-09 /
      data fpppp( 1,13,16,1),fpppp( 1,13,16,2),fpppp( 1,13,16,3)/
     x-3.4219510D-05, 1.7327555D-05, 2.8994831D-08 /
      data fpppp( 1,13,17,1),fpppp( 1,13,17,2),fpppp( 1,13,17,3)/
     x-9.4756184D-05, 2.6593174D-05, 7.3791595D-08 /
      data fpppp( 1,14, 1,1),fpppp( 1,14, 1,2),fpppp( 1,14, 1,3)/
     x 2.5248599D-03, 1.2203553D-04, 4.2413795D-07 /
      data fpppp( 1,14, 2,1),fpppp( 1,14, 2,2),fpppp( 1,14, 2,3)/
     x 1.2686738D-04, 6.9762246D-05, 2.8095918D-07 /
      data fpppp( 1,14, 3,1),fpppp( 1,14, 3,2),fpppp( 1,14, 3,3)/
     x 7.4972741D-05,-8.1488338D-06,-2.4903576D-07 /
      data fpppp( 1,14, 4,1),fpppp( 1,14, 4,2),fpppp( 1,14, 4,3)/
     x 1.2686738D-04, 3.6723835D-06, 5.7482590D-07 /
      data fpppp( 1,14, 5,1),fpppp( 1,14, 5,2),fpppp( 1,14, 5,3)/
     x 2.5248599D-03, 3.8639498D-04,-7.5132892D-07 /
      data fpppp( 1,14, 6,1),fpppp( 1,14, 6,2),fpppp( 1,14, 6,3)/
     x-1.2616324D-02,-9.0471689D-04, 2.1078370D-07 /
      data fpppp( 1,14, 7,1),fpppp( 1,14, 7,2),fpppp( 1,14, 7,3)/
     x 9.2408161D-05, 6.5470298D-04, 2.1103592D-07 /
      data fpppp( 1,14, 8,1),fpppp( 1,14, 8,2),fpppp( 1,14, 8,3)/
     x 2.4373121D-06,-1.9046431D-04,-1.0641803D-07 /
      data fpppp( 1,14, 9,1),fpppp( 1,14, 9,2),fpppp( 1,14, 9,3)/
     x 9.6123738D-06, 9.7955555D-05, 2.0216416D-08 /
      data fpppp( 1,14,10,1),fpppp( 1,14,10,2),fpppp( 1,14,10,3)/
     x 2.4373121D-06,-1.9046431D-04,-1.0641803D-07 /
      data fpppp( 1,14,11,1),fpppp( 1,14,11,2),fpppp( 1,14,11,3)/
     x 9.2408161D-05, 6.5470298D-04, 2.1103592D-07 /
      data fpppp( 1,14,12,1),fpppp( 1,14,12,2),fpppp( 1,14,12,3)/
     x-1.2616324D-02,-9.0471689D-04, 2.1078370D-07 /
      data fpppp( 1,14,13,1),fpppp( 1,14,13,2),fpppp( 1,14,13,3)/
     x 2.5248599D-03, 3.8639498D-04,-7.5132892D-07 /
      data fpppp( 1,14,14,1),fpppp( 1,14,14,2),fpppp( 1,14,14,3)/
     x 1.2686738D-04, 3.6723835D-06, 5.7482590D-07 /
      data fpppp( 1,14,15,1),fpppp( 1,14,15,2),fpppp( 1,14,15,3)/
     x 7.4972741D-05,-8.1488338D-06,-2.4903576D-07 /
      data fpppp( 1,14,16,1),fpppp( 1,14,16,2),fpppp( 1,14,16,3)/
     x 1.2686738D-04, 6.9762246D-05, 2.8095918D-07 /
      data fpppp( 1,14,17,1),fpppp( 1,14,17,2),fpppp( 1,14,17,3)/
     x 2.5248599D-03, 1.2203553D-04, 4.2413795D-07 /
      data fpppp( 1,15, 1,1),fpppp( 1,15, 1,2),fpppp( 1,15, 1,3)/
     x-2.0543696D-03, 4.7644180D-04,-8.1826056D-07 /
      data fpppp( 1,15, 2,1),fpppp( 1,15, 2,2),fpppp( 1,15, 2,3)/
     x-5.2597431D-04, 3.4065918D-04,-5.3324386D-07 /
      data fpppp( 1,15, 3,1),fpppp( 1,15, 3,2),fpppp( 1,15, 3,3)/
     x-3.6691280D-04,-2.7554827D-04, 1.6634795D-07 /
      data fpppp( 1,15, 4,1),fpppp( 1,15, 4,2),fpppp( 1,15, 4,3)/
     x-5.2597431D-04, 7.8973122D-04,-5.8507315D-07 /
      data fpppp( 1,15, 5,1),fpppp( 1,15, 5,2),fpppp( 1,15, 5,3)/
     x-2.0543696D-03,-1.3198464D-03,-6.1094341D-07 /
      data fpppp( 1,15, 6,1),fpppp( 1,15, 6,2),fpppp( 1,15, 6,3)/
     x 2.0032706D-02, 9.7456825D-04, 2.8227947D-06 /
      data fpppp( 1,15, 7,1),fpppp( 1,15, 7,2),fpppp( 1,15, 7,3)/
     x 2.7706228D-04,-3.3779566D-04,-2.0200766D-06 /
      data fpppp( 1,15, 8,1),fpppp( 1,15, 8,2),fpppp( 1,15, 8,3)/
     x 4.5362114D-05, 9.5583711D-05, 4.5932548D-07 /
      data fpppp( 1,15, 9,1),fpppp( 1,15, 9,2),fpppp( 1,15, 9,3)/
     x 4.3233584D-05,-5.4088732D-05,-3.0704006D-07 /
      data fpppp( 1,15,10,1),fpppp( 1,15,10,2),fpppp( 1,15,10,3)/
     x 4.5362114D-05, 9.5583711D-05, 4.5932548D-07 /
      data fpppp( 1,15,11,1),fpppp( 1,15,11,2),fpppp( 1,15,11,3)/
     x 2.7706228D-04,-3.3779566D-04,-2.0200766D-06 /
      data fpppp( 1,15,12,1),fpppp( 1,15,12,2),fpppp( 1,15,12,3)/
     x 2.0032706D-02, 9.7456825D-04, 2.8227947D-06 /
      data fpppp( 1,15,13,1),fpppp( 1,15,13,2),fpppp( 1,15,13,3)/
     x-2.0543696D-03,-1.3198464D-03,-6.1094341D-07 /
      data fpppp( 1,15,14,1),fpppp( 1,15,14,2),fpppp( 1,15,14,3)/
     x-5.2597431D-04, 7.8973122D-04,-5.8507315D-07 /
      data fpppp( 1,15,15,1),fpppp( 1,15,15,2),fpppp( 1,15,15,3)/
     x-3.6691280D-04,-2.7554827D-04, 1.6634795D-07 /
      data fpppp( 1,15,16,1),fpppp( 1,15,16,2),fpppp( 1,15,16,3)/
     x-5.2597431D-04, 3.4065918D-04,-5.3324386D-07 /
      data fpppp( 1,15,17,1),fpppp( 1,15,17,2),fpppp( 1,15,17,3)/
     x-2.0543696D-03, 4.7644180D-04,-8.1826056D-07 /
      data fpppp( 1,16, 1,1),fpppp( 1,16, 1,2),fpppp( 1,16, 1,3)/
     x-5.1361874D-03, 5.2729041D-04,-6.8408787D-07 /
      data fpppp( 1,16, 2,1),fpppp( 1,16, 2,2),fpppp( 1,16, 2,3)/
     x 1.2442147D-03, 3.2889828D-04,-5.0793941D-07 /
      data fpppp( 1,16, 3,1),fpppp( 1,16, 3,2),fpppp( 1,16, 3,3)/
     x 9.3010804D-04,-2.0050825D-04, 8.6418876D-08 /
      data fpppp( 1,16, 4,1),fpppp( 1,16, 4,2),fpppp( 1,16, 4,3)/
     x 1.2442147D-03, 4.2863564D-04,-7.8295724D-07 /
      data fpppp( 1,16, 5,1),fpppp( 1,16, 5,2),fpppp( 1,16, 5,3)/
     x-5.1361874D-03, 1.2834097D-04, 4.1598344D-07 /
      data fpppp( 1,16, 6,1),fpppp( 1,16, 6,2),fpppp( 1,16, 6,3)/
     x-2.2709373D-02,-1.3133820D-03, 1.2394980D-06 /
      data fpppp( 1,16, 7,1),fpppp( 1,16, 7,2),fpppp( 1,16, 7,3)/
     x-5.8304505D-04, 1.0929465D-03,-9.0129177D-07 /
      data fpppp( 1,16, 8,1),fpppp( 1,16, 8,2),fpppp( 1,16, 8,3)/
     x-1.0725253D-04,-2.9448106D-04, 3.5905379D-08 /
      data fpppp( 1,16, 9,1),fpppp( 1,16, 9,2),fpppp( 1,16, 9,3)/
     x-1.2548987D-04, 1.3301095D-04,-1.4653080D-07 /
      data fpppp( 1,16,10,1),fpppp( 1,16,10,2),fpppp( 1,16,10,3)/
     x-1.0725253D-04,-2.9448106D-04, 3.5905379D-08 /
      data fpppp( 1,16,11,1),fpppp( 1,16,11,2),fpppp( 1,16,11,3)/
     x-5.8304505D-04, 1.0929465D-03,-9.0129177D-07 /
      data fpppp( 1,16,12,1),fpppp( 1,16,12,2),fpppp( 1,16,12,3)/
     x-2.2709373D-02,-1.3133820D-03, 1.2394980D-06 /
      data fpppp( 1,16,13,1),fpppp( 1,16,13,2),fpppp( 1,16,13,3)/
     x-5.1361874D-03, 1.2834097D-04, 4.1598344D-07 /
      data fpppp( 1,16,14,1),fpppp( 1,16,14,2),fpppp( 1,16,14,3)/
     x 1.2442147D-03, 4.2863564D-04,-7.8295724D-07 /
      data fpppp( 1,16,15,1),fpppp( 1,16,15,2),fpppp( 1,16,15,3)/
     x 9.3010804D-04,-2.0050825D-04, 8.6418876D-08 /
      data fpppp( 1,16,16,1),fpppp( 1,16,16,2),fpppp( 1,16,16,3)/
     x 1.2442147D-03, 3.2889828D-04,-5.0793941D-07 /
      data fpppp( 1,16,17,1),fpppp( 1,16,17,2),fpppp( 1,16,17,3)/
     x-5.1361874D-03, 5.2729041D-04,-6.8408787D-07 /
      data fpppp( 1,17, 1,1),fpppp( 1,17, 1,2),fpppp( 1,17, 1,3)/
     x-9.3529750D-03,-2.9204745D-04, 5.8217236D-07 /
      data fpppp( 1,17, 2,1),fpppp( 1,17, 2,2),fpppp( 1,17, 2,3)/
     x-8.4653297D-03,-2.4225982D-04, 3.1302752D-07 /
      data fpppp( 1,17, 3,1),fpppp( 1,17, 3,2),fpppp( 1,17, 3,3)/
     x-5.6456693D-03, 6.9489965D-05,-3.1200783D-07 /
      data fpppp( 1,17, 4,1),fpppp( 1,17, 4,2),fpppp( 1,17, 4,3)/
     x-8.4653297D-03,-5.3562780D-04, 3.0857359D-07 /
      data fpppp( 1,17, 5,1),fpppp( 1,17, 5,2),fpppp( 1,17, 5,3)/
     x-9.3529750D-03, 8.8142449D-04, 5.9998806D-07 /
      data fpppp( 1,17, 6,1),fpppp( 1,17, 6,2),fpppp( 1,17, 6,3)/
     x 9.7351530D-03,-3.4884813D-04,-2.0409318D-06 /
      data fpppp( 1,17, 7,1),fpppp( 1,17, 7,2),fpppp( 1,17, 7,3)/
     x-2.9489500D-04,-3.1458970D-05, 1.7066459D-06 /
      data fpppp( 1,17, 8,1),fpppp( 1,17, 8,2),fpppp( 1,17, 8,3)/
     x 5.3636206D-05,-1.6397221D-05,-4.6125047D-07 /
      data fpppp( 1,17, 9,1),fpppp( 1,17, 9,2),fpppp( 1,17, 9,3)/
     x 1.7561652D-04,-1.6569351D-05, 8.5214979D-08 /
      data fpppp( 1,17,10,1),fpppp( 1,17,10,2),fpppp( 1,17,10,3)/
     x 5.3636206D-05,-1.6397221D-05,-4.6125047D-07 /
      data fpppp( 1,17,11,1),fpppp( 1,17,11,2),fpppp( 1,17,11,3)/
     x-2.9489500D-04,-3.1458970D-05, 1.7066459D-06 /
      data fpppp( 1,17,12,1),fpppp( 1,17,12,2),fpppp( 1,17,12,3)/
     x 9.7351530D-03,-3.4884813D-04,-2.0409318D-06 /
      data fpppp( 1,17,13,1),fpppp( 1,17,13,2),fpppp( 1,17,13,3)/
     x-9.3529750D-03, 8.8142449D-04, 5.9998806D-07 /
      data fpppp( 1,17,14,1),fpppp( 1,17,14,2),fpppp( 1,17,14,3)/
     x-8.4653297D-03,-5.3562780D-04, 3.0857359D-07 /
      data fpppp( 1,17,15,1),fpppp( 1,17,15,2),fpppp( 1,17,15,3)/
     x-5.6456693D-03, 6.9489965D-05,-3.1200783D-07 /
      data fpppp( 1,17,16,1),fpppp( 1,17,16,2),fpppp( 1,17,16,3)/
     x-8.4653297D-03,-2.4225982D-04, 3.1302752D-07 /
      data fpppp( 1,17,17,1),fpppp( 1,17,17,2),fpppp( 1,17,17,3)/
     x-9.3529750D-03,-2.9204745D-04, 5.8217236D-07 /
      data fpppp( 1,18, 1,1),fpppp( 1,18, 1,2),fpppp( 1,18, 1,3)/
     x 1.9950389D-02,-5.6160903D-04, 4.1874601D-07 /
      data fpppp( 1,18, 2,1),fpppp( 1,18, 2,2),fpppp( 1,18, 2,3)/
     x 8.7204940D-03,-6.1296376D-04, 3.0475416D-07 /
      data fpppp( 1,18, 3,1),fpppp( 1,18, 3,2),fpppp( 1,18, 3,3)/
     x 4.8343814D-03,-8.1289813D-05,-1.0594462D-08 /
      data fpppp( 1,18, 4,1),fpppp( 1,18, 4,2),fpppp( 1,18, 4,3)/
     x 8.7204940D-03,-1.5902162D-03, 3.7880565D-07 /
      data fpppp( 1,18, 5,1),fpppp( 1,18, 5,2),fpppp( 1,18, 5,3)/
     x 1.9950389D-02, 3.3474008D-03, 1.2254008D-07 /
      data fpppp( 1,18, 6,1),fpppp( 1,18, 6,2),fpppp( 1,18, 6,3)/
     x 1.3614303D-03,-1.8242878D-03,-5.3293664D-07 /
      data fpppp( 1,18, 7,1),fpppp( 1,18, 7,2),fpppp( 1,18, 7,3)/
     x-1.1956806D-03, 1.4209897D-04, 2.6655978D-08 /
      data fpppp( 1,18, 8,1),fpppp( 1,18, 8,2),fpppp( 1,18, 8,3)/
     x-2.3053779D-03,-1.2228300D-04, 2.6911414D-08 /
      data fpppp( 1,18, 9,1),fpppp( 1,18, 9,2),fpppp( 1,18, 9,3)/
     x-2.5438299D-03, 1.2988930D-05,-2.1016587D-08 /
      data fpppp( 1,18,10,1),fpppp( 1,18,10,2),fpppp( 1,18,10,3)/
     x-2.3053779D-03,-1.2228300D-04, 2.6911414D-08 /
      data fpppp( 1,18,11,1),fpppp( 1,18,11,2),fpppp( 1,18,11,3)/
     x-1.1956806D-03, 1.4209897D-04, 2.6655978D-08 /
      data fpppp( 1,18,12,1),fpppp( 1,18,12,2),fpppp( 1,18,12,3)/
     x 1.3614303D-03,-1.8242878D-03,-5.3293664D-07 /
      data fpppp( 1,18,13,1),fpppp( 1,18,13,2),fpppp( 1,18,13,3)/
     x 1.9950389D-02, 3.3474008D-03, 1.2254008D-07 /
      data fpppp( 1,18,14,1),fpppp( 1,18,14,2),fpppp( 1,18,14,3)/
     x 8.7204940D-03,-1.5902162D-03, 3.7880565D-07 /
      data fpppp( 1,18,15,1),fpppp( 1,18,15,2),fpppp( 1,18,15,3)/
     x 4.8343814D-03,-8.1289813D-05,-1.0594462D-08 /
      data fpppp( 1,18,16,1),fpppp( 1,18,16,2),fpppp( 1,18,16,3)/
     x 8.7204940D-03,-6.1296376D-04, 3.0475416D-07 /
      data fpppp( 1,18,17,1),fpppp( 1,18,17,2),fpppp( 1,18,17,3)/
     x 1.9950389D-02,-5.6160903D-04, 4.1874601D-07 /
      data fpppp( 1,19, 1,1),fpppp( 1,19, 1,2),fpppp( 1,19, 1,3)/
     x 3.9676568D-02, 2.3122945D-18, 6.6380154D-07 /
      data fpppp( 1,19, 2,1),fpppp( 1,19, 2,2),fpppp( 1,19, 2,3)/
     x 1.8221927D-02,-3.5937308D-18, 5.3340661D-07 /
      data fpppp( 1,19, 3,1),fpppp( 1,19, 3,2),fpppp( 1,19, 3,3)/
     x 1.0441338D-02,-4.0244860D-18, 9.0864598D-08 /
      data fpppp( 1,19, 4,1),fpppp( 1,19, 4,2),fpppp( 1,19, 4,3)/
     x 1.8221927D-02, 1.7266287D-18, 7.4083735D-07 /
      data fpppp( 1,19, 5,1),fpppp( 1,19, 5,2),fpppp( 1,19, 5,3)/
     x 3.9676568D-02, 6.2702206D-19,-1.6592145D-07 /
      data fpppp( 1,19, 6,1),fpppp( 1,19, 6,2),fpppp( 1,19, 6,3)/
     x 4.6500644D-03,-1.4759122D-18,-3.9306288D-07 /
      data fpppp( 1,19, 7,1),fpppp( 1,19, 7,2),fpppp( 1,19, 7,3)/
     x-1.7567703D-03,-1.1510699D-18,-4.2821177D-07 /
      data fpppp( 1,19, 8,1),fpppp( 1,19, 8,2),fpppp( 1,19, 8,3)/
     x-3.9444198D-03,-1.1978406D-18, 2.3355394D-07 /
      data fpppp( 1,19, 9,1),fpppp( 1,19, 9,2),fpppp( 1,19, 9,3)/
     x-4.4002613D-03, 1.1888336D-19,-3.0683199D-08 /
      data fpppp( 1,19,10,1),fpppp( 1,19,10,2),fpppp( 1,19,10,3)/
     x-3.9444198D-03, 2.6355021D-18, 2.3355394D-07 /
      data fpppp( 1,19,11,1),fpppp( 1,19,11,2),fpppp( 1,19,11,3)/
     x-1.7567703D-03,-1.6936314D-19,-4.2821177D-07 /
      data fpppp( 1,19,12,1),fpppp( 1,19,12,2),fpppp( 1,19,12,3)/
     x 4.6500644D-03, 1.4003094D-19,-3.9306288D-07 /
      data fpppp( 1,19,13,1),fpppp( 1,19,13,2),fpppp( 1,19,13,3)/
     x 3.9676568D-02, 1.3812162D-18,-1.6592145D-07 /
      data fpppp( 1,19,14,1),fpppp( 1,19,14,2),fpppp( 1,19,14,3)/
     x 1.8221927D-02,-1.0142083D-19, 7.4083735D-07 /
      data fpppp( 1,19,15,1),fpppp( 1,19,15,2),fpppp( 1,19,15,3)/
     x 1.0441338D-02, 1.9694061D-18, 9.0864598D-08 /
      data fpppp( 1,19,16,1),fpppp( 1,19,16,2),fpppp( 1,19,16,3)/
     x 1.8221927D-02,-1.2454473D-18, 5.3340661D-07 /
      data fpppp( 1,19,17,1),fpppp( 1,19,17,2),fpppp( 1,19,17,3)/
     x 3.9676568D-02, 5.8036458D-18, 6.6380154D-07 /
      data fpppp( 2, 1, 1,1),fpppp( 2, 1, 1,2),fpppp( 2, 1, 1,3)/
     x-4.1377132D-05, 8.5120682D-22,-1.9172205D-07 /
      data fpppp( 2, 1, 2,1),fpppp( 2, 1, 2,2),fpppp( 2, 1, 2,3)/
     x-1.8314100D-04,-1.2730811D-18,-3.0681651D-08 /
      data fpppp( 2, 1, 3,1),fpppp( 2, 1, 3,2),fpppp( 2, 1, 3,3)/
     x-1.0268683D-03,-6.7439344D-19, 3.7668178D-07 /
      data fpppp( 2, 1, 4,1),fpppp( 2, 1, 4,2),fpppp( 2, 1, 4,3)/
     x-1.8314100D-04,-1.1056927D-18,-7.8085416D-08 /
      data fpppp( 2, 1, 5,1),fpppp( 2, 1, 5,2),fpppp( 2, 1, 5,3)/
     x-4.1377132D-05,-2.1739933D-19,-2.1069909D-09 /
      data fpppp( 2, 1, 6,1),fpppp( 2, 1, 6,2),fpppp( 2, 1, 6,3)/
     x 6.7323684D-05, 8.1183273D-20,-3.3396592D-07 /
      data fpppp( 2, 1, 7,1),fpppp( 2, 1, 7,2),fpppp( 2, 1, 7,3)/
     x-1.6172100D-03,-4.8688597D-19, 2.4044742D-07 /
      data fpppp( 2, 1, 8,1),fpppp( 2, 1, 8,2),fpppp( 2, 1, 8,3)/
     x-6.5794883D-04,-9.3399493D-19,-7.6691590D-08 /
      data fpppp( 2, 1, 9,1),fpppp( 2, 1, 9,2),fpppp( 2, 1, 9,3)/
     x-4.6866722D-04,-3.0849588D-19, 1.1622257D-07 /
      data fpppp( 2, 1,10,1),fpppp( 2, 1,10,2),fpppp( 2, 1,10,3)/
     x-6.5794883D-04,-8.6540884D-19,-7.6691590D-08 /
      data fpppp( 2, 1,11,1),fpppp( 2, 1,11,2),fpppp( 2, 1,11,3)/
     x-1.6172100D-03, 1.0944204D-18, 2.4044742D-07 /
      data fpppp( 2, 1,12,1),fpppp( 2, 1,12,2),fpppp( 2, 1,12,3)/
     x 6.7323684D-05, 1.3761602D-20,-3.3396592D-07 /
      data fpppp( 2, 1,13,1),fpppp( 2, 1,13,2),fpppp( 2, 1,13,3)/
     x-4.1377132D-05, 3.4248436D-20,-2.1069909D-09 /
      data fpppp( 2, 1,14,1),fpppp( 2, 1,14,2),fpppp( 2, 1,14,3)/
     x-1.8314100D-04,-1.5914521D-18,-7.8085416D-08 /
      data fpppp( 2, 1,15,1),fpppp( 2, 1,15,2),fpppp( 2, 1,15,3)/
     x-1.0268683D-03, 4.5430951D-19, 3.7668178D-07 /
      data fpppp( 2, 1,16,1),fpppp( 2, 1,16,2),fpppp( 2, 1,16,3)/
     x-1.8314100D-04,-1.7663432D-18,-3.0681651D-08 /
      data fpppp( 2, 1,17,1),fpppp( 2, 1,17,2),fpppp( 2, 1,17,3)/
     x-4.1377132D-05,-4.5911759D-19,-1.9172205D-07 /
      data fpppp( 2, 2, 1,1),fpppp( 2, 2, 1,2),fpppp( 2, 2, 1,3)/
     x 9.2111978D-06, 1.2901616D-05, 3.6201890D-08 /
      data fpppp( 2, 2, 2,1),fpppp( 2, 2, 2,2),fpppp( 2, 2, 2,3)/
     x 5.8498475D-05, 1.3424463D-05, 3.4796603D-08 /
      data fpppp( 2, 2, 3,1),fpppp( 2, 2, 3,2),fpppp( 2, 2, 3,3)/
     x 4.3121376D-04, 1.2915179D-05, 1.7012103D-08 /
      data fpppp( 2, 2, 4,1),fpppp( 2, 2, 4,2),fpppp( 2, 2, 4,3)/
     x 5.8498475D-05, 1.6018354D-05, 5.6554848D-08 /
      data fpppp( 2, 2, 5,1),fpppp( 2, 2, 5,2),fpppp( 2, 2, 5,3)/
     x 9.2111978D-06, 2.5260521D-06,-5.0831091D-08 /
      data fpppp( 2, 2, 6,1),fpppp( 2, 2, 6,2),fpppp( 2, 2, 6,3)/
     x 3.5095799D-05,-2.7201079D-05,-2.3858557D-08 /
      data fpppp( 2, 2, 7,1),fpppp( 2, 2, 7,2),fpppp( 2, 2, 7,3)/
     x 5.2189452D-05,-9.4327827D-06,-5.4014866D-08 /
      data fpppp( 2, 2, 8,1),fpppp( 2, 2, 8,2),fpppp( 2, 2, 8,3)/
     x-2.2530181D-04, 7.8522873D-06, 6.0906996D-08 /
      data fpppp( 2, 2, 9,1),fpppp( 2, 2, 9,2),fpppp( 2, 2, 9,3)/
     x-1.8692372D-04, 7.9914734D-06, 9.0996110D-09 /
      data fpppp( 2, 2,10,1),fpppp( 2, 2,10,2),fpppp( 2, 2,10,3)/
     x-2.2530181D-04, 7.8522873D-06, 6.0906996D-08 /
      data fpppp( 2, 2,11,1),fpppp( 2, 2,11,2),fpppp( 2, 2,11,3)/
     x 5.2189452D-05,-9.4327827D-06,-5.4014866D-08 /
      data fpppp( 2, 2,12,1),fpppp( 2, 2,12,2),fpppp( 2, 2,12,3)/
     x 3.5095799D-05,-2.7201079D-05,-2.3858557D-08 /
      data fpppp( 2, 2,13,1),fpppp( 2, 2,13,2),fpppp( 2, 2,13,3)/
     x 9.2111978D-06, 2.5260521D-06,-5.0831091D-08 /
      data fpppp( 2, 2,14,1),fpppp( 2, 2,14,2),fpppp( 2, 2,14,3)/
     x 5.8498475D-05, 1.6018354D-05, 5.6554848D-08 /
      data fpppp( 2, 2,15,1),fpppp( 2, 2,15,2),fpppp( 2, 2,15,3)/
     x 4.3121376D-04, 1.2915179D-05, 1.7012103D-08 /
      data fpppp( 2, 2,16,1),fpppp( 2, 2,16,2),fpppp( 2, 2,16,3)/
     x 5.8498475D-05, 1.3424463D-05, 3.4796603D-08 /
      data fpppp( 2, 2,17,1),fpppp( 2, 2,17,2),fpppp( 2, 2,17,3)/
     x 9.2111978D-06, 1.2901616D-05, 3.6201890D-08 /
      data fpppp( 2, 3, 1,1),fpppp( 2, 3, 1,2),fpppp( 2, 3, 1,3)/
     x 2.0221724D-04, 9.5510812D-05, 1.1399969D-07 /
      data fpppp( 2, 3, 2,1),fpppp( 2, 3, 2,2),fpppp( 2, 3, 2,3)/
     x 6.3280179D-04, 5.2695454D-05, 2.9831502D-08 /
      data fpppp( 2, 3, 3,1),fpppp( 2, 3, 3,2),fpppp( 2, 3, 3,3)/
     x 1.2472213D-03,-6.1087386D-05,-1.9188045D-07 /
      data fpppp( 2, 3, 4,1),fpppp( 2, 3, 4,2),fpppp( 2, 3, 4,3)/
     x 6.3280179D-04, 7.3515964D-05, 6.7810768D-08 /
      data fpppp( 2, 3, 5,1),fpppp( 2, 3, 5,2),fpppp( 2, 3, 5,3)/
     x 2.0221724D-04, 1.2228773D-05,-3.7917376D-08 /
      data fpppp( 2, 3, 6,1),fpppp( 2, 3, 6,2),fpppp( 2, 3, 6,3)/
     x-1.2020979D-04,-8.2834534D-05, 1.5901032D-07 /
      data fpppp( 2, 3, 7,1),fpppp( 2, 3, 7,2),fpppp( 2, 3, 7,3)/
     x 6.2524490D-04, 3.1854261D-06,-8.8719928D-08 /
      data fpppp( 2, 3, 8,1),fpppp( 2, 3, 8,2),fpppp( 2, 3, 8,3)/
     x 5.3283399D-04, 2.5665165D-05, 9.7413126D-09 /
      data fpppp( 2, 3, 9,1),fpppp( 2, 3, 9,2),fpppp( 2, 3, 9,3)/
     x 3.6944189D-04, 1.0358822D-06,-2.1639871D-08 /
      data fpppp( 2, 3,10,1),fpppp( 2, 3,10,2),fpppp( 2, 3,10,3)/
     x 5.3283399D-04, 2.5665165D-05, 9.7413126D-09 /
      data fpppp( 2, 3,11,1),fpppp( 2, 3,11,2),fpppp( 2, 3,11,3)/
     x 6.2524490D-04, 3.1854261D-06,-8.8719928D-08 /
      data fpppp( 2, 3,12,1),fpppp( 2, 3,12,2),fpppp( 2, 3,12,3)/
     x-1.2020979D-04,-8.2834534D-05, 1.5901032D-07 /
      data fpppp( 2, 3,13,1),fpppp( 2, 3,13,2),fpppp( 2, 3,13,3)/
     x 2.0221724D-04, 1.2228773D-05,-3.7917376D-08 /
      data fpppp( 2, 3,14,1),fpppp( 2, 3,14,2),fpppp( 2, 3,14,3)/
     x 6.3280179D-04, 7.3515964D-05, 6.7810768D-08 /
      data fpppp( 2, 3,15,1),fpppp( 2, 3,15,2),fpppp( 2, 3,15,3)/
     x 1.2472213D-03,-6.1087386D-05,-1.9188045D-07 /
      data fpppp( 2, 3,16,1),fpppp( 2, 3,16,2),fpppp( 2, 3,16,3)/
     x 6.3280179D-04, 5.2695454D-05, 2.9831502D-08 /
      data fpppp( 2, 3,17,1),fpppp( 2, 3,17,2),fpppp( 2, 3,17,3)/
     x 2.0221724D-04, 9.5510812D-05, 1.1399969D-07 /
      data fpppp( 2, 4, 1,1),fpppp( 2, 4, 1,2),fpppp( 2, 4, 1,3)/
     x-1.0323871D-04, 5.9696135D-04, 7.1723897D-07 /
      data fpppp( 2, 4, 2,1),fpppp( 2, 4, 2,2),fpppp( 2, 4, 2,3)/
     x 4.2781664D-05, 2.5974083D-04, 2.7141815D-07 /
      data fpppp( 2, 4, 3,1),fpppp( 2, 4, 3,2),fpppp( 2, 4, 3,3)/
     x 4.3104896D-03,-6.4942267D-04,-9.2849295D-07 /
      data fpppp( 2, 4, 4,1),fpppp( 2, 4, 4,2),fpppp( 2, 4, 4,3)/
     x 4.2781664D-05, 4.4321423D-04, 5.1091189D-07 /
      data fpppp( 2, 4, 5,1),fpppp( 2, 4, 5,2),fpppp( 2, 4, 5,3)/
     x-1.0323871D-04,-1.3693227D-04,-2.4073601D-07 /
      data fpppp( 2, 4, 6,1),fpppp( 2, 4, 6,2),fpppp( 2, 4, 6,3)/
     x 1.5525658D-04, 2.8615504D-04, 7.8721388D-07 /
      data fpppp( 2, 4, 7,1),fpppp( 2, 4, 7,2),fpppp( 2, 4, 7,3)/
     x 5.0355044D-03,-5.3665934D-04,-1.0325753D-06 /
      data fpppp( 2, 4, 8,1),fpppp( 2, 4, 8,2),fpppp( 2, 4, 8,3)/
     x 1.5175910D-04, 3.3870242D-04, 6.1925057D-07 /
      data fpppp( 2, 4, 9,1),fpppp( 2, 4, 9,2),fpppp( 2, 4, 9,3)/
     x-3.5369927D-05,-1.0895860D-04,-3.1972154D-07 /
      data fpppp( 2, 4,10,1),fpppp( 2, 4,10,2),fpppp( 2, 4,10,3)/
     x 1.5175910D-04, 3.3870242D-04, 6.1925057D-07 /
      data fpppp( 2, 4,11,1),fpppp( 2, 4,11,2),fpppp( 2, 4,11,3)/
     x 5.0355044D-03,-5.3665934D-04,-1.0325753D-06 /
      data fpppp( 2, 4,12,1),fpppp( 2, 4,12,2),fpppp( 2, 4,12,3)/
     x 1.5525658D-04, 2.8615504D-04, 7.8721388D-07 /
      data fpppp( 2, 4,13,1),fpppp( 2, 4,13,2),fpppp( 2, 4,13,3)/
     x-1.0323871D-04,-1.3693227D-04,-2.4073601D-07 /
      data fpppp( 2, 4,14,1),fpppp( 2, 4,14,2),fpppp( 2, 4,14,3)/
     x 4.2781664D-05, 4.4321423D-04, 5.1091189D-07 /
      data fpppp( 2, 4,15,1),fpppp( 2, 4,15,2),fpppp( 2, 4,15,3)/
     x 4.3104896D-03,-6.4942267D-04,-9.2849295D-07 /
      data fpppp( 2, 4,16,1),fpppp( 2, 4,16,2),fpppp( 2, 4,16,3)/
     x 4.2781664D-05, 2.5974083D-04, 2.7141815D-07 /
      data fpppp( 2, 4,17,1),fpppp( 2, 4,17,2),fpppp( 2, 4,17,3)/
     x-1.0323871D-04, 5.9696135D-04, 7.1723897D-07 /
      data fpppp( 2, 5, 1,1),fpppp( 2, 5, 1,2),fpppp( 2, 5, 1,3)/
     x-1.2523299D-04, 1.7912726D-03,-1.3339328D-06 /
      data fpppp( 2, 5, 2,1),fpppp( 2, 5, 2,2),fpppp( 2, 5, 2,3)/
     x-6.1732894D-04, 7.6437280D-04,-5.9648969D-07 /
      data fpppp( 2, 5, 3,1),fpppp( 2, 5, 3,2),fpppp( 2, 5, 3,3)/
     x-7.9124158D-03,-2.0245657D-03, 1.4333719D-06 /
      data fpppp( 2, 5, 4,1),fpppp( 2, 5, 4,2),fpppp( 2, 5, 4,3)/
     x-6.1732894D-04, 1.3536313D-03,-1.0602313D-06 /
      data fpppp( 2, 5, 5,1),fpppp( 2, 5, 5,2),fpppp( 2, 5, 5,3)/
     x-1.2523299D-04,-5.6576137D-04, 5.2103351D-07 /
      data fpppp( 2, 5, 6,1),fpppp( 2, 5, 6,2),fpppp( 2, 5, 6,3)/
     x-5.0085446D-04, 1.3284872D-03,-9.8090126D-07 /
      data fpppp( 2, 5, 7,1),fpppp( 2, 5, 7,2),fpppp( 2, 5, 7,3)/
     x-7.9949214D-03,-2.1083792D-03, 1.5477506D-06 /
      data fpppp( 2, 5, 8,1),fpppp( 2, 5, 8,2),fpppp( 2, 5, 8,3)/
     x-6.7761883D-04, 1.3189565D-03,-9.7714632D-07 /
      data fpppp( 2, 5, 9,1),fpppp( 2, 5, 9,2),fpppp( 2, 5, 9,3)/
     x-1.5213342D-04,-5.3109359D-04, 3.8832738D-07 /
      data fpppp( 2, 5,10,1),fpppp( 2, 5,10,2),fpppp( 2, 5,10,3)/
     x-6.7761883D-04, 1.3189565D-03,-9.7714632D-07 /
      data fpppp( 2, 5,11,1),fpppp( 2, 5,11,2),fpppp( 2, 5,11,3)/
     x-7.9949214D-03,-2.1083792D-03, 1.5477506D-06 /
      data fpppp( 2, 5,12,1),fpppp( 2, 5,12,2),fpppp( 2, 5,12,3)/
     x-5.0085446D-04, 1.3284872D-03,-9.8090126D-07 /
      data fpppp( 2, 5,13,1),fpppp( 2, 5,13,2),fpppp( 2, 5,13,3)/
     x-1.2523299D-04,-5.6576137D-04, 5.2103351D-07 /
      data fpppp( 2, 5,14,1),fpppp( 2, 5,14,2),fpppp( 2, 5,14,3)/
     x-6.1732894D-04, 1.3536313D-03,-1.0602313D-06 /
      data fpppp( 2, 5,15,1),fpppp( 2, 5,15,2),fpppp( 2, 5,15,3)/
     x-7.9124158D-03,-2.0245657D-03, 1.4333719D-06 /
      data fpppp( 2, 5,16,1),fpppp( 2, 5,16,2),fpppp( 2, 5,16,3)/
     x-6.1732894D-04, 7.6437280D-04,-5.9648969D-07 /
      data fpppp( 2, 5,17,1),fpppp( 2, 5,17,2),fpppp( 2, 5,17,3)/
     x-1.2523299D-04, 1.7912726D-03,-1.3339328D-06 /
      data fpppp( 2, 6, 1,1),fpppp( 2, 6, 1,2),fpppp( 2, 6, 1,3)/
     x 3.9404800D-05, 1.2889856D-03,-2.6149873D-07 /
      data fpppp( 2, 6, 2,1),fpppp( 2, 6, 2,2),fpppp( 2, 6, 2,3)/
     x-1.4029538D-05, 5.4743224D-04,-1.3191100D-07 /
      data fpppp( 2, 6, 3,1),fpppp( 2, 6, 3,2),fpppp( 2, 6, 3,3)/
     x-8.3211322D-04,-1.4673676D-03, 2.5260281D-07 /
      data fpppp( 2, 6, 4,1),fpppp( 2, 6, 4,2),fpppp( 2, 6, 4,3)/
     x-1.4029538D-05, 9.7419510D-04,-2.5512466D-07 /
      data fpppp( 2, 6, 5,1),fpppp( 2, 6, 5,2),fpppp( 2, 6, 5,3)/
     x 3.9404800D-05,-4.1806581D-04, 2.3135591D-07 /
      data fpppp( 2, 6, 6,1),fpppp( 2, 6, 6,2),fpppp( 2, 6, 6,3)/
     x 7.1681132D-05, 1.0115172D-03,-3.3924679D-07 /
      data fpppp( 2, 6, 7,1),fpppp( 2, 6, 7,2),fpppp( 2, 6, 7,3)/
     x-9.2993765D-04,-1.5845173D-03, 4.2881089D-07 /
      data fpppp( 2, 6, 8,1),fpppp( 2, 6, 8,2),fpppp( 2, 6, 8,3)/
     x-8.6873077D-06, 9.8778082D-04,-2.9585899D-07 /
      data fpppp( 2, 6, 9,1),fpppp( 2, 6, 9,2),fpppp( 2, 6, 9,3)/
     x-1.8892606D-05,-4.0332516D-04, 1.8698887D-07 /
      data fpppp( 2, 6,10,1),fpppp( 2, 6,10,2),fpppp( 2, 6,10,3)/
     x-8.6873077D-06, 9.8778082D-04,-2.9585899D-07 /
      data fpppp( 2, 6,11,1),fpppp( 2, 6,11,2),fpppp( 2, 6,11,3)/
     x-9.2993765D-04,-1.5845173D-03, 4.2881089D-07 /
      data fpppp( 2, 6,12,1),fpppp( 2, 6,12,2),fpppp( 2, 6,12,3)/
     x 7.1681132D-05, 1.0115172D-03,-3.3924679D-07 /
      data fpppp( 2, 6,13,1),fpppp( 2, 6,13,2),fpppp( 2, 6,13,3)/
     x 3.9404800D-05,-4.1806581D-04, 2.3135591D-07 /
      data fpppp( 2, 6,14,1),fpppp( 2, 6,14,2),fpppp( 2, 6,14,3)/
     x-1.4029538D-05, 9.7419510D-04,-2.5512466D-07 /
      data fpppp( 2, 6,15,1),fpppp( 2, 6,15,2),fpppp( 2, 6,15,3)/
     x-8.3211322D-04,-1.4673676D-03, 2.5260281D-07 /
      data fpppp( 2, 6,16,1),fpppp( 2, 6,16,2),fpppp( 2, 6,16,3)/
     x-1.4029538D-05, 5.4743224D-04,-1.3191100D-07 /
      data fpppp( 2, 6,17,1),fpppp( 2, 6,17,2),fpppp( 2, 6,17,3)/
     x 3.9404800D-05, 1.2889856D-03,-2.6149873D-07 /
      data fpppp( 2, 7, 1,1),fpppp( 2, 7, 1,2),fpppp( 2, 7, 1,3)/
     x 4.3795015D-05, 2.8931765D-04, 9.5476316D-07 /
      data fpppp( 2, 7, 2,1),fpppp( 2, 7, 2,2),fpppp( 2, 7, 2,3)/
     x 1.2571837D-04, 1.1896617D-04, 4.2488947D-07 /
      data fpppp( 2, 7, 3,1),fpppp( 2, 7, 3,2),fpppp( 2, 7, 3,3)/
     x 3.1087979D-03,-3.4006782D-04,-1.0243616D-06 /
      data fpppp( 2, 7, 4,1),fpppp( 2, 7, 4,2),fpppp( 2, 7, 4,3)/
     x 1.2571837D-04, 2.1128699D-04, 7.4420813D-07 /
      data fpppp( 2, 7, 5,1),fpppp( 2, 7, 5,2),fpppp( 2, 7, 5,3)/
     x 4.3795015D-05,-7.9965626D-05,-3.2251149D-07 /
      data fpppp( 2, 7, 6,1),fpppp( 2, 7, 6,2),fpppp( 2, 7, 6,3)/
     x 2.2097810D-04, 2.3937352D-04, 5.2254754D-07 /
      data fpppp( 2, 7, 7,1),fpppp( 2, 7, 7,2),fpppp( 2, 7, 7,3)/
     x 3.1381420D-03,-3.7637079D-04,-8.7533621D-07 /
      data fpppp( 2, 7, 8,1),fpppp( 2, 7, 8,2),fpppp( 2, 7, 8,3)/
     x 1.7239345D-04, 2.2129931D-04, 6.0925143D-07 /
      data fpppp( 2, 7, 9,1),fpppp( 2, 7, 9,2),fpppp( 2, 7, 9,3)/
     x 9.7192770D-06,-7.5792184D-05,-2.7873744D-07 /
      data fpppp( 2, 7,10,1),fpppp( 2, 7,10,2),fpppp( 2, 7,10,3)/
     x 1.7239345D-04, 2.2129931D-04, 6.0925143D-07 /
      data fpppp( 2, 7,11,1),fpppp( 2, 7,11,2),fpppp( 2, 7,11,3)/
     x 3.1381420D-03,-3.7637079D-04,-8.7533621D-07 /
      data fpppp( 2, 7,12,1),fpppp( 2, 7,12,2),fpppp( 2, 7,12,3)/
     x 2.2097810D-04, 2.3937352D-04, 5.2254754D-07 /
      data fpppp( 2, 7,13,1),fpppp( 2, 7,13,2),fpppp( 2, 7,13,3)/
     x 4.3795015D-05,-7.9965626D-05,-3.2251149D-07 /
      data fpppp( 2, 7,14,1),fpppp( 2, 7,14,2),fpppp( 2, 7,14,3)/
     x 1.2571837D-04, 2.1128699D-04, 7.4420813D-07 /
      data fpppp( 2, 7,15,1),fpppp( 2, 7,15,2),fpppp( 2, 7,15,3)/
     x 3.1087979D-03,-3.4006782D-04,-1.0243616D-06 /
      data fpppp( 2, 7,16,1),fpppp( 2, 7,16,2),fpppp( 2, 7,16,3)/
     x 1.2571837D-04, 1.1896617D-04, 4.2488947D-07 /
      data fpppp( 2, 7,17,1),fpppp( 2, 7,17,2),fpppp( 2, 7,17,3)/
     x 4.3795015D-05, 2.8931765D-04, 9.5476316D-07 /
      data fpppp( 2, 8, 1,1),fpppp( 2, 8, 1,2),fpppp( 2, 8, 1,3)/
     x 2.4537951D-05, 4.3826849D-05,-1.0825988D-08 /
      data fpppp( 2, 8, 2,1),fpppp( 2, 8, 2,2),fpppp( 2, 8, 2,3)/
     x 8.2340356D-06, 1.5528446D-05, 3.3723991D-08 /
      data fpppp( 2, 8, 3,1),fpppp( 2, 8, 3,2),fpppp( 2, 8, 3,3)/
     x 3.7604214D-05,-5.7541995D-05, 1.2079224D-07 /
      data fpppp( 2, 8, 4,1),fpppp( 2, 8, 4,2),fpppp( 2, 8, 4,3)/
     x 8.2340356D-06, 2.6089700D-05, 5.9046543D-08 /
      data fpppp( 2, 8, 5,1),fpppp( 2, 8, 5,2),fpppp( 2, 8, 5,3)/
     x 2.4537951D-05, 1.5818346D-06,-1.1211620D-07 /
      data fpppp( 2, 8, 6,1),fpppp( 2, 8, 6,2),fpppp( 2, 8, 6,3)/
     x 6.7043050D-05, 3.1448708D-05,-5.3072827D-08 /
      data fpppp( 2, 8, 7,1),fpppp( 2, 8, 7,2),fpppp( 2, 8, 7,3)/
     x 1.6824081D-04,-5.9133489D-05, 1.3258017D-08 /
      data fpppp( 2, 8, 8,1),fpppp( 2, 8, 8,2),fpppp( 2, 8, 8,3)/
     x 3.7662896D-05, 2.7507494D-05, 4.9526397D-08 /
      data fpppp( 2, 8, 9,1),fpppp( 2, 8, 9,2),fpppp( 2, 8, 9,3)/
     x-1.9547850D-06, 4.3137096D-06,-2.9855681D-08 /
      data fpppp( 2, 8,10,1),fpppp( 2, 8,10,2),fpppp( 2, 8,10,3)/
     x 3.7662896D-05, 2.7507494D-05, 4.9526397D-08 /
      data fpppp( 2, 8,11,1),fpppp( 2, 8,11,2),fpppp( 2, 8,11,3)/
     x 1.6824081D-04,-5.9133489D-05, 1.3258017D-08 /
      data fpppp( 2, 8,12,1),fpppp( 2, 8,12,2),fpppp( 2, 8,12,3)/
     x 6.7043050D-05, 3.1448708D-05,-5.3072827D-08 /
      data fpppp( 2, 8,13,1),fpppp( 2, 8,13,2),fpppp( 2, 8,13,3)/
     x 2.4537951D-05, 1.5818346D-06,-1.1211620D-07 /
      data fpppp( 2, 8,14,1),fpppp( 2, 8,14,2),fpppp( 2, 8,14,3)/
     x 8.2340356D-06, 2.6089700D-05, 5.9046543D-08 /
      data fpppp( 2, 8,15,1),fpppp( 2, 8,15,2),fpppp( 2, 8,15,3)/
     x 3.7604214D-05,-5.7541995D-05, 1.2079224D-07 /
      data fpppp( 2, 8,16,1),fpppp( 2, 8,16,2),fpppp( 2, 8,16,3)/
     x 8.2340356D-06, 1.5528446D-05, 3.3723991D-08 /
      data fpppp( 2, 8,17,1),fpppp( 2, 8,17,2),fpppp( 2, 8,17,3)/
     x 2.4537951D-05, 4.3826849D-05,-1.0825988D-08 /
      data fpppp( 2, 9, 1,1),fpppp( 2, 9, 1,2),fpppp( 2, 9, 1,3)/
     x 1.3896973D-05, 1.4739708D-05,-1.7549985D-07 /
      data fpppp( 2, 9, 2,1),fpppp( 2, 9, 2,2),fpppp( 2, 9, 2,3)/
     x-4.9218820D-06, 5.9375878D-06,-4.5364138D-08 /
      data fpppp( 2, 9, 3,1),fpppp( 2, 9, 3,2),fpppp( 2, 9, 3,3)/
     x 5.3270142D-05,-1.5600248D-05, 2.8286812D-07 /
      data fpppp( 2, 9, 4,1),fpppp( 2, 9, 4,2),fpppp( 2, 9, 4,3)/
     x-4.9218820D-06, 7.4369188D-06,-8.2237529D-08 /
      data fpppp( 2, 9, 5,1),fpppp( 2, 9, 5,2),fpppp( 2, 9, 5,3)/
     x 1.3896973D-05, 8.7423844D-06,-2.8006285D-08 /
      data fpppp( 2, 9, 6,1),fpppp( 2, 9, 6,2),fpppp( 2, 9, 6,3)/
     x 3.8954812D-05,-4.3451713D-06,-9.9162763D-08 /
      data fpppp( 2, 9, 7,1),fpppp( 2, 9, 7,2),fpppp( 2, 9, 7,3)/
     x 9.2406035D-05,-2.2350242D-05, 4.5872819D-08 /
      data fpppp( 2, 9, 8,1),fpppp( 2, 9, 8,2),fpppp( 2, 9, 8,3)/
     x 1.4947599D-05, 1.2187097D-05, 1.1314790D-08 /
      data fpppp( 2, 9, 9,1),fpppp( 2, 9, 9,2),fpppp( 2, 9, 9,3)/
     x 2.4255643D-05, 1.2508163D-05, 1.5424257D-08 /
      data fpppp( 2, 9,10,1),fpppp( 2, 9,10,2),fpppp( 2, 9,10,3)/
     x 1.4947599D-05, 1.2187097D-05, 1.1314790D-08 /
      data fpppp( 2, 9,11,1),fpppp( 2, 9,11,2),fpppp( 2, 9,11,3)/
     x 9.2406035D-05,-2.2350242D-05, 4.5872819D-08 /
      data fpppp( 2, 9,12,1),fpppp( 2, 9,12,2),fpppp( 2, 9,12,3)/
     x 3.8954812D-05,-4.3451713D-06,-9.9162763D-08 /
      data fpppp( 2, 9,13,1),fpppp( 2, 9,13,2),fpppp( 2, 9,13,3)/
     x 1.3896973D-05, 8.7423844D-06,-2.8006285D-08 /
      data fpppp( 2, 9,14,1),fpppp( 2, 9,14,2),fpppp( 2, 9,14,3)/
     x-4.9218820D-06, 7.4369188D-06,-8.2237529D-08 /
      data fpppp( 2, 9,15,1),fpppp( 2, 9,15,2),fpppp( 2, 9,15,3)/
     x 5.3270142D-05,-1.5600248D-05, 2.8286812D-07 /
      data fpppp( 2, 9,16,1),fpppp( 2, 9,16,2),fpppp( 2, 9,16,3)/
     x-4.9218820D-06, 5.9375878D-06,-4.5364138D-08 /
      data fpppp( 2, 9,17,1),fpppp( 2, 9,17,2),fpppp( 2, 9,17,3)/
     x 1.3896973D-05, 1.4739708D-05,-1.7549985D-07 /
      data fpppp( 2,10, 1,1),fpppp( 2,10, 1,2),fpppp( 2,10, 1,3)/
     x 1.6859399D-05, 7.6897272D-06, 5.3388192D-09 /
      data fpppp( 2,10, 2,1),fpppp( 2,10, 2,2),fpppp( 2,10, 2,3)/
     x 4.8399768D-05, 6.3299515D-06, 1.7752362D-08 /
      data fpppp( 2,10, 3,1),fpppp( 2,10, 3,2),fpppp( 2,10, 3,3)/
     x 7.7251748D-05, 3.3746997D-06, 4.7502659D-08 /
      data fpppp( 2,10, 4,1),fpppp( 2,10, 4,2),fpppp( 2,10, 4,3)/
     x 4.8399768D-05, 6.0036142D-06, 1.6574317D-08 /
      data fpppp( 2,10, 5,1),fpppp( 2,10, 5,2),fpppp( 2,10, 5,3)/
     x 1.6859399D-05, 8.9950761D-06, 1.0051000D-08 /
      data fpppp( 2,10, 6,1),fpppp( 2,10, 6,2),fpppp( 2,10, 6,3)/
     x-2.4823262D-05,-2.5169891D-05,-1.1802551D-07 /
      data fpppp( 2,10, 7,1),fpppp( 2,10, 7,2),fpppp( 2,10, 7,3)/
     x-1.9731312D-05,-1.4197908D-05, 4.6818623D-08 /
      data fpppp( 2,10, 8,1),fpppp( 2,10, 8,2),fpppp( 2,10, 8,3)/
     x 3.1141278D-05, 1.7573007D-05, 1.0652183D-08 /
      data fpppp( 2,10, 9,1),fpppp( 2,10, 9,2),fpppp( 2,10, 9,3)/
     x 3.6881064D-05, 1.0163113D-05, 2.0159783D-08 /
      data fpppp( 2,10,10,1),fpppp( 2,10,10,2),fpppp( 2,10,10,3)/
     x 3.1141278D-05, 1.7573007D-05, 1.0652183D-08 /
      data fpppp( 2,10,11,1),fpppp( 2,10,11,2),fpppp( 2,10,11,3)/
     x-1.9731312D-05,-1.4197908D-05, 4.6818623D-08 /
      data fpppp( 2,10,12,1),fpppp( 2,10,12,2),fpppp( 2,10,12,3)/
     x-2.4823262D-05,-2.5169891D-05,-1.1802551D-07 /
      data fpppp( 2,10,13,1),fpppp( 2,10,13,2),fpppp( 2,10,13,3)/
     x 1.6859399D-05, 8.9950761D-06, 1.0051000D-08 /
      data fpppp( 2,10,14,1),fpppp( 2,10,14,2),fpppp( 2,10,14,3)/
     x 4.8399768D-05, 6.0036142D-06, 1.6574317D-08 /
      data fpppp( 2,10,15,1),fpppp( 2,10,15,2),fpppp( 2,10,15,3)/
     x 7.7251748D-05, 3.3746997D-06, 4.7502659D-08 /
      data fpppp( 2,10,16,1),fpppp( 2,10,16,2),fpppp( 2,10,16,3)/
     x 4.8399768D-05, 6.3299515D-06, 1.7752362D-08 /
      data fpppp( 2,10,17,1),fpppp( 2,10,17,2),fpppp( 2,10,17,3)/
     x 1.6859399D-05, 7.6897272D-06, 5.3388192D-09 /
      data fpppp( 2,11, 1,1),fpppp( 2,11, 1,2),fpppp( 2,11, 1,3)/
     x 5.3490776D-06, 8.8274271D-06, 4.3208068D-08 /
      data fpppp( 2,11, 2,1),fpppp( 2,11, 2,2),fpppp( 2,11, 2,3)/
     x 3.9125645D-05, 8.9826011D-06, 2.5401031D-08 /
      data fpppp( 2,11, 3,1),fpppp( 2,11, 3,2),fpppp( 2,11, 3,3)/
     x 5.5739143D-05, 1.0575739D-05,-1.4287616D-08 /
      data fpppp( 2,11, 4,1),fpppp( 2,11, 4,2),fpppp( 2,11, 4,3)/
     x 3.9125645D-05, 7.1360041D-06, 2.2609372D-08 /
      data fpppp( 2,11, 5,1),fpppp( 2,11, 5,2),fpppp( 2,11, 5,3)/
     x 5.3490776D-06, 1.6213815D-05, 5.4374706D-08 /
      data fpppp( 2,11, 6,1),fpppp( 2,11, 6,2),fpppp( 2,11, 6,3)/
     x 1.9818365D-04,-5.5059944D-05,-1.5773397D-07 /
      data fpppp( 2,11, 7,1),fpppp( 2,11, 7,2),fpppp( 2,11, 7,3)/
     x 1.0004493D-05, 4.8583921D-06, 7.8715443D-08 /
      data fpppp( 2,11, 8,1),fpppp( 2,11, 8,2),fpppp( 2,11, 8,3)/
     x 2.5895739D-05, 1.6884311D-05,-2.4157381D-09 /
      data fpppp( 2,11, 9,1),fpppp( 2,11, 9,2),fpppp( 2,11, 9,3)/
     x 2.6101038D-05, 9.0513396D-06, 2.2722717D-08 /
      data fpppp( 2,11,10,1),fpppp( 2,11,10,2),fpppp( 2,11,10,3)/
     x 2.5895739D-05, 1.6884311D-05,-2.4157381D-09 /
      data fpppp( 2,11,11,1),fpppp( 2,11,11,2),fpppp( 2,11,11,3)/
     x 1.0004493D-05, 4.8583921D-06, 7.8715443D-08 /
      data fpppp( 2,11,12,1),fpppp( 2,11,12,2),fpppp( 2,11,12,3)/
     x 1.9818365D-04,-5.5059944D-05,-1.5773397D-07 /
      data fpppp( 2,11,13,1),fpppp( 2,11,13,2),fpppp( 2,11,13,3)/
     x 5.3490776D-06, 1.6213815D-05, 5.4374706D-08 /
      data fpppp( 2,11,14,1),fpppp( 2,11,14,2),fpppp( 2,11,14,3)/
     x 3.9125645D-05, 7.1360041D-06, 2.2609372D-08 /
      data fpppp( 2,11,15,1),fpppp( 2,11,15,2),fpppp( 2,11,15,3)/
     x 5.5739143D-05, 1.0575739D-05,-1.4287616D-08 /
      data fpppp( 2,11,16,1),fpppp( 2,11,16,2),fpppp( 2,11,16,3)/
     x 3.9125645D-05, 8.9826011D-06, 2.5401031D-08 /
      data fpppp( 2,11,17,1),fpppp( 2,11,17,2),fpppp( 2,11,17,3)/
     x 5.3490776D-06, 8.8274271D-06, 4.3208068D-08 /
      data fpppp( 2,12, 1,1),fpppp( 2,12, 1,2),fpppp( 2,12, 1,3)/
     x 5.9323429D-05, 1.2580739D-05, 3.6612732D-08 /
      data fpppp( 2,12, 2,1),fpppp( 2,12, 2,2),fpppp( 2,12, 2,3)/
     x 1.9139568D-05, 1.1507697D-05, 1.8882531D-08 /
      data fpppp( 2,12, 3,1),fpppp( 2,12, 3,2),fpppp( 2,12, 3,3)/
     x 2.4712722D-05, 1.2828752D-05,-1.5092090D-08 /
      data fpppp( 2,12, 4,1),fpppp( 2,12, 4,2),fpppp( 2,12, 4,3)/
     x 1.9139568D-05, 5.7704677D-06, 7.7887598D-09 /
      data fpppp( 2,12, 5,1),fpppp( 2,12, 5,2),fpppp( 2,12, 5,3)/
     x 5.9323429D-05, 3.5529657D-05, 8.0987817D-08 /
      data fpppp( 2,12, 6,1),fpppp( 2,12, 6,2),fpppp( 2,12, 6,3)/
     x-5.3689081D-04,-1.0196224D-04,-1.9582972D-07 /
      data fpppp( 2,12, 7,1),fpppp( 2,12, 7,2),fpppp( 2,12, 7,3)/
     x-1.1203803D-05, 4.0380014D-05, 1.2534644D-07 /
      data fpppp( 2,12, 8,1),fpppp( 2,12, 8,2),fpppp( 2,12, 8,3)/
     x 1.4092950D-05, 7.5323470D-06,-2.4625471D-08 /
      data fpppp( 2,12, 9,1),fpppp( 2,12, 9,2),fpppp( 2,12, 9,3)/
     x 1.7551518D-05, 1.1714558D-05, 2.5907468D-08 /
      data fpppp( 2,12,10,1),fpppp( 2,12,10,2),fpppp( 2,12,10,3)/
     x 1.4092950D-05, 7.5323470D-06,-2.4625471D-08 /
      data fpppp( 2,12,11,1),fpppp( 2,12,11,2),fpppp( 2,12,11,3)/
     x-1.1203803D-05, 4.0380014D-05, 1.2534644D-07 /
      data fpppp( 2,12,12,1),fpppp( 2,12,12,2),fpppp( 2,12,12,3)/
     x-5.3689081D-04,-1.0196224D-04,-1.9582972D-07 /
      data fpppp( 2,12,13,1),fpppp( 2,12,13,2),fpppp( 2,12,13,3)/
     x 5.9323429D-05, 3.5529657D-05, 8.0987817D-08 /
      data fpppp( 2,12,14,1),fpppp( 2,12,14,2),fpppp( 2,12,14,3)/
     x 1.9139568D-05, 5.7704677D-06, 7.7887598D-09 /
      data fpppp( 2,12,15,1),fpppp( 2,12,15,2),fpppp( 2,12,15,3)/
     x 2.4712722D-05, 1.2828752D-05,-1.5092090D-08 /
      data fpppp( 2,12,16,1),fpppp( 2,12,16,2),fpppp( 2,12,16,3)/
     x 1.9139568D-05, 1.1507697D-05, 1.8882531D-08 /
      data fpppp( 2,12,17,1),fpppp( 2,12,17,2),fpppp( 2,12,17,3)/
     x 5.9323429D-05, 1.2580739D-05, 3.6612732D-08 /
      data fpppp( 2,13, 1,1),fpppp( 2,13, 1,2),fpppp( 2,13, 1,3)/
     x-1.3351944D-05, 2.4669646D-05, 4.6747446D-08 /
      data fpppp( 2,13, 2,1),fpppp( 2,13, 2,2),fpppp( 2,13, 2,3)/
     x-9.7307617D-06, 1.7491235D-05, 2.4029296D-08 /
      data fpppp( 2,13, 3,1),fpppp( 2,13, 3,2),fpppp( 2,13, 3,3)/
     x 3.6199616D-06, 1.2422908D-05,-2.1192270D-08 /
      data fpppp( 2,13, 4,1),fpppp( 2,13, 4,2),fpppp( 2,13, 4,3)/
     x-9.7307617D-06,-3.0715722D-08, 1.2348116D-08 /
      data fpppp( 2,13, 5,1),fpppp( 2,13, 5,2),fpppp( 2,13, 5,3)/
     x-1.3351944D-05, 9.4757447D-05, 9.3472163D-08 /
      data fpppp( 2,13, 6,1),fpppp( 2,13, 6,2),fpppp( 2,13, 6,3)/
     x 2.9874027D-03,-2.2792173D-04,-2.6813222D-07 /
      data fpppp( 2,13, 7,1),fpppp( 2,13, 7,2),fpppp( 2,13, 7,3)/
     x-5.1789024D-05, 1.3740121D-04, 2.2948091D-07 /
      data fpppp( 2,13, 8,1),fpppp( 2,13, 8,2),fpppp( 2,13, 8,3)/
     x 8.6328269D-06,-2.4080383D-05,-7.5945844D-08 /
      data fpppp( 2,13, 9,1),fpppp( 2,13, 9,2),fpppp( 2,13, 9,3)/
     x 1.4447993D-05, 2.4405119D-05, 3.6799143D-08 /
      data fpppp( 2,13,10,1),fpppp( 2,13,10,2),fpppp( 2,13,10,3)/
     x 8.6328269D-06,-2.4080383D-05,-7.5945844D-08 /
      data fpppp( 2,13,11,1),fpppp( 2,13,11,2),fpppp( 2,13,11,3)/
     x-5.1789024D-05, 1.3740121D-04, 2.2948091D-07 /
      data fpppp( 2,13,12,1),fpppp( 2,13,12,2),fpppp( 2,13,12,3)/
     x 2.9874027D-03,-2.2792173D-04,-2.6813222D-07 /
      data fpppp( 2,13,13,1),fpppp( 2,13,13,2),fpppp( 2,13,13,3)/
     x-1.3351944D-05, 9.4757447D-05, 9.3472163D-08 /
      data fpppp( 2,13,14,1),fpppp( 2,13,14,2),fpppp( 2,13,14,3)/
     x-9.7307617D-06,-3.0715722D-08, 1.2348116D-08 /
      data fpppp( 2,13,15,1),fpppp( 2,13,15,2),fpppp( 2,13,15,3)/
     x 3.6199616D-06, 1.2422908D-05,-2.1192270D-08 /
      data fpppp( 2,13,16,1),fpppp( 2,13,16,2),fpppp( 2,13,16,3)/
     x-9.7307617D-06, 1.7491235D-05, 2.4029296D-08 /
      data fpppp( 2,13,17,1),fpppp( 2,13,17,2),fpppp( 2,13,17,3)/
     x-1.3351944D-05, 2.4669646D-05, 4.6747446D-08 /
      data fpppp( 2,14, 1,1),fpppp( 2,14, 1,2),fpppp( 2,14, 1,3)/
     x 1.6621379D-03, 9.7755426D-05, 1.8689213D-07 /
      data fpppp( 2,14, 2,1),fpppp( 2,14, 2,2),fpppp( 2,14, 2,3)/
     x 6.1605314D-05, 5.8175324D-05, 1.0693766D-07 /
      data fpppp( 2,14, 3,1),fpppp( 2,14, 3,2),fpppp( 2,14, 3,3)/
     x 3.9333016D-05,-3.0114133D-06,-8.8342972D-08 /
      data fpppp( 2,14, 4,1),fpppp( 2,14, 4,2),fpppp( 2,14, 4,3)/
     x 6.1605314D-05, 1.1425073D-05, 1.2001796D-07 /
      data fpppp( 2,14, 5,1),fpppp( 2,14, 5,2),fpppp( 2,14, 5,3)/
     x 1.6621379D-03, 2.8475643D-04, 1.3457093D-07 /
      data fpppp( 2,14, 6,1),fpppp( 2,14, 6,2),fpppp( 2,14, 6,3)/
     x-6.3073227D-03,-6.9298828D-04,-6.4231020D-07 /
      data fpppp( 2,14, 7,1),fpppp( 2,14, 7,2),fpppp( 2,14, 7,3)/
     x 4.6608899D-05, 4.9180253D-04, 6.1083766D-07 /
      data fpppp( 2,14, 8,1),fpppp( 2,14, 8,2),fpppp( 2,14, 8,3)/
     x 4.6854507D-06,-1.3475000D-04,-2.1895337D-07 /
      data fpppp( 2,14, 9,1),fpppp( 2,14, 9,2),fpppp( 2,14, 9,3)/
     x 1.2092837D-05, 7.4728200D-05, 8.2197067D-08 /
      data fpppp( 2,14,10,1),fpppp( 2,14,10,2),fpppp( 2,14,10,3)/
     x 4.6854507D-06,-1.3475000D-04,-2.1895337D-07 /
      data fpppp( 2,14,11,1),fpppp( 2,14,11,2),fpppp( 2,14,11,3)/
     x 4.6608899D-05, 4.9180253D-04, 6.1083766D-07 /
      data fpppp( 2,14,12,1),fpppp( 2,14,12,2),fpppp( 2,14,12,3)/
     x-6.3073227D-03,-6.9298828D-04,-6.4231020D-07 /
      data fpppp( 2,14,13,1),fpppp( 2,14,13,2),fpppp( 2,14,13,3)/
     x 1.6621379D-03, 2.8475643D-04, 1.3457093D-07 /
      data fpppp( 2,14,14,1),fpppp( 2,14,14,2),fpppp( 2,14,14,3)/
     x 6.1605314D-05, 1.1425073D-05, 1.2001796D-07 /
      data fpppp( 2,14,15,1),fpppp( 2,14,15,2),fpppp( 2,14,15,3)/
     x 3.9333016D-05,-3.0114133D-06,-8.8342972D-08 /
      data fpppp( 2,14,16,1),fpppp( 2,14,16,2),fpppp( 2,14,16,3)/
     x 6.1605314D-05, 5.8175324D-05, 1.0693766D-07 /
      data fpppp( 2,14,17,1),fpppp( 2,14,17,2),fpppp( 2,14,17,3)/
     x 1.6621379D-03, 9.7755426D-05, 1.8689213D-07 /
      data fpppp( 2,15, 1,1),fpppp( 2,15, 1,2),fpppp( 2,15, 1,3)/
     x-1.5860775D-03, 3.3761904D-04,-4.9844636D-07 /
      data fpppp( 2,15, 2,1),fpppp( 2,15, 2,2),fpppp( 2,15, 2,3)/
     x-2.5454189D-04, 2.3498193D-04,-3.1233249D-07 /
      data fpppp( 2,15, 3,1),fpppp( 2,15, 3,2),fpppp( 2,15, 3,3)/
     x-1.7571961D-04,-1.6637394D-04, 2.3864763D-08 /
      data fpppp( 2,15, 4,1),fpppp( 2,15, 4,2),fpppp( 2,15, 4,3)/
     x-2.5454189D-04, 4.7778586D-04,-1.6522983D-07 /
      data fpppp( 2,15, 5,1),fpppp( 2,15, 5,2),fpppp( 2,15, 5,3)/
     x-1.5860775D-03,-6.3359667D-04,-1.0868570D-06 /
      data fpppp( 2,15, 6,1),fpppp( 2,15, 6,2),fpppp( 2,15, 6,3)/
     x 8.8452510D-03, 2.0792267D-04, 2.8274673D-06 /
      data fpppp( 2,15, 7,1),fpppp( 2,15, 7,2),fpppp( 2,15, 7,3)/
     x 1.4678995D-04, 5.9960646D-05,-1.8539877D-06 /
      data fpppp( 2,15, 8,1),fpppp( 2,15, 8,2),fpppp( 2,15, 8,3)/
     x 2.4468929D-05,-1.1720562D-05, 4.1764964D-07 /
      data fpppp( 2,15, 9,1),fpppp( 2,15, 9,2),fpppp( 2,15, 9,3)/
     x 2.6183162D-05, 6.1373674D-06,-2.7743258D-07 /
      data fpppp( 2,15,10,1),fpppp( 2,15,10,2),fpppp( 2,15,10,3)/
     x 2.4468929D-05,-1.1720562D-05, 4.1764964D-07 /
      data fpppp( 2,15,11,1),fpppp( 2,15,11,2),fpppp( 2,15,11,3)/
     x 1.4678995D-04, 5.9960646D-05,-1.8539877D-06 /
      data fpppp( 2,15,12,1),fpppp( 2,15,12,2),fpppp( 2,15,12,3)/
     x 8.8452510D-03, 2.0792267D-04, 2.8274673D-06 /
      data fpppp( 2,15,13,1),fpppp( 2,15,13,2),fpppp( 2,15,13,3)/
     x-1.5860775D-03,-6.3359667D-04,-1.0868570D-06 /
      data fpppp( 2,15,14,1),fpppp( 2,15,14,2),fpppp( 2,15,14,3)/
     x-2.5454189D-04, 4.7778586D-04,-1.6522983D-07 /
      data fpppp( 2,15,15,1),fpppp( 2,15,15,2),fpppp( 2,15,15,3)/
     x-1.7571961D-04,-1.6637394D-04, 2.3864763D-08 /
      data fpppp( 2,15,16,1),fpppp( 2,15,16,2),fpppp( 2,15,16,3)/
     x-2.5454189D-04, 2.3498193D-04,-3.1233249D-07 /
      data fpppp( 2,15,17,1),fpppp( 2,15,17,2),fpppp( 2,15,17,3)/
     x-1.5860775D-03, 3.3761904D-04,-4.9844636D-07 /
      data fpppp( 2,16, 1,1),fpppp( 2,16, 1,2),fpppp( 2,16, 1,3)/
     x-3.6365160D-03, 3.3498745D-04,-2.3111998D-07 /
      data fpppp( 2,16, 2,1),fpppp( 2,16, 2,2),fpppp( 2,16, 2,3)/
     x 4.4504261D-04, 2.1221136D-04,-2.0262115D-07 /
      data fpppp( 2,16, 3,1),fpppp( 2,16, 3,2),fpppp( 2,16, 3,3)/
     x 3.8193625D-04,-1.3085013D-04,-4.5849026D-08 /
      data fpppp( 2,16, 4,1),fpppp( 2,16, 4,2),fpppp( 2,16, 4,3)/
     x 4.4504261D-04, 2.9708728D-04,-3.3803342D-07 /
      data fpppp( 2,16, 5,1),fpppp( 2,16, 5,2),fpppp( 2,16, 5,3)/
     x-3.6365160D-03,-4.5162310D-06, 3.1052909D-07 /
      data fpppp( 2,16, 6,1),fpppp( 2,16, 6,2),fpppp( 2,16, 6,3)/
     x-1.1728085D-02,-7.1479082D-04, 3.1268750D-07 /
      data fpppp( 2,16, 7,1),fpppp( 2,16, 7,2),fpppp( 2,16, 7,3)/
     x-3.9149317D-04, 6.2322687D-04,-1.2282558D-07 /
      data fpppp( 2,16, 8,1),fpppp( 2,16, 8,2),fpppp( 2,16, 8,3)/
     x-5.2577649D-05,-1.6649594D-04,-1.2413700D-07 /
      data fpppp( 2,16, 9,1),fpppp( 2,16, 9,2),fpppp( 2,16, 9,3)/
     x-5.8289153D-05, 7.5973787D-05,-5.3160863D-08 /
      data fpppp( 2,16,10,1),fpppp( 2,16,10,2),fpppp( 2,16,10,3)/
     x-5.2577649D-05,-1.6649594D-04,-1.2413700D-07 /
      data fpppp( 2,16,11,1),fpppp( 2,16,11,2),fpppp( 2,16,11,3)/
     x-3.9149317D-04, 6.2322687D-04,-1.2282558D-07 /
      data fpppp( 2,16,12,1),fpppp( 2,16,12,2),fpppp( 2,16,12,3)/
     x-1.1728085D-02,-7.1479082D-04, 3.1268750D-07 /
      data fpppp( 2,16,13,1),fpppp( 2,16,13,2),fpppp( 2,16,13,3)/
     x-3.6365160D-03,-4.5162310D-06, 3.1052909D-07 /
      data fpppp( 2,16,14,1),fpppp( 2,16,14,2),fpppp( 2,16,14,3)/
     x 4.4504261D-04, 2.9708728D-04,-3.3803342D-07 /
      data fpppp( 2,16,15,1),fpppp( 2,16,15,2),fpppp( 2,16,15,3)/
     x 3.8193625D-04,-1.3085013D-04,-4.5849026D-08 /
      data fpppp( 2,16,16,1),fpppp( 2,16,16,2),fpppp( 2,16,16,3)/
     x 4.4504261D-04, 2.1221136D-04,-2.0262115D-07 /
      data fpppp( 2,16,17,1),fpppp( 2,16,17,2),fpppp( 2,16,17,3)/
     x-3.6365160D-03, 3.3498745D-04,-2.3111998D-07 /
      data fpppp( 2,17, 1,1),fpppp( 2,17, 1,2),fpppp( 2,17, 1,3)/
     x-3.0156697D-03,-1.8154174D-04, 9.8666312D-08 /
      data fpppp( 2,17, 2,1),fpppp( 2,17, 2,2),fpppp( 2,17, 2,3)/
     x-3.9893879D-03,-1.4840710D-04, 2.2517035D-08 /
      data fpppp( 2,17, 3,1),fpppp( 2,17, 3,2),fpppp( 2,17, 3,3)/
     x-2.7407256D-03, 3.5630314D-05,-1.1672848D-07 /
      data fpppp( 2,17, 4,1),fpppp( 2,17, 4,2),fpppp( 2,17, 4,3)/
     x-3.9893879D-03,-3.0849197D-04,-3.5137159D-08 /
      data fpppp( 2,17, 5,1),fpppp( 2,17, 5,2),fpppp( 2,17, 5,3)/
     x-3.0156697D-03, 4.5879775D-04, 3.2928309D-07 /
      data fpppp( 2,17, 6,1),fpppp( 2,17, 6,2),fpppp( 2,17, 6,3)/
     x 6.3573595D-03,-9.1543062D-05,-6.7708647D-07 /
      data fpppp( 2,17, 7,1),fpppp( 2,17, 7,2),fpppp( 2,17, 7,3)/
     x-1.1344143D-04,-8.2804804D-05, 6.4490402D-07 /
      data fpppp( 2,17, 8,1),fpppp( 2,17, 8,2),fpppp( 2,17, 8,3)/
     x-4.2134762D-05, 1.9080836D-06,-1.9036849D-07 /
      data fpppp( 2,17, 9,1),fpppp( 2,17, 9,2),fpppp( 2,17, 9,3)/
     x 1.9742234D-05,-1.8043118D-05,-3.6070543D-08 /
      data fpppp( 2,17,10,1),fpppp( 2,17,10,2),fpppp( 2,17,10,3)/
     x-4.2134762D-05, 1.9080836D-06,-1.9036849D-07 /
      data fpppp( 2,17,11,1),fpppp( 2,17,11,2),fpppp( 2,17,11,3)/
     x-1.1344143D-04,-8.2804804D-05, 6.4490402D-07 /
      data fpppp( 2,17,12,1),fpppp( 2,17,12,2),fpppp( 2,17,12,3)/
     x 6.3573595D-03,-9.1543062D-05,-6.7708647D-07 /
      data fpppp( 2,17,13,1),fpppp( 2,17,13,2),fpppp( 2,17,13,3)/
     x-3.0156697D-03, 4.5879775D-04, 3.2928309D-07 /
      data fpppp( 2,17,14,1),fpppp( 2,17,14,2),fpppp( 2,17,14,3)/
     x-3.9893879D-03,-3.0849197D-04,-3.5137159D-08 /
      data fpppp( 2,17,15,1),fpppp( 2,17,15,2),fpppp( 2,17,15,3)/
     x-2.7407256D-03, 3.5630314D-05,-1.1672848D-07 /
      data fpppp( 2,17,16,1),fpppp( 2,17,16,2),fpppp( 2,17,16,3)/
     x-3.9893879D-03,-1.4840710D-04, 2.2517035D-08 /
      data fpppp( 2,17,17,1),fpppp( 2,17,17,2),fpppp( 2,17,17,3)/
     x-3.0156697D-03,-1.8154174D-04, 9.8666312D-08 /
      data fpppp( 2,18, 1,1),fpppp( 2,18, 1,2),fpppp( 2,18, 1,3)/
     x 9.6218912D-03,-2.9927619D-04, 3.1027748D-07 /
      data fpppp( 2,18, 2,1),fpppp( 2,18, 2,2),fpppp( 2,18, 2,3)/
     x 4.2177291D-03,-3.1943954D-04, 1.8952085D-07 /
      data fpppp( 2,18, 3,1),fpppp( 2,18, 3,2),fpppp( 2,18, 3,3)/
     x 2.3106412D-03,-3.9257905D-05,-3.4371143D-08 /
      data fpppp( 2,18, 4,1),fpppp( 2,18, 4,2),fpppp( 2,18, 4,3)/
     x 4.2177291D-03,-8.1028372D-04, 1.0271060D-07 /
      data fpppp( 2,18, 5,1),fpppp( 2,18, 5,2),fpppp( 2,18, 5,3)/
     x 9.6218912D-03, 1.6641005D-03, 6.5751848D-07 /
      data fpppp( 2,18, 6,1),fpppp( 2,18, 6,2),fpppp( 2,18, 6,3)/
     x 5.4476008D-04,-8.6160014D-04,-9.0178985D-07 /
      data fpppp( 2,18, 7,1),fpppp( 2,18, 7,2),fpppp( 2,18, 7,3)/
     x-5.0757986D-04, 5.1019917D-05, 1.9470248D-07 /
      data fpppp( 2,18, 8,1),fpppp( 2,18, 8,2),fpppp( 2,18, 8,3)/
     x-1.1515620D-03,-6.4796254D-05,-4.2632761D-08 /
      data fpppp( 2,18, 9,1),fpppp( 2,18, 9,2),fpppp( 2,18, 9,3)/
     x-1.3047224D-03, 5.6992805D-07,-1.1151092D-09 /
      data fpppp( 2,18,10,1),fpppp( 2,18,10,2),fpppp( 2,18,10,3)/
     x-1.1515620D-03,-6.4796254D-05,-4.2632761D-08 /
      data fpppp( 2,18,11,1),fpppp( 2,18,11,2),fpppp( 2,18,11,3)/
     x-5.0757986D-04, 5.1019917D-05, 1.9470248D-07 /
      data fpppp( 2,18,12,1),fpppp( 2,18,12,2),fpppp( 2,18,12,3)/
     x 5.4476008D-04,-8.6160014D-04,-9.0178985D-07 /
      data fpppp( 2,18,13,1),fpppp( 2,18,13,2),fpppp( 2,18,13,3)/
     x 9.6218912D-03, 1.6641005D-03, 6.5751848D-07 /
      data fpppp( 2,18,14,1),fpppp( 2,18,14,2),fpppp( 2,18,14,3)/
     x 4.2177291D-03,-8.1028372D-04, 1.0271060D-07 /
      data fpppp( 2,18,15,1),fpppp( 2,18,15,2),fpppp( 2,18,15,3)/
     x 2.3106412D-03,-3.9257905D-05,-3.4371143D-08 /
      data fpppp( 2,18,16,1),fpppp( 2,18,16,2),fpppp( 2,18,16,3)/
     x 4.2177291D-03,-3.1943954D-04, 1.8952085D-07 /
      data fpppp( 2,18,17,1),fpppp( 2,18,17,2),fpppp( 2,18,17,3)/
     x 9.6218912D-03,-2.9927619D-04, 3.1027748D-07 /
      data fpppp( 2,19, 1,1),fpppp( 2,19, 1,2),fpppp( 2,19, 1,3)/
     x 1.8826105D-02, 1.1891987D-18, 5.5565298D-07 /
      data fpppp( 2,19, 2,1),fpppp( 2,19, 2,2),fpppp( 2,19, 2,3)/
     x 8.8129754D-03,-1.7940203D-18, 3.7313448D-07 /
      data fpppp( 2,19, 3,1),fpppp( 2,19, 3,2),fpppp( 2,19, 3,3)/
     x 5.0265712D-03,-1.9968759D-18, 4.2042545D-09 /
      data fpppp( 2,19, 4,1),fpppp( 2,19, 4,2),fpppp( 2,19, 4,3)/
     x 8.8129754D-03, 8.6760037D-19, 2.8771507D-07 /
      data fpppp( 2,19, 5,1),fpppp( 2,19, 5,2),fpppp( 2,19, 5,3)/
     x 1.8826105D-02, 2.6106749D-19, 8.9733061D-07 /
      data fpppp( 2,19, 6,1),fpppp( 2,19, 6,2),fpppp( 2,19, 6,3)/
     x 1.5601733D-03,-6.6285087D-19,-1.3450848D-06 /
      data fpppp( 2,19, 7,1),fpppp( 2,19, 7,2),fpppp( 2,19, 7,3)/
     x-7.0966395D-04,-6.3096345D-19, 9.2481259D-08 /
      data fpppp( 2,19, 8,1),fpppp( 2,19, 8,2),fpppp( 2,19, 8,3)/
     x-1.9410264D-03,-5.1647065D-19, 4.3969476D-08 /
      data fpppp( 2,19, 9,1),fpppp( 2,19, 9,2),fpppp( 2,19, 9,3)/
     x-2.2284738D-03, 1.2789051D-19, 2.8736007D-08 /
      data fpppp( 2,19,10,1),fpppp( 2,19,10,2),fpppp( 2,19,10,3)/
     x-1.9410264D-03, 1.2662804D-18, 4.3969476D-08 /
      data fpppp( 2,19,11,1),fpppp( 2,19,11,2),fpppp( 2,19,11,3)/
     x-7.0966395D-04,-1.8335098D-19, 9.2481259D-08 /
      data fpppp( 2,19,12,1),fpppp( 2,19,12,2),fpppp( 2,19,12,3)/
     x 1.5601733D-03, 9.8512696D-20,-1.3450848D-06 /
      data fpppp( 2,19,13,1),fpppp( 2,19,13,2),fpppp( 2,19,13,3)/
     x 1.8826105D-02, 6.5992783D-19, 8.9733061D-07 /
      data fpppp( 2,19,14,1),fpppp( 2,19,14,2),fpppp( 2,19,14,3)/
     x 8.8129754D-03,-6.9453113D-20, 2.8771507D-07 /
      data fpppp( 2,19,15,1),fpppp( 2,19,15,2),fpppp( 2,19,15,3)/
     x 5.0265712D-03, 9.9859148D-19, 4.2042545D-09 /
      data fpppp( 2,19,16,1),fpppp( 2,19,16,2),fpppp( 2,19,16,3)/
     x 8.8129754D-03,-4.9306510D-19, 3.7313448D-07 /
      data fpppp( 2,19,17,1),fpppp( 2,19,17,2),fpppp( 2,19,17,3)/
     x 1.8826105D-02, 2.7624373D-18, 5.5565298D-07 /
      data fpppp( 3, 1, 1,1),fpppp( 3, 1, 1,2),fpppp( 3, 1, 1,3)/
     x 6.8307625D-06, 5.4106296D-19,-7.5229868D-08 /
      data fpppp( 3, 1, 2,1),fpppp( 3, 1, 2,2),fpppp( 3, 1, 2,3)/
     x-1.6953702D-04, 2.3021162D-18, 8.0549537D-09 /
      data fpppp( 3, 1, 3,1),fpppp( 3, 1, 3,2),fpppp( 3, 1, 3,3)/
     x-6.0994227D-04, 2.8523346D-19, 2.0886697D-07 /
      data fpppp( 3, 1, 4,1),fpppp( 3, 1, 4,2),fpppp( 3, 1, 4,3)/
     x-1.6953702D-04, 1.4876201D-18,-1.6661896D-09 /
      data fpppp( 3, 1, 5,1),fpppp( 3, 1, 5,2),fpppp( 3, 1, 5,3)/
     x 6.8307625D-06,-3.2132896D-19,-3.6345295D-08 /
      data fpppp( 3, 1, 6,1),fpppp( 3, 1, 6,2),fpppp( 3, 1, 6,3)/
     x 8.4079063D-05, 2.3424772D-19,-1.7496786D-07 /
      data fpppp( 3, 1, 7,1),fpppp( 3, 1, 7,2),fpppp( 3, 1, 7,3)/
     x-4.5881791D-04, 9.1932465D-19, 7.0427657D-08 /
      data fpppp( 3, 1, 8,1),fpppp( 3, 1, 8,2),fpppp( 3, 1, 8,3)/
     x-2.0140950D-04, 8.4558540D-19, 2.4875247D-10 /
      data fpppp( 3, 1, 9,1),fpppp( 3, 1, 9,2),fpppp( 3, 1, 9,3)/
     x-1.8954498D-04, 4.9504765D-19, 7.4118712D-08 /
      data fpppp( 3, 1,10,1),fpppp( 3, 1,10,2),fpppp( 3, 1,10,3)/
     x-2.0140950D-04, 1.1299521D-18, 2.4875247D-10 /
      data fpppp( 3, 1,11,1),fpppp( 3, 1,11,2),fpppp( 3, 1,11,3)/
     x-4.5881791D-04,-9.2522080D-19, 7.0427657D-08 /
      data fpppp( 3, 1,12,1),fpppp( 3, 1,12,2),fpppp( 3, 1,12,3)/
     x 8.4079063D-05, 6.6931635D-19,-1.7496786D-07 /
      data fpppp( 3, 1,13,1),fpppp( 3, 1,13,2),fpppp( 3, 1,13,3)/
     x 6.8307625D-06, 2.8435784D-19,-3.6345295D-08 /
      data fpppp( 3, 1,14,1),fpppp( 3, 1,14,2),fpppp( 3, 1,14,3)/
     x-1.6953702D-04, 2.6883817D-18,-1.6661896D-09 /
      data fpppp( 3, 1,15,1),fpppp( 3, 1,15,2),fpppp( 3, 1,15,3)/
     x-6.0994227D-04,-7.5054581D-19, 2.0886697D-07 /
      data fpppp( 3, 1,16,1),fpppp( 3, 1,16,2),fpppp( 3, 1,16,3)/
     x-1.6953702D-04, 2.4233858D-18, 8.0549537D-09 /
      data fpppp( 3, 1,17,1),fpppp( 3, 1,17,2),fpppp( 3, 1,17,3)/
     x 6.8307625D-06,-8.7956770D-19,-7.5229868D-08 /
      data fpppp( 3, 2, 1,1),fpppp( 3, 2, 1,2),fpppp( 3, 2, 1,3)/
     x-4.7982957D-06, 3.2882480D-06, 2.9552803D-09 /
      data fpppp( 3, 2, 2,1),fpppp( 3, 2, 2,2),fpppp( 3, 2, 2,3)/
     x-2.6233620D-05, 4.8821261D-06, 1.7390116D-08 /
      data fpppp( 3, 2, 3,1),fpppp( 3, 2, 3,2),fpppp( 3, 2, 3,3)/
     x 5.4339383D-05, 7.7819830D-06, 4.4370430D-08 /
      data fpppp( 3, 2, 4,1),fpppp( 3, 2, 4,2),fpppp( 3, 2, 4,3)/
     x-2.6233620D-05, 6.1109143D-06, 2.7441568D-08 /
      data fpppp( 3, 2, 5,1),fpppp( 3, 2, 5,2),fpppp( 3, 2, 5,3)/
     x-4.7982957D-06,-1.6269049D-06,-3.7250528D-08 /
      data fpppp( 3, 2, 6,1),fpppp( 3, 2, 6,2),fpppp( 3, 2, 6,3)/
     x 2.5190792D-05,-8.4451529D-06,-2.6742331D-08 /
      data fpppp( 3, 2, 7,1),fpppp( 3, 2, 7,2),fpppp( 3, 2, 7,3)/
     x 5.3542784D-05,-4.3454844D-06,-2.5615327D-08 /
      data fpppp( 3, 2, 8,1),fpppp( 3, 2, 8,2),fpppp( 3, 2, 8,3)/
     x-7.5807851D-05, 2.3734870D-06, 3.2040594D-08 /
      data fpppp( 3, 2, 9,1),fpppp( 3, 2, 9,2),fpppp( 3, 2, 9,3)/
     x-9.1818994D-05, 4.2890967D-06, 1.7556859D-08 /
      data fpppp( 3, 2,10,1),fpppp( 3, 2,10,2),fpppp( 3, 2,10,3)/
     x-7.5807851D-05, 2.3734870D-06, 3.2040594D-08 /
      data fpppp( 3, 2,11,1),fpppp( 3, 2,11,2),fpppp( 3, 2,11,3)/
     x 5.3542784D-05,-4.3454844D-06,-2.5615327D-08 /
      data fpppp( 3, 2,12,1),fpppp( 3, 2,12,2),fpppp( 3, 2,12,3)/
     x 2.5190792D-05,-8.4451529D-06,-2.6742331D-08 /
      data fpppp( 3, 2,13,1),fpppp( 3, 2,13,2),fpppp( 3, 2,13,3)/
     x-4.7982957D-06,-1.6269049D-06,-3.7250528D-08 /
      data fpppp( 3, 2,14,1),fpppp( 3, 2,14,2),fpppp( 3, 2,14,3)/
     x-2.6233620D-05, 6.1109143D-06, 2.7441568D-08 /
      data fpppp( 3, 2,15,1),fpppp( 3, 2,15,2),fpppp( 3, 2,15,3)/
     x 5.4339383D-05, 7.7819830D-06, 4.4370430D-08 /
      data fpppp( 3, 2,16,1),fpppp( 3, 2,16,2),fpppp( 3, 2,16,3)/
     x-2.6233620D-05, 4.8821261D-06, 1.7390116D-08 /
      data fpppp( 3, 2,17,1),fpppp( 3, 2,17,2),fpppp( 3, 2,17,3)/
     x-4.7982957D-06, 3.2882480D-06, 2.9552803D-09 /
      data fpppp( 3, 3, 1,1),fpppp( 3, 3, 1,2),fpppp( 3, 3, 1,3)/
     x 7.5402871D-06, 3.2493253D-05, 1.2262458D-08 /
      data fpppp( 3, 3, 2,1),fpppp( 3, 3, 2,2),fpppp( 3, 3, 2,3)/
     x 2.3683007D-04, 2.1038444D-05,-4.6295040D-09 /
      data fpppp( 3, 3, 3,1),fpppp( 3, 3, 3,2),fpppp( 3, 3, 3,3)/
     x 7.1535661D-04,-1.1757049D-05,-4.9066047D-08 /
      data fpppp( 3, 3, 4,1),fpppp( 3, 3, 4,2),fpppp( 3, 3, 4,3)/
     x 2.3683007D-04, 3.0139853D-05, 2.9034453D-09 /
      data fpppp( 3, 3, 5,1),fpppp( 3, 3, 5,2),fpppp( 3, 3, 5,3)/
     x 7.5402871D-06,-3.9123831D-06,-1.7869340D-08 /
      data fpppp( 3, 3, 6,1),fpppp( 3, 3, 6,2),fpppp( 3, 3, 6,3)/
     x-5.1732058D-05,-2.0494814D-05, 7.3000641D-08 /
      data fpppp( 3, 3, 7,1),fpppp( 3, 3, 7,2),fpppp( 3, 3, 7,3)/
     x 2.8392233D-04,-1.9366243D-05,-1.0123436D-08 /
      data fpppp( 3, 3, 8,1),fpppp( 3, 3, 8,2),fpppp( 3, 3, 8,3)/
     x 1.3436814D-04, 1.5973279D-05,-1.4006246D-08 /
      data fpppp( 3, 3, 9,1),fpppp( 3, 3, 9,2),fpppp( 3, 3, 9,3)/
     x 8.5216729D-05, 8.5945670D-06,-1.7488591D-08 /
      data fpppp( 3, 3,10,1),fpppp( 3, 3,10,2),fpppp( 3, 3,10,3)/
     x 1.3436814D-04, 1.5973279D-05,-1.4006246D-08 /
      data fpppp( 3, 3,11,1),fpppp( 3, 3,11,2),fpppp( 3, 3,11,3)/
     x 2.8392233D-04,-1.9366243D-05,-1.0123436D-08 /
      data fpppp( 3, 3,12,1),fpppp( 3, 3,12,2),fpppp( 3, 3,12,3)/
     x-5.1732058D-05,-2.0494814D-05, 7.3000641D-08 /
      data fpppp( 3, 3,13,1),fpppp( 3, 3,13,2),fpppp( 3, 3,13,3)/
     x 7.5402871D-06,-3.9123831D-06,-1.7869340D-08 /
      data fpppp( 3, 3,14,1),fpppp( 3, 3,14,2),fpppp( 3, 3,14,3)/
     x 2.3683007D-04, 3.0139853D-05, 2.9034453D-09 /
      data fpppp( 3, 3,15,1),fpppp( 3, 3,15,2),fpppp( 3, 3,15,3)/
     x 7.1535661D-04,-1.1757049D-05,-4.9066047D-08 /
      data fpppp( 3, 3,16,1),fpppp( 3, 3,16,2),fpppp( 3, 3,16,3)/
     x 2.3683007D-04, 2.1038444D-05,-4.6295040D-09 /
      data fpppp( 3, 3,17,1),fpppp( 3, 3,17,2),fpppp( 3, 3,17,3)/
     x 7.5402871D-06, 3.2493253D-05, 1.2262458D-08 /
      data fpppp( 3, 4, 1,1),fpppp( 3, 4, 1,2),fpppp( 3, 4, 1,3)/
     x-6.4007874D-05, 2.5157553D-04, 2.6264253D-07 /
      data fpppp( 3, 4, 2,1),fpppp( 3, 4, 2,2),fpppp( 3, 4, 2,3)/
     x 8.0732744D-05, 1.1139188D-04, 8.3092612D-08 /
      data fpppp( 3, 4, 3,1),fpppp( 3, 4, 3,2),fpppp( 3, 4, 3,3)/
     x 1.3877993D-03,-2.6670835D-04,-3.9121273D-07 /
      data fpppp( 3, 4, 4,1),fpppp( 3, 4, 4,2),fpppp( 3, 4, 4,3)/
     x 8.0732744D-05, 1.8789947D-04, 1.6612590D-07 /
      data fpppp( 3, 4, 5,1),fpppp( 3, 4, 5,2),fpppp( 3, 4, 5,3)/
     x-6.4007874D-05,-5.4454843D-05,-6.9490626D-08 /
      data fpppp( 3, 4, 6,1),fpppp( 3, 4, 6,2),fpppp( 3, 4, 6,3)/
     x-6.5533884D-05, 1.1917923D-04, 3.4243257D-07 /
      data fpppp( 3, 4, 7,1),fpppp( 3, 4, 7,2),fpppp( 3, 4, 7,3)/
     x 1.5012359D-03,-2.4342865D-04,-3.8500361D-07 /
      data fpppp( 3, 4, 8,1),fpppp( 3, 4, 8,2),fpppp( 3, 4, 8,3)/
     x 4.8533923D-05, 1.4534833D-04, 2.1238230D-07 /
      data fpppp( 3, 4, 9,1),fpppp( 3, 4, 9,2),fpppp( 3, 4, 9,3)/
     x-1.5331624D-05,-2.9627463D-05,-1.2784145D-07 /
      data fpppp( 3, 4,10,1),fpppp( 3, 4,10,2),fpppp( 3, 4,10,3)/
     x 4.8533923D-05, 1.4534833D-04, 2.1238230D-07 /
      data fpppp( 3, 4,11,1),fpppp( 3, 4,11,2),fpppp( 3, 4,11,3)/
     x 1.5012359D-03,-2.4342865D-04,-3.8500361D-07 /
      data fpppp( 3, 4,12,1),fpppp( 3, 4,12,2),fpppp( 3, 4,12,3)/
     x-6.5533884D-05, 1.1917923D-04, 3.4243257D-07 /
      data fpppp( 3, 4,13,1),fpppp( 3, 4,13,2),fpppp( 3, 4,13,3)/
     x-6.4007874D-05,-5.4454843D-05,-6.9490626D-08 /
      data fpppp( 3, 4,14,1),fpppp( 3, 4,14,2),fpppp( 3, 4,14,3)/
     x 8.0732744D-05, 1.8789947D-04, 1.6612590D-07 /
      data fpppp( 3, 4,15,1),fpppp( 3, 4,15,2),fpppp( 3, 4,15,3)/
     x 1.3877993D-03,-2.6670835D-04,-3.9121273D-07 /
      data fpppp( 3, 4,16,1),fpppp( 3, 4,16,2),fpppp( 3, 4,16,3)/
     x 8.0732744D-05, 1.1139188D-04, 8.3092612D-08 /
      data fpppp( 3, 4,17,1),fpppp( 3, 4,17,2),fpppp( 3, 4,17,3)/
     x-6.4007874D-05, 2.5157553D-04, 2.6264253D-07 /
      data fpppp( 3, 5, 1,1),fpppp( 3, 5, 1,2),fpppp( 3, 5, 1,3)/
     x-3.5261777D-05, 6.8190406D-04,-5.2719856D-07 /
      data fpppp( 3, 5, 2,1),fpppp( 3, 5, 2,2),fpppp( 3, 5, 2,3)/
     x-3.1795934D-04, 2.8989850D-04,-2.5259568D-07 /
      data fpppp( 3, 5, 3,1),fpppp( 3, 5, 3,2),fpppp( 3, 5, 3,3)/
     x-2.6689031D-03,-7.7104148D-04, 5.1890187D-07 /
      data fpppp( 3, 5, 4,1),fpppp( 3, 5, 4,2),fpppp( 3, 5, 4,3)/
     x-3.1795934D-04, 5.0928899D-04,-4.4873192D-07 /
      data fpppp( 3, 5, 5,1),fpppp( 3, 5, 5,2),fpppp( 3, 5, 5,3)/
     x-3.5261777D-05,-1.9565789D-04, 2.5734641D-07 /
      data fpppp( 3, 5, 6,1),fpppp( 3, 5, 6,2),fpppp( 3, 5, 6,3)/
     x-2.1632473D-04, 4.8887856D-04,-3.6226429D-07 /
      data fpppp( 3, 5, 7,1),fpppp( 3, 5, 7,2),fpppp( 3, 5, 7,3)/
     x-2.5750596D-03,-7.9799407D-04, 5.8227685D-07 /
      data fpppp( 3, 5, 8,1),fpppp( 3, 5, 8,2),fpppp( 3, 5, 8,3)/
     x-3.1055932D-04, 4.8450342D-04,-3.8182551D-07 /
      data fpppp( 3, 5, 9,1),fpppp( 3, 5, 9,2),fpppp( 3, 5, 9,3)/
     x-4.7490900D-05,-1.7043145D-04, 1.5480568D-07 /
      data fpppp( 3, 5,10,1),fpppp( 3, 5,10,2),fpppp( 3, 5,10,3)/
     x-3.1055932D-04, 4.8450342D-04,-3.8182551D-07 /
      data fpppp( 3, 5,11,1),fpppp( 3, 5,11,2),fpppp( 3, 5,11,3)/
     x-2.5750596D-03,-7.9799407D-04, 5.8227685D-07 /
      data fpppp( 3, 5,12,1),fpppp( 3, 5,12,2),fpppp( 3, 5,12,3)/
     x-2.1632473D-04, 4.8887856D-04,-3.6226429D-07 /
      data fpppp( 3, 5,13,1),fpppp( 3, 5,13,2),fpppp( 3, 5,13,3)/
     x-3.5261777D-05,-1.9565789D-04, 2.5734641D-07 /
      data fpppp( 3, 5,14,1),fpppp( 3, 5,14,2),fpppp( 3, 5,14,3)/
     x-3.1795934D-04, 5.0928899D-04,-4.4873192D-07 /
      data fpppp( 3, 5,15,1),fpppp( 3, 5,15,2),fpppp( 3, 5,15,3)/
     x-2.6689031D-03,-7.7104148D-04, 5.1890187D-07 /
      data fpppp( 3, 5,16,1),fpppp( 3, 5,16,2),fpppp( 3, 5,16,3)/
     x-3.1795934D-04, 2.8989850D-04,-2.5259568D-07 /
      data fpppp( 3, 5,17,1),fpppp( 3, 5,17,2),fpppp( 3, 5,17,3)/
     x-3.5261777D-05, 6.8190406D-04,-5.2719856D-07 /
      data fpppp( 3, 6, 1,1),fpppp( 3, 6, 1,2),fpppp( 3, 6, 1,3)/
     x 3.3660469D-05, 5.4656694D-04,-4.0246820D-08 /
      data fpppp( 3, 6, 2,1),fpppp( 3, 6, 2,2),fpppp( 3, 6, 2,3)/
     x-6.2727363D-06, 2.3144833D-04,-3.3352861D-08 /
      data fpppp( 3, 6, 3,1),fpppp( 3, 6, 3,2),fpppp( 3, 6, 3,3)/
     x-6.8928312D-04,-6.2340805D-04, 9.0555900D-09 /
      data fpppp( 3, 6, 4,1),fpppp( 3, 6, 4,2),fpppp( 3, 6, 4,3)/
     x-6.2727363D-06, 4.1081775D-04,-7.2836679D-08 /
      data fpppp( 3, 6, 5,1),fpppp( 3, 6, 5,2),fpppp( 3, 6, 5,3)/
     x 3.3660469D-05,-1.7091073D-04, 1.1768845D-07 /
      data fpppp( 3, 6, 6,1),fpppp( 3, 6, 6,2),fpppp( 3, 6, 6,3)/
     x 7.0463201D-05, 4.2408692D-04,-1.3259077D-07 /
      data fpppp( 3, 6, 7,1),fpppp( 3, 6, 7,2),fpppp( 3, 6, 7,3)/
     x-7.3025661D-04,-6.6720296D-04, 1.4385418D-07 /
      data fpppp( 3, 6, 8,1),fpppp( 3, 6, 8,2),fpppp( 3, 6, 8,3)/
     x 2.2740696D-05, 4.0863292D-04,-1.0157681D-07 /
      data fpppp( 3, 6, 9,1),fpppp( 3, 6, 9,2),fpppp( 3, 6, 9,3)/
     x 3.1319947D-06,-1.5754482D-04, 7.5287021D-08 /
      data fpppp( 3, 6,10,1),fpppp( 3, 6,10,2),fpppp( 3, 6,10,3)/
     x 2.2740696D-05, 4.0863292D-04,-1.0157681D-07 /
      data fpppp( 3, 6,11,1),fpppp( 3, 6,11,2),fpppp( 3, 6,11,3)/
     x-7.3025661D-04,-6.6720296D-04, 1.4385418D-07 /
      data fpppp( 3, 6,12,1),fpppp( 3, 6,12,2),fpppp( 3, 6,12,3)/
     x 7.0463201D-05, 4.2408692D-04,-1.3259077D-07 /
      data fpppp( 3, 6,13,1),fpppp( 3, 6,13,2),fpppp( 3, 6,13,3)/
     x 3.3660469D-05,-1.7091073D-04, 1.1768845D-07 /
      data fpppp( 3, 6,14,1),fpppp( 3, 6,14,2),fpppp( 3, 6,14,3)/
     x-6.2727363D-06, 4.1081775D-04,-7.2836679D-08 /
      data fpppp( 3, 6,15,1),fpppp( 3, 6,15,2),fpppp( 3, 6,15,3)/
     x-6.8928312D-04,-6.2340805D-04, 9.0555900D-09 /
      data fpppp( 3, 6,16,1),fpppp( 3, 6,16,2),fpppp( 3, 6,16,3)/
     x-6.2727363D-06, 2.3144833D-04,-3.3352861D-08 /
      data fpppp( 3, 6,17,1),fpppp( 3, 6,17,2),fpppp( 3, 6,17,3)/
     x 3.3660469D-05, 5.4656694D-04,-4.0246820D-08 /
      data fpppp( 3, 7, 1,1),fpppp( 3, 7, 1,2),fpppp( 3, 7, 1,3)/
     x 3.3960605D-05, 1.5125951D-04, 5.0518120D-07 /
      data fpppp( 3, 7, 2,1),fpppp( 3, 7, 2,2),fpppp( 3, 7, 2,3)/
     x 1.1345078D-04, 6.2656386D-05, 2.3108307D-07 /
      data fpppp( 3, 7, 3,1),fpppp( 3, 7, 3,2),fpppp( 3, 7, 3,3)/
     x 1.2131084D-03,-1.7670251D-04,-5.2250338D-07 /
      data fpppp( 3, 7, 4,1),fpppp( 3, 7, 4,2),fpppp( 3, 7, 4,3)/
     x 1.1345078D-04, 1.1158380D-04, 4.0211926D-07 /
      data fpppp( 3, 7, 5,1),fpppp( 3, 7, 5,2),fpppp( 3, 7, 5,3)/
     x 3.3960605D-05,-4.4450153D-05,-1.7896359D-07 /
      data fpppp( 3, 7, 6,1),fpppp( 3, 7, 6,2),fpppp( 3, 7, 6,3)/
     x 1.4300334D-04, 1.2123214D-04, 2.1416021D-07 /
      data fpppp( 3, 7, 7,1),fpppp( 3, 7, 7,2),fpppp( 3, 7, 7,3)/
     x 1.2951161D-03,-1.8417184D-04,-3.7508166D-07 /
      data fpppp( 3, 7, 8,1),fpppp( 3, 7, 8,2),fpppp( 3, 7, 8,3)/
     x 1.0693267D-04, 1.0606634D-04, 2.8327222D-07 /
      data fpppp( 3, 7, 9,1),fpppp( 3, 7, 9,2),fpppp( 3, 7, 9,3)/
     x 6.5891665D-07,-3.5663487D-05,-1.4000349D-07 /
      data fpppp( 3, 7,10,1),fpppp( 3, 7,10,2),fpppp( 3, 7,10,3)/
     x 1.0693267D-04, 1.0606634D-04, 2.8327222D-07 /
      data fpppp( 3, 7,11,1),fpppp( 3, 7,11,2),fpppp( 3, 7,11,3)/
     x 1.2951161D-03,-1.8417184D-04,-3.7508166D-07 /
      data fpppp( 3, 7,12,1),fpppp( 3, 7,12,2),fpppp( 3, 7,12,3)/
     x 1.4300334D-04, 1.2123214D-04, 2.1416021D-07 /
      data fpppp( 3, 7,13,1),fpppp( 3, 7,13,2),fpppp( 3, 7,13,3)/
     x 3.3960605D-05,-4.4450153D-05,-1.7896359D-07 /
      data fpppp( 3, 7,14,1),fpppp( 3, 7,14,2),fpppp( 3, 7,14,3)/
     x 1.1345078D-04, 1.1158380D-04, 4.0211926D-07 /
      data fpppp( 3, 7,15,1),fpppp( 3, 7,15,2),fpppp( 3, 7,15,3)/
     x 1.2131084D-03,-1.7670251D-04,-5.2250338D-07 /
      data fpppp( 3, 7,16,1),fpppp( 3, 7,16,2),fpppp( 3, 7,16,3)/
     x 1.1345078D-04, 6.2656386D-05, 2.3108307D-07 /
      data fpppp( 3, 7,17,1),fpppp( 3, 7,17,2),fpppp( 3, 7,17,3)/
     x 3.3960605D-05, 1.5125951D-04, 5.0518120D-07 /
      data fpppp( 3, 8, 1,1),fpppp( 3, 8, 1,2),fpppp( 3, 8, 1,3)/
     x 2.0842264D-05, 1.5696443D-05,-6.0743420D-08 /
      data fpppp( 3, 8, 2,1),fpppp( 3, 8, 2,2),fpppp( 3, 8, 2,3)/
     x-1.7253346D-05, 4.4112790D-06, 4.8448061D-09 /
      data fpppp( 3, 8, 3,1),fpppp( 3, 8, 3,2),fpppp( 3, 8, 3,3)/
     x 1.8063554D-04,-2.3753460D-05, 1.5544651D-07 /
      data fpppp( 3, 8, 4,1),fpppp( 3, 8, 4,2),fpppp( 3, 8, 4,3)/
     x-1.7253346D-05, 7.1603123D-06, 8.5010376D-09 /
      data fpppp( 3, 8, 5,1),fpppp( 3, 8, 5,2),fpppp( 3, 8, 5,3)/
     x 2.0842264D-05, 4.7003102D-06,-7.5368346D-08 /
      data fpppp( 3, 8, 6,1),fpppp( 3, 8, 6,2),fpppp( 3, 8, 6,3)/
     x 4.5645439D-05, 1.4775004D-05,-6.6454515D-08 /
      data fpppp( 3, 8, 7,1),fpppp( 3, 8, 7,2),fpppp( 3, 8, 7,3)/
     x 1.7896866D-04,-2.6834777D-05, 4.5584408D-08 /
      data fpppp( 3, 8, 8,1),fpppp( 3, 8, 8,2),fpppp( 3, 8, 8,3)/
     x-1.4692544D-06, 7.5195770D-06, 1.6444527D-08 /
      data fpppp( 3, 8, 9,1),fpppp( 3, 8, 9,2),fpppp( 3, 8, 9,3)/
     x-1.3296669D-05, 9.5707799D-06,-1.2251362D-08 /
      data fpppp( 3, 8,10,1),fpppp( 3, 8,10,2),fpppp( 3, 8,10,3)/
     x-1.4692544D-06, 7.5195770D-06, 1.6444527D-08 /
      data fpppp( 3, 8,11,1),fpppp( 3, 8,11,2),fpppp( 3, 8,11,3)/
     x 1.7896866D-04,-2.6834777D-05, 4.5584408D-08 /
      data fpppp( 3, 8,12,1),fpppp( 3, 8,12,2),fpppp( 3, 8,12,3)/
     x 4.5645439D-05, 1.4775004D-05,-6.6454515D-08 /
      data fpppp( 3, 8,13,1),fpppp( 3, 8,13,2),fpppp( 3, 8,13,3)/
     x 2.0842264D-05, 4.7003102D-06,-7.5368346D-08 /
      data fpppp( 3, 8,14,1),fpppp( 3, 8,14,2),fpppp( 3, 8,14,3)/
     x-1.7253346D-05, 7.1603123D-06, 8.5010376D-09 /
      data fpppp( 3, 8,15,1),fpppp( 3, 8,15,2),fpppp( 3, 8,15,3)/
     x 1.8063554D-04,-2.3753460D-05, 1.5544651D-07 /
      data fpppp( 3, 8,16,1),fpppp( 3, 8,16,2),fpppp( 3, 8,16,3)/
     x-1.7253346D-05, 4.4112790D-06, 4.8448061D-09 /
      data fpppp( 3, 8,17,1),fpppp( 3, 8,17,2),fpppp( 3, 8,17,3)/
     x 2.0842264D-05, 1.5696443D-05,-6.0743420D-08 /
      data fpppp( 3, 9, 1,1),fpppp( 3, 9, 1,2),fpppp( 3, 9, 1,3)/
     x 1.1842060D-05, 9.4958535D-06,-1.3354372D-07 /
      data fpppp( 3, 9, 2,1),fpppp( 3, 9, 2,2),fpppp( 3, 9, 2,3)/
     x-3.3351612D-05, 3.1321096D-06,-3.3216563D-08 /
      data fpppp( 3, 9, 3,1),fpppp( 3, 9, 3,2),fpppp( 3, 9, 3,3)/
     x-9.6022682D-05,-1.1738634D-05, 2.1947061D-07 /
      data fpppp( 3, 9, 4,1),fpppp( 3, 9, 4,2),fpppp( 3, 9, 4,3)/
     x-3.3351612D-05, 3.1651211D-06,-6.1102281D-08 /
      data fpppp( 3, 9, 5,1),fpppp( 3, 9, 5,2),fpppp( 3, 9, 5,3)/
     x 1.1842060D-05, 9.3638074D-06,-2.2000844D-08 /
      data fpppp( 3, 9, 6,1),fpppp( 3, 9, 6,2),fpppp( 3, 9, 6,3)/
     x 1.6872015D-05,-3.5848486D-06,-8.1812014D-08 /
      data fpppp( 3, 9, 7,1),fpppp( 3, 9, 7,2),fpppp( 3, 9, 7,3)/
     x 3.8199591D-06,-1.5281180D-05, 3.6501296D-08 /
      data fpppp( 3, 9, 8,1),fpppp( 3, 9, 8,2),fpppp( 3, 9, 8,3)/
     x-6.2548731D-06, 4.8578835D-06, 7.3104562D-09 /
      data fpppp( 3, 9, 9,1),fpppp( 3, 9, 9,2),fpppp( 3, 9, 9,3)/
     x 6.2075282D-06, 1.4702569D-05, 1.8088545D-08 /
      data fpppp( 3, 9,10,1),fpppp( 3, 9,10,2),fpppp( 3, 9,10,3)/
     x-6.2548731D-06, 4.8578835D-06, 7.3104562D-09 /
      data fpppp( 3, 9,11,1),fpppp( 3, 9,11,2),fpppp( 3, 9,11,3)/
     x 3.8199591D-06,-1.5281180D-05, 3.6501296D-08 /
      data fpppp( 3, 9,12,1),fpppp( 3, 9,12,2),fpppp( 3, 9,12,3)/
     x 1.6872015D-05,-3.5848486D-06,-8.1812014D-08 /
      data fpppp( 3, 9,13,1),fpppp( 3, 9,13,2),fpppp( 3, 9,13,3)/
     x 1.1842060D-05, 9.3638074D-06,-2.2000844D-08 /
      data fpppp( 3, 9,14,1),fpppp( 3, 9,14,2),fpppp( 3, 9,14,3)/
     x-3.3351612D-05, 3.1651211D-06,-6.1102281D-08 /
      data fpppp( 3, 9,15,1),fpppp( 3, 9,15,2),fpppp( 3, 9,15,3)/
     x-9.6022682D-05,-1.1738634D-05, 2.1947061D-07 /
      data fpppp( 3, 9,16,1),fpppp( 3, 9,16,2),fpppp( 3, 9,16,3)/
     x-3.3351612D-05, 3.1321096D-06,-3.3216563D-08 /
      data fpppp( 3, 9,17,1),fpppp( 3, 9,17,2),fpppp( 3, 9,17,3)/
     x 1.1842060D-05, 9.4958535D-06,-1.3354372D-07 /
      data fpppp( 3,10, 1,1),fpppp( 3,10, 1,2),fpppp( 3,10, 1,3)/
     x 1.3466152D-05, 8.3090397D-06, 7.9424658D-10 /
      data fpppp( 3,10, 2,1),fpppp( 3,10, 2,2),fpppp( 3,10, 2,3)/
     x 2.8247831D-05, 5.6531670D-06, 1.4296195D-08 /
      data fpppp( 3,10, 3,1),fpppp( 3,10, 3,2),fpppp( 3,10, 3,3)/
     x 5.0627328D-05,-6.4152198D-07, 4.6256087D-08 /
      data fpppp( 3,10, 4,1),fpppp( 3,10, 4,2),fpppp( 3,10, 4,3)/
     x 2.8247831D-05, 5.7996459D-06, 1.3613175D-08 /
      data fpppp( 3,10, 5,1),fpppp( 3,10, 5,2),fpppp( 3,10, 5,3)/
     x 1.3466152D-05, 7.7231239D-06, 3.5263257D-09 /
      data fpppp( 3,10, 6,1),fpppp( 3,10, 6,2),fpppp( 3,10, 6,3)/
     x 3.5004874D-05,-1.8649573D-05,-9.2340929D-08 /
      data fpppp( 3,10, 7,1),fpppp( 3,10, 7,2),fpppp( 3,10, 7,3)/
     x-7.3912171D-06,-1.3686451D-05, 2.8429813D-08 /
      data fpppp( 3,10, 8,1),fpppp( 3,10, 8,2),fpppp( 3,10, 8,3)/
     x 2.2207753D-05, 1.3196844D-05, 1.4799533D-08 /
      data fpppp( 3,10, 9,1),fpppp( 3,10, 9,2),fpppp( 3,10, 9,3)/
     x 2.8020574D-05, 1.1898753D-05, 1.7574241D-08 /
      data fpppp( 3,10,10,1),fpppp( 3,10,10,2),fpppp( 3,10,10,3)/
     x 2.2207753D-05, 1.3196844D-05, 1.4799533D-08 /
      data fpppp( 3,10,11,1),fpppp( 3,10,11,2),fpppp( 3,10,11,3)/
     x-7.3912171D-06,-1.3686451D-05, 2.8429813D-08 /
      data fpppp( 3,10,12,1),fpppp( 3,10,12,2),fpppp( 3,10,12,3)/
     x 3.5004874D-05,-1.8649573D-05,-9.2340929D-08 /
      data fpppp( 3,10,13,1),fpppp( 3,10,13,2),fpppp( 3,10,13,3)/
     x 1.3466152D-05, 7.7231239D-06, 3.5263257D-09 /
      data fpppp( 3,10,14,1),fpppp( 3,10,14,2),fpppp( 3,10,14,3)/
     x 2.8247831D-05, 5.7996459D-06, 1.3613175D-08 /
      data fpppp( 3,10,15,1),fpppp( 3,10,15,2),fpppp( 3,10,15,3)/
     x 5.0627328D-05,-6.4152198D-07, 4.6256087D-08 /
      data fpppp( 3,10,16,1),fpppp( 3,10,16,2),fpppp( 3,10,16,3)/
     x 2.8247831D-05, 5.6531670D-06, 1.4296195D-08 /
      data fpppp( 3,10,17,1),fpppp( 3,10,17,2),fpppp( 3,10,17,3)/
     x 1.3466152D-05, 8.3090397D-06, 7.9424658D-10 /
      data fpppp( 3,11, 1,1),fpppp( 3,11, 1,2),fpppp( 3,11, 1,3)/
     x 1.5275576D-05, 8.6914432D-06, 3.5710756D-08 /
      data fpppp( 3,11, 2,1),fpppp( 3,11, 2,2),fpppp( 3,11, 2,3)/
     x 4.2325368D-05, 8.3957419D-06, 2.2810400D-08 /
      data fpppp( 3,11, 3,1),fpppp( 3,11, 3,2),fpppp( 3,11, 3,3)/
     x 5.8406406D-05, 8.2164268D-06,-7.0334496D-09 /
      data fpppp( 3,11, 4,1),fpppp( 3,11, 4,2),fpppp( 3,11, 4,3)/
     x 4.2325368D-05, 7.6297600D-06, 2.2424928D-08 /
      data fpppp( 3,11, 5,1),fpppp( 3,11, 5,2),fpppp( 3,11, 5,3)/
     x 1.5275576D-05, 1.1755371D-05, 3.7252644D-08 /
      data fpppp( 3,11, 6,1),fpppp( 3,11, 6,2),fpppp( 3,11, 6,3)/
     x-1.4750450D-05,-4.4252533D-05,-1.2726803D-07 /
      data fpppp( 3,11, 7,1),fpppp( 3,11, 7,2),fpppp( 3,11, 7,3)/
     x 8.7214354D-06,-9.2076169D-08, 5.8037387D-08 /
      data fpppp( 3,11, 8,1),fpppp( 3,11, 8,2),fpppp( 3,11, 8,3)/
     x 2.6694289D-05, 1.5793066D-05, 4.0634304D-09 /
      data fpppp( 3,11, 9,1),fpppp( 3,11, 9,2),fpppp( 3,11, 9,3)/
     x 2.6576901D-05, 9.9887346D-06, 1.7948484D-08 /
      data fpppp( 3,11,10,1),fpppp( 3,11,10,2),fpppp( 3,11,10,3)/
     x 2.6694289D-05, 1.5793066D-05, 4.0634304D-09 /
      data fpppp( 3,11,11,1),fpppp( 3,11,11,2),fpppp( 3,11,11,3)/
     x 8.7214354D-06,-9.2076169D-08, 5.8037387D-08 /
      data fpppp( 3,11,12,1),fpppp( 3,11,12,2),fpppp( 3,11,12,3)/
     x-1.4750450D-05,-4.4252533D-05,-1.2726803D-07 /
      data fpppp( 3,11,13,1),fpppp( 3,11,13,2),fpppp( 3,11,13,3)/
     x 1.5275576D-05, 1.1755371D-05, 3.7252644D-08 /
      data fpppp( 3,11,14,1),fpppp( 3,11,14,2),fpppp( 3,11,14,3)/
     x 4.2325368D-05, 7.6297600D-06, 2.2424928D-08 /
      data fpppp( 3,11,15,1),fpppp( 3,11,15,2),fpppp( 3,11,15,3)/
     x 5.8406406D-05, 8.2164268D-06,-7.0334496D-09 /
      data fpppp( 3,11,16,1),fpppp( 3,11,16,2),fpppp( 3,11,16,3)/
     x 4.2325368D-05, 8.3957419D-06, 2.2810400D-08 /
      data fpppp( 3,11,17,1),fpppp( 3,11,17,2),fpppp( 3,11,17,3)/
     x 1.5275576D-05, 8.6914432D-06, 3.5710756D-08 /
      data fpppp( 3,12, 1,1),fpppp( 3,12, 1,2),fpppp( 3,12, 1,3)/
     x 4.0879562D-05, 1.2025745D-05, 2.8593294D-08 /
      data fpppp( 3,12, 2,1),fpppp( 3,12, 2,2),fpppp( 3,12, 2,3)/
     x 1.9928991D-05, 1.1416116D-05, 1.5387744D-08 /
      data fpppp( 3,12, 3,1),fpppp( 3,12, 3,2),fpppp( 3,12, 3,3)/
     x 2.6998407D-05, 1.2093811D-05,-1.0055006D-08 /
      data fpppp( 3,12, 4,1),fpppp( 3,12, 4,2),fpppp( 3,12, 4,3)/
     x 1.9928991D-05, 8.2658752D-06, 7.3324467D-09 /
      data fpppp( 3,12, 5,1),fpppp( 3,12, 5,2),fpppp( 3,12, 5,3)/
     x 4.0879562D-05, 2.4626709D-05, 6.0814485D-08 /
      data fpppp( 3,12, 6,1),fpppp( 3,12, 6,2),fpppp( 3,12, 6,3)/
     x 2.3002514D-04,-8.2616699D-05,-1.5123784D-07 /
      data fpppp( 3,12, 7,1),fpppp( 3,12, 7,2),fpppp( 3,12, 7,3)/
     x 5.1404845D-06, 2.6377650D-05, 9.1112803D-08 /
      data fpppp( 3,12, 8,1),fpppp( 3,12, 8,2),fpppp( 3,12, 8,3)/
     x 1.6529949D-05, 1.1457205D-05,-1.3291015D-08 /
      data fpppp( 3,12, 9,1),fpppp( 3,12, 9,2),fpppp( 3,12, 9,3)/
     x 1.8118254D-05, 1.1159670D-05, 1.9250704D-08 /
      data fpppp( 3,12,10,1),fpppp( 3,12,10,2),fpppp( 3,12,10,3)/
     x 1.6529949D-05, 1.1457205D-05,-1.3291015D-08 /
      data fpppp( 3,12,11,1),fpppp( 3,12,11,2),fpppp( 3,12,11,3)/
     x 5.1404845D-06, 2.6377650D-05, 9.1112803D-08 /
      data fpppp( 3,12,12,1),fpppp( 3,12,12,2),fpppp( 3,12,12,3)/
     x 2.3002514D-04,-8.2616699D-05,-1.5123784D-07 /
      data fpppp( 3,12,13,1),fpppp( 3,12,13,2),fpppp( 3,12,13,3)/
     x 4.0879562D-05, 2.4626709D-05, 6.0814485D-08 /
      data fpppp( 3,12,14,1),fpppp( 3,12,14,2),fpppp( 3,12,14,3)/
     x 1.9928991D-05, 8.2658752D-06, 7.3324467D-09 /
      data fpppp( 3,12,15,1),fpppp( 3,12,15,2),fpppp( 3,12,15,3)/
     x 2.6998407D-05, 1.2093811D-05,-1.0055006D-08 /
      data fpppp( 3,12,16,1),fpppp( 3,12,16,2),fpppp( 3,12,16,3)/
     x 1.9928991D-05, 1.1416116D-05, 1.5387744D-08 /
      data fpppp( 3,12,17,1),fpppp( 3,12,17,2),fpppp( 3,12,17,3)/
     x 4.0879562D-05, 1.2025745D-05, 2.8593294D-08 /
      data fpppp( 3,13, 1,1),fpppp( 3,13, 1,2),fpppp( 3,13, 1,3)/
     x 1.1856321D-04, 2.3772359D-05, 2.5567856D-08 /
      data fpppp( 3,13, 2,1),fpppp( 3,13, 2,2),fpppp( 3,13, 2,3)/
     x 2.7997625D-05, 1.8669273D-05, 1.2861712D-08 /
      data fpppp( 3,13, 3,1),fpppp( 3,13, 3,2),fpppp( 3,13, 3,3)/
     x 2.8139991D-05, 1.1940992D-05,-1.4290673D-08 /
      data fpppp( 3,13, 4,1),fpppp( 3,13, 4,2),fpppp( 3,13, 4,3)/
     x 2.7997625D-05, 1.0900895D-05, 9.1187880D-09 /
      data fpppp( 3,13, 5,1),fpppp( 3,13, 5,2),fpppp( 3,13, 5,3)/
     x 1.1856321D-04, 5.4845872D-05, 4.0539553D-08 /
      data fpppp( 3,13, 6,1),fpppp( 3,13, 6,2),fpppp( 3,13, 6,3)/
     x-2.0860604D-04,-1.6436341D-04,-1.3649466D-07 /
      data fpppp( 3,13, 7,1),fpppp( 3,13, 7,2),fpppp( 3,13, 7,3)/
     x-1.8534268D-05, 8.8431717D-05, 1.2499749D-07 /
      data fpppp( 3,13, 8,1),fpppp( 3,13, 8,2),fpppp( 3,13, 8,3)/
     x 9.0346401D-06,-5.4896435D-06,-4.1649682D-08 /
      data fpppp( 3,13, 9,1),fpppp( 3,13, 9,2),fpppp( 3,13, 9,3)/
     x 1.2207222D-05, 1.8113409D-05, 2.0643855D-08 /
      data fpppp( 3,13,10,1),fpppp( 3,13,10,2),fpppp( 3,13,10,3)/
     x 9.0346401D-06,-5.4896435D-06,-4.1649682D-08 /
      data fpppp( 3,13,11,1),fpppp( 3,13,11,2),fpppp( 3,13,11,3)/
     x-1.8534268D-05, 8.8431717D-05, 1.2499749D-07 /
      data fpppp( 3,13,12,1),fpppp( 3,13,12,2),fpppp( 3,13,12,3)/
     x-2.0860604D-04,-1.6436341D-04,-1.3649466D-07 /
      data fpppp( 3,13,13,1),fpppp( 3,13,13,2),fpppp( 3,13,13,3)/
     x 1.1856321D-04, 5.4845872D-05, 4.0539553D-08 /
      data fpppp( 3,13,14,1),fpppp( 3,13,14,2),fpppp( 3,13,14,3)/
     x 2.7997625D-05, 1.0900895D-05, 9.1187880D-09 /
      data fpppp( 3,13,15,1),fpppp( 3,13,15,2),fpppp( 3,13,15,3)/
     x 2.8139991D-05, 1.1940992D-05,-1.4290673D-08 /
      data fpppp( 3,13,16,1),fpppp( 3,13,16,2),fpppp( 3,13,16,3)/
     x 2.7997625D-05, 1.8669273D-05, 1.2861712D-08 /
      data fpppp( 3,13,17,1),fpppp( 3,13,17,2),fpppp( 3,13,17,3)/
     x 1.1856321D-04, 2.3772359D-05, 2.5567856D-08 /
      data fpppp( 3,14, 1,1),fpppp( 3,14, 1,2),fpppp( 3,14, 1,3)/
     x 4.8240525D-04, 7.1728478D-05, 6.7499678D-08 /
      data fpppp( 3,14, 2,1),fpppp( 3,14, 2,2),fpppp( 3,14, 2,3)/
     x-5.8245915D-05, 4.5848368D-05, 3.5976615D-08 /
      data fpppp( 3,14, 3,1),fpppp( 3,14, 3,2),fpppp( 3,14, 3,3)/
     x-2.5072915D-05, 3.0611285D-06,-4.7391531D-08 /
      data fpppp( 3,14, 4,1),fpppp( 3,14, 4,2),fpppp( 3,14, 4,3)/
     x-5.8245915D-05, 1.9448846D-05, 5.0698117D-08 /
      data fpppp( 3,14, 5,1),fpppp( 3,14, 5,2),fpppp( 3,14, 5,3)/
     x 4.8240525D-04, 1.7732657D-04, 8.6136705D-09 /
      data fpppp( 3,14, 6,1),fpppp( 3,14, 6,2),fpppp( 3,14, 6,3)/
     x 3.8967580D-03,-4.6874059D-04,-1.8659473D-07 /
      data fpppp( 3,14, 7,1),fpppp( 3,14, 7,2),fpppp( 3,14, 7,3)/
     x-2.6099911D-05, 3.1738205D-04, 2.4531562D-07 /
      data fpppp( 3,14, 8,1),fpppp( 3,14, 8,2),fpppp( 3,14, 8,3)/
     x 6.1475129D-06,-7.3905734D-05,-1.0909266D-07 /
      data fpppp( 3,14, 9,1),fpppp( 3,14, 9,2),fpppp( 3,14, 9,3)/
     x 1.5000712D-05, 4.9516668D-05, 3.1965076D-08 /
      data fpppp( 3,14,10,1),fpppp( 3,14,10,2),fpppp( 3,14,10,3)/
     x 6.1475129D-06,-7.3905734D-05,-1.0909266D-07 /
      data fpppp( 3,14,11,1),fpppp( 3,14,11,2),fpppp( 3,14,11,3)/
     x-2.6099911D-05, 3.1738205D-04, 2.4531562D-07 /
      data fpppp( 3,14,12,1),fpppp( 3,14,12,2),fpppp( 3,14,12,3)/
     x 3.8967580D-03,-4.6874059D-04,-1.8659473D-07 /
      data fpppp( 3,14,13,1),fpppp( 3,14,13,2),fpppp( 3,14,13,3)/
     x 4.8240525D-04, 1.7732657D-04, 8.6136705D-09 /
      data fpppp( 3,14,14,1),fpppp( 3,14,14,2),fpppp( 3,14,14,3)/
     x-5.8245915D-05, 1.9448846D-05, 5.0698117D-08 /
      data fpppp( 3,14,15,1),fpppp( 3,14,15,2),fpppp( 3,14,15,3)/
     x-2.5072915D-05, 3.0611285D-06,-4.7391531D-08 /
      data fpppp( 3,14,16,1),fpppp( 3,14,16,2),fpppp( 3,14,16,3)/
     x-5.8245915D-05, 4.5848368D-05, 3.5976615D-08 /
      data fpppp( 3,14,17,1),fpppp( 3,14,17,2),fpppp( 3,14,17,3)/
     x 4.8240525D-04, 7.1728478D-05, 6.7499678D-08 /
      data fpppp( 3,15, 1,1),fpppp( 3,15, 1,2),fpppp( 3,15, 1,3)/
     x-9.6388637D-04, 1.6295715D-04,-2.6817106D-07 /
      data fpppp( 3,15, 2,1),fpppp( 3,15, 2,2),fpppp( 3,15, 2,3)/
     x 1.9771591D-04, 9.6429580D-05,-1.8291919D-07 /
      data fpppp( 3,15, 3,1),fpppp( 3,15, 3,2),fpppp( 3,15, 3,3)/
     x 1.1813822D-04,-1.5497016D-05,-1.8146270D-09 /
      data fpppp( 3,15, 4,1),fpppp( 3,15, 4,2),fpppp( 3,15, 4,3)/
     x 1.9771591D-04, 3.1472988D-05,-1.5619453D-07 /
      data fpppp( 3,15, 5,1),fpppp( 3,15, 5,2),fpppp( 3,15, 5,3)/
     x-9.6388637D-04, 4.2278352D-04,-3.7506971D-07 /
      data fpppp( 3,15, 6,1),fpppp( 3,15, 6,2),fpppp( 3,15, 6,3)/
     x-1.1300047D-02,-1.0571086D-03, 1.2251387D-06 /
      data fpppp( 3,15, 7,1),fpppp( 3,15, 7,2),fpppp( 3,15, 7,3)/
     x-3.5368923D-05, 7.5590105D-04,-7.4808520D-07 /
      data fpppp( 3,15, 8,1),fpppp( 3,15, 8,2),fpppp( 3,15, 8,3)/
     x-1.0852147D-05,-2.0574374D-04, 1.1653610D-07 /
      data fpppp( 3,15, 9,1),fpppp( 3,15, 9,2),fpppp( 3,15, 9,3)/
     x-3.1688290D-06, 1.1006040D-04,-1.1838205D-07 /
      data fpppp( 3,15,10,1),fpppp( 3,15,10,2),fpppp( 3,15,10,3)/
     x-1.0852147D-05,-2.0574374D-04, 1.1653610D-07 /
      data fpppp( 3,15,11,1),fpppp( 3,15,11,2),fpppp( 3,15,11,3)/
     x-3.5368923D-05, 7.5590105D-04,-7.4808520D-07 /
      data fpppp( 3,15,12,1),fpppp( 3,15,12,2),fpppp( 3,15,12,3)/
     x-1.1300047D-02,-1.0571086D-03, 1.2251387D-06 /
      data fpppp( 3,15,13,1),fpppp( 3,15,13,2),fpppp( 3,15,13,3)/
     x-9.6388637D-04, 4.2278352D-04,-3.7506971D-07 /
      data fpppp( 3,15,14,1),fpppp( 3,15,14,2),fpppp( 3,15,14,3)/
     x 1.9771591D-04, 3.1472988D-05,-1.5619453D-07 /
      data fpppp( 3,15,15,1),fpppp( 3,15,15,2),fpppp( 3,15,15,3)/
     x 1.1813822D-04,-1.5497016D-05,-1.8146270D-09 /
      data fpppp( 3,15,16,1),fpppp( 3,15,16,2),fpppp( 3,15,16,3)/
     x 1.9771591D-04, 9.6429580D-05,-1.8291919D-07 /
      data fpppp( 3,15,17,1),fpppp( 3,15,17,2),fpppp( 3,15,17,3)/
     x-9.6388637D-04, 1.6295715D-04,-2.6817106D-07 /
      data fpppp( 3,16, 1,1),fpppp( 3,16, 1,2),fpppp( 3,16, 1,3)/
     x-3.2059009D-03, 3.8211600D-05,-1.3365493D-07 /
      data fpppp( 3,16, 2,1),fpppp( 3,16, 2,2),fpppp( 3,16, 2,3)/
     x-1.0740240D-03, 3.9186014D-05,-1.0988757D-07 /
      data fpppp( 3,16, 3,1),fpppp( 3,16, 3,2),fpppp( 3,16, 3,3)/
     x-5.6217286D-04,-5.4661989D-05,-7.8639580D-08 /
      data fpppp( 3,16, 4,1),fpppp( 3,16, 4,2),fpppp( 3,16, 4,3)/
     x-1.0740240D-03, 1.8336847D-04,-7.3573792D-08 /
      data fpppp( 3,16, 5,1),fpppp( 3,16, 5,2),fpppp( 3,16, 5,3)/
     x-3.2059009D-03,-5.3851821D-04,-2.7891002D-07 /
      data fpppp( 3,16, 6,1),fpppp( 3,16, 6,2),fpppp( 3,16, 6,3)/
     x 7.7298164D-03, 7.3536065D-04, 8.7271437D-07 /
      data fpppp( 3,16, 7,1),fpppp( 3,16, 7,2),fpppp( 3,16, 7,3)/
     x-1.6453879D-04,-4.2927352D-04,-4.2629799D-07 /
      data fpppp( 3,16, 8,1),fpppp( 3,16, 8,2),fpppp( 3,16, 8,3)/
     x 2.6193765D-05, 1.1852755D-04,-1.3136818D-09 /
      data fpppp( 3,16, 9,1),fpppp( 3,16, 9,2),fpppp( 3,16, 9,3)/
     x 3.6772442D-05,-6.0237464D-05,-1.0054590D-07 /
      data fpppp( 3,16,10,1),fpppp( 3,16,10,2),fpppp( 3,16,10,3)/
     x 2.6193765D-05, 1.1852755D-04,-1.3136818D-09 /
      data fpppp( 3,16,11,1),fpppp( 3,16,11,2),fpppp( 3,16,11,3)/
     x-1.6453879D-04,-4.2927352D-04,-4.2629799D-07 /
      data fpppp( 3,16,12,1),fpppp( 3,16,12,2),fpppp( 3,16,12,3)/
     x 7.7298164D-03, 7.3536065D-04, 8.7271437D-07 /
      data fpppp( 3,16,13,1),fpppp( 3,16,13,2),fpppp( 3,16,13,3)/
     x-3.2059009D-03,-5.3851821D-04,-2.7891002D-07 /
      data fpppp( 3,16,14,1),fpppp( 3,16,14,2),fpppp( 3,16,14,3)/
     x-1.0740240D-03, 1.8336847D-04,-7.3573792D-08 /
      data fpppp( 3,16,15,1),fpppp( 3,16,15,2),fpppp( 3,16,15,3)/
     x-5.6217286D-04,-5.4661989D-05,-7.8639580D-08 /
      data fpppp( 3,16,16,1),fpppp( 3,16,16,2),fpppp( 3,16,16,3)/
     x-1.0740240D-03, 3.9186014D-05,-1.0988757D-07 /
      data fpppp( 3,16,17,1),fpppp( 3,16,17,2),fpppp( 3,16,17,3)/
     x-3.2059009D-03, 3.8211600D-05,-1.3365493D-07 /
      data fpppp( 3,17, 1,1),fpppp( 3,17, 1,2),fpppp( 3,17, 1,3)/
     x 1.0756029D-02,-1.2890608D-04,-6.0549122D-08 /
      data fpppp( 3,17, 2,1),fpppp( 3,17, 2,2),fpppp( 3,17, 2,3)/
     x 3.3401629D-03,-8.6004130D-05,-1.1765079D-07 /
      data fpppp( 3,17, 3,1),fpppp( 3,17, 3,2),fpppp( 3,17, 3,3)/
     x 1.7191038D-03, 6.2786548D-06,-1.0860620D-07 /
      data fpppp( 3,17, 4,1),fpppp( 3,17, 4,2),fpppp( 3,17, 4,3)/
     x 3.3401629D-03,-7.4271471D-05,-3.3107349D-07 /
      data fpppp( 3,17, 5,1),fpppp( 3,17, 5,2),fpppp( 3,17, 5,3)/
     x 1.0756029D-02,-1.7583672D-04, 7.9314171D-07 /
      data fpppp( 3,17, 6,1),fpppp( 3,17, 6,2),fpppp( 3,17, 6,3)/
     x 1.7803375D-03, 6.0857246D-04,-6.4676065D-07 /
      data fpppp( 3,17, 7,1),fpppp( 3,17, 7,2),fpppp( 3,17, 7,3)/
     x 7.4133645D-05,-4.2250891D-04, 3.9494295D-07 /
      data fpppp( 3,17, 8,1),fpppp( 3,17, 8,2),fpppp( 3,17, 8,3)/
     x-2.6860541D-04, 9.0261201D-05,-1.4818017D-07 /
      data fpppp( 3,17, 9,1),fpppp( 3,17, 9,2),fpppp( 3,17, 9,3)/
     x-2.7378668D-04,-5.6756335D-05,-5.1104945D-08 /
      data fpppp( 3,17,10,1),fpppp( 3,17,10,2),fpppp( 3,17,10,3)/
     x-2.6860541D-04, 9.0261201D-05,-1.4818017D-07 /
      data fpppp( 3,17,11,1),fpppp( 3,17,11,2),fpppp( 3,17,11,3)/
     x 7.4133645D-05,-4.2250891D-04, 3.9494295D-07 /
      data fpppp( 3,17,12,1),fpppp( 3,17,12,2),fpppp( 3,17,12,3)/
     x 1.7803375D-03, 6.0857246D-04,-6.4676065D-07 /
      data fpppp( 3,17,13,1),fpppp( 3,17,13,2),fpppp( 3,17,13,3)/
     x 1.0756029D-02,-1.7583672D-04, 7.9314171D-07 /
      data fpppp( 3,17,14,1),fpppp( 3,17,14,2),fpppp( 3,17,14,3)/
     x 3.3401629D-03,-7.4271471D-05,-3.3107349D-07 /
      data fpppp( 3,17,15,1),fpppp( 3,17,15,2),fpppp( 3,17,15,3)/
     x 1.7191038D-03, 6.2786548D-06,-1.0860620D-07 /
      data fpppp( 3,17,16,1),fpppp( 3,17,16,2),fpppp( 3,17,16,3)/
     x 3.3401629D-03,-8.6004130D-05,-1.1765079D-07 /
      data fpppp( 3,17,17,1),fpppp( 3,17,17,2),fpppp( 3,17,17,3)/
     x 1.0756029D-02,-1.2890608D-04,-6.0549122D-08 /
      data fpppp( 3,18, 1,1),fpppp( 3,18, 1,2),fpppp( 3,18, 1,3)/
     x-8.6037043D-03, 1.4997284D-04, 2.9653005D-07 /
      data fpppp( 3,18, 2,1),fpppp( 3,18, 2,2),fpppp( 3,18, 2,3)/
     x-3.0392981D-03, 1.7647051D-04, 2.2408676D-07 /
      data fpppp( 3,18, 3,1),fpppp( 3,18, 3,2),fpppp( 3,18, 3,3)/
     x-1.5929554D-03, 8.4680307D-06, 1.3001518D-08 /
      data fpppp( 3,18, 4,1),fpppp( 3,18, 4,2),fpppp( 3,18, 4,3)/
     x-3.0392981D-03, 5.2121610D-04, 2.8716309D-07 /
      data fpppp( 3,18, 5,1),fpppp( 3,18, 5,2),fpppp( 3,18, 5,3)/
     x-8.6037043D-03,-1.2290095D-03, 4.4224720D-08 /
      data fpppp( 3,18, 6,1),fpppp( 3,18, 6,2),fpppp( 3,18, 6,3)/
     x-1.1499858D-03, 9.0535000D-04,-4.5925322D-07 /
      data fpppp( 3,18, 7,1),fpppp( 3,18, 7,2),fpppp( 3,18, 7,3)/
     x 5.9036489D-04,-1.9031829D-04, 1.5069042D-07 /
      data fpppp( 3,18, 8,1),fpppp( 3,18, 8,2),fpppp( 3,18, 8,3)/
     x 4.7412845D-04, 3.4765054D-05,-2.0921129D-08 /
      data fpppp( 3,18, 9,1),fpppp( 3,18, 9,2),fpppp( 3,18, 9,3)/
     x 4.0069836D-04,-3.5017165D-05,-6.2965697D-09 /
      data fpppp( 3,18,10,1),fpppp( 3,18,10,2),fpppp( 3,18,10,3)/
     x 4.7412845D-04, 3.4765054D-05,-2.0921129D-08 /
      data fpppp( 3,18,11,1),fpppp( 3,18,11,2),fpppp( 3,18,11,3)/
     x 5.9036489D-04,-1.9031829D-04, 1.5069042D-07 /
      data fpppp( 3,18,12,1),fpppp( 3,18,12,2),fpppp( 3,18,12,3)/
     x-1.1499858D-03, 9.0535000D-04,-4.5925322D-07 /
      data fpppp( 3,18,13,1),fpppp( 3,18,13,2),fpppp( 3,18,13,3)/
     x-8.6037043D-03,-1.2290095D-03, 4.4224720D-08 /
      data fpppp( 3,18,14,1),fpppp( 3,18,14,2),fpppp( 3,18,14,3)/
     x-3.0392981D-03, 5.2121610D-04, 2.8716309D-07 /
      data fpppp( 3,18,15,1),fpppp( 3,18,15,2),fpppp( 3,18,15,3)/
     x-1.5929554D-03, 8.4680307D-06, 1.3001518D-08 /
      data fpppp( 3,18,16,1),fpppp( 3,18,16,2),fpppp( 3,18,16,3)/
     x-3.0392981D-03, 1.7647051D-04, 2.2408676D-07 /
      data fpppp( 3,18,17,1),fpppp( 3,18,17,2),fpppp( 3,18,17,3)/
     x-8.6037043D-03, 1.4997284D-04, 2.9653005D-07 /
      data fpppp( 3,19, 1,1),fpppp( 3,19, 1,2),fpppp( 3,19, 1,3)/
     x-1.8442963D-02, 3.9846506D-19, 5.7247398D-07 /
      data fpppp( 3,19, 2,1),fpppp( 3,19, 2,2),fpppp( 3,19, 2,3)/
     x-6.3348597D-03, 9.5142827D-19, 4.6596694D-07 /
      data fpppp( 3,19, 3,1),fpppp( 3,19, 3,2),fpppp( 3,19, 3,3)/
     x-3.3069186D-03, 1.4322035D-18, 9.1302280D-08 /
      data fpppp( 3,19, 4,1),fpppp( 3,19, 4,2),fpppp( 3,19, 4,3)/
     x-6.3348597D-03,-1.1689719D-18, 6.5518931D-07 /
      data fpppp( 3,19, 5,1),fpppp( 3,19, 5,2),fpppp( 3,19, 5,3)/
     x-1.8442963D-02,-4.3397824D-19,-1.8441549D-07 /
      data fpppp( 3,19, 6,1),fpppp( 3,19, 6,2),fpppp( 3,19, 6,3)/
     x-4.9429250D-03, 7.7514656D-19,-7.5945506D-07 /
      data fpppp( 3,19, 7,1),fpppp( 3,19, 7,2),fpppp( 3,19, 7,3)/
     x 1.0272936D-03, 5.0144851D-19, 2.1086460D-07 /
      data fpppp( 3,19, 8,1),fpppp( 3,19, 8,2),fpppp( 3,19, 8,3)/
     x 9.2042431D-04, 5.4910212D-19, 2.8016333D-08 /
      data fpppp( 3,19, 9,1),fpppp( 3,19, 9,2),fpppp( 3,19, 9,3)/
     x 7.9374221D-04, 6.5550119D-19, 3.9835400D-08 /
      data fpppp( 3,19,10,1),fpppp( 3,19,10,2),fpppp( 3,19,10,3)/
     x 9.2042431D-04,-1.5200637D-18, 2.8016333D-08 /
      data fpppp( 3,19,11,1),fpppp( 3,19,11,2),fpppp( 3,19,11,3)/
     x 1.0272936D-03,-6.4145498D-19, 2.1086460D-07 /
      data fpppp( 3,19,12,1),fpppp( 3,19,12,2),fpppp( 3,19,12,3)/
     x-4.9429250D-03, 6.5586982D-19,-7.5945506D-07 /
      data fpppp( 3,19,13,1),fpppp( 3,19,13,2),fpppp( 3,19,13,3)/
     x-1.8442963D-02,-1.0450902D-19,-1.8441549D-07 /
      data fpppp( 3,19,14,1),fpppp( 3,19,14,2),fpppp( 3,19,14,3)/
     x-6.3348597D-03,-5.8388132D-20, 6.5518931D-07 /
      data fpppp( 3,19,15,1),fpppp( 3,19,15,2),fpppp( 3,19,15,3)/
     x-3.3069186D-03,-4.1914046D-19, 9.1302280D-08 /
      data fpppp( 3,19,16,1),fpppp( 3,19,16,2),fpppp( 3,19,16,3)/
     x-6.3348597D-03, 5.0514644D-19, 4.6596694D-07 /
      data fpppp( 3,19,17,1),fpppp( 3,19,17,2),fpppp( 3,19,17,3)/
     x-1.8442963D-02,-2.7679007D-18, 5.7247398D-07 /
      data fpppp( 4, 1, 1,1),fpppp( 4, 1, 1,2),fpppp( 4, 1, 1,3)/
     x 9.4475537D-06,-2.1751716D-18,-2.2868603D-08 /
      data fpppp( 4, 1, 2,1),fpppp( 4, 1, 2,2),fpppp( 4, 1, 2,3)/
     x-9.2294629D-05,-1.2105390D-18, 2.1655611D-08 /
      data fpppp( 4, 1, 3,1),fpppp( 4, 1, 3,2),fpppp( 4, 1, 3,3)/
     x-3.1512255D-04, 4.9990081D-20, 1.2220690D-07 /
      data fpppp( 4, 1, 4,1),fpppp( 4, 1, 4,2),fpppp( 4, 1, 4,3)/
     x-9.2294629D-05,-9.4108921D-19, 2.6663426D-08 /
      data fpppp( 4, 1, 5,1),fpppp( 4, 1, 5,2),fpppp( 4, 1, 5,3)/
     x 9.4475537D-06, 8.5279285D-19,-4.2899864D-08 /
      data fpppp( 4, 1, 6,1),fpppp( 4, 1, 6,2),fpppp( 4, 1, 6,3)/
     x 5.7089991D-05,-1.1797670D-18,-1.0011028D-07 /
      data fpppp( 4, 1, 7,1),fpppp( 4, 1, 7,2),fpppp( 4, 1, 7,3)/
     x-2.4251572D-04,-1.2107699D-18, 3.9054444D-09 /
      data fpppp( 4, 1, 8,1),fpppp( 4, 1, 8,2),fpppp( 4, 1, 8,3)/
     x-1.2844487D-04,-1.0036825D-18, 2.5503496D-08 /
      data fpppp( 4, 1, 9,1),fpppp( 4, 1, 9,2),fpppp( 4, 1, 9,3)/
     x-1.2423811D-04,-2.5571240D-19, 5.2503285D-08 /
      data fpppp( 4, 1,10,1),fpppp( 4, 1,10,2),fpppp( 4, 1,10,3)/
     x-1.2844487D-04,-7.4518313D-20, 2.5503496D-08 /
      data fpppp( 4, 1,11,1),fpppp( 4, 1,11,2),fpppp( 4, 1,11,3)/
     x-2.4251572D-04, 4.5057896D-19, 3.9054444D-09 /
      data fpppp( 4, 1,12,1),fpppp( 4, 1,12,2),fpppp( 4, 1,12,3)/
     x 5.7089991D-05,-9.0892981D-19,-1.0011028D-07 /
      data fpppp( 4, 1,13,1),fpppp( 4, 1,13,2),fpppp( 4, 1,13,3)/
     x 9.4475537D-06, 8.6963596D-20,-4.2899864D-08 /
      data fpppp( 4, 1,14,1),fpppp( 4, 1,14,2),fpppp( 4, 1,14,3)/
     x-9.2294629D-05,-1.9737251D-18, 2.6663426D-08 /
      data fpppp( 4, 1,15,1),fpppp( 4, 1,15,2),fpppp( 4, 1,15,3)/
     x-3.1512255D-04, 4.7918925D-19, 1.2220690D-07 /
      data fpppp( 4, 1,16,1),fpppp( 4, 1,16,2),fpppp( 4, 1,16,3)/
     x-9.2294629D-05,-1.5607364D-18, 2.1655611D-08 /
      data fpppp( 4, 1,17,1),fpppp( 4, 1,17,2),fpppp( 4, 1,17,3)/
     x 9.4475537D-06,-4.4107630D-19,-2.2868603D-08 /
      data fpppp( 4, 2, 1,1),fpppp( 4, 2, 1,2),fpppp( 4, 2, 1,3)/
     x-4.6549592D-06, 2.1781266D-06,-9.2615680D-09 /
      data fpppp( 4, 2, 2,1),fpppp( 4, 2, 2,2),fpppp( 4, 2, 2,3)/
     x-1.8446570D-05, 3.3648968D-06, 9.1652137D-09 /
      data fpppp( 4, 2, 3,1),fpppp( 4, 2, 3,2),fpppp( 4, 2, 3,3)/
     x 2.7248519D-05, 5.5526976D-06, 4.9125899D-08 /
      data fpppp( 4, 2, 4,1),fpppp( 4, 2, 4,2),fpppp( 4, 2, 4,3)/
     x-1.8446570D-05, 4.2368912D-06, 1.3717921D-08 /
      data fpppp( 4, 2, 5,1),fpppp( 4, 2, 5,2),fpppp( 4, 2, 5,3)/
     x-4.6549592D-06,-1.3098513D-06,-2.7472399D-08 /
      data fpppp( 4, 2, 6,1),fpppp( 4, 2, 6,2),fpppp( 4, 2, 6,3)/
     x 9.1811820D-06,-6.0515371D-06,-2.4942381D-08 /
      data fpppp( 4, 2, 7,1),fpppp( 4, 2, 7,2),fpppp( 4, 2, 7,3)/
     x 1.3784157D-05,-2.5609491D-06,-1.3240355D-08 /
      data fpppp( 4, 2, 8,1),fpppp( 4, 2, 8,2),fpppp( 4, 2, 8,3)/
     x-5.6903404D-05, 1.6896702D-06, 1.8113808D-08 /
      data fpppp( 4, 2, 9,1),fpppp( 4, 2, 9,2),fpppp( 4, 2, 9,3)/
     x-6.4329806D-05, 2.5841871D-06, 1.9279697D-08 /
      data fpppp( 4, 2,10,1),fpppp( 4, 2,10,2),fpppp( 4, 2,10,3)/
     x-5.6903404D-05, 1.6896702D-06, 1.8113808D-08 /
      data fpppp( 4, 2,11,1),fpppp( 4, 2,11,2),fpppp( 4, 2,11,3)/
     x 1.3784157D-05,-2.5609491D-06,-1.3240355D-08 /
      data fpppp( 4, 2,12,1),fpppp( 4, 2,12,2),fpppp( 4, 2,12,3)/
     x 9.1811820D-06,-6.0515371D-06,-2.4942381D-08 /
      data fpppp( 4, 2,13,1),fpppp( 4, 2,13,2),fpppp( 4, 2,13,3)/
     x-4.6549592D-06,-1.3098513D-06,-2.7472399D-08 /
      data fpppp( 4, 2,14,1),fpppp( 4, 2,14,2),fpppp( 4, 2,14,3)/
     x-1.8446570D-05, 4.2368912D-06, 1.3717921D-08 /
      data fpppp( 4, 2,15,1),fpppp( 4, 2,15,2),fpppp( 4, 2,15,3)/
     x 2.7248519D-05, 5.5526976D-06, 4.9125899D-08 /
      data fpppp( 4, 2,16,1),fpppp( 4, 2,16,2),fpppp( 4, 2,16,3)/
     x-1.8446570D-05, 3.3648968D-06, 9.1652137D-09 /
      data fpppp( 4, 2,17,1),fpppp( 4, 2,17,2),fpppp( 4, 2,17,3)/
     x-4.6549592D-06, 2.1781266D-06,-9.2615680D-09 /
      data fpppp( 4, 3, 1,1),fpppp( 4, 3, 1,2),fpppp( 4, 3, 1,3)/
     x-6.3240789D-06, 1.9060722D-05,-3.4231275D-08 /
      data fpppp( 4, 3, 2,1),fpppp( 4, 3, 2,2),fpppp( 4, 3, 2,3)/
     x 1.1809192D-04, 1.3245007D-05,-1.9697499D-08 /
      data fpppp( 4, 3, 3,1),fpppp( 4, 3, 3,2),fpppp( 4, 3, 3,3)/
     x 3.5563294D-04,-4.1059198D-06, 1.8439789D-08 /
      data fpppp( 4, 3, 4,1),fpppp( 4, 3, 4,2),fpppp( 4, 3, 4,3)/
     x 1.1809192D-04, 1.8916394D-05,-2.6035218D-08 /
      data fpppp( 4, 3, 5,1),fpppp( 4, 3, 5,2),fpppp( 4, 3, 5,3)/
     x-6.3240789D-06,-3.6248260D-06,-8.8804013D-09 /
      data fpppp( 4, 3, 6,1),fpppp( 4, 3, 6,2),fpppp( 4, 3, 6,3)/
     x-4.9552499D-05,-1.5495641D-05, 3.3899353D-08 /
      data fpppp( 4, 3, 7,1),fpppp( 4, 3, 7,2),fpppp( 4, 3, 7,3)/
     x 1.2498416D-04,-9.0371453D-06, 1.9247635D-08 /
      data fpppp( 4, 3, 8,1),fpppp( 4, 3, 8,2),fpppp( 4, 3, 8,3)/
     x 6.8071603D-05, 9.2179180D-06,-2.1544917D-08 /
      data fpppp( 4, 3, 9,1),fpppp( 4, 3, 9,2),fpppp( 4, 3, 9,3)/
     x 4.2294467D-05, 5.0977510D-06,-1.2868979D-08 /
      data fpppp( 4, 3,10,1),fpppp( 4, 3,10,2),fpppp( 4, 3,10,3)/
     x 6.8071603D-05, 9.2179180D-06,-2.1544917D-08 /
      data fpppp( 4, 3,11,1),fpppp( 4, 3,11,2),fpppp( 4, 3,11,3)/
     x 1.2498416D-04,-9.0371453D-06, 1.9247635D-08 /
      data fpppp( 4, 3,12,1),fpppp( 4, 3,12,2),fpppp( 4, 3,12,3)/
     x-4.9552499D-05,-1.5495641D-05, 3.3899353D-08 /
      data fpppp( 4, 3,13,1),fpppp( 4, 3,13,2),fpppp( 4, 3,13,3)/
     x-6.3240789D-06,-3.6248260D-06,-8.8804013D-09 /
      data fpppp( 4, 3,14,1),fpppp( 4, 3,14,2),fpppp( 4, 3,14,3)/
     x 1.1809192D-04, 1.8916394D-05,-2.6035218D-08 /
      data fpppp( 4, 3,15,1),fpppp( 4, 3,15,2),fpppp( 4, 3,15,3)/
     x 3.5563294D-04,-4.1059198D-06, 1.8439789D-08 /
      data fpppp( 4, 3,16,1),fpppp( 4, 3,16,2),fpppp( 4, 3,16,3)/
     x 1.1809192D-04, 1.3245007D-05,-1.9697499D-08 /
      data fpppp( 4, 3,17,1),fpppp( 4, 3,17,2),fpppp( 4, 3,17,3)/
     x-6.3240789D-06, 1.9060722D-05,-3.4231275D-08 /
      data fpppp( 4, 4, 1,1),fpppp( 4, 4, 1,2),fpppp( 4, 4, 1,3)/
     x-5.1510075D-05, 1.3203110D-04, 7.5817614D-08 /
      data fpppp( 4, 4, 2,1),fpppp( 4, 4, 2,2),fpppp( 4, 4, 2,3)/
     x 3.5213896D-05, 6.0385861D-05, 8.7428929D-09 /
      data fpppp( 4, 4, 3,1),fpppp( 4, 4, 3,2),fpppp( 4, 4, 3,3)/
     x 7.3297061D-04,-1.3411535D-04,-1.6062844D-07 /
      data fpppp( 4, 4, 4,1),fpppp( 4, 4, 4,2),fpppp( 4, 4, 4,3)/
     x 3.5213896D-05, 1.0137933D-04, 2.8038364D-08 /
      data fpppp( 4, 4, 5,1),fpppp( 4, 4, 5,2),fpppp( 4, 4, 5,3)/
     x-5.1510075D-05,-3.1942755D-05,-1.3642695D-09 /
      data fpppp( 4, 4, 6,1),fpppp( 4, 4, 6,2),fpppp( 4, 4, 6,3)/
     x-7.0399128D-05, 5.4914175D-05, 1.4988265D-07 /
      data fpppp( 4, 4, 7,1),fpppp( 4, 4, 7,2),fpppp( 4, 4, 7,3)/
     x 7.4403373D-04,-1.2057617D-04,-1.2198264D-07 /
      data fpppp( 4, 4, 8,1),fpppp( 4, 4, 8,2),fpppp( 4, 4, 8,3)/
     x 6.0292114D-06, 7.3418571D-05, 5.1737988D-08 /
      data fpppp( 4, 4, 9,1),fpppp( 4, 4, 9,2),fpppp( 4, 4, 9,3)/
     x-1.4587166D-05,-1.3438703D-05,-4.8779845D-08 /
      data fpppp( 4, 4,10,1),fpppp( 4, 4,10,2),fpppp( 4, 4,10,3)/
     x 6.0292114D-06, 7.3418571D-05, 5.1737988D-08 /
      data fpppp( 4, 4,11,1),fpppp( 4, 4,11,2),fpppp( 4, 4,11,3)/
     x 7.4403373D-04,-1.2057617D-04,-1.2198264D-07 /
      data fpppp( 4, 4,12,1),fpppp( 4, 4,12,2),fpppp( 4, 4,12,3)/
     x-7.0399128D-05, 5.4914175D-05, 1.4988265D-07 /
      data fpppp( 4, 4,13,1),fpppp( 4, 4,13,2),fpppp( 4, 4,13,3)/
     x-5.1510075D-05,-3.1942755D-05,-1.3642695D-09 /
      data fpppp( 4, 4,14,1),fpppp( 4, 4,14,2),fpppp( 4, 4,14,3)/
     x 3.5213896D-05, 1.0137933D-04, 2.8038364D-08 /
      data fpppp( 4, 4,15,1),fpppp( 4, 4,15,2),fpppp( 4, 4,15,3)/
     x 7.3297061D-04,-1.3411535D-04,-1.6062844D-07 /
      data fpppp( 4, 4,16,1),fpppp( 4, 4,16,2),fpppp( 4, 4,16,3)/
     x 3.5213896D-05, 6.0385861D-05, 8.7428929D-09 /
      data fpppp( 4, 4,17,1),fpppp( 4, 4,17,2),fpppp( 4, 4,17,3)/
     x-5.1510075D-05, 1.3203110D-04, 7.5817614D-08 /
      data fpppp( 4, 5, 1,1),fpppp( 4, 5, 1,2),fpppp( 4, 5, 1,3)/
     x-1.8553106D-05, 3.5859507D-04,-1.8621819D-07 /
      data fpppp( 4, 5, 2,1),fpppp( 4, 5, 2,2),fpppp( 4, 5, 2,3)/
     x-1.5725386D-04, 1.5456543D-04,-1.0510272D-07 /
      data fpppp( 4, 5, 3,1),fpppp( 4, 5, 3,2),fpppp( 4, 5, 3,3)/
     x-1.3556825D-03,-3.9948120D-04, 1.3864755D-07 /
      data fpppp( 4, 5, 4,1),fpppp( 4, 5, 4,2),fpppp( 4, 5, 4,3)/
     x-1.5725386D-04, 2.7153158D-04,-1.8682397D-07 /
      data fpppp( 4, 5, 5,1),fpppp( 4, 5, 5,2),fpppp( 4, 5, 5,3)/
     x-1.8553106D-05,-1.0926956D-04, 1.4066680D-07 /
      data fpppp( 4, 5, 6,1),fpppp( 4, 5, 6,2),fpppp( 4, 5, 6,3)/
     x-1.0314377D-04, 2.4802971D-04,-1.1300153D-07 /
      data fpppp( 4, 5, 7,1),fpppp( 4, 5, 7,2),fpppp( 4, 5, 7,3)/
     x-1.3049854D-03,-4.0350676D-04, 1.9411988D-07 /
      data fpppp( 4, 5, 8,1),fpppp( 4, 5, 8,2),fpppp( 4, 5, 8,3)/
     x-1.5101808D-04, 2.4654757D-04,-1.4150331D-07 /
      data fpppp( 4, 5, 9,1),fpppp( 4, 5, 9,2),fpppp( 4, 5, 9,3)/
     x-2.0271891D-05,-8.7689525D-05, 6.0816496D-08 /
      data fpppp( 4, 5,10,1),fpppp( 4, 5,10,2),fpppp( 4, 5,10,3)/
     x-1.5101808D-04, 2.4654757D-04,-1.4150331D-07 /
      data fpppp( 4, 5,11,1),fpppp( 4, 5,11,2),fpppp( 4, 5,11,3)/
     x-1.3049854D-03,-4.0350676D-04, 1.9411988D-07 /
      data fpppp( 4, 5,12,1),fpppp( 4, 5,12,2),fpppp( 4, 5,12,3)/
     x-1.0314377D-04, 2.4802971D-04,-1.1300153D-07 /
      data fpppp( 4, 5,13,1),fpppp( 4, 5,13,2),fpppp( 4, 5,13,3)/
     x-1.8553106D-05,-1.0926956D-04, 1.4066680D-07 /
      data fpppp( 4, 5,14,1),fpppp( 4, 5,14,2),fpppp( 4, 5,14,3)/
     x-1.5725386D-04, 2.7153158D-04,-1.8682397D-07 /
      data fpppp( 4, 5,15,1),fpppp( 4, 5,15,2),fpppp( 4, 5,15,3)/
     x-1.3556825D-03,-3.9948120D-04, 1.3864755D-07 /
      data fpppp( 4, 5,16,1),fpppp( 4, 5,16,2),fpppp( 4, 5,16,3)/
     x-1.5725386D-04, 1.5456543D-04,-1.0510272D-07 /
      data fpppp( 4, 5,17,1),fpppp( 4, 5,17,2),fpppp( 4, 5,17,3)/
     x-1.8553106D-05, 3.5859507D-04,-1.8621819D-07 /
      data fpppp( 4, 6, 1,1),fpppp( 4, 6, 1,2),fpppp( 4, 6, 1,3)/
     x 2.6066401D-05, 2.9135848D-04, 7.5024422D-08 /
      data fpppp( 4, 6, 2,1),fpppp( 4, 6, 2,2),fpppp( 4, 6, 2,3)/
     x 2.0874533D-05, 1.2516738D-04, 1.9642773D-08 /
      data fpppp( 4, 6, 3,1),fpppp( 4, 6, 3,2),fpppp( 4, 6, 3,3)/
     x-4.1316853D-04,-3.2748379D-04,-1.1363022D-07 /
      data fpppp( 4, 6, 4,1),fpppp( 4, 6, 4,2),fpppp( 4, 6, 4,3)/
     x 2.0874533D-05, 2.2247526D-04, 2.5716496D-08 /
      data fpppp( 4, 6, 5,1),fpppp( 4, 6, 5,2),fpppp( 4, 6, 5,3)/
     x 2.6066401D-05,-9.7873060D-05, 5.0729530D-08 /
      data fpppp( 4, 6, 6,1),fpppp( 4, 6, 6,2),fpppp( 4, 6, 6,3)/
     x 6.2432816D-05, 2.1722101D-04,-2.9145426D-08 /
      data fpppp( 4, 6, 7,1),fpppp( 4, 6, 7,2),fpppp( 4, 6, 7,3)/
     x-3.6833696D-04,-3.3533241D-04, 9.4262971D-09 /
      data fpppp( 4, 6, 8,1),fpppp( 4, 6, 8,2),fpppp( 4, 6, 8,3)/
     x 3.2797229D-05, 2.0614797D-04,-7.5485133D-09 /
      data fpppp( 4, 6, 9,1),fpppp( 4, 6, 9,2),fpppp( 4, 6, 9,3)/
     x 5.6238671D-06,-8.1575772D-05, 1.6285741D-08 /
      data fpppp( 4, 6,10,1),fpppp( 4, 6,10,2),fpppp( 4, 6,10,3)/
     x 3.2797229D-05, 2.0614797D-04,-7.5485133D-09 /
      data fpppp( 4, 6,11,1),fpppp( 4, 6,11,2),fpppp( 4, 6,11,3)/
     x-3.6833696D-04,-3.3533241D-04, 9.4262971D-09 /
      data fpppp( 4, 6,12,1),fpppp( 4, 6,12,2),fpppp( 4, 6,12,3)/
     x 6.2432816D-05, 2.1722101D-04,-2.9145426D-08 /
      data fpppp( 4, 6,13,1),fpppp( 4, 6,13,2),fpppp( 4, 6,13,3)/
     x 2.6066401D-05,-9.7873060D-05, 5.0729530D-08 /
      data fpppp( 4, 6,14,1),fpppp( 4, 6,14,2),fpppp( 4, 6,14,3)/
     x 2.0874533D-05, 2.2247526D-04, 2.5716496D-08 /
      data fpppp( 4, 6,15,1),fpppp( 4, 6,15,2),fpppp( 4, 6,15,3)/
     x-4.1316853D-04,-3.2748379D-04,-1.1363022D-07 /
      data fpppp( 4, 6,16,1),fpppp( 4, 6,16,2),fpppp( 4, 6,16,3)/
     x 2.0874533D-05, 1.2516738D-04, 1.9642773D-08 /
      data fpppp( 4, 6,17,1),fpppp( 4, 6,17,2),fpppp( 4, 6,17,3)/
     x 2.6066401D-05, 2.9135848D-04, 7.5024422D-08 /
      data fpppp( 4, 7, 1,1),fpppp( 4, 7, 1,2),fpppp( 4, 7, 1,3)/
     x 2.5643460D-05, 7.1295926D-05, 2.6924048D-07 /
      data fpppp( 4, 7, 2,1),fpppp( 4, 7, 2,2),fpppp( 4, 7, 2,3)/
     x 7.5582468D-05, 3.0071711D-05, 1.2849168D-07 /
      data fpppp( 4, 7, 3,1),fpppp( 4, 7, 3,2),fpppp( 4, 7, 3,3)/
     x 7.2123649D-04,-8.2027451D-05,-2.6236685D-07 /
      data fpppp( 4, 7, 4,1),fpppp( 4, 7, 4,2),fpppp( 4, 7, 4,3)/
     x 7.5582468D-05, 5.3935706D-05, 2.2215865D-07 /
      data fpppp( 4, 7, 5,1),fpppp( 4, 7, 5,2),fpppp( 4, 7, 5,3)/
     x 2.5643460D-05,-2.4160052D-05,-1.0542743D-07 /
      data fpppp( 4, 7, 6,1),fpppp( 4, 7, 6,2),fpppp( 4, 7, 6,3)/
     x 8.6138698D-05, 5.7945189D-05, 7.3632570D-08 /
      data fpppp( 4, 7, 7,1),fpppp( 4, 7, 7,2),fpppp( 4, 7, 7,3)/
     x 7.2314293D-04,-8.3304580D-05,-1.4341989D-07 /
      data fpppp( 4, 7, 8,1),fpppp( 4, 7, 8,2),fpppp( 4, 7, 8,3)/
     x 5.4659229D-05, 4.5238972D-05, 1.2826731D-07 /
      data fpppp( 4, 7, 9,1),fpppp( 4, 7, 9,2),fpppp( 4, 7, 9,3)/
     x-1.6229898D-06,-1.3305685D-05,-7.2444436D-08 /
      data fpppp( 4, 7,10,1),fpppp( 4, 7,10,2),fpppp( 4, 7,10,3)/
     x 5.4659229D-05, 4.5238972D-05, 1.2826731D-07 /
      data fpppp( 4, 7,11,1),fpppp( 4, 7,11,2),fpppp( 4, 7,11,3)/
     x 7.2314293D-04,-8.3304580D-05,-1.4341989D-07 /
      data fpppp( 4, 7,12,1),fpppp( 4, 7,12,2),fpppp( 4, 7,12,3)/
     x 8.6138698D-05, 5.7945189D-05, 7.3632570D-08 /
      data fpppp( 4, 7,13,1),fpppp( 4, 7,13,2),fpppp( 4, 7,13,3)/
     x 2.5643460D-05,-2.4160052D-05,-1.0542743D-07 /
      data fpppp( 4, 7,14,1),fpppp( 4, 7,14,2),fpppp( 4, 7,14,3)/
     x 7.5582468D-05, 5.3935706D-05, 2.2215865D-07 /
      data fpppp( 4, 7,15,1),fpppp( 4, 7,15,2),fpppp( 4, 7,15,3)/
     x 7.2123649D-04,-8.2027451D-05,-2.6236685D-07 /
      data fpppp( 4, 7,16,1),fpppp( 4, 7,16,2),fpppp( 4, 7,16,3)/
     x 7.5582468D-05, 3.0071711D-05, 1.2849168D-07 /
      data fpppp( 4, 7,17,1),fpppp( 4, 7,17,2),fpppp( 4, 7,17,3)/
     x 2.5643460D-05, 7.1295926D-05, 2.6924048D-07 /
      data fpppp( 4, 8, 1,1),fpppp( 4, 8, 1,2),fpppp( 4, 8, 1,3)/
     x 1.6556327D-05, 9.8182184D-07,-8.2083891D-08 /
      data fpppp( 4, 8, 2,1),fpppp( 4, 8, 2,2),fpppp( 4, 8, 2,3)/
     x-3.5790487D-05,-1.3624492D-06,-1.0981035D-08 /
      data fpppp( 4, 8, 3,1),fpppp( 4, 8, 3,2),fpppp( 4, 8, 3,3)/
     x 7.3596576D-05,-5.8830624D-06, 1.6048138D-07 /
      data fpppp( 4, 8, 4,1),fpppp( 4, 8, 4,2),fpppp( 4, 8, 4,3)/
     x-3.5790487D-05,-2.7864779D-06,-1.9314664D-08 /
      data fpppp( 4, 8, 5,1),fpppp( 4, 8, 5,2),fpppp( 4, 8, 5,3)/
     x 1.6556327D-05, 6.6779366D-06,-4.8749372D-08 /
      data fpppp( 4, 8, 6,1),fpppp( 4, 8, 6,2),fpppp( 4, 8, 6,3)/
     x 2.7187816D-05, 6.2627581D-06,-6.5103119D-08 /
      data fpppp( 4, 8, 7,1),fpppp( 4, 8, 7,2),fpppp( 4, 8, 7,3)/
     x 6.1388136D-05,-1.1834339D-05, 5.2055854D-08 /
      data fpppp( 4, 8, 8,1),fpppp( 4, 8, 8,2),fpppp( 4, 8, 8,3)/
     x-1.7392022D-05,-1.3695342D-06, 9.4709570D-10 /
      data fpppp( 4, 8, 9,1),fpppp( 4, 8, 9,2),fpppp( 4, 8, 9,3)/
     x-1.5845594D-05, 1.1745037D-05,-1.5419092D-09 /
      data fpppp( 4, 8,10,1),fpppp( 4, 8,10,2),fpppp( 4, 8,10,3)/
     x-1.7392022D-05,-1.3695342D-06, 9.4709570D-10 /
      data fpppp( 4, 8,11,1),fpppp( 4, 8,11,2),fpppp( 4, 8,11,3)/
     x 6.1388136D-05,-1.1834339D-05, 5.2055854D-08 /
      data fpppp( 4, 8,12,1),fpppp( 4, 8,12,2),fpppp( 4, 8,12,3)/
     x 2.7187816D-05, 6.2627581D-06,-6.5103119D-08 /
      data fpppp( 4, 8,13,1),fpppp( 4, 8,13,2),fpppp( 4, 8,13,3)/
     x 1.6556327D-05, 6.6779366D-06,-4.8749372D-08 /
      data fpppp( 4, 8,14,1),fpppp( 4, 8,14,2),fpppp( 4, 8,14,3)/
     x-3.5790487D-05,-2.7864779D-06,-1.9314664D-08 /
      data fpppp( 4, 8,15,1),fpppp( 4, 8,15,2),fpppp( 4, 8,15,3)/
     x 7.3596576D-05,-5.8830624D-06, 1.6048138D-07 /
      data fpppp( 4, 8,16,1),fpppp( 4, 8,16,2),fpppp( 4, 8,16,3)/
     x-3.5790487D-05,-1.3624492D-06,-1.0981035D-08 /
      data fpppp( 4, 8,17,1),fpppp( 4, 8,17,2),fpppp( 4, 8,17,3)/
     x 1.6556327D-05, 9.8182184D-07,-8.2083891D-08 /
      data fpppp( 4, 9, 1,1),fpppp( 4, 9, 1,2),fpppp( 4, 9, 1,3)/
     x 1.0500549D-05, 6.7886438D-06,-9.5546866D-08 /
      data fpppp( 4, 9, 2,1),fpppp( 4, 9, 2,2),fpppp( 4, 9, 2,3)/
     x-3.5996273D-05, 1.7937748D-06,-2.1976970D-08 /
      data fpppp( 4, 9, 3,1),fpppp( 4, 9, 3,2),fpppp( 4, 9, 3,3)/
     x-1.1261906D-04,-9.4961868D-06, 1.6264100D-07 /
      data fpppp( 4, 9, 4,1),fpppp( 4, 9, 4,2),fpppp( 4, 9, 4,3)/
     x-3.5996273D-05, 1.2466761D-06,-4.1409279D-08 /
      data fpppp( 4, 9, 5,1),fpppp( 4, 9, 5,2),fpppp( 4, 9, 5,3)/
     x 1.0500549D-05, 8.9770388D-06,-1.7817626D-08 /
      data fpppp( 4, 9, 6,1),fpppp( 4, 9, 6,2),fpppp( 4, 9, 6,3)/
     x 1.7676478D-05,-2.6581247D-06,-6.4340649D-08 /
      data fpppp( 4, 9, 7,1),fpppp( 4, 9, 7,2),fpppp( 4, 9, 7,3)/
     x-6.5496358D-06,-1.1828928D-05, 2.5121233D-08 /
      data fpppp( 4, 9, 8,1),fpppp( 4, 9, 8,2),fpppp( 4, 9, 8,3)/
     x-1.2886892D-05, 1.8396239D-06, 6.7258021D-09 /
      data fpppp( 4, 9, 9,1),fpppp( 4, 9, 9,2),fpppp( 4, 9, 9,3)/
     x-5.3694919D-06, 1.4252432D-05, 1.7561325D-08 /
      data fpppp( 4, 9,10,1),fpppp( 4, 9,10,2),fpppp( 4, 9,10,3)/
     x-1.2886892D-05, 1.8396239D-06, 6.7258021D-09 /
      data fpppp( 4, 9,11,1),fpppp( 4, 9,11,2),fpppp( 4, 9,11,3)/
     x-6.5496358D-06,-1.1828928D-05, 2.5121233D-08 /
      data fpppp( 4, 9,12,1),fpppp( 4, 9,12,2),fpppp( 4, 9,12,3)/
     x 1.7676478D-05,-2.6581247D-06,-6.4340649D-08 /
      data fpppp( 4, 9,13,1),fpppp( 4, 9,13,2),fpppp( 4, 9,13,3)/
     x 1.0500549D-05, 8.9770388D-06,-1.7817626D-08 /
      data fpppp( 4, 9,14,1),fpppp( 4, 9,14,2),fpppp( 4, 9,14,3)/
     x-3.5996273D-05, 1.2466761D-06,-4.1409279D-08 /
      data fpppp( 4, 9,15,1),fpppp( 4, 9,15,2),fpppp( 4, 9,15,3)/
     x-1.1261906D-04,-9.4961868D-06, 1.6264100D-07 /
      data fpppp( 4, 9,16,1),fpppp( 4, 9,16,2),fpppp( 4, 9,16,3)/
     x-3.5996273D-05, 1.7937748D-06,-2.1976970D-08 /
      data fpppp( 4, 9,17,1),fpppp( 4, 9,17,2),fpppp( 4, 9,17,3)/
     x 1.0500549D-05, 6.7886438D-06,-9.5546866D-08 /
      data fpppp( 4,10, 1,1),fpppp( 4,10, 1,2),fpppp( 4,10, 1,3)/
     x 1.2749611D-05, 7.9972537D-06,-1.4925425D-09 /
      data fpppp( 4,10, 2,1),fpppp( 4,10, 2,2),fpppp( 4,10, 2,3)/
     x 1.2377158D-05, 4.8777681D-06, 1.1463372D-08 /
      data fpppp( 4,10, 3,1),fpppp( 4,10, 3,2),fpppp( 4,10, 3,3)/
     x 2.1254559D-05,-2.6133010D-06, 4.1900695D-08 /
      data fpppp( 4,10, 4,1),fpppp( 4,10, 4,2),fpppp( 4,10, 4,3)/
     x 1.2377158D-05, 5.1961719D-06, 1.1153090D-08 /
      data fpppp( 4,10, 5,1),fpppp( 4,10, 5,2),fpppp( 4,10, 5,3)/
     x 1.2749611D-05, 6.7236384D-06,-2.5141269D-10 /
      data fpppp( 4,10, 6,1),fpppp( 4,10, 6,2),fpppp( 4,10, 6,3)/
     x 2.3213747D-05,-1.4275030D-05,-7.1690433D-08 /
      data fpppp( 4,10, 7,1),fpppp( 4,10, 7,2),fpppp( 4,10, 7,3)/
     x-5.6523612D-06,-1.2194656D-05, 1.6395098D-08 /
      data fpppp( 4,10, 8,1),fpppp( 4,10, 8,2),fpppp( 4,10, 8,3)/
     x 1.1468994D-05, 9.7362922D-06, 1.5442300D-08 /
      data fpppp( 4,10, 9,1),fpppp( 4,10, 9,2),fpppp( 4,10, 9,3)/
     x 1.8058638D-05, 1.2293535D-05, 1.5950306D-08 /
      data fpppp( 4,10,10,1),fpppp( 4,10,10,2),fpppp( 4,10,10,3)/
     x 1.1468994D-05, 9.7362922D-06, 1.5442300D-08 /
      data fpppp( 4,10,11,1),fpppp( 4,10,11,2),fpppp( 4,10,11,3)/
     x-5.6523612D-06,-1.2194656D-05, 1.6395098D-08 /
      data fpppp( 4,10,12,1),fpppp( 4,10,12,2),fpppp( 4,10,12,3)/
     x 2.3213747D-05,-1.4275030D-05,-7.1690433D-08 /
      data fpppp( 4,10,13,1),fpppp( 4,10,13,2),fpppp( 4,10,13,3)/
     x 1.2749611D-05, 6.7236384D-06,-2.5141269D-10 /
      data fpppp( 4,10,14,1),fpppp( 4,10,14,2),fpppp( 4,10,14,3)/
     x 1.2377158D-05, 5.1961719D-06, 1.1153090D-08 /
      data fpppp( 4,10,15,1),fpppp( 4,10,15,2),fpppp( 4,10,15,3)/
     x 2.1254559D-05,-2.6133010D-06, 4.1900695D-08 /
      data fpppp( 4,10,16,1),fpppp( 4,10,16,2),fpppp( 4,10,16,3)/
     x 1.2377158D-05, 4.8777681D-06, 1.1463372D-08 /
      data fpppp( 4,10,17,1),fpppp( 4,10,17,2),fpppp( 4,10,17,3)/
     x 1.2749611D-05, 7.9972537D-06,-1.4925425D-09 /
      data fpppp( 4,11, 1,1),fpppp( 4,11, 1,2),fpppp( 4,11, 1,3)/
     x 1.0288391D-05, 8.3920553D-06, 2.8601887D-08 /
      data fpppp( 4,11, 2,1),fpppp( 4,11, 2,2),fpppp( 4,11, 2,3)/
     x 3.3124483D-05, 7.6972545D-06, 1.9787111D-08 /
      data fpppp( 4,11, 3,1),fpppp( 4,11, 3,2),fpppp( 4,11, 3,3)/
     x 4.8912405D-05, 6.1220065D-06,-1.4631513D-09 /
      data fpppp( 4,11, 4,1),fpppp( 4,11, 4,2),fpppp( 4,11, 4,3)/
     x 3.3124483D-05, 7.6283240D-06, 2.0810786D-08 /
      data fpppp( 4,11, 5,1),fpppp( 4,11, 5,2),fpppp( 4,11, 5,3)/
     x 1.0288391D-05, 8.6677773D-06, 2.4507186D-08 /
      data fpppp( 4,11, 6,1),fpppp( 4,11, 6,2),fpppp( 4,11, 6,3)/
     x 3.2658874D-05,-3.6025592D-05,-1.0132712D-07 /
      data fpppp( 4,11, 7,1),fpppp( 4,11, 7,2),fpppp( 4,11, 7,3)/
     x 8.0676974D-06,-2.4104841D-06, 4.1572471D-08 /
      data fpppp( 4,11, 8,1),fpppp( 4,11, 8,2),fpppp( 4,11, 8,3)/
     x 2.2420757D-05, 1.3920680D-05, 8.0381133D-09 /
      data fpppp( 4,11, 9,1),fpppp( 4,11, 9,2),fpppp( 4,11, 9,3)/
     x 2.2487104D-05, 1.0305094D-05, 1.4430891D-08 /
      data fpppp( 4,11,10,1),fpppp( 4,11,10,2),fpppp( 4,11,10,3)/
     x 2.2420757D-05, 1.3920680D-05, 8.0381133D-09 /
      data fpppp( 4,11,11,1),fpppp( 4,11,11,2),fpppp( 4,11,11,3)/
     x 8.0676974D-06,-2.4104841D-06, 4.1572471D-08 /
      data fpppp( 4,11,12,1),fpppp( 4,11,12,2),fpppp( 4,11,12,3)/
     x 3.2658874D-05,-3.6025592D-05,-1.0132712D-07 /
      data fpppp( 4,11,13,1),fpppp( 4,11,13,2),fpppp( 4,11,13,3)/
     x 1.0288391D-05, 8.6677773D-06, 2.4507186D-08 /
      data fpppp( 4,11,14,1),fpppp( 4,11,14,2),fpppp( 4,11,14,3)/
     x 3.3124483D-05, 7.6283240D-06, 2.0810786D-08 /
      data fpppp( 4,11,15,1),fpppp( 4,11,15,2),fpppp( 4,11,15,3)/
     x 4.8912405D-05, 6.1220065D-06,-1.4631513D-09 /
      data fpppp( 4,11,16,1),fpppp( 4,11,16,2),fpppp( 4,11,16,3)/
     x 3.3124483D-05, 7.6972545D-06, 1.9787111D-08 /
      data fpppp( 4,11,17,1),fpppp( 4,11,17,2),fpppp( 4,11,17,3)/
     x 1.0288391D-05, 8.3920553D-06, 2.8601887D-08 /
      data fpppp( 4,12, 1,1),fpppp( 4,12, 1,2),fpppp( 4,12, 1,3)/
     x 4.0125616D-05, 1.1228412D-05, 2.3508202D-08 /
      data fpppp( 4,12, 2,1),fpppp( 4,12, 2,2),fpppp( 4,12, 2,3)/
     x 3.0169814D-05, 1.0753577D-05, 1.3488437D-08 /
      data fpppp( 4,12, 3,1),fpppp( 4,12, 3,2),fpppp( 4,12, 3,3)/
     x 3.3869353D-05, 1.0880917D-05,-6.7123028D-09 /
      data fpppp( 4,12, 4,1),fpppp( 4,12, 4,2),fpppp( 4,12, 4,3)/
     x 3.0169814D-05, 8.9006441D-06, 8.7203653D-09 /
      data fpppp( 4,12, 5,1),fpppp( 4,12, 5,2),fpppp( 4,12, 5,3)/
     x 4.0125616D-05, 1.8640143D-05, 4.2580487D-08 /
      data fpppp( 4,12, 6,1),fpppp( 4,12, 6,2),fpppp( 4,12, 6,3)/
     x 3.3917407D-05,-6.9312120D-05,-1.1534896D-07 /
      data fpppp( 4,12, 7,1),fpppp( 4,12, 7,2),fpppp( 4,12, 7,3)/
     x 9.2586802D-06, 1.8197392D-05, 6.5188676D-08 /
      data fpppp( 4,12, 8,1),fpppp( 4,12, 8,2),fpppp( 4,12, 8,3)/
     x 1.9371373D-05, 1.2627976D-05,-5.1815122D-09 /
      data fpppp( 4,12, 9,1),fpppp( 4,12, 9,2),fpppp( 4,12, 9,3)/
     x 1.8870490D-05, 1.0702190D-05, 1.3999508D-08 /
      data fpppp( 4,12,10,1),fpppp( 4,12,10,2),fpppp( 4,12,10,3)/
     x 1.9371373D-05, 1.2627976D-05,-5.1815122D-09 /
      data fpppp( 4,12,11,1),fpppp( 4,12,11,2),fpppp( 4,12,11,3)/
     x 9.2586802D-06, 1.8197392D-05, 6.5188676D-08 /
      data fpppp( 4,12,12,1),fpppp( 4,12,12,2),fpppp( 4,12,12,3)/
     x 3.3917407D-05,-6.9312120D-05,-1.1534896D-07 /
      data fpppp( 4,12,13,1),fpppp( 4,12,13,2),fpppp( 4,12,13,3)/
     x 4.0125616D-05, 1.8640143D-05, 4.2580487D-08 /
      data fpppp( 4,12,14,1),fpppp( 4,12,14,2),fpppp( 4,12,14,3)/
     x 3.0169814D-05, 8.9006441D-06, 8.7203653D-09 /
      data fpppp( 4,12,15,1),fpppp( 4,12,15,2),fpppp( 4,12,15,3)/
     x 3.3869353D-05, 1.0880917D-05,-6.7123028D-09 /
      data fpppp( 4,12,16,1),fpppp( 4,12,16,2),fpppp( 4,12,16,3)/
     x 3.0169814D-05, 1.0753577D-05, 1.3488437D-08 /
      data fpppp( 4,12,17,1),fpppp( 4,12,17,2),fpppp( 4,12,17,3)/
     x 4.0125616D-05, 1.1228412D-05, 2.3508202D-08 /
      data fpppp( 4,13, 1,1),fpppp( 4,13, 1,2),fpppp( 4,13, 1,3)/
     x 7.3690166D-05, 1.9283228D-05, 1.1143761D-08 /
      data fpppp( 4,13, 2,1),fpppp( 4,13, 2,2),fpppp( 4,13, 2,3)/
     x 1.9387278D-05, 1.6297054D-05, 4.8955625D-09 /
      data fpppp( 4,13, 3,1),fpppp( 4,13, 3,2),fpppp( 4,13, 3,3)/
     x 2.6740093D-05, 1.2609291D-05,-7.6517711D-09 /
      data fpppp( 4,13, 4,1),fpppp( 4,13, 4,2),fpppp( 4,13, 4,3)/
     x 1.9387278D-05, 1.1377091D-05, 1.8478687D-09 /
      data fpppp( 4,13, 5,1),fpppp( 4,13, 5,2),fpppp( 4,13, 5,3)/
     x 7.3690166D-05, 3.8963083D-05, 2.3334536D-08 /
      data fpppp( 4,13, 6,1),fpppp( 4,13, 6,2),fpppp( 4,13, 6,3)/
     x 2.9787216D-04,-1.2849067D-04,-7.6911845D-08 /
      data fpppp( 4,13, 7,1),fpppp( 4,13, 7,2),fpppp( 4,13, 7,3)/
     x 2.1009042D-06, 6.0832007D-05, 7.3408347D-08 /
      data fpppp( 4,13, 8,1),fpppp( 4,13, 8,2),fpppp( 4,13, 8,3)/
     x 1.2898497D-05, 2.9646475D-06,-2.4379357D-08 /
      data fpppp( 4,13, 9,1),fpppp( 4,13, 9,2),fpppp( 4,13, 9,3)/
     x 1.4947280D-05, 1.5278399D-05, 1.2544724D-08 /
      data fpppp( 4,13,10,1),fpppp( 4,13,10,2),fpppp( 4,13,10,3)/
     x 1.2898497D-05, 2.9646475D-06,-2.4379357D-08 /
      data fpppp( 4,13,11,1),fpppp( 4,13,11,2),fpppp( 4,13,11,3)/
     x 2.1009042D-06, 6.0832007D-05, 7.3408347D-08 /
      data fpppp( 4,13,12,1),fpppp( 4,13,12,2),fpppp( 4,13,12,3)/
     x 2.9787216D-04,-1.2849067D-04,-7.6911845D-08 /
      data fpppp( 4,13,13,1),fpppp( 4,13,13,2),fpppp( 4,13,13,3)/
     x 7.3690166D-05, 3.8963083D-05, 2.3334536D-08 /
      data fpppp( 4,13,14,1),fpppp( 4,13,14,2),fpppp( 4,13,14,3)/
     x 1.9387278D-05, 1.1377091D-05, 1.8478687D-09 /
      data fpppp( 4,13,15,1),fpppp( 4,13,15,2),fpppp( 4,13,15,3)/
     x 2.6740093D-05, 1.2609291D-05,-7.6517711D-09 /
      data fpppp( 4,13,16,1),fpppp( 4,13,16,2),fpppp( 4,13,16,3)/
     x 1.9387278D-05, 1.6297054D-05, 4.8955625D-09 /
      data fpppp( 4,13,17,1),fpppp( 4,13,17,2),fpppp( 4,13,17,3)/
     x 7.3690166D-05, 1.9283228D-05, 1.1143761D-08 /
      data fpppp( 4,14, 1,1),fpppp( 4,14, 1,2),fpppp( 4,14, 1,3)/
     x 4.1220963D-04, 5.1815498D-05, 1.0275838D-08 /
      data fpppp( 4,14, 2,1),fpppp( 4,14, 2,2),fpppp( 4,14, 2,3)/
     x 1.2964933D-05, 3.6111531D-05, 2.0844810D-09 /
      data fpppp( 4,14, 3,1),fpppp( 4,14, 3,2),fpppp( 4,14, 3,3)/
     x 1.1202873D-05, 5.8607460D-06,-2.7060365D-08 /
      data fpppp( 4,14, 4,1),fpppp( 4,14, 4,2),fpppp( 4,14, 4,3)/
     x 1.2964933D-05, 2.6523827D-05, 1.7132002D-08 /
      data fpppp( 4,14, 5,1),fpppp( 4,14, 5,2),fpppp( 4,14, 5,3)/
     x 4.1220963D-04, 9.0166315D-05,-4.9914246D-08 /
      data fpppp( 4,14, 6,1),fpppp( 4,14, 6,2),fpppp( 4,14, 6,3)/
     x 4.6806043D-04,-2.8830973D-04, 3.3934958D-08 /
      data fpppp( 4,14, 7,1),fpppp( 4,14, 7,2),fpppp( 4,14, 7,3)/
     x-4.6253014D-06, 1.8328168D-04, 6.1819079D-08 /
      data fpppp( 4,14, 8,1),fpppp( 4,14, 8,2),fpppp( 4,14, 8,3)/
     x 1.0360842D-05,-3.1016320D-05,-5.1604244D-08 /
      data fpppp( 4,14, 9,1),fpppp( 4,14, 9,2),fpppp( 4,14, 9,3)/
     x 1.6412643D-05, 3.1249758D-05, 6.8331881D-09 /
      data fpppp( 4,14,10,1),fpppp( 4,14,10,2),fpppp( 4,14,10,3)/
     x 1.0360842D-05,-3.1016320D-05,-5.1604244D-08 /
      data fpppp( 4,14,11,1),fpppp( 4,14,11,2),fpppp( 4,14,11,3)/
     x-4.6253014D-06, 1.8328168D-04, 6.1819079D-08 /
      data fpppp( 4,14,12,1),fpppp( 4,14,12,2),fpppp( 4,14,12,3)/
     x 4.6806043D-04,-2.8830973D-04, 3.3934958D-08 /
      data fpppp( 4,14,13,1),fpppp( 4,14,13,2),fpppp( 4,14,13,3)/
     x 4.1220963D-04, 9.0166315D-05,-4.9914246D-08 /
      data fpppp( 4,14,14,1),fpppp( 4,14,14,2),fpppp( 4,14,14,3)/
     x 1.2964933D-05, 2.6523827D-05, 1.7132002D-08 /
      data fpppp( 4,14,15,1),fpppp( 4,14,15,2),fpppp( 4,14,15,3)/
     x 1.1202873D-05, 5.8607460D-06,-2.7060365D-08 /
      data fpppp( 4,14,16,1),fpppp( 4,14,16,2),fpppp( 4,14,16,3)/
     x 1.2964933D-05, 3.6111531D-05, 2.0844810D-09 /
      data fpppp( 4,14,17,1),fpppp( 4,14,17,2),fpppp( 4,14,17,3)/
     x 4.1220963D-04, 5.1815498D-05, 1.0275838D-08 /
      data fpppp( 4,15, 1,1),fpppp( 4,15, 1,2),fpppp( 4,15, 1,3)/
     x-8.8034204D-04, 1.1373221D-04,-1.4562471D-07 /
      data fpppp( 4,15, 2,1),fpppp( 4,15, 2,2),fpppp( 4,15, 2,3)/
     x 1.7084867D-05, 7.2940071D-05,-1.0628496D-07 /
      data fpppp( 4,15, 3,1),fpppp( 4,15, 3,2),fpppp( 4,15, 3,3)/
     x 5.2669785D-05,-1.0579132D-05,-2.3283291D-08 /
      data fpppp( 4,15, 4,1),fpppp( 4,15, 4,2),fpppp( 4,15, 4,3)/
     x 1.7084867D-05, 5.5446389D-05,-9.3098318D-08 /
      data fpppp( 4,15, 5,1),fpppp( 4,15, 5,2),fpppp( 4,15, 5,3)/
     x-8.8034204D-04, 1.8370694D-04,-1.9837126D-07 /
      data fpppp( 4,15, 6,1),fpppp( 4,15, 6,2),fpppp( 4,15, 6,3)/
     x-9.2895111D-05,-5.7779002D-04, 6.7574930D-07 /
      data fpppp( 4,15, 7,1),fpppp( 4,15, 7,2),fpppp( 4,15, 7,3)/
     x-3.5924877D-05, 4.0819711D-04,-3.6138008D-07 /
      data fpppp( 4,15, 8,1),fpppp( 4,15, 8,2),fpppp( 4,15, 8,3)/
     x 4.3243938D-06,-9.6250747D-05, 2.1440740D-08 /
      data fpppp( 4,15, 9,1),fpppp( 4,15, 9,2),fpppp( 4,15, 9,3)/
     x 1.0534673D-05, 6.1044164D-05,-6.3199679D-08 /
      data fpppp( 4,15,10,1),fpppp( 4,15,10,2),fpppp( 4,15,10,3)/
     x 4.3243938D-06,-9.6250747D-05, 2.1440740D-08 /
      data fpppp( 4,15,11,1),fpppp( 4,15,11,2),fpppp( 4,15,11,3)/
     x-3.5924877D-05, 4.0819711D-04,-3.6138008D-07 /
      data fpppp( 4,15,12,1),fpppp( 4,15,12,2),fpppp( 4,15,12,3)/
     x-9.2895111D-05,-5.7779002D-04, 6.7574930D-07 /
      data fpppp( 4,15,13,1),fpppp( 4,15,13,2),fpppp( 4,15,13,3)/
     x-8.8034204D-04, 1.8370694D-04,-1.9837126D-07 /
      data fpppp( 4,15,14,1),fpppp( 4,15,14,2),fpppp( 4,15,14,3)/
     x 1.7084867D-05, 5.5446389D-05,-9.3098318D-08 /
      data fpppp( 4,15,15,1),fpppp( 4,15,15,2),fpppp( 4,15,15,3)/
     x 5.2669785D-05,-1.0579132D-05,-2.3283291D-08 /
      data fpppp( 4,15,16,1),fpppp( 4,15,16,2),fpppp( 4,15,16,3)/
     x 1.7084867D-05, 7.2940071D-05,-1.0628496D-07 /
      data fpppp( 4,15,17,1),fpppp( 4,15,17,2),fpppp( 4,15,17,3)/
     x-8.8034204D-04, 1.1373221D-04,-1.4562471D-07 /
      data fpppp( 4,16, 1,1),fpppp( 4,16, 1,2),fpppp( 4,16, 1,3)/
     x 9.6641130D-04, 1.0709087D-04,-1.3742271D-07 /
      data fpppp( 4,16, 2,1),fpppp( 4,16, 2,2),fpppp( 4,16, 2,3)/
     x-7.3459637D-05, 6.3345152D-05,-1.1402657D-07 /
      data fpppp( 4,16, 3,1),fpppp( 4,16, 3,2),fpppp( 4,16, 3,3)/
     x-1.2050132D-04,-1.3289063D-06,-5.0793115D-08 /
      data fpppp( 4,16, 4,1),fpppp( 4,16, 4,2),fpppp( 4,16, 4,3)/
     x-7.3459637D-05, 7.2462352D-06,-1.2699024D-07 /
      data fpppp( 4,16, 5,1),fpppp( 4,16, 5,2),fpppp( 4,16, 5,3)/
     x 9.6641130D-04, 3.3148653D-04,-8.5568004D-08 /
      data fpppp( 4,16, 6,1),fpppp( 4,16, 6,2),fpppp( 4,16, 6,3)/
     x-2.4804291D-03,-7.9494902D-04, 5.6498857D-07 /
      data fpppp( 4,16, 7,1),fpppp( 4,16, 7,2),fpppp( 4,16, 7,3)/
     x-6.1493151D-05, 5.5795877D-04,-2.6493432D-07 /
      data fpppp( 4,16, 8,1),fpppp( 4,16, 8,2),fpppp( 4,16, 8,3)/
     x 2.0627298D-05,-1.4608326D-04,-2.5377121D-08 /
      data fpppp( 4,16, 9,1),fpppp( 4,16, 9,2),fpppp( 4,16, 9,3)/
     x 3.4320979D-05, 8.0660581D-05,-7.5605267D-08 /
      data fpppp( 4,16,10,1),fpppp( 4,16,10,2),fpppp( 4,16,10,3)/
     x 2.0627298D-05,-1.4608326D-04,-2.5377121D-08 /
      data fpppp( 4,16,11,1),fpppp( 4,16,11,2),fpppp( 4,16,11,3)/
     x-6.1493151D-05, 5.5795877D-04,-2.6493432D-07 /
      data fpppp( 4,16,12,1),fpppp( 4,16,12,2),fpppp( 4,16,12,3)/
     x-2.4804291D-03,-7.9494902D-04, 5.6498857D-07 /
      data fpppp( 4,16,13,1),fpppp( 4,16,13,2),fpppp( 4,16,13,3)/
     x 9.6641130D-04, 3.3148653D-04,-8.5568004D-08 /
      data fpppp( 4,16,14,1),fpppp( 4,16,14,2),fpppp( 4,16,14,3)/
     x-7.3459637D-05, 7.2462352D-06,-1.2699024D-07 /
      data fpppp( 4,16,15,1),fpppp( 4,16,15,2),fpppp( 4,16,15,3)/
     x-1.2050132D-04,-1.3289063D-06,-5.0793115D-08 /
      data fpppp( 4,16,16,1),fpppp( 4,16,16,2),fpppp( 4,16,16,3)/
     x-7.3459637D-05, 6.3345152D-05,-1.1402657D-07 /
      data fpppp( 4,16,17,1),fpppp( 4,16,17,2),fpppp( 4,16,17,3)/
     x 9.6641130D-04, 1.0709087D-04,-1.3742271D-07 /
      data fpppp( 4,17, 1,1),fpppp( 4,17, 1,2),fpppp( 4,17, 1,3)/
     x-1.4926493D-03, 1.2627473D-04, 2.9871399D-08 /
      data fpppp( 4,17, 2,1),fpppp( 4,17, 2,2),fpppp( 4,17, 2,3)/
     x 6.8208224D-04, 8.6472964D-05,-4.8313802D-08 /
      data fpppp( 4,17, 3,1),fpppp( 4,17, 3,2),fpppp( 4,17, 3,3)/
     x 7.3683338D-04,-3.8850976D-05,-1.5339999D-07 /
      data fpppp( 4,17, 4,1),fpppp( 4,17, 4,2),fpppp( 4,17, 4,3)/
     x 6.8208224D-04, 1.3515268D-04,-1.6433273D-07 /
      data fpppp( 4,17, 5,1),fpppp( 4,17, 5,2),fpppp( 4,17, 5,3)/
     x-1.4926493D-03,-6.8444135D-05, 4.9394711D-07 /
      data fpppp( 4,17, 6,1),fpppp( 4,17, 6,2),fpppp( 4,17, 6,3)/
     x 1.4006152D-03,-2.4114859D-04,-3.4240689D-07 /
      data fpppp( 4,17, 7,1),fpppp( 4,17, 7,2),fpppp( 4,17, 7,3)/
     x 2.4028341D-04, 2.4704094D-04, 2.1994672D-07 /
      data fpppp( 4,17, 8,1),fpppp( 4,17, 8,2),fpppp( 4,17, 8,3)/
     x-3.7627183D-05,-6.6553026D-05,-1.0750635D-07 /
      data fpppp( 4,17, 9,1),fpppp( 4,17, 9,2),fpppp( 4,17, 9,3)/
     x-8.5524415D-05, 3.4868526D-05,-6.5232203D-08 /
      data fpppp( 4,17,10,1),fpppp( 4,17,10,2),fpppp( 4,17,10,3)/
     x-3.7627183D-05,-6.6553026D-05,-1.0750635D-07 /
      data fpppp( 4,17,11,1),fpppp( 4,17,11,2),fpppp( 4,17,11,3)/
     x 2.4028341D-04, 2.4704094D-04, 2.1994672D-07 /
      data fpppp( 4,17,12,1),fpppp( 4,17,12,2),fpppp( 4,17,12,3)/
     x 1.4006152D-03,-2.4114859D-04,-3.4240689D-07 /
      data fpppp( 4,17,13,1),fpppp( 4,17,13,2),fpppp( 4,17,13,3)/
     x-1.4926493D-03,-6.8444135D-05, 4.9394711D-07 /
      data fpppp( 4,17,14,1),fpppp( 4,17,14,2),fpppp( 4,17,14,3)/
     x 6.8208224D-04, 1.3515268D-04,-1.6433273D-07 /
      data fpppp( 4,17,15,1),fpppp( 4,17,15,2),fpppp( 4,17,15,3)/
     x 7.3683338D-04,-3.8850976D-05,-1.5339999D-07 /
      data fpppp( 4,17,16,1),fpppp( 4,17,16,2),fpppp( 4,17,16,3)/
     x 6.8208224D-04, 8.6472964D-05,-4.8313802D-08 /
      data fpppp( 4,17,17,1),fpppp( 4,17,17,2),fpppp( 4,17,17,3)/
     x-1.4926493D-03, 1.2627473D-04, 2.9871399D-08 /
      data fpppp( 4,18, 1,1),fpppp( 4,18, 1,2),fpppp( 4,18, 1,3)/
     x 8.1054073D-04,-5.4984817D-05, 1.7840674D-07 /
      data fpppp( 4,18, 2,1),fpppp( 4,18, 2,2),fpppp( 4,18, 2,3)/
     x-6.5640694D-04,-3.5969869D-05, 1.5537585D-07 /
      data fpppp( 4,18, 3,1),fpppp( 4,18, 3,2),fpppp( 4,18, 3,3)/
     x-6.6705484D-04, 3.6264870D-05, 6.5907142D-08 /
      data fpppp( 4,18, 4,1),fpppp( 4,18, 4,2),fpppp( 4,18, 4,3)/
     x-6.5640694D-04,-7.7769658D-05, 2.0897077D-07 /
      data fpppp( 4,18, 5,1),fpppp( 4,18, 5,2),fpppp( 4,18, 5,3)/
     x 8.1054073D-04, 1.1221434D-04,-3.5972948D-08 /
      data fpppp( 4,18, 6,1),fpppp( 4,18, 6,2),fpppp( 4,18, 6,3)/
     x 2.2853331D-04,-1.4261840D-04,-3.0680054D-07 /
      data fpppp( 4,18, 7,1),fpppp( 4,18, 7,2),fpppp( 4,18, 7,3)/
     x 2.5385556D-04, 9.4250555D-05, 1.0185810D-07 /
      data fpppp( 4,18, 8,1),fpppp( 4,18, 8,2),fpppp( 4,18, 8,3)/
     x 4.4825782D-04,-1.2934619D-05, 5.7594977D-09 /
      data fpppp( 4,18, 9,1),fpppp( 4,18, 9,2),fpppp( 4,18, 9,3)/
     x 4.7402291D-04, 1.0484059D-05,-4.6044022D-09 /
      data fpppp( 4,18,10,1),fpppp( 4,18,10,2),fpppp( 4,18,10,3)/
     x 4.4825782D-04,-1.2934619D-05, 5.7594977D-09 /
      data fpppp( 4,18,11,1),fpppp( 4,18,11,2),fpppp( 4,18,11,3)/
     x 2.5385556D-04, 9.4250555D-05, 1.0185810D-07 /
      data fpppp( 4,18,12,1),fpppp( 4,18,12,2),fpppp( 4,18,12,3)/
     x 2.2853331D-04,-1.4261840D-04,-3.0680054D-07 /
      data fpppp( 4,18,13,1),fpppp( 4,18,13,2),fpppp( 4,18,13,3)/
     x 8.1054073D-04, 1.1221434D-04,-3.5972948D-08 /
      data fpppp( 4,18,14,1),fpppp( 4,18,14,2),fpppp( 4,18,14,3)/
     x-6.5640694D-04,-7.7769658D-05, 2.0897077D-07 /
      data fpppp( 4,18,15,1),fpppp( 4,18,15,2),fpppp( 4,18,15,3)/
     x-6.6705484D-04, 3.6264870D-05, 6.5907142D-08 /
      data fpppp( 4,18,16,1),fpppp( 4,18,16,2),fpppp( 4,18,16,3)/
     x-6.5640694D-04,-3.5969869D-05, 1.5537585D-07 /
      data fpppp( 4,18,17,1),fpppp( 4,18,17,2),fpppp( 4,18,17,3)/
     x 8.1054073D-04,-5.4984817D-05, 1.7840674D-07 /
      data fpppp( 4,19, 1,1),fpppp( 4,19, 1,2),fpppp( 4,19, 1,3)/
     x 1.7530878D-03,-1.5555361D-18, 3.3230173D-07 /
      data fpppp( 4,19, 2,1),fpppp( 4,19, 2,2),fpppp( 4,19, 2,3)/
     x-1.3966015D-03, 3.8679377D-19, 3.1964353D-07 /
      data fpppp( 4,19, 3,1),fpppp( 4,19, 3,2),fpppp( 4,19, 3,3)/
     x-1.4248794D-03,-4.3859642D-20, 1.9323884D-07 /
      data fpppp( 4,19, 4,1),fpppp( 4,19, 4,2),fpppp( 4,19, 4,3)/
     x-1.3966015D-03, 9.1585977D-19, 4.6494685D-07 /
      data fpppp( 4,19, 5,1),fpppp( 4,19, 5,2),fpppp( 4,19, 5,3)/
     x 1.7530878D-03, 2.2795110D-20,-2.4891153D-07 /
      data fpppp( 4,19, 6,1),fpppp( 4,19, 6,2),fpppp( 4,19, 6,3)/
     x 5.0020177D-04, 2.5867753D-20,-5.4062329D-07 /
      data fpppp( 4,19, 7,1),fpppp( 4,19, 7,2),fpppp( 4,19, 7,3)/
     x 3.4977183D-04,-5.0920893D-19, 1.5604652D-07 /
      data fpppp( 4,19, 8,1),fpppp( 4,19, 8,2),fpppp( 4,19, 8,3)/
     x 7.7867440D-04, 2.6996503D-19, 6.3198182D-08 /
      data fpppp( 4,19, 9,1),fpppp( 4,19, 9,2),fpppp( 4,19, 9,3)/
     x 8.3945803D-04,-6.3200049D-19, 4.1664902D-08 /
      data fpppp( 4,19,10,1),fpppp( 4,19,10,2),fpppp( 4,19,10,3)/
     x 7.7867440D-04, 6.5352031D-19, 6.3198182D-08 /
      data fpppp( 4,19,11,1),fpppp( 4,19,11,2),fpppp( 4,19,11,3)/
     x 3.4977183D-04, 4.5484761D-19, 1.5604652D-07 /
      data fpppp( 4,19,12,1),fpppp( 4,19,12,2),fpppp( 4,19,12,3)/
     x 5.0020177D-04,-8.8283685D-19,-5.4062329D-07 /
      data fpppp( 4,19,13,1),fpppp( 4,19,13,2),fpppp( 4,19,13,3)/
     x 1.7530878D-03,-7.1792629D-19,-2.4891153D-07 /
      data fpppp( 4,19,14,1),fpppp( 4,19,14,2),fpppp( 4,19,14,3)/
     x-1.3966015D-03, 2.5836442D-20, 4.6494685D-07 /
      data fpppp( 4,19,15,1),fpppp( 4,19,15,2),fpppp( 4,19,15,3)/
     x-1.4248794D-03,-2.7266187D-19, 1.9323884D-07 /
      data fpppp( 4,19,16,1),fpppp( 4,19,16,2),fpppp( 4,19,16,3)/
     x-1.3966015D-03, 6.4295518D-19, 3.1964353D-07 /
      data fpppp( 4,19,17,1),fpppp( 4,19,17,2),fpppp( 4,19,17,3)/
     x 1.7530878D-03, 4.1371466D-19, 3.3230173D-07 /
      data fpppp( 5, 1, 1,1),fpppp( 5, 1, 1,2),fpppp( 5, 1, 1,3)/
     x 6.6934532D-06, 1.2552357D-18,-8.6279430D-10 /
      data fpppp( 5, 1, 2,1),fpppp( 5, 1, 2,2),fpppp( 5, 1, 2,3)/
     x-7.3944853D-05, 8.7740638D-19, 2.4053627D-08 /
      data fpppp( 5, 1, 3,1),fpppp( 5, 1, 3,2),fpppp( 5, 1, 3,3)/
     x-1.8980616D-04,-6.1980375D-20, 7.5886034D-08 /
      data fpppp( 5, 1, 4,1),fpppp( 5, 1, 4,2),fpppp( 5, 1, 4,3)/
     x-7.3944853D-05, 4.4216960D-19, 3.3512493D-08 /
      data fpppp( 5, 1, 5,1),fpppp( 5, 1, 5,2),fpppp( 5, 1, 5,3)/
     x 6.6934532D-06,-6.5637048D-19,-3.8698257D-08 /
      data fpppp( 5, 1, 6,1),fpppp( 5, 1, 6,2),fpppp( 5, 1, 6,3)/
     x 3.8733646D-05, 1.3254766D-18,-6.2979806D-08 /
      data fpppp( 5, 1, 7,1),fpppp( 5, 1, 7,2),fpppp( 5, 1, 7,3)/
     x-9.1333251D-05, 7.2581903D-19,-1.8964272D-08 /
      data fpppp( 5, 1, 8,1),fpppp( 5, 1, 8,2),fpppp( 5, 1, 8,3)/
     x-7.5685607D-05, 6.3910392D-19, 2.9463196D-08 /
      data fpppp( 5, 1, 9,1),fpppp( 5, 1, 9,2),fpppp( 5, 1, 9,3)/
     x-8.1353163D-05, 4.1821552D-19, 4.1023734D-08 /
      data fpppp( 5, 1,10,1),fpppp( 5, 1,10,2),fpppp( 5, 1,10,3)/
     x-7.5685607D-05,-5.9296947D-19, 2.9463196D-08 /
      data fpppp( 5, 1,11,1),fpppp( 5, 1,11,2),fpppp( 5, 1,11,3)/
     x-9.1333251D-05,-7.9977614D-19,-1.8964272D-08 /
      data fpppp( 5, 1,12,1),fpppp( 5, 1,12,2),fpppp( 5, 1,12,3)/
     x 3.8733646D-05, 7.1702327D-19,-6.2979806D-08 /
      data fpppp( 5, 1,13,1),fpppp( 5, 1,13,2),fpppp( 5, 1,13,3)/
     x 6.6934532D-06,-7.8597027D-19,-3.8698257D-08 /
      data fpppp( 5, 1,14,1),fpppp( 5, 1,14,2),fpppp( 5, 1,14,3)/
     x-7.3944853D-05, 6.0934786D-19, 3.3512493D-08 /
      data fpppp( 5, 1,15,1),fpppp( 5, 1,15,2),fpppp( 5, 1,15,3)/
     x-1.8980616D-04,-2.5986745D-19, 7.5886034D-08 /
      data fpppp( 5, 1,16,1),fpppp( 5, 1,16,2),fpppp( 5, 1,16,3)/
     x-7.3944853D-05, 6.3523490D-19, 2.4053627D-08 /
      data fpppp( 5, 1,17,1),fpppp( 5, 1,17,2),fpppp( 5, 1,17,3)/
     x 6.6934532D-06, 1.5796734D-18,-8.6279430D-10 /
      data fpppp( 5, 2, 1,1),fpppp( 5, 2, 1,2),fpppp( 5, 2, 1,3)/
     x-6.9107282D-06, 8.1187823D-07,-1.2593546D-08 /
      data fpppp( 5, 2, 2,1),fpppp( 5, 2, 2,2),fpppp( 5, 2, 2,3)/
     x-2.6909321D-05, 2.0496885D-06, 5.0587920D-09 /
      data fpppp( 5, 2, 3,1),fpppp( 5, 2, 3,2),fpppp( 5, 2, 3,3)/
     x-1.5606230D-05, 4.5289869D-06, 4.5022879D-08 /
      data fpppp( 5, 2, 4,1),fpppp( 5, 2, 4,2),fpppp( 5, 2, 4,3)/
     x-2.6909321D-05, 2.6630771D-06, 6.8958448D-09 /
      data fpppp( 5, 2, 5,1),fpppp( 5, 2, 5,2),fpppp( 5, 2, 5,3)/
     x-6.9107282D-06,-1.6416761D-06,-1.9941757D-08 /
      data fpppp( 5, 2, 6,1),fpppp( 5, 2, 6,2),fpppp( 5, 2, 6,3)/
     x 4.3913288D-07,-3.6383105D-06,-2.1228137D-08 /
      data fpppp( 5, 2, 7,1),fpppp( 5, 2, 7,2),fpppp( 5, 2, 7,3)/
     x-4.3512953D-06,-1.3442850D-06,-8.5288575D-09 /
      data fpppp( 5, 2, 8,1),fpppp( 5, 2, 8,2),fpppp( 5, 2, 8,3)/
     x-4.1129384D-05, 9.9170820D-07, 1.1110960D-08 /
      data fpppp( 5, 2, 9,1),fpppp( 5, 2, 9,2),fpppp( 5, 2, 9,3)/
     x-4.6110649D-05, 1.5122171D-06, 1.8667189D-08 /
      data fpppp( 5, 2,10,1),fpppp( 5, 2,10,2),fpppp( 5, 2,10,3)/
     x-4.1129384D-05, 9.9170820D-07, 1.1110960D-08 /
      data fpppp( 5, 2,11,1),fpppp( 5, 2,11,2),fpppp( 5, 2,11,3)/
     x-4.3512953D-06,-1.3442850D-06,-8.5288575D-09 /
      data fpppp( 5, 2,12,1),fpppp( 5, 2,12,2),fpppp( 5, 2,12,3)/
     x 4.3913288D-07,-3.6383105D-06,-2.1228137D-08 /
      data fpppp( 5, 2,13,1),fpppp( 5, 2,13,2),fpppp( 5, 2,13,3)/
     x-6.9107282D-06,-1.6416761D-06,-1.9941757D-08 /
      data fpppp( 5, 2,14,1),fpppp( 5, 2,14,2),fpppp( 5, 2,14,3)/
     x-2.6909321D-05, 2.6630771D-06, 6.8958448D-09 /
      data fpppp( 5, 2,15,1),fpppp( 5, 2,15,2),fpppp( 5, 2,15,3)/
     x-1.5606230D-05, 4.5289869D-06, 4.5022879D-08 /
      data fpppp( 5, 2,16,1),fpppp( 5, 2,16,2),fpppp( 5, 2,16,3)/
     x-2.6909321D-05, 2.0496885D-06, 5.0587920D-09 /
      data fpppp( 5, 2,17,1),fpppp( 5, 2,17,2),fpppp( 5, 2,17,3)/
     x-6.9107282D-06, 8.1187823D-07,-1.2593546D-08 /
      data fpppp( 5, 3, 1,1),fpppp( 5, 3, 1,2),fpppp( 5, 3, 1,3)/
     x-1.8442958D-05, 8.5248696D-06,-4.9254733D-08 /
      data fpppp( 5, 3, 2,1),fpppp( 5, 3, 2,2),fpppp( 5, 3, 2,3)/
     x 5.0279495D-05, 7.7761689D-06,-2.3632040D-08 /
      data fpppp( 5, 3, 3,1),fpppp( 5, 3, 3,2),fpppp( 5, 3, 3,3)/
     x 1.7474132D-04, 3.6411486D-06, 4.3607140D-08 /
      data fpppp( 5, 3, 4,1),fpppp( 5, 3, 4,2),fpppp( 5, 3, 4,3)/
     x 5.0279495D-05, 1.1358247D-05,-3.4811385D-08 /
      data fpppp( 5, 3, 5,1),fpppp( 5, 3, 5,2),fpppp( 5, 3, 5,3)/
     x-1.8442958D-05,-5.8034418D-06,-4.5373545D-09 /
      data fpppp( 5, 3, 6,1),fpppp( 5, 3, 6,2),fpppp( 5, 3, 6,3)/
     x-4.2849229D-05,-9.3257836D-06, 1.7178421D-08 /
      data fpppp( 5, 3, 7,1),fpppp( 5, 3, 7,2),fpppp( 5, 3, 7,3)/
     x 2.7442603D-05,-4.8574014D-06, 2.4218068D-08 /
      data fpppp( 5, 3, 8,1),fpppp( 5, 3, 8,2),fpppp( 5, 3, 8,3)/
     x 1.6423419D-05, 5.6471139D-06,-2.0186571D-08 /
      data fpppp( 5, 3, 9,1),fpppp( 5, 3, 9,2),fpppp( 5, 3, 9,3)/
     x 1.0951433D-05, 2.9183967D-06,-9.1927220D-09 /
      data fpppp( 5, 3,10,1),fpppp( 5, 3,10,2),fpppp( 5, 3,10,3)/
     x 1.6423419D-05, 5.6471139D-06,-2.0186571D-08 /
      data fpppp( 5, 3,11,1),fpppp( 5, 3,11,2),fpppp( 5, 3,11,3)/
     x 2.7442603D-05,-4.8574014D-06, 2.4218068D-08 /
      data fpppp( 5, 3,12,1),fpppp( 5, 3,12,2),fpppp( 5, 3,12,3)/
     x-4.2849229D-05,-9.3257836D-06, 1.7178421D-08 /
      data fpppp( 5, 3,13,1),fpppp( 5, 3,13,2),fpppp( 5, 3,13,3)/
     x-1.8442958D-05,-5.8034418D-06,-4.5373545D-09 /
      data fpppp( 5, 3,14,1),fpppp( 5, 3,14,2),fpppp( 5, 3,14,3)/
     x 5.0279495D-05, 1.1358247D-05,-3.4811385D-08 /
      data fpppp( 5, 3,15,1),fpppp( 5, 3,15,2),fpppp( 5, 3,15,3)/
     x 1.7474132D-04, 3.6411486D-06, 4.3607140D-08 /
      data fpppp( 5, 3,16,1),fpppp( 5, 3,16,2),fpppp( 5, 3,16,3)/
     x 5.0279495D-05, 7.7761689D-06,-2.3632040D-08 /
      data fpppp( 5, 3,17,1),fpppp( 5, 3,17,2),fpppp( 5, 3,17,3)/
     x-1.8442958D-05, 8.5248696D-06,-4.9254733D-08 /
      data fpppp( 5, 4, 1,1),fpppp( 5, 4, 1,2),fpppp( 5, 4, 1,3)/
     x-3.7227018D-05, 5.9794147D-05, 1.3406043D-09 /
      data fpppp( 5, 4, 2,1),fpppp( 5, 4, 2,2),fpppp( 5, 4, 2,3)/
     x 2.1931819D-05, 2.9943164D-05,-1.8386883D-08 /
      data fpppp( 5, 4, 3,1),fpppp( 5, 4, 3,2),fpppp( 5, 4, 3,3)/
     x 3.0857221D-04,-5.3038287D-05,-6.0874557D-08 /
      data fpppp( 5, 4, 4,1),fpppp( 5, 4, 4,2),fpppp( 5, 4, 4,3)/
     x 2.1931819D-05, 4.9936897D-05,-2.3701580D-08 /
      data fpppp( 5, 4, 5,1),fpppp( 5, 4, 5,2),fpppp( 5, 4, 5,3)/
     x-3.7227018D-05,-2.0180785D-05, 2.2599389D-08 /
      data fpppp( 5, 4, 6,1),fpppp( 5, 4, 6,2),fpppp( 5, 4, 6,3)/
     x-6.8659122D-05, 1.7336989D-05, 6.7292870D-08 /
      data fpppp( 5, 4, 7,1),fpppp( 5, 4, 7,2),fpppp( 5, 4, 7,3)/
     x 2.5239470D-04,-4.7651695D-05,-2.1125297D-08 /
      data fpppp( 5, 4, 8,1),fpppp( 5, 4, 8,2),fpppp( 5, 4, 8,3)/
     x-6.5118073D-06, 3.0944531D-05,-6.1755682D-09 /
      data fpppp( 5, 4, 9,1),fpppp( 5, 4, 9,2),fpppp( 5, 4, 9,3)/
     x-8.3549735D-06,-4.4012977D-06,-1.7790855D-08 /
      data fpppp( 5, 4,10,1),fpppp( 5, 4,10,2),fpppp( 5, 4,10,3)/
     x-6.5118073D-06, 3.0944531D-05,-6.1755682D-09 /
      data fpppp( 5, 4,11,1),fpppp( 5, 4,11,2),fpppp( 5, 4,11,3)/
     x 2.5239470D-04,-4.7651695D-05,-2.1125297D-08 /
      data fpppp( 5, 4,12,1),fpppp( 5, 4,12,2),fpppp( 5, 4,12,3)/
     x-6.8659122D-05, 1.7336989D-05, 6.7292870D-08 /
      data fpppp( 5, 4,13,1),fpppp( 5, 4,13,2),fpppp( 5, 4,13,3)/
     x-3.7227018D-05,-2.0180785D-05, 2.2599389D-08 /
      data fpppp( 5, 4,14,1),fpppp( 5, 4,14,2),fpppp( 5, 4,14,3)/
     x 2.1931819D-05, 4.9936897D-05,-2.3701580D-08 /
      data fpppp( 5, 4,15,1),fpppp( 5, 4,15,2),fpppp( 5, 4,15,3)/
     x 3.0857221D-04,-5.3038287D-05,-6.0874557D-08 /
      data fpppp( 5, 4,16,1),fpppp( 5, 4,16,2),fpppp( 5, 4,16,3)/
     x 2.1931819D-05, 2.9943164D-05,-1.8386883D-08 /
      data fpppp( 5, 4,17,1),fpppp( 5, 4,17,2),fpppp( 5, 4,17,3)/
     x-3.7227018D-05, 5.9794147D-05, 1.3406043D-09 /
      data fpppp( 5, 5, 1,1),fpppp( 5, 5, 1,2),fpppp( 5, 5, 1,3)/
     x-6.7260462D-06, 1.5610214D-04,-4.1836005D-08 /
      data fpppp( 5, 5, 2,1),fpppp( 5, 5, 2,2),fpppp( 5, 5, 2,3)/
     x-6.0283061D-05, 6.9866803D-05,-3.9997118D-08 /
      data fpppp( 5, 5, 3,1),fpppp( 5, 5, 3,2),fpppp( 5, 5, 3,3)/
     x-5.4441266D-04,-1.6632824D-04,-1.4913825D-08 /
      data fpppp( 5, 5, 4,1),fpppp( 5, 5, 4,2),fpppp( 5, 5, 4,3)/
     x-6.0283061D-05, 1.2233569D-04,-7.1185955D-08 /
      data fpppp( 5, 5, 5,1),fpppp( 5, 5, 5,2),fpppp( 5, 5, 5,3)/
     x-6.7260462D-06,-5.3773389D-05, 8.2919342D-08 /
      data fpppp( 5, 5, 6,1),fpppp( 5, 5, 6,2),fpppp( 5, 5, 6,3)/
     x-3.5950808D-05, 9.5089703D-05,-1.7184418D-08 /
      data fpppp( 5, 5, 7,1),fpppp( 5, 5, 7,2),fpppp( 5, 5, 7,3)/
     x-4.8736261D-04,-1.5531774D-04, 4.6641642D-08 /
      data fpppp( 5, 5, 8,1),fpppp( 5, 5, 8,2),fpppp( 5, 5, 8,3)/
     x-5.4702186D-05, 9.6074555D-05,-4.6870735D-08 /
      data fpppp( 5, 5, 9,1),fpppp( 5, 5, 9,2),fpppp( 5, 5, 9,3)/
     x-3.9265194D-06,-3.3744574D-05, 2.1075932D-08 /
      data fpppp( 5, 5,10,1),fpppp( 5, 5,10,2),fpppp( 5, 5,10,3)/
     x-5.4702186D-05, 9.6074555D-05,-4.6870735D-08 /
      data fpppp( 5, 5,11,1),fpppp( 5, 5,11,2),fpppp( 5, 5,11,3)/
     x-4.8736261D-04,-1.5531774D-04, 4.6641642D-08 /
      data fpppp( 5, 5,12,1),fpppp( 5, 5,12,2),fpppp( 5, 5,12,3)/
     x-3.5950808D-05, 9.5089703D-05,-1.7184418D-08 /
      data fpppp( 5, 5,13,1),fpppp( 5, 5,13,2),fpppp( 5, 5,13,3)/
     x-6.7260462D-06,-5.3773389D-05, 8.2919342D-08 /
      data fpppp( 5, 5,14,1),fpppp( 5, 5,14,2),fpppp( 5, 5,14,3)/
     x-6.0283061D-05, 1.2233569D-04,-7.1185955D-08 /
      data fpppp( 5, 5,15,1),fpppp( 5, 5,15,2),fpppp( 5, 5,15,3)/
     x-5.4441266D-04,-1.6632824D-04,-1.4913825D-08 /
      data fpppp( 5, 5,16,1),fpppp( 5, 5,16,2),fpppp( 5, 5,16,3)/
     x-6.0283061D-05, 6.9866803D-05,-3.9997118D-08 /
      data fpppp( 5, 5,17,1),fpppp( 5, 5,17,2),fpppp( 5, 5,17,3)/
     x-6.7260462D-06, 1.5610214D-04,-4.1836005D-08 /
      data fpppp( 5, 6, 1,1),fpppp( 5, 6, 1,2),fpppp( 5, 6, 1,3)/
     x 1.8550105D-05, 1.2745482D-04, 1.1801119D-07 /
      data fpppp( 5, 6, 2,1),fpppp( 5, 6, 2,2),fpppp( 5, 6, 2,3)/
     x 3.6285882D-05, 5.6754125D-05, 4.1246482D-08 /
      data fpppp( 5, 6, 3,1),fpppp( 5, 6, 3,2),fpppp( 5, 6, 3,3)/
     x-2.0781412D-04,-1.3770034D-04,-1.5492242D-07 /
      data fpppp( 5, 6, 4,1),fpppp( 5, 6, 4,2),fpppp( 5, 6, 4,3)/
     x 3.6285882D-05, 1.0098339D-04, 6.6823373D-08 /
      data fpppp( 5, 6, 5,1),fpppp( 5, 6, 5,2),fpppp( 5, 6, 5,3)/
     x 1.8550105D-05,-4.9462255D-05, 1.5703620D-08 /
      data fpppp( 5, 6, 6,1),fpppp( 5, 6, 6,2),fpppp( 5, 6, 6,3)/
     x 4.9597616D-05, 8.6687756D-05, 1.1585318D-08 /
      data fpppp( 5, 6, 7,1),fpppp( 5, 6, 7,2),fpppp( 5, 6, 7,3)/
     x-1.3710623D-04,-1.2893705D-04,-3.6023717D-08 /
      data fpppp( 5, 6, 8,1),fpppp( 5, 6, 8,2),fpppp( 5, 6, 8,3)/
     x 3.2066699D-05, 7.9195122D-05, 2.6047778D-08 /
      data fpppp( 5, 6, 9,1),fpppp( 5, 6, 9,2),fpppp( 5, 6, 9,3)/
     x 6.8277325D-06,-3.1862040D-05,-9.0875087D-09 /
      data fpppp( 5, 6,10,1),fpppp( 5, 6,10,2),fpppp( 5, 6,10,3)/
     x 3.2066699D-05, 7.9195122D-05, 2.6047778D-08 /
      data fpppp( 5, 6,11,1),fpppp( 5, 6,11,2),fpppp( 5, 6,11,3)/
     x-1.3710623D-04,-1.2893705D-04,-3.6023717D-08 /
      data fpppp( 5, 6,12,1),fpppp( 5, 6,12,2),fpppp( 5, 6,12,3)/
     x 4.9597616D-05, 8.6687756D-05, 1.1585318D-08 /
      data fpppp( 5, 6,13,1),fpppp( 5, 6,13,2),fpppp( 5, 6,13,3)/
     x 1.8550105D-05,-4.9462255D-05, 1.5703620D-08 /
      data fpppp( 5, 6,14,1),fpppp( 5, 6,14,2),fpppp( 5, 6,14,3)/
     x 3.6285882D-05, 1.0098339D-04, 6.6823373D-08 /
      data fpppp( 5, 6,15,1),fpppp( 5, 6,15,2),fpppp( 5, 6,15,3)/
     x-2.0781412D-04,-1.3770034D-04,-1.5492242D-07 /
      data fpppp( 5, 6,16,1),fpppp( 5, 6,16,2),fpppp( 5, 6,16,3)/
     x 3.6285882D-05, 5.6754125D-05, 4.1246482D-08 /
      data fpppp( 5, 6,17,1),fpppp( 5, 6,17,2),fpppp( 5, 6,17,3)/
     x 1.8550105D-05, 1.2745482D-04, 1.1801119D-07 /
      data fpppp( 5, 7, 1,1),fpppp( 5, 7, 1,2),fpppp( 5, 7, 1,3)/
     x 1.9761085D-05, 2.1067679D-05, 1.3943026D-07 /
      data fpppp( 5, 7, 2,1),fpppp( 5, 7, 2,2),fpppp( 5, 7, 2,3)/
     x 4.2032102D-05, 9.4516488D-06, 7.0926530D-08 /
      data fpppp( 5, 7, 3,1),fpppp( 5, 7, 3,2),fpppp( 5, 7, 3,3)/
     x 3.8657681D-04,-2.2978097D-05,-1.2289685D-07 /
      data fpppp( 5, 7, 4,1),fpppp( 5, 7, 4,2),fpppp( 5, 7, 4,3)/
     x 4.2032102D-05, 1.7440162D-05, 1.2189854D-07 /
      data fpppp( 5, 7, 5,1),fpppp( 5, 7, 5,2),fpppp( 5, 7, 5,3)/
     x 1.9761085D-05,-1.0886374D-05,-6.4457771D-08 /
      data fpppp( 5, 7, 6,1),fpppp( 5, 7, 6,2),fpppp( 5, 7, 6,3)/
     x 4.9924179D-05, 2.1727262D-05, 1.4012864D-08 /
      data fpppp( 5, 7, 7,1),fpppp( 5, 7, 7,2),fpppp( 5, 7, 7,3)/
     x 3.2111853D-04,-2.7493728D-05,-4.3261696D-08 /
      data fpppp( 5, 7, 8,1),fpppp( 5, 7, 8,2),fpppp( 5, 7, 8,3)/
     x 2.1278996D-05, 1.1573172D-05, 5.6889602D-08 /
      data fpppp( 5, 7, 9,1),fpppp( 5, 7, 9,2),fpppp( 5, 7, 9,3)/
     x-4.0827560D-06,-4.1147286D-07,-3.8770887D-08 /
      data fpppp( 5, 7,10,1),fpppp( 5, 7,10,2),fpppp( 5, 7,10,3)/
     x 2.1278996D-05, 1.1573172D-05, 5.6889602D-08 /
      data fpppp( 5, 7,11,1),fpppp( 5, 7,11,2),fpppp( 5, 7,11,3)/
     x 3.2111853D-04,-2.7493728D-05,-4.3261696D-08 /
      data fpppp( 5, 7,12,1),fpppp( 5, 7,12,2),fpppp( 5, 7,12,3)/
     x 4.9924179D-05, 2.1727262D-05, 1.4012864D-08 /
      data fpppp( 5, 7,13,1),fpppp( 5, 7,13,2),fpppp( 5, 7,13,3)/
     x 1.9761085D-05,-1.0886374D-05,-6.4457771D-08 /
      data fpppp( 5, 7,14,1),fpppp( 5, 7,14,2),fpppp( 5, 7,14,3)/
     x 4.2032102D-05, 1.7440162D-05, 1.2189854D-07 /
      data fpppp( 5, 7,15,1),fpppp( 5, 7,15,2),fpppp( 5, 7,15,3)/
     x 3.8657681D-04,-2.2978097D-05,-1.2289685D-07 /
      data fpppp( 5, 7,16,1),fpppp( 5, 7,16,2),fpppp( 5, 7,16,3)/
     x 4.2032102D-05, 9.4516488D-06, 7.0926530D-08 /
      data fpppp( 5, 7,17,1),fpppp( 5, 7,17,2),fpppp( 5, 7,17,3)/
     x 1.9761085D-05, 2.1067679D-05, 1.3943026D-07 /
      data fpppp( 5, 8, 1,1),fpppp( 5, 8, 1,2),fpppp( 5, 8, 1,3)/
     x 1.3274121D-05,-6.3839857D-06,-8.0592446D-08 /
      data fpppp( 5, 8, 2,1),fpppp( 5, 8, 2,2),fpppp( 5, 8, 2,3)/
     x-4.2846981D-05,-4.1743055D-06,-1.5972172D-08 /
      data fpppp( 5, 8, 3,1),fpppp( 5, 8, 3,2),fpppp( 5, 8, 3,3)/
     x 5.2501545D-07, 3.2972572D-06, 1.4300833D-07 /
      data fpppp( 5, 8, 4,1),fpppp( 5, 8, 4,2),fpppp( 5, 8, 4,3)/
     x-4.2846981D-05,-7.6477689D-06,-2.8271956D-08 /
      data fpppp( 5, 8, 5,1),fpppp( 5, 8, 5,2),fpppp( 5, 8, 5,3)/
     x 1.3274121D-05, 7.5098679D-06,-3.1393308D-08 /
      data fpppp( 5, 8, 6,1),fpppp( 5, 8, 6,2),fpppp( 5, 8, 6,3)/
     x 1.6881973D-05, 1.9196334D-06,-5.5899246D-08 /
      data fpppp( 5, 8, 7,1),fpppp( 5, 8, 7,2),fpppp( 5, 8, 7,3)/
     x 1.2563908D-05,-4.4324702D-06, 4.5041167D-08 /
      data fpppp( 5, 8, 8,1),fpppp( 5, 8, 8,2),fpppp( 5, 8, 8,3)/
     x-2.3653288D-05,-5.4686965D-06,-3.9063772D-09 /
      data fpppp( 5, 8, 9,1),fpppp( 5, 8, 9,2),fpppp( 5, 8, 9,3)/
     x-1.6012956D-05, 1.2362701D-05, 3.8011504D-09 /
      data fpppp( 5, 8,10,1),fpppp( 5, 8,10,2),fpppp( 5, 8,10,3)/
     x-2.3653288D-05,-5.4686965D-06,-3.9063772D-09 /
      data fpppp( 5, 8,11,1),fpppp( 5, 8,11,2),fpppp( 5, 8,11,3)/
     x 1.2563908D-05,-4.4324702D-06, 4.5041167D-08 /
      data fpppp( 5, 8,12,1),fpppp( 5, 8,12,2),fpppp( 5, 8,12,3)/
     x 1.6881973D-05, 1.9196334D-06,-5.5899246D-08 /
      data fpppp( 5, 8,13,1),fpppp( 5, 8,13,2),fpppp( 5, 8,13,3)/
     x 1.3274121D-05, 7.5098679D-06,-3.1393308D-08 /
      data fpppp( 5, 8,14,1),fpppp( 5, 8,14,2),fpppp( 5, 8,14,3)/
     x-4.2846981D-05,-7.6477689D-06,-2.8271956D-08 /
      data fpppp( 5, 8,15,1),fpppp( 5, 8,15,2),fpppp( 5, 8,15,3)/
     x 5.2501545D-07, 3.2972572D-06, 1.4300833D-07 /
      data fpppp( 5, 8,16,1),fpppp( 5, 8,16,2),fpppp( 5, 8,16,3)/
     x-4.2846981D-05,-4.1743055D-06,-1.5972172D-08 /
      data fpppp( 5, 8,17,1),fpppp( 5, 8,17,2),fpppp( 5, 8,17,3)/
     x 1.3274121D-05,-6.3839857D-06,-8.0592446D-08 /
      data fpppp( 5, 9, 1,1),fpppp( 5, 9, 1,2),fpppp( 5, 9, 1,3)/
     x 9.4934330D-06, 5.0979059D-06,-6.5896285D-08 /
      data fpppp( 5, 9, 2,1),fpppp( 5, 9, 2,2),fpppp( 5, 9, 2,3)/
     x-3.4426940D-05, 1.0127888D-06,-1.3446225D-08 /
      data fpppp( 5, 9, 3,1),fpppp( 5, 9, 3,2),fpppp( 5, 9, 3,3)/
     x-1.0911965D-04,-8.0049444D-06, 1.1749289D-07 /
      data fpppp( 5, 9, 4,1),fpppp( 5, 9, 4,2),fpppp( 5, 9, 4,3)/
     x-3.4426940D-05, 2.4147866D-07,-2.6279685D-08 /
      data fpppp( 5, 9, 5,1),fpppp( 5, 9, 5,2),fpppp( 5, 9, 5,3)/
     x 9.4934330D-06, 8.1831466D-06,-1.4562448D-08 /
      data fpppp( 5, 9, 6,1),fpppp( 5, 9, 6,2),fpppp( 5, 9, 6,3)/
     x 1.6425053D-05,-1.5963933D-06,-4.9013099D-08 /
      data fpppp( 5, 9, 7,1),fpppp( 5, 9, 7,2),fpppp( 5, 9, 7,3)/
     x-1.3968276D-05,-9.7032531D-06, 1.5199355D-08 /
      data fpppp( 5, 9, 8,1),fpppp( 5, 9, 8,2),fpppp( 5, 9, 8,3)/
     x-1.4683617D-05, 1.9794868D-07, 7.0838127D-09 /
      data fpppp( 5, 9, 9,1),fpppp( 5, 9, 9,2),fpppp( 5, 9, 9,3)/
     x-9.9457592D-06, 1.3230538D-05, 1.5512332D-08 /
      data fpppp( 5, 9,10,1),fpppp( 5, 9,10,2),fpppp( 5, 9,10,3)/
     x-1.4683617D-05, 1.9794868D-07, 7.0838127D-09 /
      data fpppp( 5, 9,11,1),fpppp( 5, 9,11,2),fpppp( 5, 9,11,3)/
     x-1.3968276D-05,-9.7032531D-06, 1.5199355D-08 /
      data fpppp( 5, 9,12,1),fpppp( 5, 9,12,2),fpppp( 5, 9,12,3)/
     x 1.6425053D-05,-1.5963933D-06,-4.9013099D-08 /
      data fpppp( 5, 9,13,1),fpppp( 5, 9,13,2),fpppp( 5, 9,13,3)/
     x 9.4934330D-06, 8.1831466D-06,-1.4562448D-08 /
      data fpppp( 5, 9,14,1),fpppp( 5, 9,14,2),fpppp( 5, 9,14,3)/
     x-3.4426940D-05, 2.4147866D-07,-2.6279685D-08 /
      data fpppp( 5, 9,15,1),fpppp( 5, 9,15,2),fpppp( 5, 9,15,3)/
     x-1.0911965D-04,-8.0049444D-06, 1.1749289D-07 /
      data fpppp( 5, 9,16,1),fpppp( 5, 9,16,2),fpppp( 5, 9,16,3)/
     x-3.4426940D-05, 1.0127888D-06,-1.3446225D-08 /
      data fpppp( 5, 9,17,1),fpppp( 5, 9,17,2),fpppp( 5, 9,17,3)/
     x 9.4934330D-06, 5.0979059D-06,-6.5896285D-08 /
      data fpppp( 5,10, 1,1),fpppp( 5,10, 1,2),fpppp( 5,10, 1,3)/
     x 1.0242947D-05, 7.4228484D-06,-2.2405732D-09 /
      data fpppp( 5,10, 2,1),fpppp( 5,10, 2,2),fpppp( 5,10, 2,3)/
     x 2.3603861D-06, 4.1606217D-06, 9.2200585D-09 /
      data fpppp( 5,10, 3,1),fpppp( 5,10, 3,2),fpppp( 5,10, 3,3)/
     x 2.4818362D-06,-3.7256205D-06, 3.5986344D-08 /
      data fpppp( 5,10, 4,1),fpppp( 5,10, 4,2),fpppp( 5,10, 4,3)/
     x 2.3603861D-06, 4.5721917D-06, 9.1828406D-09 /
      data fpppp( 5,10, 5,1),fpppp( 5,10, 5,2),fpppp( 5,10, 5,3)/
     x 1.0242947D-05, 5.7765685D-06,-2.0917015D-09 /
      data fpppp( 5,10, 6,1),fpppp( 5,10, 6,2),fpppp( 5,10, 6,3)/
     x 2.3749544D-05,-1.0883816D-05,-5.5621297D-08 /
      data fpppp( 5,10, 7,1),fpppp( 5,10, 7,2),fpppp( 5,10, 7,3)/
     x-1.5970146D-06,-1.0595135D-05, 9.1879739D-09 /
      data fpppp( 5,10, 8,1),fpppp( 5,10, 8,2),fpppp( 5,10, 8,3)/
     x 3.3511294D-06, 7.1323323D-06, 1.4077824D-08 /
      data fpppp( 5,10, 9,1),fpppp( 5,10, 9,2),fpppp( 5,10, 9,3)/
     x 6.9016702D-06, 1.1789933D-05, 1.4536173D-08 /
      data fpppp( 5,10,10,1),fpppp( 5,10,10,2),fpppp( 5,10,10,3)/
     x 3.3511294D-06, 7.1323323D-06, 1.4077824D-08 /
      data fpppp( 5,10,11,1),fpppp( 5,10,11,2),fpppp( 5,10,11,3)/
     x-1.5970146D-06,-1.0595135D-05, 9.1879739D-09 /
      data fpppp( 5,10,12,1),fpppp( 5,10,12,2),fpppp( 5,10,12,3)/
     x 2.3749544D-05,-1.0883816D-05,-5.5621297D-08 /
      data fpppp( 5,10,13,1),fpppp( 5,10,13,2),fpppp( 5,10,13,3)/
     x 1.0242947D-05, 5.7765685D-06,-2.0917015D-09 /
      data fpppp( 5,10,14,1),fpppp( 5,10,14,2),fpppp( 5,10,14,3)/
     x 2.3603861D-06, 4.5721917D-06, 9.1828406D-09 /
      data fpppp( 5,10,15,1),fpppp( 5,10,15,2),fpppp( 5,10,15,3)/
     x 2.4818362D-06,-3.7256205D-06, 3.5986344D-08 /
      data fpppp( 5,10,16,1),fpppp( 5,10,16,2),fpppp( 5,10,16,3)/
     x 2.3603861D-06, 4.1606217D-06, 9.2200585D-09 /
      data fpppp( 5,10,17,1),fpppp( 5,10,17,2),fpppp( 5,10,17,3)/
     x 1.0242947D-05, 7.4228484D-06,-2.2405732D-09 /
      data fpppp( 5,11, 1,1),fpppp( 5,11, 1,2),fpppp( 5,11, 1,3)/
     x 1.2502992D-05, 7.7998007D-06, 2.2230653D-08 /
      data fpppp( 5,11, 2,1),fpppp( 5,11, 2,2),fpppp( 5,11, 2,3)/
     x 2.4272938D-05, 6.8796433D-06, 1.6608508D-08 /
      data fpppp( 5,11, 3,1),fpppp( 5,11, 3,2),fpppp( 5,11, 3,3)/
     x 3.7152944D-05, 4.4784690D-06, 2.2995935D-09 /
      data fpppp( 5,11, 4,1),fpppp( 5,11, 4,2),fpppp( 5,11, 4,3)/
     x 2.4272938D-05, 7.2608538D-06, 1.8394374D-08 /
      data fpppp( 5,11, 5,1),fpppp( 5,11, 5,2),fpppp( 5,11, 5,3)/
     x 1.2502992D-05, 6.2749587D-06, 1.5087191D-08 /
      data fpppp( 5,11, 6,1),fpppp( 5,11, 6,2),fpppp( 5,11, 6,3)/
     x 2.5074342D-05,-2.9054763D-05,-7.8899511D-08 /
      data fpppp( 5,11, 7,1),fpppp( 5,11, 7,2),fpppp( 5,11, 7,3)/
     x 6.5453418D-06,-3.7287703D-06, 2.8482003D-08 /
      data fpppp( 5,11, 8,1),fpppp( 5,11, 8,2),fpppp( 5,11, 8,3)/
     x 1.6869309D-05, 1.1885008D-05, 9.9896781D-09 /
      data fpppp( 5,11, 9,1),fpppp( 5,11, 9,2),fpppp( 5,11, 9,3)/
     x 1.8263700D-05, 1.0310492D-05, 1.1890582D-08 /
      data fpppp( 5,11,10,1),fpppp( 5,11,10,2),fpppp( 5,11,10,3)/
     x 1.6869309D-05, 1.1885008D-05, 9.9896781D-09 /
      data fpppp( 5,11,11,1),fpppp( 5,11,11,2),fpppp( 5,11,11,3)/
     x 6.5453418D-06,-3.7287703D-06, 2.8482003D-08 /
      data fpppp( 5,11,12,1),fpppp( 5,11,12,2),fpppp( 5,11,12,3)/
     x 2.5074342D-05,-2.9054763D-05,-7.8899511D-08 /
      data fpppp( 5,11,13,1),fpppp( 5,11,13,2),fpppp( 5,11,13,3)/
     x 1.2502992D-05, 6.2749587D-06, 1.5087191D-08 /
      data fpppp( 5,11,14,1),fpppp( 5,11,14,2),fpppp( 5,11,14,3)/
     x 2.4272938D-05, 7.2608538D-06, 1.8394374D-08 /
      data fpppp( 5,11,15,1),fpppp( 5,11,15,2),fpppp( 5,11,15,3)/
     x 3.7152944D-05, 4.4784690D-06, 2.2995935D-09 /
      data fpppp( 5,11,16,1),fpppp( 5,11,16,2),fpppp( 5,11,16,3)/
     x 2.4272938D-05, 6.8796433D-06, 1.6608508D-08 /
      data fpppp( 5,11,17,1),fpppp( 5,11,17,2),fpppp( 5,11,17,3)/
     x 1.2502992D-05, 7.7998007D-06, 2.2230653D-08 /
      data fpppp( 5,12, 1,1),fpppp( 5,12, 1,2),fpppp( 5,12, 1,3)/
     x 2.0581898D-05, 1.0463814D-05, 1.9935886D-08 /
      data fpppp( 5,12, 2,1),fpppp( 5,12, 2,2),fpppp( 5,12, 2,3)/
     x 2.9589945D-05, 1.0046498D-05, 1.2290064D-08 /
      data fpppp( 5,12, 3,1),fpppp( 5,12, 3,2),fpppp( 5,12, 3,3)/
     x 3.4860909D-05, 9.5716278D-06,-4.1792590D-09 /
      data fpppp( 5,12, 4,1),fpppp( 5,12, 4,2),fpppp( 5,12, 4,3)/
     x 2.9589945D-05, 9.2981976D-06, 1.0233672D-08 /
      data fpppp( 5,12, 5,1),fpppp( 5,12, 5,2),fpppp( 5,12, 5,3)/
     x 2.0581898D-05, 1.3457016D-05, 2.8161451D-08 /
      data fpppp( 5,12, 6,1),fpppp( 5,12, 6,2),fpppp( 5,12, 6,3)/
     x 5.0158273D-05,-5.7578654D-05,-8.8528716D-08 /
      data fpppp( 5,12, 7,1),fpppp( 5,12, 7,2),fpppp( 5,12, 7,3)/
     x 1.0772203D-05, 1.2063814D-05, 4.6977723D-08 /
      data fpppp( 5,12, 8,1),fpppp( 5,12, 8,2),fpppp( 5,12, 8,3)/
     x 1.8863207D-05, 1.2750596D-05,-6.3309278D-11 /
      data fpppp( 5,12, 9,1),fpppp( 5,12, 9,2),fpppp( 5,12, 9,3)/
     x 1.7886925D-05, 1.0321716D-05, 1.0274884D-08 /
      data fpppp( 5,12,10,1),fpppp( 5,12,10,2),fpppp( 5,12,10,3)/
     x 1.8863207D-05, 1.2750596D-05,-6.3309278D-11 /
      data fpppp( 5,12,11,1),fpppp( 5,12,11,2),fpppp( 5,12,11,3)/
     x 1.0772203D-05, 1.2063814D-05, 4.6977723D-08 /
      data fpppp( 5,12,12,1),fpppp( 5,12,12,2),fpppp( 5,12,12,3)/
     x 5.0158273D-05,-5.7578654D-05,-8.8528716D-08 /
      data fpppp( 5,12,13,1),fpppp( 5,12,13,2),fpppp( 5,12,13,3)/
     x 2.0581898D-05, 1.3457016D-05, 2.8161451D-08 /
      data fpppp( 5,12,14,1),fpppp( 5,12,14,2),fpppp( 5,12,14,3)/
     x 2.9589945D-05, 9.2981976D-06, 1.0233672D-08 /
      data fpppp( 5,12,15,1),fpppp( 5,12,15,2),fpppp( 5,12,15,3)/
     x 3.4860909D-05, 9.5716278D-06,-4.1792590D-09 /
      data fpppp( 5,12,16,1),fpppp( 5,12,16,2),fpppp( 5,12,16,3)/
     x 2.9589945D-05, 1.0046498D-05, 1.2290064D-08 /
      data fpppp( 5,12,17,1),fpppp( 5,12,17,2),fpppp( 5,12,17,3)/
     x 2.0581898D-05, 1.0463814D-05, 1.9935886D-08 /
      data fpppp( 5,13, 1,1),fpppp( 5,13, 1,2),fpppp( 5,13, 1,3)/
     x 8.2488304D-05, 1.6041450D-05, 2.8108413D-09 /
      data fpppp( 5,13, 2,1),fpppp( 5,13, 2,2),fpppp( 5,13, 2,3)/
     x 2.6164259D-05, 1.4315732D-05, 3.9449782D-10 /
      data fpppp( 5,13, 3,1),fpppp( 5,13, 3,2),fpppp( 5,13, 3,3)/
     x 2.9043753D-05, 1.2382232D-05,-3.3406390D-09 /
      data fpppp( 5,13, 4,1),fpppp( 5,13, 4,2),fpppp( 5,13, 4,3)/
     x 2.6164259D-05, 1.1175968D-05,-2.4599993D-09 /
      data fpppp( 5,13, 5,1),fpppp( 5,13, 5,2),fpppp( 5,13, 5,3)/
     x 8.2488304D-05, 2.8600505D-05, 1.4228830D-08 /
      data fpppp( 5,13, 6,1),fpppp( 5,13, 6,2),fpppp( 5,13, 6,3)/
     x 9.4545851D-05,-1.0285398D-04,-4.3021993D-08 /
      data fpppp( 5,13, 7,1),fpppp( 5,13, 7,2),fpppp( 5,13, 7,3)/
     x 1.0003450D-05, 4.2061813D-05, 4.2750743D-08 /
      data fpppp( 5,13, 8,1),fpppp( 5,13, 8,2),fpppp( 5,13, 8,3)/
     x 1.6110164D-05, 7.9248945D-06,-1.3834623D-08 /
      data fpppp( 5,13, 9,1),fpppp( 5,13, 9,2),fpppp( 5,13, 9,3)/
     x 1.6866088D-05, 1.3276075D-05, 7.5389744D-09 /
      data fpppp( 5,13,10,1),fpppp( 5,13,10,2),fpppp( 5,13,10,3)/
     x 1.6110164D-05, 7.9248945D-06,-1.3834623D-08 /
      data fpppp( 5,13,11,1),fpppp( 5,13,11,2),fpppp( 5,13,11,3)/
     x 1.0003450D-05, 4.2061813D-05, 4.2750743D-08 /
      data fpppp( 5,13,12,1),fpppp( 5,13,12,2),fpppp( 5,13,12,3)/
     x 9.4545851D-05,-1.0285398D-04,-4.3021993D-08 /
      data fpppp( 5,13,13,1),fpppp( 5,13,13,2),fpppp( 5,13,13,3)/
     x 8.2488304D-05, 2.8600505D-05, 1.4228830D-08 /
      data fpppp( 5,13,14,1),fpppp( 5,13,14,2),fpppp( 5,13,14,3)/
     x 2.6164259D-05, 1.1175968D-05,-2.4599993D-09 /
      data fpppp( 5,13,15,1),fpppp( 5,13,15,2),fpppp( 5,13,15,3)/
     x 2.9043753D-05, 1.2382232D-05,-3.3406390D-09 /
      data fpppp( 5,13,16,1),fpppp( 5,13,16,2),fpppp( 5,13,16,3)/
     x 2.6164259D-05, 1.4315732D-05, 3.9449782D-10 /
      data fpppp( 5,13,17,1),fpppp( 5,13,17,2),fpppp( 5,13,17,3)/
     x 8.2488304D-05, 1.6041450D-05, 2.8108413D-09 /
      data fpppp( 5,14, 1,1),fpppp( 5,14, 1,2),fpppp( 5,14, 1,3)/
     x 1.6534362D-04, 3.5737564D-05,-1.3530363D-08 /
      data fpppp( 5,14, 2,1),fpppp( 5,14, 2,2),fpppp( 5,14, 2,3)/
     x 2.0344005D-05, 2.6999440D-05,-1.2199165D-08 /
      data fpppp( 5,14, 3,1),fpppp( 5,14, 3,2),fpppp( 5,14, 3,3)/
     x 2.2748231D-05, 9.6921182D-06,-1.5862634D-08 /
      data fpppp( 5,14, 4,1),fpppp( 5,14, 4,2),fpppp( 5,14, 4,3)/
     x 2.0344005D-05, 2.2376989D-05,-2.0447705D-09 /
      data fpppp( 5,14, 5,1),fpppp( 5,14, 5,2),fpppp( 5,14, 5,3)/
     x 1.6534362D-04, 5.4227368D-05,-5.4147941D-08 /
      data fpppp( 5,14, 6,1),fpppp( 5,14, 6,2),fpppp( 5,14, 6,3)/
     x 4.8453334D-04,-1.9541844D-04, 9.7312464D-08 /
      data fpppp( 5,14, 7,1),fpppp( 5,14, 7,2),fpppp( 5,14, 7,3)/
     x 8.3625135D-06, 1.1176376D-04,-2.7726342D-09 /
      data fpppp( 5,14, 8,1),fpppp( 5,14, 8,2),fpppp( 5,14, 8,3)/
     x 1.4975296D-05,-9.2211329D-06,-2.8646216D-08 /
      data fpppp( 5,14, 9,1),fpppp( 5,14, 9,2),fpppp( 5,14, 9,3)/
     x 1.8511853D-05, 2.2080376D-05,-1.8467725D-09 /
      data fpppp( 5,14,10,1),fpppp( 5,14,10,2),fpppp( 5,14,10,3)/
     x 1.4975296D-05,-9.2211329D-06,-2.8646216D-08 /
      data fpppp( 5,14,11,1),fpppp( 5,14,11,2),fpppp( 5,14,11,3)/
     x 8.3625135D-06, 1.1176376D-04,-2.7726342D-09 /
      data fpppp( 5,14,12,1),fpppp( 5,14,12,2),fpppp( 5,14,12,3)/
     x 4.8453334D-04,-1.9541844D-04, 9.7312464D-08 /
      data fpppp( 5,14,13,1),fpppp( 5,14,13,2),fpppp( 5,14,13,3)/
     x 1.6534362D-04, 5.4227368D-05,-5.4147941D-08 /
      data fpppp( 5,14,14,1),fpppp( 5,14,14,2),fpppp( 5,14,14,3)/
     x 2.0344005D-05, 2.2376989D-05,-2.0447705D-09 /
      data fpppp( 5,14,15,1),fpppp( 5,14,15,2),fpppp( 5,14,15,3)/
     x 2.2748231D-05, 9.6921182D-06,-1.5862634D-08 /
      data fpppp( 5,14,16,1),fpppp( 5,14,16,2),fpppp( 5,14,16,3)/
     x 2.0344005D-05, 2.6999440D-05,-1.2199165D-08 /
      data fpppp( 5,14,17,1),fpppp( 5,14,17,2),fpppp( 5,14,17,3)/
     x 1.6534362D-04, 3.5737564D-05,-1.3530363D-08 /
      data fpppp( 5,15, 1,1),fpppp( 5,15, 1,2),fpppp( 5,15, 1,3)/
     x-2.2890714D-04, 7.0320135D-05,-9.2561387D-08 /
      data fpppp( 5,15, 2,1),fpppp( 5,15, 2,2),fpppp( 5,15, 2,3)/
     x 4.1402328D-05, 4.8347890D-05,-7.1500513D-08 /
      data fpppp( 5,15, 3,1),fpppp( 5,15, 3,2),fpppp( 5,15, 3,3)/
     x 5.6191282D-05, 1.1564016D-06,-2.7606130D-08 /
      data fpppp( 5,15, 4,1),fpppp( 5,15, 4,2),fpppp( 5,15, 4,3)/
     x 4.1402328D-05, 4.2232267D-05,-6.3629028D-08 /
      data fpppp( 5,15, 5,1),fpppp( 5,15, 5,2),fpppp( 5,15, 5,3)/
     x-2.2890714D-04, 9.4782630D-05,-1.2404732D-07 /
      data fpppp( 5,15, 6,1),fpppp( 5,15, 6,2),fpppp( 5,15, 6,3)/
     x-1.0369338D-03,-3.4359778D-04, 4.3736128D-07 /
      data fpppp( 5,15, 7,1),fpppp( 5,15, 7,2),fpppp( 5,15, 7,3)/
     x-1.7849953D-05, 2.2778222D-04,-2.0492651D-07 /
      data fpppp( 5,15, 8,1),fpppp( 5,15, 8,2),fpppp( 5,15, 8,3)/
     x 1.6651065D-05,-4.0773764D-05,-9.9444249D-09 /
      data fpppp( 5,15, 9,1),fpppp( 5,15, 9,2),fpppp( 5,15, 9,3)/
     x 2.1815152D-05, 3.6973188D-05,-4.0709928D-08 /
      data fpppp( 5,15,10,1),fpppp( 5,15,10,2),fpppp( 5,15,10,3)/
     x 1.6651065D-05,-4.0773764D-05,-9.9444249D-09 /
      data fpppp( 5,15,11,1),fpppp( 5,15,11,2),fpppp( 5,15,11,3)/
     x-1.7849953D-05, 2.2778222D-04,-2.0492651D-07 /
      data fpppp( 5,15,12,1),fpppp( 5,15,12,2),fpppp( 5,15,12,3)/
     x-1.0369338D-03,-3.4359778D-04, 4.3736128D-07 /
      data fpppp( 5,15,13,1),fpppp( 5,15,13,2),fpppp( 5,15,13,3)/
     x-2.2890714D-04, 9.4782630D-05,-1.2404732D-07 /
      data fpppp( 5,15,14,1),fpppp( 5,15,14,2),fpppp( 5,15,14,3)/
     x 4.1402328D-05, 4.2232267D-05,-6.3629028D-08 /
      data fpppp( 5,15,15,1),fpppp( 5,15,15,2),fpppp( 5,15,15,3)/
     x 5.6191282D-05, 1.1564016D-06,-2.7606130D-08 /
      data fpppp( 5,15,16,1),fpppp( 5,15,16,2),fpppp( 5,15,16,3)/
     x 4.1402328D-05, 4.8347890D-05,-7.1500513D-08 /
      data fpppp( 5,15,17,1),fpppp( 5,15,17,2),fpppp( 5,15,17,3)/
     x-2.2890714D-04, 7.0320135D-05,-9.2561387D-08 /
      data fpppp( 5,16, 1,1),fpppp( 5,16, 1,2),fpppp( 5,16, 1,3)/
     x-1.1248497D-04, 6.9941603D-05,-1.0674306D-07 /
      data fpppp( 5,16, 2,1),fpppp( 5,16, 2,2),fpppp( 5,16, 2,3)/
     x-1.0260946D-06, 4.9866702D-05,-9.5714180D-08 /
      data fpppp( 5,16, 3,1),fpppp( 5,16, 3,2),fpppp( 5,16, 3,3)/
     x-1.9043249D-05,-4.6723503D-06,-4.8452296D-08 /
      data fpppp( 5,16, 4,1),fpppp( 5,16, 4,2),fpppp( 5,16, 4,3)/
     x-1.0260946D-06, 6.1413127D-05,-1.2800593D-07 /
      data fpppp( 5,16, 5,1),fpppp( 5,16, 5,2),fpppp( 5,16, 5,3)/
     x-1.1248497D-04, 2.3755903D-05, 2.2423925D-08 /
      data fpppp( 5,16, 6,1),fpppp( 5,16, 6,2),fpppp( 5,16, 6,3)/
     x-2.6490100D-05,-2.4246640D-04, 3.3818249D-07 /
      data fpppp( 5,16, 7,1),fpppp( 5,16, 7,2),fpppp( 5,16, 7,3)/
     x-4.8764610D-06, 1.7466202D-04,-1.3884825D-07 /
      data fpppp( 5,16, 8,1),fpppp( 5,16, 8,2),fpppp( 5,16, 8,3)/
     x 2.6144891D-05,-2.7986957D-05,-4.4928387D-08 /
      data fpppp( 5,16, 9,1),fpppp( 5,16, 9,2),fpppp( 5,16, 9,3)/
     x 3.5340441D-05, 2.7841366D-05,-5.4577363D-08 /
      data fpppp( 5,16,10,1),fpppp( 5,16,10,2),fpppp( 5,16,10,3)/
     x 2.6144891D-05,-2.7986957D-05,-4.4928387D-08 /
      data fpppp( 5,16,11,1),fpppp( 5,16,11,2),fpppp( 5,16,11,3)/
     x-4.8764610D-06, 1.7466202D-04,-1.3884825D-07 /
      data fpppp( 5,16,12,1),fpppp( 5,16,12,2),fpppp( 5,16,12,3)/
     x-2.6490100D-05,-2.4246640D-04, 3.3818249D-07 /
      data fpppp( 5,16,13,1),fpppp( 5,16,13,2),fpppp( 5,16,13,3)/
     x-1.1248497D-04, 2.3755903D-05, 2.2423925D-08 /
      data fpppp( 5,16,14,1),fpppp( 5,16,14,2),fpppp( 5,16,14,3)/
     x-1.0260946D-06, 6.1413127D-05,-1.2800593D-07 /
      data fpppp( 5,16,15,1),fpppp( 5,16,15,2),fpppp( 5,16,15,3)/
     x-1.9043249D-05,-4.6723503D-06,-4.8452296D-08 /
      data fpppp( 5,16,16,1),fpppp( 5,16,16,2),fpppp( 5,16,16,3)/
     x-1.0260946D-06, 4.9866702D-05,-9.5714180D-08 /
      data fpppp( 5,16,17,1),fpppp( 5,16,17,2),fpppp( 5,16,17,3)/
     x-1.1248497D-04, 6.9941603D-05,-1.0674306D-07 /
      data fpppp( 5,17, 1,1),fpppp( 5,17, 1,2),fpppp( 5,17, 1,3)/
     x 5.3329244D-04, 3.8997100D-05, 6.4130289D-08 /
      data fpppp( 5,17, 2,1),fpppp( 5,17, 2,2),fpppp( 5,17, 2,3)/
     x 5.5490512D-04, 3.3032370D-05,-9.0960953D-09 /
      data fpppp( 5,17, 3,1),fpppp( 5,17, 3,2),fpppp( 5,17, 3,3)/
     x 5.4513963D-04, 4.0549091D-06,-1.4228804D-07 /
      data fpppp( 5,17, 4,1),fpppp( 5,17, 4,2),fpppp( 5,17, 4,3)/
     x 5.5490512D-04, 5.5622006D-05,-6.5600521D-08 /
      data fpppp( 5,17, 5,1),fpppp( 5,17, 5,2),fpppp( 5,17, 5,3)/
     x 5.3329244D-04,-5.1361445D-05, 2.9014799D-07 /
      data fpppp( 5,17, 6,1),fpppp( 5,17, 6,2),fpppp( 5,17, 6,3)/
     x 3.6722217D-04,-8.8040535D-05,-1.8558347D-07 /
      data fpppp( 5,17, 7,1),fpppp( 5,17, 7,2),fpppp( 5,17, 7,3)/
     x 1.6350252D-04, 8.2669648D-05, 1.4045205D-07 /
      data fpppp( 5,17, 8,1),fpppp( 5,17, 8,2),fpppp( 5,17, 8,3)/
     x 7.1726257D-05,-5.7846691D-06,-7.8859890D-08 /
      data fpppp( 5,17, 9,1),fpppp( 5,17, 9,2),fpppp( 5,17, 9,3)/
     x 3.8812124D-05, 1.3500018D-05,-6.8241687D-08 /
      data fpppp( 5,17,10,1),fpppp( 5,17,10,2),fpppp( 5,17,10,3)/
     x 7.1726257D-05,-5.7846691D-06,-7.8859890D-08 /
      data fpppp( 5,17,11,1),fpppp( 5,17,11,2),fpppp( 5,17,11,3)/
     x 1.6350252D-04, 8.2669648D-05, 1.4045205D-07 /
      data fpppp( 5,17,12,1),fpppp( 5,17,12,2),fpppp( 5,17,12,3)/
     x 3.6722217D-04,-8.8040535D-05,-1.8558347D-07 /
      data fpppp( 5,17,13,1),fpppp( 5,17,13,2),fpppp( 5,17,13,3)/
     x 5.3329244D-04,-5.1361445D-05, 2.9014799D-07 /
      data fpppp( 5,17,14,1),fpppp( 5,17,14,2),fpppp( 5,17,14,3)/
     x 5.5490512D-04, 5.5622006D-05,-6.5600521D-08 /
      data fpppp( 5,17,15,1),fpppp( 5,17,15,2),fpppp( 5,17,15,3)/
     x 5.4513963D-04, 4.0549091D-06,-1.4228804D-07 /
      data fpppp( 5,17,16,1),fpppp( 5,17,16,2),fpppp( 5,17,16,3)/
     x 5.5490512D-04, 3.3032370D-05,-9.0960953D-09 /
      data fpppp( 5,17,17,1),fpppp( 5,17,17,2),fpppp( 5,17,17,3)/
     x 5.3329244D-04, 3.8997100D-05, 6.4130289D-08 /
      data fpppp( 5,18, 1,1),fpppp( 5,18, 1,2),fpppp( 5,18, 1,3)/
     x-7.0161562D-04, 2.8331584D-06, 1.0608392D-07 /
      data fpppp( 5,18, 2,1),fpppp( 5,18, 2,2),fpppp( 5,18, 2,3)/
     x-6.7947325D-04, 1.1808838D-05, 1.0508786D-07 /
      data fpppp( 5,18, 3,1),fpppp( 5,18, 3,2),fpppp( 5,18, 3,3)/
     x-5.8911154D-04, 1.4806260D-05, 7.8225258D-08 /
      data fpppp( 5,18, 4,1),fpppp( 5,18, 4,2),fpppp( 5,18, 4,3)/
     x-6.7947325D-04, 3.8727583D-05, 1.4189552D-07 /
      data fpppp( 5,18, 5,1),fpppp( 5,18, 5,2),fpppp( 5,18, 5,3)/
     x-7.0161562D-04,-1.0484182D-04,-4.1146745D-08 /
      data fpppp( 5,18, 6,1),fpppp( 5,18, 6,2),fpppp( 5,18, 6,3)/
     x 2.4661034D-05, 3.1834345D-05,-2.1797273D-07 /
      data fpppp( 5,18, 7,1),fpppp( 5,18, 7,2),fpppp( 5,18, 7,3)/
     x 1.3002148D-04, 1.4367024D-05, 5.8947321D-08 /
      data fpppp( 5,18, 8,1),fpppp( 5,18, 8,2),fpppp( 5,18, 8,3)/
     x 2.7904395D-04, 1.1858864D-05, 2.1863016D-08 /
      data fpppp( 5,18, 9,1),fpppp( 5,18, 9,2),fpppp( 5,18, 9,3)/
     x 3.2320206D-04, 5.7882068D-06, 7.3657744D-10 /
      data fpppp( 5,18,10,1),fpppp( 5,18,10,2),fpppp( 5,18,10,3)/
     x 2.7904395D-04, 1.1858864D-05, 2.1863016D-08 /
      data fpppp( 5,18,11,1),fpppp( 5,18,11,2),fpppp( 5,18,11,3)/
     x 1.3002148D-04, 1.4367024D-05, 5.8947321D-08 /
      data fpppp( 5,18,12,1),fpppp( 5,18,12,2),fpppp( 5,18,12,3)/
     x 2.4661034D-05, 3.1834345D-05,-2.1797273D-07 /
      data fpppp( 5,18,13,1),fpppp( 5,18,13,2),fpppp( 5,18,13,3)/
     x-7.0161562D-04,-1.0484182D-04,-4.1146745D-08 /
      data fpppp( 5,18,14,1),fpppp( 5,18,14,2),fpppp( 5,18,14,3)/
     x-6.7947325D-04, 3.8727583D-05, 1.4189552D-07 /
      data fpppp( 5,18,15,1),fpppp( 5,18,15,2),fpppp( 5,18,15,3)/
     x-5.8911154D-04, 1.4806260D-05, 7.8225258D-08 /
      data fpppp( 5,18,16,1),fpppp( 5,18,16,2),fpppp( 5,18,16,3)/
     x-6.7947325D-04, 1.1808838D-05, 1.0508786D-07 /
      data fpppp( 5,18,17,1),fpppp( 5,18,17,2),fpppp( 5,18,17,3)/
     x-7.0161562D-04, 2.8331584D-06, 1.0608392D-07 /
      data fpppp( 5,19, 1,1),fpppp( 5,19, 1,2),fpppp( 5,19, 1,3)/
     x-1.3991850D-03, 1.2366886D-18, 1.8487176D-07 /
      data fpppp( 5,19, 2,1),fpppp( 5,19, 2,2),fpppp( 5,19, 2,3)/
     x-1.4023346D-03,-8.3721441D-19, 2.1139585D-07 /
      data fpppp( 5,19, 3,1),fpppp( 5,19, 3,2),fpppp( 5,19, 3,3)/
     x-1.2380958D-03,-3.5487779D-19, 2.0892454D-07 /
      data fpppp( 5,19, 4,1),fpppp( 5,19, 4,2),fpppp( 5,19, 4,3)/
     x-1.4023346D-03,-6.5881716D-19, 3.0793710D-07 /
      data fpppp( 5,19, 5,1),fpppp( 5,19, 5,2),fpppp( 5,19, 5,3)/
     x-1.3991850D-03,-3.0190682D-20,-2.0129325D-07 /
      data fpppp( 5,19, 6,1),fpppp( 5,19, 6,2),fpppp( 5,19, 6,3)/
     x-1.0753627D-04,-7.4466275D-19,-3.9075533D-07 /
      data fpppp( 5,19, 7,1),fpppp( 5,19, 7,2),fpppp( 5,19, 7,3)/
     x 1.5421473D-04, 3.9786378D-19, 8.0529745D-08 /
      data fpppp( 5,19, 8,1),fpppp( 5,19, 8,2),fpppp( 5,19, 8,3)/
     x 4.4015127D-04,-3.6550511D-19, 8.4113233D-08 /
      data fpppp( 5,19, 9,1),fpppp( 5,19, 9,2),fpppp( 5,19, 9,3)/
     x 5.2732964D-04,-1.8239093D-19, 4.6102674D-08 /
      data fpppp( 5,19,10,1),fpppp( 5,19,10,2),fpppp( 5,19,10,3)/
     x 4.4015127D-04,-3.2946932D-19, 8.4113233D-08 /
      data fpppp( 5,19,11,1),fpppp( 5,19,11,2),fpppp( 5,19,11,3)/
     x 1.5421473D-04,-8.4231769D-20, 8.0529745D-08 /
      data fpppp( 5,19,12,1),fpppp( 5,19,12,2),fpppp( 5,19,12,3)/
     x-1.0753627D-04, 8.3212958D-19,-3.9075533D-07 /
      data fpppp( 5,19,13,1),fpppp( 5,19,13,2),fpppp( 5,19,13,3)/
     x-1.3991850D-03, 7.7425057D-19,-2.0129325D-07 /
      data fpppp( 5,19,14,1),fpppp( 5,19,14,2),fpppp( 5,19,14,3)/
     x-1.4023346D-03,-1.7294729D-19, 3.0793710D-07 /
      data fpppp( 5,19,15,1),fpppp( 5,19,15,2),fpppp( 5,19,15,3)/
     x-1.2380958D-03, 9.2344910D-20, 2.0892454D-07 /
      data fpppp( 5,19,16,1),fpppp( 5,19,16,2),fpppp( 5,19,16,3)/
     x-1.4023346D-03,-1.1707701D-18, 2.1139585D-07 /
      data fpppp( 5,19,17,1),fpppp( 5,19,17,2),fpppp( 5,19,17,3)/
     x-1.3991850D-03, 1.1823867D-18, 1.8487176D-07 /
      data fpppp( 6, 1, 1,1),fpppp( 6, 1, 1,2),fpppp( 6, 1, 1,3)/
     x 1.3034110D-06,-1.7585150D-19, 7.4229144D-09 /
      data fpppp( 6, 1, 2,1),fpppp( 6, 1, 2,2),fpppp( 6, 1, 2,3)/
     x-6.2434170D-05,-2.1658494D-19, 2.1985185D-08 /
      data fpppp( 6, 1, 3,1),fpppp( 6, 1, 3,2),fpppp( 6, 1, 3,3)/
     x-1.2589033D-04, 5.9152184D-20, 4.9520157D-08 /
      data fpppp( 6, 1, 4,1),fpppp( 6, 1, 4,2),fpppp( 6, 1, 4,3)/
     x-6.2434170D-05,-3.4600233D-20, 3.1650672D-08 /
      data fpppp( 6, 1, 5,1),fpppp( 6, 1, 5,2),fpppp( 6, 1, 5,3)/
     x 1.3034110D-06, 2.0856068D-19,-3.1239036D-08 /
      data fpppp( 6, 1, 6,1),fpppp( 6, 1, 6,2),fpppp( 6, 1, 6,3)/
     x 2.2284999D-05,-2.9973140D-19,-4.3113269D-08 /
      data fpppp( 6, 1, 7,1),fpppp( 6, 1, 7,2),fpppp( 6, 1, 7,3)/
     x-4.0879796D-05,-2.4283135D-20,-2.4027996D-08 /
      data fpppp( 6, 1, 8,1),fpppp( 6, 1, 8,2),fpppp( 6, 1, 8,3)/
     x-5.7094318D-05,-2.1839522D-19, 2.5839974D-08 /
      data fpppp( 6, 1, 9,1),fpppp( 6, 1, 9,2),fpppp( 6, 1, 9,3)/
     x-6.2679816D-05,-2.5706217D-19, 3.3870066D-08 /
      data fpppp( 6, 1,10,1),fpppp( 6, 1,10,2),fpppp( 6, 1,10,3)/
     x-5.7094318D-05, 3.9365678D-19, 2.5839974D-08 /
      data fpppp( 6, 1,11,1),fpppp( 6, 1,11,2),fpppp( 6, 1,11,3)/
     x-4.0879796D-05, 3.6825501D-19,-2.4027996D-08 /
      data fpppp( 6, 1,12,1),fpppp( 6, 1,12,2),fpppp( 6, 1,12,3)/
     x 2.2284999D-05,-2.4438476D-19,-4.3113269D-08 /
      data fpppp( 6, 1,13,1),fpppp( 6, 1,13,2),fpppp( 6, 1,13,3)/
     x 1.3034110D-06, 3.7639879D-19,-3.1239036D-08 /
      data fpppp( 6, 1,14,1),fpppp( 6, 1,14,2),fpppp( 6, 1,14,3)/
     x-6.2434170D-05, 8.7411248D-20, 3.1650672D-08 /
      data fpppp( 6, 1,15,1),fpppp( 6, 1,15,2),fpppp( 6, 1,15,3)/
     x-1.2589033D-04, 7.7698829D-20, 4.9520157D-08 /
      data fpppp( 6, 1,16,1),fpppp( 6, 1,16,2),fpppp( 6, 1,16,3)/
     x-6.2434170D-05,-1.0299696D-19, 2.1985185D-08 /
      data fpppp( 6, 1,17,1),fpppp( 6, 1,17,2),fpppp( 6, 1,17,3)/
     x 1.3034110D-06,-6.9016829D-19, 7.4229144D-09 /
      data fpppp( 6, 2, 1,1),fpppp( 6, 2, 1,2),fpppp( 6, 2, 1,3)/
     x-7.6516831D-06, 3.9823090D-07,-1.1937950D-08 /
      data fpppp( 6, 2, 2,1),fpppp( 6, 2, 2,2),fpppp( 6, 2, 2,3)/
     x-2.9499724D-05, 1.4719416D-06, 3.0338720D-09 /
      data fpppp( 6, 2, 3,1),fpppp( 6, 2, 3,2),fpppp( 6, 2, 3,3)/
     x-3.3798543D-05, 3.6651140D-06, 3.7594840D-08 /
      data fpppp( 6, 2, 4,1),fpppp( 6, 2, 4,2),fpppp( 6, 2, 4,3)/
     x-2.9499724D-05, 1.9401704D-06, 3.5937954D-09 /
      data fpppp( 6, 2, 5,1),fpppp( 6, 2, 5,2),fpppp( 6, 2, 5,3)/
     x-7.6516831D-06,-1.4746844D-06,-1.4177643D-08 /
      data fpppp( 6, 2, 6,1),fpppp( 6, 2, 6,2),fpppp( 6, 2, 6,3)/
     x-4.9568652D-06,-2.6196309D-06,-1.7065745D-08 /
      data fpppp( 6, 2, 7,1),fpppp( 6, 2, 7,2),fpppp( 6, 2, 7,3)/
     x-1.7421924D-05,-9.1303111D-07,-7.0858299D-09 /
      data fpppp( 6, 2, 8,1),fpppp( 6, 2, 8,2),fpppp( 6, 2, 8,3)/
     x-3.4865837D-05, 7.7238854D-07, 7.4796210D-09 /
      data fpppp( 6, 2, 9,1),fpppp( 6, 2, 9,2),fpppp( 6, 2, 9,3)/
     x-3.6366452D-05, 1.0024989D-06, 1.7010083D-08 /
      data fpppp( 6, 2,10,1),fpppp( 6, 2,10,2),fpppp( 6, 2,10,3)/
     x-3.4865837D-05, 7.7238854D-07, 7.4796210D-09 /
      data fpppp( 6, 2,11,1),fpppp( 6, 2,11,2),fpppp( 6, 2,11,3)/
     x-1.7421924D-05,-9.1303111D-07,-7.0858299D-09 /
      data fpppp( 6, 2,12,1),fpppp( 6, 2,12,2),fpppp( 6, 2,12,3)/
     x-4.9568652D-06,-2.6196309D-06,-1.7065745D-08 /
      data fpppp( 6, 2,13,1),fpppp( 6, 2,13,2),fpppp( 6, 2,13,3)/
     x-7.6516831D-06,-1.4746844D-06,-1.4177643D-08 /
      data fpppp( 6, 2,14,1),fpppp( 6, 2,14,2),fpppp( 6, 2,14,3)/
     x-2.9499724D-05, 1.9401704D-06, 3.5937954D-09 /
      data fpppp( 6, 2,15,1),fpppp( 6, 2,15,2),fpppp( 6, 2,15,3)/
     x-3.3798543D-05, 3.6651140D-06, 3.7594840D-08 /
      data fpppp( 6, 2,16,1),fpppp( 6, 2,16,2),fpppp( 6, 2,16,3)/
     x-2.9499724D-05, 1.4719416D-06, 3.0338720D-09 /
      data fpppp( 6, 2,17,1),fpppp( 6, 2,17,2),fpppp( 6, 2,17,3)/
     x-7.6516831D-06, 3.9823090D-07,-1.1937950D-08 /
      data fpppp( 6, 3, 1,1),fpppp( 6, 3, 1,2),fpppp( 6, 3, 1,3)/
     x-1.7230645D-05, 2.7155544D-06,-4.8817183D-08 /
      data fpppp( 6, 3, 2,1),fpppp( 6, 3, 2,2),fpppp( 6, 3, 2,3)/
     x 1.5632610D-05, 4.7154733D-06,-2.2228540D-08 /
      data fpppp( 6, 3, 3,1),fpppp( 6, 3, 3,2),fpppp( 6, 3, 3,3)/
     x 6.4239093D-05, 7.9049457D-06, 4.7598017D-08 /
      data fpppp( 6, 3, 4,1),fpppp( 6, 3, 4,2),fpppp( 6, 3, 4,3)/
     x 1.5632610D-05, 6.9309810D-06,-3.3908124D-08 /
      data fpppp( 6, 3, 5,1),fpppp( 6, 3, 5,2),fpppp( 6, 3, 5,3)/
     x-1.7230645D-05,-6.1464764D-06,-2.0988445D-09 /
      data fpppp( 6, 3, 6,1),fpppp( 6, 3, 6,2),fpppp( 6, 3, 6,3)/
     x-3.9083555D-05,-7.5413090D-06, 1.0372328D-08 /
      data fpppp( 6, 3, 7,1),fpppp( 6, 3, 7,2),fpppp( 6, 3, 7,3)/
     x-2.0254260D-05,-9.8784169D-07, 1.9755448D-08 /
      data fpppp( 6, 3, 8,1),fpppp( 6, 3, 8,2),fpppp( 6, 3, 8,3)/
     x-3.6365670D-06, 3.2520815D-06,-1.5851067D-08 /
      data fpppp( 6, 3, 9,1),fpppp( 6, 3, 9,2),fpppp( 6, 3, 9,3)/
     x 2.5857872D-06, 1.4494348D-06,-6.0840944D-09 /
      data fpppp( 6, 3,10,1),fpppp( 6, 3,10,2),fpppp( 6, 3,10,3)/
     x-3.6365670D-06, 3.2520815D-06,-1.5851067D-08 /
      data fpppp( 6, 3,11,1),fpppp( 6, 3,11,2),fpppp( 6, 3,11,3)/
     x-2.0254260D-05,-9.8784169D-07, 1.9755448D-08 /
      data fpppp( 6, 3,12,1),fpppp( 6, 3,12,2),fpppp( 6, 3,12,3)/
     x-3.9083555D-05,-7.5413090D-06, 1.0372328D-08 /
      data fpppp( 6, 3,13,1),fpppp( 6, 3,13,2),fpppp( 6, 3,13,3)/
     x-1.7230645D-05,-6.1464764D-06,-2.0988445D-09 /
      data fpppp( 6, 3,14,1),fpppp( 6, 3,14,2),fpppp( 6, 3,14,3)/
     x 1.5632610D-05, 6.9309810D-06,-3.3908124D-08 /
      data fpppp( 6, 3,15,1),fpppp( 6, 3,15,2),fpppp( 6, 3,15,3)/
     x 6.4239093D-05, 7.9049457D-06, 4.7598017D-08 /
      data fpppp( 6, 3,16,1),fpppp( 6, 3,16,2),fpppp( 6, 3,16,3)/
     x 1.5632610D-05, 4.7154733D-06,-2.2228540D-08 /
      data fpppp( 6, 3,17,1),fpppp( 6, 3,17,2),fpppp( 6, 3,17,3)/
     x-1.7230645D-05, 2.7155544D-06,-4.8817183D-08 /
      data fpppp( 6, 4, 1,1),fpppp( 6, 4, 1,2),fpppp( 6, 4, 1,3)/
     x-2.4626069D-05, 2.1184672D-05,-2.4382123D-08 /
      data fpppp( 6, 4, 2,1),fpppp( 6, 4, 2,2),fpppp( 6, 4, 2,3)/
     x 1.8072338D-05, 1.3806756D-05,-2.5402105D-08 /
      data fpppp( 6, 4, 3,1),fpppp( 6, 4, 3,2),fpppp( 6, 4, 3,3)/
     x 1.4146626D-04,-9.4849494D-06,-1.9148536D-08 /
      data fpppp( 6, 4, 4,1),fpppp( 6, 4, 4,2),fpppp( 6, 4, 4,3)/
     x 1.8072338D-05, 2.2921607D-05,-3.8352394D-08 /
      data fpppp( 6, 4, 5,1),fpppp( 6, 4, 5,2),fpppp( 6, 4, 5,3)/
     x-2.4626069D-05,-1.5274730D-05, 2.7419033D-08 /
      data fpppp( 6, 4, 6,1),fpppp( 6, 4, 6,2),fpppp( 6, 4, 6,3)/
     x-4.9113355D-05,-8.4814822D-07, 3.2943482D-08 /
      data fpppp( 6, 4, 7,1),fpppp( 6, 4, 7,2),fpppp( 6, 4, 7,3)/
     x 6.8929135D-05,-1.0832356D-05, 1.1949834D-08 /
      data fpppp( 6, 4, 8,1),fpppp( 6, 4, 8,2),fpppp( 6, 4, 8,3)/
     x-3.9100569D-06, 1.0450533D-05,-2.1785582D-08 /
      data fpppp( 6, 4, 9,1),fpppp( 6, 4, 9,2),fpppp( 6, 4, 9,3)/
     x-2.6980389D-06,-1.8297206D-06,-7.3585919D-09 /
      data fpppp( 6, 4,10,1),fpppp( 6, 4,10,2),fpppp( 6, 4,10,3)/
     x-3.9100569D-06, 1.0450533D-05,-2.1785582D-08 /
      data fpppp( 6, 4,11,1),fpppp( 6, 4,11,2),fpppp( 6, 4,11,3)/
     x 6.8929135D-05,-1.0832356D-05, 1.1949834D-08 /
      data fpppp( 6, 4,12,1),fpppp( 6, 4,12,2),fpppp( 6, 4,12,3)/
     x-4.9113355D-05,-8.4814822D-07, 3.2943482D-08 /
      data fpppp( 6, 4,13,1),fpppp( 6, 4,13,2),fpppp( 6, 4,13,3)/
     x-2.4626069D-05,-1.5274730D-05, 2.7419033D-08 /
      data fpppp( 6, 4,14,1),fpppp( 6, 4,14,2),fpppp( 6, 4,14,3)/
     x 1.8072338D-05, 2.2921607D-05,-3.8352394D-08 /
      data fpppp( 6, 4,15,1),fpppp( 6, 4,15,2),fpppp( 6, 4,15,3)/
     x 1.4146626D-04,-9.4849494D-06,-1.9148536D-08 /
      data fpppp( 6, 4,16,1),fpppp( 6, 4,16,2),fpppp( 6, 4,16,3)/
     x 1.8072338D-05, 1.3806756D-05,-2.5402105D-08 /
      data fpppp( 6, 4,17,1),fpppp( 6, 4,17,2),fpppp( 6, 4,17,3)/
     x-2.4626069D-05, 2.1184672D-05,-2.4382123D-08 /
      data fpppp( 6, 5, 1,1),fpppp( 6, 5, 1,2),fpppp( 6, 5, 1,3)/
     x-3.7392873D-06, 5.6021313D-05, 1.6114434D-08 /
      data fpppp( 6, 5, 2,1),fpppp( 6, 5, 2,2),fpppp( 6, 5, 2,3)/
     x-1.1045514D-07, 2.8450799D-05,-1.1240559D-08 /
      data fpppp( 6, 5, 3,1),fpppp( 6, 5, 3,2),fpppp( 6, 5, 3,3)/
     x-1.9740706D-04,-5.0164536D-05,-6.9222564D-08 /
      data fpppp( 6, 5, 4,1),fpppp( 6, 5, 4,2),fpppp( 6, 5, 4,3)/
     x-1.1045514D-07, 4.9877005D-05,-2.0010024D-08 /
      data fpppp( 6, 5, 5,1),fpppp( 6, 5, 5,2),fpppp( 6, 5, 5,3)/
     x-3.7392873D-06,-2.9683510D-05, 5.1192295D-08 /
      data fpppp( 6, 5, 6,1),fpppp( 6, 5, 6,2),fpppp( 6, 5, 6,3)/
     x-5.3241351D-06, 2.5546659D-05, 1.4463136D-08 /
      data fpppp( 6, 5, 7,1),fpppp( 6, 5, 7,2),fpppp( 6, 5, 7,3)/
     x-1.4623124D-04,-4.1816369D-05,-1.0819259D-09 /
      data fpppp( 6, 5, 8,1),fpppp( 6, 5, 8,2),fpppp( 6, 5, 8,3)/
     x-4.7895923D-06, 2.8795381D-05,-1.2667423D-08 /
      data fpppp( 6, 5, 9,1),fpppp( 6, 5, 9,2),fpppp( 6, 5, 9,3)/
     x 2.5123766D-06,-1.1702763D-05, 3.9688700D-09 /
      data fpppp( 6, 5,10,1),fpppp( 6, 5,10,2),fpppp( 6, 5,10,3)/
     x-4.7895923D-06, 2.8795381D-05,-1.2667423D-08 /
      data fpppp( 6, 5,11,1),fpppp( 6, 5,11,2),fpppp( 6, 5,11,3)/
     x-1.4623124D-04,-4.1816369D-05,-1.0819259D-09 /
      data fpppp( 6, 5,12,1),fpppp( 6, 5,12,2),fpppp( 6, 5,12,3)/
     x-5.3241351D-06, 2.5546659D-05, 1.4463136D-08 /
      data fpppp( 6, 5,13,1),fpppp( 6, 5,13,2),fpppp( 6, 5,13,3)/
     x-3.7392873D-06,-2.9683510D-05, 5.1192295D-08 /
      data fpppp( 6, 5,14,1),fpppp( 6, 5,14,2),fpppp( 6, 5,14,3)/
     x-1.1045514D-07, 4.9877005D-05,-2.0010024D-08 /
      data fpppp( 6, 5,15,1),fpppp( 6, 5,15,2),fpppp( 6, 5,15,3)/
     x-1.9740706D-04,-5.0164536D-05,-6.9222564D-08 /
      data fpppp( 6, 5,16,1),fpppp( 6, 5,16,2),fpppp( 6, 5,16,3)/
     x-1.1045514D-07, 2.8450799D-05,-1.1240559D-08 /
      data fpppp( 6, 5,17,1),fpppp( 6, 5,17,2),fpppp( 6, 5,17,3)/
     x-3.7392873D-06, 5.6021313D-05, 1.6114434D-08 /
      data fpppp( 6, 6, 1,1),fpppp( 6, 6, 1,2),fpppp( 6, 6, 1,3)/
     x 1.2863708D-05, 3.6807012D-05, 1.1890156D-07 /
      data fpppp( 6, 6, 2,1),fpppp( 6, 6, 2,2),fpppp( 6, 6, 2,3)/
     x 4.2254681D-05, 1.8979908D-05, 4.4196673D-08 /
      data fpppp( 6, 6, 3,1),fpppp( 6, 6, 3,2),fpppp( 6, 6, 3,3)/
     x-3.7139988D-05,-3.2754766D-05,-1.4994771D-07 /
      data fpppp( 6, 6, 4,1),fpppp( 6, 6, 4,2),fpppp( 6, 6, 4,3)/
     x 4.2254681D-05, 3.4187054D-05, 7.3946149D-08 /
      data fpppp( 6, 6, 5,1),fpppp( 6, 6, 5,2),fpppp( 6, 6, 5,3)/
     x 1.2863708D-05,-2.4021571D-05,-9.6349294D-11 /
      data fpppp( 6, 6, 6,1),fpppp( 6, 6, 6,2),fpppp( 6, 6, 6,3)/
     x 3.5410261D-05, 2.3006675D-05, 2.1762857D-08 /
      data fpppp( 6, 6, 7,1),fpppp( 6, 6, 7,2),fpppp( 6, 6, 7,3)/
     x-6.6116502D-06,-3.0390566D-05,-4.0829521D-08 /
      data fpppp( 6, 6, 8,1),fpppp( 6, 6, 8,2),fpppp( 6, 6, 8,3)/
     x 2.4829704D-05, 1.8877601D-05, 3.1125956D-08 /
      data fpppp( 6, 6, 9,1),fpppp( 6, 6, 9,2),fpppp( 6, 6, 9,3)/
     x 4.9326698D-06,-8.0290947D-06,-1.6912230D-08 /
      data fpppp( 6, 6,10,1),fpppp( 6, 6,10,2),fpppp( 6, 6,10,3)/
     x 2.4829704D-05, 1.8877601D-05, 3.1125956D-08 /
      data fpppp( 6, 6,11,1),fpppp( 6, 6,11,2),fpppp( 6, 6,11,3)/
     x-6.6116502D-06,-3.0390566D-05,-4.0829521D-08 /
      data fpppp( 6, 6,12,1),fpppp( 6, 6,12,2),fpppp( 6, 6,12,3)/
     x 3.5410261D-05, 2.3006675D-05, 2.1762857D-08 /
      data fpppp( 6, 6,13,1),fpppp( 6, 6,13,2),fpppp( 6, 6,13,3)/
     x 1.2863708D-05,-2.4021571D-05,-9.6349294D-11 /
      data fpppp( 6, 6,14,1),fpppp( 6, 6,14,2),fpppp( 6, 6,14,3)/
     x 4.2254681D-05, 3.4187054D-05, 7.3946149D-08 /
      data fpppp( 6, 6,15,1),fpppp( 6, 6,15,2),fpppp( 6, 6,15,3)/
     x-3.7139988D-05,-3.2754766D-05,-1.4994771D-07 /
      data fpppp( 6, 6,16,1),fpppp( 6, 6,16,2),fpppp( 6, 6,16,3)/
     x 4.2254681D-05, 1.8979908D-05, 4.4196673D-08 /
      data fpppp( 6, 6,17,1),fpppp( 6, 6,17,2),fpppp( 6, 6,17,3)/
     x 1.2863708D-05, 3.6807012D-05, 1.1890156D-07 /
      data fpppp( 6, 7, 1,1),fpppp( 6, 7, 1,2),fpppp( 6, 7, 1,3)/
     x 1.3986663D-05,-8.9289507D-06, 6.8314600D-08 /
      data fpppp( 6, 7, 2,1),fpppp( 6, 7, 2,2),fpppp( 6, 7, 2,3)/
     x 1.0194718D-05,-3.0370213D-06, 3.8323354D-08 /
      data fpppp( 6, 7, 3,1),fpppp( 6, 7, 3,2),fpppp( 6, 7, 3,3)/
     x 1.9675648D-04, 1.1837008D-05,-4.9739811D-08 /
      data fpppp( 6, 7, 4,1),fpppp( 6, 7, 4,2),fpppp( 6, 7, 4,3)/
     x 1.0194718D-05,-4.7263131D-06, 6.5448744D-08 /
      data fpppp( 6, 7, 5,1),fpppp( 6, 7, 5,2),fpppp( 6, 7, 5,3)/
     x 1.3986663D-05,-2.1717836D-06,-4.0186958D-08 /
      data fpppp( 6, 7, 6,1),fpppp( 6, 7, 6,2),fpppp( 6, 7, 6,3)/
     x 2.5301558D-05, 3.0850459D-06,-8.0576405D-09 /
      data fpppp( 6, 7, 7,1),fpppp( 6, 7, 7,2),fpppp( 6, 7, 7,3)/
     x 1.1584407D-04,-1.0003142D-06,-4.6076227D-09 /
      data fpppp( 6, 7, 8,1),fpppp( 6, 7, 8,2),fpppp( 6, 7, 8,3)/
     x-1.1337173D-06,-4.5517153D-06, 2.5217209D-08 /
      data fpppp( 6, 7, 9,1),fpppp( 6, 7, 9,2),fpppp( 6, 7, 9,3)/
     x-4.6502615D-06, 6.6116035D-06,-2.1366755D-08 /
      data fpppp( 6, 7,10,1),fpppp( 6, 7,10,2),fpppp( 6, 7,10,3)/
     x-1.1337173D-06,-4.5517153D-06, 2.5217209D-08 /
      data fpppp( 6, 7,11,1),fpppp( 6, 7,11,2),fpppp( 6, 7,11,3)/
     x 1.1584407D-04,-1.0003142D-06,-4.6076227D-09 /
      data fpppp( 6, 7,12,1),fpppp( 6, 7,12,2),fpppp( 6, 7,12,3)/
     x 2.5301558D-05, 3.0850459D-06,-8.0576405D-09 /
      data fpppp( 6, 7,13,1),fpppp( 6, 7,13,2),fpppp( 6, 7,13,3)/
     x 1.3986663D-05,-2.1717836D-06,-4.0186958D-08 /
      data fpppp( 6, 7,14,1),fpppp( 6, 7,14,2),fpppp( 6, 7,14,3)/
     x 1.0194718D-05,-4.7263131D-06, 6.5448744D-08 /
      data fpppp( 6, 7,15,1),fpppp( 6, 7,15,2),fpppp( 6, 7,15,3)/
     x 1.9675648D-04, 1.1837008D-05,-4.9739811D-08 /
      data fpppp( 6, 7,16,1),fpppp( 6, 7,16,2),fpppp( 6, 7,16,3)/
     x 1.0194718D-05,-3.0370213D-06, 3.8323354D-08 /
      data fpppp( 6, 7,17,1),fpppp( 6, 7,17,2),fpppp( 6, 7,17,3)/
     x 1.3986663D-05,-8.9289507D-06, 6.8314600D-08 /
      data fpppp( 6, 8, 1,1),fpppp( 6, 8, 1,2),fpppp( 6, 8, 1,3)/
     x 1.0318801D-05,-8.7877334D-06,-6.7235813D-08 /
      data fpppp( 6, 8, 2,1),fpppp( 6, 8, 2,2),fpppp( 6, 8, 2,3)/
     x-4.2016705D-05,-4.9732868D-06,-1.4778375D-08 /
      data fpppp( 6, 8, 3,1),fpppp( 6, 8, 3,2),fpppp( 6, 8, 3,3)/
     x-5.9032469D-05, 6.6677198D-06, 1.1537594D-07 /
      data fpppp( 6, 8, 4,1),fpppp( 6, 8, 4,2),fpppp( 6, 8, 4,3)/
     x-4.2016705D-05,-9.0842337D-06,-2.6408819D-08 /
      data fpppp( 6, 8, 5,1),fpppp( 6, 8, 5,2),fpppp( 6, 8, 5,3)/
     x 1.0318801D-05, 7.6560542D-06,-2.0714034D-08 /
      data fpppp( 6, 8, 6,1),fpppp( 6, 8, 6,2),fpppp( 6, 8, 6,3)/
     x 1.0602859D-05, 2.6646055D-08,-4.4311743D-08 /
      data fpppp( 6, 8, 7,1),fpppp( 6, 8, 7,2),fpppp( 6, 8, 7,3)/
     x-1.4114777D-05,-1.7809944D-06, 3.3696017D-08 /
      data fpppp( 6, 8, 8,1),fpppp( 6, 8, 8,2),fpppp( 6, 8, 8,3)/
     x-2.2754541D-05,-6.4427614D-06,-3.7993654D-09 /
      data fpppp( 6, 8, 9,1),fpppp( 6, 8, 9,2),fpppp( 6, 8, 9,3)/
     x-1.4252948D-05, 1.1897701D-05, 5.7615376D-09 /
      data fpppp( 6, 8,10,1),fpppp( 6, 8,10,2),fpppp( 6, 8,10,3)/
     x-2.2754541D-05,-6.4427614D-06,-3.7993654D-09 /
      data fpppp( 6, 8,11,1),fpppp( 6, 8,11,2),fpppp( 6, 8,11,3)/
     x-1.4114777D-05,-1.7809944D-06, 3.3696017D-08 /
      data fpppp( 6, 8,12,1),fpppp( 6, 8,12,2),fpppp( 6, 8,12,3)/
     x 1.0602859D-05, 2.6646055D-08,-4.4311743D-08 /
      data fpppp( 6, 8,13,1),fpppp( 6, 8,13,2),fpppp( 6, 8,13,3)/
     x 1.0318801D-05, 7.6560542D-06,-2.0714034D-08 /
      data fpppp( 6, 8,14,1),fpppp( 6, 8,14,2),fpppp( 6, 8,14,3)/
     x-4.2016705D-05,-9.0842337D-06,-2.6408819D-08 /
      data fpppp( 6, 8,15,1),fpppp( 6, 8,15,2),fpppp( 6, 8,15,3)/
     x-5.9032469D-05, 6.6677198D-06, 1.1537594D-07 /
      data fpppp( 6, 8,16,1),fpppp( 6, 8,16,2),fpppp( 6, 8,16,3)/
     x-4.2016705D-05,-4.9732868D-06,-1.4778375D-08 /
      data fpppp( 6, 8,17,1),fpppp( 6, 8,17,2),fpppp( 6, 8,17,3)/
     x 1.0318801D-05,-8.7877334D-06,-6.7235813D-08 /
      data fpppp( 6, 9, 1,1),fpppp( 6, 9, 1,2),fpppp( 6, 9, 1,3)/
     x 8.8648063D-06, 4.0755948D-06,-4.4570111D-08 /
      data fpppp( 6, 9, 2,1),fpppp( 6, 9, 2,2),fpppp( 6, 9, 2,3)/
     x-2.8421096D-05, 6.1001181D-07,-7.6723318D-09 /
      data fpppp( 6, 9, 3,1),fpppp( 6, 9, 3,2),fpppp( 6, 9, 3,3)/
     x-8.8259240D-05,-6.9596657D-06, 8.3884697D-08 /
      data fpppp( 6, 9, 4,1),fpppp( 6, 9, 4,2),fpppp( 6, 9, 4,3)/
     x-2.8421096D-05,-1.6501258D-07,-1.5865648D-08 /
      data fpppp( 6, 9, 5,1),fpppp( 6, 9, 5,2),fpppp( 6, 9, 5,3)/
     x 8.8648063D-06, 7.1756924D-06,-1.1796845D-08 /
      data fpppp( 6, 9, 6,1),fpppp( 6, 9, 6,2),fpppp( 6, 9, 6,3)/
     x 1.6712071D-05,-6.4515030D-07,-3.6643446D-08 /
      data fpppp( 6, 9, 7,1),fpppp( 6, 9, 7,2),fpppp( 6, 9, 7,3)/
     x-1.3054365D-05,-8.2879848D-06, 7.8957239D-09 /
      data fpppp( 6, 9, 8,1),fpppp( 6, 9, 8,2),fpppp( 6, 9, 8,3)/
     x-1.3081272D-05,-4.2286845D-07, 7.3196328D-09 /
      data fpppp( 6, 9, 9,1),fpppp( 6, 9, 9,2),fpppp( 6, 9, 9,3)/
     x-1.2841735D-05, 1.1521142D-05, 1.2930915D-08 /
      data fpppp( 6, 9,10,1),fpppp( 6, 9,10,2),fpppp( 6, 9,10,3)/
     x-1.3081272D-05,-4.2286845D-07, 7.3196328D-09 /
      data fpppp( 6, 9,11,1),fpppp( 6, 9,11,2),fpppp( 6, 9,11,3)/
     x-1.3054365D-05,-8.2879848D-06, 7.8957239D-09 /
      data fpppp( 6, 9,12,1),fpppp( 6, 9,12,2),fpppp( 6, 9,12,3)/
     x 1.6712071D-05,-6.4515030D-07,-3.6643446D-08 /
      data fpppp( 6, 9,13,1),fpppp( 6, 9,13,2),fpppp( 6, 9,13,3)/
     x 8.8648063D-06, 7.1756924D-06,-1.1796845D-08 /
      data fpppp( 6, 9,14,1),fpppp( 6, 9,14,2),fpppp( 6, 9,14,3)/
     x-2.8421096D-05,-1.6501258D-07,-1.5865648D-08 /
      data fpppp( 6, 9,15,1),fpppp( 6, 9,15,2),fpppp( 6, 9,15,3)/
     x-8.8259240D-05,-6.9596657D-06, 8.3884697D-08 /
      data fpppp( 6, 9,16,1),fpppp( 6, 9,16,2),fpppp( 6, 9,16,3)/
     x-2.8421096D-05, 6.1001181D-07,-7.6723318D-09 /
      data fpppp( 6, 9,17,1),fpppp( 6, 9,17,2),fpppp( 6, 9,17,3)/
     x 8.8648063D-06, 4.0755948D-06,-4.4570111D-08 /
      data fpppp( 6,10, 1,1),fpppp( 6,10, 1,2),fpppp( 6,10, 1,3)/
     x 8.6506387D-06, 6.5041056D-06,-2.2204959D-09 /
      data fpppp( 6,10, 2,1),fpppp( 6,10, 2,2),fpppp( 6,10, 2,3)/
     x-4.5230719D-06, 3.3942394D-06, 7.4078744D-09 /
      data fpppp( 6,10, 3,1),fpppp( 6,10, 3,2),fpppp( 6,10, 3,3)/
     x-9.4185362D-06,-4.1349473D-06, 2.9781328D-08 /
      data fpppp( 6,10, 4,1),fpppp( 6,10, 4,2),fpppp( 6,10, 4,3)/
     x-4.5230719D-06, 3.8034879D-06, 7.5469897D-09 /
      data fpppp( 6,10, 5,1),fpppp( 6,10, 5,2),fpppp( 6,10, 5,3)/
     x 8.6506387D-06, 4.8671115D-06,-2.7769573D-09 /
      data fpppp( 6,10, 6,1),fpppp( 6,10, 6,2),fpppp( 6,10, 6,3)/
     x 2.0514461D-05,-8.0662259D-06,-4.3116560D-08 /
      data fpppp( 6,10, 7,1),fpppp( 6,10, 7,2),fpppp( 6,10, 7,3)/
     x 2.2198518D-06,-8.8157418D-06, 5.0878026D-09 /
      data fpppp( 6,10, 8,1),fpppp( 6,10, 8,2),fpppp( 6,10, 8,3)/
     x-3.1032692D-06, 4.8746459D-06, 1.1856058D-08 /
      data fpppp( 6,10, 9,1),fpppp( 6,10, 9,2),fpppp( 6,10, 9,3)/
     x-1.2378978D-06, 1.0876600D-05, 1.3047192D-08 /
      data fpppp( 6,10,10,1),fpppp( 6,10,10,2),fpppp( 6,10,10,3)/
     x-3.1032692D-06, 4.8746459D-06, 1.1856058D-08 /
      data fpppp( 6,10,11,1),fpppp( 6,10,11,2),fpppp( 6,10,11,3)/
     x 2.2198518D-06,-8.8157418D-06, 5.0878026D-09 /
      data fpppp( 6,10,12,1),fpppp( 6,10,12,2),fpppp( 6,10,12,3)/
     x 2.0514461D-05,-8.0662259D-06,-4.3116560D-08 /
      data fpppp( 6,10,13,1),fpppp( 6,10,13,2),fpppp( 6,10,13,3)/
     x 8.6506387D-06, 4.8671115D-06,-2.7769573D-09 /
      data fpppp( 6,10,14,1),fpppp( 6,10,14,2),fpppp( 6,10,14,3)/
     x-4.5230719D-06, 3.8034879D-06, 7.5469897D-09 /
      data fpppp( 6,10,15,1),fpppp( 6,10,15,2),fpppp( 6,10,15,3)/
     x-9.4185362D-06,-4.1349473D-06, 2.9781328D-08 /
      data fpppp( 6,10,16,1),fpppp( 6,10,16,2),fpppp( 6,10,16,3)/
     x-4.5230719D-06, 3.3942394D-06, 7.4078744D-09 /
      data fpppp( 6,10,17,1),fpppp( 6,10,17,2),fpppp( 6,10,17,3)/
     x 8.6506387D-06, 6.5041056D-06,-2.2204959D-09 /
      data fpppp( 6,11, 1,1),fpppp( 6,11, 1,2),fpppp( 6,11, 1,3)/
     x 1.1772401D-05, 7.1119063D-06, 1.6940802D-08 /
      data fpppp( 6,11, 2,1),fpppp( 6,11, 2,2),fpppp( 6,11, 2,3)/
     x 1.4426371D-05, 6.0111769D-06, 1.3603420D-08 /
      data fpppp( 6,11, 3,1),fpppp( 6,11, 3,2),fpppp( 6,11, 3,3)/
     x 2.2479236D-05, 2.9529348D-06, 4.4109388D-09 /
      data fpppp( 6,11, 4,1),fpppp( 6,11, 4,2),fpppp( 6,11, 4,3)/
     x 1.4426371D-05, 6.7459870D-06, 1.5711306D-08 /
      data fpppp( 6,11, 5,1),fpppp( 6,11, 5,2),fpppp( 6,11, 5,3)/
     x 1.1772401D-05, 4.1726656D-06, 8.5092580D-09 /
      data fpppp( 6,11, 6,1),fpppp( 6,11, 6,2),fpppp( 6,11, 6,3)/
     x 2.8349452D-05,-2.2634192D-05,-6.0382263D-08 /
      data fpppp( 6,11, 7,1),fpppp( 6,11, 7,2),fpppp( 6,11, 7,3)/
     x 4.9103132D-06,-4.3993629D-06, 1.8796283D-08 /
      data fpppp( 6,11, 8,1),fpppp( 6,11, 8,2),fpppp( 6,11, 8,3)/
     x 9.4236713D-06, 9.7178381D-06, 1.0335214D-08 /
      data fpppp( 6,11, 9,1),fpppp( 6,11, 9,2),fpppp( 6,11, 9,3)/
     x 1.0642676D-05, 9.9636621D-06, 1.0000779D-08 /
      data fpppp( 6,11,10,1),fpppp( 6,11,10,2),fpppp( 6,11,10,3)/
     x 9.4236713D-06, 9.7178381D-06, 1.0335214D-08 /
      data fpppp( 6,11,11,1),fpppp( 6,11,11,2),fpppp( 6,11,11,3)/
     x 4.9103132D-06,-4.3993629D-06, 1.8796283D-08 /
      data fpppp( 6,11,12,1),fpppp( 6,11,12,2),fpppp( 6,11,12,3)/
     x 2.8349452D-05,-2.2634192D-05,-6.0382263D-08 /
      data fpppp( 6,11,13,1),fpppp( 6,11,13,2),fpppp( 6,11,13,3)/
     x 1.1772401D-05, 4.1726656D-06, 8.5092580D-09 /
      data fpppp( 6,11,14,1),fpppp( 6,11,14,2),fpppp( 6,11,14,3)/
     x 1.4426371D-05, 6.7459870D-06, 1.5711306D-08 /
      data fpppp( 6,11,15,1),fpppp( 6,11,15,2),fpppp( 6,11,15,3)/
     x 2.2479236D-05, 2.9529348D-06, 4.4109388D-09 /
      data fpppp( 6,11,16,1),fpppp( 6,11,16,2),fpppp( 6,11,16,3)/
     x 1.4426371D-05, 6.0111769D-06, 1.3603420D-08 /
      data fpppp( 6,11,17,1),fpppp( 6,11,17,2),fpppp( 6,11,17,3)/
     x 1.1772401D-05, 7.1119063D-06, 1.6940802D-08 /
      data fpppp( 6,12, 1,1),fpppp( 6,12, 1,2),fpppp( 6,12, 1,3)/
     x 1.2883711D-05, 9.6870991D-06, 1.6692803D-08 /
      data fpppp( 6,12, 2,1),fpppp( 6,12, 2,2),fpppp( 6,12, 2,3)/
     x 2.6004352D-05, 9.2522306D-06, 1.1027417D-08 /
      data fpppp( 6,12, 3,1),fpppp( 6,12, 3,2),fpppp( 6,12, 3,3)/
     x 3.1909985D-05, 8.0946064D-06,-2.0964838D-09 /
      data fpppp( 6,12, 4,1),fpppp( 6,12, 4,2),fpppp( 6,12, 4,3)/
     x 2.6004352D-05, 9.4666272D-06, 1.0884416D-08 /
      data fpppp( 6,12, 5,1),fpppp( 6,12, 5,2),fpppp( 6,12, 5,3)/
     x 1.2883711D-05, 8.8295129D-06, 1.7264806D-08 /
      data fpppp( 6,12, 6,1),fpppp( 6,12, 6,2),fpppp( 6,12, 6,3)/
     x 3.0000339D-05,-4.6624198D-05,-6.7450541D-08 /
      data fpppp( 6,12, 7,1),fpppp( 6,12, 7,2),fpppp( 6,12, 7,3)/
     x 1.0535563D-05, 7.1533723D-06, 3.3506799D-08 /
      data fpppp( 6,12, 8,1),fpppp( 6,12, 8,2),fpppp( 6,12, 8,3)/
     x 1.7118909D-05, 1.2196489D-05, 2.9803032D-09 /
      data fpppp( 6,12, 9,1),fpppp( 6,12, 9,2),fpppp( 6,12, 9,3)/
     x 1.6416067D-05, 9.8975194D-06, 7.7010847D-09 /
      data fpppp( 6,12,10,1),fpppp( 6,12,10,2),fpppp( 6,12,10,3)/
     x 1.7118909D-05, 1.2196489D-05, 2.9803032D-09 /
      data fpppp( 6,12,11,1),fpppp( 6,12,11,2),fpppp( 6,12,11,3)/
     x 1.0535563D-05, 7.1533723D-06, 3.3506799D-08 /
      data fpppp( 6,12,12,1),fpppp( 6,12,12,2),fpppp( 6,12,12,3)/
     x 3.0000339D-05,-4.6624198D-05,-6.7450541D-08 /
      data fpppp( 6,12,13,1),fpppp( 6,12,13,2),fpppp( 6,12,13,3)/
     x 1.2883711D-05, 8.8295129D-06, 1.7264806D-08 /
      data fpppp( 6,12,14,1),fpppp( 6,12,14,2),fpppp( 6,12,14,3)/
     x 2.6004352D-05, 9.4666272D-06, 1.0884416D-08 /
      data fpppp( 6,12,15,1),fpppp( 6,12,15,2),fpppp( 6,12,15,3)/
     x 3.1909985D-05, 8.0946064D-06,-2.0964838D-09 /
      data fpppp( 6,12,16,1),fpppp( 6,12,16,2),fpppp( 6,12,16,3)/
     x 2.6004352D-05, 9.2522306D-06, 1.1027417D-08 /
      data fpppp( 6,12,17,1),fpppp( 6,12,17,2),fpppp( 6,12,17,3)/
     x 1.2883711D-05, 9.6870991D-06, 1.6692803D-08 /
      data fpppp( 6,13, 1,1),fpppp( 6,13, 1,2),fpppp( 6,13, 1,3)/
     x 4.9436183D-05, 1.3489810D-05,-6.8020998D-10 /
      data fpppp( 6,13, 2,1),fpppp( 6,13, 2,2),fpppp( 6,13, 2,3)/
     x 2.8577293D-05, 1.2579008D-05,-1.2300246D-09 /
      data fpppp( 6,13, 3,1),fpppp( 6,13, 3,2),fpppp( 6,13, 3,3)/
     x 3.1189588D-05, 1.1666982D-05,-1.0690528D-09 /
      data fpppp( 6,13, 4,1),fpppp( 6,13, 4,2),fpppp( 6,13, 4,3)/
     x 2.8577293D-05, 1.0759242D-05,-3.3958334D-09 /
      data fpppp( 6,13, 5,1),fpppp( 6,13, 5,2),fpppp( 6,13, 5,3)/
     x 4.9436183D-05, 2.0768874D-05, 7.9830251D-09 /
      data fpppp( 6,13, 6,1),fpppp( 6,13, 6,2),fpppp( 6,13, 6,3)/
     x 7.3635381D-05,-8.2369523D-05,-2.4114739D-08 /
      data fpppp( 6,13, 7,1),fpppp( 6,13, 7,2),fpppp( 6,13, 7,3)/
     x 1.1893694D-05, 2.8191235D-05, 2.5061681D-08 /
      data fpppp( 6,13, 8,1),fpppp( 6,13, 8,2),fpppp( 6,13, 8,3)/
     x 1.8166748D-05, 1.0729919D-05,-7.4179015D-09 /
      data fpppp( 6,13, 9,1),fpppp( 6,13, 9,2),fpppp( 6,13, 9,3)/
     x 1.8566763D-05, 1.1870229D-05, 4.4756200D-09 /
      data fpppp( 6,13,10,1),fpppp( 6,13,10,2),fpppp( 6,13,10,3)/
     x 1.8166748D-05, 1.0729919D-05,-7.4179015D-09 /
      data fpppp( 6,13,11,1),fpppp( 6,13,11,2),fpppp( 6,13,11,3)/
     x 1.1893694D-05, 2.8191235D-05, 2.5061681D-08 /
      data fpppp( 6,13,12,1),fpppp( 6,13,12,2),fpppp( 6,13,12,3)/
     x 7.3635381D-05,-8.2369523D-05,-2.4114739D-08 /
      data fpppp( 6,13,13,1),fpppp( 6,13,13,2),fpppp( 6,13,13,3)/
     x 4.9436183D-05, 2.0768874D-05, 7.9830251D-09 /
      data fpppp( 6,13,14,1),fpppp( 6,13,14,2),fpppp( 6,13,14,3)/
     x 2.8577293D-05, 1.0759242D-05,-3.3958334D-09 /
      data fpppp( 6,13,15,1),fpppp( 6,13,15,2),fpppp( 6,13,15,3)/
     x 3.1189588D-05, 1.1666982D-05,-1.0690528D-09 /
      data fpppp( 6,13,16,1),fpppp( 6,13,16,2),fpppp( 6,13,16,3)/
     x 2.8577293D-05, 1.2579008D-05,-1.2300246D-09 /
      data fpppp( 6,13,17,1),fpppp( 6,13,17,2),fpppp( 6,13,17,3)/
     x 4.9436183D-05, 1.3489810D-05,-6.8020998D-10 /
      data fpppp( 6,14, 1,1),fpppp( 6,14, 1,2),fpppp( 6,14, 1,3)/
     x 1.0446071D-04, 2.3525278D-05,-2.2159620D-08 /
      data fpppp( 6,14, 2,1),fpppp( 6,14, 2,2),fpppp( 6,14, 2,3)/
     x 3.1438676D-05, 1.9541976D-05,-1.7298670D-08 /
      data fpppp( 6,14, 3,1),fpppp( 6,14, 3,2),fpppp( 6,14, 3,3)/
     x 3.2062455D-05, 1.2274676D-05,-9.4342393D-09 /
      data fpppp( 6,14, 4,1),fpppp( 6,14, 4,2),fpppp( 6,14, 4,3)/
     x 3.1438676D-05, 1.6501370D-05,-1.2081992D-08 /
      data fpppp( 6,14, 5,1),fpppp( 6,14, 5,2),fpppp( 6,14, 5,3)/
     x 1.0446071D-04, 3.5687704D-05,-4.3026331D-08 /
      data fpppp( 6,14, 6,1),fpppp( 6,14, 6,2),fpppp( 6,14, 6,3)/
     x 1.1389159D-04,-1.3670364D-04, 1.0300811D-07 /
      data fpppp( 6,14, 7,1),fpppp( 6,14, 7,2),fpppp( 6,14, 7,3)/
     x 1.6258601D-05, 6.6448265D-05,-2.1638535D-08 /
      data fpppp( 6,14, 8,1),fpppp( 6,14, 8,2),fpppp( 6,14, 8,3)/
     x 1.9871256D-05, 3.3479966D-06,-1.8907266D-08 /
      data fpppp( 6,14, 9,1),fpppp( 6,14, 9,2),fpppp( 6,14, 9,3)/
     x 2.1592107D-05, 1.6655166D-05,-4.4042804D-09 /
      data fpppp( 6,14,10,1),fpppp( 6,14,10,2),fpppp( 6,14,10,3)/
     x 1.9871256D-05, 3.3479966D-06,-1.8907266D-08 /
      data fpppp( 6,14,11,1),fpppp( 6,14,11,2),fpppp( 6,14,11,3)/
     x 1.6258601D-05, 6.6448265D-05,-2.1638535D-08 /
      data fpppp( 6,14,12,1),fpppp( 6,14,12,2),fpppp( 6,14,12,3)/
     x 1.1389159D-04,-1.3670364D-04, 1.0300811D-07 /
      data fpppp( 6,14,13,1),fpppp( 6,14,13,2),fpppp( 6,14,13,3)/
     x 1.0446071D-04, 3.5687704D-05,-4.3026331D-08 /
      data fpppp( 6,14,14,1),fpppp( 6,14,14,2),fpppp( 6,14,14,3)/
     x 3.1438676D-05, 1.6501370D-05,-1.2081992D-08 /
      data fpppp( 6,14,15,1),fpppp( 6,14,15,2),fpppp( 6,14,15,3)/
     x 3.2062455D-05, 1.2274676D-05,-9.4342393D-09 /
      data fpppp( 6,14,16,1),fpppp( 6,14,16,2),fpppp( 6,14,16,3)/
     x 3.1438676D-05, 1.9541976D-05,-1.7298670D-08 /
      data fpppp( 6,14,17,1),fpppp( 6,14,17,2),fpppp( 6,14,17,3)/
     x 1.0446071D-04, 2.3525278D-05,-2.2159620D-08 /
      data fpppp( 6,15, 1,1),fpppp( 6,15, 1,2),fpppp( 6,15, 1,3)/
     x-7.9788228D-05, 4.1342216D-05,-6.6363007D-08 /
      data fpppp( 6,15, 2,1),fpppp( 6,15, 2,2),fpppp( 6,15, 2,3)/
     x 4.0865698D-05, 3.1425101D-05,-5.3691900D-08 /
      data fpppp( 6,15, 3,1),fpppp( 6,15, 3,2),fpppp( 6,15, 3,3)/
     x 5.1827377D-05, 8.5716241D-06,-2.5765872D-08 /
      data fpppp( 6,15, 4,1),fpppp( 6,15, 4,2),fpppp( 6,15, 4,3)/
     x 4.0865698D-05, 3.0995416D-05,-5.1232066D-08 /
      data fpppp( 6,15, 5,1),fpppp( 6,15, 5,2),fpppp( 6,15, 5,3)/
     x-7.9788228D-05, 4.3060955D-05,-7.6202343D-08 /
      data fpppp( 6,15, 6,1),fpppp( 6,15, 6,2),fpppp( 6,15, 6,3)/
     x-1.9760214D-04,-1.9718339D-04, 3.0137675D-07 /
      data fpppp( 6,15, 7,1),fpppp( 6,15, 7,2),fpppp( 6,15, 7,3)/
     x 5.2828780D-06, 1.1533370D-04,-1.2500066D-07 /
      data fpppp( 6,15, 8,1),fpppp( 6,15, 8,2),fpppp( 6,15, 8,3)/
     x 2.7432318D-05,-7.9283898D-06,-2.1435001D-08 /
      data fpppp( 6,15, 9,1),fpppp( 6,15, 9,2),fpppp( 6,15, 9,3)/
     x 3.0717677D-05, 2.2800181D-05,-2.8837515D-08 /
      data fpppp( 6,15,10,1),fpppp( 6,15,10,2),fpppp( 6,15,10,3)/
     x 2.7432318D-05,-7.9283898D-06,-2.1435001D-08 /
      data fpppp( 6,15,11,1),fpppp( 6,15,11,2),fpppp( 6,15,11,3)/
     x 5.2828780D-06, 1.1533370D-04,-1.2500066D-07 /
      data fpppp( 6,15,12,1),fpppp( 6,15,12,2),fpppp( 6,15,12,3)/
     x-1.9760214D-04,-1.9718339D-04, 3.0137675D-07 /
      data fpppp( 6,15,13,1),fpppp( 6,15,13,2),fpppp( 6,15,13,3)/
     x-7.9788228D-05, 4.3060955D-05,-7.6202343D-08 /
      data fpppp( 6,15,14,1),fpppp( 6,15,14,2),fpppp( 6,15,14,3)/
     x 4.0865698D-05, 3.0995416D-05,-5.1232066D-08 /
      data fpppp( 6,15,15,1),fpppp( 6,15,15,2),fpppp( 6,15,15,3)/
     x 5.1827377D-05, 8.5716241D-06,-2.5765872D-08 /
      data fpppp( 6,15,16,1),fpppp( 6,15,16,2),fpppp( 6,15,16,3)/
     x 4.0865698D-05, 3.1425101D-05,-5.3691900D-08 /
      data fpppp( 6,15,17,1),fpppp( 6,15,17,2),fpppp( 6,15,17,3)/
     x-7.9788228D-05, 4.1342216D-05,-6.6363007D-08 /
      data fpppp( 6,16, 1,1),fpppp( 6,16, 1,2),fpppp( 6,16, 1,3)/
     x 3.3219079D-05, 4.4421573D-05,-7.3036597D-08 /
      data fpppp( 6,16, 2,1),fpppp( 6,16, 2,2),fpppp( 6,16, 2,3)/
     x 8.2644873D-05, 3.4263671D-05,-7.2597238D-08 /
      data fpppp( 6,16, 3,1),fpppp( 6,16, 3,2),fpppp( 6,16, 3,3)/
     x 6.2066898D-05, 7.4369360D-06,-5.0359998D-08 /
      data fpppp( 6,16, 4,1),fpppp( 6,16, 4,2),fpppp( 6,16, 4,3)/
     x 8.2644873D-05, 3.8951114D-05,-1.0441534D-07 /
      data fpppp( 6,16, 5,1),fpppp( 6,16, 5,2),fpppp( 6,16, 5,3)/
     x 3.3219079D-05, 2.5671799D-05, 5.4235821D-08 /
      data fpppp( 6,16, 6,1),fpppp( 6,16, 6,2),fpppp( 6,16, 6,3)/
     x-3.0136629D-04,-1.8956302D-04, 2.1451002D-07 /
      data fpppp( 6,16, 7,1),fpppp( 6,16, 7,2),fpppp( 6,16, 7,3)/
     x 1.2982882D-05, 1.1932175D-04,-7.1019433D-08 /
      data fpppp( 6,16, 8,1),fpppp( 6,16, 8,2),fpppp( 6,16, 8,3)/
     x 3.6515972D-05,-9.1056534D-06,-4.9695413D-08 /
      data fpppp( 6,16, 9,1),fpppp( 6,16, 9,2),fpppp( 6,16, 9,3)/
     x 4.1513269D-05, 2.2792325D-05,-4.2174317D-08 /
      data fpppp( 6,16,10,1),fpppp( 6,16,10,2),fpppp( 6,16,10,3)/
     x 3.6515972D-05,-9.1056534D-06,-4.9695413D-08 /
      data fpppp( 6,16,11,1),fpppp( 6,16,11,2),fpppp( 6,16,11,3)/
     x 1.2982882D-05, 1.1932175D-04,-7.1019433D-08 /
      data fpppp( 6,16,12,1),fpppp( 6,16,12,2),fpppp( 6,16,12,3)/
     x-3.0136629D-04,-1.8956302D-04, 2.1451002D-07 /
      data fpppp( 6,16,13,1),fpppp( 6,16,13,2),fpppp( 6,16,13,3)/
     x 3.3219079D-05, 2.5671799D-05, 5.4235821D-08 /
      data fpppp( 6,16,14,1),fpppp( 6,16,14,2),fpppp( 6,16,14,3)/
     x 8.2644873D-05, 3.8951114D-05,-1.0441534D-07 /
      data fpppp( 6,16,15,1),fpppp( 6,16,15,2),fpppp( 6,16,15,3)/
     x 6.2066898D-05, 7.4369360D-06,-5.0359998D-08 /
      data fpppp( 6,16,16,1),fpppp( 6,16,16,2),fpppp( 6,16,16,3)/
     x 8.2644873D-05, 3.4263671D-05,-7.2597238D-08 /
      data fpppp( 6,16,17,1),fpppp( 6,16,17,2),fpppp( 6,16,17,3)/
     x 3.3219079D-05, 4.4421573D-05,-7.3036597D-08 /
      data fpppp( 6,17, 1,1),fpppp( 6,17, 1,2),fpppp( 6,17, 1,3)/
     x-1.4182361D-04, 2.6194885D-05, 6.6048990D-08 /
      data fpppp( 6,17, 2,1),fpppp( 6,17, 2,2),fpppp( 6,17, 2,3)/
     x 1.6461399D-04, 2.4364849D-05, 6.5083334D-09 /
      data fpppp( 6,17, 3,1),fpppp( 6,17, 3,2),fpppp( 6,17, 3,3)/
     x 2.5097548D-04, 1.0804145D-05,-1.1396365D-07 /
      data fpppp( 6,17, 4,1),fpppp( 6,17, 4,2),fpppp( 6,17, 4,3)/
     x 1.6461399D-04, 3.8300777D-05,-2.1175989D-08 /
      data fpppp( 6,17, 5,1),fpppp( 6,17, 5,2),fpppp( 6,17, 5,3)/
     x-1.4182361D-04,-2.9548826D-05, 1.7678628D-07 /
      data fpppp( 6,17, 6,1),fpppp( 6,17, 6,2),fpppp( 6,17, 6,3)/
     x 1.3005156D-04,-8.4175789D-05,-1.1093628D-07 /
      data fpppp( 6,17, 7,1),fpppp( 6,17, 7,2),fpppp( 6,17, 7,3)/
     x 9.0012757D-05, 5.9465297D-05, 9.8509017D-08 /
      data fpppp( 6,17, 8,1),fpppp( 6,17, 8,2),fpppp( 6,17, 8,3)/
     x 1.0886985D-04, 4.5388931D-06,-5.6506382D-08 /
      data fpppp( 6,17, 9,1),fpppp( 6,17, 9,2),fpppp( 6,17, 9,3)/
     x 1.0387892D-04, 1.4357807D-05,-6.4003700D-08 /
      data fpppp( 6,17,10,1),fpppp( 6,17,10,2),fpppp( 6,17,10,3)/
     x 1.0886985D-04, 4.5388931D-06,-5.6506382D-08 /
      data fpppp( 6,17,11,1),fpppp( 6,17,11,2),fpppp( 6,17,11,3)/
     x 9.0012757D-05, 5.9465297D-05, 9.8509017D-08 /
      data fpppp( 6,17,12,1),fpppp( 6,17,12,2),fpppp( 6,17,12,3)/
     x 1.3005156D-04,-8.4175789D-05,-1.1093628D-07 /
      data fpppp( 6,17,13,1),fpppp( 6,17,13,2),fpppp( 6,17,13,3)/
     x-1.4182361D-04,-2.9548826D-05, 1.7678628D-07 /
      data fpppp( 6,17,14,1),fpppp( 6,17,14,2),fpppp( 6,17,14,3)/
     x 1.6461399D-04, 3.8300777D-05,-2.1175989D-08 /
      data fpppp( 6,17,15,1),fpppp( 6,17,15,2),fpppp( 6,17,15,3)/
     x 2.5097548D-04, 1.0804145D-05,-1.1396365D-07 /
      data fpppp( 6,17,16,1),fpppp( 6,17,16,2),fpppp( 6,17,16,3)/
     x 1.6461399D-04, 2.4364849D-05, 6.5083334D-09 /
      data fpppp( 6,17,17,1),fpppp( 6,17,17,2),fpppp( 6,17,17,3)/
     x-1.4182361D-04, 2.6194885D-05, 6.6048990D-08 /
      data fpppp( 6,18, 1,1),fpppp( 6,18, 1,2),fpppp( 6,18, 1,3)/
     x-7.6955901D-05,-6.5360491D-06, 6.5764876D-08 /
      data fpppp( 6,18, 2,1),fpppp( 6,18, 2,2),fpppp( 6,18, 2,3)/
     x-3.3344768D-04,-1.0723502D-06, 7.2982094D-08 /
      data fpppp( 6,18, 3,1),fpppp( 6,18, 3,2),fpppp( 6,18, 3,3)/
     x-3.5966110D-04, 1.0825793D-05, 7.2897602D-08 /
      data fpppp( 6,18, 4,1),fpppp( 6,18, 4,2),fpppp( 6,18, 4,3)/
     x-3.3344768D-04, 2.0338098D-07, 9.8369096D-08 /
      data fpppp( 6,18, 5,1),fpppp( 6,18, 5,2),fpppp( 6,18, 5,3)/
     x-7.6955901D-05,-1.1638974D-05,-3.5783129D-08 /
      data fpppp( 6,18, 6,1),fpppp( 6,18, 6,2),fpppp( 6,18, 6,3)/
     x 6.2756721D-05,-2.1495374D-05,-1.5804597D-07 /
      data fpppp( 6,18, 7,1),fpppp( 6,18, 7,2),fpppp( 6,18, 7,3)/
     x 4.7649576D-05, 1.3578838D-05, 3.0829807D-08 /
      data fpppp( 6,18, 8,1),fpppp( 6,18, 8,2),fpppp( 6,18, 8,3)/
     x 1.2805275D-04, 9.4855945D-06, 2.7216245D-08 /
      data fpppp( 6,18, 9,1),fpppp( 6,18, 9,2),fpppp( 6,18, 9,3)/
     x 1.6376084D-04, 9.1198980D-06, 6.1614656D-09 /
      data fpppp( 6,18,10,1),fpppp( 6,18,10,2),fpppp( 6,18,10,3)/
     x 1.2805275D-04, 9.4855945D-06, 2.7216245D-08 /
      data fpppp( 6,18,11,1),fpppp( 6,18,11,2),fpppp( 6,18,11,3)/
     x 4.7649576D-05, 1.3578838D-05, 3.0829807D-08 /
      data fpppp( 6,18,12,1),fpppp( 6,18,12,2),fpppp( 6,18,12,3)/
     x 6.2756721D-05,-2.1495374D-05,-1.5804597D-07 /
      data fpppp( 6,18,13,1),fpppp( 6,18,13,2),fpppp( 6,18,13,3)/
     x-7.6955901D-05,-1.1638974D-05,-3.5783129D-08 /
      data fpppp( 6,18,14,1),fpppp( 6,18,14,2),fpppp( 6,18,14,3)/
     x-3.3344768D-04, 2.0338098D-07, 9.8369096D-08 /
      data fpppp( 6,18,15,1),fpppp( 6,18,15,2),fpppp( 6,18,15,3)/
     x-3.5966110D-04, 1.0825793D-05, 7.2897602D-08 /
      data fpppp( 6,18,16,1),fpppp( 6,18,16,2),fpppp( 6,18,16,3)/
     x-3.3344768D-04,-1.0723502D-06, 7.2982094D-08 /
      data fpppp( 6,18,17,1),fpppp( 6,18,17,2),fpppp( 6,18,17,3)/
     x-7.6955901D-05,-6.5360491D-06, 6.5764876D-08 /
      data fpppp( 6,19, 1,1),fpppp( 6,19, 1,2),fpppp( 6,19, 1,3)/
     x-8.0634019D-05,-5.6430771D-19, 1.0530068D-07 /
      data fpppp( 6,19, 2,1),fpppp( 6,19, 2,2),fpppp( 6,19, 2,3)/
     x-6.6578627D-04, 4.8163043D-19, 1.4306494D-07 /
      data fpppp( 6,19, 3,1),fpppp( 6,19, 3,2),fpppp( 6,19, 3,3)/
     x-7.4185620D-04, 2.3027602D-19, 1.8819745D-07 /
      data fpppp( 6,19, 4,1),fpppp( 6,19, 4,2),fpppp( 6,19, 4,3)/
     x-6.6578627D-04, 1.3974900D-19, 2.0754111D-07 /
      data fpppp( 6,19, 5,1),fpppp( 6,19, 5,2),fpppp( 6,19, 5,3)/
     x-8.0634019D-05, 1.5212854D-19,-1.5260400D-07 /
      data fpppp( 6,19, 6,1),fpppp( 6,19, 6,2),fpppp( 6,19, 6,3)/
     x 1.3795122D-04, 4.3344954D-19,-2.8468040D-07 /
      data fpppp( 6,19, 7,1),fpppp( 6,19, 7,2),fpppp( 6,19, 7,3)/
     x 3.9398696D-05,-1.2151912D-19, 3.0924214D-08 /
      data fpppp( 6,19, 8,1),fpppp( 6,19, 8,2),fpppp( 6,19, 8,3)/
     x 1.6242735D-04, 8.6233878D-20, 8.5072130D-08 /
      data fpppp( 6,19, 9,1),fpppp( 6,19, 9,2),fpppp( 6,19, 9,3)/
     x 2.2435239D-04, 1.6999272D-19, 5.0042474D-08 /
      data fpppp( 6,19,10,1),fpppp( 6,19,10,2),fpppp( 6,19,10,3)/
     x 1.6242735D-04, 2.1605736D-19, 8.5072130D-08 /
      data fpppp( 6,19,11,1),fpppp( 6,19,11,2),fpppp( 6,19,11,3)/
     x 3.9398696D-05,-2.2748623D-22, 3.0924214D-08 /
      data fpppp( 6,19,12,1),fpppp( 6,19,12,2),fpppp( 6,19,12,3)/
     x 1.3795122D-04,-2.6545578D-19,-2.8468040D-07 /
      data fpppp( 6,19,13,1),fpppp( 6,19,13,2),fpppp( 6,19,13,3)/
     x-8.0634019D-05,-2.8452550D-19,-1.5260400D-07 /
      data fpppp( 6,19,14,1),fpppp( 6,19,14,2),fpppp( 6,19,14,3)/
     x-6.6578627D-04, 1.7457003D-19, 2.0754111D-07 /
      data fpppp( 6,19,15,1),fpppp( 6,19,15,2),fpppp( 6,19,15,3)/
     x-7.4185620D-04, 2.4451194D-20, 1.8819745D-07 /
      data fpppp( 6,19,16,1),fpppp( 6,19,16,2),fpppp( 6,19,16,3)/
     x-6.6578627D-04, 4.5111758D-19, 1.4306494D-07 /
      data fpppp( 6,19,17,1),fpppp( 6,19,17,2),fpppp( 6,19,17,3)/
     x-8.0634019D-05,-5.3916882D-19, 1.0530068D-07 /
      data fpppp( 7, 1, 1,1),fpppp( 7, 1, 1,2),fpppp( 7, 1, 1,3)/
     x-1.7866833D-06,-1.2422834D-20, 8.1836488D-09 /
      data fpppp( 7, 1, 2,1),fpppp( 7, 1, 2,2),fpppp( 7, 1, 2,3)/
     x-3.9028787D-05, 1.1075551D-19, 1.2986803D-08 /
      data fpppp( 7, 1, 3,1),fpppp( 7, 1, 3,2),fpppp( 7, 1, 3,3)/
     x-5.7726483D-05, 1.6812276D-20, 2.0324542D-08 /
      data fpppp( 7, 1, 4,1),fpppp( 7, 1, 4,2),fpppp( 7, 1, 4,3)/
     x-3.9028787D-05,-3.4041572D-20, 1.8791237D-08 /
      data fpppp( 7, 1, 5,1),fpppp( 7, 1, 5,2),fpppp( 7, 1, 5,3)/
     x-1.7866833D-06,-8.2966242D-20,-1.5034084D-08 /
      data fpppp( 7, 1, 6,1),fpppp( 7, 1, 6,2),fpppp( 7, 1, 6,3)/
     x 1.2232982D-05, 5.7641398D-20,-2.0574764D-08 /
      data fpppp( 7, 1, 7,1),fpppp( 7, 1, 7,2),fpppp( 7, 1, 7,3)/
     x-9.9407279D-07,-4.8153210D-20,-1.6760473D-08 /
      data fpppp( 7, 1, 8,1),fpppp( 7, 1, 8,2),fpppp( 7, 1, 8,3)/
     x-2.7508887D-05, 6.7599061D-20, 1.3218766D-08 /
      data fpppp( 7, 1, 9,1),fpppp( 7, 1, 9,2),fpppp( 7, 1, 9,3)/
     x-3.5479488D-05, 5.0860764D-20, 2.1361503D-08 /
      data fpppp( 7, 1,10,1),fpppp( 7, 1,10,2),fpppp( 7, 1,10,3)/
     x-2.7508887D-05,-1.1155884D-19, 1.3218766D-08 /
      data fpppp( 7, 1,11,1),fpppp( 7, 1,11,2),fpppp( 7, 1,11,3)/
     x-9.9407279D-07,-1.6014189D-19,-1.6760473D-08 /
      data fpppp( 7, 1,12,1),fpppp( 7, 1,12,2),fpppp( 7, 1,12,3)/
     x 1.2232982D-05, 7.6736661D-20,-2.0574764D-08 /
      data fpppp( 7, 1,13,1),fpppp( 7, 1,13,2),fpppp( 7, 1,13,3)/
     x-1.7866833D-06,-1.1762087D-19,-1.5034084D-08 /
      data fpppp( 7, 1,14,1),fpppp( 7, 1,14,2),fpppp( 7, 1,14,3)/
     x-3.9028787D-05,-5.9658984D-20, 1.8791237D-08 /
      data fpppp( 7, 1,15,1),fpppp( 7, 1,15,2),fpppp( 7, 1,15,3)/
     x-5.7726483D-05,-3.2140293D-20, 2.0324542D-08 /
      data fpppp( 7, 1,16,1),fpppp( 7, 1,16,2),fpppp( 7, 1,16,3)/
     x-3.9028787D-05, 3.7939593D-20, 1.2986803D-08 /
      data fpppp( 7, 1,17,1),fpppp( 7, 1,17,2),fpppp( 7, 1,17,3)/
     x-1.7866833D-06, 1.9207613D-19, 8.1836488D-09 /
      data fpppp( 7, 2, 1,1),fpppp( 7, 2, 1,2),fpppp( 7, 2, 1,3)/
     x-5.2554936D-06, 6.8744814D-08,-6.2718493D-09 /
      data fpppp( 7, 2, 2,1),fpppp( 7, 2, 2,2),fpppp( 7, 2, 2,3)/
     x-2.2036238D-05, 7.2693616D-07, 1.4254968D-09 /
      data fpppp( 7, 2, 3,1),fpppp( 7, 2, 3,2),fpppp( 7, 2, 3,3)/
     x-3.4653845D-05, 2.1285510D-06, 1.9465721D-08 /
      data fpppp( 7, 2, 4,1),fpppp( 7, 2, 4,2),fpppp( 7, 2, 4,3)/
     x-2.2036238D-05, 9.2818362D-07, 1.3058716D-09 /
      data fpppp( 7, 2, 5,1),fpppp( 7, 2, 5,2),fpppp( 7, 2, 5,3)/
     x-5.2554936D-06,-7.3624504D-07,-5.7933489D-09 /
      data fpppp( 7, 2, 6,1),fpppp( 7, 2, 6,2),fpppp( 7, 2, 6,3)/
     x-2.4213075D-06,-1.3794740D-06,-8.6994122D-09 /
      data fpppp( 7, 2, 7,1),fpppp( 7, 2, 7,2),fpppp( 7, 2, 7,3)/
     x-1.2120488D-05,-6.0070838D-07,-5.9151076D-09 /
      data fpppp( 7, 2, 8,1),fpppp( 7, 2, 8,2),fpppp( 7, 2, 8,3)/
     x-1.8553460D-05, 3.5003152D-07, 3.6689599D-09 /
      data fpppp( 7, 2, 9,1),fpppp( 7, 2, 9,2),fpppp( 7, 2, 9,3)/
     x-2.0617198D-05, 7.8141480D-07, 1.1380416D-08 /
      data fpppp( 7, 2,10,1),fpppp( 7, 2,10,2),fpppp( 7, 2,10,3)/
     x-1.8553460D-05, 3.5003152D-07, 3.6689599D-09 /
      data fpppp( 7, 2,11,1),fpppp( 7, 2,11,2),fpppp( 7, 2,11,3)/
     x-1.2120488D-05,-6.0070838D-07,-5.9151076D-09 /
      data fpppp( 7, 2,12,1),fpppp( 7, 2,12,2),fpppp( 7, 2,12,3)/
     x-2.4213075D-06,-1.3794740D-06,-8.6994122D-09 /
      data fpppp( 7, 2,13,1),fpppp( 7, 2,13,2),fpppp( 7, 2,13,3)/
     x-5.2554936D-06,-7.3624504D-07,-5.7933489D-09 /
      data fpppp( 7, 2,14,1),fpppp( 7, 2,14,2),fpppp( 7, 2,14,3)/
     x-2.2036238D-05, 9.2818362D-07, 1.3058716D-09 /
      data fpppp( 7, 2,15,1),fpppp( 7, 2,15,2),fpppp( 7, 2,15,3)/
     x-3.4653845D-05, 2.1285510D-06, 1.9465721D-08 /
      data fpppp( 7, 2,16,1),fpppp( 7, 2,16,2),fpppp( 7, 2,16,3)/
     x-2.2036238D-05, 7.2693616D-07, 1.4254968D-09 /
      data fpppp( 7, 2,17,1),fpppp( 7, 2,17,2),fpppp( 7, 2,17,3)/
     x-5.2554936D-06, 6.8744814D-08,-6.2718493D-09 /
      data fpppp( 7, 3, 1,1),fpppp( 7, 3, 1,2),fpppp( 7, 3, 1,3)/
     x-9.7712689D-06,-1.8521838D-06,-2.8517629D-08 /
      data fpppp( 7, 3, 2,1),fpppp( 7, 3, 2,2),fpppp( 7, 3, 2,3)/
     x-8.5199335D-06, 1.4235746D-06,-1.2706035D-08 /
      data fpppp( 7, 3, 3,1),fpppp( 7, 3, 3,2),fpppp( 7, 3, 3,3)/
     x-2.0695089D-05, 8.7869066D-06, 2.9022931D-08 /
      data fpppp( 7, 3, 4,1),fpppp( 7, 3, 4,2),fpppp( 7, 3, 4,3)/
     x-8.5199335D-06, 1.8437314D-06,-1.9958905D-08 /
      data fpppp( 7, 3, 5,1),fpppp( 7, 3, 5,2),fpppp( 7, 3, 5,3)/
     x-9.7712689D-06,-3.5328109D-06, 4.9384898D-10 /
      data fpppp( 7, 3, 6,1),fpppp( 7, 3, 6,2),fpppp( 7, 3, 6,3)/
     x-2.2819284D-05,-4.5945124D-06, 5.8911181D-09 /
      data fpppp( 7, 3, 7,1),fpppp( 7, 3, 7,2),fpppp( 7, 3, 7,3)/
     x-3.2088738D-05, 2.3203373D-08, 5.1797139D-09 /
      data fpppp( 7, 3, 8,1),fpppp( 7, 3, 8,2),fpppp( 7, 3, 8,3)/
     x-1.0773531D-05, 1.0106731D-06,-6.1285511D-09 /
      data fpppp( 7, 3, 9,1),fpppp( 7, 3, 9,2),fpppp( 7, 3, 9,3)/
     x-1.2984434D-06, 1.7825503D-06,-1.1861927D-09 /
      data fpppp( 7, 3,10,1),fpppp( 7, 3,10,2),fpppp( 7, 3,10,3)/
     x-1.0773531D-05, 1.0106731D-06,-6.1285511D-09 /
      data fpppp( 7, 3,11,1),fpppp( 7, 3,11,2),fpppp( 7, 3,11,3)/
     x-3.2088738D-05, 2.3203373D-08, 5.1797139D-09 /
      data fpppp( 7, 3,12,1),fpppp( 7, 3,12,2),fpppp( 7, 3,12,3)/
     x-2.2819284D-05,-4.5945124D-06, 5.8911181D-09 /
      data fpppp( 7, 3,13,1),fpppp( 7, 3,13,2),fpppp( 7, 3,13,3)/
     x-9.7712689D-06,-3.5328109D-06, 4.9384898D-10 /
      data fpppp( 7, 3,14,1),fpppp( 7, 3,14,2),fpppp( 7, 3,14,3)/
     x-8.5199335D-06, 1.8437314D-06,-1.9958905D-08 /
      data fpppp( 7, 3,15,1),fpppp( 7, 3,15,2),fpppp( 7, 3,15,3)/
     x-2.0695089D-05, 8.7869066D-06, 2.9022931D-08 /
      data fpppp( 7, 3,16,1),fpppp( 7, 3,16,2),fpppp( 7, 3,16,3)/
     x-8.5199335D-06, 1.4235746D-06,-1.2706035D-08 /
      data fpppp( 7, 3,17,1),fpppp( 7, 3,17,2),fpppp( 7, 3,17,3)/
     x-9.7712689D-06,-1.8521838D-06,-2.8517629D-08 /
      data fpppp( 7, 4, 1,1),fpppp( 7, 4, 1,2),fpppp( 7, 4, 1,3)/
     x-1.0622667D-05,-8.0041157D-06,-2.3497423D-08 /
      data fpppp( 7, 4, 2,1),fpppp( 7, 4, 2,2),fpppp( 7, 4, 2,3)/
     x 1.7163228D-05, 2.1323272D-07,-1.7841778D-08 /
      data fpppp( 7, 4, 3,1),fpppp( 7, 4, 3,2),fpppp( 7, 4, 3,3)/
     x 2.5162255D-05, 1.9600887D-05, 2.1240342D-09 /
      data fpppp( 7, 4, 4,1),fpppp( 7, 4, 4,2),fpppp( 7, 4, 4,3)/
     x 1.7163228D-05,-1.0752974D-07,-2.7995741D-08 /
      data fpppp( 7, 4, 5,1),fpppp( 7, 4, 5,2),fpppp( 7, 4, 5,3)/
     x-1.0622667D-05,-6.7210659D-06, 1.7118429D-08 /
      data fpppp( 7, 4, 6,1),fpppp( 7, 4, 6,2),fpppp( 7, 4, 6,3)/
     x-2.3114357D-05,-8.4692156D-06, 1.0978523D-08 /
      data fpppp( 7, 4, 7,1),fpppp( 7, 4, 7,2),fpppp( 7, 4, 7,3)/
     x-2.1110567D-05, 5.5748370D-06, 1.5401441D-08 /
      data fpppp( 7, 4, 8,1),fpppp( 7, 4, 8,2),fpppp( 7, 4, 8,3)/
     x 1.1206424D-06,-1.1763226D-06,-1.5059095D-08 /
      data fpppp( 7, 4, 9,1),fpppp( 7, 4, 9,2),fpppp( 7, 4, 9,3)/
     x 2.4226864D-06, 2.1442459D-06,-4.7034753D-09 /
      data fpppp( 7, 4,10,1),fpppp( 7, 4,10,2),fpppp( 7, 4,10,3)/
     x 1.1206424D-06,-1.1763226D-06,-1.5059095D-08 /
      data fpppp( 7, 4,11,1),fpppp( 7, 4,11,2),fpppp( 7, 4,11,3)/
     x-2.1110567D-05, 5.5748370D-06, 1.5401441D-08 /
      data fpppp( 7, 4,12,1),fpppp( 7, 4,12,2),fpppp( 7, 4,12,3)/
     x-2.3114357D-05,-8.4692156D-06, 1.0978523D-08 /
      data fpppp( 7, 4,13,1),fpppp( 7, 4,13,2),fpppp( 7, 4,13,3)/
     x-1.0622667D-05,-6.7210659D-06, 1.7118429D-08 /
      data fpppp( 7, 4,14,1),fpppp( 7, 4,14,2),fpppp( 7, 4,14,3)/
     x 1.7163228D-05,-1.0752974D-07,-2.7995741D-08 /
      data fpppp( 7, 4,15,1),fpppp( 7, 4,15,2),fpppp( 7, 4,15,3)/
     x 2.5162255D-05, 1.9600887D-05, 2.1240342D-09 /
      data fpppp( 7, 4,16,1),fpppp( 7, 4,16,2),fpppp( 7, 4,16,3)/
     x 1.7163228D-05, 2.1323272D-07,-1.7841778D-08 /
      data fpppp( 7, 4,17,1),fpppp( 7, 4,17,2),fpppp( 7, 4,17,3)/
     x-1.0622667D-05,-8.0041157D-06,-2.3497423D-08 /
      data fpppp( 7, 5, 1,1),fpppp( 7, 5, 1,2),fpppp( 7, 5, 1,3)/
     x-2.0754512D-06,-1.6913246D-05, 3.3737153D-08 /
      data fpppp( 7, 5, 2,1),fpppp( 7, 5, 2,2),fpppp( 7, 5, 2,3)/
     x 3.5433317D-05,-3.3608620D-06, 4.9601526D-09 /
      data fpppp( 7, 5, 3,1),fpppp( 7, 5, 3,2),fpppp( 7, 5, 3,3)/
     x 5.1623290D-05, 2.9972327D-05,-6.5016914D-08 /
      data fpppp( 7, 5, 4,1),fpppp( 7, 5, 4,2),fpppp( 7, 5, 4,3)/
     x 3.5433317D-05,-5.9273015D-06, 9.2062528D-09 /
      data fpppp( 7, 5, 5,1),fpppp( 7, 5, 5,2),fpppp( 7, 5, 5,3)/
     x-2.0754512D-06,-6.6474880D-06, 1.6752752D-08 /
      data fpppp( 7, 5, 6,1),fpppp( 7, 5, 6,2),fpppp( 7, 5, 6,3)/
     x 2.4064335D-06,-1.1370430D-05, 1.6849136D-08 /
      data fpppp( 7, 5, 7,1),fpppp( 7, 5, 7,2),fpppp( 7, 5, 7,3)/
     x 3.1532572D-05, 1.3571210D-05,-6.7631869D-09 /
      data fpppp( 7, 5, 8,1),fpppp( 7, 5, 8,2),fpppp( 7, 5, 8,3)/
     x 1.4735242D-05,-6.8301131D-06, 1.4141973D-10 /
      data fpppp( 7, 5, 9,1),fpppp( 7, 5, 9,2),fpppp( 7, 5, 9,3)/
     x 4.2128674D-06, 4.0081783D-06,-6.6481504D-09 /
      data fpppp( 7, 5,10,1),fpppp( 7, 5,10,2),fpppp( 7, 5,10,3)/
     x 1.4735242D-05,-6.8301131D-06, 1.4141973D-10 /
      data fpppp( 7, 5,11,1),fpppp( 7, 5,11,2),fpppp( 7, 5,11,3)/
     x 3.1532572D-05, 1.3571210D-05,-6.7631869D-09 /
      data fpppp( 7, 5,12,1),fpppp( 7, 5,12,2),fpppp( 7, 5,12,3)/
     x 2.4064335D-06,-1.1370430D-05, 1.6849136D-08 /
      data fpppp( 7, 5,13,1),fpppp( 7, 5,13,2),fpppp( 7, 5,13,3)/
     x-2.0754512D-06,-6.6474880D-06, 1.6752752D-08 /
      data fpppp( 7, 5,14,1),fpppp( 7, 5,14,2),fpppp( 7, 5,14,3)/
     x 3.5433317D-05,-5.9273015D-06, 9.2062528D-09 /
      data fpppp( 7, 5,15,1),fpppp( 7, 5,15,2),fpppp( 7, 5,15,3)/
     x 5.1623290D-05, 2.9972327D-05,-6.5016914D-08 /
      data fpppp( 7, 5,16,1),fpppp( 7, 5,16,2),fpppp( 7, 5,16,3)/
     x 3.5433317D-05,-3.3608620D-06, 4.9601526D-09 /
      data fpppp( 7, 5,17,1),fpppp( 7, 5,17,2),fpppp( 7, 5,17,3)/
     x-2.0754512D-06,-1.6913246D-05, 3.3737153D-08 /
      data fpppp( 7, 6, 1,1),fpppp( 7, 6, 1,2),fpppp( 7, 6, 1,3)/
     x 4.5475391D-06,-2.4349251D-05, 6.5320386D-08 /
      data fpppp( 7, 6, 2,1),fpppp( 7, 6, 2,2),fpppp( 7, 6, 2,3)/
     x 2.2494764D-05,-7.8886790D-06, 2.5011355D-08 /
      data fpppp( 7, 6, 3,1),fpppp( 7, 6, 3,2),fpppp( 7, 6, 3,3)/
     x 7.0451123D-05, 3.4346318D-05,-8.0828699D-08 /
      data fpppp( 7, 6, 4,1),fpppp( 7, 6, 4,2),fpppp( 7, 6, 4,3)/
     x 2.2494764D-05,-1.3629172D-05, 4.2689828D-08 /
      data fpppp( 7, 6, 5,1),fpppp( 7, 6, 5,2),fpppp( 7, 6, 5,3)/
     x 4.5475391D-06,-1.3872777D-06,-5.3935044D-09 /
      data fpppp( 7, 6, 6,1),fpppp( 7, 6, 6,2),fpppp( 7, 6, 6,3)/
     x 1.0529495D-05,-1.0115409D-05, 1.1922104D-08 /
      data fpppp( 7, 6, 7,1),fpppp( 7, 6, 7,2),fpppp( 7, 6, 7,3)/
     x 3.2385986D-05, 1.4083456D-05,-1.5913317D-08 /
      data fpppp( 7, 6, 8,1),fpppp( 7, 6, 8,2),fpppp( 7, 6, 8,3)/
     x 5.9723502D-06,-1.0229917D-05, 1.4654737D-08 /
      data fpppp( 7, 6, 9,1),fpppp( 7, 6, 9,2),fpppp( 7, 6, 9,3)/
     x 1.6075872D-06, 7.2535742D-06,-1.2144584D-08 /
      data fpppp( 7, 6,10,1),fpppp( 7, 6,10,2),fpppp( 7, 6,10,3)/
     x 5.9723502D-06,-1.0229917D-05, 1.4654737D-08 /
      data fpppp( 7, 6,11,1),fpppp( 7, 6,11,2),fpppp( 7, 6,11,3)/
     x 3.2385986D-05, 1.4083456D-05,-1.5913317D-08 /
      data fpppp( 7, 6,12,1),fpppp( 7, 6,12,2),fpppp( 7, 6,12,3)/
     x 1.0529495D-05,-1.0115409D-05, 1.1922104D-08 /
      data fpppp( 7, 6,13,1),fpppp( 7, 6,13,2),fpppp( 7, 6,13,3)/
     x 4.5475391D-06,-1.3872777D-06,-5.3935044D-09 /
      data fpppp( 7, 6,14,1),fpppp( 7, 6,14,2),fpppp( 7, 6,14,3)/
     x 2.2494764D-05,-1.3629172D-05, 4.2689828D-08 /
      data fpppp( 7, 6,15,1),fpppp( 7, 6,15,2),fpppp( 7, 6,15,3)/
     x 7.0451123D-05, 3.4346318D-05,-8.0828699D-08 /
      data fpppp( 7, 6,16,1),fpppp( 7, 6,16,2),fpppp( 7, 6,16,3)/
     x 2.2494764D-05,-7.8886790D-06, 2.5011355D-08 /
      data fpppp( 7, 6,17,1),fpppp( 7, 6,17,2),fpppp( 7, 6,17,3)/
     x 4.5475391D-06,-2.4349251D-05, 6.5320386D-08 /
      data fpppp( 7, 7, 1,1),fpppp( 7, 7, 1,2),fpppp( 7, 7, 1,3)/
     x 6.4809314D-06,-1.9241782D-05, 8.9744420D-09 /
      data fpppp( 7, 7, 2,1),fpppp( 7, 7, 2,2),fpppp( 7, 7, 2,3)/
     x-1.3169766D-05,-7.7561221D-06, 8.3881501D-09 /
      data fpppp( 7, 7, 3,1),fpppp( 7, 7, 3,2),fpppp( 7, 7, 3,3)/
     x 7.1026311D-06, 2.2939877D-05, 3.3636835D-09 /
      data fpppp( 7, 7, 4,1),fpppp( 7, 7, 4,2),fpppp( 7, 7, 4,3)/
     x-1.3169766D-05,-1.3600312D-05, 1.3872828D-08 /
      data fpppp( 7, 7, 5,1),fpppp( 7, 7, 5,2),fpppp( 7, 7, 5,3)/
     x 6.4809314D-06, 4.1349763D-06,-1.2964270D-08 /
      data fpppp( 7, 7, 6,1),fpppp( 7, 7, 6,2),fpppp( 7, 7, 6,3)/
     x 6.1663425D-06,-4.5568402D-06,-1.2833800D-08 /
      data fpppp( 7, 7, 7,1),fpppp( 7, 7, 7,2),fpppp( 7, 7, 7,3)/
     x-5.2983589D-06, 5.6741651D-06, 9.1869819D-09 /
      data fpppp( 7, 7, 8,1),fpppp( 7, 7, 8,2),fpppp( 7, 7, 8,3)/
     x-1.0181503D-05,-8.0718358D-06, 3.9737665D-09 /
      data fpppp( 7, 7, 9,1),fpppp( 7, 7, 9,2),fpppp( 7, 7, 9,3)/
     x-3.9037026D-06, 8.9257842D-06,-4.9205826D-09 /
      data fpppp( 7, 7,10,1),fpppp( 7, 7,10,2),fpppp( 7, 7,10,3)/
     x-1.0181503D-05,-8.0718358D-06, 3.9737665D-09 /
      data fpppp( 7, 7,11,1),fpppp( 7, 7,11,2),fpppp( 7, 7,11,3)/
     x-5.2983589D-06, 5.6741651D-06, 9.1869819D-09 /
      data fpppp( 7, 7,12,1),fpppp( 7, 7,12,2),fpppp( 7, 7,12,3)/
     x 6.1663425D-06,-4.5568402D-06,-1.2833800D-08 /
      data fpppp( 7, 7,13,1),fpppp( 7, 7,13,2),fpppp( 7, 7,13,3)/
     x 6.4809314D-06, 4.1349763D-06,-1.2964270D-08 /
      data fpppp( 7, 7,14,1),fpppp( 7, 7,14,2),fpppp( 7, 7,14,3)/
     x-1.3169766D-05,-1.3600312D-05, 1.3872828D-08 /
      data fpppp( 7, 7,15,1),fpppp( 7, 7,15,2),fpppp( 7, 7,15,3)/
     x 7.1026311D-06, 2.2939877D-05, 3.3636835D-09 /
      data fpppp( 7, 7,16,1),fpppp( 7, 7,16,2),fpppp( 7, 7,16,3)/
     x-1.3169766D-05,-7.7561221D-06, 8.3881501D-09 /
      data fpppp( 7, 7,17,1),fpppp( 7, 7,17,2),fpppp( 7, 7,17,3)/
     x 6.4809314D-06,-1.9241782D-05, 8.9744420D-09 /
      data fpppp( 7, 8, 1,1),fpppp( 7, 8, 1,2),fpppp( 7, 8, 1,3)/
     x 6.5236560D-06,-5.0895248D-06,-2.9145417D-08 /
      data fpppp( 7, 8, 2,1),fpppp( 7, 8, 2,2),fpppp( 7, 8, 2,3)/
     x-2.3721796D-05,-3.0021960D-06,-5.7294302D-09 /
      data fpppp( 7, 8, 3,1),fpppp( 7, 8, 3,2),fpppp( 7, 8, 3,3)/
     x-6.7002646D-05, 3.6327397D-06, 5.2243128D-08 /
      data fpppp( 7, 8, 4,1),fpppp( 7, 8, 4,2),fpppp( 7, 8, 4,3)/
     x-2.3721796D-05,-5.6489488D-06,-1.0732314D-08 /
      data fpppp( 7, 8, 5,1),fpppp( 7, 8, 5,2),fpppp( 7, 8, 5,3)/
     x 6.5236560D-06, 5.4974861D-06,-9.1338797D-09 /
      data fpppp( 7, 8, 6,1),fpppp( 7, 8, 6,2),fpppp( 7, 8, 6,3)/
     x 9.2324247D-06, 4.4390872D-07,-1.9857870D-08 /
      data fpppp( 7, 8, 7,1),fpppp( 7, 8, 7,2),fpppp( 7, 8, 7,3)/
     x-1.7832847D-05,-2.8440966D-06, 9.9137266D-09 /
      data fpppp( 7, 8, 8,1),fpppp( 7, 8, 8,2),fpppp( 7, 8, 8,3)/
     x-1.0674921D-05,-3.5556840D-06, 1.1278145D-09 /
      data fpppp( 7, 8, 9,1),fpppp( 7, 8, 9,2),fpppp( 7, 8, 9,3)/
     x-8.4145689D-06, 8.1408040D-06, 4.2881051D-09 /
      data fpppp( 7, 8,10,1),fpppp( 7, 8,10,2),fpppp( 7, 8,10,3)/
     x-1.0674921D-05,-3.5556840D-06, 1.1278145D-09 /
      data fpppp( 7, 8,11,1),fpppp( 7, 8,11,2),fpppp( 7, 8,11,3)/
     x-1.7832847D-05,-2.8440966D-06, 9.9137266D-09 /
      data fpppp( 7, 8,12,1),fpppp( 7, 8,12,2),fpppp( 7, 8,12,3)/
     x 9.2324247D-06, 4.4390872D-07,-1.9857870D-08 /
      data fpppp( 7, 8,13,1),fpppp( 7, 8,13,2),fpppp( 7, 8,13,3)/
     x 6.5236560D-06, 5.4974861D-06,-9.1338797D-09 /
      data fpppp( 7, 8,14,1),fpppp( 7, 8,14,2),fpppp( 7, 8,14,3)/
     x-2.3721796D-05,-5.6489488D-06,-1.0732314D-08 /
      data fpppp( 7, 8,15,1),fpppp( 7, 8,15,2),fpppp( 7, 8,15,3)/
     x-6.7002646D-05, 3.6327397D-06, 5.2243128D-08 /
      data fpppp( 7, 8,16,1),fpppp( 7, 8,16,2),fpppp( 7, 8,16,3)/
     x-2.3721796D-05,-3.0021960D-06,-5.7294302D-09 /
      data fpppp( 7, 8,17,1),fpppp( 7, 8,17,2),fpppp( 7, 8,17,3)/
     x 6.5236560D-06,-5.0895248D-06,-2.9145417D-08 /
      data fpppp( 7, 9, 1,1),fpppp( 7, 9, 1,2),fpppp( 7, 9, 1,3)/
     x 6.0653620D-06, 2.5036198D-06,-1.6908369D-08 /
      data fpppp( 7, 9, 2,1),fpppp( 7, 9, 2,2),fpppp( 7, 9, 2,3)/
     x-1.6456990D-05, 2.2595598D-07,-1.4325752D-09 /
      data fpppp( 7, 9, 3,1),fpppp( 7, 9, 3,2),fpppp( 7, 9, 3,3)/
     x-4.2111569D-05,-4.7178243D-06, 3.6467982D-08 /
      data fpppp( 7, 9, 4,1),fpppp( 7, 9, 4,2),fpppp( 7, 9, 4,3)/
     x-1.6456990D-05,-3.3019689D-07,-4.1181316D-09 /
      data fpppp( 7, 9, 5,1),fpppp( 7, 9, 5,2),fpppp( 7, 9, 5,3)/
     x 6.0653620D-06, 4.7282313D-06,-6.1661438D-09 /
      data fpppp( 7, 9, 6,1),fpppp( 7, 9, 6,2),fpppp( 7, 9, 6,3)/
     x 1.2346928D-05, 3.4290449D-07,-1.7816426D-08 /
      data fpppp( 7, 9, 7,1),fpppp( 7, 9, 7,2),fpppp( 7, 9, 7,3)/
     x-1.3702810D-06,-5.5174754D-06, 3.5087943D-10 /
      data fpppp( 7, 9, 8,1),fpppp( 7, 9, 8,2),fpppp( 7, 9, 8,3)/
     x-8.2908820D-06,-6.2053811D-07, 5.4656132D-09 /
      data fpppp( 7, 9, 9,1),fpppp( 7, 9, 9,2),fpppp( 7, 9, 9,3)/
     x-1.0523274D-05, 7.4192815D-06, 7.6528434D-09 /
      data fpppp( 7, 9,10,1),fpppp( 7, 9,10,2),fpppp( 7, 9,10,3)/
     x-8.2908820D-06,-6.2053811D-07, 5.4656132D-09 /
      data fpppp( 7, 9,11,1),fpppp( 7, 9,11,2),fpppp( 7, 9,11,3)/
     x-1.3702810D-06,-5.5174754D-06, 3.5087943D-10 /
      data fpppp( 7, 9,12,1),fpppp( 7, 9,12,2),fpppp( 7, 9,12,3)/
     x 1.2346928D-05, 3.4290449D-07,-1.7816426D-08 /
      data fpppp( 7, 9,13,1),fpppp( 7, 9,13,2),fpppp( 7, 9,13,3)/
     x 6.0653620D-06, 4.7282313D-06,-6.1661438D-09 /
      data fpppp( 7, 9,14,1),fpppp( 7, 9,14,2),fpppp( 7, 9,14,3)/
     x-1.6456990D-05,-3.3019689D-07,-4.1181316D-09 /
      data fpppp( 7, 9,15,1),fpppp( 7, 9,15,2),fpppp( 7, 9,15,3)/
     x-4.2111569D-05,-4.7178243D-06, 3.6467982D-08 /
      data fpppp( 7, 9,16,1),fpppp( 7, 9,16,2),fpppp( 7, 9,16,3)/
     x-1.6456990D-05, 2.2595598D-07,-1.4325752D-09 /
      data fpppp( 7, 9,17,1),fpppp( 7, 9,17,2),fpppp( 7, 9,17,3)/
     x 6.0653620D-06, 2.5036198D-06,-1.6908369D-08 /
      data fpppp( 7,10, 1,1),fpppp( 7,10, 1,2),fpppp( 7,10, 1,3)/
     x 6.3463158D-06, 4.2128220D-06,-1.1648705D-09 /
      data fpppp( 7,10, 2,1),fpppp( 7,10, 2,2),fpppp( 7,10, 2,3)/
     x-7.0808503D-06, 1.9689671D-06, 4.2472603D-09 /
      data fpppp( 7,10, 3,1),fpppp( 7,10, 3,2),fpppp( 7,10, 3,3)/
     x-1.5012080D-05,-3.4737008D-06, 1.6638590D-08 /
      data fpppp( 7,10, 4,1),fpppp( 7,10, 4,2),fpppp( 7,10, 4,3)/
     x-7.0808503D-06, 2.2794772D-06, 4.6027237D-09 /
      data fpppp( 7,10, 5,1),fpppp( 7,10, 5,2),fpppp( 7,10, 5,3)/
     x 6.3463158D-06, 2.9707817D-06,-2.5867238D-09 /
      data fpppp( 7,10, 6,1),fpppp( 7,10, 6,2),fpppp( 7,10, 6,3)/
     x 1.5431483D-05,-3.8564465D-06,-2.2213592D-08 /
      data fpppp( 7,10, 7,1),fpppp( 7,10, 7,2),fpppp( 7,10, 7,3)/
     x 3.5671357D-06,-5.3335675D-06, 7.7660877D-10 /
      data fpppp( 7,10, 8,1),fpppp( 7,10, 8,2),fpppp( 7,10, 8,3)/
     x-6.3787907D-06, 2.0202580D-06, 6.8914889D-09 /
      data fpppp( 7,10, 9,1),fpppp( 7,10, 9,2),fpppp( 7,10, 9,3)/
     x-9.0608050D-06, 7.3644466D-06, 8.4796432D-09 /
      data fpppp( 7,10,10,1),fpppp( 7,10,10,2),fpppp( 7,10,10,3)/
     x-6.3787907D-06, 2.0202580D-06, 6.8914889D-09 /
      data fpppp( 7,10,11,1),fpppp( 7,10,11,2),fpppp( 7,10,11,3)/
     x 3.5671357D-06,-5.3335675D-06, 7.7660877D-10 /
      data fpppp( 7,10,12,1),fpppp( 7,10,12,2),fpppp( 7,10,12,3)/
     x 1.5431483D-05,-3.8564465D-06,-2.2213592D-08 /
      data fpppp( 7,10,13,1),fpppp( 7,10,13,2),fpppp( 7,10,13,3)/
     x 6.3463158D-06, 2.9707817D-06,-2.5867238D-09 /
      data fpppp( 7,10,14,1),fpppp( 7,10,14,2),fpppp( 7,10,14,3)/
     x-7.0808503D-06, 2.2794772D-06, 4.6027237D-09 /
      data fpppp( 7,10,15,1),fpppp( 7,10,15,2),fpppp( 7,10,15,3)/
     x-1.5012080D-05,-3.4737008D-06, 1.6638590D-08 /
      data fpppp( 7,10,16,1),fpppp( 7,10,16,2),fpppp( 7,10,16,3)/
     x-7.0808503D-06, 1.9689671D-06, 4.2472603D-09 /
      data fpppp( 7,10,17,1),fpppp( 7,10,17,2),fpppp( 7,10,17,3)/
     x 6.3463158D-06, 4.2128220D-06,-1.1648705D-09 /
      data fpppp( 7,11, 1,1),fpppp( 7,11, 1,2),fpppp( 7,11, 1,3)/
     x 8.6507563D-06, 4.9300673D-06, 8.1752864D-09 /
      data fpppp( 7,11, 2,1),fpppp( 7,11, 2,2),fpppp( 7,11, 2,3)/
     x 2.0690112D-06, 3.8968637D-06, 7.6686640D-09 /
      data fpppp( 7,11, 3,1),fpppp( 7,11, 3,2),fpppp( 7,11, 3,3)/
     x 2.6472481D-06, 9.1300469D-07, 5.2297020D-09 /
      data fpppp( 7,11, 4,1),fpppp( 7,11, 4,2),fpppp( 7,11, 4,3)/
     x 2.0690112D-06, 4.7564398D-06, 9.5539282D-09 /
      data fpppp( 7,11, 5,1),fpppp( 7,11, 5,2),fpppp( 7,11, 5,3)/
     x 8.6507563D-06, 1.4917632D-06, 6.3422948D-10 /
      data fpppp( 7,11, 6,1),fpppp( 7,11, 6,2),fpppp( 7,11, 6,3)/
     x 2.0689882D-05,-1.2164743D-05,-2.9740658D-08 /
      data fpppp( 7,11, 7,1),fpppp( 7,11, 7,2),fpppp( 7,11, 7,3)/
     x 4.8951409D-06,-3.6179409D-06, 6.3073075D-09 /
      data fpppp( 7,11, 8,1),fpppp( 7,11, 8,2),fpppp( 7,11, 8,3)/
     x-1.7361434D-06, 5.2690973D-06, 7.4413962D-09 /
      data fpppp( 7,11, 9,1),fpppp( 7,11, 9,2),fpppp( 7,11, 9,3)/
     x-2.3735357D-06, 7.7610258D-06, 6.6921012D-09 /
      data fpppp( 7,11,10,1),fpppp( 7,11,10,2),fpppp( 7,11,10,3)/
     x-1.7361434D-06, 5.2690973D-06, 7.4413962D-09 /
      data fpppp( 7,11,11,1),fpppp( 7,11,11,2),fpppp( 7,11,11,3)/
     x 4.8951409D-06,-3.6179409D-06, 6.3073075D-09 /
      data fpppp( 7,11,12,1),fpppp( 7,11,12,2),fpppp( 7,11,12,3)/
     x 2.0689882D-05,-1.2164743D-05,-2.9740658D-08 /
      data fpppp( 7,11,13,1),fpppp( 7,11,13,2),fpppp( 7,11,13,3)/
     x 8.6507563D-06, 1.4917632D-06, 6.3422948D-10 /
      data fpppp( 7,11,14,1),fpppp( 7,11,14,2),fpppp( 7,11,14,3)/
     x 2.0690112D-06, 4.7564398D-06, 9.5539282D-09 /
      data fpppp( 7,11,15,1),fpppp( 7,11,15,2),fpppp( 7,11,15,3)/
     x 2.6472481D-06, 9.1300469D-07, 5.2297020D-09 /
      data fpppp( 7,11,16,1),fpppp( 7,11,16,2),fpppp( 7,11,16,3)/
     x 2.0690112D-06, 3.8968637D-06, 7.6686640D-09 /
      data fpppp( 7,11,17,1),fpppp( 7,11,17,2),fpppp( 7,11,17,3)/
     x 8.6507563D-06, 4.9300673D-06, 8.1752864D-09 /
      data fpppp( 7,12, 1,1),fpppp( 7,12, 1,2),fpppp( 7,12, 1,3)/
     x 1.1552865D-05, 6.9272475D-06, 9.0018607D-09 /
      data fpppp( 7,12, 2,1),fpppp( 7,12, 2,2),fpppp( 7,12, 2,3)/
     x 1.1665038D-05, 6.6098536D-06, 6.9684786D-09 /
      data fpppp( 7,12, 3,1),fpppp( 7,12, 3,2),fpppp( 7,12, 3,3)/
     x 1.5329779D-05, 5.0670060D-06, 1.2628869D-09 /
      data fpppp( 7,12, 4,1),fpppp( 7,12, 4,2),fpppp( 7,12, 4,3)/
     x 1.1665038D-05, 7.8132463D-06, 8.4100291D-09 /
      data fpppp( 7,12, 5,1),fpppp( 7,12, 5,2),fpppp( 7,12, 5,3)/
     x 1.1552865D-05, 2.1136767D-06, 3.2356590D-09 /
      data fpppp( 7,12, 6,1),fpppp( 7,12, 6,2),fpppp( 7,12, 6,3)/
     x 2.3331611D-05,-2.6192341D-05,-3.2395656D-08 /
      data fpppp( 7,12, 7,1),fpppp( 7,12, 7,2),fpppp( 7,12, 7,3)/
     x 6.7110083D-06, 1.0201436D-06, 1.3175821D-08 /
      data fpppp( 7,12, 8,1),fpppp( 7,12, 8,2),fpppp( 7,12, 8,3)/
     x 6.2498250D-06, 8.6287024D-06, 4.8681665D-09 /
      data fpppp( 7,12, 9,1),fpppp( 7,12, 9,2),fpppp( 7,12, 9,3)/
     x 6.7207399D-06, 8.3667036D-06, 4.3893319D-09 /
      data fpppp( 7,12,10,1),fpppp( 7,12,10,2),fpppp( 7,12,10,3)/
     x 6.2498250D-06, 8.6287024D-06, 4.8681665D-09 /
      data fpppp( 7,12,11,1),fpppp( 7,12,11,2),fpppp( 7,12,11,3)/
     x 6.7110083D-06, 1.0201436D-06, 1.3175821D-08 /
      data fpppp( 7,12,12,1),fpppp( 7,12,12,2),fpppp( 7,12,12,3)/
     x 2.3331611D-05,-2.6192341D-05,-3.2395656D-08 /
      data fpppp( 7,12,13,1),fpppp( 7,12,13,2),fpppp( 7,12,13,3)/
     x 1.1552865D-05, 2.1136767D-06, 3.2356590D-09 /
      data fpppp( 7,12,14,1),fpppp( 7,12,14,2),fpppp( 7,12,14,3)/
     x 1.1665038D-05, 7.8132463D-06, 8.4100291D-09 /
      data fpppp( 7,12,15,1),fpppp( 7,12,15,2),fpppp( 7,12,15,3)/
     x 1.5329779D-05, 5.0670060D-06, 1.2628869D-09 /
      data fpppp( 7,12,16,1),fpppp( 7,12,16,2),fpppp( 7,12,16,3)/
     x 1.1665038D-05, 6.6098536D-06, 6.9684786D-09 /
      data fpppp( 7,12,17,1),fpppp( 7,12,17,2),fpppp( 7,12,17,3)/
     x 1.1552865D-05, 6.9272475D-06, 9.0018607D-09 /
      data fpppp( 7,13, 1,1),fpppp( 7,13, 1,2),fpppp( 7,13, 1,3)/
     x 1.3280632D-05, 1.0044653D-05,-1.2272000D-09 /
      data fpppp( 7,13, 2,1),fpppp( 7,13, 2,2),fpppp( 7,13, 2,3)/
     x 2.2893045D-05, 9.6870836D-06,-6.4697021D-10 /
      data fpppp( 7,13, 3,1),fpppp( 7,13, 3,2),fpppp( 7,13, 3,3)/
     x 2.5216964D-05, 8.2084617D-06, 6.6078775D-10 /
      data fpppp( 7,13, 4,1),fpppp( 7,13, 4,2),fpppp( 7,13, 4,3)/
     x 2.2893045D-05, 1.0653524D-05,-5.7780281D-10 /
      data fpppp( 7,13, 5,1),fpppp( 7,13, 5,2),fpppp( 7,13, 5,3)/
     x 1.3280632D-05, 6.1788911D-06,-1.5038696D-09 /
      data fpppp( 7,13, 6,1),fpppp( 7,13, 6,2),fpppp( 7,13, 6,3)/
     x 1.7385029D-05,-4.6361295D-05,-5.0249455D-09 /
      data fpppp( 7,13, 7,1),fpppp( 7,13, 7,2),fpppp( 7,13, 7,3)/
     x 1.0332256D-05, 9.8260812D-06, 6.7493162D-09 /
      data fpppp( 7,13, 8,1),fpppp( 7,13, 8,2),fpppp( 7,13, 8,3)/
     x 1.5162967D-05, 1.0978764D-05,-5.6546428D-10 /
      data fpppp( 7,13, 9,1),fpppp( 7,13, 9,2),fpppp( 7,13, 9,3)/
     x 1.5293198D-05, 9.4006812D-06, 1.1962723D-09 /
      data fpppp( 7,13,10,1),fpppp( 7,13,10,2),fpppp( 7,13,10,3)/
     x 1.5162967D-05, 1.0978764D-05,-5.6546428D-10 /
      data fpppp( 7,13,11,1),fpppp( 7,13,11,2),fpppp( 7,13,11,3)/
     x 1.0332256D-05, 9.8260812D-06, 6.7493162D-09 /
      data fpppp( 7,13,12,1),fpppp( 7,13,12,2),fpppp( 7,13,12,3)/
     x 1.7385029D-05,-4.6361295D-05,-5.0249455D-09 /
      data fpppp( 7,13,13,1),fpppp( 7,13,13,2),fpppp( 7,13,13,3)/
     x 1.3280632D-05, 6.1788911D-06,-1.5038696D-09 /
      data fpppp( 7,13,14,1),fpppp( 7,13,14,2),fpppp( 7,13,14,3)/
     x 2.2893045D-05, 1.0653524D-05,-5.7780281D-10 /
      data fpppp( 7,13,15,1),fpppp( 7,13,15,2),fpppp( 7,13,15,3)/
     x 2.5216964D-05, 8.2084617D-06, 6.6078775D-10 /
      data fpppp( 7,13,16,1),fpppp( 7,13,16,2),fpppp( 7,13,16,3)/
     x 2.2893045D-05, 9.6870836D-06,-6.4697021D-10 /
      data fpppp( 7,13,17,1),fpppp( 7,13,17,2),fpppp( 7,13,17,3)/
     x 1.3280632D-05, 1.0044653D-05,-1.2272000D-09 /
      data fpppp( 7,14, 1,1),fpppp( 7,14, 1,2),fpppp( 7,14, 1,3)/
     x 3.0691496D-05, 1.2770183D-05,-2.0103991D-08 /
      data fpppp( 7,14, 2,1),fpppp( 7,14, 2,2),fpppp( 7,14, 2,3)/
     x 3.2908229D-05, 1.2245385D-05,-1.5152071D-08 /
      data fpppp( 7,14, 3,1),fpppp( 7,14, 3,2),fpppp( 7,14, 3,3)/
     x 3.4786493D-05, 1.0935299D-05,-3.0092152D-09 /
      data fpppp( 7,14, 4,1),fpppp( 7,14, 4,2),fpppp( 7,14, 4,3)/
     x 3.2908229D-05, 1.2373719D-05,-1.6034636D-08 /
      data fpppp( 7,14, 5,1),fpppp( 7,14, 5,2),fpppp( 7,14, 5,3)/
     x 3.0691496D-05, 1.2256847D-05,-1.6573732D-08 /
      data fpppp( 7,14, 6,1),fpppp( 7,14, 6,2),fpppp( 7,14, 6,3)/
     x 3.9886041D-06,-6.8764241D-05, 6.4605462D-08 /
      data fpppp( 7,14, 7,1),fpppp( 7,14, 7,2),fpppp( 7,14, 7,3)/
     x 1.2675532D-05, 2.1373224D-05,-1.8699630D-08 /
      data fpppp( 7,14, 8,1),fpppp( 7,14, 8,2),fpppp( 7,14, 8,3)/
     x 2.2130607D-05, 1.1760385D-05,-9.7301537D-09 /
      data fpppp( 7,14, 9,1),fpppp( 7,14, 9,2),fpppp( 7,14, 9,3)/
     x 2.3526580D-05, 1.1086223D-05,-4.2724989D-09 /
      data fpppp( 7,14,10,1),fpppp( 7,14,10,2),fpppp( 7,14,10,3)/
     x 2.2130607D-05, 1.1760385D-05,-9.7301537D-09 /
      data fpppp( 7,14,11,1),fpppp( 7,14,11,2),fpppp( 7,14,11,3)/
     x 1.2675532D-05, 2.1373224D-05,-1.8699630D-08 /
      data fpppp( 7,14,12,1),fpppp( 7,14,12,2),fpppp( 7,14,12,3)/
     x 3.9886041D-06,-6.8764241D-05, 6.4605462D-08 /
      data fpppp( 7,14,13,1),fpppp( 7,14,13,2),fpppp( 7,14,13,3)/
     x 3.0691496D-05, 1.2256847D-05,-1.6573732D-08 /
      data fpppp( 7,14,14,1),fpppp( 7,14,14,2),fpppp( 7,14,14,3)/
     x 3.2908229D-05, 1.2373719D-05,-1.6034636D-08 /
      data fpppp( 7,14,15,1),fpppp( 7,14,15,2),fpppp( 7,14,15,3)/
     x 3.4786493D-05, 1.0935299D-05,-3.0092152D-09 /
      data fpppp( 7,14,16,1),fpppp( 7,14,16,2),fpppp( 7,14,16,3)/
     x 3.2908229D-05, 1.2245385D-05,-1.5152071D-08 /
      data fpppp( 7,14,17,1),fpppp( 7,14,17,2),fpppp( 7,14,17,3)/
     x 3.0691496D-05, 1.2770183D-05,-2.0103991D-08 /
      data fpppp( 7,15, 1,1),fpppp( 7,15, 1,2),fpppp( 7,15, 1,3)/
     x 2.6604935D-05, 1.5099395D-05,-3.5196838D-08 /
      data fpppp( 7,15, 2,1),fpppp( 7,15, 2,2),fpppp( 7,15, 2,3)/
     x 4.3871451D-05, 1.4560588D-05,-3.0898077D-08 /
      data fpppp( 7,15, 3,1),fpppp( 7,15, 3,2),fpppp( 7,15, 3,3)/
     x 4.7678887D-05, 1.2575129D-05,-1.7370601D-08 /
      data fpppp( 7,15, 4,1),fpppp( 7,15, 4,2),fpppp( 7,15, 4,3)/
     x 4.3871451D-05, 1.5652954D-05,-3.6143628D-08 /
      data fpppp( 7,15, 5,1),fpppp( 7,15, 5,2),fpppp( 7,15, 5,3)/
     x 2.6604935D-05, 1.0729933D-05,-1.4214635D-08 /
      data fpppp( 7,15, 6,1),fpppp( 7,15, 6,2),fpppp( 7,15, 6,3)/
     x-6.4836464D-05,-7.9907050D-05, 1.2967680D-07 /
      data fpppp( 7,15, 7,1),fpppp( 7,15, 7,2),fpppp( 7,15, 7,3)/
     x 1.4397470D-05, 2.8937735D-05,-4.0752176D-08 /
      data fpppp( 7,15, 8,1),fpppp( 7,15, 8,2),fpppp( 7,15, 8,3)/
     x 3.3246190D-05, 1.2164716D-05,-2.2902097D-08 /
      data fpppp( 7,15, 9,1),fpppp( 7,15, 9,2),fpppp( 7,15, 9,3)/
     x 3.6712990D-05, 1.2450358D-05,-1.4832188D-08 /
      data fpppp( 7,15,10,1),fpppp( 7,15,10,2),fpppp( 7,15,10,3)/
     x 3.3246190D-05, 1.2164716D-05,-2.2902097D-08 /
      data fpppp( 7,15,11,1),fpppp( 7,15,11,2),fpppp( 7,15,11,3)/
     x 1.4397470D-05, 2.8937735D-05,-4.0752176D-08 /
      data fpppp( 7,15,12,1),fpppp( 7,15,12,2),fpppp( 7,15,12,3)/
     x-6.4836464D-05,-7.9907050D-05, 1.2967680D-07 /
      data fpppp( 7,15,13,1),fpppp( 7,15,13,2),fpppp( 7,15,13,3)/
     x 2.6604935D-05, 1.0729933D-05,-1.4214635D-08 /
      data fpppp( 7,15,14,1),fpppp( 7,15,14,2),fpppp( 7,15,14,3)/
     x 4.3871451D-05, 1.5652954D-05,-3.6143628D-08 /
      data fpppp( 7,15,15,1),fpppp( 7,15,15,2),fpppp( 7,15,15,3)/
     x 4.7678887D-05, 1.2575129D-05,-1.7370601D-08 /
      data fpppp( 7,15,16,1),fpppp( 7,15,16,2),fpppp( 7,15,16,3)/
     x 4.3871451D-05, 1.4560588D-05,-3.0898077D-08 /
      data fpppp( 7,15,17,1),fpppp( 7,15,17,2),fpppp( 7,15,17,3)/
     x 2.6604935D-05, 1.5099395D-05,-3.5196838D-08 /
      data fpppp( 7,16, 1,1),fpppp( 7,16, 1,2),fpppp( 7,16, 1,3)/
     x-2.5622517D-05, 1.3606638D-05,-2.2759182D-08 /
      data fpppp( 7,16, 2,1),fpppp( 7,16, 2,2),fpppp( 7,16, 2,3)/
     x 6.0969323D-05, 1.4437005D-05,-3.2027901D-08 /
      data fpppp( 7,16, 3,1),fpppp( 7,16, 3,2),fpppp( 7,16, 3,3)/
     x 7.1073103D-05, 1.3273977D-05,-4.2328732D-08 /
      data fpppp( 7,16, 4,1),fpppp( 7,16, 4,2),fpppp( 7,16, 4,3)/
     x 6.0969323D-05, 1.9087835D-05,-4.9017168D-08 /
      data fpppp( 7,16, 5,1),fpppp( 7,16, 5,2),fpppp( 7,16, 5,3)/
     x-2.5622517D-05,-4.9966806D-06, 4.5197886D-08 /
      data fpppp( 7,16, 6,1),fpppp( 7,16, 6,2),fpppp( 7,16, 6,3)/
     x-3.8900872D-05,-6.1948065D-05, 8.3691186D-08 /
      data fpppp( 7,16, 7,1),fpppp( 7,16, 7,2),fpppp( 7,16, 7,3)/
     x 1.4791708D-05, 2.1523892D-05,-1.0152702D-08 /
      data fpppp( 7,16, 8,1),fpppp( 7,16, 8,2),fpppp( 7,16, 8,3)/
     x 4.5580654D-05, 1.4083299D-05,-3.6661160D-08 /
      data fpppp( 7,16, 9,1),fpppp( 7,16, 9,2),fpppp( 7,16, 9,3)/
     x 4.9339267D-05, 1.2000602D-05,-2.6618896D-08 /
      data fpppp( 7,16,10,1),fpppp( 7,16,10,2),fpppp( 7,16,10,3)/
     x 4.5580654D-05, 1.4083299D-05,-3.6661160D-08 /
      data fpppp( 7,16,11,1),fpppp( 7,16,11,2),fpppp( 7,16,11,3)/
     x 1.4791708D-05, 2.1523892D-05,-1.0152702D-08 /
      data fpppp( 7,16,12,1),fpppp( 7,16,12,2),fpppp( 7,16,12,3)/
     x-3.8900872D-05,-6.1948065D-05, 8.3691186D-08 /
      data fpppp( 7,16,13,1),fpppp( 7,16,13,2),fpppp( 7,16,13,3)/
     x-2.5622517D-05,-4.9966806D-06, 4.5197886D-08 /
      data fpppp( 7,16,14,1),fpppp( 7,16,14,2),fpppp( 7,16,14,3)/
     x 6.0969323D-05, 1.9087835D-05,-4.9017168D-08 /
      data fpppp( 7,16,15,1),fpppp( 7,16,15,2),fpppp( 7,16,15,3)/
     x 7.1073103D-05, 1.3273977D-05,-4.2328732D-08 /
      data fpppp( 7,16,16,1),fpppp( 7,16,16,2),fpppp( 7,16,16,3)/
     x 6.0969323D-05, 1.4437005D-05,-3.2027901D-08 /
      data fpppp( 7,16,17,1),fpppp( 7,16,17,2),fpppp( 7,16,17,3)/
     x-2.5622517D-05, 1.3606638D-05,-2.2759182D-08 /
      data fpppp( 7,17, 1,1),fpppp( 7,17, 1,2),fpppp( 7,17, 1,3)/
     x-4.5689565D-05, 3.8858079D-06, 4.0852013D-08 /
      data fpppp( 7,17, 2,1),fpppp( 7,17, 2,2),fpppp( 7,17, 2,3)/
     x 2.2843386D-06, 7.5701537D-06, 1.1766121D-08 /
      data fpppp( 7,17, 3,1),fpppp( 7,17, 3,2),fpppp( 7,17, 3,3)/
     x 4.7536282D-05, 1.3381387D-05,-5.3558680D-08 /
      data fpppp( 7,17, 4,1),fpppp( 7,17, 4,2),fpppp( 7,17, 4,3)/
     x 2.2843386D-06, 1.1748514D-05, 7.9527022D-09 /
      data fpppp( 7,17, 5,1),fpppp( 7,17, 5,2),fpppp( 7,17, 5,3)/
     x-4.5689565D-05,-1.2827633D-05, 5.6105691D-08 /
      data fpppp( 7,17, 6,1),fpppp( 7,17, 6,2),fpppp( 7,17, 6,3)/
     x-1.8567156D-05,-3.2111369D-05,-3.8672346D-08 /
      data fpppp( 7,17, 7,1),fpppp( 7,17, 7,2),fpppp( 7,17, 7,3)/
     x 1.6772948D-05, 8.3454070D-06, 4.3843586D-08 /
      data fpppp( 7,17, 8,1),fpppp( 7,17, 8,2),fpppp( 7,17, 8,3)/
     x 7.7191470D-05, 1.3080368D-05,-2.1824863D-08 /
      data fpppp( 7,17, 9,1),fpppp( 7,17, 9,2),fpppp( 7,17, 9,3)/
     x 9.7699250D-05, 1.0844434D-05,-4.1886427D-08 /
      data fpppp( 7,17,10,1),fpppp( 7,17,10,2),fpppp( 7,17,10,3)/
     x 7.7191470D-05, 1.3080368D-05,-2.1824863D-08 /
      data fpppp( 7,17,11,1),fpppp( 7,17,11,2),fpppp( 7,17,11,3)/
     x 1.6772948D-05, 8.3454070D-06, 4.3843586D-08 /
      data fpppp( 7,17,12,1),fpppp( 7,17,12,2),fpppp( 7,17,12,3)/
     x-1.8567156D-05,-3.2111369D-05,-3.8672346D-08 /
      data fpppp( 7,17,13,1),fpppp( 7,17,13,2),fpppp( 7,17,13,3)/
     x-4.5689565D-05,-1.2827633D-05, 5.6105691D-08 /
      data fpppp( 7,17,14,1),fpppp( 7,17,14,2),fpppp( 7,17,14,3)/
     x 2.2843386D-06, 1.1748514D-05, 7.9527022D-09 /
      data fpppp( 7,17,15,1),fpppp( 7,17,15,2),fpppp( 7,17,15,3)/
     x 4.7536282D-05, 1.3381387D-05,-5.3558680D-08 /
      data fpppp( 7,17,16,1),fpppp( 7,17,16,2),fpppp( 7,17,16,3)/
     x 2.2843386D-06, 7.5701537D-06, 1.1766121D-08 /
      data fpppp( 7,17,17,1),fpppp( 7,17,17,2),fpppp( 7,17,17,3)/
     x-4.5689565D-05, 3.8858079D-06, 4.0852013D-08 /
      data fpppp( 7,18, 1,1),fpppp( 7,18, 1,2),fpppp( 7,18, 1,3)/
     x-6.1967311D-05,-1.4421119D-06, 2.3164026D-08 /
      data fpppp( 7,18, 2,1),fpppp( 7,18, 2,2),fpppp( 7,18, 2,3)/
     x-1.3914392D-04, 7.7861788D-07, 3.1984286D-08 /
      data fpppp( 7,18, 3,1),fpppp( 7,18, 3,2),fpppp( 7,18, 3,3)/
     x-1.6524931D-04, 4.7607717D-06, 4.5187072D-08 /
      data fpppp( 7,18, 4,1),fpppp( 7,18, 4,2),fpppp( 7,18, 4,3)/
     x-1.3914392D-04, 2.5779416D-06, 4.3051015D-08 /
      data fpppp( 7,18, 5,1),fpppp( 7,18, 5,2),fpppp( 7,18, 5,3)/
     x-6.1967311D-05,-8.6394068D-06,-2.1102890D-08 /
      data fpppp( 7,18, 6,1),fpppp( 7,18, 6,2),fpppp( 7,18, 6,3)/
     x 1.9691035D-05,-6.5000845D-06,-7.3237489D-08 /
      data fpppp( 7,18, 7,1),fpppp( 7,18, 7,2),fpppp( 7,18, 7,3)/
     x 2.9646869D-06, 2.1128112D-07, 2.5633516D-09 /
      data fpppp( 7,18, 8,1),fpppp( 7,18, 8,2),fpppp( 7,18, 8,3)/
     x 2.4411411D-06, 6.5268366D-06, 2.1136330D-08 /
      data fpppp( 7,18, 9,1),fpppp( 7,18, 9,2),fpppp( 7,18, 9,3)/
     x 1.1647955D-05, 7.1859795D-06, 1.1836747D-08 /
      data fpppp( 7,18,10,1),fpppp( 7,18,10,2),fpppp( 7,18,10,3)/
     x 2.4411411D-06, 6.5268366D-06, 2.1136330D-08 /
      data fpppp( 7,18,11,1),fpppp( 7,18,11,2),fpppp( 7,18,11,3)/
     x 2.9646869D-06, 2.1128112D-07, 2.5633516D-09 /
      data fpppp( 7,18,12,1),fpppp( 7,18,12,2),fpppp( 7,18,12,3)/
     x 1.9691035D-05,-6.5000845D-06,-7.3237489D-08 /
      data fpppp( 7,18,13,1),fpppp( 7,18,13,2),fpppp( 7,18,13,3)/
     x-6.1967311D-05,-8.6394068D-06,-2.1102890D-08 /
      data fpppp( 7,18,14,1),fpppp( 7,18,14,2),fpppp( 7,18,14,3)/
     x-1.3914392D-04, 2.5779416D-06, 4.3051015D-08 /
      data fpppp( 7,18,15,1),fpppp( 7,18,15,2),fpppp( 7,18,15,3)/
     x-1.6524931D-04, 4.7607717D-06, 4.5187072D-08 /
      data fpppp( 7,18,16,1),fpppp( 7,18,16,2),fpppp( 7,18,16,3)/
     x-1.3914392D-04, 7.7861788D-07, 3.1984286D-08 /
      data fpppp( 7,18,17,1),fpppp( 7,18,17,2),fpppp( 7,18,17,3)/
     x-6.1967311D-05,-1.4421119D-06, 2.3164026D-08 /
      data fpppp( 7,19, 1,1),fpppp( 7,19, 1,2),fpppp( 7,19, 1,3)/
     x-7.9327714D-05, 2.6536986D-19, 2.8704377D-08 /
      data fpppp( 7,19, 2,1),fpppp( 7,19, 2,2),fpppp( 7,19, 2,3)/
     x-2.5693125D-04,-1.8059599D-19, 5.8938410D-08 /
      data fpppp( 7,19, 3,1),fpppp( 7,19, 3,2),fpppp( 7,19, 3,3)/
     x-3.2396382D-04,-7.2103777D-20, 1.1251120D-07 /
      data fpppp( 7,19, 4,1),fpppp( 7,19, 4,2),fpppp( 7,19, 4,3)/
     x-2.5693125D-04,-1.7975874D-21, 8.4398344D-08 /
      data fpppp( 7,19, 5,1),fpppp( 7,19, 5,2),fpppp( 7,19, 5,3)/
     x-7.9327714D-05,-7.7885544D-20,-7.3135361D-08 /
      data fpppp( 7,19, 6,1),fpppp( 7,19, 6,2),fpppp( 7,19, 6,3)/
     x 5.2827947D-05,-1.4452234D-19,-1.3288789D-07 /
      data fpppp( 7,19, 7,1),fpppp( 7,19, 7,2),fpppp( 7,19, 7,3)/
     x-6.3322883D-06, 7.0788609D-20,-1.1495019D-08 /
      data fpppp( 7,19, 8,1),fpppp( 7,19, 8,2),fpppp( 7,19, 8,3)/
     x-4.1920289D-05,-4.7331354D-20, 5.6061838D-08 /
      data fpppp( 7,19, 9,1),fpppp( 7,19, 9,2),fpppp( 7,19, 9,3)/
     x-3.6000118D-05,-5.8428163D-20, 4.5848292D-08 /
      data fpppp( 7,19,10,1),fpppp( 7,19,10,2),fpppp( 7,19,10,3)/
     x-4.1920289D-05,-7.3263887D-20, 5.6061838D-08 /
      data fpppp( 7,19,11,1),fpppp( 7,19,11,2),fpppp( 7,19,11,3)/
     x-6.3322883D-06, 5.3377978D-21,-1.1495019D-08 /
      data fpppp( 7,19,12,1),fpppp( 7,19,12,2),fpppp( 7,19,12,3)/
     x 5.2827947D-05, 9.1517707D-20,-1.3288789D-07 /
      data fpppp( 7,19,13,1),fpppp( 7,19,13,2),fpppp( 7,19,13,3)/
     x-7.9327714D-05, 1.0037263D-19,-7.3135361D-08 /
      data fpppp( 7,19,14,1),fpppp( 7,19,14,2),fpppp( 7,19,14,3)/
     x-2.5693125D-04,-9.4754226D-20, 8.4398344D-08 /
      data fpppp( 7,19,15,1),fpppp( 7,19,15,2),fpppp( 7,19,15,3)/
     x-3.2396382D-04, 8.2804961D-21, 1.1251120D-07 /
      data fpppp( 7,19,16,1),fpppp( 7,19,16,2),fpppp( 7,19,16,3)/
     x-2.5693125D-04,-1.5322298D-19, 5.8938410D-08 /
      data fpppp( 7,19,17,1),fpppp( 7,19,17,2),fpppp( 7,19,17,3)/
     x-7.9327714D-05, 1.7536708D-19, 2.8704377D-08 /
      data fpppp( 8, 1, 1,1),fpppp( 8, 1, 1,2),fpppp( 8, 1, 1,3)/
     x 4.1005348D-07,-7.8318078D-21, 4.1458828D-09 /
      data fpppp( 8, 1, 2,1),fpppp( 8, 1, 2,2),fpppp( 8, 1, 2,3)/
     x-1.8369625D-05,-1.4361911D-20, 6.4290297D-09 /
      data fpppp( 8, 1, 3,1),fpppp( 8, 1, 3,2),fpppp( 8, 1, 3,3)/
     x-2.5901175D-05, 5.6589391D-21, 9.9725451D-09 /
      data fpppp( 8, 1, 4,1),fpppp( 8, 1, 4,2),fpppp( 8, 1, 4,3)/
     x-1.8369625D-05, 2.8771900D-20, 9.1047706D-09 /
      data fpppp( 8, 1, 5,1),fpppp( 8, 1, 5,2),fpppp( 8, 1, 5,3)/
     x 4.1005348D-07, 2.5398855D-20,-6.5570809D-09 /
      data fpppp( 8, 1, 6,1),fpppp( 8, 1, 6,2),fpppp( 8, 1, 6,3)/
     x 9.2699491D-06,-6.1728644D-22,-1.0732307D-08 /
      data fpppp( 8, 1, 7,1),fpppp( 8, 1, 7,2),fpppp( 8, 1, 7,3)/
     x 3.5011901D-06, 3.7837471D-20,-8.6924571D-09 /
      data fpppp( 8, 1, 8,1),fpppp( 8, 1, 8,2),fpppp( 8, 1, 8,3)/
     x-1.0784259D-05,-3.1606817D-20, 6.0034478D-09 /
      data fpppp( 8, 1, 9,1),fpppp( 8, 1, 9,2),fpppp( 8, 1, 9,3)/
     x-1.7025187D-05, 9.8979848D-23, 1.2220665D-08 /
      data fpppp( 8, 1,10,1),fpppp( 8, 1,10,2),fpppp( 8, 1,10,3)/
     x-1.0784259D-05, 2.7703998D-20, 6.0034478D-09 /
      data fpppp( 8, 1,11,1),fpppp( 8, 1,11,2),fpppp( 8, 1,11,3)/
     x 3.5011901D-06, 4.5280942D-20,-8.6924571D-09 /
      data fpppp( 8, 1,12,1),fpppp( 8, 1,12,2),fpppp( 8, 1,12,3)/
     x 9.2699491D-06,-1.7222756D-20,-1.0732307D-08 /
      data fpppp( 8, 1,13,1),fpppp( 8, 1,13,2),fpppp( 8, 1,13,3)/
     x 4.1005348D-07, 1.8246343D-20,-6.5570809D-09 /
      data fpppp( 8, 1,14,1),fpppp( 8, 1,14,2),fpppp( 8, 1,14,3)/
     x-1.8369625D-05, 1.2500420D-20, 9.1047706D-09 /
      data fpppp( 8, 1,15,1),fpppp( 8, 1,15,2),fpppp( 8, 1,15,3)/
     x-2.5901175D-05, 4.2953559D-21, 9.9725451D-09 /
      data fpppp( 8, 1,16,1),fpppp( 8, 1,16,2),fpppp( 8, 1,16,3)/
     x-1.8369625D-05,-1.4585854D-20, 6.4290297D-09 /
      data fpppp( 8, 1,17,1),fpppp( 8, 1,17,2),fpppp( 8, 1,17,3)/
     x 4.1005348D-07,-6.5166923D-21, 4.1458828D-09 /
      data fpppp( 8, 2, 1,1),fpppp( 8, 2, 1,2),fpppp( 8, 2, 1,3)/
     x-2.0998051D-06, 8.0860371D-08,-2.5755176D-09 /
      data fpppp( 8, 2, 2,1),fpppp( 8, 2, 2,2),fpppp( 8, 2, 2,3)/
     x-1.0269442D-05, 3.9483936D-07, 9.0500017D-10 /
      data fpppp( 8, 2, 3,1),fpppp( 8, 2, 3,2),fpppp( 8, 2, 3,3)/
     x-1.6311203D-05, 1.0565090D-06, 9.0464237D-09 /
      data fpppp( 8, 2, 4,1),fpppp( 8, 2, 4,2),fpppp( 8, 2, 4,3)/
     x-1.0269442D-05, 5.0126133D-07, 8.7467690D-10 /
      data fpppp( 8, 2, 5,1),fpppp( 8, 2, 5,2),fpppp( 8, 2, 5,3)/
     x-2.0998051D-06,-3.4482751D-07,-2.4542245D-09 /
      data fpppp( 8, 2, 6,1),fpppp( 8, 2, 6,2),fpppp( 8, 2, 6,3)/
     x 9.8033975D-07,-7.0267111D-07,-4.2393926D-09 /
      data fpppp( 8, 2, 7,1),fpppp( 8, 2, 7,2),fpppp( 8, 2, 7,3)/
     x-2.0103288D-06,-4.1485131D-07,-3.8973406D-09 /
      data fpppp( 8, 2, 8,1),fpppp( 8, 2, 8,2),fpppp( 8, 2, 8,3)/
     x-7.3400702D-06, 1.9854706D-07, 1.9727961D-09 /
      data fpppp( 8, 2, 9,1),fpppp( 8, 2, 9,2),fpppp( 8, 2, 9,3)/
     x-1.0126846D-05, 4.8631101D-07, 6.4354917D-09 /
      data fpppp( 8, 2,10,1),fpppp( 8, 2,10,2),fpppp( 8, 2,10,3)/
     x-7.3400702D-06, 1.9854706D-07, 1.9727961D-09 /
      data fpppp( 8, 2,11,1),fpppp( 8, 2,11,2),fpppp( 8, 2,11,3)/
     x-2.0103288D-06,-4.1485131D-07,-3.8973406D-09 /
      data fpppp( 8, 2,12,1),fpppp( 8, 2,12,2),fpppp( 8, 2,12,3)/
     x 9.8033975D-07,-7.0267111D-07,-4.2393926D-09 /
      data fpppp( 8, 2,13,1),fpppp( 8, 2,13,2),fpppp( 8, 2,13,3)/
     x-2.0998051D-06,-3.4482751D-07,-2.4542245D-09 /
      data fpppp( 8, 2,14,1),fpppp( 8, 2,14,2),fpppp( 8, 2,14,3)/
     x-1.0269442D-05, 5.0126133D-07, 8.7467690D-10 /
      data fpppp( 8, 2,15,1),fpppp( 8, 2,15,2),fpppp( 8, 2,15,3)/
     x-1.6311203D-05, 1.0565090D-06, 9.0464237D-09 /
      data fpppp( 8, 2,16,1),fpppp( 8, 2,16,2),fpppp( 8, 2,16,3)/
     x-1.0269442D-05, 3.9483936D-07, 9.0500017D-10 /
      data fpppp( 8, 2,17,1),fpppp( 8, 2,17,2),fpppp( 8, 2,17,3)/
     x-2.0998051D-06, 8.0860371D-08,-2.5755176D-09 /
      data fpppp( 8, 3, 1,1),fpppp( 8, 3, 1,2),fpppp( 8, 3, 1,3)/
     x-5.6691605D-06,-7.3449732D-07,-1.2880050D-08 /
      data fpppp( 8, 3, 2,1),fpppp( 8, 3, 2,2),fpppp( 8, 3, 2,3)/
     x-4.9614677D-06, 8.0291807D-07,-5.8165561D-09 /
      data fpppp( 8, 3, 3,1),fpppp( 8, 3, 3,2),fpppp( 8, 3, 3,3)/
     x-1.2132794D-05, 4.2763468D-06, 1.2908100D-08 /
      data fpppp( 8, 3, 4,1),fpppp( 8, 3, 4,2),fpppp( 8, 3, 4,3)/
     x-4.9614677D-06, 9.7372886D-07,-9.1813132D-09 /
      data fpppp( 8, 3, 5,1),fpppp( 8, 3, 5,2),fpppp( 8, 3, 5,3)/
     x-5.6691605D-06,-1.4177405D-06, 5.7897880D-10 /
      data fpppp( 8, 3, 6,1),fpppp( 8, 3, 6,2),fpppp( 8, 3, 6,3)/
     x-9.2391623D-06,-2.1464354D-06, 3.7677125D-09 /
      data fpppp( 8, 3, 7,1),fpppp( 8, 3, 7,2),fpppp( 8, 3, 7,3)/
     x-9.2590713D-06,-1.0663349D-06, 1.6547907D-10 /
      data fpppp( 8, 3, 8,1),fpppp( 8, 3, 8,2),fpppp( 8, 3, 8,3)/
     x-3.9001947D-06, 6.9647258D-07,-2.1471067D-09 /
      data fpppp( 8, 3, 9,1),fpppp( 8, 3, 9,2),fpppp( 8, 3, 9,3)/
     x-1.8086994D-06, 1.6727405D-06, 1.6360577D-10 /
      data fpppp( 8, 3,10,1),fpppp( 8, 3,10,2),fpppp( 8, 3,10,3)/
     x-3.9001947D-06, 6.9647258D-07,-2.1471067D-09 /
      data fpppp( 8, 3,11,1),fpppp( 8, 3,11,2),fpppp( 8, 3,11,3)/
     x-9.2590713D-06,-1.0663349D-06, 1.6547907D-10 /
      data fpppp( 8, 3,12,1),fpppp( 8, 3,12,2),fpppp( 8, 3,12,3)/
     x-9.2391623D-06,-2.1464354D-06, 3.7677125D-09 /
      data fpppp( 8, 3,13,1),fpppp( 8, 3,13,2),fpppp( 8, 3,13,3)/
     x-5.6691605D-06,-1.4177405D-06, 5.7897880D-10 /
      data fpppp( 8, 3,14,1),fpppp( 8, 3,14,2),fpppp( 8, 3,14,3)/
     x-4.9614677D-06, 9.7372886D-07,-9.1813132D-09 /
      data fpppp( 8, 3,15,1),fpppp( 8, 3,15,2),fpppp( 8, 3,15,3)/
     x-1.2132794D-05, 4.2763468D-06, 1.2908100D-08 /
      data fpppp( 8, 3,16,1),fpppp( 8, 3,16,2),fpppp( 8, 3,16,3)/
     x-4.9614677D-06, 8.0291807D-07,-5.8165561D-09 /
      data fpppp( 8, 3,17,1),fpppp( 8, 3,17,2),fpppp( 8, 3,17,3)/
     x-5.6691605D-06,-7.3449732D-07,-1.2880050D-08 /
      data fpppp( 8, 4, 1,1),fpppp( 8, 4, 1,2),fpppp( 8, 4, 1,3)/
     x-5.5302770D-06,-4.2370618D-06,-1.0643621D-08 /
      data fpppp( 8, 4, 2,1),fpppp( 8, 4, 2,2),fpppp( 8, 4, 2,3)/
     x 1.0119235D-05,-1.2648903D-08,-8.3467687D-09 /
      data fpppp( 8, 4, 3,1),fpppp( 8, 4, 3,2),fpppp( 8, 4, 3,3)/
     x 1.0986082D-05, 1.0170100D-05, 1.2483689D-11 /
      data fpppp( 8, 4, 4,1),fpppp( 8, 4, 4,2),fpppp( 8, 4, 4,3)/
     x 1.0119235D-05,-5.0132735D-07,-1.2846666D-08 /
      data fpppp( 8, 4, 5,1),fpppp( 8, 4, 5,2),fpppp( 8, 4, 5,3)/
     x-5.5302770D-06,-2.2823480D-06, 7.3559680D-09 /
      data fpppp( 8, 4, 6,1),fpppp( 8, 4, 6,2),fpppp( 8, 4, 6,3)/
     x-1.2704040D-05,-3.3717845D-06, 6.4751494D-09 /
      data fpppp( 8, 4, 7,1),fpppp( 8, 4, 7,2),fpppp( 8, 4, 7,3)/
     x-1.0427531D-05,-8.4647069D-07, 6.7913378D-09 /
      data fpppp( 8, 4, 8,1),fpppp( 8, 4, 8,2),fpppp( 8, 4, 8,3)/
     x-4.4522327D-07, 4.7746570D-07,-5.9546305D-09 /
      data fpppp( 8, 4, 9,1),fpppp( 8, 4, 9,2),fpppp( 8, 4, 9,3)/
     x 1.5401266D-06, 2.7973831D-06,-4.4047843D-09 /
      data fpppp( 8, 4,10,1),fpppp( 8, 4,10,2),fpppp( 8, 4,10,3)/
     x-4.4522327D-07, 4.7746570D-07,-5.9546305D-09 /
      data fpppp( 8, 4,11,1),fpppp( 8, 4,11,2),fpppp( 8, 4,11,3)/
     x-1.0427531D-05,-8.4647069D-07, 6.7913378D-09 /
      data fpppp( 8, 4,12,1),fpppp( 8, 4,12,2),fpppp( 8, 4,12,3)/
     x-1.2704040D-05,-3.3717845D-06, 6.4751494D-09 /
      data fpppp( 8, 4,13,1),fpppp( 8, 4,13,2),fpppp( 8, 4,13,3)/
     x-5.5302770D-06,-2.2823480D-06, 7.3559680D-09 /
      data fpppp( 8, 4,14,1),fpppp( 8, 4,14,2),fpppp( 8, 4,14,3)/
     x 1.0119235D-05,-5.0132735D-07,-1.2846666D-08 /
      data fpppp( 8, 4,15,1),fpppp( 8, 4,15,2),fpppp( 8, 4,15,3)/
     x 1.0986082D-05, 1.0170100D-05, 1.2483689D-11 /
      data fpppp( 8, 4,16,1),fpppp( 8, 4,16,2),fpppp( 8, 4,16,3)/
     x 1.0119235D-05,-1.2648903D-08,-8.3467687D-09 /
      data fpppp( 8, 4,17,1),fpppp( 8, 4,17,2),fpppp( 8, 4,17,3)/
     x-5.5302770D-06,-4.2370618D-06,-1.0643621D-08 /
      data fpppp( 8, 5, 1,1),fpppp( 8, 5, 1,2),fpppp( 8, 5, 1,3)/
     x-1.8659780D-06,-9.5726450D-06, 1.6909710D-08 /
      data fpppp( 8, 5, 2,1),fpppp( 8, 5, 2,2),fpppp( 8, 5, 2,3)/
     x 1.7559842D-05,-2.2627178D-06, 2.7132737D-09 /
      data fpppp( 8, 5, 3,1),fpppp( 8, 5, 3,2),fpppp( 8, 5, 3,3)/
     x 3.6622523D-05, 1.6149011D-05,-3.2171785D-08 /
      data fpppp( 8, 5, 4,1),fpppp( 8, 5, 4,2),fpppp( 8, 5, 4,3)/
     x 1.7559842D-05,-4.2955659D-06, 5.3533336D-09 /
      data fpppp( 8, 5, 5,1),fpppp( 8, 5, 5,2),fpppp( 8, 5, 5,3)/
     x-1.8659780D-06,-1.4412526D-06, 6.3494706D-09 /
      data fpppp( 8, 5, 6,1),fpppp( 8, 5, 6,2),fpppp( 8, 5, 6,3)/
     x-5.1864514D-06,-3.8623139D-06, 7.8570469D-09 /
      data fpppp( 8, 5, 7,1),fpppp( 8, 5, 7,2),fpppp( 8, 5, 7,3)/
     x 1.0758849D-06, 3.8774459D-07, 3.7541980D-10 /
      data fpppp( 8, 5, 8,1),fpppp( 8, 5, 8,2),fpppp( 8, 5, 8,3)/
     x 2.4503509D-06,-1.0544192D-06,-9.0472834D-10 /
      data fpppp( 8, 5, 9,1),fpppp( 8, 5, 9,2),fpppp( 8, 5, 9,3)/
     x 2.0415058D-06, 4.0437952D-06,-5.4492901D-09 /
      data fpppp( 8, 5,10,1),fpppp( 8, 5,10,2),fpppp( 8, 5,10,3)/
     x 2.4503509D-06,-1.0544192D-06,-9.0472834D-10 /
      data fpppp( 8, 5,11,1),fpppp( 8, 5,11,2),fpppp( 8, 5,11,3)/
     x 1.0758849D-06, 3.8774459D-07, 3.7541980D-10 /
      data fpppp( 8, 5,12,1),fpppp( 8, 5,12,2),fpppp( 8, 5,12,3)/
     x-5.1864514D-06,-3.8623139D-06, 7.8570469D-09 /
      data fpppp( 8, 5,13,1),fpppp( 8, 5,13,2),fpppp( 8, 5,13,3)/
     x-1.8659780D-06,-1.4412526D-06, 6.3494706D-09 /
      data fpppp( 8, 5,14,1),fpppp( 8, 5,14,2),fpppp( 8, 5,14,3)/
     x 1.7559842D-05,-4.2955659D-06, 5.3533336D-09 /
      data fpppp( 8, 5,15,1),fpppp( 8, 5,15,2),fpppp( 8, 5,15,3)/
     x 3.6622523D-05, 1.6149011D-05,-3.2171785D-08 /
      data fpppp( 8, 5,16,1),fpppp( 8, 5,16,2),fpppp( 8, 5,16,3)/
     x 1.7559842D-05,-2.2627178D-06, 2.7132737D-09 /
      data fpppp( 8, 5,17,1),fpppp( 8, 5,17,2),fpppp( 8, 5,17,3)/
     x-1.8659780D-06,-9.5726450D-06, 1.6909710D-08 /
      data fpppp( 8, 6, 1,1),fpppp( 8, 6, 1,2),fpppp( 8, 6, 1,3)/
     x 1.7494280D-06,-1.1420847D-05, 2.5893114D-08 /
      data fpppp( 8, 6, 2,1),fpppp( 8, 6, 2,2),fpppp( 8, 6, 2,3)/
     x 7.2631577D-06,-3.8008475D-06, 9.6370048D-09 /
      data fpppp( 8, 6, 3,1),fpppp( 8, 6, 3,2),fpppp( 8, 6, 3,3)/
     x 3.1191645D-05, 1.6034954D-05,-3.2867001D-08 /
      data fpppp( 8, 6, 4,1),fpppp( 8, 6, 4,2),fpppp( 8, 6, 4,3)/
     x 7.2631577D-06,-6.8845532D-06, 1.6496633D-08 /
      data fpppp( 8, 6, 5,1),fpppp( 8, 6, 5,2),fpppp( 8, 6, 5,3)/
     x 1.7494280D-06, 9.1397589D-07,-1.5453982D-09 /
      data fpppp( 8, 6, 6,1),fpppp( 8, 6, 6,2),fpppp( 8, 6, 6,3)/
     x 1.3739928D-06,-2.9440240D-06, 2.8795521D-09 /
      data fpppp( 8, 6, 7,1),fpppp( 8, 6, 7,2),fpppp( 8, 6, 7,3)/
     x 7.6206299D-06, 5.1739159D-07,-1.7930256D-09 /
      data fpppp( 8, 6, 8,1),fpppp( 8, 6, 8,2),fpppp( 8, 6, 8,3)/
     x-2.1330571D-07,-2.4575454D-06, 3.4306892D-09 /
      data fpppp( 8, 6, 9,1),fpppp( 8, 6, 9,2),fpppp( 8, 6, 9,3)/
     x 6.1073928D-07, 5.1606050D-06,-4.9266281D-09 /
      data fpppp( 8, 6,10,1),fpppp( 8, 6,10,2),fpppp( 8, 6,10,3)/
     x-2.1330571D-07,-2.4575454D-06, 3.4306892D-09 /
      data fpppp( 8, 6,11,1),fpppp( 8, 6,11,2),fpppp( 8, 6,11,3)/
     x 7.6206299D-06, 5.1739159D-07,-1.7930256D-09 /
      data fpppp( 8, 6,12,1),fpppp( 8, 6,12,2),fpppp( 8, 6,12,3)/
     x 1.3739928D-06,-2.9440240D-06, 2.8795521D-09 /
      data fpppp( 8, 6,13,1),fpppp( 8, 6,13,2),fpppp( 8, 6,13,3)/
     x 1.7494280D-06, 9.1397589D-07,-1.5453982D-09 /
      data fpppp( 8, 6,14,1),fpppp( 8, 6,14,2),fpppp( 8, 6,14,3)/
     x 7.2631577D-06,-6.8845532D-06, 1.6496633D-08 /
      data fpppp( 8, 6,15,1),fpppp( 8, 6,15,2),fpppp( 8, 6,15,3)/
     x 3.1191645D-05, 1.6034954D-05,-3.2867001D-08 /
      data fpppp( 8, 6,16,1),fpppp( 8, 6,16,2),fpppp( 8, 6,16,3)/
     x 7.2631577D-06,-3.8008475D-06, 9.6370048D-09 /
      data fpppp( 8, 6,17,1),fpppp( 8, 6,17,2),fpppp( 8, 6,17,3)/
     x 1.7494280D-06,-1.1420847D-05, 2.5893114D-08 /
      data fpppp( 8, 7, 1,1),fpppp( 8, 7, 1,2),fpppp( 8, 7, 1,3)/
     x 3.4875128D-06,-6.8091683D-06, 2.7491433D-09 /
      data fpppp( 8, 7, 2,1),fpppp( 8, 7, 2,2),fpppp( 8, 7, 2,3)/
     x-6.3818826D-06,-2.8106654D-06, 3.2160891D-09 /
      data fpppp( 8, 7, 3,1),fpppp( 8, 7, 3,2),fpppp( 8, 7, 3,3)/
     x-1.0908223D-05, 8.0854310D-06, 3.0189531D-09 /
      data fpppp( 8, 7, 4,1),fpppp( 8, 7, 4,2),fpppp( 8, 7, 4,3)/
     x-6.3818826D-06,-5.1600502D-06, 5.1461034D-09 /
      data fpppp( 8, 7, 5,1),fpppp( 8, 7, 5,2),fpppp( 8, 7, 5,3)/
     x 3.4875128D-06, 2.5883706D-06,-4.9709136D-09 /
      data fpppp( 8, 7, 6,1),fpppp( 8, 7, 6,2),fpppp( 8, 7, 6,3)/
     x 4.6689911D-06,-5.0804381D-07,-6.0490809D-09 /
      data fpppp( 8, 7, 7,1),fpppp( 8, 7, 7,2),fpppp( 8, 7, 7,3)/
     x-2.8292614D-06,-1.6994035D-06, 3.1750202D-09 /
      data fpppp( 8, 7, 8,1),fpppp( 8, 7, 8,2),fpppp( 8, 7, 8,3)/
     x-3.2771949D-06,-2.0103537D-06, 2.0224465D-09 /
      data fpppp( 8, 7, 9,1),fpppp( 8, 7, 9,2),fpppp( 8, 7, 9,3)/
     x-1.6593125D-06, 5.1019660D-06,-1.3444350D-09 /
      data fpppp( 8, 7,10,1),fpppp( 8, 7,10,2),fpppp( 8, 7,10,3)/
     x-3.2771949D-06,-2.0103537D-06, 2.0224465D-09 /
      data fpppp( 8, 7,11,1),fpppp( 8, 7,11,2),fpppp( 8, 7,11,3)/
     x-2.8292614D-06,-1.6994035D-06, 3.1750202D-09 /
      data fpppp( 8, 7,12,1),fpppp( 8, 7,12,2),fpppp( 8, 7,12,3)/
     x 4.6689911D-06,-5.0804381D-07,-6.0490809D-09 /
      data fpppp( 8, 7,13,1),fpppp( 8, 7,13,2),fpppp( 8, 7,13,3)/
     x 3.4875128D-06, 2.5883706D-06,-4.9709136D-09 /
      data fpppp( 8, 7,14,1),fpppp( 8, 7,14,2),fpppp( 8, 7,14,3)/
     x-6.3818826D-06,-5.1600502D-06, 5.1461034D-09 /
      data fpppp( 8, 7,15,1),fpppp( 8, 7,15,2),fpppp( 8, 7,15,3)/
     x-1.0908223D-05, 8.0854310D-06, 3.0189531D-09 /
      data fpppp( 8, 7,16,1),fpppp( 8, 7,16,2),fpppp( 8, 7,16,3)/
     x-6.3818826D-06,-2.8106654D-06, 3.2160891D-09 /
      data fpppp( 8, 7,17,1),fpppp( 8, 7,17,2),fpppp( 8, 7,17,3)/
     x 3.4875128D-06,-6.8091683D-06, 2.7491433D-09 /
      data fpppp( 8, 8, 1,1),fpppp( 8, 8, 1,2),fpppp( 8, 8, 1,3)/
     x 3.5756762D-06,-1.2527357D-06,-1.0165644D-08 /
      data fpppp( 8, 8, 2,1),fpppp( 8, 8, 2,2),fpppp( 8, 8, 2,3)/
     x-1.0312082D-05,-1.0341256D-06,-1.1627817D-09 /
      data fpppp( 8, 8, 3,1),fpppp( 8, 8, 3,2),fpppp( 8, 8, 3,3)/
     x-2.6664238D-05, 1.9267590D-07, 2.0792827D-08 /
      data fpppp( 8, 8, 4,1),fpppp( 8, 8, 4,2),fpppp( 8, 8, 4,3)/
     x-1.0312082D-05,-2.1091928D-06,-2.5861780D-09 /
      data fpppp( 8, 8, 5,1),fpppp( 8, 8, 5,2),fpppp( 8, 8, 5,3)/
     x 3.5756762D-06, 3.0475331D-06,-4.4720585D-09 /
      data fpppp( 8, 8, 6,1),fpppp( 8, 8, 6,2),fpppp( 8, 8, 6,3)/
     x 6.5255312D-06, 9.5681365D-07,-8.2936524D-09 /
      data fpppp( 8, 8, 7,1),fpppp( 8, 8, 7,2),fpppp( 8, 8, 7,3)/
     x-1.9922460D-06,-3.2125291D-06, 1.3957514D-09 /
      data fpppp( 8, 8, 8,1),fpppp( 8, 8, 8,2),fpppp( 8, 8, 8,3)/
     x-3.6718799D-06,-1.0779567D-06, 2.2787231D-09 /
      data fpppp( 8, 8, 9,1),fpppp( 8, 8, 9,2),fpppp( 8, 8, 9,3)/
     x-4.0929968D-06, 4.4188100D-06, 2.3247690D-09 /
      data fpppp( 8, 8,10,1),fpppp( 8, 8,10,2),fpppp( 8, 8,10,3)/
     x-3.6718799D-06,-1.0779567D-06, 2.2787231D-09 /
      data fpppp( 8, 8,11,1),fpppp( 8, 8,11,2),fpppp( 8, 8,11,3)/
     x-1.9922460D-06,-3.2125291D-06, 1.3957514D-09 /
      data fpppp( 8, 8,12,1),fpppp( 8, 8,12,2),fpppp( 8, 8,12,3)/
     x 6.5255312D-06, 9.5681365D-07,-8.2936524D-09 /
      data fpppp( 8, 8,13,1),fpppp( 8, 8,13,2),fpppp( 8, 8,13,3)/
     x 3.5756762D-06, 3.0475331D-06,-4.4720585D-09 /
      data fpppp( 8, 8,14,1),fpppp( 8, 8,14,2),fpppp( 8, 8,14,3)/
     x-1.0312082D-05,-2.1091928D-06,-2.5861780D-09 /
      data fpppp( 8, 8,15,1),fpppp( 8, 8,15,2),fpppp( 8, 8,15,3)/
     x-2.6664238D-05, 1.9267590D-07, 2.0792827D-08 /
      data fpppp( 8, 8,16,1),fpppp( 8, 8,16,2),fpppp( 8, 8,16,3)/
     x-1.0312082D-05,-1.0341256D-06,-1.1627817D-09 /
      data fpppp( 8, 8,17,1),fpppp( 8, 8,17,2),fpppp( 8, 8,17,3)/
     x 3.5756762D-06,-1.2527357D-06,-1.0165644D-08 /
      data fpppp( 8, 9, 1,1),fpppp( 8, 9, 1,2),fpppp( 8, 9, 1,3)/
     x 3.4234410D-06, 1.4638512D-06,-6.8044535D-09 /
      data fpppp( 8, 9, 2,1),fpppp( 8, 9, 2,2),fpppp( 8, 9, 2,3)/
     x-7.7488264D-06, 1.2498052D-07,-2.9192779D-11 /
      data fpppp( 8, 9, 3,1),fpppp( 8, 9, 3,2),fpppp( 8, 9, 3,3)/
     x-1.8148108D-05,-2.8062271D-06, 1.6424545D-08 /
      data fpppp( 8, 9, 4,1),fpppp( 8, 9, 4,2),fpppp( 8, 9, 4,3)/
     x-7.7488264D-06,-1.6425550D-07,-9.9638765D-10 /
      data fpppp( 8, 9, 5,1),fpppp( 8, 9, 5,2),fpppp( 8, 9, 5,3)/
     x 3.4234410D-06, 2.6207953D-06,-2.9356739D-09 /
      data fpppp( 8, 9, 6,1),fpppp( 8, 9, 6,2),fpppp( 8, 9, 6,3)/
     x 7.7679414D-06, 4.8593717D-07,-8.8820273D-09 /
      data fpppp( 8, 9, 7,1),fpppp( 8, 9, 7,2),fpppp( 8, 9, 7,3)/
     x 2.1477578D-06,-3.2651457D-06,-6.6033243D-10 /
      data fpppp( 8, 9, 8,1),fpppp( 8, 9, 8,2),fpppp( 8, 9, 8,3)/
     x-3.7778652D-06,-2.6325568D-07, 3.0976058D-09 /
      data fpppp( 8, 9, 9,1),fpppp( 8, 9, 9,2),fpppp( 8, 9, 9,3)/
     x-6.1479029D-06, 3.9298700D-06, 4.1678866D-09 /
      data fpppp( 8, 9,10,1),fpppp( 8, 9,10,2),fpppp( 8, 9,10,3)/
     x-3.7778652D-06,-2.6325568D-07, 3.0976058D-09 /
      data fpppp( 8, 9,11,1),fpppp( 8, 9,11,2),fpppp( 8, 9,11,3)/
     x 2.1477578D-06,-3.2651457D-06,-6.6033243D-10 /
      data fpppp( 8, 9,12,1),fpppp( 8, 9,12,2),fpppp( 8, 9,12,3)/
     x 7.7679414D-06, 4.8593717D-07,-8.8820273D-09 /
      data fpppp( 8, 9,13,1),fpppp( 8, 9,13,2),fpppp( 8, 9,13,3)/
     x 3.4234410D-06, 2.6207953D-06,-2.9356739D-09 /
      data fpppp( 8, 9,14,1),fpppp( 8, 9,14,2),fpppp( 8, 9,14,3)/
     x-7.7488264D-06,-1.6425550D-07,-9.9638765D-10 /
      data fpppp( 8, 9,15,1),fpppp( 8, 9,15,2),fpppp( 8, 9,15,3)/
     x-1.8148108D-05,-2.8062271D-06, 1.6424545D-08 /
      data fpppp( 8, 9,16,1),fpppp( 8, 9,16,2),fpppp( 8, 9,16,3)/
     x-7.7488264D-06, 1.2498052D-07,-2.9192779D-11 /
      data fpppp( 8, 9,17,1),fpppp( 8, 9,17,2),fpppp( 8, 9,17,3)/
     x 3.4234410D-06, 1.4638512D-06,-6.8044535D-09 /
      data fpppp( 8,10, 1,1),fpppp( 8,10, 1,2),fpppp( 8,10, 1,3)/
     x 4.1282157D-06, 2.2295004D-06,-5.7113138D-10 /
      data fpppp( 8,10, 2,1),fpppp( 8,10, 2,2),fpppp( 8,10, 2,3)/
     x-4.3620190D-06, 9.6543761D-07, 2.2687305D-09 /
      data fpppp( 8,10, 3,1),fpppp( 8,10, 3,2),fpppp( 8,10, 3,3)/
     x-8.9953608D-06,-2.0813255D-06, 8.7068694D-09 /
      data fpppp( 8,10, 4,1),fpppp( 8,10, 4,2),fpppp( 8,10, 4,3)/
     x-4.3620190D-06, 1.1113624D-06, 2.5510389D-09 /
      data fpppp( 8,10, 5,1),fpppp( 8,10, 5,2),fpppp( 8,10, 5,3)/
     x 4.1282157D-06, 1.6458012D-06,-1.7003648D-09 /
      data fpppp( 8,10, 6,1),fpppp( 8,10, 6,2),fpppp( 8,10, 6,3)/
     x 9.4466195D-06,-1.7249059D-06,-1.1057072D-08 /
      data fpppp( 8,10, 7,1),fpppp( 8,10, 7,2),fpppp( 8,10, 7,3)/
     x 3.0129409D-06,-2.8183566D-06,-1.6396634D-10 /
      data fpppp( 8,10, 8,1),fpppp( 8,10, 8,2),fpppp( 8,10, 8,3)/
     x-4.1328059D-06, 8.3871305D-07, 3.7278664D-09 /
      data fpppp( 8,10, 9,1),fpppp( 8,10, 9,2),fpppp( 8,10, 9,3)/
     x-6.8877298D-06, 4.0004178D-06, 4.6251782D-09 /
      data fpppp( 8,10,10,1),fpppp( 8,10,10,2),fpppp( 8,10,10,3)/
     x-4.1328059D-06, 8.3871305D-07, 3.7278664D-09 /
      data fpppp( 8,10,11,1),fpppp( 8,10,11,2),fpppp( 8,10,11,3)/
     x 3.0129409D-06,-2.8183566D-06,-1.6396634D-10 /
      data fpppp( 8,10,12,1),fpppp( 8,10,12,2),fpppp( 8,10,12,3)/
     x 9.4466195D-06,-1.7249059D-06,-1.1057072D-08 /
      data fpppp( 8,10,13,1),fpppp( 8,10,13,2),fpppp( 8,10,13,3)/
     x 4.1282157D-06, 1.6458012D-06,-1.7003648D-09 /
      data fpppp( 8,10,14,1),fpppp( 8,10,14,2),fpppp( 8,10,14,3)/
     x-4.3620190D-06, 1.1113624D-06, 2.5510389D-09 /
      data fpppp( 8,10,15,1),fpppp( 8,10,15,2),fpppp( 8,10,15,3)/
     x-8.9953608D-06,-2.0813255D-06, 8.7068694D-09 /
      data fpppp( 8,10,16,1),fpppp( 8,10,16,2),fpppp( 8,10,16,3)/
     x-4.3620190D-06, 9.6543761D-07, 2.2687305D-09 /
      data fpppp( 8,10,17,1),fpppp( 8,10,17,2),fpppp( 8,10,17,3)/
     x 4.1282157D-06, 2.2295004D-06,-5.7113138D-10 /
      data fpppp( 8,11, 1,1),fpppp( 8,11, 1,2),fpppp( 8,11, 1,3)/
     x 5.7624078D-06, 2.7320794D-06, 3.6861231D-09 /
      data fpppp( 8,11, 2,1),fpppp( 8,11, 2,2),fpppp( 8,11, 2,3)/
     x-9.7456279D-07, 2.0808581D-06, 3.9599825D-09 /
      data fpppp( 8,11, 3,1),fpppp( 8,11, 3,2),fpppp( 8,11, 3,3)/
     x-2.3657405D-06, 2.0083170D-07, 3.8079854D-09 /
      data fpppp( 8,11, 4,1),fpppp( 8,11, 4,2),fpppp( 8,11, 4,3)/
     x-9.7456279D-07, 2.6216230D-06, 5.1464859D-09 /
      data fpppp( 8,11, 5,1),fpppp( 8,11, 5,2),fpppp( 8,11, 5,3)/
     x 5.7624078D-06, 5.6901971D-07,-1.0598907D-09 /
      data fpppp( 8,11, 6,1),fpppp( 8,11, 6,2),fpppp( 8,11, 6,3)/
     x 1.2035242D-05,-5.9831563D-06,-1.4295842D-08 /
      data fpppp( 8,11, 7,1),fpppp( 8,11, 7,2),fpppp( 8,11, 7,3)/
     x 3.6035123D-06,-2.0443255D-06, 2.2978559D-09 /
      data fpppp( 8,11, 8,1),fpppp( 8,11, 8,2),fpppp( 8,11, 8,3)/
     x-3.7554822D-06, 2.4479019D-06, 4.0704548D-09 /
      data fpppp( 8,11, 9,1),fpppp( 8,11, 9,2),fpppp( 8,11, 9,3)/
     x-5.6624112D-06, 4.6671702D-06, 4.0716373D-09 /
      data fpppp( 8,11,10,1),fpppp( 8,11,10,2),fpppp( 8,11,10,3)/
     x-3.7554822D-06, 2.4479019D-06, 4.0704548D-09 /
      data fpppp( 8,11,11,1),fpppp( 8,11,11,2),fpppp( 8,11,11,3)/
     x 3.6035123D-06,-2.0443255D-06, 2.2978559D-09 /
      data fpppp( 8,11,12,1),fpppp( 8,11,12,2),fpppp( 8,11,12,3)/
     x 1.2035242D-05,-5.9831563D-06,-1.4295842D-08 /
      data fpppp( 8,11,13,1),fpppp( 8,11,13,2),fpppp( 8,11,13,3)/
     x 5.7624078D-06, 5.6901971D-07,-1.0598907D-09 /
      data fpppp( 8,11,14,1),fpppp( 8,11,14,2),fpppp( 8,11,14,3)/
     x-9.7456279D-07, 2.6216230D-06, 5.1464859D-09 /
      data fpppp( 8,11,15,1),fpppp( 8,11,15,2),fpppp( 8,11,15,3)/
     x-2.3657405D-06, 2.0083170D-07, 3.8079854D-09 /
      data fpppp( 8,11,16,1),fpppp( 8,11,16,2),fpppp( 8,11,16,3)/
     x-9.7456279D-07, 2.0808581D-06, 3.9599825D-09 /
      data fpppp( 8,11,17,1),fpppp( 8,11,17,2),fpppp( 8,11,17,3)/
     x 5.7624078D-06, 2.7320794D-06, 3.6861231D-09 /
      data fpppp( 8,12, 1,1),fpppp( 8,12, 1,2),fpppp( 8,12, 1,3)/
     x 8.9733760D-06, 3.9391606D-06, 4.1464810D-09 /
      data fpppp( 8,12, 2,1),fpppp( 8,12, 2,2),fpppp( 8,12, 2,3)/
     x 4.3525773D-06, 3.7818552D-06, 3.6983225D-09 /
      data fpppp( 8,12, 3,1),fpppp( 8,12, 3,2),fpppp( 8,12, 3,3)/
     x 4.2631626D-06, 2.7441189D-06, 1.8334153D-09 /
      data fpppp( 8,12, 4,1),fpppp( 8,12, 4,2),fpppp( 8,12, 4,3)/
     x 4.3525773D-06, 4.7878908D-06, 4.9271285D-09 /
      data fpppp( 8,12, 5,1),fpppp( 8,12, 5,2),fpppp( 8,12, 5,3)/
     x 8.9733760D-06,-8.4981683D-08,-7.6874293D-10 /
      data fpppp( 8,12, 6,1),fpppp( 8,12, 6,2),fpppp( 8,12, 6,3)/
     x 1.5145324D-05,-1.2974893D-05,-1.4388989D-08 /
      data fpppp( 8,12, 7,1),fpppp( 8,12, 7,2),fpppp( 8,12, 7,3)/
     x 4.5495120D-06,-4.6336251D-07, 4.6389275D-09 /
      data fpppp( 8,12, 8,1),fpppp( 8,12, 8,2),fpppp( 8,12, 8,3)/
     x-2.2943415D-07, 4.6068200D-06, 3.4342046D-09 /
      data fpppp( 8,12, 9,1),fpppp( 8,12, 9,2),fpppp( 8,12, 9,3)/
     x-1.0346690D-06, 5.6806066D-06, 2.6863275D-09 /
      data fpppp( 8,12,10,1),fpppp( 8,12,10,2),fpppp( 8,12,10,3)/
     x-2.2943415D-07, 4.6068200D-06, 3.4342046D-09 /
      data fpppp( 8,12,11,1),fpppp( 8,12,11,2),fpppp( 8,12,11,3)/
     x 4.5495120D-06,-4.6336251D-07, 4.6389275D-09 /
      data fpppp( 8,12,12,1),fpppp( 8,12,12,2),fpppp( 8,12,12,3)/
     x 1.5145324D-05,-1.2974893D-05,-1.4388989D-08 /
      data fpppp( 8,12,13,1),fpppp( 8,12,13,2),fpppp( 8,12,13,3)/
     x 8.9733760D-06,-8.4981683D-08,-7.6874293D-10 /
      data fpppp( 8,12,14,1),fpppp( 8,12,14,2),fpppp( 8,12,14,3)/
     x 4.3525773D-06, 4.7878908D-06, 4.9271285D-09 /
      data fpppp( 8,12,15,1),fpppp( 8,12,15,2),fpppp( 8,12,15,3)/
     x 4.2631626D-06, 2.7441189D-06, 1.8334153D-09 /
      data fpppp( 8,12,16,1),fpppp( 8,12,16,2),fpppp( 8,12,16,3)/
     x 4.3525773D-06, 3.7818552D-06, 3.6983225D-09 /
      data fpppp( 8,12,17,1),fpppp( 8,12,17,2),fpppp( 8,12,17,3)/
     x 8.9733760D-06, 3.9391606D-06, 4.1464810D-09 /
      data fpppp( 8,13, 1,1),fpppp( 8,13, 1,2),fpppp( 8,13, 1,3)/
     x 1.1221269D-05, 5.9587977D-06,-1.0903559D-09 /
      data fpppp( 8,13, 2,1),fpppp( 8,13, 2,2),fpppp( 8,13, 2,3)/
     x 1.2150346D-05, 5.9888867D-06,-3.2332106D-10 /
      data fpppp( 8,13, 3,1),fpppp( 8,13, 3,2),fpppp( 8,13, 3,3)/
     x 1.3191010D-05, 5.0710366D-06, 1.1968569D-09 /
      data fpppp( 8,13, 4,1),fpppp( 8,13, 4,2),fpppp( 8,13, 4,3)/
     x 1.2150346D-05, 7.4709735D-06, 8.1034064D-11 /
      data fpppp( 8,13, 5,1),fpppp( 8,13, 5,2),fpppp( 8,13, 5,3)/
     x 1.1221269D-05, 3.0450558D-08,-2.7077764D-09 /
      data fpppp( 8,13, 6,1),fpppp( 8,13, 6,2),fpppp( 8,13, 6,3)/
     x 1.0527858D-05,-2.2897165D-05,-6.7368214D-10 /
      data fpppp( 8,13, 7,1),fpppp( 8,13, 7,2),fpppp( 8,13, 7,3)/
     x 6.4224604D-06, 2.6050200D-06, 1.8909860D-09 /
      data fpppp( 8,13, 8,1),fpppp( 8,13, 8,2),fpppp( 8,13, 8,3)/
     x 6.7586692D-06, 6.9445738D-06, 5.3999759D-10 /
      data fpppp( 8,13, 9,1),fpppp( 8,13, 9,2),fpppp( 8,13, 9,3)/
     x 7.1408913D-06, 6.8682721D-06, 6.0941738D-10 /
      data fpppp( 8,13,10,1),fpppp( 8,13,10,2),fpppp( 8,13,10,3)/
     x 6.7586692D-06, 6.9445738D-06, 5.3999759D-10 /
      data fpppp( 8,13,11,1),fpppp( 8,13,11,2),fpppp( 8,13,11,3)/
     x 6.4224604D-06, 2.6050200D-06, 1.8909860D-09 /
      data fpppp( 8,13,12,1),fpppp( 8,13,12,2),fpppp( 8,13,12,3)/
     x 1.0527858D-05,-2.2897165D-05,-6.7368214D-10 /
      data fpppp( 8,13,13,1),fpppp( 8,13,13,2),fpppp( 8,13,13,3)/
     x 1.1221269D-05, 3.0450558D-08,-2.7077764D-09 /
      data fpppp( 8,13,14,1),fpppp( 8,13,14,2),fpppp( 8,13,14,3)/
     x 1.2150346D-05, 7.4709735D-06, 8.1034064D-11 /
      data fpppp( 8,13,15,1),fpppp( 8,13,15,2),fpppp( 8,13,15,3)/
     x 1.3191010D-05, 5.0710366D-06, 1.1968569D-09 /
      data fpppp( 8,13,16,1),fpppp( 8,13,16,2),fpppp( 8,13,16,3)/
     x 1.2150346D-05, 5.9888867D-06,-3.2332106D-10 /
      data fpppp( 8,13,17,1),fpppp( 8,13,17,2),fpppp( 8,13,17,3)/
     x 1.1221269D-05, 5.9587977D-06,-1.0903559D-09 /
      data fpppp( 8,14, 1,1),fpppp( 8,14, 1,2),fpppp( 8,14, 1,3)/
     x 1.1776850D-05, 8.0606375D-06,-1.1750613D-08 /
      data fpppp( 8,14, 2,1),fpppp( 8,14, 2,2),fpppp( 8,14, 2,3)/
     x 2.2424048D-05, 8.1591927D-06,-8.9472600D-09 /
      data fpppp( 8,14, 3,1),fpppp( 8,14, 3,2),fpppp( 8,14, 3,3)/
     x 2.4529501D-05, 7.0666524D-06,-1.4064000D-09 /
      data fpppp( 8,14, 4,1),fpppp( 8,14, 4,2),fpppp( 8,14, 4,3)/
     x 2.2424048D-05, 1.0142946D-05,-1.0446815D-08 /
      data fpppp( 8,14, 5,1),fpppp( 8,14, 5,2),fpppp( 8,14, 5,3)/
     x 1.1776850D-05, 1.2562357D-07,-5.7523934D-09 /
      data fpppp( 8,14, 6,1),fpppp( 8,14, 6,2),fpppp( 8,14, 6,3)/
     x-4.2995330D-06,-3.3053442D-05, 3.2808236D-08 /
      data fpppp( 8,14, 7,1),fpppp( 8,14, 7,2),fpppp( 8,14, 7,3)/
     x 7.6334568D-06, 6.3623115D-06,-9.1887035D-09 /
      data fpppp( 8,14, 8,1),fpppp( 8,14, 8,2),fpppp( 8,14, 8,3)/
     x 1.6304405D-05, 9.0186131D-06,-5.3753859D-09 /
      data fpppp( 8,14, 9,1),fpppp( 8,14, 9,2),fpppp( 8,14, 9,3)/
     x 1.7667428D-05, 8.0718684D-06,-2.9334016D-09 /
      data fpppp( 8,14,10,1),fpppp( 8,14,10,2),fpppp( 8,14,10,3)/
     x 1.6304405D-05, 9.0186131D-06,-5.3753859D-09 /
      data fpppp( 8,14,11,1),fpppp( 8,14,11,2),fpppp( 8,14,11,3)/
     x 7.6334568D-06, 6.3623115D-06,-9.1887035D-09 /
      data fpppp( 8,14,12,1),fpppp( 8,14,12,2),fpppp( 8,14,12,3)/
     x-4.2995330D-06,-3.3053442D-05, 3.2808236D-08 /
      data fpppp( 8,14,13,1),fpppp( 8,14,13,2),fpppp( 8,14,13,3)/
     x 1.1776850D-05, 1.2562357D-07,-5.7523934D-09 /
      data fpppp( 8,14,14,1),fpppp( 8,14,14,2),fpppp( 8,14,14,3)/
     x 2.2424048D-05, 1.0142946D-05,-1.0446815D-08 /
      data fpppp( 8,14,15,1),fpppp( 8,14,15,2),fpppp( 8,14,15,3)/
     x 2.4529501D-05, 7.0666524D-06,-1.4064000D-09 /
      data fpppp( 8,14,16,1),fpppp( 8,14,16,2),fpppp( 8,14,16,3)/
     x 2.2424048D-05, 8.1591927D-06,-8.9472600D-09 /
      data fpppp( 8,14,17,1),fpppp( 8,14,17,2),fpppp( 8,14,17,3)/
     x 1.1776850D-05, 8.0606375D-06,-1.1750613D-08 /
      data fpppp( 8,15, 1,1),fpppp( 8,15, 1,2),fpppp( 8,15, 1,3)/
     x 4.0223450D-06, 8.7212131D-06,-1.8018163D-08 /
      data fpppp( 8,15, 2,1),fpppp( 8,15, 2,2),fpppp( 8,15, 2,3)/
     x 3.0118118D-05, 9.2478646D-06,-1.6912363D-08 /
      data fpppp( 8,15, 3,1),fpppp( 8,15, 3,2),fpppp( 8,15, 3,3)/
     x 3.5544912D-05, 8.7495829D-06,-1.0921387D-08 /
      data fpppp( 8,15, 4,1),fpppp( 8,15, 4,2),fpppp( 8,15, 4,3)/
     x 3.0118118D-05, 1.1838567D-05,-2.2028528D-08 /
      data fpppp( 8,15, 5,1),fpppp( 8,15, 5,2),fpppp( 8,15, 5,3)/
     x 4.0223450D-06,-1.6415981D-06, 2.4464967D-09 /
      data fpppp( 8,15, 6,1),fpppp( 8,15, 6,2),fpppp( 8,15, 6,3)/
     x-2.5709243D-05,-3.7574555D-05, 5.7618907D-08 /
      data fpppp( 8,15, 7,1),fpppp( 8,15, 7,2),fpppp( 8,15, 7,3)/
     x 6.0653322D-06, 8.3448579D-06,-1.3937986D-08 /
      data fpppp( 8,15, 8,1),fpppp( 8,15, 8,2),fpppp( 8,15, 8,3)/
     x 2.6333277D-05, 1.0321670D-05,-1.4769364D-08 /
      data fpppp( 8,15, 9,1),fpppp( 8,15, 9,2),fpppp( 8,15, 9,3)/
     x 3.0518497D-05, 9.1043153D-06,-8.5903560D-09 /
      data fpppp( 8,15,10,1),fpppp( 8,15,10,2),fpppp( 8,15,10,3)/
     x 2.6333277D-05, 1.0321670D-05,-1.4769364D-08 /
      data fpppp( 8,15,11,1),fpppp( 8,15,11,2),fpppp( 8,15,11,3)/
     x 6.0653322D-06, 8.3448579D-06,-1.3937986D-08 /
      data fpppp( 8,15,12,1),fpppp( 8,15,12,2),fpppp( 8,15,12,3)/
     x-2.5709243D-05,-3.7574555D-05, 5.7618907D-08 /
      data fpppp( 8,15,13,1),fpppp( 8,15,13,2),fpppp( 8,15,13,3)/
     x 4.0223450D-06,-1.6415981D-06, 2.4464967D-09 /
      data fpppp( 8,15,14,1),fpppp( 8,15,14,2),fpppp( 8,15,14,3)/
     x 3.0118118D-05, 1.1838567D-05,-2.2028528D-08 /
      data fpppp( 8,15,15,1),fpppp( 8,15,15,2),fpppp( 8,15,15,3)/
     x 3.5544912D-05, 8.7495829D-06,-1.0921387D-08 /
      data fpppp( 8,15,16,1),fpppp( 8,15,16,2),fpppp( 8,15,16,3)/
     x 3.0118118D-05, 9.2478646D-06,-1.6912363D-08 /
      data fpppp( 8,15,17,1),fpppp( 8,15,17,2),fpppp( 8,15,17,3)/
     x 4.0223450D-06, 8.7212131D-06,-1.8018163D-08 /
      data fpppp( 8,16, 1,1),fpppp( 8,16, 1,2),fpppp( 8,16, 1,3)/
     x-1.6731983D-05, 6.3619729D-06,-5.4427202D-09 /
      data fpppp( 8,16, 2,1),fpppp( 8,16, 2,2),fpppp( 8,16, 2,3)/
     x 2.6343711D-05, 7.9334470D-06,-1.3291314D-08 /
      data fpppp( 8,16, 3,1),fpppp( 8,16, 3,2),fpppp( 8,16, 3,3)/
     x 3.9711413D-05, 9.6285039D-06,-2.6689954D-08 /
      data fpppp( 8,16, 4,1),fpppp( 8,16, 4,2),fpppp( 8,16, 4,3)/
     x 2.6343711D-05, 1.0891021D-05,-2.0663432D-08 /
      data fpppp( 8,16, 5,1),fpppp( 8,16, 5,2),fpppp( 8,16, 5,3)/
     x-1.6731983D-05,-5.4683227D-06, 2.4045752D-08 /
      data fpppp( 8,16, 6,1),fpppp( 8,16, 6,2),fpppp( 8,16, 6,3)/
     x-3.9211745D-05,-3.1145211D-05, 3.6343118D-08 /
      data fpppp( 8,16, 7,1),fpppp( 8,16, 7,2),fpppp( 8,16, 7,3)/
     x 3.3117453D-06, 6.2558908D-06, 1.6733838D-09 /
      data fpppp( 8,16, 8,1),fpppp( 8,16, 8,2),fpppp( 8,16, 8,3)/
     x 3.4245894D-05, 1.0196113D-05,-2.0385081D-08 /
      data fpppp( 8,16, 9,1),fpppp( 8,16, 9,2),fpppp( 8,16, 9,3)/
     x 4.2163277D-05, 9.4054420D-06,-1.6566212D-08 /
      data fpppp( 8,16,10,1),fpppp( 8,16,10,2),fpppp( 8,16,10,3)/
     x 3.4245894D-05, 1.0196113D-05,-2.0385081D-08 /
      data fpppp( 8,16,11,1),fpppp( 8,16,11,2),fpppp( 8,16,11,3)/
     x 3.3117453D-06, 6.2558908D-06, 1.6733838D-09 /
      data fpppp( 8,16,12,1),fpppp( 8,16,12,2),fpppp( 8,16,12,3)/
     x-3.9211745D-05,-3.1145211D-05, 3.6343118D-08 /
      data fpppp( 8,16,13,1),fpppp( 8,16,13,2),fpppp( 8,16,13,3)/
     x-1.6731983D-05,-5.4683227D-06, 2.4045752D-08 /
      data fpppp( 8,16,14,1),fpppp( 8,16,14,2),fpppp( 8,16,14,3)/
     x 2.6343711D-05, 1.0891021D-05,-2.0663432D-08 /
      data fpppp( 8,16,15,1),fpppp( 8,16,15,2),fpppp( 8,16,15,3)/
     x 3.9711413D-05, 9.6285039D-06,-2.6689954D-08 /
      data fpppp( 8,16,16,1),fpppp( 8,16,16,2),fpppp( 8,16,16,3)/
     x 2.6343711D-05, 7.9334470D-06,-1.3291314D-08 /
      data fpppp( 8,16,17,1),fpppp( 8,16,17,2),fpppp( 8,16,17,3)/
     x-1.6731983D-05, 6.3619729D-06,-5.4427202D-09 /
      data fpppp( 8,17, 1,1),fpppp( 8,17, 1,2),fpppp( 8,17, 1,3)/
     x-3.3244095D-05, 1.6382718D-06, 2.0029349D-08 /
      data fpppp( 8,17, 2,1),fpppp( 8,17, 2,2),fpppp( 8,17, 2,3)/
     x-1.3972462D-05, 3.9457587D-06, 7.2036768D-09 /
      data fpppp( 8,17, 3,1),fpppp( 8,17, 3,2),fpppp( 8,17, 3,3)/
     x 3.6446621D-06, 7.8810284D-06,-2.2863331D-08 /
      data fpppp( 8,17, 4,1),fpppp( 8,17, 4,2),fpppp( 8,17, 4,3)/
     x-1.3972462D-05, 6.1190584D-06, 7.4143373D-09 /
      data fpppp( 8,17, 5,1),fpppp( 8,17, 5,2),fpppp( 8,17, 5,3)/
     x-3.3244095D-05,-7.0549271D-06, 1.9186707D-08 /
      data fpppp( 8,17, 6,1),fpppp( 8,17, 6,2),fpppp( 8,17, 6,3)/
     x-7.4555963D-06,-1.6095483D-05,-1.5188299D-08 /
      data fpppp( 8,17, 7,1),fpppp( 8,17, 7,2),fpppp( 8,17, 7,3)/
     x 3.4715176D-06, 1.5183534D-06, 1.8895930D-08 /
      data fpppp( 8,17, 8,1),fpppp( 8,17, 8,2),fpppp( 8,17, 8,3)/
     x 3.3371983D-05, 7.7232715D-06,-7.7393044D-09 /
      data fpppp( 8,17, 9,1),fpppp( 8,17, 9,2),fpppp( 8,17, 9,3)/
     x 4.8269492D-05, 8.0606415D-06,-2.2240299D-08 /
      data fpppp( 8,17,10,1),fpppp( 8,17,10,2),fpppp( 8,17,10,3)/
     x 3.3371983D-05, 7.7232715D-06,-7.7393044D-09 /
      data fpppp( 8,17,11,1),fpppp( 8,17,11,2),fpppp( 8,17,11,3)/
     x 3.4715176D-06, 1.5183534D-06, 1.8895930D-08 /
      data fpppp( 8,17,12,1),fpppp( 8,17,12,2),fpppp( 8,17,12,3)/
     x-7.4555963D-06,-1.6095483D-05,-1.5188299D-08 /
      data fpppp( 8,17,13,1),fpppp( 8,17,13,2),fpppp( 8,17,13,3)/
     x-3.3244095D-05,-7.0549271D-06, 1.9186707D-08 /
      data fpppp( 8,17,14,1),fpppp( 8,17,14,2),fpppp( 8,17,14,3)/
     x-1.3972462D-05, 6.1190584D-06, 7.4143373D-09 /
      data fpppp( 8,17,15,1),fpppp( 8,17,15,2),fpppp( 8,17,15,3)/
     x 3.6446621D-06, 7.8810284D-06,-2.2863331D-08 /
      data fpppp( 8,17,16,1),fpppp( 8,17,16,2),fpppp( 8,17,16,3)/
     x-1.3972462D-05, 3.9457587D-06, 7.2036768D-09 /
      data fpppp( 8,17,17,1),fpppp( 8,17,17,2),fpppp( 8,17,17,3)/
     x-3.3244095D-05, 1.6382718D-06, 2.0029349D-08 /
      data fpppp( 8,18, 1,1),fpppp( 8,18, 1,2),fpppp( 8,18, 1,3)/
     x-1.3452007D-05,-9.4448498D-07, 9.0477267D-09 /
      data fpppp( 8,18, 2,1),fpppp( 8,18, 2,2),fpppp( 8,18, 2,3)/
     x-6.1350023D-05, 1.8117585D-07, 1.4565138D-08 /
      data fpppp( 8,18, 3,1),fpppp( 8,18, 3,2),fpppp( 8,18, 3,3)/
     x-7.8009474D-05, 2.5349134D-06, 2.4066752D-08 /
      data fpppp( 8,18, 4,1),fpppp( 8,18, 4,2),fpppp( 8,18, 4,3)/
     x-6.1350023D-05, 5.9038250D-07, 1.9623657D-08 /
      data fpppp( 8,18, 5,1),fpppp( 8,18, 5,2),fpppp( 8,18, 5,3)/
     x-1.3452007D-05,-2.5813116D-06,-1.1186348D-08 /
      data fpppp( 8,18, 6,1),fpppp( 8,18, 6,2),fpppp( 8,18, 6,3)/
     x 1.5191331D-05,-4.3541672D-06,-3.4072415D-08 /
      data fpppp( 8,18, 7,1),fpppp( 8,18, 7,2),fpppp( 8,18, 7,3)/
     x 1.7659427D-06,-1.0253330D-07,-2.3733543D-09 /
      data fpppp( 8,18, 8,1),fpppp( 8,18, 8,2),fpppp( 8,18, 8,3)/
     x-1.2612658D-05, 3.1312223D-06, 1.1649799D-08 /
      data fpppp( 8,18, 9,1),fpppp( 8,18, 9,2),fpppp( 8,18, 9,3)/
     x-1.5151917D-05, 4.1661025D-06, 9.4936578D-09 /
      data fpppp( 8,18,10,1),fpppp( 8,18,10,2),fpppp( 8,18,10,3)/
     x-1.2612658D-05, 3.1312223D-06, 1.1649799D-08 /
      data fpppp( 8,18,11,1),fpppp( 8,18,11,2),fpppp( 8,18,11,3)/
     x 1.7659427D-06,-1.0253330D-07,-2.3733543D-09 /
      data fpppp( 8,18,12,1),fpppp( 8,18,12,2),fpppp( 8,18,12,3)/
     x 1.5191331D-05,-4.3541672D-06,-3.4072415D-08 /
      data fpppp( 8,18,13,1),fpppp( 8,18,13,2),fpppp( 8,18,13,3)/
     x-1.3452007D-05,-2.5813116D-06,-1.1186348D-08 /
      data fpppp( 8,18,14,1),fpppp( 8,18,14,2),fpppp( 8,18,14,3)/
     x-6.1350023D-05, 5.9038250D-07, 1.9623657D-08 /
      data fpppp( 8,18,15,1),fpppp( 8,18,15,2),fpppp( 8,18,15,3)/
     x-7.8009474D-05, 2.5349134D-06, 2.4066752D-08 /
      data fpppp( 8,18,16,1),fpppp( 8,18,16,2),fpppp( 8,18,16,3)/
     x-6.1350023D-05, 1.8117585D-07, 1.4565138D-08 /
      data fpppp( 8,18,17,1),fpppp( 8,18,17,2),fpppp( 8,18,17,3)/
     x-1.3452007D-05,-9.4448498D-07, 9.0477267D-09 /
      data fpppp( 8,19, 1,1),fpppp( 8,19, 1,2),fpppp( 8,19, 1,3)/
     x-4.0325479D-06,-9.9874236D-20, 8.4814451D-09 /
      data fpppp( 8,19, 2,1),fpppp( 8,19, 2,2),fpppp( 8,19, 2,3)/
     x-1.0671004D-04, 7.2429408D-20, 2.5679036D-08 /
      data fpppp( 8,19, 3,1),fpppp( 8,19, 3,2),fpppp( 8,19, 3,3)/
     x-1.4663864D-04, 2.5920703D-20, 5.8681561D-08 /
      data fpppp( 8,19, 4,1),fpppp( 8,19, 4,2),fpppp( 8,19, 4,3)/
     x-1.0671004D-04,-5.9959603D-21, 3.6366819D-08 /
      data fpppp( 8,19, 5,1),fpppp( 8,19, 5,2),fpppp( 8,19, 5,3)/
     x-4.0325479D-06, 2.7225136D-20,-3.4269686D-08 /
      data fpppp( 8,19, 6,1),fpppp( 8,19, 6,2),fpppp( 8,19, 6,3)/
     x 4.0440892D-05, 3.8754201D-20,-6.2284331D-08 /
      data fpppp( 8,19, 7,1),fpppp( 8,19, 7,2),fpppp( 8,19, 7,3)/
     x 5.9332417D-07,-9.3596440D-21,-1.2644973D-08 /
      data fpppp( 8,19, 8,1),fpppp( 8,19, 8,2),fpppp( 8,19, 8,3)/
     x-4.5708519D-05,-6.7988279D-21, 2.9112238D-08 /
      data fpppp( 8,19, 9,1),fpppp( 8,19, 9,2),fpppp( 8,19, 9,3)/
     x-5.8708291D-05, 7.7323116D-21, 3.0539602D-08 /
      data fpppp( 8,19,10,1),fpppp( 8,19,10,2),fpppp( 8,19,10,3)/
     x-4.5708519D-05, 2.8021247D-20, 2.9112238D-08 /
      data fpppp( 8,19,11,1),fpppp( 8,19,11,2),fpppp( 8,19,11,3)/
     x 5.9332417D-07,-1.3465701D-20,-1.2644973D-08 /
      data fpppp( 8,19,12,1),fpppp( 8,19,12,2),fpppp( 8,19,12,3)/
     x 4.0440892D-05,-1.8905427D-20,-6.2284331D-08 /
      data fpppp( 8,19,13,1),fpppp( 8,19,13,2),fpppp( 8,19,13,3)/
     x-4.0325479D-06,-2.7812269D-20,-3.4269686D-08 /
      data fpppp( 8,19,14,1),fpppp( 8,19,14,2),fpppp( 8,19,14,3)/
     x-1.0671004D-04, 2.2333474D-20, 3.6366819D-08 /
      data fpppp( 8,19,15,1),fpppp( 8,19,15,2),fpppp( 8,19,15,3)/
     x-1.4663864D-04,-1.5558291D-20, 5.8681561D-08 /
      data fpppp( 8,19,16,1),fpppp( 8,19,16,2),fpppp( 8,19,16,3)/
     x-1.0671004D-04, 2.7951176D-20, 2.5679036D-08 /
      data fpppp( 8,19,17,1),fpppp( 8,19,17,2),fpppp( 8,19,17,3)/
     x-4.0325479D-06,-3.4753874D-20, 8.4814451D-09 /
      data fpppp( 9, 1, 1,1),fpppp( 9, 1, 1,2),fpppp( 9, 1, 1,3)/
     x 7.1207668D-07, 2.1310936D-21, 6.8238156D-10 /
      data fpppp( 9, 1, 2,1),fpppp( 9, 1, 2,2),fpppp( 9, 1, 2,3)/
     x-3.1659492D-06, 9.1755848D-21, 1.4119896D-09 /
      data fpppp( 9, 1, 3,1),fpppp( 9, 1, 3,2),fpppp( 9, 1, 3,3)/
     x-4.6278602D-06, 1.9003677D-21, 2.7432723D-09 /
      data fpppp( 9, 1, 4,1),fpppp( 9, 1, 4,2),fpppp( 9, 1, 4,3)/
     x-3.1659492D-06,-8.9611900D-21, 1.9686934D-09 /
      data fpppp( 9, 1, 5,1),fpppp( 9, 1, 5,2),fpppp( 9, 1, 5,3)/
     x 7.1207668D-07,-5.7326727D-21,-1.5444339D-09 /
      data fpppp( 9, 1, 6,1),fpppp( 9, 1, 6,2),fpppp( 9, 1, 6,3)/
     x 3.4947433D-06, 1.6207406D-21,-2.7031685D-09 /
      data fpppp( 9, 1, 7,1),fpppp( 9, 1, 7,2),fpppp( 9, 1, 7,3)/
     x 2.7039982D-06,-8.5490535D-21,-1.8616671D-09 /
      data fpppp( 9, 1, 8,1),fpppp( 9, 1, 8,2),fpppp( 9, 1, 8,3)/
     x-1.0725385D-06, 5.4722140D-21, 1.3609581D-09 /
      data fpppp( 9, 1, 9,1),fpppp( 9, 1, 9,2),fpppp( 9, 1, 9,3)/
     x-3.3193507D-06,-2.6074303D-21, 2.9087477D-09 /
      data fpppp( 9, 1,10,1),fpppp( 9, 1,10,2),fpppp( 9, 1,10,3)/
     x-1.0725385D-06,-3.8578362D-21, 1.3609581D-09 /
      data fpppp( 9, 1,11,1),fpppp( 9, 1,11,2),fpppp( 9, 1,11,3)/
     x 2.7039982D-06,-1.4578724D-20,-1.8616671D-09 /
      data fpppp( 9, 1,12,1),fpppp( 9, 1,12,2),fpppp( 9, 1,12,3)/
     x 3.4947433D-06, 7.8755625D-21,-2.7031685D-09 /
      data fpppp( 9, 1,13,1),fpppp( 9, 1,13,2),fpppp( 9, 1,13,3)/
     x 7.1207668D-07,-3.2045131D-21,-1.5444339D-09 /
      data fpppp( 9, 1,14,1),fpppp( 9, 1,14,2),fpppp( 9, 1,14,3)/
     x-3.1659492D-06,-5.6315502D-21, 1.9686934D-09 /
      data fpppp( 9, 1,15,1),fpppp( 9, 1,15,2),fpppp( 9, 1,15,3)/
     x-4.6278602D-06,-2.4029113D-21, 2.7432723D-09 /
      data fpppp( 9, 1,16,1),fpppp( 9, 1,16,2),fpppp( 9, 1,16,3)/
     x-3.1659492D-06, 4.8207354D-21, 1.4119896D-09 /
      data fpppp( 9, 1,17,1),fpppp( 9, 1,17,2),fpppp( 9, 1,17,3)/
     x 7.1207668D-07, 1.6174069D-21, 6.8238156D-10 /
      data fpppp( 9, 2, 1,1),fpppp( 9, 2, 1,2),fpppp( 9, 2, 1,3)/
     x-2.0862888D-07, 4.0428538D-08,-5.5383818D-10 /
      data fpppp( 9, 2, 2,1),fpppp( 9, 2, 2,2),fpppp( 9, 2, 2,3)/
     x-1.8071220D-06, 9.3249712D-08, 2.5972657D-10 /
      data fpppp( 9, 2, 3,1),fpppp( 9, 2, 3,2),fpppp( 9, 2, 3,3)/
     x-2.7462148D-06, 2.0387179D-07, 2.1343744D-09 /
      data fpppp( 9, 2, 4,1),fpppp( 9, 2, 4,2),fpppp( 9, 2, 4,3)/
     x-1.8071220D-06, 1.1219070D-07, 2.9523145D-10 /
      data fpppp( 9, 2, 5,1),fpppp( 9, 2, 5,2),fpppp( 9, 2, 5,3)/
     x-2.0862888D-07,-3.5335427D-08,-6.9585769D-10 /
      data fpppp( 9, 2, 6,1),fpppp( 9, 2, 6,2),fpppp( 9, 2, 6,3)/
     x 1.0374711D-06,-1.6255430D-07,-1.0273791D-09 /
      data fpppp( 9, 2, 7,1),fpppp( 9, 2, 7,2),fpppp( 9, 2, 7,3)/
     x 8.7816623D-07,-1.3593296D-07,-8.7040888D-10 /
      data fpppp( 9, 2, 8,1),fpppp( 9, 2, 8,2),fpppp( 9, 2, 8,3)/
     x-9.3154275D-07, 4.1011931D-08, 5.0677226D-10 /
      data fpppp( 9, 2, 9,1),fpppp( 9, 2, 9,2),fpppp( 9, 2, 9,3)/
     x-2.1095487D-06, 1.6052514D-07, 1.4548271D-09 /
      data fpppp( 9, 2,10,1),fpppp( 9, 2,10,2),fpppp( 9, 2,10,3)/
     x-9.3154275D-07, 4.1011931D-08, 5.0677226D-10 /
      data fpppp( 9, 2,11,1),fpppp( 9, 2,11,2),fpppp( 9, 2,11,3)/
     x 8.7816623D-07,-1.3593296D-07,-8.7040888D-10 /
      data fpppp( 9, 2,12,1),fpppp( 9, 2,12,2),fpppp( 9, 2,12,3)/
     x 1.0374711D-06,-1.6255430D-07,-1.0273791D-09 /
      data fpppp( 9, 2,13,1),fpppp( 9, 2,13,2),fpppp( 9, 2,13,3)/
     x-2.0862888D-07,-3.5335427D-08,-6.9585769D-10 /
      data fpppp( 9, 2,14,1),fpppp( 9, 2,14,2),fpppp( 9, 2,14,3)/
     x-1.8071220D-06, 1.1219070D-07, 2.9523145D-10 /
      data fpppp( 9, 2,15,1),fpppp( 9, 2,15,2),fpppp( 9, 2,15,3)/
     x-2.7462148D-06, 2.0387179D-07, 2.1343744D-09 /
      data fpppp( 9, 2,16,1),fpppp( 9, 2,16,2),fpppp( 9, 2,16,3)/
     x-1.8071220D-06, 9.3249712D-08, 2.5972657D-10 /
      data fpppp( 9, 2,17,1),fpppp( 9, 2,17,2),fpppp( 9, 2,17,3)/
     x-2.0862888D-07, 4.0428538D-08,-5.5383818D-10 /
      data fpppp( 9, 3, 1,1),fpppp( 9, 3, 1,2),fpppp( 9, 3, 1,3)/
     x-1.5446156D-06,-1.6094418D-09,-2.3925592D-09 /
      data fpppp( 9, 3, 2,1),fpppp( 9, 3, 2,2),fpppp( 9, 3, 2,3)/
     x-1.1241455D-06, 2.2517846D-07,-1.0865017D-09 /
      data fpppp( 9, 3, 3,1),fpppp( 9, 3, 3,2),fpppp( 9, 3, 3,3)/
     x-2.1364585D-06, 7.3781985D-07, 2.3471840D-09 /
      data fpppp( 9, 3, 4,1),fpppp( 9, 3, 4,2),fpppp( 9, 3, 4,3)/
     x-1.1241455D-06, 2.4997404D-07,-1.6658289D-09 /
      data fpppp( 9, 3, 5,1),fpppp( 9, 3, 5,2),fpppp( 9, 3, 5,3)/
     x-1.5446156D-06,-1.0079177D-07,-7.5250396D-11 /
      data fpppp( 9, 3, 6,1),fpppp( 9, 3, 6,2),fpppp( 9, 3, 6,3)/
     x-1.6972989D-06,-4.7878925D-07, 1.0613551D-09 /
      data fpppp( 9, 3, 7,1),fpppp( 9, 3, 7,2),fpppp( 9, 3, 7,3)/
     x-8.6069281D-07,-5.3877146D-07,-1.6826239D-10 /
      data fpppp( 9, 3, 8,1),fpppp( 9, 3, 8,2),fpppp( 9, 3, 8,3)/
     x-7.1495903D-07, 1.6129556D-07,-3.5045717D-10 /
      data fpppp( 9, 3, 9,1),fpppp( 9, 3, 9,2),fpppp( 9, 3, 9,3)/
     x-9.3927685D-07, 6.8047852D-07,-4.6850943D-11 /
      data fpppp( 9, 3,10,1),fpppp( 9, 3,10,2),fpppp( 9, 3,10,3)/
     x-7.1495903D-07, 1.6129556D-07,-3.5045717D-10 /
      data fpppp( 9, 3,11,1),fpppp( 9, 3,11,2),fpppp( 9, 3,11,3)/
     x-8.6069281D-07,-5.3877146D-07,-1.6826239D-10 /
      data fpppp( 9, 3,12,1),fpppp( 9, 3,12,2),fpppp( 9, 3,12,3)/
     x-1.6972989D-06,-4.7878925D-07, 1.0613551D-09 /
      data fpppp( 9, 3,13,1),fpppp( 9, 3,13,2),fpppp( 9, 3,13,3)/
     x-1.5446156D-06,-1.0079177D-07,-7.5250396D-11 /
      data fpppp( 9, 3,14,1),fpppp( 9, 3,14,2),fpppp( 9, 3,14,3)/
     x-1.1241455D-06, 2.4997404D-07,-1.6658289D-09 /
      data fpppp( 9, 3,15,1),fpppp( 9, 3,15,2),fpppp( 9, 3,15,3)/
     x-2.1364585D-06, 7.3781985D-07, 2.3471840D-09 /
      data fpppp( 9, 3,16,1),fpppp( 9, 3,16,2),fpppp( 9, 3,16,3)/
     x-1.1241455D-06, 2.2517846D-07,-1.0865017D-09 /
      data fpppp( 9, 3,17,1),fpppp( 9, 3,17,2),fpppp( 9, 3,17,3)/
     x-1.5446156D-06,-1.6094418D-09,-2.3925592D-09 /
      data fpppp( 9, 4, 1,1),fpppp( 9, 4, 1,2),fpppp( 9, 4, 1,3)/
     x-1.4271182D-06,-4.3734233D-07,-2.1225257D-09 /
      data fpppp( 9, 4, 2,1),fpppp( 9, 4, 2,2),fpppp( 9, 4, 2,3)/
     x 1.9243084D-06, 1.6183469D-07,-1.7538515D-09 /
      data fpppp( 9, 4, 3,1),fpppp( 9, 4, 3,2),fpppp( 9, 4, 3,3)/
     x 2.9249093D-06, 1.6218242D-06,-3.1598270D-10 /
      data fpppp( 9, 4, 4,1),fpppp( 9, 4, 4,2),fpppp( 9, 4, 4,3)/
     x 1.9243084D-06, 6.8969971D-08,-2.6202949D-09 /
      data fpppp( 9, 4, 5,1),fpppp( 9, 4, 5,2),fpppp( 9, 4, 5,3)/
     x-1.4271182D-06,-6.5883470D-08, 1.3432482D-09 /
      data fpppp( 9, 4, 6,1),fpppp( 9, 4, 6,2),fpppp( 9, 4, 6,3)/
     x-3.4608264D-06,-6.5142059D-07, 1.7047824D-09 /
      data fpppp( 9, 4, 7,1),fpppp( 9, 4, 7,2),fpppp( 9, 4, 7,3)/
     x-2.9039571D-06,-1.0450190D-06, 1.5457752D-09 /
      data fpppp( 9, 4, 8,1),fpppp( 9, 4, 8,2),fpppp( 9, 4, 8,3)/
     x-7.6293318D-07, 2.3719639D-07,-1.1970341D-09 /
      data fpppp( 9, 4, 9,1),fpppp( 9, 4, 9,2),fpppp( 9, 4, 9,3)/
     x 3.6935079D-07, 1.2750118D-06,-1.3813780D-09 /
      data fpppp( 9, 4,10,1),fpppp( 9, 4,10,2),fpppp( 9, 4,10,3)/
     x-7.6293318D-07, 2.3719639D-07,-1.1970341D-09 /
      data fpppp( 9, 4,11,1),fpppp( 9, 4,11,2),fpppp( 9, 4,11,3)/
     x-2.9039571D-06,-1.0450190D-06, 1.5457752D-09 /
      data fpppp( 9, 4,12,1),fpppp( 9, 4,12,2),fpppp( 9, 4,12,3)/
     x-3.4608264D-06,-6.5142059D-07, 1.7047824D-09 /
      data fpppp( 9, 4,13,1),fpppp( 9, 4,13,2),fpppp( 9, 4,13,3)/
     x-1.4271182D-06,-6.5883470D-08, 1.3432482D-09 /
      data fpppp( 9, 4,14,1),fpppp( 9, 4,14,2),fpppp( 9, 4,14,3)/
     x 1.9243084D-06, 6.8969971D-08,-2.6202949D-09 /
      data fpppp( 9, 4,15,1),fpppp( 9, 4,15,2),fpppp( 9, 4,15,3)/
     x 2.9249093D-06, 1.6218242D-06,-3.1598270D-10 /
      data fpppp( 9, 4,16,1),fpppp( 9, 4,16,2),fpppp( 9, 4,16,3)/
     x 1.9243084D-06, 1.6183469D-07,-1.7538515D-09 /
      data fpppp( 9, 4,17,1),fpppp( 9, 4,17,2),fpppp( 9, 4,17,3)/
     x-1.4271182D-06,-4.3734233D-07,-2.1225257D-09 /
      data fpppp( 9, 5, 1,1),fpppp( 9, 5, 1,2),fpppp( 9, 5, 1,3)/
     x-5.2147937D-07,-1.0092198D-06, 2.6505340D-09 /
      data fpppp( 9, 5, 2,1),fpppp( 9, 5, 2,2),fpppp( 9, 5, 2,3)/
     x 3.0298156D-06,-9.2526757D-08, 9.2830093D-11 /
      data fpppp( 9, 5, 3,1),fpppp( 9, 5, 3,2),fpppp( 9, 5, 3,3)/
     x 6.9140348D-06, 2.2390259D-06,-6.0548153D-09 /
      data fpppp( 9, 5, 4,1),fpppp( 9, 5, 4,2),fpppp( 9, 5, 4,3)/
     x 3.0298156D-06,-3.8142991D-07, 3.6233467D-10 /
      data fpppp( 9, 5, 5,1),fpppp( 9, 5, 5,2),fpppp( 9, 5, 5,3)/
     x-5.2147937D-07, 1.4639279D-07, 1.5725157D-09 /
      data fpppp( 9, 5, 6,1),fpppp( 9, 5, 6,2),fpppp( 9, 5, 6,3)/
     x-2.8029374D-06,-5.0762821D-07, 1.4631575D-09 /
      data fpppp( 9, 5, 7,1),fpppp( 9, 5, 7,2),fpppp( 9, 5, 7,3)/
     x-2.2723310D-06,-1.4205890D-06, 1.0203350D-09 /
      data fpppp( 9, 5, 8,1),fpppp( 9, 5, 8,2),fpppp( 9, 5, 8,3)/
     x-6.9923794D-07, 2.1710001D-07,-7.0574177D-10 /
      data fpppp( 9, 5, 9,1),fpppp( 9, 5, 9,2),fpppp( 9, 5, 9,3)/
     x 6.1935006D-07, 1.6051323D-06,-1.3254693D-09 /
      data fpppp( 9, 5,10,1),fpppp( 9, 5,10,2),fpppp( 9, 5,10,3)/
     x-6.9923794D-07, 2.1710001D-07,-7.0574177D-10 /
      data fpppp( 9, 5,11,1),fpppp( 9, 5,11,2),fpppp( 9, 5,11,3)/
     x-2.2723310D-06,-1.4205890D-06, 1.0203350D-09 /
      data fpppp( 9, 5,12,1),fpppp( 9, 5,12,2),fpppp( 9, 5,12,3)/
     x-2.8029374D-06,-5.0762821D-07, 1.4631575D-09 /
      data fpppp( 9, 5,13,1),fpppp( 9, 5,13,2),fpppp( 9, 5,13,3)/
     x-5.2147937D-07, 1.4639279D-07, 1.5725157D-09 /
      data fpppp( 9, 5,14,1),fpppp( 9, 5,14,2),fpppp( 9, 5,14,3)/
     x 3.0298156D-06,-3.8142991D-07, 3.6233467D-10 /
      data fpppp( 9, 5,15,1),fpppp( 9, 5,15,2),fpppp( 9, 5,15,3)/
     x 6.9140348D-06, 2.2390259D-06,-6.0548153D-09 /
      data fpppp( 9, 5,16,1),fpppp( 9, 5,16,2),fpppp( 9, 5,16,3)/
     x 3.0298156D-06,-9.2526757D-08, 9.2830093D-11 /
      data fpppp( 9, 5,17,1),fpppp( 9, 5,17,2),fpppp( 9, 5,17,3)/
     x-5.2147937D-07,-1.0092198D-06, 2.6505340D-09 /
      data fpppp( 9, 6, 1,1),fpppp( 9, 6, 1,2),fpppp( 9, 6, 1,3)/
     x 2.2778424D-07,-9.8780995D-07, 4.5621921D-09 /
      data fpppp( 9, 6, 2,1),fpppp( 9, 6, 2,2),fpppp( 9, 6, 2,3)/
     x 1.2155134D-06,-2.3316694D-07, 1.5189265D-09 /
      data fpppp( 9, 6, 3,1),fpppp( 9, 6, 3,2),fpppp( 9, 6, 3,3)/
     x 2.7822207D-06, 1.7591494D-06,-6.2921399D-09 /
      data fpppp( 9, 6, 4,1),fpppp( 9, 6, 4,2),fpppp( 9, 6, 4,3)/
     x 1.2155134D-06,-5.8039098D-07, 2.5840969D-09 /
      data fpppp( 9, 6, 5,1),fpppp( 9, 6, 5,2),fpppp( 9, 6, 5,3)/
     x 2.2778424D-07, 4.0108620D-07, 3.0151057D-10 /
      data fpppp( 9, 6, 6,1),fpppp( 9, 6, 6,2),fpppp( 9, 6, 6,3)/
     x-5.1630240D-07,-4.7086735D-08, 4.1016129D-10 /
      data fpppp( 9, 6, 7,1),fpppp( 9, 6, 7,2),fpppp( 9, 6, 7,3)/
     x-1.8714892D-06,-1.6358242D-06, 4.7769016D-11 /
      data fpppp( 9, 6, 8,1),fpppp( 9, 6, 8,2),fpppp( 9, 6, 8,3)/
     x-5.0971981D-07, 1.8014393D-07, 2.3289142D-10 /
      data fpppp( 9, 6, 9,1),fpppp( 9, 6, 9,2),fpppp( 9, 6, 9,3)/
     x 2.2170977D-07, 1.5471234D-06,-6.8319005D-10 /
      data fpppp( 9, 6,10,1),fpppp( 9, 6,10,2),fpppp( 9, 6,10,3)/
     x-5.0971981D-07, 1.8014393D-07, 2.3289142D-10 /
      data fpppp( 9, 6,11,1),fpppp( 9, 6,11,2),fpppp( 9, 6,11,3)/
     x-1.8714892D-06,-1.6358242D-06, 4.7769016D-11 /
      data fpppp( 9, 6,12,1),fpppp( 9, 6,12,2),fpppp( 9, 6,12,3)/
     x-5.1630240D-07,-4.7086735D-08, 4.1016129D-10 /
      data fpppp( 9, 6,13,1),fpppp( 9, 6,13,2),fpppp( 9, 6,13,3)/
     x 2.2778424D-07, 4.0108620D-07, 3.0151057D-10 /
      data fpppp( 9, 6,14,1),fpppp( 9, 6,14,2),fpppp( 9, 6,14,3)/
     x 1.2155134D-06,-5.8039098D-07, 2.5840969D-09 /
      data fpppp( 9, 6,15,1),fpppp( 9, 6,15,2),fpppp( 9, 6,15,3)/
     x 2.7822207D-06, 1.7591494D-06,-6.2921399D-09 /
      data fpppp( 9, 6,16,1),fpppp( 9, 6,16,2),fpppp( 9, 6,16,3)/
     x 1.2155134D-06,-2.3316694D-07, 1.5189265D-09 /
      data fpppp( 9, 6,17,1),fpppp( 9, 6,17,2),fpppp( 9, 6,17,3)/
     x 2.2778424D-07,-9.8780995D-07, 4.5621921D-09 /
      data fpppp( 9, 7, 1,1),fpppp( 9, 7, 1,2),fpppp( 9, 7, 1,3)/
     x 8.3078361D-07,-5.2910767D-07, 1.6950459D-09 /
      data fpppp( 9, 7, 2,1),fpppp( 9, 7, 2,2),fpppp( 9, 7, 2,3)/
     x-1.1049435D-06,-2.2893590D-07, 1.0761009D-09 /
      data fpppp( 9, 7, 3,1),fpppp( 9, 7, 3,2),fpppp( 9, 7, 3,3)/
     x-2.0467642D-06, 6.6724494D-07,-7.8952150D-10 /
      data fpppp( 9, 7, 4,1),fpppp( 9, 7, 4,2),fpppp( 9, 7, 4,3)/
     x-1.1049435D-06,-5.2260600D-07, 1.7082271D-09 /
      data fpppp( 9, 7, 5,1),fpppp( 9, 7, 5,2),fpppp( 9, 7, 5,3)/
     x 8.3078361D-07, 6.4557270D-07,-8.3345877D-10 /
      data fpppp( 9, 7, 6,1),fpppp( 9, 7, 6,2),fpppp( 9, 7, 6,3)/
     x 1.2712360D-06, 2.8077329D-07,-8.1114882D-10 /
      data fpppp( 9, 7, 7,1),fpppp( 9, 7, 7,2),fpppp( 9, 7, 7,3)/
     x 1.5777946D-07,-1.4419316D-06,-5.2712551D-10 /
      data fpppp( 9, 7, 8,1),fpppp( 9, 7, 8,2),fpppp( 9, 7, 8,3)/
     x-3.9525246D-07, 2.4995923D-08, 9.4438024D-10 /
      data fpppp( 9, 7, 9,1),fpppp( 9, 7, 9,2),fpppp( 9, 7, 9,3)/
     x-3.5539741D-07, 1.3102015D-06,-6.6872595D-11 /
      data fpppp( 9, 7,10,1),fpppp( 9, 7,10,2),fpppp( 9, 7,10,3)/
     x-3.9525246D-07, 2.4995923D-08, 9.4438024D-10 /
      data fpppp( 9, 7,11,1),fpppp( 9, 7,11,2),fpppp( 9, 7,11,3)/
     x 1.5777946D-07,-1.4419316D-06,-5.2712551D-10 /
      data fpppp( 9, 7,12,1),fpppp( 9, 7,12,2),fpppp( 9, 7,12,3)/
     x 1.2712360D-06, 2.8077329D-07,-8.1114882D-10 /
      data fpppp( 9, 7,13,1),fpppp( 9, 7,13,2),fpppp( 9, 7,13,3)/
     x 8.3078361D-07, 6.4557270D-07,-8.3345877D-10 /
      data fpppp( 9, 7,14,1),fpppp( 9, 7,14,2),fpppp( 9, 7,14,3)/
     x-1.1049435D-06,-5.2260600D-07, 1.7082271D-09 /
      data fpppp( 9, 7,15,1),fpppp( 9, 7,15,2),fpppp( 9, 7,15,3)/
     x-2.0467642D-06, 6.6724494D-07,-7.8952150D-10 /
      data fpppp( 9, 7,16,1),fpppp( 9, 7,16,2),fpppp( 9, 7,16,3)/
     x-1.1049435D-06,-2.2893590D-07, 1.0761009D-09 /
      data fpppp( 9, 7,17,1),fpppp( 9, 7,17,2),fpppp( 9, 7,17,3)/
     x 8.3078361D-07,-5.2910767D-07, 1.6950459D-09 /
      data fpppp( 9, 8, 1,1),fpppp( 9, 8, 1,2),fpppp( 9, 8, 1,3)/
     x 8.0215448D-07,-2.5102842D-08,-1.2961306D-09 /
      data fpppp( 9, 8, 2,1),fpppp( 9, 8, 2,2),fpppp( 9, 8, 2,3)/
     x-1.7253281D-06,-1.3238049D-07, 1.4417961D-10 /
      data fpppp( 9, 8, 3,1),fpppp( 9, 8, 3,2),fpppp( 9, 8, 3,3)/
     x-3.5842099D-06,-2.5890357D-07, 3.5739416D-09 /
      data fpppp( 9, 8, 4,1),fpppp( 9, 8, 4,2),fpppp( 9, 8, 4,3)/
     x-1.7253281D-06,-3.1806766D-07, 4.0622380D-11 /
      data fpppp( 9, 8, 5,1),fpppp( 9, 8, 5,2),fpppp( 9, 8, 5,3)/
     x 8.0215448D-07, 7.1764583D-07,-8.8190170D-10 /
      data fpppp( 9, 8, 6,1),fpppp( 9, 8, 6,2),fpppp( 9, 8, 6,3)/
     x 1.9952477D-06, 3.6577282D-07,-1.8062889D-09 /
      data fpppp( 9, 8, 7,1),fpppp( 9, 8, 7,2),fpppp( 9, 8, 7,3)/
     x 1.2145047D-06,-1.0820250D-06,-3.0214926D-10 /
      data fpppp( 9, 8, 8,1),fpppp( 9, 8, 8,2),fpppp( 9, 8, 8,3)/
     x-3.5308373D-07,-8.7813434D-08, 8.0183971D-10 /
      data fpppp( 9, 8, 9,1),fpppp( 9, 8, 9,2),fpppp( 9, 8, 9,3)/
     x-9.7070192D-07, 1.0369307D-06, 7.0455439D-10 /
      data fpppp( 9, 8,10,1),fpppp( 9, 8,10,2),fpppp( 9, 8,10,3)/
     x-3.5308373D-07,-8.7813434D-08, 8.0183971D-10 /
      data fpppp( 9, 8,11,1),fpppp( 9, 8,11,2),fpppp( 9, 8,11,3)/
     x 1.2145047D-06,-1.0820250D-06,-3.0214926D-10 /
      data fpppp( 9, 8,12,1),fpppp( 9, 8,12,2),fpppp( 9, 8,12,3)/
     x 1.9952477D-06, 3.6577282D-07,-1.8062889D-09 /
      data fpppp( 9, 8,13,1),fpppp( 9, 8,13,2),fpppp( 9, 8,13,3)/
     x 8.0215448D-07, 7.1764583D-07,-8.8190170D-10 /
      data fpppp( 9, 8,14,1),fpppp( 9, 8,14,2),fpppp( 9, 8,14,3)/
     x-1.7253281D-06,-3.1806766D-07, 4.0622380D-11 /
      data fpppp( 9, 8,15,1),fpppp( 9, 8,15,2),fpppp( 9, 8,15,3)/
     x-3.5842099D-06,-2.5890357D-07, 3.5739416D-09 /
      data fpppp( 9, 8,16,1),fpppp( 9, 8,16,2),fpppp( 9, 8,16,3)/
     x-1.7253281D-06,-1.3238049D-07, 1.4417961D-10 /
      data fpppp( 9, 8,17,1),fpppp( 9, 8,17,2),fpppp( 9, 8,17,3)/
     x 8.0215448D-07,-2.5102842D-08,-1.2961306D-09 /
      data fpppp( 9, 9, 1,1),fpppp( 9, 9, 1,2),fpppp( 9, 9, 1,3)/
     x 8.0316448D-07, 2.9626658D-07,-1.4502768D-09 /
      data fpppp( 9, 9, 2,1),fpppp( 9, 9, 2,2),fpppp( 9, 9, 2,3)/
     x-1.6676682D-06,-1.8464726D-09, 6.6687280D-11 /
      data fpppp( 9, 9, 3,1),fpppp( 9, 9, 3,2),fpppp( 9, 9, 3,3)/
     x-3.3427899D-06,-6.4232888D-07, 3.7554819D-09 /
      data fpppp( 9, 9, 4,1),fpppp( 9, 9, 4,2),fpppp( 9, 9, 4,3)/
     x-1.6676682D-06,-8.4518536D-08,-1.5713045D-10 /
      data fpppp( 9, 9, 5,1),fpppp( 9, 9, 5,2),fpppp( 9, 9, 5,3)/
     x 8.0316448D-07, 6.2695483D-07,-5.5500585D-10 /
      data fpppp( 9, 9, 6,1),fpppp( 9, 9, 6,2),fpppp( 9, 9, 6,3)/
     x 2.1011159D-06, 1.8329435D-07,-2.3729961D-09 /
      data fpppp( 9, 9, 7,1),fpppp( 9, 9, 7,2),fpppp( 9, 9, 7,3)/
     x 1.1476777D-06,-7.8951389D-07, 8.9957677D-12 /
      data fpppp( 9, 9, 8,1),fpppp( 9, 9, 8,2),fpppp( 9, 9, 8,3)/
     x-7.6663989D-07,-5.7767124D-08, 6.4446859D-10 /
      data fpppp( 9, 9, 9,1),fpppp( 9, 9, 9,2),fpppp( 9, 9, 9,3)/
     x-1.5655614D-06, 8.7165095D-07, 1.0705512D-09 /
      data fpppp( 9, 9,10,1),fpppp( 9, 9,10,2),fpppp( 9, 9,10,3)/
     x-7.6663989D-07,-5.7767124D-08, 6.4446859D-10 /
      data fpppp( 9, 9,11,1),fpppp( 9, 9,11,2),fpppp( 9, 9,11,3)/
     x 1.1476777D-06,-7.8951389D-07, 8.9957677D-12 /
      data fpppp( 9, 9,12,1),fpppp( 9, 9,12,2),fpppp( 9, 9,12,3)/
     x 2.1011159D-06, 1.8329435D-07,-2.3729961D-09 /
      data fpppp( 9, 9,13,1),fpppp( 9, 9,13,2),fpppp( 9, 9,13,3)/
     x 8.0316448D-07, 6.2695483D-07,-5.5500585D-10 /
      data fpppp( 9, 9,14,1),fpppp( 9, 9,14,2),fpppp( 9, 9,14,3)/
     x-1.6676682D-06,-8.4518536D-08,-1.5713045D-10 /
      data fpppp( 9, 9,15,1),fpppp( 9, 9,15,2),fpppp( 9, 9,15,3)/
     x-3.3427899D-06,-6.4232888D-07, 3.7554819D-09 /
      data fpppp( 9, 9,16,1),fpppp( 9, 9,16,2),fpppp( 9, 9,16,3)/
     x-1.6676682D-06,-1.8464726D-09, 6.6687280D-11 /
      data fpppp( 9, 9,17,1),fpppp( 9, 9,17,2),fpppp( 9, 9,17,3)/
     x 8.0316448D-07, 2.9626658D-07,-1.4502768D-09 /
      data fpppp( 9,10, 1,1),fpppp( 9,10, 1,2),fpppp( 9,10, 1,3)/
     x 9.9451006D-07, 4.6903964D-07,-3.1280621D-10 /
      data fpppp( 9,10, 2,1),fpppp( 9,10, 2,2),fpppp( 9,10, 2,3)/
     x-1.4364761D-06, 1.7863319D-07, 4.9582590D-10 /
      data fpppp( 9,10, 3,1),fpppp( 9,10, 3,2),fpppp( 9,10, 3,3)/
     x-2.6060343D-06,-5.0884342D-07, 2.3471562D-09 /
      data fpppp( 9,10, 4,1),fpppp( 9,10, 4,2),fpppp( 9,10, 4,3)/
     x-1.4364761D-06, 1.9342554D-07, 5.4904287D-10 /
      data fpppp( 9,10, 5,1),fpppp( 9,10, 5,2),fpppp( 9,10, 5,3)/
     x 9.9451006D-07, 4.0987025D-07,-5.2567409D-10 /
      data fpppp( 9,10, 6,1),fpppp( 9,10, 6,2),fpppp( 9,10, 6,3)/
     x 2.3867294D-06,-3.2296928D-07,-2.5924733D-09 /
      data fpppp( 9,10, 7,1),fpppp( 9,10, 7,2),fpppp( 9,10, 7,3)/
     x 9.3702340D-07,-6.1117075D-07,-2.3248182D-11 /
      data fpppp( 9,10, 8,1),fpppp( 9,10, 8,2),fpppp( 9,10, 8,3)/
     x-1.3632977D-06, 1.4373878D-07, 9.0869004D-10 /
      data fpppp( 9,10, 9,1),fpppp( 9,10, 9,2),fpppp( 9,10, 9,3)/
     x-2.3178035D-06, 8.8551973D-07, 1.0290387D-09 /
      data fpppp( 9,10,10,1),fpppp( 9,10,10,2),fpppp( 9,10,10,3)/
     x-1.3632977D-06, 1.4373878D-07, 9.0869004D-10 /
      data fpppp( 9,10,11,1),fpppp( 9,10,11,2),fpppp( 9,10,11,3)/
     x 9.3702340D-07,-6.1117075D-07,-2.3248182D-11 /
      data fpppp( 9,10,12,1),fpppp( 9,10,12,2),fpppp( 9,10,12,3)/
     x 2.3867294D-06,-3.2296928D-07,-2.5924733D-09 /
      data fpppp( 9,10,13,1),fpppp( 9,10,13,2),fpppp( 9,10,13,3)/
     x 9.9451006D-07, 4.0987025D-07,-5.2567409D-10 /
      data fpppp( 9,10,14,1),fpppp( 9,10,14,2),fpppp( 9,10,14,3)/
     x-1.4364761D-06, 1.9342554D-07, 5.4904287D-10 /
      data fpppp( 9,10,15,1),fpppp( 9,10,15,2),fpppp( 9,10,15,3)/
     x-2.6060343D-06,-5.0884342D-07, 2.3471562D-09 /
      data fpppp( 9,10,16,1),fpppp( 9,10,16,2),fpppp( 9,10,16,3)/
     x-1.4364761D-06, 1.7863319D-07, 4.9582590D-10 /
      data fpppp( 9,10,17,1),fpppp( 9,10,17,2),fpppp( 9,10,17,3)/
     x 9.9451006D-07, 4.6903964D-07,-3.1280621D-10 /
      data fpppp( 9,11, 1,1),fpppp( 9,11, 1,2),fpppp( 9,11, 1,3)/
     x 1.7159691D-06, 6.6074183D-07, 6.1546599D-10 /
      data fpppp( 9,11, 2,1),fpppp( 9,11, 2,2),fpppp( 9,11, 2,3)/
     x-8.2434113D-07, 4.7896621D-07, 8.8874707D-10 /
      data fpppp( 9,11, 3,1),fpppp( 9,11, 3,2),fpppp( 9,11, 3,3)/
     x-1.7108766D-06,-4.0900788D-08, 1.3069774D-09 /
      data fpppp( 9,11, 4,1),fpppp( 9,11, 4,2),fpppp( 9,11, 4,3)/
     x-8.2434113D-07, 6.2255203D-07, 1.2178854D-09 /
      data fpppp( 9,11, 5,1),fpppp( 9,11, 5,2),fpppp( 9,11, 5,3)/
     x 1.7159691D-06, 8.6398556D-08,-7.0108746D-10 /
      data fpppp( 9,11, 6,1),fpppp( 9,11, 6,2),fpppp( 9,11, 6,3)/
     x 3.1736115D-06,-1.2671575D-06,-2.9988783D-09 /
      data fpppp( 9,11, 7,1),fpppp( 9,11, 7,2),fpppp( 9,11, 7,3)/
     x 9.4642653D-07,-4.9739966D-07, 3.2985750D-10 /
      data fpppp( 9,11, 8,1),fpppp( 9,11, 8,2),fpppp( 9,11, 8,3)/
     x-1.5553626D-06, 5.2613044D-07, 1.0790968D-09 /
      data fpppp( 9,11, 9,1),fpppp( 9,11, 9,2),fpppp( 9,11, 9,3)/
     x-2.6055106D-06, 1.1237841D-06, 8.9413111D-10 /
      data fpppp( 9,11,10,1),fpppp( 9,11,10,2),fpppp( 9,11,10,3)/
     x-1.5553626D-06, 5.2613044D-07, 1.0790968D-09 /
      data fpppp( 9,11,11,1),fpppp( 9,11,11,2),fpppp( 9,11,11,3)/
     x 9.4642653D-07,-4.9739966D-07, 3.2985750D-10 /
      data fpppp( 9,11,12,1),fpppp( 9,11,12,2),fpppp( 9,11,12,3)/
     x 3.1736115D-06,-1.2671575D-06,-2.9988783D-09 /
      data fpppp( 9,11,13,1),fpppp( 9,11,13,2),fpppp( 9,11,13,3)/
     x 1.7159691D-06, 8.6398556D-08,-7.0108746D-10 /
      data fpppp( 9,11,14,1),fpppp( 9,11,14,2),fpppp( 9,11,14,3)/
     x-8.2434113D-07, 6.2255203D-07, 1.2178854D-09 /
      data fpppp( 9,11,15,1),fpppp( 9,11,15,2),fpppp( 9,11,15,3)/
     x-1.7108766D-06,-4.0900788D-08, 1.3069774D-09 /
      data fpppp( 9,11,16,1),fpppp( 9,11,16,2),fpppp( 9,11,16,3)/
     x-8.2434113D-07, 4.7896621D-07, 8.8874707D-10 /
      data fpppp( 9,11,17,1),fpppp( 9,11,17,2),fpppp( 9,11,17,3)/
     x 1.7159691D-06, 6.6074183D-07, 6.1546599D-10 /
      data fpppp( 9,12, 1,1),fpppp( 9,12, 1,2),fpppp( 9,12, 1,3)/
     x 2.8408415D-06, 9.9762942D-07, 7.2078925D-10 /
      data fpppp( 9,12, 2,1),fpppp( 9,12, 2,2),fpppp( 9,12, 2,3)/
     x 5.9480286D-07, 9.5337073D-07, 8.2282516D-10 /
      data fpppp( 9,12, 3,1),fpppp( 9,12, 3,2),fpppp( 9,12, 3,3)/
     x-1.4632443D-07, 6.2795250D-07, 7.8053006D-10 /
      data fpppp( 9,12, 4,1),fpppp( 9,12, 4,2),fpppp( 9,12, 4,3)/
     x 5.9480286D-07, 1.2865927D-06, 1.2433935D-09 /
      data fpppp( 9,12, 5,1),fpppp( 9,12, 5,2),fpppp( 9,12, 5,3)/
     x 2.8408415D-06,-3.3525839D-07,-9.6148402D-10 /
      data fpppp( 9,12, 6,1),fpppp( 9,12, 6,2),fpppp( 9,12, 6,3)/
     x 3.8947833D-06,-2.7825783D-06,-2.4699597D-09 /
      data fpppp( 9,12, 7,1),fpppp( 9,12, 7,2),fpppp( 9,12, 7,3)/
     x 1.4664107D-06,-3.4090751D-07, 5.8711143D-10 /
      data fpppp( 9,12, 8,1),fpppp( 9,12, 8,2),fpppp( 9,12, 8,3)/
     x-1.0339760D-06, 1.0843098D-06, 8.5969604D-10 /
      data fpppp( 9,12, 9,1),fpppp( 9,12, 9,2),fpppp( 9,12, 9,3)/
     x-1.8029191D-06, 1.6032680D-06, 7.7205015D-10 /
      data fpppp( 9,12,10,1),fpppp( 9,12,10,2),fpppp( 9,12,10,3)/
     x-1.0339760D-06, 1.0843098D-06, 8.5969604D-10 /
      data fpppp( 9,12,11,1),fpppp( 9,12,11,2),fpppp( 9,12,11,3)/
     x 1.4664107D-06,-3.4090751D-07, 5.8711143D-10 /
      data fpppp( 9,12,12,1),fpppp( 9,12,12,2),fpppp( 9,12,12,3)/
     x 3.8947833D-06,-2.7825783D-06,-2.4699597D-09 /
      data fpppp( 9,12,13,1),fpppp( 9,12,13,2),fpppp( 9,12,13,3)/
     x 2.8408415D-06,-3.3525839D-07,-9.6148402D-10 /
      data fpppp( 9,12,14,1),fpppp( 9,12,14,2),fpppp( 9,12,14,3)/
     x 5.9480286D-07, 1.2865927D-06, 1.2433935D-09 /
      data fpppp( 9,12,15,1),fpppp( 9,12,15,2),fpppp( 9,12,15,3)/
     x-1.4632443D-07, 6.2795250D-07, 7.8053006D-10 /
      data fpppp( 9,12,16,1),fpppp( 9,12,16,2),fpppp( 9,12,16,3)/
     x 5.9480286D-07, 9.5337073D-07, 8.2282516D-10 /
      data fpppp( 9,12,17,1),fpppp( 9,12,17,2),fpppp( 9,12,17,3)/
     x 2.8408415D-06, 9.9762942D-07, 7.2078925D-10 /
      data fpppp( 9,13, 1,1),fpppp( 9,13, 1,2),fpppp( 9,13, 1,3)/
     x 3.8457000D-06, 1.4627040D-06,-6.0493662D-10 /
      data fpppp( 9,13, 2,1),fpppp( 9,13, 2,2),fpppp( 9,13, 2,3)/
     x 3.4517484D-06, 1.5736177D-06,-2.2075381D-10 /
      data fpppp( 9,13, 3,1),fpppp( 9,13, 3,2),fpppp( 9,13, 3,3)/
     x 3.0947499D-06, 1.4419570D-06, 6.0004042D-10 /
      data fpppp( 9,13, 4,1),fpppp( 9,13, 4,2),fpppp( 9,13, 4,3)/
     x 3.4517484D-06, 2.1593065D-06,-1.0730536D-10 /
      data fpppp( 9,13, 5,1),fpppp( 9,13, 5,2),fpppp( 9,13, 5,3)/
     x 3.8457000D-06,-8.8005118D-07,-1.0587304D-09 /
      data fpppp( 9,13, 6,1),fpppp( 9,13, 6,2),fpppp( 9,13, 6,3)/
     x 3.1813895D-06,-4.7818309D-06, 5.3757891D-10 /
      data fpppp( 9,13, 7,1),fpppp( 9,13, 7,2),fpppp( 9,13, 7,3)/
     x 2.1401533D-06,-1.2495387D-07, 9.2003191D-11 /
      data fpppp( 9,13, 8,1),fpppp( 9,13, 8,2),fpppp( 9,13, 8,3)/
     x 1.2458536D-06, 1.8422834D-06, 1.4203149D-10 /
      data fpppp( 9,13, 9,1),fpppp( 9,13, 9,2),fpppp( 9,13, 9,3)/
     x 9.9246443D-07, 2.2261498D-06, 2.0771206D-10 /
      data fpppp( 9,13,10,1),fpppp( 9,13,10,2),fpppp( 9,13,10,3)/
     x 1.2458536D-06, 1.8422834D-06, 1.4203149D-10 /
      data fpppp( 9,13,11,1),fpppp( 9,13,11,2),fpppp( 9,13,11,3)/
     x 2.1401533D-06,-1.2495387D-07, 9.2003191D-11 /
      data fpppp( 9,13,12,1),fpppp( 9,13,12,2),fpppp( 9,13,12,3)/
     x 3.1813895D-06,-4.7818309D-06, 5.3757891D-10 /
      data fpppp( 9,13,13,1),fpppp( 9,13,13,2),fpppp( 9,13,13,3)/
     x 3.8457000D-06,-8.8005118D-07,-1.0587304D-09 /
      data fpppp( 9,13,14,1),fpppp( 9,13,14,2),fpppp( 9,13,14,3)/
     x 3.4517484D-06, 2.1593065D-06,-1.0730536D-10 /
      data fpppp( 9,13,15,1),fpppp( 9,13,15,2),fpppp( 9,13,15,3)/
     x 3.0947499D-06, 1.4419570D-06, 6.0004042D-10 /
      data fpppp( 9,13,16,1),fpppp( 9,13,16,2),fpppp( 9,13,16,3)/
     x 3.4517484D-06, 1.5736177D-06,-2.2075381D-10 /
      data fpppp( 9,13,17,1),fpppp( 9,13,17,2),fpppp( 9,13,17,3)/
     x 3.8457000D-06, 1.4627040D-06,-6.0493662D-10 /
      data fpppp( 9,14, 1,1),fpppp( 9,14, 1,2),fpppp( 9,14, 1,3)/
     x 2.1830138D-06, 1.8106904D-06,-2.8400258D-09 /
      data fpppp( 9,14, 2,1),fpppp( 9,14, 2,2),fpppp( 9,14, 2,3)/
     x 6.8234552D-06, 2.1423410D-06,-2.2351773D-09 /
      data fpppp( 9,14, 3,1),fpppp( 9,14, 3,2),fpppp( 9,14, 3,3)/
     x 7.7331507D-06, 2.3482534D-06,-4.2023928D-10 /
      data fpppp( 9,14, 4,1),fpppp( 9,14, 4,2),fpppp( 9,14, 4,3)/
     x 6.8234552D-06, 2.9942493D-06,-2.8406145D-09 /
      data fpppp( 9,14, 5,1),fpppp( 9,14, 5,2),fpppp( 9,14, 5,3)/
     x 2.1830138D-06,-1.5969429D-06,-4.1827679D-10 /
      data fpppp( 9,14, 6,1),fpppp( 9,14, 6,2),fpppp( 9,14, 6,3)/
     x-2.1261776D-06,-6.6209051D-06, 6.6848167D-09 /
      data fpppp( 9,14, 7,1),fpppp( 9,14, 7,2),fpppp( 9,14, 7,3)/
     x 2.0927642D-06, 1.5509445D-08,-1.2411322D-09 /
      data fpppp( 9,14, 8,1),fpppp( 9,14, 8,2),fpppp( 9,14, 8,3)/
     x 5.1574680D-06, 2.6710949D-06,-1.5689626D-09 /
      data fpppp( 9,14, 9,1),fpppp( 9,14, 9,2),fpppp( 9,14, 9,3)/
     x 5.9660336D-06, 2.8677201D-06,-9.1232810D-10 /
      data fpppp( 9,14,10,1),fpppp( 9,14,10,2),fpppp( 9,14,10,3)/
     x 5.1574680D-06, 2.6710949D-06,-1.5689626D-09 /
      data fpppp( 9,14,11,1),fpppp( 9,14,11,2),fpppp( 9,14,11,3)/
     x 2.0927642D-06, 1.5509445D-08,-1.2411322D-09 /
      data fpppp( 9,14,12,1),fpppp( 9,14,12,2),fpppp( 9,14,12,3)/
     x-2.1261776D-06,-6.6209051D-06, 6.6848167D-09 /
      data fpppp( 9,14,13,1),fpppp( 9,14,13,2),fpppp( 9,14,13,3)/
     x 2.1830138D-06,-1.5969429D-06,-4.1827679D-10 /
      data fpppp( 9,14,14,1),fpppp( 9,14,14,2),fpppp( 9,14,14,3)/
     x 6.8234552D-06, 2.9942493D-06,-2.8406145D-09 /
      data fpppp( 9,14,15,1),fpppp( 9,14,15,2),fpppp( 9,14,15,3)/
     x 7.7331507D-06, 2.3482534D-06,-4.2023928D-10 /
      data fpppp( 9,14,16,1),fpppp( 9,14,16,2),fpppp( 9,14,16,3)/
     x 6.8234552D-06, 2.1423410D-06,-2.2351773D-09 /
      data fpppp( 9,14,17,1),fpppp( 9,14,17,2),fpppp( 9,14,17,3)/
     x 2.1830138D-06, 1.8106904D-06,-2.8400258D-09 /
      data fpppp( 9,15, 1,1),fpppp( 9,15, 1,2),fpppp( 9,15, 1,3)/
     x-2.6045723D-06, 1.5965326D-06,-3.5288300D-09 /
      data fpppp( 9,15, 2,1),fpppp( 9,15, 2,2),fpppp( 9,15, 2,3)/
     x 8.0057604D-06, 2.2610402D-06,-3.7707978D-09 /
      data fpppp( 9,15, 3,1),fpppp( 9,15, 3,2),fpppp( 9,15, 3,3)/
     x 1.1265962D-05, 3.1461055D-06,-3.3761709D-09 /
      data fpppp( 9,15, 4,1),fpppp( 9,15, 4,2),fpppp( 9,15, 4,3)/
     x 8.0057604D-06, 3.2592188D-06,-5.2096254D-09 /
      data fpppp( 9,15, 5,1),fpppp( 9,15, 5,2),fpppp( 9,15, 5,3)/
     x-2.6045723D-06,-2.3961819D-06, 2.2264805D-09 /
      data fpppp( 9,15, 6,1),fpppp( 9,15, 6,2),fpppp( 9,15, 6,3)/
     x-8.2936199D-06,-6.9841696D-06, 1.1223972D-08 /
      data fpppp( 9,15, 7,1),fpppp( 9,15, 7,2),fpppp( 9,15, 7,3)/
     x 6.9200530D-07,-2.8599881D-07,-1.5053867D-09 /
      data fpppp( 9,15, 8,1),fpppp( 9,15, 8,2),fpppp( 9,15, 8,3)/
     x 9.2537773D-06, 3.2482197D-06,-3.8153492D-09 /
      data fpppp( 9,15, 9,1),fpppp( 9,15, 9,2),fpppp( 9,15, 9,3)/
     x 1.1619848D-05, 3.3380813D-06,-2.7038157D-09 /
      data fpppp( 9,15,10,1),fpppp( 9,15,10,2),fpppp( 9,15,10,3)/
     x 9.2537773D-06, 3.2482197D-06,-3.8153492D-09 /
      data fpppp( 9,15,11,1),fpppp( 9,15,11,2),fpppp( 9,15,11,3)/
     x 6.9200530D-07,-2.8599881D-07,-1.5053867D-09 /
      data fpppp( 9,15,12,1),fpppp( 9,15,12,2),fpppp( 9,15,12,3)/
     x-8.2936199D-06,-6.9841696D-06, 1.1223972D-08 /
      data fpppp( 9,15,13,1),fpppp( 9,15,13,2),fpppp( 9,15,13,3)/
     x-2.6045723D-06,-2.3961819D-06, 2.2264805D-09 /
      data fpppp( 9,15,14,1),fpppp( 9,15,14,2),fpppp( 9,15,14,3)/
     x 8.0057604D-06, 3.2592188D-06,-5.2096254D-09 /
      data fpppp( 9,15,15,1),fpppp( 9,15,15,2),fpppp( 9,15,15,3)/
     x 1.1265962D-05, 3.1461055D-06,-3.3761709D-09 /
      data fpppp( 9,15,16,1),fpppp( 9,15,16,2),fpppp( 9,15,16,3)/
     x 8.0057604D-06, 2.2610402D-06,-3.7707978D-09 /
      data fpppp( 9,15,17,1),fpppp( 9,15,17,2),fpppp( 9,15,17,3)/
     x-2.6045723D-06, 1.5965326D-06,-3.5288300D-09 /
      data fpppp( 9,16, 1,1),fpppp( 9,16, 1,2),fpppp( 9,16, 1,3)/
     x-6.9318252D-06, 7.0457944D-07,-2.3833290D-11 /
      data fpppp( 9,16, 2,1),fpppp( 9,16, 2,2),fpppp( 9,16, 2,3)/
     x 3.3271339D-06, 1.6521892D-06,-2.3632737D-09 /
      data fpppp( 9,16, 3,1),fpppp( 9,16, 3,2),fpppp( 9,16, 3,3)/
     x 8.7337481D-06, 3.3115521D-06,-6.9293296D-09 /
      data fpppp( 9,16, 4,1),fpppp( 9,16, 4,2),fpppp( 9,16, 4,3)/
     x 3.3271339D-06, 2.4797787D-06,-3.7022315D-09 /
      data fpppp( 9,16, 5,1),fpppp( 9,16, 5,2),fpppp( 9,16, 5,3)/
     x-6.9318252D-06,-2.6057788D-06, 5.3319978D-09 /
      data fpppp( 9,16, 6,1),fpppp( 9,16, 6,2),fpppp( 9,16, 6,3)/
     x-7.5175348D-06,-5.3627445D-06, 7.1620722D-09 /
      data fpppp( 9,16, 7,1),fpppp( 9,16, 7,2),fpppp( 9,16, 7,3)/
     x-9.0893712D-07,-8.4689291D-07, 1.5519316D-09 /
      data fpppp( 9,16, 8,1),fpppp( 9,16, 8,2),fpppp( 9,16, 8,3)/
     x 1.0145183D-05, 3.0555174D-06,-4.6694272D-09 /
      data fpppp( 9,16, 9,1),fpppp( 9,16, 9,2),fpppp( 9,16, 9,3)/
     x 1.4393591D-05, 3.3866196D-06,-4.6425158D-09 /
      data fpppp( 9,16,10,1),fpppp( 9,16,10,2),fpppp( 9,16,10,3)/
     x 1.0145183D-05, 3.0555174D-06,-4.6694272D-09 /
      data fpppp( 9,16,11,1),fpppp( 9,16,11,2),fpppp( 9,16,11,3)/
     x-9.0893712D-07,-8.4689291D-07, 1.5519316D-09 /
      data fpppp( 9,16,12,1),fpppp( 9,16,12,2),fpppp( 9,16,12,3)/
     x-7.5175348D-06,-5.3627445D-06, 7.1620722D-09 /
      data fpppp( 9,16,13,1),fpppp( 9,16,13,2),fpppp( 9,16,13,3)/
     x-6.9318252D-06,-2.6057788D-06, 5.3319978D-09 /
      data fpppp( 9,16,14,1),fpppp( 9,16,14,2),fpppp( 9,16,14,3)/
     x 3.3271339D-06, 2.4797787D-06,-3.7022315D-09 /
      data fpppp( 9,16,15,1),fpppp( 9,16,15,2),fpppp( 9,16,15,3)/
     x 8.7337481D-06, 3.3115521D-06,-6.9293296D-09 /
      data fpppp( 9,16,16,1),fpppp( 9,16,16,2),fpppp( 9,16,16,3)/
     x 3.3271339D-06, 1.6521892D-06,-2.3632737D-09 /
      data fpppp( 9,16,17,1),fpppp( 9,16,17,2),fpppp( 9,16,17,3)/
     x-6.9318252D-06, 7.0457944D-07,-2.3833290D-11 /
      data fpppp( 9,17, 1,1),fpppp( 9,17, 1,2),fpppp( 9,17, 1,3)/
     x-4.4077316D-06,-9.8018826D-08, 3.9275437D-09 /
      data fpppp( 9,17, 2,1),fpppp( 9,17, 2,2),fpppp( 9,17, 2,3)/
     x-6.5523408D-06, 6.8557931D-07, 1.5971315D-09 /
      data fpppp( 9,17, 3,1),fpppp( 9,17, 3,2),fpppp( 9,17, 3,3)/
     x-5.0124265D-06, 2.2547917D-06,-4.0228466D-09 /
      data fpppp( 9,17, 4,1),fpppp( 9,17, 4,2),fpppp( 9,17, 4,3)/
     x-6.5523408D-06, 1.0743542D-06, 1.8706562D-09 /
      data fpppp( 9,17, 5,1),fpppp( 9,17, 5,2),fpppp( 9,17, 5,3)/
     x-4.4077316D-06,-1.6531185D-06, 2.8334450D-09 /
      data fpppp( 9,17, 6,1),fpppp( 9,17, 6,2),fpppp( 9,17, 6,3)/
     x-2.7532314D-06,-2.9727884D-06,-2.3160320D-09 /
      data fpppp( 9,17, 7,1),fpppp( 9,17, 7,2),fpppp( 9,17, 7,3)/
     x-9.5637597D-07,-8.0036163D-07, 3.0848295D-09 /
      data fpppp( 9,17, 8,1),fpppp( 9,17, 8,2),fpppp( 9,17, 8,3)/
     x 4.0268412D-06, 1.9473155D-06,-1.0918475D-09 /
      data fpppp( 9,17, 9,1),fpppp( 9,17, 9,2),fpppp( 9,17, 9,3)/
     x 7.5938460D-06, 2.6192018D-06,-4.6936683D-09 /
      data fpppp( 9,17,10,1),fpppp( 9,17,10,2),fpppp( 9,17,10,3)/
     x 4.0268412D-06, 1.9473155D-06,-1.0918475D-09 /
      data fpppp( 9,17,11,1),fpppp( 9,17,11,2),fpppp( 9,17,11,3)/
     x-9.5637597D-07,-8.0036163D-07, 3.0848295D-09 /
      data fpppp( 9,17,12,1),fpppp( 9,17,12,2),fpppp( 9,17,12,3)/
     x-2.7532314D-06,-2.9727884D-06,-2.3160320D-09 /
      data fpppp( 9,17,13,1),fpppp( 9,17,13,2),fpppp( 9,17,13,3)/
     x-4.4077316D-06,-1.6531185D-06, 2.8334450D-09 /
      data fpppp( 9,17,14,1),fpppp( 9,17,14,2),fpppp( 9,17,14,3)/
     x-6.5523408D-06, 1.0743542D-06, 1.8706562D-09 /
      data fpppp( 9,17,15,1),fpppp( 9,17,15,2),fpppp( 9,17,15,3)/
     x-5.0124265D-06, 2.2547917D-06,-4.0228466D-09 /
      data fpppp( 9,17,16,1),fpppp( 9,17,16,2),fpppp( 9,17,16,3)/
     x-6.5523408D-06, 6.8557931D-07, 1.5971315D-09 /
      data fpppp( 9,17,17,1),fpppp( 9,17,17,2),fpppp( 9,17,17,3)/
     x-4.4077316D-06,-9.8018826D-08, 3.9275437D-09 /
      data fpppp( 9,18, 1,1),fpppp( 9,18, 1,2),fpppp( 9,18, 1,3)/
     x-2.0580948D-06,-1.4694655D-07, 1.5846503D-09 /
      data fpppp( 9,18, 2,1),fpppp( 9,18, 2,2),fpppp( 9,18, 2,3)/
     x-1.1010668D-05, 9.2078461D-08, 2.9994305D-09 /
      data fpppp( 9,18, 3,1),fpppp( 9,18, 3,2),fpppp( 9,18, 3,3)/
     x-1.5334268D-05, 5.6467177D-07, 5.6109925D-09 /
      data fpppp( 9,18, 4,1),fpppp( 9,18, 4,2),fpppp( 9,18, 4,3)/
     x-1.1010668D-05, 2.1977604D-07, 4.0338183D-09 /
      data fpppp( 9,18, 5,1),fpppp( 9,18, 5,2),fpppp( 9,18, 5,3)/
     x-2.0580948D-06,-6.5773688D-07,-2.5529009D-09 /
      data fpppp( 9,18, 6,1),fpppp( 9,18, 6,2),fpppp( 9,18, 6,3)/
     x 4.0300903D-06,-7.6585038D-07,-7.0836637D-09 /
      data fpppp( 9,18, 7,1),fpppp( 9,18, 7,2),fpppp( 9,18, 7,3)/
     x 4.5907087D-07,-2.7508833D-07,-1.3012482D-09 /
      data fpppp( 9,18, 8,1),fpppp( 9,18, 8,2),fpppp( 9,18, 8,3)/
     x-6.1338900D-06, 6.8149999D-07, 2.7025310D-09 /
      data fpppp( 9,18, 9,1),fpppp( 9,18, 9,2),fpppp( 9,18, 9,3)/
     x-8.8250681D-06, 1.0514103D-06, 2.9643322D-09 /
      data fpppp( 9,18,10,1),fpppp( 9,18,10,2),fpppp( 9,18,10,3)/
     x-6.1338900D-06, 6.8149999D-07, 2.7025310D-09 /
      data fpppp( 9,18,11,1),fpppp( 9,18,11,2),fpppp( 9,18,11,3)/
     x 4.5907087D-07,-2.7508833D-07,-1.3012482D-09 /
      data fpppp( 9,18,12,1),fpppp( 9,18,12,2),fpppp( 9,18,12,3)/
     x 4.0300903D-06,-7.6585038D-07,-7.0836637D-09 /
      data fpppp( 9,18,13,1),fpppp( 9,18,13,2),fpppp( 9,18,13,3)/
     x-2.0580948D-06,-6.5773688D-07,-2.5529009D-09 /
      data fpppp( 9,18,14,1),fpppp( 9,18,14,2),fpppp( 9,18,14,3)/
     x-1.1010668D-05, 2.1977604D-07, 4.0338183D-09 /
      data fpppp( 9,18,15,1),fpppp( 9,18,15,2),fpppp( 9,18,15,3)/
     x-1.5334268D-05, 5.6467177D-07, 5.6109925D-09 /
      data fpppp( 9,18,16,1),fpppp( 9,18,16,2),fpppp( 9,18,16,3)/
     x-1.1010668D-05, 9.2078461D-08, 2.9994305D-09 /
      data fpppp( 9,18,17,1),fpppp( 9,18,17,2),fpppp( 9,18,17,3)/
     x-2.0580948D-06,-1.4694655D-07, 1.5846503D-09 /
      data fpppp( 9,19, 1,1),fpppp( 9,19, 1,2),fpppp( 9,19, 1,3)/
     x 3.4138673D-07, 2.4634949D-20, 1.0401198D-09 /
      data fpppp( 9,19, 2,1),fpppp( 9,19, 2,2),fpppp( 9,19, 2,3)/
     x-1.7017895D-05,-1.3104471D-20, 5.1326170D-09 /
      data fpppp( 9,19, 3,1),fpppp( 9,19, 3,2),fpppp( 9,19, 3,3)/
     x-2.6634490D-05,-3.9061417D-21, 1.3322730D-08 /
      data fpppp( 9,19, 4,1),fpppp( 9,19, 4,2),fpppp( 9,19, 4,3)/
     x-1.7017895D-05, 1.0091887D-21, 7.1711877D-09 /
      data fpppp( 9,19, 5,1),fpppp( 9,19, 5,2),fpppp( 9,19, 5,3)/
     x 3.4138673D-07,-7.9385517D-21,-7.1141630D-09 /
      data fpppp( 9,19, 6,1),fpppp( 9,19, 6,2),fpppp( 9,19, 6,3)/
     x 1.0236550D-05,-7.7062339D-21,-1.3197145D-08 /
      data fpppp( 9,19, 7,1),fpppp( 9,19, 7,2),fpppp( 9,19, 7,3)/
     x 1.4565504D-06, 5.0575678D-21,-3.9961899D-09 /
      data fpppp( 9,19, 8,1),fpppp( 9,19, 8,2),fpppp( 9,19, 8,3)/
     x-1.5139653D-05,-3.0732383D-21, 6.4349671D-09 /
      data fpppp( 9,19, 9,1),fpppp( 9,19, 9,2),fpppp( 9,19, 9,3)/
     x-2.2495648D-05,-2.8231906D-21, 8.4197176D-09 /
      data fpppp( 9,19,10,1),fpppp( 9,19,10,2),fpppp( 9,19,10,3)/
     x-1.5139653D-05,-4.0273563D-21, 6.4349671D-09 /
      data fpppp( 9,19,11,1),fpppp( 9,19,11,2),fpppp( 9,19,11,3)/
     x 1.4565504D-06, 2.8437938D-21,-3.9961899D-09 /
      data fpppp( 9,19,12,1),fpppp( 9,19,12,2),fpppp( 9,19,12,3)/
     x 1.0236550D-05, 5.9268604D-21,-1.3197145D-08 /
      data fpppp( 9,19,13,1),fpppp( 9,19,13,2),fpppp( 9,19,13,3)/
     x 3.4138673D-07, 6.5403192D-21,-7.1141630D-09 /
      data fpppp( 9,19,14,1),fpppp( 9,19,14,2),fpppp( 9,19,14,3)/
     x-1.7017895D-05,-5.6828587D-21, 7.1711877D-09 /
      data fpppp( 9,19,15,1),fpppp( 9,19,15,2),fpppp( 9,19,15,3)/
     x-2.6634490D-05, 4.0526228D-21, 1.3322730D-08 /
      data fpppp( 9,19,16,1),fpppp( 9,19,16,2),fpppp( 9,19,16,3)/
     x-1.7017895D-05,-5.7327490D-21, 5.1326170D-09 /
      data fpppp( 9,19,17,1),fpppp( 9,19,17,2),fpppp( 9,19,17,3)/
     x 3.4138673D-07, 1.1072981D-20, 1.0401198D-09 /
      data fpppp(10, 1, 1,1),fpppp(10, 1, 1,2),fpppp(10, 1, 1,3)/
     x 2.3419214D-07,-9.2443746D-22, 6.8019933D-11 /
      data fpppp(10, 1, 2,1),fpppp(10, 1, 2,2),fpppp(10, 1, 2,3)/
     x-6.7854391D-07,-9.9225035D-22, 3.1339549D-10 /
      data fpppp(10, 1, 3,1),fpppp(10, 1, 3,2),fpppp(10, 1, 3,3)/
     x-1.0873802D-06,-8.9500521D-23, 7.8717290D-10 /
      data fpppp(10, 1, 4,1),fpppp(10, 1, 4,2),fpppp(10, 1, 4,3)/
     x-6.7854391D-07, 1.7158018D-21, 4.6154385D-10 /
      data fpppp(10, 1, 5,1),fpppp(10, 1, 5,2),fpppp(10, 1, 5,3)/
     x 2.3419214D-07, 1.1303235D-21,-5.2457349D-10 /
      data fpppp(10, 1, 6,1),fpppp(10, 1, 6,2),fpppp(10, 1, 6,3)/
     x 7.8191035D-07,-5.3776342D-23,-6.2763120D-10 /
      data fpppp(10, 1, 7,1),fpppp(10, 1, 7,2),fpppp(10, 1, 7,3)/
     x 5.0384026D-07, 1.8742402D-21,-2.7711931D-10 /
      data fpppp(10, 1, 8,1),fpppp(10, 1, 8,2),fpppp(10, 1, 8,3)/
     x-2.9105412D-07,-1.4745137D-21, 3.4961522D-10 /
      data fpppp(10, 1, 9,1),fpppp(10, 1, 9,2),fpppp(10, 1, 9,3)/
     x-7.0954042D-07, 4.2383195D-22, 4.7384834D-10 /
      data fpppp(10, 1,10,1),fpppp(10, 1,10,2),fpppp(10, 1,10,3)/
     x-2.9105412D-07, 9.6337998D-22, 3.4961522D-10 /
      data fpppp(10, 1,11,1),fpppp(10, 1,11,2),fpppp(10, 1,11,3)/
     x 5.0384026D-07, 2.4935730D-21,-2.7711931D-10 /
      data fpppp(10, 1,12,1),fpppp(10, 1,12,2),fpppp(10, 1,12,3)/
     x 7.8191035D-07,-1.3563311D-21,-6.2763120D-10 /
      data fpppp(10, 1,13,1),fpppp(10, 1,13,2),fpppp(10, 1,13,3)/
     x 2.3419214D-07, 6.1458724D-22,-5.2457349D-10 /
      data fpppp(10, 1,14,1),fpppp(10, 1,14,2),fpppp(10, 1,14,3)/
     x-6.7854391D-07, 8.8306392D-22, 4.6154385D-10 /
      data fpppp(10, 1,15,1),fpppp(10, 1,15,2),fpppp(10, 1,15,3)/
     x-1.0873802D-06, 4.6254065D-22, 7.8717290D-10 /
      data fpppp(10, 1,16,1),fpppp(10, 1,16,2),fpppp(10, 1,16,3)/
     x-6.7854391D-07,-7.9128707D-22, 3.1339549D-10 /
      data fpppp(10, 1,17,1),fpppp(10, 1,17,2),fpppp(10, 1,17,3)/
     x 2.3419214D-07,-3.3058266D-22, 6.8019933D-11 /
      data fpppp(10, 2, 1,1),fpppp(10, 2, 1,2),fpppp(10, 2, 1,3)/
     x 4.1215887D-08, 6.9970487D-09,-1.9414796D-10 /
      data fpppp(10, 2, 2,1),fpppp(10, 2, 2,2),fpppp(10, 2, 2,3)/
     x-3.6613901D-07, 2.1685310D-08, 5.0536303D-11 /
      data fpppp(10, 2, 3,1),fpppp(10, 2, 3,2),fpppp(10, 2, 3,3)/
     x-6.1794581D-07, 5.2338135D-08, 6.0778645D-10 /
      data fpppp(10, 2, 4,1),fpppp(10, 2, 4,2),fpppp(10, 2, 4,3)/
     x-3.6613901D-07, 2.7114986D-08, 7.1055988D-11 /
      data fpppp(10, 2, 5,1),fpppp(10, 2, 5,2),fpppp(10, 2, 5,3)/
     x 4.1215887D-08,-1.4721655D-08,-2.7622670D-10 /
      data fpppp(10, 2, 6,1),fpppp(10, 2, 6,2),fpppp(10, 2, 6,3)/
     x 2.4411071D-07,-3.6687342D-08,-2.6405325D-10 /
      data fpppp(10, 2, 7,1),fpppp(10, 2, 7,2),fpppp(10, 2, 7,3)/
     x 1.3361758D-07,-2.6223422D-08,-4.9791779D-11 /
      data fpppp(10, 2, 8,1),fpppp(10, 2, 8,2),fpppp(10, 2, 8,3)/
     x-2.2082501D-07, 1.0207087D-08, 1.0954015D-10 /
      data fpppp(10, 2, 9,1),fpppp(10, 2, 9,2),fpppp(10, 2, 9,3)/
     x-4.1669784D-07, 2.9187504D-08, 2.1458468D-10 /
      data fpppp(10, 2,10,1),fpppp(10, 2,10,2),fpppp(10, 2,10,3)/
     x-2.2082501D-07, 1.0207087D-08, 1.0954015D-10 /
      data fpppp(10, 2,11,1),fpppp(10, 2,11,2),fpppp(10, 2,11,3)/
     x 1.3361758D-07,-2.6223422D-08,-4.9791779D-11 /
      data fpppp(10, 2,12,1),fpppp(10, 2,12,2),fpppp(10, 2,12,3)/
     x 2.4411071D-07,-3.6687342D-08,-2.6405325D-10 /
      data fpppp(10, 2,13,1),fpppp(10, 2,13,2),fpppp(10, 2,13,3)/
     x 4.1215887D-08,-1.4721655D-08,-2.7622670D-10 /
      data fpppp(10, 2,14,1),fpppp(10, 2,14,2),fpppp(10, 2,14,3)/
     x-3.6613901D-07, 2.7114986D-08, 7.1055988D-11 /
      data fpppp(10, 2,15,1),fpppp(10, 2,15,2),fpppp(10, 2,15,3)/
     x-6.1794581D-07, 5.2338135D-08, 6.0778645D-10 /
      data fpppp(10, 2,16,1),fpppp(10, 2,16,2),fpppp(10, 2,16,3)/
     x-3.6613901D-07, 2.1685310D-08, 5.0536303D-11 /
      data fpppp(10, 2,17,1),fpppp(10, 2,17,2),fpppp(10, 2,17,3)/
     x 4.1215887D-08, 6.9970487D-09,-1.9414796D-10 /
      data fpppp(10, 3, 1,1),fpppp(10, 3, 1,2),fpppp(10, 3, 1,3)/
     x-2.3251038D-07,-7.1066205D-09,-5.7810030D-10 /
      data fpppp(10, 3, 2,1),fpppp(10, 3, 2,2),fpppp(10, 3, 2,3)/
     x-1.2570851D-07, 5.3118175D-08,-2.4219633D-10 /
      data fpppp(10, 3, 3,1),fpppp(10, 3, 3,2),fpppp(10, 3, 3,3)/
     x-2.5734265D-07, 1.8541523D-07, 6.1497598D-10 /
      data fpppp(10, 3, 4,1),fpppp(10, 3, 4,2),fpppp(10, 3, 4,3)/
     x-1.2570851D-07, 6.5459374D-08,-3.5229088D-10 /
      data fpppp(10, 3, 5,1),fpppp(10, 3, 5,2),fpppp(10, 3, 5,3)/
     x-2.3251038D-07,-5.6471417D-08,-1.3772210D-10 /
      data fpppp(10, 3, 6,1),fpppp(10, 3, 6,2),fpppp(10, 3, 6,3)/
     x-3.3981413D-07,-1.0797610D-07, 1.9917680D-10 /
      data fpppp(10, 3, 7,1),fpppp(10, 3, 7,2),fpppp(10, 3, 7,3)/
     x-2.0299561D-07,-9.0926157D-08, 1.4215842D-10 /
      data fpppp(10, 3, 8,1),fpppp(10, 3, 8,2),fpppp(10, 3, 8,3)/
     x-8.2237476D-08, 4.1301454D-08,-8.6596385D-11 /
      data fpppp(10, 3, 9,1),fpppp(10, 3, 9,2),fpppp(10, 3, 9,3)/
     x-6.7107279D-08, 1.1386734D-07,-1.6277679D-10 /
      data fpppp(10, 3,10,1),fpppp(10, 3,10,2),fpppp(10, 3,10,3)/
     x-8.2237476D-08, 4.1301454D-08,-8.6596385D-11 /
      data fpppp(10, 3,11,1),fpppp(10, 3,11,2),fpppp(10, 3,11,3)/
     x-2.0299561D-07,-9.0926157D-08, 1.4215842D-10 /
      data fpppp(10, 3,12,1),fpppp(10, 3,12,2),fpppp(10, 3,12,3)/
     x-3.3981413D-07,-1.0797610D-07, 1.9917680D-10 /
      data fpppp(10, 3,13,1),fpppp(10, 3,13,2),fpppp(10, 3,13,3)/
     x-2.3251038D-07,-5.6471417D-08,-1.3772210D-10 /
      data fpppp(10, 3,14,1),fpppp(10, 3,14,2),fpppp(10, 3,14,3)/
     x-1.2570851D-07, 6.5459374D-08,-3.5229088D-10 /
      data fpppp(10, 3,15,1),fpppp(10, 3,15,2),fpppp(10, 3,15,3)/
     x-2.5734265D-07, 1.8541523D-07, 6.1497598D-10 /
      data fpppp(10, 3,16,1),fpppp(10, 3,16,2),fpppp(10, 3,16,3)/
     x-1.2570851D-07, 5.3118175D-08,-2.4219633D-10 /
      data fpppp(10, 3,17,1),fpppp(10, 3,17,2),fpppp(10, 3,17,3)/
     x-2.3251038D-07,-7.1066205D-09,-5.7810030D-10 /
      data fpppp(10, 4, 1,1),fpppp(10, 4, 1,2),fpppp(10, 4, 1,3)/
     x-2.2361161D-07,-8.8073032D-08,-5.3580705D-10 /
      data fpppp(10, 4, 2,1),fpppp(10, 4, 2,2),fpppp(10, 4, 2,3)/
     x 3.6663237D-07, 5.1651751D-08,-4.3037193D-10 /
      data fpppp(10, 4, 3,1),fpppp(10, 4, 3,2),fpppp(10, 4, 3,3)/
     x 4.8416966D-07, 3.7574081D-07,-3.0850431D-11 /
      data fpppp(10, 4, 4,1),fpppp(10, 4, 4,2),fpppp(10, 4, 4,3)/
     x 3.6663237D-07, 5.4554897D-08,-6.6063124D-10 /
      data fpppp(10, 4, 5,1),fpppp(10, 4, 5,2),fpppp(10, 4, 5,3)/
     x-2.2361161D-07,-9.9685616D-08, 3.8523017D-10 /
      data fpppp(10, 4, 6,1),fpppp(10, 4, 6,2),fpppp(10, 4, 6,3)/
     x-7.6230079D-07,-1.4137078D-07, 3.1362448D-10 /
      data fpppp(10, 4, 7,1),fpppp(10, 4, 7,2),fpppp(10, 4, 7,3)/
     x-6.5724199D-07,-1.6053535D-07, 4.5792928D-10 /
      data fpppp(10, 4, 8,1),fpppp(10, 4, 8,2),fpppp(10, 4, 8,3)/
     x-1.8290443D-07, 6.0915099D-08,-4.3651781D-10 /
      data fpppp(10, 4, 9,1),fpppp(10, 4, 9,2),fpppp(10, 4, 9,3)/
     x 8.3865380D-08, 1.9698654D-07,-1.2679591D-10 /
      data fpppp(10, 4,10,1),fpppp(10, 4,10,2),fpppp(10, 4,10,3)/
     x-1.8290443D-07, 6.0915099D-08,-4.3651781D-10 /
      data fpppp(10, 4,11,1),fpppp(10, 4,11,2),fpppp(10, 4,11,3)/
     x-6.5724199D-07,-1.6053535D-07, 4.5792928D-10 /
      data fpppp(10, 4,12,1),fpppp(10, 4,12,2),fpppp(10, 4,12,3)/
     x-7.6230079D-07,-1.4137078D-07, 3.1362448D-10 /
      data fpppp(10, 4,13,1),fpppp(10, 4,13,2),fpppp(10, 4,13,3)/
     x-2.2361161D-07,-9.9685616D-08, 3.8523017D-10 /
      data fpppp(10, 4,14,1),fpppp(10, 4,14,2),fpppp(10, 4,14,3)/
     x 3.6663237D-07, 5.4554897D-08,-6.6063124D-10 /
      data fpppp(10, 4,15,1),fpppp(10, 4,15,2),fpppp(10, 4,15,3)/
     x 4.8416966D-07, 3.7574081D-07,-3.0850431D-11 /
      data fpppp(10, 4,16,1),fpppp(10, 4,16,2),fpppp(10, 4,16,3)/
     x 3.6663237D-07, 5.1651751D-08,-4.3037193D-10 /
      data fpppp(10, 4,17,1),fpppp(10, 4,17,2),fpppp(10, 4,17,3)/
     x-2.2361161D-07,-8.8073032D-08,-5.3580705D-10 /
      data fpppp(10, 5, 1,1),fpppp(10, 5, 1,2),fpppp(10, 5, 1,3)/
     x-3.6252540D-07,-2.3069896D-07, 4.0932700D-10 /
      data fpppp(10, 5, 2,1),fpppp(10, 5, 2,2),fpppp(10, 5, 2,3)/
     x 7.3624697D-07,-3.3953049D-09,-8.5646268D-11 /
      data fpppp(10, 5, 3,1),fpppp(10, 5, 3,2),fpppp(10, 5, 3,3)/
     x 1.3177507D-06, 5.4798940D-07,-1.2222515D-09 /
      data fpppp(10, 5, 4,1),fpppp(10, 5, 4,2),fpppp(10, 5, 4,3)/
     x 7.3624697D-07,-3.4909561D-08,-1.1314483D-10 /
      data fpppp(10, 5, 5,1),fpppp(10, 5, 5,2),fpppp(10, 5, 5,3)/
     x-3.6252540D-07,-1.0464194D-07, 5.1932124D-10 /
      data fpppp(10, 5, 6,1),fpppp(10, 5, 6,2),fpppp(10, 5, 6,3)/
     x-4.4704223D-07,-1.1368446D-07, 3.2420655D-10 /
      data fpppp(10, 5, 7,1),fpppp(10, 5, 7,2),fpppp(10, 5, 7,3)/
     x-4.1931734D-07,-1.8702019D-07, 1.9207949D-10 /
      data fpppp(10, 5, 8,1),fpppp(10, 5, 8,2),fpppp(10, 5, 8,3)/
     x-1.5689164D-08, 5.1056785D-08,-2.4903383D-10 /
      data fpppp(10, 5, 9,1),fpppp(10, 5, 9,2),fpppp(10, 5, 9,3)/
     x 1.5642739D-07, 2.2515695D-07,-1.2918884D-10 /
      data fpppp(10, 5,10,1),fpppp(10, 5,10,2),fpppp(10, 5,10,3)/
     x-1.5689164D-08, 5.1056785D-08,-2.4903383D-10 /
      data fpppp(10, 5,11,1),fpppp(10, 5,11,2),fpppp(10, 5,11,3)/
     x-4.1931734D-07,-1.8702019D-07, 1.9207949D-10 /
      data fpppp(10, 5,12,1),fpppp(10, 5,12,2),fpppp(10, 5,12,3)/
     x-4.4704223D-07,-1.1368446D-07, 3.2420655D-10 /
      data fpppp(10, 5,13,1),fpppp(10, 5,13,2),fpppp(10, 5,13,3)/
     x-3.6252540D-07,-1.0464194D-07, 5.1932124D-10 /
      data fpppp(10, 5,14,1),fpppp(10, 5,14,2),fpppp(10, 5,14,3)/
     x 7.3624697D-07,-3.4909561D-08,-1.1314483D-10 /
      data fpppp(10, 5,15,1),fpppp(10, 5,15,2),fpppp(10, 5,15,3)/
     x 1.3177507D-06, 5.4798940D-07,-1.2222515D-09 /
      data fpppp(10, 5,16,1),fpppp(10, 5,16,2),fpppp(10, 5,16,3)/
     x 7.3624697D-07,-3.3953049D-09,-8.5646268D-11 /
      data fpppp(10, 5,17,1),fpppp(10, 5,17,2),fpppp(10, 5,17,3)/
     x-3.6252540D-07,-2.3069896D-07, 4.0932700D-10 /
      data fpppp(10, 6, 1,1),fpppp(10, 6, 1,2),fpppp(10, 6, 1,3)/
     x 4.9947982D-07,-3.2782096D-07, 1.1541184D-09 /
      data fpppp(10, 6, 2,1),fpppp(10, 6, 2,2),fpppp(10, 6, 2,3)/
     x 4.9028032D-07,-7.8669786D-08, 3.6838492D-10 /
      data fpppp(10, 6, 3,1),fpppp(10, 6, 3,2),fpppp(10, 6, 3,3)/
     x 1.2359297D-06, 5.5709570D-07,-1.6374746D-09 /
      data fpppp(10, 6, 4,1),fpppp(10, 6, 4,2),fpppp(10, 6, 4,3)/
     x 4.9028032D-07,-1.6028890D-07, 6.2710680D-10 /
      data fpppp(10, 6, 5,1),fpppp(10, 6, 5,2),fpppp(10, 6, 5,3)/
     x 4.9947982D-07,-1.3445128D-09, 1.1923089D-10 /
      data fpppp(10, 6, 6,1),fpppp(10, 6, 6,2),fpppp(10, 6, 6,3)/
     x 1.7836244D-08,-8.1127796D-08, 3.4866893D-10 /
      data fpppp(10, 6, 7,1),fpppp(10, 6, 7,2),fpppp(10, 6, 7,3)/
     x 1.0095428D-07,-1.5707607D-07,-4.4447177D-10 /
      data fpppp(10, 6, 8,1),fpppp(10, 6, 8,2),fpppp(10, 6, 8,3)/
     x 7.3205466D-08, 6.3928446D-09, 2.6643156D-10 /
      data fpppp(10, 6, 9,1),fpppp(10, 6, 9,2),fpppp(10, 6, 9,3)/
     x 9.9692738D-08, 2.1618998D-07,-1.5333796D-10 /
      data fpppp(10, 6,10,1),fpppp(10, 6,10,2),fpppp(10, 6,10,3)/
     x 7.3205466D-08, 6.3928446D-09, 2.6643156D-10 /
      data fpppp(10, 6,11,1),fpppp(10, 6,11,2),fpppp(10, 6,11,3)/
     x 1.0095428D-07,-1.5707607D-07,-4.4447177D-10 /
      data fpppp(10, 6,12,1),fpppp(10, 6,12,2),fpppp(10, 6,12,3)/
     x 1.7836244D-08,-8.1127796D-08, 3.4866893D-10 /
      data fpppp(10, 6,13,1),fpppp(10, 6,13,2),fpppp(10, 6,13,3)/
     x 4.9947982D-07,-1.3445128D-09, 1.1923089D-10 /
      data fpppp(10, 6,14,1),fpppp(10, 6,14,2),fpppp(10, 6,14,3)/
     x 4.9028032D-07,-1.6028890D-07, 6.2710680D-10 /
      data fpppp(10, 6,15,1),fpppp(10, 6,15,2),fpppp(10, 6,15,3)/
     x 1.2359297D-06, 5.5709570D-07,-1.6374746D-09 /
      data fpppp(10, 6,16,1),fpppp(10, 6,16,2),fpppp(10, 6,16,3)/
     x 4.9028032D-07,-7.8669786D-08, 3.6838492D-10 /
      data fpppp(10, 6,17,1),fpppp(10, 6,17,2),fpppp(10, 6,17,3)/
     x 4.9947982D-07,-3.2782096D-07, 1.1541184D-09 /
      data fpppp(10, 7, 1,1),fpppp(10, 7, 1,2),fpppp(10, 7, 1,3)/
     x-1.2440551D-07,-2.2472056D-07, 1.0243079D-09 /
      data fpppp(10, 7, 2,1),fpppp(10, 7, 2,2),fpppp(10, 7, 2,3)/
     x-1.2766160D-07,-7.4951896D-08, 4.9188937D-10 /
      data fpppp(10, 7, 3,1),fpppp(10, 7, 3,2),fpppp(10, 7, 3,3)/
     x-2.2696303D-07, 3.1735252D-07,-9.5708995D-10 /
      data fpppp(10, 7, 4,1),fpppp(10, 7, 4,2),fpppp(10, 7, 4,3)/
     x-1.2766160D-07,-1.3921818D-07, 8.0189362D-10 /
      data fpppp(10, 7, 5,1),fpppp(10, 7, 5,2),fpppp(10, 7, 5,3)/
     x-1.2440551D-07, 3.2344575D-08,-2.1570910D-10 /
      data fpppp(10, 7, 6,1),fpppp(10, 7, 6,2),fpppp(10, 7, 6,3)/
     x 2.8083030D-07, 2.2619136D-08, 1.2179887D-10 /
      data fpppp(10, 7, 7,1),fpppp(10, 7, 7,2),fpppp(10, 7, 7,3)/
     x 7.6390849D-08,-1.4654994D-07,-7.1745272D-10 /
      data fpppp(10, 7, 8,1),fpppp(10, 7, 8,2),fpppp(10, 7, 8,3)/
     x-3.1587314D-08,-2.8578619D-08, 5.5566769D-10 /
      data fpppp(10, 7, 9,1),fpppp(10, 7, 9,2),fpppp(10, 7, 9,3)/
     x-9.9515679D-08, 1.9070249D-07,-8.3639379D-11 /
      data fpppp(10, 7,10,1),fpppp(10, 7,10,2),fpppp(10, 7,10,3)/
     x-3.1587314D-08,-2.8578619D-08, 5.5566769D-10 /
      data fpppp(10, 7,11,1),fpppp(10, 7,11,2),fpppp(10, 7,11,3)/
     x 7.6390849D-08,-1.4654994D-07,-7.1745272D-10 /
      data fpppp(10, 7,12,1),fpppp(10, 7,12,2),fpppp(10, 7,12,3)/
     x 2.8083030D-07, 2.2619136D-08, 1.2179887D-10 /
      data fpppp(10, 7,13,1),fpppp(10, 7,13,2),fpppp(10, 7,13,3)/
     x-1.2440551D-07, 3.2344575D-08,-2.1570910D-10 /
      data fpppp(10, 7,14,1),fpppp(10, 7,14,2),fpppp(10, 7,14,3)/
     x-1.2766160D-07,-1.3921818D-07, 8.0189362D-10 /
      data fpppp(10, 7,15,1),fpppp(10, 7,15,2),fpppp(10, 7,15,3)/
     x-2.2696303D-07, 3.1735252D-07,-9.5708995D-10 /
      data fpppp(10, 7,16,1),fpppp(10, 7,16,2),fpppp(10, 7,16,3)/
     x-1.2766160D-07,-7.4951896D-08, 4.9188937D-10 /
      data fpppp(10, 7,17,1),fpppp(10, 7,17,2),fpppp(10, 7,17,3)/
     x-1.2440551D-07,-2.2472056D-07, 1.0243079D-09 /
      data fpppp(10, 8, 1,1),fpppp(10, 8, 1,2),fpppp(10, 8, 1,3)/
     x 1.7469415D-07,-9.7933526D-08,-3.8639308D-10 /
      data fpppp(10, 8, 2,1),fpppp(10, 8, 2,2),fpppp(10, 8, 2,3)/
     x-5.7282588D-07,-5.6191240D-08,-3.2522752D-11 /
      data fpppp(10, 8, 3,1),fpppp(10, 8, 3,2),fpppp(10, 8, 3,3)/
     x-9.7440887D-07, 7.3374372D-08, 8.6719891D-10 /
      data fpppp(10, 8, 4,1),fpppp(10, 8, 4,2),fpppp(10, 8, 4,3)/
     x-5.7282588D-07,-1.0444166D-07,-1.4355911D-10 /
      data fpppp(10, 8, 5,1),fpppp(10, 8, 5,2),fpppp(10, 8, 5,3)/
     x 1.7469415D-07, 9.5068155D-08, 5.7752333D-11 /
      data fpppp(10, 8, 6,1),fpppp(10, 8, 6,2),fpppp(10, 8, 6,3)/
     x 3.1579677D-07, 5.3262118D-08,-6.6357385D-10 /
      data fpppp(10, 8, 7,1),fpppp(10, 8, 7,2),fpppp(10, 8, 7,3)/
     x 1.2961068D-07,-1.1722340D-07, 1.5097366D-10 /
      data fpppp(10, 8, 8,1),fpppp(10, 8, 8,2),fpppp(10, 8, 8,3)/
     x-2.4963752D-07,-5.6545958D-08,-4.8156900D-11 /
      data fpppp(10, 8, 9,1),fpppp(10, 8, 9,2),fpppp(10, 8, 9,3)/
     x-3.0379539D-07, 1.7834538D-07, 4.0742276D-10 /
      data fpppp(10, 8,10,1),fpppp(10, 8,10,2),fpppp(10, 8,10,3)/
     x-2.4963752D-07,-5.6545958D-08,-4.8156900D-11 /
      data fpppp(10, 8,11,1),fpppp(10, 8,11,2),fpppp(10, 8,11,3)/
     x 1.2961068D-07,-1.1722340D-07, 1.5097366D-10 /
      data fpppp(10, 8,12,1),fpppp(10, 8,12,2),fpppp(10, 8,12,3)/
     x 3.1579677D-07, 5.3262118D-08,-6.6357385D-10 /
      data fpppp(10, 8,13,1),fpppp(10, 8,13,2),fpppp(10, 8,13,3)/
     x 1.7469415D-07, 9.5068155D-08, 5.7752333D-11 /
      data fpppp(10, 8,14,1),fpppp(10, 8,14,2),fpppp(10, 8,14,3)/
     x-5.7282588D-07,-1.0444166D-07,-1.4355911D-10 /
      data fpppp(10, 8,15,1),fpppp(10, 8,15,2),fpppp(10, 8,15,3)/
     x-9.7440887D-07, 7.3374372D-08, 8.6719891D-10 /
      data fpppp(10, 8,16,1),fpppp(10, 8,16,2),fpppp(10, 8,16,3)/
     x-5.7282588D-07,-5.6191240D-08,-3.2522752D-11 /
      data fpppp(10, 8,17,1),fpppp(10, 8,17,2),fpppp(10, 8,17,3)/
     x 1.7469415D-07,-9.7933526D-08,-3.8639308D-10 /
      data fpppp(10, 9, 1,1),fpppp(10, 9, 1,2),fpppp(10, 9, 1,3)/
     x 2.5706397D-08, 9.1738980D-09,-5.4102691D-10 /
      data fpppp(10, 9, 2,1),fpppp(10, 9, 2,2),fpppp(10, 9, 2,3)/
     x-5.6230420D-07,-1.7777493D-08,-7.7215643D-11 /
      data fpppp(10, 9, 3,1),fpppp(10, 9, 3,2),fpppp(10, 9, 3,3)/
     x-9.6454475D-07,-6.5817318D-08, 1.0922548D-09 /
      data fpppp(10, 9, 4,1),fpppp(10, 9, 4,2),fpppp(10, 9, 4,3)/
     x-5.6230420D-07,-4.0047622D-08,-2.0808184D-10 /
      data fpppp(10, 9, 5,1),fpppp(10, 9, 5,2),fpppp(10, 9, 5,3)/
     x 2.5706397D-08, 9.8254417D-08,-1.7562138D-11 /
      data fpppp(10, 9, 6,1),fpppp(10, 9, 6,2),fpppp(10, 9, 6,3)/
     x 3.2755390D-07, 3.5786516D-08,-7.1803119D-10 /
      data fpppp(10, 9, 7,1),fpppp(10, 9, 7,2),fpppp(10, 9, 7,3)/
     x 6.9749663D-08,-1.1127208D-07, 2.3793094D-10 /
      data fpppp(10, 9, 8,1),fpppp(10, 9, 8,2),fpppp(10, 9, 8,3)/
     x-3.3837379D-07,-3.4683432D-08, 2.9996235D-11 /
      data fpppp(10, 9, 9,1),fpppp(10, 9, 9,2),fpppp(10, 9, 9,3)/
     x-5.0303436D-07, 1.6603003D-07, 2.3743018D-10 /
      data fpppp(10, 9,10,1),fpppp(10, 9,10,2),fpppp(10, 9,10,3)/
     x-3.3837379D-07,-3.4683432D-08, 2.9996235D-11 /
      data fpppp(10, 9,11,1),fpppp(10, 9,11,2),fpppp(10, 9,11,3)/
     x 6.9749663D-08,-1.1127208D-07, 2.3793094D-10 /
      data fpppp(10, 9,12,1),fpppp(10, 9,12,2),fpppp(10, 9,12,3)/
     x 3.2755390D-07, 3.5786516D-08,-7.1803119D-10 /
      data fpppp(10, 9,13,1),fpppp(10, 9,13,2),fpppp(10, 9,13,3)/
     x 2.5706397D-08, 9.8254417D-08,-1.7562138D-11 /
      data fpppp(10, 9,14,1),fpppp(10, 9,14,2),fpppp(10, 9,14,3)/
     x-5.6230420D-07,-4.0047622D-08,-2.0808184D-10 /
      data fpppp(10, 9,15,1),fpppp(10, 9,15,2),fpppp(10, 9,15,3)/
     x-9.6454475D-07,-6.5817318D-08, 1.0922548D-09 /
      data fpppp(10, 9,16,1),fpppp(10, 9,16,2),fpppp(10, 9,16,3)/
     x-5.6230420D-07,-1.7777493D-08,-7.7215643D-11 /
      data fpppp(10, 9,17,1),fpppp(10, 9,17,2),fpppp(10, 9,17,3)/
     x 2.5706397D-08, 9.1738980D-09,-5.4102691D-10 /
      data fpppp(10,10, 1,1),fpppp(10,10, 1,2),fpppp(10,10, 1,3)/
     x 4.7534521D-08, 8.2433381D-08,-1.0670923D-10 /
      data fpppp(10,10, 2,1),fpppp(10,10, 2,2),fpppp(10,10, 2,3)/
     x-4.5064263D-07, 3.3844917D-08, 1.0913856D-10 /
      data fpppp(10,10, 3,1),fpppp(10,10, 3,2),fpppp(10,10, 3,3)/
     x-7.6576500D-07,-8.2654375D-08, 5.8997901D-10 /
      data fpppp(10,10, 4,1),fpppp(10,10, 4,2),fpppp(10,10, 4,3)/
     x-4.5064263D-07, 3.8534229D-08, 1.4334513D-10 /
      data fpppp(10,10, 5,1),fpppp(10,10, 5,2),fpppp(10,10, 5,3)/
     x 4.7534521D-08, 6.3676131D-08,-2.4353553D-10 /
      data fpppp(10,10, 6,1),fpppp(10,10, 6,2),fpppp(10,10, 6,3)/
     x 3.7230764D-07,-5.8649134D-08,-4.8763308D-10 /
      data fpppp(10,10, 7,1),fpppp(10,10, 7,2),fpppp(10,10, 7,3)/
     x 1.8708429D-08,-1.2019024D-07, 6.6611239D-12 /
      data fpppp(10,10, 8,1),fpppp(10,10, 8,2),fpppp(10,10, 8,3)/
     x-4.1295681D-07, 2.6683193D-08, 2.3406952D-10 /
      data fpppp(10,10, 9,1),fpppp(10,10, 9,2),fpppp(10,10, 9,3)/
     x-5.8872563D-07, 1.8332758D-07, 1.0990774D-10 /
      data fpppp(10,10,10,1),fpppp(10,10,10,2),fpppp(10,10,10,3)/
     x-4.1295681D-07, 2.6683193D-08, 2.3406952D-10 /
      data fpppp(10,10,11,1),fpppp(10,10,11,2),fpppp(10,10,11,3)/
     x 1.8708429D-08,-1.2019024D-07, 6.6611239D-12 /
      data fpppp(10,10,12,1),fpppp(10,10,12,2),fpppp(10,10,12,3)/
     x 3.7230764D-07,-5.8649134D-08,-4.8763308D-10 /
      data fpppp(10,10,13,1),fpppp(10,10,13,2),fpppp(10,10,13,3)/
     x 4.7534521D-08, 6.3676131D-08,-2.4353553D-10 /
      data fpppp(10,10,14,1),fpppp(10,10,14,2),fpppp(10,10,14,3)/
     x-4.5064263D-07, 3.8534229D-08, 1.4334513D-10 /
      data fpppp(10,10,15,1),fpppp(10,10,15,2),fpppp(10,10,15,3)/
     x-7.6576500D-07,-8.2654375D-08, 5.8997901D-10 /
      data fpppp(10,10,16,1),fpppp(10,10,16,2),fpppp(10,10,16,3)/
     x-4.5064263D-07, 3.3844917D-08, 1.0913856D-10 /
      data fpppp(10,10,17,1),fpppp(10,10,17,2),fpppp(10,10,17,3)/
     x 4.7534521D-08, 8.2433381D-08,-1.0670923D-10 /
      data fpppp(10,11, 1,1),fpppp(10,11, 1,2),fpppp(10,11, 1,3)/
     x 2.2474847D-07, 1.3376746D-07, 1.0585801D-10 /
      data fpppp(10,11, 2,1),fpppp(10,11, 2,2),fpppp(10,11, 2,3)/
     x-2.5200506D-07, 9.8981933D-08, 1.9133970D-10 /
      data fpppp(10,11, 3,1),fpppp(10,11, 3,2),fpppp(10,11, 3,3)/
     x-4.6988820D-07,-8.6228091D-10, 3.2712186D-10 /
      data fpppp(10,11, 4,1),fpppp(10,11, 4,2),fpppp(10,11, 4,3)/
     x-2.5200506D-07, 1.2699891D-07, 2.8685235D-10 /
      data fpppp(10,11, 5,1),fpppp(10,11, 5,2),fpppp(10,11, 5,3)/
     x 2.2474847D-07, 2.1699559D-08,-2.7619258D-10 /
      data fpppp(10,11, 6,1),fpppp(10,11, 6,2),fpppp(10,11, 6,3)/
     x 5.0297336D-07,-2.6429756D-07,-5.1200023D-10 /
      data fpppp(10,11, 7,1),fpppp(10,11, 7,2),fpppp(10,11, 7,3)/
     x 4.7591625D-08,-1.2205323D-07, 5.5763421D-12 /
      data fpppp(10,11, 8,1),fpppp(10,11, 8,2),fpppp(10,11, 8,3)/
     x-4.0845457D-07, 1.1956988D-07, 2.9368231D-10 /
      data fpppp(10,11, 9,1),fpppp(10,11, 9,2),fpppp(10,11, 9,3)/
     x-5.6368661D-07, 2.4169664D-07, 9.2960527D-11 /
      data fpppp(10,11,10,1),fpppp(10,11,10,2),fpppp(10,11,10,3)/
     x-4.0845457D-07, 1.1956988D-07, 2.9368231D-10 /
      data fpppp(10,11,11,1),fpppp(10,11,11,2),fpppp(10,11,11,3)/
     x 4.7591625D-08,-1.2205323D-07, 5.5763421D-12 /
      data fpppp(10,11,12,1),fpppp(10,11,12,2),fpppp(10,11,12,3)/
     x 5.0297336D-07,-2.6429756D-07,-5.1200023D-10 /
      data fpppp(10,11,13,1),fpppp(10,11,13,2),fpppp(10,11,13,3)/
     x 2.2474847D-07, 2.1699559D-08,-2.7619258D-10 /
      data fpppp(10,11,14,1),fpppp(10,11,14,2),fpppp(10,11,14,3)/
     x-2.5200506D-07, 1.2699891D-07, 2.8685235D-10 /
      data fpppp(10,11,15,1),fpppp(10,11,15,2),fpppp(10,11,15,3)/
     x-4.6988820D-07,-8.6228091D-10, 3.2712186D-10 /
      data fpppp(10,11,16,1),fpppp(10,11,16,2),fpppp(10,11,16,3)/
     x-2.5200506D-07, 9.8981933D-08, 1.9133970D-10 /
      data fpppp(10,11,17,1),fpppp(10,11,17,2),fpppp(10,11,17,3)/
     x 2.2474847D-07, 1.3376746D-07, 1.0585801D-10 /
      data fpppp(10,12, 1,1),fpppp(10,12, 1,2),fpppp(10,12, 1,3)/
     x 5.2933695D-07, 1.9418830D-07, 4.6434182D-11 /
      data fpppp(10,12, 2,1),fpppp(10,12, 2,2),fpppp(10,12, 2,3)/
     x 1.4250666D-07, 1.8892867D-07, 1.3252196D-10 /
      data fpppp(10,12, 3,1),fpppp(10,12, 3,2),fpppp(10,12, 3,3)/
     x 3.5937990D-08, 1.3913727D-07, 2.7029929D-10 /
      data fpppp(10,12, 4,1),fpppp(10,12, 4,2),fpppp(10,12, 4,3)/
     x 1.4250666D-07, 2.4520705D-07, 2.2716317D-10 /
      data fpppp(10,12, 5,1),fpppp(10,12, 5,2),fpppp(10,12, 5,3)/
     x 5.2933695D-07,-3.0925220D-08,-3.3213067D-10 /
      data fpppp(10,12, 6,1),fpppp(10,12, 6,2),fpppp(10,12, 6,3)/
     x 6.8305278D-07,-5.9050029D-07,-3.4053767D-10 /
      data fpppp(10,12, 7,1),fpppp(10,12, 7,2),fpppp(10,12, 7,3)/
     x 2.1786212D-07,-1.0124025D-07, 7.6156646D-11 /
      data fpppp(10,12, 8,1),fpppp(10,12, 8,2),fpppp(10,12, 8,3)/
     x-1.4616005D-07, 2.4457870D-07, 1.6688035D-10 /
      data fpppp(10,12, 9,1),fpppp(10,12, 9,2),fpppp(10,12, 9,3)/
     x-2.8542413D-07, 3.3600248D-07, 1.5041060D-10 /
      data fpppp(10,12,10,1),fpppp(10,12,10,2),fpppp(10,12,10,3)/
     x-1.4616005D-07, 2.4457870D-07, 1.6688035D-10 /
      data fpppp(10,12,11,1),fpppp(10,12,11,2),fpppp(10,12,11,3)/
     x 2.1786212D-07,-1.0124025D-07, 7.6156646D-11 /
      data fpppp(10,12,12,1),fpppp(10,12,12,2),fpppp(10,12,12,3)/
     x 6.8305278D-07,-5.9050029D-07,-3.4053767D-10 /
      data fpppp(10,12,13,1),fpppp(10,12,13,2),fpppp(10,12,13,3)/
     x 5.2933695D-07,-3.0925220D-08,-3.3213067D-10 /
      data fpppp(10,12,14,1),fpppp(10,12,14,2),fpppp(10,12,14,3)/
     x 1.4250666D-07, 2.4520705D-07, 2.2716317D-10 /
      data fpppp(10,12,15,1),fpppp(10,12,15,2),fpppp(10,12,15,3)/
     x 3.5937990D-08, 1.3913727D-07, 2.7029929D-10 /
      data fpppp(10,12,16,1),fpppp(10,12,16,2),fpppp(10,12,16,3)/
     x 1.4250666D-07, 1.8892867D-07, 1.3252196D-10 /
      data fpppp(10,12,17,1),fpppp(10,12,17,2),fpppp(10,12,17,3)/
     x 5.2933695D-07, 1.9418830D-07, 4.6434182D-11 /
      data fpppp(10,13, 1,1),fpppp(10,13, 1,2),fpppp(10,13, 1,3)/
     x 7.4058338D-07, 2.7870895D-07,-1.9187457D-10 /
      data fpppp(10,13, 2,1),fpppp(10,13, 2,2),fpppp(10,13, 2,3)/
     x 7.4941142D-07, 3.0466352D-07,-8.0867881D-11 /
      data fpppp(10,13, 3,1),fpppp(10,13, 3,2),fpppp(10,13, 3,3)/
     x 7.1791401D-07, 3.0072808D-07, 1.6972222D-10 /
      data fpppp(10,13, 4,1),fpppp(10,13, 4,2),fpppp(10,13, 4,3)/
     x 7.4941142D-07, 4.0140767D-07,-6.8229622D-11 /
      data fpppp(10,13, 5,1),fpppp(10,13, 5,2),fpppp(10,13, 5,3)/
     x 7.4058338D-07,-1.0826767D-07,-2.4242760D-10 /
      data fpppp(10,13, 6,1),fpppp(10,13, 6,2),fpppp(10,13, 6,3)/
     x 5.1988174D-07,-1.0050315D-06, 1.7544692D-10 /
      data fpppp(10,13, 7,1),fpppp(10,13, 7,2),fpppp(10,13, 7,3)/
     x 3.8804831D-07,-4.9102945D-08, 5.1755836D-11 /
      data fpppp(10,13, 8,1),fpppp(10,13, 8,2),fpppp(10,13, 8,3)/
     x 3.4529596D-07, 3.8740647D-07,-3.0334765D-11 /
      data fpppp(10,13, 9,1),fpppp(10,13, 9,2),fpppp(10,13, 9,3)/
     x 3.1647014D-07, 4.6257185D-07, 5.9962625D-11 /
      data fpppp(10,13,10,1),fpppp(10,13,10,2),fpppp(10,13,10,3)/
     x 3.4529596D-07, 3.8740647D-07,-3.0334765D-11 /
      data fpppp(10,13,11,1),fpppp(10,13,11,2),fpppp(10,13,11,3)/
     x 3.8804831D-07,-4.9102945D-08, 5.1755836D-11 /
      data fpppp(10,13,12,1),fpppp(10,13,12,2),fpppp(10,13,12,3)/
     x 5.1988174D-07,-1.0050315D-06, 1.7544692D-10 /
      data fpppp(10,13,13,1),fpppp(10,13,13,2),fpppp(10,13,13,3)/
     x 7.4058338D-07,-1.0826767D-07,-2.4242760D-10 /
      data fpppp(10,13,14,1),fpppp(10,13,14,2),fpppp(10,13,14,3)/
     x 7.4941142D-07, 4.0140767D-07,-6.8229622D-11 /
      data fpppp(10,13,15,1),fpppp(10,13,15,2),fpppp(10,13,15,3)/
     x 7.1791401D-07, 3.0072808D-07, 1.6972222D-10 /
      data fpppp(10,13,16,1),fpppp(10,13,16,2),fpppp(10,13,16,3)/
     x 7.4941142D-07, 3.0466352D-07,-8.0867881D-11 /
      data fpppp(10,13,17,1),fpppp(10,13,17,2),fpppp(10,13,17,3)/
     x 7.4058338D-07, 2.7870895D-07,-1.9187457D-10 /
      data fpppp(10,14, 1,1),fpppp(10,14, 1,2),fpppp(10,14, 1,3)/
     x 5.5440792D-07, 3.4046589D-07,-4.8048619D-10 /
      data fpppp(10,14, 2,1),fpppp(10,14, 2,2),fpppp(10,14, 2,3)/
     x 1.4248334D-06, 4.0771346D-07,-4.1261654D-10 /
      data fpppp(10,14, 3,1),fpppp(10,14, 3,2),fpppp(10,14, 3,3)/
     x 1.5963997D-06, 4.7138894D-07,-1.7337343D-10 /
      data fpppp(10,14, 4,1),fpppp(10,14, 4,2),fpppp(10,14, 4,3)/
     x 1.4248334D-06, 5.4756677D-07,-5.3393745D-10 /
      data fpppp(10,14, 5,1),fpppp(10,14, 5,2),fpppp(10,14, 5,3)/
     x 5.5440792D-07,-2.1894734D-07, 4.7974253D-12 /
      data fpppp(10,14, 6,1),fpppp(10,14, 6,2),fpppp(10,14, 6,3)/
     x-1.8845798D-07,-1.3820667D-06, 1.0866174D-09 /
      data fpppp(10,14, 7,1),fpppp(10,14, 7,2),fpppp(10,14, 7,3)/
     x 4.3798243D-07, 9.2623630D-09, 6.2394179D-11 /
      data fpppp(10,14, 8,1),fpppp(10,14, 8,2),fpppp(10,14, 8,3)/
     x 1.0917024D-06, 5.2168984D-07,-4.3570533D-10 /
      data fpppp(10,14, 9,1),fpppp(10,14, 9,2),fpppp(10,14, 9,3)/
     x 1.2833310D-06, 5.9691001D-07,-2.1517907D-10 /
      data fpppp(10,14,10,1),fpppp(10,14,10,2),fpppp(10,14,10,3)/
     x 1.0917024D-06, 5.2168984D-07,-4.3570533D-10 /
      data fpppp(10,14,11,1),fpppp(10,14,11,2),fpppp(10,14,11,3)/
     x 4.3798243D-07, 9.2623630D-09, 6.2394179D-11 /
      data fpppp(10,14,12,1),fpppp(10,14,12,2),fpppp(10,14,12,3)/
     x-1.8845798D-07,-1.3820667D-06, 1.0866174D-09 /
      data fpppp(10,14,13,1),fpppp(10,14,13,2),fpppp(10,14,13,3)/
     x 5.5440792D-07,-2.1894734D-07, 4.7974253D-12 /
      data fpppp(10,14,14,1),fpppp(10,14,14,2),fpppp(10,14,14,3)/
     x 1.4248334D-06, 5.4756677D-07,-5.3393745D-10 /
      data fpppp(10,14,15,1),fpppp(10,14,15,2),fpppp(10,14,15,3)/
     x 1.5963997D-06, 4.7138894D-07,-1.7337343D-10 /
      data fpppp(10,14,16,1),fpppp(10,14,16,2),fpppp(10,14,16,3)/
     x 1.4248334D-06, 4.0771346D-07,-4.1261654D-10 /
      data fpppp(10,14,17,1),fpppp(10,14,17,2),fpppp(10,14,17,3)/
     x 5.5440792D-07, 3.4046589D-07,-4.8048619D-10 /
      data fpppp(10,15, 1,1),fpppp(10,15, 1,2),fpppp(10,15, 1,3)/
     x-1.8996005D-07, 3.0578689D-07,-6.2571716D-10 /
      data fpppp(10,15, 2,1),fpppp(10,15, 2,2),fpppp(10,15, 2,3)/
     x 1.5652825D-06, 4.3104724D-07,-7.2292629D-10 /
      data fpppp(10,15, 3,1),fpppp(10,15, 3,2),fpppp(10,15, 3,3)/
     x 2.1893045D-06, 6.1657456D-07,-7.5965059D-10 /
      data fpppp(10,15, 4,1),fpppp(10,15, 4,2),fpppp(10,15, 4,3)/
     x 1.5652825D-06, 5.9116746D-07,-1.0080718D-09 /
      data fpppp(10,15, 5,1),fpppp(10,15, 5,2),fpppp(10,15, 5,3)/
     x-1.8996005D-07,-3.3469400D-07, 5.1486488D-10 /
      data fpppp(10,15, 6,1),fpppp(10,15, 6,2),fpppp(10,15, 6,3)/
     x-1.2267692D-06,-1.5232979D-06, 2.0436269D-09 /
      data fpppp(10,15, 7,1),fpppp(10,15, 7,2),fpppp(10,15, 7,3)/
     x 2.7754138D-07, 3.0280257D-08,-5.5132666D-11 /
      data fpppp(10,15, 8,1),fpppp(10,15, 8,2),fpppp(10,15, 8,3)/
     x 1.8163148D-06, 5.9541023D-07,-7.7718673D-10 /
      data fpppp(10,15, 9,1),fpppp(10,15, 9,2),fpppp(10,15, 9,3)/
     x 2.3233194D-06, 6.9238003D-07,-7.2407493D-10 /
      data fpppp(10,15,10,1),fpppp(10,15,10,2),fpppp(10,15,10,3)/
     x 1.8163148D-06, 5.9541023D-07,-7.7718673D-10 /
      data fpppp(10,15,11,1),fpppp(10,15,11,2),fpppp(10,15,11,3)/
     x 2.7754138D-07, 3.0280257D-08,-5.5132666D-11 /
      data fpppp(10,15,12,1),fpppp(10,15,12,2),fpppp(10,15,12,3)/
     x-1.2267692D-06,-1.5232979D-06, 2.0436269D-09 /
      data fpppp(10,15,13,1),fpppp(10,15,13,2),fpppp(10,15,13,3)/
     x-1.8996005D-07,-3.3469400D-07, 5.1486488D-10 /
      data fpppp(10,15,14,1),fpppp(10,15,14,2),fpppp(10,15,14,3)/
     x 1.5652825D-06, 5.9116746D-07,-1.0080718D-09 /
      data fpppp(10,15,15,1),fpppp(10,15,15,2),fpppp(10,15,15,3)/
     x 2.1893045D-06, 6.1657456D-07,-7.5965059D-10 /
      data fpppp(10,15,16,1),fpppp(10,15,16,2),fpppp(10,15,16,3)/
     x 1.5652825D-06, 4.3104724D-07,-7.2292629D-10 /
      data fpppp(10,15,17,1),fpppp(10,15,17,2),fpppp(10,15,17,3)/
     x-1.8996005D-07, 3.0578689D-07,-6.2571716D-10 /
      data fpppp(10,16, 1,1),fpppp(10,16, 1,2),fpppp(10,16, 1,3)/
     x-1.0564119D-06, 1.7369541D-07, 6.8859597D-12 /
      data fpppp(10,16, 2,1),fpppp(10,16, 2,2),fpppp(10,16, 2,3)/
     x 8.4328388D-07, 3.3915763D-07,-4.5607389D-10 /
      data fpppp(10,16, 3,1),fpppp(10,16, 3,2),fpppp(10,16, 3,3)/
     x 1.7548349D-06, 6.2985660D-07,-1.3699729D-09 /
      data fpppp(10,16, 4,1),fpppp(10,16, 4,2),fpppp(10,16, 4,3)/
     x 8.4328388D-07, 4.8222699D-07,-7.0558478D-10 /
      data fpppp(10,16, 5,1),fpppp(10,16, 5,2),fpppp(10,16, 5,3)/
     x-1.0564119D-06,-3.9858201D-07, 1.0049295D-09 /
      data fpppp(10,16, 6,1),fpppp(10,16, 6,2),fpppp(10,16, 6,3)/
     x-1.8954481D-06,-1.2680945D-06, 1.4539383D-09 /
      data fpppp(10,16, 7,1),fpppp(10,16, 7,2),fpppp(10,16, 7,3)/
     x-7.4071730D-08,-9.1659643D-09, 3.0869634D-10 /
      data fpppp(10,16, 8,1),fpppp(10,16, 8,2),fpppp(10,16, 8,3)/
     x 1.8965891D-06, 5.4948750D-07,-8.9285057D-10 /
      data fpppp(10,16, 9,1),fpppp(10,16, 9,2),fpppp(10,16, 9,3)/
     x 2.6546348D-06, 6.8224423D-07,-1.0098698D-09 /
      data fpppp(10,16,10,1),fpppp(10,16,10,2),fpppp(10,16,10,3)/
     x 1.8965891D-06, 5.4948750D-07,-8.9285057D-10 /
      data fpppp(10,16,11,1),fpppp(10,16,11,2),fpppp(10,16,11,3)/
     x-7.4071730D-08,-9.1659643D-09, 3.0869634D-10 /
      data fpppp(10,16,12,1),fpppp(10,16,12,2),fpppp(10,16,12,3)/
     x-1.8954481D-06,-1.2680945D-06, 1.4539383D-09 /
      data fpppp(10,16,13,1),fpppp(10,16,13,2),fpppp(10,16,13,3)/
     x-1.0564119D-06,-3.9858201D-07, 1.0049295D-09 /
      data fpppp(10,16,14,1),fpppp(10,16,14,2),fpppp(10,16,14,3)/
     x 8.4328388D-07, 4.8222699D-07,-7.0558478D-10 /
      data fpppp(10,16,15,1),fpppp(10,16,15,2),fpppp(10,16,15,3)/
     x 1.7548349D-06, 6.2985660D-07,-1.3699729D-09 /
      data fpppp(10,16,16,1),fpppp(10,16,16,2),fpppp(10,16,16,3)/
     x 8.4328388D-07, 3.3915763D-07,-4.5607389D-10 /
      data fpppp(10,16,17,1),fpppp(10,16,17,2),fpppp(10,16,17,3)/
     x-1.0564119D-06, 1.7369541D-07, 6.8859597D-12 /
      data fpppp(10,17, 1,1),fpppp(10,17, 1,2),fpppp(10,17, 1,3)/
     x-1.4242913D-06, 2.4483487D-08, 7.2301254D-10 /
      data fpppp(10,17, 2,1),fpppp(10,17, 2,2),fpppp(10,17, 2,3)/
     x-1.0067407D-06, 1.6456406D-07, 2.9754339D-10 /
      data fpppp(10,17, 3,1),fpppp(10,17, 3,2),fpppp(10,17, 3,3)/
     x-5.4998235D-07, 4.3056474D-07,-7.2658312D-10 /
      data fpppp(10,17, 4,1),fpppp(10,17, 4,2),fpppp(10,17, 4,3)/
     x-1.0067407D-06, 2.5584505D-07, 3.4459110D-10 /
      data fpppp(10,17, 5,1),fpppp(10,17, 5,2),fpppp(10,17, 5,3)/
     x-1.4242913D-06,-3.4064047D-07, 5.3482170D-10 /
      data fpppp(10,17, 6,1),fpppp(10,17, 6,2),fpppp(10,17, 6,3)/
     x-5.2765800D-07,-6.8551717D-07,-3.3117925D-10 /
      data fpppp(10,17, 7,1),fpppp(10,17, 7,2),fpppp(10,17, 7,3)/
     x-7.2609004D-08,-6.4250057D-08, 3.9813942D-10 /
      data fpppp(10,17, 8,1),fpppp(10,17, 8,2),fpppp(10,17, 8,3)/
     x 9.5909476D-07, 3.7299298D-07,-1.7078015D-10 /
      data fpppp(10,17, 9,1),fpppp(10,17, 9,2),fpppp(10,17, 9,3)/
     x 1.5528196D-06, 5.0778809D-07,-8.1676125D-10 /
      data fpppp(10,17,10,1),fpppp(10,17,10,2),fpppp(10,17,10,3)/
     x 9.5909476D-07, 3.7299298D-07,-1.7078015D-10 /
      data fpppp(10,17,11,1),fpppp(10,17,11,2),fpppp(10,17,11,3)/
     x-7.2609004D-08,-6.4250057D-08, 3.9813942D-10 /
      data fpppp(10,17,12,1),fpppp(10,17,12,2),fpppp(10,17,12,3)/
     x-5.2765800D-07,-6.8551717D-07,-3.3117925D-10 /
      data fpppp(10,17,13,1),fpppp(10,17,13,2),fpppp(10,17,13,3)/
     x-1.4242913D-06,-3.4064047D-07, 5.3482170D-10 /
      data fpppp(10,17,14,1),fpppp(10,17,14,2),fpppp(10,17,14,3)/
     x-1.0067407D-06, 2.5584505D-07, 3.4459110D-10 /
      data fpppp(10,17,15,1),fpppp(10,17,15,2),fpppp(10,17,15,3)/
     x-5.4998235D-07, 4.3056474D-07,-7.2658312D-10 /
      data fpppp(10,17,16,1),fpppp(10,17,16,2),fpppp(10,17,16,3)/
     x-1.0067407D-06, 1.6456406D-07, 2.9754339D-10 /
      data fpppp(10,17,17,1),fpppp(10,17,17,2),fpppp(10,17,17,3)/
     x-1.4242913D-06, 2.4483487D-08, 7.2301254D-10 /
      data fpppp(10,18, 1,1),fpppp(10,18, 1,2),fpppp(10,18, 1,3)/
     x-3.3466696D-07,-4.2601354D-08, 2.9818197D-10 /
      data fpppp(10,18, 2,1),fpppp(10,18, 2,2),fpppp(10,18, 2,3)/
     x-2.5125706D-06, 1.0255399D-08, 5.8499745D-10 /
      data fpppp(10,18, 3,1),fpppp(10,18, 3,2),fpppp(10,18, 3,3)/
     x-3.3705906D-06, 1.2229175D-07, 1.1227988D-09 /
      data fpppp(10,18, 4,1),fpppp(10,18, 4,2),fpppp(10,18, 4,3)/
     x-2.5125706D-06, 2.7199513D-08, 7.8214961D-10 /
      data fpppp(10,18, 5,1),fpppp(10,18, 5,2),fpppp(10,18, 5,3)/
     x-3.3466696D-07,-1.1037781D-07,-4.9042667D-10 /
      data fpppp(10,18, 6,1),fpppp(10,18, 6,2),fpppp(10,18, 6,3)/
     x 8.6635969D-07,-1.9656982D-07,-1.3593092D-09 /
      data fpppp(10,18, 7,1),fpppp(10,18, 7,2),fpppp(10,18, 7,3)/
     x 1.9422955D-07,-2.5922243D-08,-3.5469188D-10 /
      data fpppp(10,18, 8,1),fpppp(10,18, 8,2),fpppp(10,18, 8,3)/
     x-9.2076560D-07, 1.4015174D-07, 5.3981056D-10 /
      data fpppp(10,18, 9,1),fpppp(10,18, 9,2),fpppp(10,18, 9,3)/
     x-1.3548663D-06, 2.1156952D-07, 6.7499510D-10 /
      data fpppp(10,18,10,1),fpppp(10,18,10,2),fpppp(10,18,10,3)/
     x-9.2076560D-07, 1.4015174D-07, 5.3981056D-10 /
      data fpppp(10,18,11,1),fpppp(10,18,11,2),fpppp(10,18,11,3)/
     x 1.9422955D-07,-2.5922243D-08,-3.5469188D-10 /
      data fpppp(10,18,12,1),fpppp(10,18,12,2),fpppp(10,18,12,3)/
     x 8.6635969D-07,-1.9656982D-07,-1.3593092D-09 /
      data fpppp(10,18,13,1),fpppp(10,18,13,2),fpppp(10,18,13,3)/
     x-3.3466696D-07,-1.1037781D-07,-4.9042667D-10 /
      data fpppp(10,18,14,1),fpppp(10,18,14,2),fpppp(10,18,14,3)/
     x-2.5125706D-06, 2.7199513D-08, 7.8214961D-10 /
      data fpppp(10,18,15,1),fpppp(10,18,15,2),fpppp(10,18,15,3)/
     x-3.3705906D-06, 1.2229175D-07, 1.1227988D-09 /
      data fpppp(10,18,16,1),fpppp(10,18,16,2),fpppp(10,18,16,3)/
     x-2.5125706D-06, 1.0255399D-08, 5.8499745D-10 /
      data fpppp(10,18,17,1),fpppp(10,18,17,2),fpppp(10,18,17,3)/
     x-3.3466696D-07,-4.2601354D-08, 2.9818197D-10 /
      data fpppp(10,19, 1,1),fpppp(10,19, 1,2),fpppp(10,19, 1,3)/
     x 3.3852774D-07,-4.5581622D-21, 1.9933915D-10 /
      data fpppp(10,19, 2,1),fpppp(10,19, 2,2),fpppp(10,19, 2,3)/
     x-4.1167419D-06, 3.4125696D-21, 1.0056410D-09 /
      data fpppp(10,19, 3,1),fpppp(10,19, 3,2),fpppp(10,19, 3,3)/
     x-6.0438299D-06, 9.2324444D-22, 2.6276116D-09 /
      data fpppp(10,19, 4,1),fpppp(10,19, 4,2),fpppp(10,19, 4,3)/
     x-4.1167419D-06,-1.6689648D-22, 1.3947417D-09 /
      data fpppp(10,19, 5,1),fpppp(10,19, 5,2),fpppp(10,19, 5,3)/
     x 3.3852774D-07, 1.5414347D-21,-1.3570635D-09 /
      data fpppp(10,19, 6,1),fpppp(10,19, 6,2),fpppp(10,19, 6,3)/
     x 2.2528838D-06, 1.6708786D-21,-2.6037214D-09 /
      data fpppp(10,19, 7,1),fpppp(10,19, 7,2),fpppp(10,19, 7,3)/
     x 3.8524643D-07,-5.2071819D-22,-8.6687335D-10 /
      data fpppp(10,19, 8,1),fpppp(10,19, 8,2),fpppp(10,19, 8,3)/
     x-2.5313785D-06, 1.8975020D-22, 1.2536812D-09 /
      data fpppp(10,19, 9,1),fpppp(10,19, 9,2),fpppp(10,19, 9,3)/
     x-3.7465891D-06, 2.7902226D-22, 1.7957092D-09 /
      data fpppp(10,19,10,1),fpppp(10,19,10,2),fpppp(10,19,10,3)/
     x-2.5313785D-06, 1.2148067D-21, 1.2536812D-09 /
      data fpppp(10,19,11,1),fpppp(10,19,11,2),fpppp(10,19,11,3)/
     x 3.8524643D-07,-8.4920580D-22,-8.6687335D-10 /
      data fpppp(10,19,12,1),fpppp(10,19,12,2),fpppp(10,19,12,3)/
     x 2.2528838D-06,-9.9272199D-22,-2.6037214D-09 /
      data fpppp(10,19,13,1),fpppp(10,19,13,2),fpppp(10,19,13,3)/
     x 3.3852774D-07,-1.2866144D-21,-1.3570635D-09 /
      data fpppp(10,19,14,1),fpppp(10,19,14,2),fpppp(10,19,14,3)/
     x-4.1167419D-06, 8.6834452D-22, 1.3947417D-09 /
      data fpppp(10,19,15,1),fpppp(10,19,15,2),fpppp(10,19,15,3)/
     x-6.0438299D-06,-8.3602825D-22, 2.6276116D-09 /
      data fpppp(10,19,16,1),fpppp(10,19,16,2),fpppp(10,19,16,3)/
     x-4.1167419D-06, 9.2922218D-22, 1.0056410D-09 /
      data fpppp(10,19,17,1),fpppp(10,19,17,2),fpppp(10,19,17,3)/
     x 3.3852774D-07,-1.7227152D-21, 1.9933915D-10 /
      data fpppp(11, 1, 1,1),fpppp(11, 1, 1,2),fpppp(11, 1, 1,3)/
     x-3.5205415D-08, 3.5010108D-22,-1.2084536D-11 /
      data fpppp(11, 1, 2,1),fpppp(11, 1, 2,2),fpppp(11, 1, 2,3)/
     x 1.2865368D-08, 2.1482322D-22, 1.5370042D-11 /
      data fpppp(11, 1, 3,1),fpppp(11, 1, 3,2),fpppp(11, 1, 3,3)/
     x 2.8039452D-08, 2.0134345D-23, 7.1305451D-11 /
      data fpppp(11, 1, 4,1),fpppp(11, 1, 4,2),fpppp(11, 1, 4,3)/
     x 1.2865368D-08,-4.7868621D-22, 2.7557951D-11 /
      data fpppp(11, 1, 5,1),fpppp(11, 1, 5,2),fpppp(11, 1, 5,3)/
     x-3.5205415D-08,-3.1824489D-22,-6.0836170D-11 /
      data fpppp(11, 1, 6,1),fpppp(11, 1, 6,2),fpppp(11, 1, 6,3)/
     x-8.1197983D-08, 1.2834440D-23,-4.4735538D-11 /
      data fpppp(11, 1, 7,1),fpppp(11, 1, 7,2),fpppp(11, 1, 7,3)/
     x-7.2519267D-08,-5.2016749D-22, 3.2233726D-11 /
      data fpppp(11, 1, 8,1),fpppp(11, 1, 8,2),fpppp(11, 1, 8,3)/
     x-1.4166342D-08, 4.0840827D-22, 2.8769941D-11 /
      data fpppp(11, 1, 9,1),fpppp(11, 1, 9,2),fpppp(11, 1, 9,3)/
     x 1.9471195D-08,-1.0192365D-22,-3.5253952D-11 /
      data fpppp(11, 1,10,1),fpppp(11, 1,10,2),fpppp(11, 1,10,3)/
     x-1.4166342D-08,-2.5035798D-22, 2.8769941D-11 /
      data fpppp(11, 1,11,1),fpppp(11, 1,11,2),fpppp(11, 1,11,3)/
     x-7.2519267D-08,-6.5190658D-22, 3.2233726D-11 /
      data fpppp(11, 1,12,1),fpppp(11, 1,12,2),fpppp(11, 1,12,3)/
     x-8.1197983D-08, 3.5269568D-22,-4.4735538D-11 /
      data fpppp(11, 1,13,1),fpppp(11, 1,13,2),fpppp(11, 1,13,3)/
     x-3.5205415D-08,-2.1114172D-22,-6.0836170D-11 /
      data fpppp(11, 1,14,1),fpppp(11, 1,14,2),fpppp(11, 1,14,3)/
     x 1.2865368D-08,-2.0471174D-22, 2.7557951D-11 /
      data fpppp(11, 1,15,1),fpppp(11, 1,15,2),fpppp(11, 1,15,3)/
     x 2.8039452D-08,-1.4470770D-22, 7.1305451D-11 /
      data fpppp(11, 1,16,1),fpppp(11, 1,16,2),fpppp(11, 1,16,3)/
     x 1.2865368D-08, 1.8656488D-22, 1.5370042D-11 /
      data fpppp(11, 1,17,1),fpppp(11, 1,17,2),fpppp(11, 1,17,3)/
     x-3.5205415D-08, 1.4198098D-22,-1.2084536D-11 /
      data fpppp(11, 2, 1,1),fpppp(11, 2, 1,2),fpppp(11, 2, 1,3)/
     x-8.1519406D-09,-5.4636807D-10,-1.9970288D-11 /
      data fpppp(11, 2, 2,1),fpppp(11, 2, 2,2),fpppp(11, 2, 2,3)/
     x 1.8459985D-08,-1.3322130D-09, 7.5386342D-12 /
      data fpppp(11, 2, 3,1),fpppp(11, 2, 3,2),fpppp(11, 2, 3,3)/
     x 2.8007100D-08,-3.0036360D-09, 6.1746915D-11 /
      data fpppp(11, 2, 4,1),fpppp(11, 2, 4,2),fpppp(11, 2, 4,3)/
     x 1.8459985D-08,-1.5755360D-09, 2.2507441D-11 /
      data fpppp(11, 2, 5,1),fpppp(11, 2, 5,2),fpppp(11, 2, 5,3)/
     x-8.1519406D-09, 4.2692376D-10,-7.9845516D-11 /
      data fpppp(11, 2, 6,1),fpppp(11, 2, 6,2),fpppp(11, 2, 6,3)/
     x-1.8377111D-08, 2.0974200D-09,-2.0808389D-12 /
      data fpppp(11, 2, 7,1),fpppp(11, 2, 7,2),fpppp(11, 2, 7,3)/
     x-1.8437077D-08, 2.0095250D-09, 3.6591397D-11 /
      data fpppp(11, 2, 8,1),fpppp(11, 2, 8,2),fpppp(11, 2, 8,3)/
     x 1.0942294D-08,-3.7659346D-10, 9.7766371D-12 /
      data fpppp(11, 2, 9,1),fpppp(11, 2, 9,2),fpppp(11, 2, 9,3)/
     x 2.6518689D-08,-2.2003966D-09,-3.3150355D-11 /
      data fpppp(11, 2,10,1),fpppp(11, 2,10,2),fpppp(11, 2,10,3)/
     x 1.0942294D-08,-3.7659346D-10, 9.7766371D-12 /
      data fpppp(11, 2,11,1),fpppp(11, 2,11,2),fpppp(11, 2,11,3)/
     x-1.8437077D-08, 2.0095250D-09, 3.6591397D-11 /
      data fpppp(11, 2,12,1),fpppp(11, 2,12,2),fpppp(11, 2,12,3)/
     x-1.8377111D-08, 2.0974200D-09,-2.0808389D-12 /
      data fpppp(11, 2,13,1),fpppp(11, 2,13,2),fpppp(11, 2,13,3)/
     x-8.1519406D-09, 4.2692376D-10,-7.9845516D-11 /
      data fpppp(11, 2,14,1),fpppp(11, 2,14,2),fpppp(11, 2,14,3)/
     x 1.8459985D-08,-1.5755360D-09, 2.2507441D-11 /
      data fpppp(11, 2,15,1),fpppp(11, 2,15,2),fpppp(11, 2,15,3)/
     x 2.8007100D-08,-3.0036360D-09, 6.1746915D-11 /
      data fpppp(11, 2,16,1),fpppp(11, 2,16,2),fpppp(11, 2,16,3)/
     x 1.8459985D-08,-1.3322130D-09, 7.5386342D-12 /
      data fpppp(11, 2,17,1),fpppp(11, 2,17,2),fpppp(11, 2,17,3)/
     x-8.1519406D-09,-5.4636807D-10,-1.9970288D-11 /
      data fpppp(11, 3, 1,1),fpppp(11, 3, 1,2),fpppp(11, 3, 1,3)/
     x 5.9704490D-08,-1.4890345D-09,-1.1425854D-10 /
      data fpppp(11, 3, 2,1),fpppp(11, 3, 2,2),fpppp(11, 3, 2,3)/
     x 2.3011449D-08,-3.7165203D-09,-5.3076125D-11 /
      data fpppp(11, 3, 3,1),fpppp(11, 3, 3,2),fpppp(11, 3, 3,3)/
     x 2.4039337D-08,-8.4509312D-09, 1.1813730D-10 /
      data fpppp(11, 3, 4,1),fpppp(11, 3, 4,2),fpppp(11, 3, 4,3)/
     x 2.3011449D-08,-4.4111041D-09,-9.5757819D-11 /
      data fpppp(11, 3, 5,1),fpppp(11, 3, 5,2),fpppp(11, 3, 5,3)/
     x 5.9704490D-08, 1.2893009D-09, 5.6468235D-11 /
      data fpppp(11, 3, 6,1),fpppp(11, 3, 6,2),fpppp(11, 3, 6,3)/
     x 4.4424844D-08, 5.4522309D-09,-7.3771004D-11 /
      data fpppp(11, 3, 7,1),fpppp(11, 3, 7,2),fpppp(11, 3, 7,3)/
     x 2.9337481D-08, 9.1678537D-09, 9.2470273D-11 /
      data fpppp(11, 3, 8,1),fpppp(11, 3, 8,2),fpppp(11, 3, 8,3)/
     x 2.6006325D-08,-2.6960403D-09,-2.5324943D-11 /
      data fpppp(11, 3, 9,1),fpppp(11, 3, 9,2),fpppp(11, 3, 9,3)/
     x 3.5182278D-08,-9.2693148D-09,-3.3420402D-11 /
      data fpppp(11, 3,10,1),fpppp(11, 3,10,2),fpppp(11, 3,10,3)/
     x 2.6006325D-08,-2.6960403D-09,-2.5324943D-11 /
      data fpppp(11, 3,11,1),fpppp(11, 3,11,2),fpppp(11, 3,11,3)/
     x 2.9337481D-08, 9.1678537D-09, 9.2470273D-11 /
      data fpppp(11, 3,12,1),fpppp(11, 3,12,2),fpppp(11, 3,12,3)/
     x 4.4424844D-08, 5.4522309D-09,-7.3771004D-11 /
      data fpppp(11, 3,13,1),fpppp(11, 3,13,2),fpppp(11, 3,13,3)/
     x 5.9704490D-08, 1.2893009D-09, 5.6468235D-11 /
      data fpppp(11, 3,14,1),fpppp(11, 3,14,2),fpppp(11, 3,14,3)/
     x 2.3011449D-08,-4.4111041D-09,-9.5757819D-11 /
      data fpppp(11, 3,15,1),fpppp(11, 3,15,2),fpppp(11, 3,15,3)/
     x 2.4039337D-08,-8.4509312D-09, 1.1813730D-10 /
      data fpppp(11, 3,16,1),fpppp(11, 3,16,2),fpppp(11, 3,16,3)/
     x 2.3011449D-08,-3.7165203D-09,-5.3076125D-11 /
      data fpppp(11, 3,17,1),fpppp(11, 3,17,2),fpppp(11, 3,17,3)/
     x 5.9704490D-08,-1.4890345D-09,-1.1425854D-10 /
      data fpppp(11, 4, 1,1),fpppp(11, 4, 1,2),fpppp(11, 4, 1,3)/
     x-1.5249428D-08, 1.2720934D-09, 9.3861951D-11 /
      data fpppp(11, 4, 2,1),fpppp(11, 4, 2,2),fpppp(11, 4, 2,3)/
     x 3.1213950D-08,-3.9695940D-09, 7.1050845D-11 /
      data fpppp(11, 4, 3,1),fpppp(11, 4, 3,2),fpppp(11, 4, 3,3)/
     x 3.3845513D-08,-1.6128389D-08,-5.6293536D-11 /
      data fpppp(11, 4, 4,1),fpppp(11, 4, 4,2),fpppp(11, 4, 4,3)/
     x 3.1213950D-08,-4.0773079D-09, 1.8222855D-10 /
      data fpppp(11, 4, 5,1),fpppp(11, 4, 5,2),fpppp(11, 4, 5,3)/
     x-1.5249428D-08, 1.7029490D-09,-3.5084885D-10 /
      data fpppp(11, 4, 6,1),fpppp(11, 4, 6,2),fpppp(11, 4, 6,3)/
     x 1.0729301D-07, 4.9327955D-09, 2.5474585D-10 /
      data fpppp(11, 4, 7,1),fpppp(11, 4, 7,2),fpppp(11, 4, 7,3)/
     x 9.9188750D-08, 1.8970523D-08,-3.1975068D-11 /
      data fpppp(11, 4, 8,1),fpppp(11, 4, 8,2),fpppp(11, 4, 8,3)/
     x 7.6226471D-08,-4.8734754D-09,-4.0475569D-12 /
      data fpppp(11, 4, 9,1),fpppp(11, 4, 9,2),fpppp(11, 4, 9,3)/
     x 3.8189536D-08,-1.7200532D-08,-2.5382692D-11 /
      data fpppp(11, 4,10,1),fpppp(11, 4,10,2),fpppp(11, 4,10,3)/
     x 7.6226471D-08,-4.8734754D-09,-4.0475569D-12 /
      data fpppp(11, 4,11,1),fpppp(11, 4,11,2),fpppp(11, 4,11,3)/
     x 9.9188750D-08, 1.8970523D-08,-3.1975068D-11 /
      data fpppp(11, 4,12,1),fpppp(11, 4,12,2),fpppp(11, 4,12,3)/
     x 1.0729301D-07, 4.9327955D-09, 2.5474585D-10 /
      data fpppp(11, 4,13,1),fpppp(11, 4,13,2),fpppp(11, 4,13,3)/
     x-1.5249428D-08, 1.7029490D-09,-3.5084885D-10 /
      data fpppp(11, 4,14,1),fpppp(11, 4,14,2),fpppp(11, 4,14,3)/
     x 3.1213950D-08,-4.0773079D-09, 1.8222855D-10 /
      data fpppp(11, 4,15,1),fpppp(11, 4,15,2),fpppp(11, 4,15,3)/
     x 3.3845513D-08,-1.6128389D-08,-5.6293536D-11 /
      data fpppp(11, 4,16,1),fpppp(11, 4,16,2),fpppp(11, 4,16,3)/
     x 3.1213950D-08,-3.9695940D-09, 7.1050845D-11 /
      data fpppp(11, 4,17,1),fpppp(11, 4,17,2),fpppp(11, 4,17,3)/
     x-1.5249428D-08, 1.2720934D-09, 9.3861951D-11 /
      data fpppp(11, 5, 1,1),fpppp(11, 5, 1,2),fpppp(11, 5, 1,3)/
     x 3.3802376D-07, 1.0094693D-08,-6.1251352D-10 /
      data fpppp(11, 5, 2,1),fpppp(11, 5, 2,2),fpppp(11, 5, 2,3)/
     x-1.1523016D-08,-1.5982361D-10,-4.4847875D-10 /
      data fpppp(11, 5, 3,1),fpppp(11, 5, 3,2),fpppp(11, 5, 3,3)/
     x-3.7288157D-08,-2.5432549D-08, 2.8776709D-10 /
      data fpppp(11, 5, 4,1),fpppp(11, 5, 4,2),fpppp(11, 5, 4,3)/
     x-1.1523016D-08, 1.8584564D-09,-9.7872583D-10 /
      data fpppp(11, 5, 5,1),fpppp(11, 5, 5,2),fpppp(11, 5, 5,3)/
     x 3.3802376D-07, 2.0215733D-09, 1.5084748D-09 /
      data fpppp(11, 5, 6,1),fpppp(11, 5, 6,2),fpppp(11, 5, 6,3)/
     x 5.5352626D-08,-1.7159940D-09,-8.8583343D-10 /
      data fpppp(11, 5, 7,1),fpppp(11, 5, 7,2),fpppp(11, 5, 7,3)/
     x 7.0176336D-08, 2.8396779D-08, 2.3636642D-10 /
      data fpppp(11, 5, 8,1),fpppp(11, 5, 8,2),fpppp(11, 5, 8,3)/
     x 3.4685735D-08,-1.0303702D-08,-1.0160952D-10 /
      data fpppp(11, 5, 9,1),fpppp(11, 5, 9,2),fpppp(11, 5, 9,3)/
     x 1.9976512D-08,-1.4745296D-08, 6.6513517D-11 /
      data fpppp(11, 5,10,1),fpppp(11, 5,10,2),fpppp(11, 5,10,3)/
     x 3.4685735D-08,-1.0303702D-08,-1.0160952D-10 /
      data fpppp(11, 5,11,1),fpppp(11, 5,11,2),fpppp(11, 5,11,3)/
     x 7.0176336D-08, 2.8396779D-08, 2.3636642D-10 /
      data fpppp(11, 5,12,1),fpppp(11, 5,12,2),fpppp(11, 5,12,3)/
     x 5.5352626D-08,-1.7159940D-09,-8.8583343D-10 /
      data fpppp(11, 5,13,1),fpppp(11, 5,13,2),fpppp(11, 5,13,3)/
     x 3.3802376D-07, 2.0215733D-09, 1.5084748D-09 /
      data fpppp(11, 5,14,1),fpppp(11, 5,14,2),fpppp(11, 5,14,3)/
     x-1.1523016D-08, 1.8584564D-09,-9.7872583D-10 /
      data fpppp(11, 5,15,1),fpppp(11, 5,15,2),fpppp(11, 5,15,3)/
     x-3.7288157D-08,-2.5432549D-08, 2.8776709D-10 /
      data fpppp(11, 5,16,1),fpppp(11, 5,16,2),fpppp(11, 5,16,3)/
     x-1.1523016D-08,-1.5982361D-10,-4.4847875D-10 /
      data fpppp(11, 5,17,1),fpppp(11, 5,17,2),fpppp(11, 5,17,3)/
     x 3.3802376D-07, 1.0094693D-08,-6.1251352D-10 /
      data fpppp(11, 6, 1,1),fpppp(11, 6, 1,2),fpppp(11, 6, 1,3)/
     x-4.8251979D-07, 3.7644946D-08, 1.1147709D-09 /
      data fpppp(11, 6, 2,1),fpppp(11, 6, 2,2),fpppp(11, 6, 2,3)/
     x-3.0365786D-08, 1.9705332D-08, 7.2570658D-10 /
      data fpppp(11, 6, 3,1),fpppp(11, 6, 3,2),fpppp(11, 6, 3,3)/
     x-1.0863360D-07,-3.7588912D-08,-7.4472326D-10 /
      data fpppp(11, 6, 4,1),fpppp(11, 6, 4,2),fpppp(11, 6, 4,3)/
     x-3.0365786D-08, 4.2858046D-08, 1.5696262D-09 /
      data fpppp(11, 6, 5,1),fpppp(11, 6, 5,2),fpppp(11, 6, 5,3)/
     x-4.8251979D-07,-5.4965913D-08,-2.2609075D-09 /
      data fpppp(11, 6, 6,1),fpppp(11, 6, 6,2),fpppp(11, 6, 6,3)/
     x-1.3363821D-08, 2.5956293D-08, 1.5230650D-09 /
      data fpppp(11, 6, 7,1),fpppp(11, 6, 7,2),fpppp(11, 6, 7,3)/
     x-2.1837635D-08, 2.2478496D-08,-5.5354217D-10 /
      data fpppp(11, 6, 8,1),fpppp(11, 6, 8,2),fpppp(11, 6, 8,3)/
     x-1.1800174D-08,-1.0632844D-08, 1.7621466D-10 /
      data fpppp(11, 6, 9,1),fpppp(11, 6, 9,2),fpppp(11, 6, 9,3)/
     x-3.1289591D-09,-9.9404582D-09,-2.3535882D-11 /
      data fpppp(11, 6,10,1),fpppp(11, 6,10,2),fpppp(11, 6,10,3)/
     x-1.1800174D-08,-1.0632844D-08, 1.7621466D-10 /
      data fpppp(11, 6,11,1),fpppp(11, 6,11,2),fpppp(11, 6,11,3)/
     x-2.1837635D-08, 2.2478496D-08,-5.5354217D-10 /
      data fpppp(11, 6,12,1),fpppp(11, 6,12,2),fpppp(11, 6,12,3)/
     x-1.3363821D-08, 2.5956293D-08, 1.5230650D-09 /
      data fpppp(11, 6,13,1),fpppp(11, 6,13,2),fpppp(11, 6,13,3)/
     x-4.8251979D-07,-5.4965913D-08,-2.2609075D-09 /
      data fpppp(11, 6,14,1),fpppp(11, 6,14,2),fpppp(11, 6,14,3)/
     x-3.0365786D-08, 4.2858046D-08, 1.5696262D-09 /
      data fpppp(11, 6,15,1),fpppp(11, 6,15,2),fpppp(11, 6,15,3)/
     x-1.0863360D-07,-3.7588912D-08,-7.4472326D-10 /
      data fpppp(11, 6,16,1),fpppp(11, 6,16,2),fpppp(11, 6,16,3)/
     x-3.0365786D-08, 1.9705332D-08, 7.2570658D-10 /
      data fpppp(11, 6,17,1),fpppp(11, 6,17,2),fpppp(11, 6,17,3)/
     x-4.8251979D-07, 3.7644946D-08, 1.1147709D-09 /
      data fpppp(11, 7, 1,1),fpppp(11, 7, 1,2),fpppp(11, 7, 1,3)/
     x 2.8286964D-07, 6.3026334D-09,-4.6810691D-10 /
      data fpppp(11, 7, 2,1),fpppp(11, 7, 2,2),fpppp(11, 7, 2,3)/
     x-7.5966326D-09, 3.3160810D-09,-3.7794068D-10 /
      data fpppp(11, 7, 3,1),fpppp(11, 7, 3,2),fpppp(11, 7, 3,3)/
     x 5.6226409D-08,-6.2368980D-09, 1.6703519D-10 /
      data fpppp(11, 7, 4,1),fpppp(11, 7, 4,2),fpppp(11, 7, 4,3)/
     x-7.5966326D-09, 7.1926158D-09,-8.7982266D-10 /
      data fpppp(11, 7, 5,1),fpppp(11, 7, 5,2),fpppp(11, 7, 5,3)/
     x 2.8286964D-07,-9.2035061D-09, 1.5394210D-09 /
      data fpppp(11, 7, 6,1),fpppp(11, 7, 6,2),fpppp(11, 7, 6,3)/
     x-4.2840941D-08,-9.9454029D-09,-9.2344640D-10 /
      data fpppp(11, 7, 7,1),fpppp(11, 7, 7,2),fpppp(11, 7, 7,3)/
     x 8.7566067D-09, 3.0804455D-08, 1.2161528D-10 /
      data fpppp(11, 7, 8,1),fpppp(11, 7, 8,2),fpppp(11, 7, 8,3)/
     x-3.0436381D-08,-1.1816055D-08,-6.1481402D-11 /
      data fpppp(11, 7, 9,1),fpppp(11, 7, 9,2),fpppp(11, 7, 9,3)/
     x-5.9045069D-09,-7.1812251D-09, 1.5674615D-10 /
      data fpppp(11, 7,10,1),fpppp(11, 7,10,2),fpppp(11, 7,10,3)/
     x-3.0436381D-08,-1.1816055D-08,-6.1481402D-11 /
      data fpppp(11, 7,11,1),fpppp(11, 7,11,2),fpppp(11, 7,11,3)/
     x 8.7566067D-09, 3.0804455D-08, 1.2161528D-10 /
      data fpppp(11, 7,12,1),fpppp(11, 7,12,2),fpppp(11, 7,12,3)/
     x-4.2840941D-08,-9.9454029D-09,-9.2344640D-10 /
      data fpppp(11, 7,13,1),fpppp(11, 7,13,2),fpppp(11, 7,13,3)/
     x 2.8286964D-07,-9.2035061D-09, 1.5394210D-09 /
      data fpppp(11, 7,14,1),fpppp(11, 7,14,2),fpppp(11, 7,14,3)/
     x-7.5966326D-09, 7.1926158D-09,-8.7982266D-10 /
      data fpppp(11, 7,15,1),fpppp(11, 7,15,2),fpppp(11, 7,15,3)/
     x 5.6226409D-08,-6.2368980D-09, 1.6703519D-10 /
      data fpppp(11, 7,16,1),fpppp(11, 7,16,2),fpppp(11, 7,16,3)/
     x-7.5966326D-09, 3.3160810D-09,-3.7794068D-10 /
      data fpppp(11, 7,17,1),fpppp(11, 7,17,2),fpppp(11, 7,17,3)/
     x 2.8286964D-07, 6.3026334D-09,-4.6810691D-10 /
      data fpppp(11, 8, 1,1),fpppp(11, 8, 1,2),fpppp(11, 8, 1,3)/
     x-1.2415112D-07, 6.0796713D-09, 2.5325832D-10 /
      data fpppp(11, 8, 2,1),fpppp(11, 8, 2,2),fpppp(11, 8, 2,3)/
     x 3.9122508D-08, 5.6419545D-09, 1.6151964D-10 /
      data fpppp(11, 8, 3,1),fpppp(11, 8, 3,2),fpppp(11, 8, 3,3)/
     x 4.4244752D-08, 8.9050245D-11,-1.6087312D-10 /
      data fpppp(11, 8, 4,1),fpppp(11, 8, 4,2),fpppp(11, 8, 4,3)/
     x 3.9122508D-08, 1.2439302D-08, 3.2402339D-10 /
      data fpppp(11, 8, 5,1),fpppp(11, 8, 5,2),fpppp(11, 8, 5,3)/
     x-1.2415112D-07,-2.1109719D-08,-3.9675670D-10 /
      data fpppp(11, 8, 6,1),fpppp(11, 8, 6,2),fpppp(11, 8, 6,3)/
     x-3.4079670D-08, 5.7611391D-10, 1.9628225D-10 /
      data fpppp(11, 8, 7,1),fpppp(11, 8, 7,2),fpppp(11, 8, 7,3)/
     x-3.3640520D-08, 1.5769562D-08,-5.5185542D-11 /
      data fpppp(11, 8, 8,1),fpppp(11, 8, 8,2),fpppp(11, 8, 8,3)/
     x 1.3796313D-08, 9.4834953D-10, 1.3215695D-11 /
      data fpppp(11, 8, 9,1),fpppp(11, 8, 9,2),fpppp(11, 8, 9,3)/
     x-6.4660073D-09,-1.6203377D-08, 2.4798891D-11 /
      data fpppp(11, 8,10,1),fpppp(11, 8,10,2),fpppp(11, 8,10,3)/
     x 1.3796313D-08, 9.4834953D-10, 1.3215695D-11 /
      data fpppp(11, 8,11,1),fpppp(11, 8,11,2),fpppp(11, 8,11,3)/
     x-3.3640520D-08, 1.5769562D-08,-5.5185542D-11 /
      data fpppp(11, 8,12,1),fpppp(11, 8,12,2),fpppp(11, 8,12,3)/
     x-3.4079670D-08, 5.7611391D-10, 1.9628225D-10 /
      data fpppp(11, 8,13,1),fpppp(11, 8,13,2),fpppp(11, 8,13,3)/
     x-1.2415112D-07,-2.1109719D-08,-3.9675670D-10 /
      data fpppp(11, 8,14,1),fpppp(11, 8,14,2),fpppp(11, 8,14,3)/
     x 3.9122508D-08, 1.2439302D-08, 3.2402339D-10 /
      data fpppp(11, 8,15,1),fpppp(11, 8,15,2),fpppp(11, 8,15,3)/
     x 4.4244752D-08, 8.9050245D-11,-1.6087312D-10 /
      data fpppp(11, 8,16,1),fpppp(11, 8,16,2),fpppp(11, 8,16,3)/
     x 3.9122508D-08, 5.6419545D-09, 1.6151964D-10 /
      data fpppp(11, 8,17,1),fpppp(11, 8,17,2),fpppp(11, 8,17,3)/
     x-1.2415112D-07, 6.0796713D-09, 2.5325832D-10 /
      data fpppp(11, 9, 1,1),fpppp(11, 9, 1,2),fpppp(11, 9, 1,3)/
     x-2.0780598D-08,-7.9893489D-10,-1.3278126D-10 /
      data fpppp(11, 9, 2,1),fpppp(11, 9, 2,2),fpppp(11, 9, 2,3)/
     x 5.8765810D-09, 1.8769509D-09,-5.9094760D-11 /
      data fpppp(11, 9, 3,1),fpppp(11, 9, 3,2),fpppp(11, 9, 3,3)/
     x 2.1421255D-08, 5.2754025D-09, 1.4813971D-10 /
      data fpppp(11, 9, 4,1),fpppp(11, 9, 4,2),fpppp(11, 9, 4,3)/
     x 5.8765810D-09, 6.1448740D-09,-1.1204371D-10 /
      data fpppp(11, 9, 5,1),fpppp(11, 9, 5,2),fpppp(11, 9, 5,3)/
     x-2.0780598D-08,-1.7870627D-08, 7.9014521D-11 /
      data fpppp(11, 9, 6,1),fpppp(11, 9, 6,2),fpppp(11, 9, 6,3)/
     x-4.2225605D-08, 6.7703786D-09,-9.1544728D-11 /
      data fpppp(11, 9, 7,1),fpppp(11, 9, 7,2),fpppp(11, 9, 7,3)/
     x-3.5682261D-08, 8.0947380D-09, 6.7166698D-11 /
      data fpppp(11, 9, 8,1),fpppp(11, 9, 8,2),fpppp(11, 9, 8,3)/
     x 3.8982941D-09, 3.0705576D-09, 6.3215356D-12 /
      data fpppp(11, 9, 9,1),fpppp(11, 9, 9,2),fpppp(11, 9, 9,3)/
     x 7.8465733D-09,-1.6983924D-08,-5.4793176D-11 /
      data fpppp(11, 9,10,1),fpppp(11, 9,10,2),fpppp(11, 9,10,3)/
     x 3.8982941D-09, 3.0705576D-09, 6.3215356D-12 /
      data fpppp(11, 9,11,1),fpppp(11, 9,11,2),fpppp(11, 9,11,3)/
     x-3.5682261D-08, 8.0947380D-09, 6.7166698D-11 /
      data fpppp(11, 9,12,1),fpppp(11, 9,12,2),fpppp(11, 9,12,3)/
     x-4.2225605D-08, 6.7703786D-09,-9.1544728D-11 /
      data fpppp(11, 9,13,1),fpppp(11, 9,13,2),fpppp(11, 9,13,3)/
     x-2.0780598D-08,-1.7870627D-08, 7.9014521D-11 /
      data fpppp(11, 9,14,1),fpppp(11, 9,14,2),fpppp(11, 9,14,3)/
     x 5.8765810D-09, 6.1448740D-09,-1.1204371D-10 /
      data fpppp(11, 9,15,1),fpppp(11, 9,15,2),fpppp(11, 9,15,3)/
     x 2.1421255D-08, 5.2754025D-09, 1.4813971D-10 /
      data fpppp(11, 9,16,1),fpppp(11, 9,16,2),fpppp(11, 9,16,3)/
     x 5.8765810D-09, 1.8769509D-09,-5.9094760D-11 /
      data fpppp(11, 9,17,1),fpppp(11, 9,17,2),fpppp(11, 9,17,3)/
     x-2.0780598D-08,-7.9893489D-10,-1.3278126D-10 /
      data fpppp(11,10, 1,1),fpppp(11,10, 1,2),fpppp(11,10, 1,3)/
     x-3.2550498D-08,-1.1307874D-08,-5.2568552D-11 /
      data fpppp(11,10, 2,1),fpppp(11,10, 2,2),fpppp(11,10, 2,3)/
     x-7.3342918D-09,-5.8755234D-09,-1.0936705D-11 /
      data fpppp(11,10, 3,1),fpppp(11,10, 3,2),fpppp(11,10, 3,3)/
     x 2.1830697D-08, 7.9694573D-09, 8.1933985D-11 /
      data fpppp(11,10, 4,1),fpppp(11,10, 4,2),fpppp(11,10, 4,3)/
     x-7.3342918D-09,-7.6297666D-09,-4.5312742D-12 /
      data fpppp(11,10, 5,1),fpppp(11,10, 5,2),fpppp(11,10, 5,3)/
     x-3.2550498D-08,-4.2909016D-09,-7.8190275D-11 /
      data fpppp(11,10, 6,1),fpppp(11,10, 6,2),fpppp(11,10, 6,3)/
     x-5.3198453D-08, 1.0055877D-08, 5.4134922D-11 /
      data fpppp(11,10, 7,1),fpppp(11,10, 7,2),fpppp(11,10, 7,3)/
     x-3.0703235D-08, 8.9881539D-09,-3.1545394D-11 /
      data fpppp(11,10, 8,1),fpppp(11,10, 8,2),fpppp(11,10, 8,3)/
     x 4.3494571D-09,-4.8709846D-09, 6.9516490D-11 /
      data fpppp(11,10, 9,1),fpppp(11,10, 9,2),fpppp(11,10, 9,3)/
     x 9.4305109D-09,-1.2766587D-08,-9.9635350D-11 /
      data fpppp(11,10,10,1),fpppp(11,10,10,2),fpppp(11,10,10,3)/
     x 4.3494571D-09,-4.8709846D-09, 6.9516490D-11 /
      data fpppp(11,10,11,1),fpppp(11,10,11,2),fpppp(11,10,11,3)/
     x-3.0703235D-08, 8.9881539D-09,-3.1545394D-11 /
      data fpppp(11,10,12,1),fpppp(11,10,12,2),fpppp(11,10,12,3)/
     x-5.3198453D-08, 1.0055877D-08, 5.4134922D-11 /
      data fpppp(11,10,13,1),fpppp(11,10,13,2),fpppp(11,10,13,3)/
     x-3.2550498D-08,-4.2909016D-09,-7.8190275D-11 /
      data fpppp(11,10,14,1),fpppp(11,10,14,2),fpppp(11,10,14,3)/
     x-7.3342918D-09,-7.6297666D-09,-4.5312742D-12 /
      data fpppp(11,10,15,1),fpppp(11,10,15,2),fpppp(11,10,15,3)/
     x 2.1830697D-08, 7.9694573D-09, 8.1933985D-11 /
      data fpppp(11,10,16,1),fpppp(11,10,16,2),fpppp(11,10,16,3)/
     x-7.3342918D-09,-5.8755234D-09,-1.0936705D-11 /
      data fpppp(11,10,17,1),fpppp(11,10,17,2),fpppp(11,10,17,3)/
     x-3.2550498D-08,-1.1307874D-08,-5.2568552D-11 /
      data fpppp(11,11, 1,1),fpppp(11,11, 1,2),fpppp(11,11, 1,3)/
     x-2.7383173D-08,-1.5947694D-08,-8.8591764D-11 /
      data fpppp(11,11, 2,1),fpppp(11,11, 2,2),fpppp(11,11, 2,3)/
     x-2.1943223D-08,-1.2046775D-08,-4.0530618D-11 /
      data fpppp(11,11, 3,1),fpppp(11,11, 3,2),fpppp(11,11, 3,3)/
     x-3.6332731D-10, 7.8312010D-10, 8.9260376D-11 /
      data fpppp(11,11, 4,1),fpppp(11,11, 4,2),fpppp(11,11, 4,3)/
     x-2.1943223D-08,-1.7638401D-08,-6.7003100D-11 /
      data fpppp(11,11, 5,1),fpppp(11,11, 5,2),fpppp(11,11, 5,3)/
     x-2.7383173D-08, 6.4188115D-09, 1.7298165D-11 /
      data fpppp(11,11, 6,1),fpppp(11,11, 6,2),fpppp(11,11, 6,3)/
     x-5.7076750D-08, 2.0970036D-08, 1.7970595D-11 /
      data fpppp(11,11, 7,1),fpppp(11,11, 7,2),fpppp(11,11, 7,3)/
     x-2.7128741D-08, 1.1148344D-08,-1.6398923D-11 /
      data fpppp(11,11, 8,1),fpppp(11,11, 8,2),fpppp(11,11, 8,3)/
     x-7.7326993D-09,-1.7428825D-08,-5.6978388D-12 /
      data fpppp(11,11, 9,1),fpppp(11,11, 9,2),fpppp(11,11, 9,3)/
     x 1.1444765D-08,-8.6549881D-09, 1.3989748D-11 /
      data fpppp(11,11,10,1),fpppp(11,11,10,2),fpppp(11,11,10,3)/
     x-7.7326993D-09,-1.7428825D-08,-5.6978388D-12 /
      data fpppp(11,11,11,1),fpppp(11,11,11,2),fpppp(11,11,11,3)/
     x-2.7128741D-08, 1.1148344D-08,-1.6398923D-11 /
      data fpppp(11,11,12,1),fpppp(11,11,12,2),fpppp(11,11,12,3)/
     x-5.7076750D-08, 2.0970036D-08, 1.7970595D-11 /
      data fpppp(11,11,13,1),fpppp(11,11,13,2),fpppp(11,11,13,3)/
     x-2.7383173D-08, 6.4188115D-09, 1.7298165D-11 /
      data fpppp(11,11,14,1),fpppp(11,11,14,2),fpppp(11,11,14,3)/
     x-2.1943223D-08,-1.7638401D-08,-6.7003100D-11 /
      data fpppp(11,11,15,1),fpppp(11,11,15,2),fpppp(11,11,15,3)/
     x-3.6332731D-10, 7.8312010D-10, 8.9260376D-11 /
      data fpppp(11,11,16,1),fpppp(11,11,16,2),fpppp(11,11,16,3)/
     x-2.1943223D-08,-1.2046775D-08,-4.0530618D-11 /
      data fpppp(11,11,17,1),fpppp(11,11,17,2),fpppp(11,11,17,3)/
     x-2.7383173D-08,-1.5947694D-08,-8.8591764D-11 /
      data fpppp(11,12, 1,1),fpppp(11,12, 1,2),fpppp(11,12, 1,3)/
     x-5.9126802D-08,-1.5320419D-08,-3.8484128D-11 /
      data fpppp(11,12, 2,1),fpppp(11,12, 2,2),fpppp(11,12, 2,3)/
     x-4.2905343D-08,-1.6256434D-08,-1.6101353D-11 /
      data fpppp(11,12, 3,1),fpppp(11,12, 3,2),fpppp(11,12, 3,3)/
     x-4.8305524D-08,-1.4307023D-08, 4.3086366D-11 /
      data fpppp(11,12, 4,1),fpppp(11,12, 4,2),fpppp(11,12, 4,3)/
     x-4.2905343D-08,-2.2456602D-08,-2.6543217D-11 /
      data fpppp(11,12, 5,1),fpppp(11,12, 5,2),fpppp(11,12, 5,3)/
     x-5.9126802D-08, 9.4802531D-09, 3.2833276D-12 /
      data fpppp(11,12, 6,1),fpppp(11,12, 6,2),fpppp(11,12, 6,3)/
     x-9.3235642D-08, 4.5027553D-08,-4.0732654D-12 /
      data fpppp(11,12, 7,1),fpppp(11,12, 7,2),fpppp(11,12, 7,3)/
     x-5.1163072D-08, 8.1490308D-09, 1.5079231D-11 /
      data fpppp(11,12, 8,1),fpppp(11,12, 8,2),fpppp(11,12, 8,3)/
     x-2.9251296D-08,-2.8026587D-08,-4.0421748D-11 /
      data fpppp(11,12, 9,1),fpppp(11,12, 9,2),fpppp(11,12, 9,3)/
     x-1.1138485D-08,-1.1073635D-08, 6.0524665D-11 /
      data fpppp(11,12,10,1),fpppp(11,12,10,2),fpppp(11,12,10,3)/
     x-2.9251296D-08,-2.8026587D-08,-4.0421748D-11 /
      data fpppp(11,12,11,1),fpppp(11,12,11,2),fpppp(11,12,11,3)/
     x-5.1163072D-08, 8.1490308D-09, 1.5079231D-11 /
      data fpppp(11,12,12,1),fpppp(11,12,12,2),fpppp(11,12,12,3)/
     x-9.3235642D-08, 4.5027553D-08,-4.0732654D-12 /
      data fpppp(11,12,13,1),fpppp(11,12,13,2),fpppp(11,12,13,3)/
     x-5.9126802D-08, 9.4802531D-09, 3.2833276D-12 /
      data fpppp(11,12,14,1),fpppp(11,12,14,2),fpppp(11,12,14,3)/
     x-4.2905343D-08,-2.2456602D-08,-2.6543217D-11 /
      data fpppp(11,12,15,1),fpppp(11,12,15,2),fpppp(11,12,15,3)/
     x-4.8305524D-08,-1.4307023D-08, 4.3086366D-11 /
      data fpppp(11,12,16,1),fpppp(11,12,16,2),fpppp(11,12,16,3)/
     x-4.2905343D-08,-1.6256434D-08,-1.6101353D-11 /
      data fpppp(11,12,17,1),fpppp(11,12,17,2),fpppp(11,12,17,3)/
     x-5.9126802D-08,-1.5320419D-08,-3.8484128D-11 /
      data fpppp(11,13, 1,1),fpppp(11,13, 1,2),fpppp(11,13, 1,3)/
     x-8.5666040D-08,-1.8492014D-08, 5.8078105D-11 /
      data fpppp(11,13, 2,1),fpppp(11,13, 2,2),fpppp(11,13, 2,3)/
     x-6.7043720D-08,-2.2606420D-08, 3.3836373D-11 /
      data fpppp(11,13, 3,1),fpppp(11,13, 3,2),fpppp(11,13, 3,3)/
     x-7.6035684D-08,-2.7921532D-08,-3.2757043D-11 /
      data fpppp(11,13, 4,1),fpppp(11,13, 4,2),fpppp(11,13, 4,3)/
     x-6.7043720D-08,-2.9034170D-08, 4.8880434D-11 /
      data fpppp(11,13, 5,1),fpppp(11,13, 5,2),fpppp(11,13, 5,3)/
     x-8.5666040D-08, 7.2189874D-09,-2.0981425D-12 /
      data fpppp(11,13, 6,1),fpppp(11,13, 6,2),fpppp(11,13, 6,3)/
     x-8.5246481D-08, 8.3606237D-08,-1.1071533D-10 /
      data fpppp(11,13, 7,1),fpppp(11,13, 7,2),fpppp(11,13, 7,3)/
     x-4.7595585D-08,-2.9901785D-09, 1.2389987D-10 /
      data fpppp(11,13, 8,1),fpppp(11,13, 8,2),fpppp(11,13, 8,3)/
     x-4.7159315D-08,-3.4853684D-08,-7.4848847D-11 /
      data fpppp(11,13, 9,1),fpppp(11,13, 9,2),fpppp(11,13, 9,3)/
     x-3.6790501D-08,-2.1044143D-08, 6.5028430D-11 /
      data fpppp(11,13,10,1),fpppp(11,13,10,2),fpppp(11,13,10,3)/
     x-4.7159315D-08,-3.4853684D-08,-7.4848847D-11 /
      data fpppp(11,13,11,1),fpppp(11,13,11,2),fpppp(11,13,11,3)/
     x-4.7595585D-08,-2.9901785D-09, 1.2389987D-10 /
      data fpppp(11,13,12,1),fpppp(11,13,12,2),fpppp(11,13,12,3)/
     x-8.5246481D-08, 8.3606237D-08,-1.1071533D-10 /
      data fpppp(11,13,13,1),fpppp(11,13,13,2),fpppp(11,13,13,3)/
     x-8.5666040D-08, 7.2189874D-09,-2.0981425D-12 /
      data fpppp(11,13,14,1),fpppp(11,13,14,2),fpppp(11,13,14,3)/
     x-6.7043720D-08,-2.9034170D-08, 4.8880434D-11 /
      data fpppp(11,13,15,1),fpppp(11,13,15,2),fpppp(11,13,15,3)/
     x-7.6035684D-08,-2.7921532D-08,-3.2757043D-11 /
      data fpppp(11,13,16,1),fpppp(11,13,16,2),fpppp(11,13,16,3)/
     x-6.7043720D-08,-2.2606420D-08, 3.3836373D-11 /
      data fpppp(11,13,17,1),fpppp(11,13,17,2),fpppp(11,13,17,3)/
     x-8.5666040D-08,-1.8492014D-08, 5.8078105D-11 /
      data fpppp(11,14, 1,1),fpppp(11,14, 1,2),fpppp(11,14, 1,3)/
     x-5.1771818D-08,-2.5993816D-08, 3.2868854D-11 /
      data fpppp(11,14, 2,1),fpppp(11,14, 2,2),fpppp(11,14, 2,3)/
     x-1.0150258D-07,-3.1142277D-08, 2.0694907D-11 /
      data fpppp(11,14, 3,1),fpppp(11,14, 3,2),fpppp(11,14, 3,3)/
     x-1.0244560D-07,-3.7716908D-08,-1.8511515D-11 /
      data fpppp(11,14, 4,1),fpppp(11,14, 4,2),fpppp(11,14, 4,3)/
     x-1.0150258D-07,-3.9299945D-08, 3.6895722D-11 /
      data fpppp(11,14, 5,1),fpppp(11,14, 5,2),fpppp(11,14, 5,3)/
     x-5.1771818D-08, 6.6368547D-09,-3.1934408D-11 /
      data fpppp(11,14, 6,1),fpppp(11,14, 6,2),fpppp(11,14, 6,3)/
     x 8.7744956D-09, 1.2683389D-07,-5.0765039D-11 /
      data fpppp(11,14, 7,1),fpppp(11,14, 7,2),fpppp(11,14, 7,3)/
     x-3.1461948D-08,-2.0590638D-08, 7.7163509D-11 /
      data fpppp(11,14, 8,1),fpppp(11,14, 8,2),fpppp(11,14, 8,3)/
     x-5.6743173D-08,-3.7602986D-08, 6.1479336D-12 /
      data fpppp(11,14, 9,1),fpppp(11,14, 9,2),fpppp(11,14, 9,3)/
     x-7.0547967D-08,-3.5597064D-08,-5.3803784D-11 /
      data fpppp(11,14,10,1),fpppp(11,14,10,2),fpppp(11,14,10,3)/
     x-5.6743173D-08,-3.7602986D-08, 6.1479336D-12 /
      data fpppp(11,14,11,1),fpppp(11,14,11,2),fpppp(11,14,11,3)/
     x-3.1461948D-08,-2.0590638D-08, 7.7163509D-11 /
      data fpppp(11,14,12,1),fpppp(11,14,12,2),fpppp(11,14,12,3)/
     x 8.7744956D-09, 1.2683389D-07,-5.0765039D-11 /
      data fpppp(11,14,13,1),fpppp(11,14,13,2),fpppp(11,14,13,3)/
     x-5.1771818D-08, 6.6368547D-09,-3.1934408D-11 /
      data fpppp(11,14,14,1),fpppp(11,14,14,2),fpppp(11,14,14,3)/
     x-1.0150258D-07,-3.9299945D-08, 3.6895722D-11 /
      data fpppp(11,14,15,1),fpppp(11,14,15,2),fpppp(11,14,15,3)/
     x-1.0244560D-07,-3.7716908D-08,-1.8511515D-11 /
      data fpppp(11,14,16,1),fpppp(11,14,16,2),fpppp(11,14,16,3)/
     x-1.0150258D-07,-3.1142277D-08, 2.0694907D-11 /
      data fpppp(11,14,17,1),fpppp(11,14,17,2),fpppp(11,14,17,3)/
     x-5.1771818D-08,-2.5993816D-08, 3.2868854D-11 /
      data fpppp(11,15, 1,1),fpppp(11,15, 1,2),fpppp(11,15, 1,3)/
     x 3.3396966D-08,-2.7054717D-08, 2.2017007D-11 /
      data fpppp(11,15, 2,1),fpppp(11,15, 2,2),fpppp(11,15, 2,3)/
     x-6.8692743D-08,-3.4972971D-08, 6.9096101D-12 /
      data fpppp(11,15, 3,1),fpppp(11,15, 3,2),fpppp(11,15, 3,3)/
     x-1.0729048D-07,-4.7103988D-08,-3.8869865D-11 /
      data fpppp(11,15, 4,1),fpppp(11,15, 4,2),fpppp(11,15, 4,3)/
     x-6.8692743D-08,-4.4490334D-08, 2.2702934D-11 /
      data fpppp(11,15, 5,1),fpppp(11,15, 5,2),fpppp(11,15, 5,3)/
     x 3.3396966D-08, 1.1014735D-08,-4.1156287D-11 /
      data fpppp(11,15, 6,1),fpppp(11,15, 6,2),fpppp(11,15, 6,3)/
     x 1.2577708D-07, 1.5098995D-07, 5.8577485D-11 /
      data fpppp(11,15, 7,1),fpppp(11,15, 7,2),fpppp(11,15, 7,3)/
     x 2.7750431D-10,-3.1729074D-08,-7.6982443D-13 /
      data fpppp(11,15, 8,1),fpppp(11,15, 8,2),fpppp(11,15, 8,3)/
     x-8.1880057D-08,-3.9801192D-08, 1.8318805D-11 /
      data fpppp(11,15, 9,1),fpppp(11,15, 9,2),fpppp(11,15, 9,3)/
     x-1.0858198D-07,-4.6450406D-08,-7.3844138D-11 /
      data fpppp(11,15,10,1),fpppp(11,15,10,2),fpppp(11,15,10,3)/
     x-8.1880057D-08,-3.9801192D-08, 1.8318805D-11 /
      data fpppp(11,15,11,1),fpppp(11,15,11,2),fpppp(11,15,11,3)/
     x 2.7750431D-10,-3.1729074D-08,-7.6982443D-13 /
      data fpppp(11,15,12,1),fpppp(11,15,12,2),fpppp(11,15,12,3)/
     x 1.2577708D-07, 1.5098995D-07, 5.8577485D-11 /
      data fpppp(11,15,13,1),fpppp(11,15,13,2),fpppp(11,15,13,3)/
     x 3.3396966D-08, 1.1014735D-08,-4.1156287D-11 /
      data fpppp(11,15,14,1),fpppp(11,15,14,2),fpppp(11,15,14,3)/
     x-6.8692743D-08,-4.4490334D-08, 2.2702934D-11 /
      data fpppp(11,15,15,1),fpppp(11,15,15,2),fpppp(11,15,15,3)/
     x-1.0729048D-07,-4.7103988D-08,-3.8869865D-11 /
      data fpppp(11,15,16,1),fpppp(11,15,16,2),fpppp(11,15,16,3)/
     x-6.8692743D-08,-3.4972971D-08, 6.9096101D-12 /
      data fpppp(11,15,17,1),fpppp(11,15,17,2),fpppp(11,15,17,3)/
     x 3.3396966D-08,-2.7054717D-08, 2.2017007D-11 /
      data fpppp(11,16, 1,1),fpppp(11,16, 1,2),fpppp(11,16, 1,3)/
     x 1.2726690D-07,-2.0954325D-08,-5.0939746D-11 /
      data fpppp(11,16, 2,1),fpppp(11,16, 2,2),fpppp(11,16, 2,3)/
     x-4.7283658D-08,-3.1244037D-08,-4.1660953D-11 /
      data fpppp(11,16, 3,1),fpppp(11,16, 3,2),fpppp(11,16, 3,3)/
     x-1.1212313D-07,-4.8061243D-08,-2.6957387D-12 /
      data fpppp(11,16, 4,1),fpppp(11,16, 4,2),fpppp(11,16, 4,3)/
     x-4.7283658D-08,-4.2032219D-08,-6.7633001D-11 /
      data fpppp(11,16, 5,1),fpppp(11,16, 5,2),fpppp(11,16, 5,3)/
     x 1.2726690D-07, 2.2198402D-08, 5.2948447D-11 /
      data fpppp(11,16, 6,1),fpppp(11,16, 6,2),fpppp(11,16, 6,3)/
     x 2.6316174D-07, 1.3286562D-07, 5.0825088D-11 /
      data fpppp(11,16, 7,1),fpppp(11,16, 7,2),fpppp(11,16, 7,3)/
     x 5.8199090D-08,-2.6458321D-08, 1.2046946D-11 /
      data fpppp(11,16, 8,1),fpppp(11,16, 8,2),fpppp(11,16, 8,3)/
     x-9.6268833D-08,-3.8820440D-08,-1.8317770D-11 /
      data fpppp(11,16, 9,1),fpppp(11,16, 9,2),fpppp(11,16, 9,3)/
     x-1.4936270D-07,-4.9242874D-08,-6.1372354D-11 /
      data fpppp(11,16,10,1),fpppp(11,16,10,2),fpppp(11,16,10,3)/
     x-9.6268833D-08,-3.8820440D-08,-1.8317770D-11 /
      data fpppp(11,16,11,1),fpppp(11,16,11,2),fpppp(11,16,11,3)/
     x 5.8199090D-08,-2.6458321D-08, 1.2046946D-11 /
      data fpppp(11,16,12,1),fpppp(11,16,12,2),fpppp(11,16,12,3)/
     x 2.6316174D-07, 1.3286562D-07, 5.0825088D-11 /
      data fpppp(11,16,13,1),fpppp(11,16,13,2),fpppp(11,16,13,3)/
     x 1.2726690D-07, 2.2198402D-08, 5.2948447D-11 /
      data fpppp(11,16,14,1),fpppp(11,16,14,2),fpppp(11,16,14,3)/
     x-4.7283658D-08,-4.2032219D-08,-6.7633001D-11 /
      data fpppp(11,16,15,1),fpppp(11,16,15,2),fpppp(11,16,15,3)/
     x-1.1212313D-07,-4.8061243D-08,-2.6957387D-12 /
      data fpppp(11,16,16,1),fpppp(11,16,16,2),fpppp(11,16,16,3)/
     x-4.7283658D-08,-3.1244037D-08,-4.1660953D-11 /
      data fpppp(11,16,17,1),fpppp(11,16,17,2),fpppp(11,16,17,3)/
     x 1.2726690D-07,-2.0954325D-08,-5.0939746D-11 /
      data fpppp(11,17, 1,1),fpppp(11,17, 1,2),fpppp(11,17, 1,3)/
     x 1.8303470D-07,-7.1724951D-09,-1.0598271D-11 /
      data fpppp(11,17, 2,1),fpppp(11,17, 2,2),fpppp(11,17, 2,3)/
     x 6.2817774D-08,-1.7352279D-08,-8.9186366D-12 /
      data fpppp(11,17, 3,1),fpppp(11,17, 3,2),fpppp(11,17, 3,3)/
     x 2.5337765D-09,-3.4876869D-08,-3.3955767D-12 /
      data fpppp(11,17, 4,1),fpppp(11,17, 4,2),fpppp(11,17, 4,3)/
     x 6.2817774D-08,-2.6694636D-08,-1.1324504D-11 /
      data fpppp(11,17, 5,1),fpppp(11,17, 5,2),fpppp(11,17, 5,3)/
     x 1.8303470D-07, 3.0196934D-08,-9.7480053D-13 /
      data fpppp(11,17, 6,1),fpppp(11,17, 6,2),fpppp(11,17, 6,3)/
     x 6.6730067D-08, 7.0063025D-08, 7.8624946D-11 /
      data fpppp(11,17, 7,1),fpppp(11,17, 7,2),fpppp(11,17, 7,3)/
     x 2.0049327D-08,-7.2544385D-09,-5.9091785D-11 /
      data fpppp(11,17, 8,1),fpppp(11,17, 8,2),fpppp(11,17, 8,3)/
     x-1.0201753D-07,-3.0012296D-08, 1.1447967D-12 /
      data fpppp(11,17, 9,1),fpppp(11,17, 9,2),fpppp(11,17, 9,3)/
     x-1.6303019D-07,-3.9277368D-08,-1.3762706D-11 /
      data fpppp(11,17,10,1),fpppp(11,17,10,2),fpppp(11,17,10,3)/
     x-1.0201753D-07,-3.0012296D-08, 1.1447967D-12 /
      data fpppp(11,17,11,1),fpppp(11,17,11,2),fpppp(11,17,11,3)/
     x 2.0049327D-08,-7.2544385D-09,-5.9091785D-11 /
      data fpppp(11,17,12,1),fpppp(11,17,12,2),fpppp(11,17,12,3)/
     x 6.6730067D-08, 7.0063025D-08, 7.8624946D-11 /
      data fpppp(11,17,13,1),fpppp(11,17,13,2),fpppp(11,17,13,3)/
     x 1.8303470D-07, 3.0196934D-08,-9.7480053D-13 /
      data fpppp(11,17,14,1),fpppp(11,17,14,2),fpppp(11,17,14,3)/
     x 6.2817774D-08,-2.6694636D-08,-1.1324504D-11 /
      data fpppp(11,17,15,1),fpppp(11,17,15,2),fpppp(11,17,15,3)/
     x 2.5337765D-09,-3.4876869D-08,-3.3955767D-12 /
      data fpppp(11,17,16,1),fpppp(11,17,16,2),fpppp(11,17,16,3)/
     x 6.2817774D-08,-1.7352279D-08,-8.9186366D-12 /
      data fpppp(11,17,17,1),fpppp(11,17,17,2),fpppp(11,17,17,3)/
     x 1.8303470D-07,-7.1724951D-09,-1.0598271D-11 /
      data fpppp(11,18, 1,1),fpppp(11,18, 1,2),fpppp(11,18, 1,3)/
     x 1.0749733D-08, 5.2501733D-09, 1.6997125D-11 /
      data fpppp(11,18, 2,1),fpppp(11,18, 2,2),fpppp(11,18, 2,3)/
     x 2.3421035D-07,-8.4431954D-11, 1.6673578D-11 /
      data fpppp(11,18, 3,1),fpppp(11,18, 3,2),fpppp(11,18, 3,3)/
     x 3.0415592D-07,-1.2067936D-08, 1.5261436D-11 /
      data fpppp(11,18, 4,1),fpppp(11,18, 4,2),fpppp(11,18, 4,3)/
     x 2.3421035D-07,-7.8029429D-10, 1.7659377D-11 /
      data fpppp(11,18, 5,1),fpppp(11,18, 5,2),fpppp(11,18, 5,3)/
     x 1.0749733D-08, 8.0336226D-09, 1.3053930D-11 /
      data fpppp(11,18, 6,1),fpppp(11,18, 6,2),fpppp(11,18, 6,3)/
     x-9.6735732D-08, 2.0801396D-08,-3.8465928D-11 /
      data fpppp(11,18, 7,1),fpppp(11,18, 7,2),fpppp(11,18, 7,3)/
     x-3.6876743D-08,-3.8784890D-10,-2.5218751D-11 /
      data fpppp(11,18, 8,1),fpppp(11,18, 8,2),fpppp(11,18, 8,3)/
     x 2.9402566D-08,-1.2576995D-08, 5.0354251D-12 /
      data fpppp(11,18, 9,1),fpppp(11,18, 9,2),fpppp(11,18, 9,3)/
     x 4.9389536D-08,-1.8227801D-08, 4.0774756D-11 /
      data fpppp(11,18,10,1),fpppp(11,18,10,2),fpppp(11,18,10,3)/
     x 2.9402566D-08,-1.2576995D-08, 5.0354251D-12 /
      data fpppp(11,18,11,1),fpppp(11,18,11,2),fpppp(11,18,11,3)/
     x-3.6876743D-08,-3.8784890D-10,-2.5218751D-11 /
      data fpppp(11,18,12,1),fpppp(11,18,12,2),fpppp(11,18,12,3)/
     x-9.6735732D-08, 2.0801396D-08,-3.8465928D-11 /
      data fpppp(11,18,13,1),fpppp(11,18,13,2),fpppp(11,18,13,3)/
     x 1.0749733D-08, 8.0336226D-09, 1.3053930D-11 /
      data fpppp(11,18,14,1),fpppp(11,18,14,2),fpppp(11,18,14,3)/
     x 2.3421035D-07,-7.8029429D-10, 1.7659377D-11 /
      data fpppp(11,18,15,1),fpppp(11,18,15,2),fpppp(11,18,15,3)/
     x 3.0415592D-07,-1.2067936D-08, 1.5261436D-11 /
      data fpppp(11,18,16,1),fpppp(11,18,16,2),fpppp(11,18,16,3)/
     x 2.3421035D-07,-8.4431954D-11, 1.6673578D-11 /
      data fpppp(11,18,17,1),fpppp(11,18,17,2),fpppp(11,18,17,3)/
     x 1.0749733D-08, 5.2501733D-09, 1.6997125D-11 /
      data fpppp(11,19, 1,1),fpppp(11,19, 1,2),fpppp(11,19, 1,3)/
     x-9.6377304D-08, 1.1613789D-21, 4.8234259D-11 /
      data fpppp(11,19, 2,1),fpppp(11,19, 2,2),fpppp(11,19, 2,3)/
     x 3.8809117D-07,-8.9481712D-22, 4.4308679D-11 /
      data fpppp(11,19, 3,1),fpppp(11,19, 3,2),fpppp(11,19, 3,3)/
     x 5.5235943D-07,-2.5073433D-22, 2.8387920D-11 /
      data fpppp(11,19, 4,1),fpppp(11,19, 4,2),fpppp(11,19, 4,3)/
     x 3.8809117D-07, 5.9879822D-23, 5.4450292D-11 /
      data fpppp(11,19, 5,1),fpppp(11,19, 5,2),fpppp(11,19, 5,3)/
     x-9.6377304D-08,-4.0951008D-22, 7.6678101D-12 /
      data fpppp(11,19, 6,1),fpppp(11,19, 6,2),fpppp(11,19, 6,3)/
     x-2.6962035D-07,-4.3223972D-22,-1.1415945D-10 /
      data fpppp(11,19, 7,1),fpppp(11,19, 7,2),fpppp(11,19, 7,3)/
     x-8.8438154D-08, 1.2672309D-22,-2.1349077D-11 /
      data fpppp(11,19, 8,1),fpppp(11,19, 8,2),fpppp(11,19, 8,3)/
     x 1.2163158D-07,-6.1591459D-23, 1.3375179D-11 /
      data fpppp(11,19, 9,1),fpppp(11,19, 9,2),fpppp(11,19, 9,3)/
     x 1.9721292D-07,-7.7876716D-23, 9.3332843D-11 /
      data fpppp(11,19,10,1),fpppp(11,19,10,2),fpppp(11,19,10,3)/
     x 1.2163158D-07,-3.2362526D-22, 1.3375179D-11 /
      data fpppp(11,19,11,1),fpppp(11,19,11,2),fpppp(11,19,11,3)/
     x-8.8438154D-08, 2.2096526D-22,-2.1349077D-11 /
      data fpppp(11,19,12,1),fpppp(11,19,12,2),fpppp(11,19,12,3)/
     x-2.6962035D-07, 2.6739817D-22,-1.1415945D-10 /
      data fpppp(11,19,13,1),fpppp(11,19,13,2),fpppp(11,19,13,3)/
     x-9.6377304D-08, 3.3787141D-22, 7.6678101D-12 /
      data fpppp(11,19,14,1),fpppp(11,19,14,2),fpppp(11,19,14,3)/
     x 3.8809117D-07,-2.2261115D-22, 5.4450292D-11 /
      data fpppp(11,19,15,1),fpppp(11,19,15,2),fpppp(11,19,15,3)/
     x 5.5235943D-07, 1.9299647D-22, 2.8387920D-11 /
      data fpppp(11,19,16,1),fpppp(11,19,16,2),fpppp(11,19,16,3)/
     x 3.8809117D-07,-2.3052805D-22, 4.4308679D-11 /
      data fpppp(11,19,17,1),fpppp(11,19,17,2),fpppp(11,19,17,3)/
     x-9.6377304D-08, 4.2192065D-22, 4.8234259D-11 /
      data fpppp(12, 1, 1,1),fpppp(12, 1, 1,2),fpppp(12, 1, 1,3)/
     x 1.7575907D-08,-5.8994067D-23,-2.7551291D-11 /
      data fpppp(12, 1, 2,1),fpppp(12, 1, 2,2),fpppp(12, 1, 2,3)/
     x-5.0205793D-08,-7.3674175D-23,-1.1945866D-11 /
      data fpppp(12, 1, 3,1),fpppp(12, 1, 3,2),fpppp(12, 1, 3,3)/
     x-7.9976258D-08,-1.1480374D-23, 3.1625419D-11 /
      data fpppp(12, 1, 4,1),fpppp(12, 1, 4,2),fpppp(12, 1, 4,3)/
     x-5.0205793D-08, 1.0673711D-22,-2.2683803D-11 /
      data fpppp(12, 1, 5,1),fpppp(12, 1, 5,2),fpppp(12, 1, 5,3)/
     x 1.7575907D-08, 7.2620797D-23, 1.5400459D-11 /
      data fpppp(12, 1, 6,1),fpppp(12, 1, 6,2),fpppp(12, 1, 6,3)/
     x 5.3307335D-08,-8.1715154D-24,-2.3382426D-11 /
      data fpppp(12, 1, 7,1),fpppp(12, 1, 7,2),fpppp(12, 1, 7,3)/
     x 3.1528049D-08, 1.1487500D-22, 2.1418179D-11 /
      data fpppp(12, 1, 8,1),fpppp(12, 1, 8,2),fpppp(12, 1, 8,3)/
     x-2.3113991D-08,-8.0074267D-23,-9.8148796D-12 /
      data fpppp(12, 1, 9,1),fpppp(12, 1, 9,2),fpppp(12, 1, 9,3)/
     x-4.9766184D-08, 2.5490949D-23, 4.7098649D-12 /
      data fpppp(12, 1,10,1),fpppp(12, 1,10,2),fpppp(12, 1,10,3)/
     x-2.3113991D-08, 5.4600883D-23,-9.8148796D-12 /
      data fpppp(12, 1,11,1),fpppp(12, 1,11,2),fpppp(12, 1,11,3)/
     x 3.1528049D-08, 1.5837104D-22, 2.1418179D-11 /
      data fpppp(12, 1,12,1),fpppp(12, 1,12,2),fpppp(12, 1,12,3)/
     x 5.3307335D-08,-8.4775928D-23,-2.3382426D-11 /
      data fpppp(12, 1,13,1),fpppp(12, 1,13,2),fpppp(12, 1,13,3)/
     x 1.7575907D-08, 4.4379493D-23, 1.5400459D-11 /
      data fpppp(12, 1,14,1),fpppp(12, 1,14,2),fpppp(12, 1,14,3)/
     x-5.0205793D-08, 5.3082340D-23,-2.2683803D-11 /
      data fpppp(12, 1,15,1),fpppp(12, 1,15,2),fpppp(12, 1,15,3)/
     x-7.9976258D-08, 2.8830573D-23, 3.1625419D-11 /
      data fpppp(12, 1,16,1),fpppp(12, 1,16,2),fpppp(12, 1,16,3)/
     x-5.0205793D-08,-5.2579053D-23,-1.1945866D-11 /
      data fpppp(12, 1,17,1),fpppp(12, 1,17,2),fpppp(12, 1,17,3)/
     x 1.7575907D-08,-2.0593702D-23,-2.7551291D-11 /
      data fpppp(12, 2, 1,1),fpppp(12, 2, 1,2),fpppp(12, 2, 1,3)/
     x 6.4990903D-09, 3.3435404D-10,-1.8681748D-11 /
      data fpppp(12, 2, 2,1),fpppp(12, 2, 2,2),fpppp(12, 2, 2,3)/
     x-2.5624465D-08, 1.5183481D-09,-7.4284974D-12 /
      data fpppp(12, 2, 3,1),fpppp(12, 2, 3,2),fpppp(12, 2, 3,3)/
     x-4.4685367D-08, 4.0312560D-09, 2.2481073D-11 /
      data fpppp(12, 2, 4,1),fpppp(12, 2, 4,2),fpppp(12, 2, 4,3)/
     x-2.5624465D-08, 1.8929656D-09,-1.2906476D-11 /
      data fpppp(12, 2, 5,1),fpppp(12, 2, 5,2),fpppp(12, 2, 5,3)/
     x 6.4990903D-09,-1.1641158D-09, 3.2301659D-12 /
      data fpppp(12, 2, 6,1),fpppp(12, 2, 6,2),fpppp(12, 2, 6,3)/
     x 1.7546222D-08,-2.6958433D-09,-1.1085404D-11 /
      data fpppp(12, 2, 7,1),fpppp(12, 2, 7,2),fpppp(12, 2, 7,3)/
     x 7.5482480D-09,-1.6625806D-09, 1.4533582D-11 /
      data fpppp(12, 2, 8,1),fpppp(12, 2, 8,2),fpppp(12, 2, 8,3)/
     x-1.5777221D-08, 6.8440148D-10,-5.3330810D-12 /
      data fpppp(12, 2, 9,1),fpppp(12, 2, 9,2),fpppp(12, 2, 9,3)/
     x-2.7533265D-08, 1.9215254D-09,-2.7164310D-13 /
      data fpppp(12, 2,10,1),fpppp(12, 2,10,2),fpppp(12, 2,10,3)/
     x-1.5777221D-08, 6.8440148D-10,-5.3330810D-12 /
      data fpppp(12, 2,11,1),fpppp(12, 2,11,2),fpppp(12, 2,11,3)/
     x 7.5482480D-09,-1.6625806D-09, 1.4533582D-11 /
      data fpppp(12, 2,12,1),fpppp(12, 2,12,2),fpppp(12, 2,12,3)/
     x 1.7546222D-08,-2.6958433D-09,-1.1085404D-11 /
      data fpppp(12, 2,13,1),fpppp(12, 2,13,2),fpppp(12, 2,13,3)/
     x 6.4990903D-09,-1.1641158D-09, 3.2301659D-12 /
      data fpppp(12, 2,14,1),fpppp(12, 2,14,2),fpppp(12, 2,14,3)/
     x-2.5624465D-08, 1.8929656D-09,-1.2906476D-11 /
      data fpppp(12, 2,15,1),fpppp(12, 2,15,2),fpppp(12, 2,15,3)/
     x-4.4685367D-08, 4.0312560D-09, 2.2481073D-11 /
      data fpppp(12, 2,16,1),fpppp(12, 2,16,2),fpppp(12, 2,16,3)/
     x-2.5624465D-08, 1.5183481D-09,-7.4284974D-12 /
      data fpppp(12, 2,17,1),fpppp(12, 2,17,2),fpppp(12, 2,17,3)/
     x 6.4990903D-09, 3.3435404D-10,-1.8681748D-11 /
      data fpppp(12, 3, 1,1),fpppp(12, 3, 1,2),fpppp(12, 3, 1,3)/
     x-1.5682829D-08,-9.6212497D-10, 3.8322431D-12 /
      data fpppp(12, 3, 2,1),fpppp(12, 3, 2,2),fpppp(12, 3, 2,3)/
     x-6.3549110D-09, 3.7976734D-09, 5.2186018D-12 /
      data fpppp(12, 3, 3,1),fpppp(12, 3, 3,2),fpppp(12, 3, 3,3)/
     x-1.9204973D-08, 1.4214311D-08, 2.6613433D-12 /
      data fpppp(12, 3, 4,1),fpppp(12, 3, 4,2),fpppp(12, 3, 4,3)/
     x-6.3549110D-09, 4.8320114D-09, 1.3906745D-11 /
      data fpppp(12, 3, 5,1),fpppp(12, 3, 5,2),fpppp(12, 3, 5,3)/
     x-1.5682829D-08,-5.0994770D-09,-3.0920329D-11 /
      data fpppp(12, 3, 6,1),fpppp(12, 3, 6,2),fpppp(12, 3, 6,3)/
     x-2.0904961D-08,-7.8250272D-09, 1.8523831D-11 /
      data fpppp(12, 3, 7,1),fpppp(12, 3, 7,2),fpppp(12, 3, 7,3)/
     x-1.5315640D-08,-5.3627409D-09,-1.5245158D-13 /
      data fpppp(12, 3, 8,1),fpppp(12, 3, 8,2),fpppp(12, 3, 8,3)/
     x-4.6221376D-09, 2.9448457D-09, 2.7471872D-12 /
      data fpppp(12, 3, 9,1),fpppp(12, 3, 9,2),fpppp(12, 3, 9,3)/
     x-1.5746268D-09, 6.9788549D-09,-9.4232843D-12 /
      data fpppp(12, 3,10,1),fpppp(12, 3,10,2),fpppp(12, 3,10,3)/
     x-4.6221376D-09, 2.9448457D-09, 2.7471872D-12 /
      data fpppp(12, 3,11,1),fpppp(12, 3,11,2),fpppp(12, 3,11,3)/
     x-1.5315640D-08,-5.3627409D-09,-1.5245158D-13 /
      data fpppp(12, 3,12,1),fpppp(12, 3,12,2),fpppp(12, 3,12,3)/
     x-2.0904961D-08,-7.8250272D-09, 1.8523831D-11 /
      data fpppp(12, 3,13,1),fpppp(12, 3,13,2),fpppp(12, 3,13,3)/
     x-1.5682829D-08,-5.0994770D-09,-3.0920329D-11 /
      data fpppp(12, 3,14,1),fpppp(12, 3,14,2),fpppp(12, 3,14,3)/
     x-6.3549110D-09, 4.8320114D-09, 1.3906745D-11 /
      data fpppp(12, 3,15,1),fpppp(12, 3,15,2),fpppp(12, 3,15,3)/
     x-1.9204973D-08, 1.4214311D-08, 2.6613433D-12 /
      data fpppp(12, 3,16,1),fpppp(12, 3,16,2),fpppp(12, 3,16,3)/
     x-6.3549110D-09, 3.7976734D-09, 5.2186018D-12 /
      data fpppp(12, 3,17,1),fpppp(12, 3,17,2),fpppp(12, 3,17,3)/
     x-1.5682829D-08,-9.6212497D-10, 3.8322431D-12 /
      data fpppp(12, 4, 1,1),fpppp(12, 4, 1,2),fpppp(12, 4, 1,3)/
     x 1.0031116D-09,-7.7318728D-09,-2.1409334D-11 /
      data fpppp(12, 4, 2,1),fpppp(12, 4, 2,2),fpppp(12, 4, 2,3)/
     x 3.1505853D-08, 3.4930197D-09,-1.0588358D-11 /
      data fpppp(12, 4, 3,1),fpppp(12, 4, 3,2),fpppp(12, 4, 3,3)/
     x 4.0612159D-08, 2.9423694D-08, 2.0205455D-11 /
      data fpppp(12, 4, 4,1),fpppp(12, 4, 4,2),fpppp(12, 4, 4,3)/
     x 3.1505853D-08, 3.8841311D-09,-1.8905662D-11 /
      data fpppp(12, 4, 5,1),fpppp(12, 4, 5,2),fpppp(12, 4, 5,3)/
     x 1.0031116D-09,-9.2963187D-09, 1.1859881D-11 /
      data fpppp(12, 4, 6,1),fpppp(12, 4, 6,2),fpppp(12, 4, 6,3)/
     x-4.9940899D-08,-1.0809646D-08,-1.2459683D-11 /
      data fpppp(12, 4, 7,1),fpppp(12, 4, 7,2),fpppp(12, 4, 7,3)/
     x-4.2085222D-08,-8.3796381D-09, 1.2466545D-11 /
      data fpppp(12, 4, 8,1),fpppp(12, 4, 8,2),fpppp(12, 4, 8,3)/
     x-6.8311519D-09, 4.1596308D-09,-1.7671879D-12 /
      data fpppp(12, 4, 9,1),fpppp(12, 4, 9,2),fpppp(12, 4, 9,3)/
     x 1.1343995D-08, 1.1525172D-08,-3.9794594D-12 /
      data fpppp(12, 4,10,1),fpppp(12, 4,10,2),fpppp(12, 4,10,3)/
     x-6.8311519D-09, 4.1596308D-09,-1.7671879D-12 /
      data fpppp(12, 4,11,1),fpppp(12, 4,11,2),fpppp(12, 4,11,3)/
     x-4.2085222D-08,-8.3796381D-09, 1.2466545D-11 /
      data fpppp(12, 4,12,1),fpppp(12, 4,12,2),fpppp(12, 4,12,3)/
     x-4.9940899D-08,-1.0809646D-08,-1.2459683D-11 /
      data fpppp(12, 4,13,1),fpppp(12, 4,13,2),fpppp(12, 4,13,3)/
     x 1.0031116D-09,-9.2963187D-09, 1.1859881D-11 /
      data fpppp(12, 4,14,1),fpppp(12, 4,14,2),fpppp(12, 4,14,3)/
     x 3.1505853D-08, 3.8841311D-09,-1.8905662D-11 /
      data fpppp(12, 4,15,1),fpppp(12, 4,15,2),fpppp(12, 4,15,3)/
     x 4.0612159D-08, 2.9423694D-08, 2.0205455D-11 /
      data fpppp(12, 4,16,1),fpppp(12, 4,16,2),fpppp(12, 4,16,3)/
     x 3.1505853D-08, 3.4930197D-09,-1.0588358D-11 /
      data fpppp(12, 4,17,1),fpppp(12, 4,17,2),fpppp(12, 4,17,3)/
     x 1.0031116D-09,-7.7318728D-09,-2.1409334D-11 /
      data fpppp(12, 5, 1,1),fpppp(12, 5, 1,2),fpppp(12, 5, 1,3)/
     x-7.0769577D-08,-1.9182690D-08, 7.3700573D-12 /
      data fpppp(12, 5, 2,1),fpppp(12, 5, 2,2),fpppp(12, 5, 2,3)/
     x 5.6886637D-08,-7.9297595D-10,-6.6176673D-13 /
      data fpppp(12, 5, 3,1),fpppp(12, 5, 3,2),fpppp(12, 5, 3,3)/
     x 9.7136754D-08, 4.3553980D-08,-1.7861745D-11 /
      data fpppp(12, 5, 4,1),fpppp(12, 5, 4,2),fpppp(12, 5, 4,3)/
     x 5.6886637D-08,-2.9494092D-09,-2.9731837D-12 /
      data fpppp(12, 5, 5,1),fpppp(12, 5, 5,2),fpppp(12, 5, 5,3)/
     x-7.0769577D-08,-1.0556957D-08, 1.6615725D-11 /
      data fpppp(12, 5, 6,1),fpppp(12, 5, 6,2),fpppp(12, 5, 6,3)/
     x-3.0069986D-08,-9.5760264D-09, 3.4643031D-12 /
      data fpppp(12, 5, 7,1),fpppp(12, 5, 7,2),fpppp(12, 5, 7,3)/
     x-2.6137814D-08,-7.9564934D-09,-1.1446258D-11 /
      data fpppp(12, 5, 8,1),fpppp(12, 5, 8,2),fpppp(12, 5, 8,3)/
     x 2.0993293D-09, 2.8407580D-09,-8.9771212D-13 /
      data fpppp(12, 5, 9,1),fpppp(12, 5, 9,2),fpppp(12, 5, 9,3)/
     x 1.3749283D-08, 1.2482871D-08, 7.9507604D-12 /
      data fpppp(12, 5,10,1),fpppp(12, 5,10,2),fpppp(12, 5,10,3)/
     x 2.0993293D-09, 2.8407580D-09,-8.9771212D-13 /
      data fpppp(12, 5,11,1),fpppp(12, 5,11,2),fpppp(12, 5,11,3)/
     x-2.6137814D-08,-7.9564934D-09,-1.1446258D-11 /
      data fpppp(12, 5,12,1),fpppp(12, 5,12,2),fpppp(12, 5,12,3)/
     x-3.0069986D-08,-9.5760264D-09, 3.4643031D-12 /
      data fpppp(12, 5,13,1),fpppp(12, 5,13,2),fpppp(12, 5,13,3)/
     x-7.0769577D-08,-1.0556957D-08, 1.6615725D-11 /
      data fpppp(12, 5,14,1),fpppp(12, 5,14,2),fpppp(12, 5,14,3)/
     x 5.6886637D-08,-2.9494092D-09,-2.9731837D-12 /
      data fpppp(12, 5,15,1),fpppp(12, 5,15,2),fpppp(12, 5,15,3)/
     x 9.7136754D-08, 4.3553980D-08,-1.7861745D-11 /
      data fpppp(12, 5,16,1),fpppp(12, 5,16,2),fpppp(12, 5,16,3)/
     x 5.6886637D-08,-7.9297595D-10,-6.6176673D-13 /
      data fpppp(12, 5,17,1),fpppp(12, 5,17,2),fpppp(12, 5,17,3)/
     x-7.0769577D-08,-1.9182690D-08, 7.3700573D-12 /
      data fpppp(12, 6, 1,1),fpppp(12, 6, 1,2),fpppp(12, 6, 1,3)/
     x 1.0900525D-07,-3.1370853D-08, 4.0555148D-11 /
      data fpppp(12, 6, 2,1),fpppp(12, 6, 2,2),fpppp(12, 6, 2,3)/
     x 3.5022635D-08,-9.2608107D-09, 1.5983338D-11 /
      data fpppp(12, 6, 3,1),fpppp(12, 6, 3,2),fpppp(12, 6, 3,3)/
     x 9.0501667D-08, 4.8309059D-08,-4.8376174D-11 /
      data fpppp(12, 6, 4,1),fpppp(12, 6, 4,2),fpppp(12, 6, 4,3)/
     x 3.5022635D-08,-1.8230466D-08, 2.6521273D-11 /
      data fpppp(12, 6, 5,1),fpppp(12, 6, 5,2),fpppp(12, 6, 5,3)/
     x 1.0900525D-07, 4.5077675D-09,-1.5965919D-12 /
      data fpppp(12, 6, 6,1),fpppp(12, 6, 6,2),fpppp(12, 6, 6,3)/
     x 1.4955375D-09,-1.2808609D-08, 1.5974832D-11 /
      data fpppp(12, 6, 7,1),fpppp(12, 6, 7,2),fpppp(12, 6, 7,3)/
     x 1.1967733D-08,-2.6925794D-09,-3.2897147D-11 /
      data fpppp(12, 6, 8,1),fpppp(12, 6, 8,2),fpppp(12, 6, 8,3)/
     x 6.2125013D-09,-1.3315619D-09, 1.2848218D-11 /
      data fpppp(12, 6, 9,1),fpppp(12, 6, 9,2),fpppp(12, 6, 9,3)/
     x 5.5247074D-09, 1.1306896D-08, 8.4313271D-12 /
      data fpppp(12, 6,10,1),fpppp(12, 6,10,2),fpppp(12, 6,10,3)/
     x 6.2125013D-09,-1.3315619D-09, 1.2848218D-11 /
      data fpppp(12, 6,11,1),fpppp(12, 6,11,2),fpppp(12, 6,11,3)/
     x 1.1967733D-08,-2.6925794D-09,-3.2897147D-11 /
      data fpppp(12, 6,12,1),fpppp(12, 6,12,2),fpppp(12, 6,12,3)/
     x 1.4955375D-09,-1.2808609D-08, 1.5974832D-11 /
      data fpppp(12, 6,13,1),fpppp(12, 6,13,2),fpppp(12, 6,13,3)/
     x 1.0900525D-07, 4.5077675D-09,-1.5965919D-12 /
      data fpppp(12, 6,14,1),fpppp(12, 6,14,2),fpppp(12, 6,14,3)/
     x 3.5022635D-08,-1.8230466D-08, 2.6521273D-11 /
      data fpppp(12, 6,15,1),fpppp(12, 6,15,2),fpppp(12, 6,15,3)/
     x 9.0501667D-08, 4.8309059D-08,-4.8376174D-11 /
      data fpppp(12, 6,16,1),fpppp(12, 6,16,2),fpppp(12, 6,16,3)/
     x 3.5022635D-08,-9.2608107D-09, 1.5983338D-11 /
      data fpppp(12, 6,17,1),fpppp(12, 6,17,2),fpppp(12, 6,17,3)/
     x 1.0900525D-07,-3.1370853D-08, 4.0555148D-11 /
      data fpppp(12, 7, 1,1),fpppp(12, 7, 1,2),fpppp(12, 7, 1,3)/
     x-5.9496800D-08,-2.1571183D-08, 2.8260990D-12 /
      data fpppp(12, 7, 2,1),fpppp(12, 7, 2,2),fpppp(12, 7, 2,3)/
     x-8.3526558D-09,-6.9833392D-09,-1.4384170D-12 /
      data fpppp(12, 7, 3,1),fpppp(12, 7, 3,2),fpppp(12, 7, 3,3)/
     x-7.2653379D-09, 3.0359932D-08,-8.3829856D-12 /
      data fpppp(12, 7, 4,1),fpppp(12, 7, 4,2),fpppp(12, 7, 4,3)/
     x-8.3526558D-09,-1.1940794D-08,-5.9473703D-12 /
      data fpppp(12, 7, 5,1),fpppp(12, 7, 5,2),fpppp(12, 7, 5,3)/
     x-5.9496800D-08,-1.7413643D-09, 2.0861912D-11 /
      data fpppp(12, 7, 6,1),fpppp(12, 7, 6,2),fpppp(12, 7, 6,3)/
     x 2.1729187D-08, 3.9424018D-10,-8.8932494D-12 /
      data fpppp(12, 7, 7,1),fpppp(12, 7, 7,2),fpppp(12, 7, 7,3)/
     x 1.4046653D-08,-3.3841240D-09,-1.9379502D-12 /
      data fpppp(12, 7, 8,1),fpppp(12, 7, 8,2),fpppp(12, 7, 8,3)/
     x-1.6893549D-09,-3.5239469D-09,-9.0743616D-12 /
      data fpppp(12, 7, 9,1),fpppp(12, 7, 9,2),fpppp(12, 7, 9,3)/
     x-1.1755447D-08, 9.2058033D-09, 1.7613532D-11 /
      data fpppp(12, 7,10,1),fpppp(12, 7,10,2),fpppp(12, 7,10,3)/
     x-1.6893549D-09,-3.5239469D-09,-9.0743616D-12 /
      data fpppp(12, 7,11,1),fpppp(12, 7,11,2),fpppp(12, 7,11,3)/
     x 1.4046653D-08,-3.3841240D-09,-1.9379502D-12 /
      data fpppp(12, 7,12,1),fpppp(12, 7,12,2),fpppp(12, 7,12,3)/
     x 2.1729187D-08, 3.9424018D-10,-8.8932494D-12 /
      data fpppp(12, 7,13,1),fpppp(12, 7,13,2),fpppp(12, 7,13,3)/
     x-5.9496800D-08,-1.7413643D-09, 2.0861912D-11 /
      data fpppp(12, 7,14,1),fpppp(12, 7,14,2),fpppp(12, 7,14,3)/
     x-8.3526558D-09,-1.1940794D-08,-5.9473703D-12 /
      data fpppp(12, 7,15,1),fpppp(12, 7,15,2),fpppp(12, 7,15,3)/
     x-7.2653379D-09, 3.0359932D-08,-8.3829856D-12 /
      data fpppp(12, 7,16,1),fpppp(12, 7,16,2),fpppp(12, 7,16,3)/
     x-8.3526558D-09,-6.9833392D-09,-1.4384170D-12 /
      data fpppp(12, 7,17,1),fpppp(12, 7,17,2),fpppp(12, 7,17,3)/
     x-5.9496800D-08,-2.1571183D-08, 2.8260990D-12 /
      data fpppp(12, 8, 1,1),fpppp(12, 8, 1,2),fpppp(12, 8, 1,3)/
     x 2.2199478D-08,-1.1547695D-08, 9.9010105D-12 /
      data fpppp(12, 8, 2,1),fpppp(12, 8, 2,2),fpppp(12, 8, 2,3)/
     x-4.1900797D-08,-5.3848414D-09, 6.2492201D-12 /
      data fpppp(12, 8, 3,1),fpppp(12, 8, 3,2),fpppp(12, 8, 3,3)/
     x-6.6176198D-08, 1.1465017D-08,-5.7680004D-12 /
      data fpppp(12, 8, 4,1),fpppp(12, 8, 4,2),fpppp(12, 8, 4,3)/
     x-4.1900797D-08,-9.0896434D-09, 1.1493785D-11 /
      data fpppp(12, 8, 5,1),fpppp(12, 8, 5,2),fpppp(12, 8, 5,3)/
     x 2.2199478D-08, 3.2715133D-09,-1.1077247D-11 /
      data fpppp(12, 8, 6,1),fpppp(12, 8, 6,2),fpppp(12, 8, 6,3)/
     x 2.2862530D-08, 3.6043479D-09, 2.2773509D-12 /
      data fpppp(12, 8, 7,1),fpppp(12, 8, 7,2),fpppp(12, 8, 7,3)/
     x 8.5242114D-09,-3.4393282D-09,-8.4160247D-13 /
      data fpppp(12, 8, 8,1),fpppp(12, 8, 8,2),fpppp(12, 8, 8,3)/
     x-1.8676235D-08,-5.0804464D-09, 6.7322424D-12 /
      data fpppp(12, 8, 9,1),fpppp(12, 8, 9,2),fpppp(12, 8, 9,3)/
     x-2.4485577D-08, 9.3846294D-09,-1.0526962D-11 /
      data fpppp(12, 8,10,1),fpppp(12, 8,10,2),fpppp(12, 8,10,3)/
     x-1.8676235D-08,-5.0804464D-09, 6.7322424D-12 /
      data fpppp(12, 8,11,1),fpppp(12, 8,11,2),fpppp(12, 8,11,3)/
     x 8.5242114D-09,-3.4393282D-09,-8.4160247D-13 /
      data fpppp(12, 8,12,1),fpppp(12, 8,12,2),fpppp(12, 8,12,3)/
     x 2.2862530D-08, 3.6043479D-09, 2.2773509D-12 /
      data fpppp(12, 8,13,1),fpppp(12, 8,13,2),fpppp(12, 8,13,3)/
     x 2.2199478D-08, 3.2715133D-09,-1.1077247D-11 /
      data fpppp(12, 8,14,1),fpppp(12, 8,14,2),fpppp(12, 8,14,3)/
     x-4.1900797D-08,-9.0896434D-09, 1.1493785D-11 /
      data fpppp(12, 8,15,1),fpppp(12, 8,15,2),fpppp(12, 8,15,3)/
     x-6.6176198D-08, 1.1465017D-08,-5.7680004D-12 /
      data fpppp(12, 8,16,1),fpppp(12, 8,16,2),fpppp(12, 8,16,3)/
     x-4.1900797D-08,-5.3848414D-09, 6.2492201D-12 /
      data fpppp(12, 8,17,1),fpppp(12, 8,17,2),fpppp(12, 8,17,3)/
     x 2.2199478D-08,-1.1547695D-08, 9.9010105D-12 /
      data fpppp(12, 9, 1,1),fpppp(12, 9, 1,2),fpppp(12, 9, 1,3)/
     x-6.3168054D-09,-1.7619653D-09,-1.7446505D-11 /
      data fpppp(12, 9, 2,1),fpppp(12, 9, 2,2),fpppp(12, 9, 2,3)/
     x-4.4854741D-08,-1.9960306D-09,-6.8590690D-12 /
      data fpppp(12, 9, 3,1),fpppp(12, 9, 3,2),fpppp(12, 9, 3,3)/
     x-7.6393287D-08,-1.4376065D-09, 1.9673773D-11 /
      data fpppp(12, 9, 4,1),fpppp(12, 9, 4,2),fpppp(12, 9, 4,3)/
     x-4.4854741D-08,-3.6528951D-09,-9.6023058D-12 /
      data fpppp(12, 9, 5,1),fpppp(12, 9, 5,2),fpppp(12, 9, 5,3)/
     x-6.3168054D-09, 4.8654928D-09,-6.4735581D-12 /
      data fpppp(12, 9, 6,1),fpppp(12, 9, 6,2),fpppp(12, 9, 6,3)/
     x 1.6790325D-08, 2.7033873D-09, 9.0409233D-12 /
      data fpppp(12, 9, 7,1),fpppp(12, 9, 7,2),fpppp(12, 9, 7,3)/
     x-3.7757968D-09,-5.0299456D-09,-1.8033146D-12 /
      data fpppp(12, 9, 8,1),fpppp(12, 9, 8,2),fpppp(12, 9, 8,3)/
     x-2.8683190D-08,-3.4779202D-09, 1.3190131D-12 /
      data fpppp(12, 9, 9,1),fpppp(12, 9, 9,2),fpppp(12, 9, 9,3)/
     x-3.7882791D-08, 1.0345224D-08,-5.0924949D-12 /
      data fpppp(12, 9,10,1),fpppp(12, 9,10,2),fpppp(12, 9,10,3)/
     x-2.8683190D-08,-3.4779202D-09, 1.3190131D-12 /
      data fpppp(12, 9,11,1),fpppp(12, 9,11,2),fpppp(12, 9,11,3)/
     x-3.7757968D-09,-5.0299456D-09,-1.8033146D-12 /
      data fpppp(12, 9,12,1),fpppp(12, 9,12,2),fpppp(12, 9,12,3)/
     x 1.6790325D-08, 2.7033873D-09, 9.0409233D-12 /
      data fpppp(12, 9,13,1),fpppp(12, 9,13,2),fpppp(12, 9,13,3)/
     x-6.3168054D-09, 4.8654928D-09,-6.4735581D-12 /
      data fpppp(12, 9,14,1),fpppp(12, 9,14,2),fpppp(12, 9,14,3)/
     x-4.4854741D-08,-3.6528951D-09,-9.6023058D-12 /
      data fpppp(12, 9,15,1),fpppp(12, 9,15,2),fpppp(12, 9,15,3)/
     x-7.6393287D-08,-1.4376065D-09, 1.9673773D-11 /
      data fpppp(12, 9,16,1),fpppp(12, 9,16,2),fpppp(12, 9,16,3)/
     x-4.4854741D-08,-1.9960306D-09,-6.8590690D-12 /
      data fpppp(12, 9,17,1),fpppp(12, 9,17,2),fpppp(12, 9,17,3)/
     x-6.3168054D-09,-1.7619653D-09,-1.7446505D-11 /
      data fpppp(12,10, 1,1),fpppp(12,10, 1,2),fpppp(12,10, 1,3)/
     x-1.6904722D-09, 4.9378638D-09,-1.9825242D-12 /
      data fpppp(12,10, 2,1),fpppp(12,10, 2,2),fpppp(12,10, 2,3)/
     x-3.9173071D-08, 2.0443476D-09,-1.7445427D-12 /
      data fpppp(12,10, 3,1),fpppp(12,10, 3,2),fpppp(12,10, 3,3)/
     x-6.3939671D-08,-4.9118847D-09, 6.6683783D-13 /
      data fpppp(12,10, 4,1),fpppp(12,10, 4,2),fpppp(12,10, 4,3)/
     x-3.9173071D-08, 2.3513892D-09,-4.5286786D-12 /
      data fpppp(12,10, 5,1),fpppp(12,10, 5,2),fpppp(12,10, 5,3)/
     x-1.6904722D-09, 3.7096973D-09, 9.1540193D-12 /
      data fpppp(12,10, 6,1),fpppp(12,10, 6,2),fpppp(12,10, 6,3)/
     x 1.6378314D-08,-3.8298151D-09,-1.5727086D-11 /
      data fpppp(12,10, 7,1),fpppp(12,10, 7,2),fpppp(12,10, 7,3)/
     x-6.4475927D-09,-6.9628287D-09, 2.5016487D-11 /
      data fpppp(12,10, 8,1),fpppp(12,10, 8,2),fpppp(12,10, 8,3)/
     x-3.7457314D-08, 8.5801871D-10,-2.2568760D-11 /
      data fpppp(12,10, 9,1),fpppp(12,10, 9,2),fpppp(12,10, 9,3)/
     x-4.4727983D-08, 1.2710135D-08, 1.6177174D-11 /
      data fpppp(12,10,10,1),fpppp(12,10,10,2),fpppp(12,10,10,3)/
     x-3.7457314D-08, 8.5801871D-10,-2.2568760D-11 /
      data fpppp(12,10,11,1),fpppp(12,10,11,2),fpppp(12,10,11,3)/
     x-6.4475927D-09,-6.9628287D-09, 2.5016487D-11 /
      data fpppp(12,10,12,1),fpppp(12,10,12,2),fpppp(12,10,12,3)/
     x 1.6378314D-08,-3.8298151D-09,-1.5727086D-11 /
      data fpppp(12,10,13,1),fpppp(12,10,13,2),fpppp(12,10,13,3)/
     x-1.6904722D-09, 3.7096973D-09, 9.1540193D-12 /
      data fpppp(12,10,14,1),fpppp(12,10,14,2),fpppp(12,10,14,3)/
     x-3.9173071D-08, 2.3513892D-09,-4.5286786D-12 /
      data fpppp(12,10,15,1),fpppp(12,10,15,2),fpppp(12,10,15,3)/
     x-6.3939671D-08,-4.9118847D-09, 6.6683783D-13 /
      data fpppp(12,10,16,1),fpppp(12,10,16,2),fpppp(12,10,16,3)/
     x-3.9173071D-08, 2.0443476D-09,-1.7445427D-12 /
      data fpppp(12,10,17,1),fpppp(12,10,17,2),fpppp(12,10,17,3)/
     x-1.6904722D-09, 4.9378638D-09,-1.9825242D-12 /
      data fpppp(12,11, 1,1),fpppp(12,11, 1,2),fpppp(12,11, 1,3)/
     x 6.9487896D-09, 9.1910200D-09,-1.1735982D-11 /
      data fpppp(12,11, 2,1),fpppp(12,11, 2,2),fpppp(12,11, 2,3)/
     x-2.3957960D-08, 6.7030907D-09,-5.2709256D-12 /
      data fpppp(12,11, 3,1),fpppp(12,11, 3,2),fpppp(12,11, 3,3)/
     x-4.0877945D-08,-4.2959956D-10, 1.1204122D-11 /
      data fpppp(12,11, 4,1),fpppp(12,11, 4,2),fpppp(12,11, 4,3)/
     x-2.3957960D-08, 8.6943732D-09,-7.3557993D-12 /
      data fpppp(12,11, 5,1),fpppp(12,11, 5,2),fpppp(12,11, 5,3)/
     x 6.9487896D-09, 1.2258896D-09,-3.3964874D-12 /
      data fpppp(12,11, 6,1),fpppp(12,11, 6,2),fpppp(12,11, 6,3)/
     x 2.5323249D-08,-1.7125041D-08, 2.1956112D-11 /
      data fpppp(12,11, 7,1),fpppp(12,11, 7,2),fpppp(12,11, 7,3)/
     x-5.1130733D-09,-8.9710286D-09,-3.7363437D-11 /
      data fpppp(12,11, 8,1),fpppp(12,11, 8,2),fpppp(12,11, 8,3)/
     x-3.3085672D-08, 8.4113812D-09, 3.7270540D-11 /
      data fpppp(12,11, 9,1),fpppp(12,11, 9,2),fpppp(12,11, 9,3)/
     x-4.5635315D-08, 1.6290331D-08,-3.3773458D-11 /
      data fpppp(12,11,10,1),fpppp(12,11,10,2),fpppp(12,11,10,3)/
     x-3.3085672D-08, 8.4113812D-09, 3.7270540D-11 /
      data fpppp(12,11,11,1),fpppp(12,11,11,2),fpppp(12,11,11,3)/
     x-5.1130733D-09,-8.9710286D-09,-3.7363437D-11 /
      data fpppp(12,11,12,1),fpppp(12,11,12,2),fpppp(12,11,12,3)/
     x 2.5323249D-08,-1.7125041D-08, 2.1956112D-11 /
      data fpppp(12,11,13,1),fpppp(12,11,13,2),fpppp(12,11,13,3)/
     x 6.9487896D-09, 1.2258896D-09,-3.3964874D-12 /
      data fpppp(12,11,14,1),fpppp(12,11,14,2),fpppp(12,11,14,3)/
     x-2.3957960D-08, 8.6943732D-09,-7.3557993D-12 /
      data fpppp(12,11,15,1),fpppp(12,11,15,2),fpppp(12,11,15,3)/
     x-4.0877945D-08,-4.2959956D-10, 1.1204122D-11 /
      data fpppp(12,11,16,1),fpppp(12,11,16,2),fpppp(12,11,16,3)/
     x-2.3957960D-08, 6.7030907D-09,-5.2709256D-12 /
      data fpppp(12,11,17,1),fpppp(12,11,17,2),fpppp(12,11,17,3)/
     x 6.9487896D-09, 9.1910200D-09,-1.1735982D-11 /
      data fpppp(12,12, 1,1),fpppp(12,12, 1,2),fpppp(12,12, 1,3)/
     x 3.1869934D-08, 1.3083141D-08,-1.3305793D-11 /
      data fpppp(12,12, 2,1),fpppp(12,12, 2,2),fpppp(12,12, 2,3)/
     x 5.2112215D-09, 1.2617531D-08,-6.0405979D-12 /
      data fpppp(12,12, 3,1),fpppp(12,12, 3,2),fpppp(12,12, 3,3)/
     x-3.4562127D-09, 9.0191926D-09, 1.2224291D-11 /
      data fpppp(12,12, 4,1),fpppp(12,12, 4,2),fpppp(12,12, 4,3)/
     x 5.2112215D-09, 1.6385404D-08,-8.0097509D-12 /
      data fpppp(12,12, 5,1),fpppp(12,12, 5,2),fpppp(12,12, 5,3)/
     x 3.1869934D-08,-1.9883521D-09,-5.4291808D-12 /
      data fpppp(12,12, 6,1),fpppp(12,12, 6,2),fpppp(12,12, 6,3)/
     x 4.2039199D-08,-3.8405735D-08, 9.3087092D-12 /
      data fpppp(12,12, 7,1),fpppp(12,12, 7,2),fpppp(12,12, 7,3)/
     x 1.0487916D-08,-9.1800747D-09, 8.6740880D-12 /
      data fpppp(12,12, 8,1),fpppp(12,12, 8,2),fpppp(12,12, 8,3)/
     x-1.4934337D-08, 1.7620276D-08,-2.4866781D-11 /
      data fpppp(12,12, 9,1),fpppp(12,12, 9,2),fpppp(12,12, 9,3)/
     x-2.4118911D-08, 2.2745750D-08, 2.8093347D-11 /
      data fpppp(12,12,10,1),fpppp(12,12,10,2),fpppp(12,12,10,3)/
     x-1.4934337D-08, 1.7620276D-08,-2.4866781D-11 /
      data fpppp(12,12,11,1),fpppp(12,12,11,2),fpppp(12,12,11,3)/
     x 1.0487916D-08,-9.1800747D-09, 8.6740880D-12 /
      data fpppp(12,12,12,1),fpppp(12,12,12,2),fpppp(12,12,12,3)/
     x 4.2039199D-08,-3.8405735D-08, 9.3087092D-12 /
      data fpppp(12,12,13,1),fpppp(12,12,13,2),fpppp(12,12,13,3)/
     x 3.1869934D-08,-1.9883521D-09,-5.4291808D-12 /
      data fpppp(12,12,14,1),fpppp(12,12,14,2),fpppp(12,12,14,3)/
     x 5.2112215D-09, 1.6385404D-08,-8.0097509D-12 /
      data fpppp(12,12,15,1),fpppp(12,12,15,2),fpppp(12,12,15,3)/
     x-3.4562127D-09, 9.0191926D-09, 1.2224291D-11 /
      data fpppp(12,12,16,1),fpppp(12,12,16,2),fpppp(12,12,16,3)/
     x 5.2112215D-09, 1.2617531D-08,-6.0405979D-12 /
      data fpppp(12,12,17,1),fpppp(12,12,17,2),fpppp(12,12,17,3)/
     x 3.1869934D-08, 1.3083141D-08,-1.3305793D-11 /
      data fpppp(12,13, 1,1),fpppp(12,13, 1,2),fpppp(12,13, 1,3)/
     x 5.3117524D-08, 1.8231661D-08, 2.7674078D-12 /
      data fpppp(12,13, 2,1),fpppp(12,13, 2,2),fpppp(12,13, 2,3)/
     x 5.0113351D-08, 2.0150397D-08, 4.8347285D-13 /
      data fpppp(12,13, 3,1),fpppp(12,13, 3,2),fpppp(12,13, 3,3)/
     x 4.8409443D-08, 2.0432564D-08,-2.1101648D-12 /
      data fpppp(12,13, 4,1),fpppp(12,13, 4,2),fpppp(12,13, 4,3)/
     x 5.0113351D-08, 2.6442722D-08,-3.6198430D-12 /
      data fpppp(12,13, 5,1),fpppp(12,13, 5,2),fpppp(12,13, 5,3)/
     x 5.3117524D-08,-6.9376409D-09, 1.9180671D-11 /
      data fpppp(12,13, 6,1),fpppp(12,13, 6,2),fpppp(12,13, 6,3)/
     x 3.8516951D-08,-6.5789731D-08,-3.2446144D-11 /
      data fpppp(12,13, 7,1),fpppp(12,13, 7,2),fpppp(12,13, 7,3)/
     x 2.5579437D-08,-7.0219650D-09, 2.1620407D-11 /
      data fpppp(12,13, 8,1),fpppp(12,13, 8,2),fpppp(12,13, 8,3)/
     x 2.4210595D-08, 2.7747018D-08,-3.6150877D-13 /
      data fpppp(12,13, 9,1),fpppp(12,13, 9,2),fpppp(12,13, 9,3)/
     x 1.9622647D-08, 3.1735350D-08,-7.3208855D-12 /
      data fpppp(12,13,10,1),fpppp(12,13,10,2),fpppp(12,13,10,3)/
     x 2.4210595D-08, 2.7747018D-08,-3.6150877D-13 /
      data fpppp(12,13,11,1),fpppp(12,13,11,2),fpppp(12,13,11,3)/
     x 2.5579437D-08,-7.0219650D-09, 2.1620407D-11 /
      data fpppp(12,13,12,1),fpppp(12,13,12,2),fpppp(12,13,12,3)/
     x 3.8516951D-08,-6.5789731D-08,-3.2446144D-11 /
      data fpppp(12,13,13,1),fpppp(12,13,13,2),fpppp(12,13,13,3)/
     x 5.3117524D-08,-6.9376409D-09, 1.9180671D-11 /
      data fpppp(12,13,14,1),fpppp(12,13,14,2),fpppp(12,13,14,3)/
     x 5.0113351D-08, 2.6442722D-08,-3.6198430D-12 /
      data fpppp(12,13,15,1),fpppp(12,13,15,2),fpppp(12,13,15,3)/
     x 4.8409443D-08, 2.0432564D-08,-2.1101648D-12 /
      data fpppp(12,13,16,1),fpppp(12,13,16,2),fpppp(12,13,16,3)/
     x 5.0113351D-08, 2.0150397D-08, 4.8347285D-13 /
      data fpppp(12,13,17,1),fpppp(12,13,17,2),fpppp(12,13,17,3)/
     x 5.3117524D-08, 1.8231661D-08, 2.7674078D-12 /
      data fpppp(12,14, 1,1),fpppp(12,14, 1,2),fpppp(12,14, 1,3)/
     x 4.3832724D-08, 2.2421019D-08, 1.5433060D-11 /
      data fpppp(12,14, 2,1),fpppp(12,14, 2,2),fpppp(12,14, 2,3)/
     x 1.0168091D-07, 2.7199034D-08, 1.1046242D-11 /
      data fpppp(12,14, 3,1),fpppp(12,14, 3,2),fpppp(12,14, 3,3)/
     x 1.1340019D-07, 3.2193507D-08,-4.7386721D-12 /
      data fpppp(12,14, 4,1),fpppp(12,14, 4,2),fpppp(12,14, 4,3)/
     x 1.0168091D-07, 3.6430376D-08, 1.9369748D-11 /
      data fpppp(12,14, 5,1),fpppp(12,14, 5,2),fpppp(12,14, 5,3)/
     x 4.3832724D-08,-1.4504349D-08,-1.7860964D-11 /
      data fpppp(12,14, 6,1),fpppp(12,14, 6,2),fpppp(12,14, 6,3)/
     x-6.4404642D-09,-9.1449213D-08,-1.0134916D-11 /
      data fpppp(12,14, 7,1),fpppp(12,14, 7,2),fpppp(12,14, 7,3)/
     x 3.1185984D-08,-3.2743476D-09, 1.3854879D-11 /
      data fpppp(12,14, 8,1),fpppp(12,14, 8,2),fpppp(12,14, 8,3)/
     x 7.5892699D-08, 3.6400547D-08, 8.8121720D-13 /
      data fpppp(12,14, 9,1),fpppp(12,14, 9,2),fpppp(12,14, 9,3)/
     x 9.1234681D-08, 4.2139023D-08,-6.0940059D-12 /
      data fpppp(12,14,10,1),fpppp(12,14,10,2),fpppp(12,14,10,3)/
     x 7.5892699D-08, 3.6400547D-08, 8.8121720D-13 /
      data fpppp(12,14,11,1),fpppp(12,14,11,2),fpppp(12,14,11,3)/
     x 3.1185984D-08,-3.2743476D-09, 1.3854879D-11 /
      data fpppp(12,14,12,1),fpppp(12,14,12,2),fpppp(12,14,12,3)/
     x-6.4404642D-09,-9.1449213D-08,-1.0134916D-11 /
      data fpppp(12,14,13,1),fpppp(12,14,13,2),fpppp(12,14,13,3)/
     x 4.3832724D-08,-1.4504349D-08,-1.7860964D-11 /
      data fpppp(12,14,14,1),fpppp(12,14,14,2),fpppp(12,14,14,3)/
     x 1.0168091D-07, 3.6430376D-08, 1.9369748D-11 /
      data fpppp(12,14,15,1),fpppp(12,14,15,2),fpppp(12,14,15,3)/
     x 1.1340019D-07, 3.2193507D-08,-4.7386721D-12 /
      data fpppp(12,14,16,1),fpppp(12,14,16,2),fpppp(12,14,16,3)/
     x 1.0168091D-07, 2.7199034D-08, 1.1046242D-11 /
      data fpppp(12,14,17,1),fpppp(12,14,17,2),fpppp(12,14,17,3)/
     x 4.3832724D-08, 2.2421019D-08, 1.5433060D-11 /
      data fpppp(12,15, 1,1),fpppp(12,15, 1,2),fpppp(12,15, 1,3)/
     x-6.2780206D-09, 2.0412930D-08, 2.3386744D-11 /
      data fpppp(12,15, 2,1),fpppp(12,15, 2,2),fpppp(12,15, 2,3)/
     x 1.1312276D-07, 2.9049412D-08, 1.2892106D-11 /
      data fpppp(12,15, 3,1),fpppp(12,15, 3,2),fpppp(12,15, 3,3)/
     x 1.5560694D-07, 4.2041382D-08,-1.7063726D-11 /
      data fpppp(12,15, 4,1),fpppp(12,15, 4,2),fpppp(12,15, 4,3)/
     x 1.1312276D-07, 3.9789142D-08, 2.1094623D-11 /
      data fpppp(12,15, 5,1),fpppp(12,15, 5,2),fpppp(12,15, 5,3)/
     x-6.2780206D-09,-2.2545990D-08,-9.4233235D-12 /
      data fpppp(12,15, 6,1),fpppp(12,15, 6,2),fpppp(12,15, 6,3)/
     x-7.8550054D-08,-1.0193296D-07,-1.5221931D-11 /
      data fpppp(12,15, 7,1),fpppp(12,15, 7,2),fpppp(12,15, 7,3)/
     x 2.3820696D-08,-1.0986766D-09, 1.7477544D-11 /
      data fpppp(12,15, 8,1),fpppp(12,15, 8,2),fpppp(12,15, 8,3)/
     x 1.2984666D-07, 4.1004458D-08,-1.3025494D-11 /
      data fpppp(12,15, 9,1),fpppp(12,15, 9,2),fpppp(12,15, 9,3)/
     x 1.6758234D-07, 4.9316634D-08, 1.6627976D-11 /
      data fpppp(12,15,10,1),fpppp(12,15,10,2),fpppp(12,15,10,3)/
     x 1.2984666D-07, 4.1004458D-08,-1.3025494D-11 /
      data fpppp(12,15,11,1),fpppp(12,15,11,2),fpppp(12,15,11,3)/
     x 2.3820696D-08,-1.0986766D-09, 1.7477544D-11 /
      data fpppp(12,15,12,1),fpppp(12,15,12,2),fpppp(12,15,12,3)/
     x-7.8550054D-08,-1.0193296D-07,-1.5221931D-11 /
      data fpppp(12,15,13,1),fpppp(12,15,13,2),fpppp(12,15,13,3)/
     x-6.2780206D-09,-2.2545990D-08,-9.4233235D-12 /
      data fpppp(12,15,14,1),fpppp(12,15,14,2),fpppp(12,15,14,3)/
     x 1.1312276D-07, 3.9789142D-08, 2.1094623D-11 /
      data fpppp(12,15,15,1),fpppp(12,15,15,2),fpppp(12,15,15,3)/
     x 1.5560694D-07, 4.2041382D-08,-1.7063726D-11 /
      data fpppp(12,15,16,1),fpppp(12,15,16,2),fpppp(12,15,16,3)/
     x 1.1312276D-07, 2.9049412D-08, 1.2892106D-11 /
      data fpppp(12,15,17,1),fpppp(12,15,17,2),fpppp(12,15,17,3)/
     x-6.2780206D-09, 2.0412930D-08, 2.3386744D-11 /
      data fpppp(12,16, 1,1),fpppp(12,16, 1,2),fpppp(12,16, 1,3)/
     x-7.0208226D-08, 1.1761607D-08,-8.9389226D-12 /
      data fpppp(12,16, 2,1),fpppp(12,16, 2,2),fpppp(12,16, 2,3)/
     x 6.2809597D-08, 2.3039089D-08,-2.6968962D-12 /
      data fpppp(12,16, 3,1),fpppp(12,16, 3,2),fpppp(12,16, 3,3)/
     x 1.2564228D-07, 4.2866361D-08, 1.3281378D-11 /
      data fpppp(12,16, 4,1),fpppp(12,16, 4,2),fpppp(12,16, 4,3)/
     x 6.2809597D-08, 3.2769371D-08,-4.8172151D-12 /
      data fpppp(12,16, 5,1),fpppp(12,16, 5,2),fpppp(12,16, 5,3)/
     x-7.0208226D-08,-2.7159518D-08,-4.5764677D-13 /
      data fpppp(12,16, 6,1),fpppp(12,16, 6,2),fpppp(12,16, 6,3)/
     x-1.2655468D-07,-8.5443817D-08,-3.8607649D-12 /
      data fpppp(12,16, 7,1),fpppp(12,16, 7,2),fpppp(12,16, 7,3)/
     x-1.9336469D-09,-2.7495704D-09,-8.2195224D-12 /
      data fpppp(12,16, 8,1),fpppp(12,16, 8,2),fpppp(12,16, 8,3)/
     x 1.3629885D-07, 3.7865350D-08, 2.3922035D-11 /
      data fpppp(12,16, 9,1),fpppp(12,16, 9,2),fpppp(12,16, 9,3)/
     x 1.8914671D-07, 4.8191722D-08,-2.6768536D-11 /
      data fpppp(12,16,10,1),fpppp(12,16,10,2),fpppp(12,16,10,3)/
     x 1.3629885D-07, 3.7865350D-08, 2.3922035D-11 /
      data fpppp(12,16,11,1),fpppp(12,16,11,2),fpppp(12,16,11,3)/
     x-1.9336469D-09,-2.7495704D-09,-8.2195224D-12 /
      data fpppp(12,16,12,1),fpppp(12,16,12,2),fpppp(12,16,12,3)/
     x-1.2655468D-07,-8.5443817D-08,-3.8607649D-12 /
      data fpppp(12,16,13,1),fpppp(12,16,13,2),fpppp(12,16,13,3)/
     x-7.0208226D-08,-2.7159518D-08,-4.5764677D-13 /
      data fpppp(12,16,14,1),fpppp(12,16,14,2),fpppp(12,16,14,3)/
     x 6.2809597D-08, 3.2769371D-08,-4.8172151D-12 /
      data fpppp(12,16,15,1),fpppp(12,16,15,2),fpppp(12,16,15,3)/
     x 1.2564228D-07, 4.2866361D-08, 1.3281378D-11 /
      data fpppp(12,16,16,1),fpppp(12,16,16,2),fpppp(12,16,16,3)/
     x 6.2809597D-08, 2.3039089D-08,-2.6968962D-12 /
      data fpppp(12,16,17,1),fpppp(12,16,17,2),fpppp(12,16,17,3)/
     x-7.0208226D-08, 1.1761607D-08,-8.9389226D-12 /
      data fpppp(12,17, 1,1),fpppp(12,17, 1,2),fpppp(12,17, 1,3)/
     x-9.5987225D-08, 1.6340266D-09,-1.1988360D-11 /
      data fpppp(12,17, 2,1),fpppp(12,17, 2,2),fpppp(12,17, 2,3)/
     x-6.9000060D-08, 1.1156654D-08,-6.7232421D-12 /
      data fpppp(12,17, 3,1),fpppp(12,17, 3,2),fpppp(12,17, 3,3)/
     x-3.8840941D-08, 2.9268803D-08, 6.7704019D-12 /
      data fpppp(12,17, 4,1),fpppp(12,17, 4,2),fpppp(12,17, 4,3)/
     x-6.9000060D-08, 1.7317628D-08,-8.5357939D-12 /
      data fpppp(12,17, 5,1),fpppp(12,17, 5,2),fpppp(12,17, 5,3)/
     x-9.5987225D-08,-2.3009870D-08,-4.7381529D-12 /
      data fpppp(12,17, 6,1),fpppp(12,17, 6,2),fpppp(12,17, 6,3)/
     x-3.6628004D-08,-4.6668666D-08, 2.1343276D-11 /
      data fpppp(12,17, 7,1),fpppp(12,17, 7,2),fpppp(12,17, 7,3)/
     x-1.2243387D-09,-5.1346445D-09,-1.1320531D-11 /
      data fpppp(12,17, 8,1),fpppp(12,17, 8,2),fpppp(12,17, 8,3)/
     x 6.8083505D-08, 2.5599765D-08,-6.4566233D-12 /
      data fpppp(12,17, 9,1),fpppp(12,17, 9,2),fpppp(12,17, 9,3)/
     x 1.0840445D-07, 3.5549601D-08, 1.2343156D-11 /
      data fpppp(12,17,10,1),fpppp(12,17,10,2),fpppp(12,17,10,3)/
     x 6.8083505D-08, 2.5599765D-08,-6.4566233D-12 /
      data fpppp(12,17,11,1),fpppp(12,17,11,2),fpppp(12,17,11,3)/
     x-1.2243387D-09,-5.1346445D-09,-1.1320531D-11 /
      data fpppp(12,17,12,1),fpppp(12,17,12,2),fpppp(12,17,12,3)/
     x-3.6628004D-08,-4.6668666D-08, 2.1343276D-11 /
      data fpppp(12,17,13,1),fpppp(12,17,13,2),fpppp(12,17,13,3)/
     x-9.5987225D-08,-2.3009870D-08,-4.7381529D-12 /
      data fpppp(12,17,14,1),fpppp(12,17,14,2),fpppp(12,17,14,3)/
     x-6.9000060D-08, 1.7317628D-08,-8.5357939D-12 /
      data fpppp(12,17,15,1),fpppp(12,17,15,2),fpppp(12,17,15,3)/
     x-3.8840941D-08, 2.9268803D-08, 6.7704019D-12 /
      data fpppp(12,17,16,1),fpppp(12,17,16,2),fpppp(12,17,16,3)/
     x-6.9000060D-08, 1.1156654D-08,-6.7232421D-12 /
      data fpppp(12,17,17,1),fpppp(12,17,17,2),fpppp(12,17,17,3)/
     x-9.5987225D-08, 1.6340266D-09,-1.1988360D-11 /
      data fpppp(12,18, 1,1),fpppp(12,18, 1,2),fpppp(12,18, 1,3)/
     x-2.4220626D-08,-3.0088652D-09,-5.8923684D-12 /
      data fpppp(12,18, 2,1),fpppp(12,18, 2,2),fpppp(12,18, 2,3)/
     x-1.7235085D-07, 6.3471405D-10,-4.8406707D-12 /
      data fpppp(12,18, 3,1),fpppp(12,18, 3,2),fpppp(12,18, 3,3)/
     x-2.3026508D-07, 8.3799843D-09, 1.4388725D-13 /
      data fpppp(12,18, 4,1),fpppp(12,18, 4,2),fpppp(12,18, 4,3)/
     x-1.7235085D-07, 1.7693360D-09,-8.6365654D-12 /
      data fpppp(12,18, 5,1),fpppp(12,18, 5,2),fpppp(12,18, 5,3)/
     x-2.4220626D-08,-7.5473528D-09, 9.2912107D-12 /
      data fpppp(12,18, 6,1),fpppp(12,18, 6,2),fpppp(12,18, 6,3)/
     x 5.9402022D-08,-1.3320736D-08, 6.5608071D-12 /
      data fpppp(12,18, 7,1),fpppp(12,18, 7,2),fpppp(12,18, 7,3)/
     x 1.4030579D-08,-1.9957917D-09,-8.6718927D-12 /
      data fpppp(12,18, 8,1),fpppp(12,18, 8,2),fpppp(12,18, 8,3)/
     x-6.3089850D-08, 9.7189384D-09, 2.5254697D-12 /
      data fpppp(12,18, 9,1),fpppp(12,18, 9,2),fpppp(12,18, 9,3)/
     x-9.4435674D-08, 1.4560332D-08,-2.9145952D-12 /
      data fpppp(12,18,10,1),fpppp(12,18,10,2),fpppp(12,18,10,3)/
     x-6.3089850D-08, 9.7189384D-09, 2.5254697D-12 /
      data fpppp(12,18,11,1),fpppp(12,18,11,2),fpppp(12,18,11,3)/
     x 1.4030579D-08,-1.9957917D-09,-8.6718927D-12 /
      data fpppp(12,18,12,1),fpppp(12,18,12,2),fpppp(12,18,12,3)/
     x 5.9402022D-08,-1.3320736D-08, 6.5608071D-12 /
      data fpppp(12,18,13,1),fpppp(12,18,13,2),fpppp(12,18,13,3)/
     x-2.4220626D-08,-7.5473528D-09, 9.2912107D-12 /
      data fpppp(12,18,14,1),fpppp(12,18,14,2),fpppp(12,18,14,3)/
     x-1.7235085D-07, 1.7693360D-09,-8.6365654D-12 /
      data fpppp(12,18,15,1),fpppp(12,18,15,2),fpppp(12,18,15,3)/
     x-2.3026508D-07, 8.3799843D-09, 1.4388725D-13 /
      data fpppp(12,18,16,1),fpppp(12,18,16,2),fpppp(12,18,16,3)/
     x-1.7235085D-07, 6.3471405D-10,-4.8406707D-12 /
      data fpppp(12,18,17,1),fpppp(12,18,17,2),fpppp(12,18,17,3)/
     x-2.4220626D-08,-3.0088652D-09,-5.8923684D-12 /
      data fpppp(12,19, 1,1),fpppp(12,19, 1,2),fpppp(12,19, 1,3)/
     x 1.9675803D-08,-2.7119208D-22,-2.4093564D-12 /
      data fpppp(12,19, 2,1),fpppp(12,19, 2,2),fpppp(12,19, 2,3)/
     x-2.8383275D-07, 1.9918914D-22,-4.6463613D-12 /
      data fpppp(12,19, 3,1),fpppp(12,19, 3,2),fpppp(12,19, 3,3)/
     x-4.1399181D-07, 5.3862849D-23,-6.4496164D-12 /
      data fpppp(12,19, 4,1),fpppp(12,19, 4,2),fpppp(12,19, 4,3)/
     x-2.8383275D-07,-1.3906872D-23,-9.7709962D-12 /
      data fpppp(12,19, 5,1),fpppp(12,19, 5,2),fpppp(12,19, 5,3)/
     x 1.9675803D-08, 9.6047037D-23, 1.8089183D-11 /
      data fpppp(12,19, 6,1),fpppp(12,19, 6,2),fpppp(12,19, 6,3)/
     x 1.5368823D-07, 1.0018963D-22, 3.2030552D-12 /
      data fpppp(12,19, 7,1),fpppp(12,19, 7,2),fpppp(12,19, 7,3)/
     x 2.5129608D-08,-3.7994136D-23,-7.6660105D-12 /
      data fpppp(12,19, 8,1),fpppp(12,19, 8,2),fpppp(12,19, 8,3)/
     x-1.7627520D-07, 1.8041938D-23, 2.6163378D-13 /
      data fpppp(12,19, 9,1),fpppp(12,19, 9,2),fpppp(12,19, 9,3)/
     x-2.6239069D-07, 1.8980681D-23,-2.6382200D-12 /
      data fpppp(12,19,10,1),fpppp(12,19,10,2),fpppp(12,19,10,3)/
     x-1.7627520D-07, 7.0294488D-23, 2.6163378D-13 /
      data fpppp(12,19,11,1),fpppp(12,19,11,2),fpppp(12,19,11,3)/
     x 2.5129608D-08,-5.2280037D-23,-7.6660105D-12 /
      data fpppp(12,19,12,1),fpppp(12,19,12,2),fpppp(12,19,12,3)/
     x 1.5368823D-07,-6.4371105D-23, 3.2030552D-12 /
      data fpppp(12,19,13,1),fpppp(12,19,13,2),fpppp(12,19,13,3)/
     x 1.9675803D-08,-7.7074318D-23, 1.8089183D-11 /
      data fpppp(12,19,14,1),fpppp(12,19,14,2),fpppp(12,19,14,3)/
     x-2.8383275D-07, 5.2259218D-23,-9.7709962D-12 /
      data fpppp(12,19,15,1),fpppp(12,19,15,2),fpppp(12,19,15,3)/
     x-4.1399181D-07,-4.9025590D-23,-6.4496164D-12 /
      data fpppp(12,19,16,1),fpppp(12,19,16,2),fpppp(12,19,16,3)/
     x-2.8383275D-07, 5.2282957D-23,-4.6463613D-12 /
      data fpppp(12,19,17,1),fpppp(12,19,17,2),fpppp(12,19,17,3)/
     x 1.9675803D-08,-9.9029921D-23,-2.4093564D-12 /
      data fpppp(13, 1, 1,1),fpppp(13, 1, 1,2),fpppp(13, 1, 1,3)/
     x-2.1700229D-08,-5.3653811D-23,-1.2698237D-11 /
      data fpppp(13, 1, 2,1),fpppp(13, 1, 2,2),fpppp(13, 1, 2,3)/
     x 1.3256998D-07, 4.3422001D-23,-7.2895079D-12 /
      data fpppp(13, 1, 3,1),fpppp(13, 1, 3,2),fpppp(13, 1, 3,3)/
     x 2.0779257D-07,-6.9724569D-24, 8.7850563D-12 /
      data fpppp(13, 1, 4,1),fpppp(13, 1, 4,2),fpppp(13, 1, 4,3)/
     x 1.3256998D-07,-3.7154134D-23,-1.2470802D-11 /
      data fpppp(13, 1, 5,1),fpppp(13, 1, 5,2),fpppp(13, 1, 5,3)/
     x-2.1700229D-08,-1.7343212D-23, 8.0269369D-12 /
      data fpppp(13, 1, 6,1),fpppp(13, 1, 6,2),fpppp(13, 1, 6,3)/
     x-1.1170441D-07,-7.4684131D-24,-1.8419353D-12 /
      data fpppp(13, 1, 7,1),fpppp(13, 1, 7,2),fpppp(13, 1, 7,3)/
     x-6.2550552D-08,-4.6329732D-23, 7.9119249D-12 /
      data fpppp(13, 1, 8,1),fpppp(13, 1, 8,2),fpppp(13, 1, 8,3)/
     x 6.8551088D-08, 5.9041836D-23,-1.2857136D-11 /
      data fpppp(13, 1, 9,1),fpppp(13, 1, 9,2),fpppp(13, 1, 9,3)/
     x 1.3985164D-07,-2.3523253D-23, 1.2813416D-11 /
      data fpppp(13, 1,10,1),fpppp(13, 1,10,2),fpppp(13, 1,10,3)/
     x 6.8551088D-08,-4.6305241D-23,-1.2857136D-11 /
      data fpppp(13, 1,11,1),fpppp(13, 1,11,2),fpppp(13, 1,11,3)/
     x-6.2550552D-08,-8.0535039D-23, 7.9119249D-12 /
      data fpppp(13, 1,12,1),fpppp(13, 1,12,2),fpppp(13, 1,12,3)/
     x-1.1170441D-07, 4.8170487D-23,-1.8419353D-12 /
      data fpppp(13, 1,13,1),fpppp(13, 1,13,2),fpppp(13, 1,13,3)/
     x-2.1700229D-08, 3.0142867D-23, 8.0269369D-12 /
      data fpppp(13, 1,14,1),fpppp(13, 1,14,2),fpppp(13, 1,14,3)/
     x 1.3256998D-07,-5.4921298D-23,-1.2470802D-11 /
      data fpppp(13, 1,15,1),fpppp(13, 1,15,2),fpppp(13, 1,15,3)/
     x 2.0779257D-07, 2.0840775D-24, 8.7850563D-12 /
      data fpppp(13, 1,16,1),fpppp(13, 1,16,2),fpppp(13, 1,16,3)/
     x 1.3256998D-07, 3.6130004D-23,-7.2895079D-12 /
      data fpppp(13, 1,17,1),fpppp(13, 1,17,2),fpppp(13, 1,17,3)/
     x-2.1700229D-08,-3.0948990D-23,-1.2698237D-11 /
      data fpppp(13, 2, 1,1),fpppp(13, 2, 1,2),fpppp(13, 2, 1,3)/
     x 4.9392916D-09,-1.4416727D-09,-5.7498189D-12 /
      data fpppp(13, 2, 2,1),fpppp(13, 2, 2,2),fpppp(13, 2, 2,3)/
     x 6.5853068D-08,-3.7161351D-09,-3.1283970D-12 /
      data fpppp(13, 2, 3,1),fpppp(13, 2, 3,2),fpppp(13, 2, 3,3)/
     x 1.1048379D-07,-8.3490025D-09, 4.4058323D-12 /
      data fpppp(13, 2, 4,1),fpppp(13, 2, 4,2),fpppp(13, 2, 4,3)/
     x 6.5853068D-08,-4.7274523D-09,-5.2547642D-12 /
      data fpppp(13, 2, 5,1),fpppp(13, 2, 5,2),fpppp(13, 2, 5,3)/
     x 4.9392916D-09, 2.6035963D-09, 2.7556500D-12 /
      data fpppp(13, 2, 6,1),fpppp(13, 2, 6,2),fpppp(13, 2, 6,3)/
     x-3.8278761D-08, 6.1355947D-09,-1.3578574D-12 /
      data fpppp(13, 2, 7,1),fpppp(13, 2, 7,2),fpppp(13, 2, 7,3)/
     x-1.8929641D-08, 4.5590596D-09, 5.5335385D-12 /
      data fpppp(13, 2, 8,1),fpppp(13, 2, 8,2),fpppp(13, 2, 8,3)/
     x 3.9175425D-08,-2.0052369D-09,-8.0068869D-12 /
      data fpppp(13, 2, 9,1),fpppp(13, 2, 9,2),fpppp(13, 2, 9,3)/
     x 7.4208099D-08,-4.9506732D-09, 7.9004132D-12 /
      data fpppp(13, 2,10,1),fpppp(13, 2,10,2),fpppp(13, 2,10,3)/
     x 3.9175425D-08,-2.0052369D-09,-8.0068869D-12 /
      data fpppp(13, 2,11,1),fpppp(13, 2,11,2),fpppp(13, 2,11,3)/
     x-1.8929641D-08, 4.5590596D-09, 5.5335385D-12 /
      data fpppp(13, 2,12,1),fpppp(13, 2,12,2),fpppp(13, 2,12,3)/
     x-3.8278761D-08, 6.1355947D-09,-1.3578574D-12 /
      data fpppp(13, 2,13,1),fpppp(13, 2,13,2),fpppp(13, 2,13,3)/
     x 4.9392916D-09, 2.6035963D-09, 2.7556500D-12 /
      data fpppp(13, 2,14,1),fpppp(13, 2,14,2),fpppp(13, 2,14,3)/
     x 6.5853068D-08,-4.7274523D-09,-5.2547642D-12 /
      data fpppp(13, 2,15,1),fpppp(13, 2,15,2),fpppp(13, 2,15,3)/
     x 1.1048379D-07,-8.3490025D-09, 4.4058323D-12 /
      data fpppp(13, 2,16,1),fpppp(13, 2,16,2),fpppp(13, 2,16,3)/
     x 6.5853068D-08,-3.7161351D-09,-3.1283970D-12 /
      data fpppp(13, 2,17,1),fpppp(13, 2,17,2),fpppp(13, 2,17,3)/
     x 4.9392916D-09,-1.4416727D-09,-5.7498189D-12 /
      data fpppp(13, 3, 1,1),fpppp(13, 3, 1,2),fpppp(13, 3, 1,3)/
     x 6.3840575D-09, 1.6998115D-09,-1.6249384D-12 /
      data fpppp(13, 3, 2,1),fpppp(13, 3, 2,2),fpppp(13, 3, 2,3)/
     x 1.5068459D-08,-8.5887157D-09, 1.1146652D-12 /
      data fpppp(13, 3, 3,1),fpppp(13, 3, 3,2),fpppp(13, 3, 3,3)/
     x 3.5276465D-08,-3.1394960D-08, 5.6677885D-12 /
      data fpppp(13, 3, 4,1),fpppp(13, 3, 4,2),fpppp(13, 3, 4,3)/
     x 1.5068459D-08,-1.0389195D-08, 3.8735926D-12 /
      data fpppp(13, 3, 5,1),fpppp(13, 3, 5,2),fpppp(13, 3, 5,3)/
     x 6.3840575D-09, 8.9017297D-09,-1.2660648D-11 /
      data fpppp(13, 3, 6,1),fpppp(13, 3, 6,2),fpppp(13, 3, 6,3)/
     x 4.6382970D-08, 1.8842024D-08, 1.1334075D-11 /
      data fpppp(13, 3, 7,1),fpppp(13, 3, 7,2),fpppp(13, 3, 7,3)/
     x 1.9537844D-08, 1.4982766D-08,-1.2677809D-11 /
      data fpppp(13, 3, 8,1),fpppp(13, 3, 8,2),fpppp(13, 3, 8,3)/
     x 4.9114741D-10,-6.8432297D-09, 1.1350892D-11 /
      data fpppp(13, 3, 9,1),fpppp(13, 3, 9,2),fpppp(13, 3, 9,3)/
     x-5.5899615D-09,-1.9893310D-08,-7.6481733D-12 /
      data fpppp(13, 3,10,1),fpppp(13, 3,10,2),fpppp(13, 3,10,3)/
     x 4.9114741D-10,-6.8432297D-09, 1.1350892D-11 /
      data fpppp(13, 3,11,1),fpppp(13, 3,11,2),fpppp(13, 3,11,3)/
     x 1.9537844D-08, 1.4982766D-08,-1.2677809D-11 /
      data fpppp(13, 3,12,1),fpppp(13, 3,12,2),fpppp(13, 3,12,3)/
     x 4.6382970D-08, 1.8842024D-08, 1.1334075D-11 /
      data fpppp(13, 3,13,1),fpppp(13, 3,13,2),fpppp(13, 3,13,3)/
     x 6.3840575D-09, 8.9017297D-09,-1.2660648D-11 /
      data fpppp(13, 3,14,1),fpppp(13, 3,14,2),fpppp(13, 3,14,3)/
     x 1.5068459D-08,-1.0389195D-08, 3.8735926D-12 /
      data fpppp(13, 3,15,1),fpppp(13, 3,15,2),fpppp(13, 3,15,3)/
     x 3.5276465D-08,-3.1394960D-08, 5.6677885D-12 /
      data fpppp(13, 3,16,1),fpppp(13, 3,16,2),fpppp(13, 3,16,3)/
     x 1.5068459D-08,-8.5887157D-09, 1.1146652D-12 /
      data fpppp(13, 3,17,1),fpppp(13, 3,17,2),fpppp(13, 3,17,3)/
     x 6.3840575D-09, 1.6998115D-09,-1.6249384D-12 /
      data fpppp(13, 4, 1,1),fpppp(13, 4, 1,2),fpppp(13, 4, 1,3)/
     x 9.6010464D-08, 1.4919932D-08, 1.2382325D-11 /
      data fpppp(13, 4, 2,1),fpppp(13, 4, 2,2),fpppp(13, 4, 2,3)/
     x-9.1479204D-08,-8.5056917D-09, 5.0708982D-12 /
      data fpppp(13, 4, 3,1),fpppp(13, 4, 3,2),fpppp(13, 4, 3,3)/
     x-1.1728596D-07,-6.3064830D-08,-1.2814386D-11 /
      data fpppp(13, 4, 4,1),fpppp(13, 4, 4,2),fpppp(13, 4, 4,3)/
     x-9.1479204D-08,-8.6566677D-09, 6.3088312D-12 /
      data fpppp(13, 4, 5,1),fpppp(13, 4, 5,2),fpppp(13, 4, 5,3)/
     x 9.6010464D-08, 1.5523836D-08, 7.4305931D-12 /
      data fpppp(13, 4, 6,1),fpppp(13, 4, 6,2),fpppp(13, 4, 6,3)/
     x 9.1718425D-08, 2.5152432D-08,-1.8701483D-11 /
      data fpppp(13, 4, 7,1),fpppp(13, 4, 7,2),fpppp(13, 4, 7,3)/
     x 7.6042317D-08, 2.6645133D-08, 2.4526207D-11 /
      data fpppp(13, 4, 8,1),fpppp(13, 4, 8,2),fpppp(13, 4, 8,3)/
     x-5.6129813D-09,-9.7986806D-09,-2.0067684D-11 /
      data fpppp(13, 4, 9,1),fpppp(13, 4, 9,2),fpppp(13, 4, 9,3)/
     x-3.5847221D-08,-3.4692439D-08, 1.4027781D-11 /
      data fpppp(13, 4,10,1),fpppp(13, 4,10,2),fpppp(13, 4,10,3)/
     x-5.6129813D-09,-9.7986806D-09,-2.0067684D-11 /
      data fpppp(13, 4,11,1),fpppp(13, 4,11,2),fpppp(13, 4,11,3)/
     x 7.6042317D-08, 2.6645133D-08, 2.4526207D-11 /
      data fpppp(13, 4,12,1),fpppp(13, 4,12,2),fpppp(13, 4,12,3)/
     x 9.1718425D-08, 2.5152432D-08,-1.8701483D-11 /
      data fpppp(13, 4,13,1),fpppp(13, 4,13,2),fpppp(13, 4,13,3)/
     x 9.6010464D-08, 1.5523836D-08, 7.4305931D-12 /
      data fpppp(13, 4,14,1),fpppp(13, 4,14,2),fpppp(13, 4,14,3)/
     x-9.1479204D-08,-8.6566677D-09, 6.3088312D-12 /
      data fpppp(13, 4,15,1),fpppp(13, 4,15,2),fpppp(13, 4,15,3)/
     x-1.1728596D-07,-6.3064830D-08,-1.2814386D-11 /
      data fpppp(13, 4,16,1),fpppp(13, 4,16,2),fpppp(13, 4,16,3)/
     x-9.1479204D-08,-8.5056917D-09, 5.0708982D-12 /
      data fpppp(13, 4,17,1),fpppp(13, 4,17,2),fpppp(13, 4,17,3)/
     x 9.6010464D-08, 1.4919932D-08, 1.2382325D-11 /
      data fpppp(13, 5, 1,1),fpppp(13, 5, 1,2),fpppp(13, 5, 1,3)/
     x-2.7611308D-07, 3.6192057D-08,-2.2957748D-11 /
      data fpppp(13, 5, 2,1),fpppp(13, 5, 2,2),fpppp(13, 5, 2,3)/
     x-1.4056493D-07,-3.2041268D-10,-1.1291483D-11 /
      data fpppp(13, 5, 3,1),fpppp(13, 5, 3,2),fpppp(13, 5, 3,3)/
     x-2.4882284D-07,-8.9145814D-08, 2.0216044D-11 /
      data fpppp(13, 5, 4,1),fpppp(13, 5, 4,2),fpppp(13, 5, 4,3)/
     x-1.4056493D-07, 5.1240437D-09,-1.7720846D-11 /
      data fpppp(13, 5, 5,1),fpppp(13, 5, 5,2),fpppp(13, 5, 5,3)/
     x-2.7611308D-07, 1.4414232D-08, 2.7597042D-12 /
      data fpppp(13, 5, 6,1),fpppp(13, 5, 6,2),fpppp(13, 5, 6,3)/
     x 5.7905459D-08, 2.2688518D-08, 1.2798072D-11 /
      data fpppp(13, 5, 7,1),fpppp(13, 5, 7,2),fpppp(13, 5, 7,3)/
     x 4.4761486D-08, 3.0076188D-08,-2.2553307D-11 /
      data fpppp(13, 5, 8,1),fpppp(13, 5, 8,2),fpppp(13, 5, 8,3)/
     x-1.6279800D-08,-4.8340764D-09, 2.8098785D-11 /
      data fpppp(13, 5, 9,1),fpppp(13, 5, 9,2),fpppp(13, 5, 9,3)/
     x-4.3467900D-08,-4.4884587D-08,-2.8052422D-11 /
      data fpppp(13, 5,10,1),fpppp(13, 5,10,2),fpppp(13, 5,10,3)/
     x-1.6279800D-08,-4.8340764D-09, 2.8098785D-11 /
      data fpppp(13, 5,11,1),fpppp(13, 5,11,2),fpppp(13, 5,11,3)/
     x 4.4761486D-08, 3.0076188D-08,-2.2553307D-11 /
      data fpppp(13, 5,12,1),fpppp(13, 5,12,2),fpppp(13, 5,12,3)/
     x 5.7905459D-08, 2.2688518D-08, 1.2798072D-11 /
      data fpppp(13, 5,13,1),fpppp(13, 5,13,2),fpppp(13, 5,13,3)/
     x-2.7611308D-07, 1.4414232D-08, 2.7597042D-12 /
      data fpppp(13, 5,14,1),fpppp(13, 5,14,2),fpppp(13, 5,14,3)/
     x-1.4056493D-07, 5.1240437D-09,-1.7720846D-11 /
      data fpppp(13, 5,15,1),fpppp(13, 5,15,2),fpppp(13, 5,15,3)/
     x-2.4882284D-07,-8.9145814D-08, 2.0216044D-11 /
      data fpppp(13, 5,16,1),fpppp(13, 5,16,2),fpppp(13, 5,16,3)/
     x-1.4056493D-07,-3.2041268D-10,-1.1291483D-11 /
      data fpppp(13, 5,17,1),fpppp(13, 5,17,2),fpppp(13, 5,17,3)/
     x-2.7611308D-07, 3.6192057D-08,-2.2957748D-11 /
      data fpppp(13, 6, 1,1),fpppp(13, 6, 1,2),fpppp(13, 6, 1,3)/
     x 4.1779110D-07, 2.4841369D-08, 2.9547875D-11 /
      data fpppp(13, 6, 2,1),fpppp(13, 6, 2,2),fpppp(13, 6, 2,3)/
     x-8.2348603D-08,-5.8933846D-09, 1.3229956D-11 /
      data fpppp(13, 6, 3,1),fpppp(13, 6, 3,2),fpppp(13, 6, 3,3)/
     x-1.7833168D-07,-7.3058170D-08,-3.0688680D-11 /
      data fpppp(13, 6, 4,1),fpppp(13, 6, 4,2),fpppp(13, 6, 4,3)/
     x-8.2348603D-08,-1.2717846D-08, 2.1995190D-11 /
      data fpppp(13, 6, 5,1),fpppp(13, 6, 5,2),fpppp(13, 6, 5,3)/
     x 4.1779110D-07, 5.2139214D-08,-5.5130608D-12 /
      data fpppp(13, 6, 6,1),fpppp(13, 6, 6,2),fpppp(13, 6, 6,3)/
     x 6.8509636D-09,-1.7335009D-08,-1.7368386D-12 /
      data fpppp(13, 6, 7,1),fpppp(13, 6, 7,2),fpppp(13, 6, 7,3)/
     x 5.1032550D-09, 3.4817588D-08, 9.7147979D-12 /
      data fpppp(13, 6, 8,1),fpppp(13, 6, 8,2),fpppp(13, 6, 8,3)/
     x-4.6428665D-09, 2.9413283D-09,-1.9192536D-11 /
      data fpppp(13, 6, 9,1),fpppp(13, 6, 9,2),fpppp(13, 6, 9,3)/
     x-2.2478382D-08,-4.7769793D-08, 2.1614448D-11 /
      data fpppp(13, 6,10,1),fpppp(13, 6,10,2),fpppp(13, 6,10,3)/
     x-4.6428665D-09, 2.9413283D-09,-1.9192536D-11 /
      data fpppp(13, 6,11,1),fpppp(13, 6,11,2),fpppp(13, 6,11,3)/
     x 5.1032550D-09, 3.4817588D-08, 9.7147979D-12 /
      data fpppp(13, 6,12,1),fpppp(13, 6,12,2),fpppp(13, 6,12,3)/
     x 6.8509636D-09,-1.7335009D-08,-1.7368386D-12 /
      data fpppp(13, 6,13,1),fpppp(13, 6,13,2),fpppp(13, 6,13,3)/
     x 4.1779110D-07, 5.2139214D-08,-5.5130608D-12 /
      data fpppp(13, 6,14,1),fpppp(13, 6,14,2),fpppp(13, 6,14,3)/
     x-8.2348603D-08,-1.2717846D-08, 2.1995190D-11 /
      data fpppp(13, 6,15,1),fpppp(13, 6,15,2),fpppp(13, 6,15,3)/
     x-1.7833168D-07,-7.3058170D-08,-3.0688680D-11 /
      data fpppp(13, 6,16,1),fpppp(13, 6,16,2),fpppp(13, 6,16,3)/
     x-8.2348603D-08,-5.8933846D-09, 1.3229956D-11 /
      data fpppp(13, 6,17,1),fpppp(13, 6,17,2),fpppp(13, 6,17,3)/
     x 4.1779110D-07, 2.4841369D-08, 2.9547875D-11 /
      data fpppp(13, 7, 1,1),fpppp(13, 7, 1,2),fpppp(13, 7, 1,3)/
     x-2.9744293D-07, 3.1800818D-08,-2.1178157D-11 /
      data fpppp(13, 7, 2,1),fpppp(13, 7, 2,2),fpppp(13, 7, 2,3)/
     x 3.4932793D-08, 1.0129073D-08,-9.7395325D-12 /
      data fpppp(13, 7, 3,1),fpppp(13, 7, 3,2),fpppp(13, 7, 3,3)/
     x 2.4953359D-08,-4.7166236D-08, 2.0927850D-11 /
      data fpppp(13, 7, 4,1),fpppp(13, 7, 4,2),fpppp(13, 7, 4,3)/
     x 3.4932793D-08, 2.0220932D-08,-1.5705421D-11 /
      data fpppp(13, 7, 5,1),fpppp(13, 7, 5,2),fpppp(13, 7, 5,3)/
     x-2.9744293D-07,-8.5666159D-09, 2.6853961D-12 /
      data fpppp(13, 7, 6,1),fpppp(13, 7, 6,2),fpppp(13, 7, 6,3)/
     x-2.4151417D-08, 1.3010854D-10, 6.0233613D-12 /
      data fpppp(13, 7, 7,1),fpppp(13, 7, 7,2),fpppp(13, 7, 7,3)/
     x-4.8286769D-09, 2.3106160D-08,-7.1950602D-12 /
      data fpppp(13, 7, 8,1),fpppp(13, 7, 8,2),fpppp(13, 7, 8,3)/
     x 3.1285562D-08, 1.2028354D-08, 3.5398107D-13 /
      data fpppp(13, 7, 9,1),fpppp(13, 7, 9,2),fpppp(13, 7, 9,3)/
     x 1.6035096D-08,-4.4989663D-08, 5.7533204D-12 /
      data fpppp(13, 7,10,1),fpppp(13, 7,10,2),fpppp(13, 7,10,3)/
     x 3.1285562D-08, 1.2028354D-08, 3.5398107D-13 /
      data fpppp(13, 7,11,1),fpppp(13, 7,11,2),fpppp(13, 7,11,3)/
     x-4.8286769D-09, 2.3106160D-08,-7.1950602D-12 /
      data fpppp(13, 7,12,1),fpppp(13, 7,12,2),fpppp(13, 7,12,3)/
     x-2.4151417D-08, 1.3010854D-10, 6.0233613D-12 /
      data fpppp(13, 7,13,1),fpppp(13, 7,13,2),fpppp(13, 7,13,3)/
     x-2.9744293D-07,-8.5666159D-09, 2.6853961D-12 /
      data fpppp(13, 7,14,1),fpppp(13, 7,14,2),fpppp(13, 7,14,3)/
     x 3.4932793D-08, 2.0220932D-08,-1.5705421D-11 /
      data fpppp(13, 7,15,1),fpppp(13, 7,15,2),fpppp(13, 7,15,3)/
     x 2.4953359D-08,-4.7166236D-08, 2.0927850D-11 /
      data fpppp(13, 7,16,1),fpppp(13, 7,16,2),fpppp(13, 7,16,3)/
     x 3.4932793D-08, 1.0129073D-08,-9.7395325D-12 /
      data fpppp(13, 7,17,1),fpppp(13, 7,17,2),fpppp(13, 7,17,3)/
     x-2.9744293D-07, 3.1800818D-08,-2.1178157D-11 /
      data fpppp(13, 8, 1,1),fpppp(13, 8, 1,2),fpppp(13, 8, 1,3)/
     x 7.8050425D-08, 6.7320517D-09, 1.7930665D-11 /
      data fpppp(13, 8, 2,1),fpppp(13, 8, 2,2),fpppp(13, 8, 2,3)/
     x 9.1333252D-08, 4.8617261D-09, 6.8630129D-12 /
      data fpppp(13, 8, 3,1),fpppp(13, 8, 3,2),fpppp(13, 8, 3,3)/
     x 1.8329332D-07,-2.5965059D-09,-2.0327988D-11 /
      data fpppp(13, 8, 4,1),fpppp(13, 8, 4,2),fpppp(13, 8, 4,3)/
     x 9.1333252D-08, 9.5029341D-09, 8.9127307D-12 /
      data fpppp(13, 8, 5,1),fpppp(13, 8, 5,2),fpppp(13, 8, 5,3)/
     x 7.8050425D-08,-1.1832780D-08, 9.7317940D-12 /
      data fpppp(13, 8, 6,1),fpppp(13, 8, 6,2),fpppp(13, 8, 6,3)/
     x-4.1289845D-08,-1.2336477D-08,-1.0284114D-11 /
      data fpppp(13, 8, 7,1),fpppp(13, 8, 7,2),fpppp(13, 8, 7,3)/
     x-3.7492548D-09, 2.3703900D-08,-4.1848436D-12 /
      data fpppp(13, 8, 8,1),fpppp(13, 8, 8,2),fpppp(13, 8, 8,3)/
     x 4.1404053D-08, 9.2304417D-09, 1.8705265D-11 /
      data fpppp(13, 8, 9,1),fpppp(13, 8, 9,2),fpppp(13, 8, 9,3)/
     x 6.4422183D-08,-3.3165995D-08,-2.5092056D-11 /
      data fpppp(13, 8,10,1),fpppp(13, 8,10,2),fpppp(13, 8,10,3)/
     x 4.1404053D-08, 9.2304417D-09, 1.8705265D-11 /
      data fpppp(13, 8,11,1),fpppp(13, 8,11,2),fpppp(13, 8,11,3)/
     x-3.7492548D-09, 2.3703900D-08,-4.1848436D-12 /
      data fpppp(13, 8,12,1),fpppp(13, 8,12,2),fpppp(13, 8,12,3)/
     x-4.1289845D-08,-1.2336477D-08,-1.0284114D-11 /
      data fpppp(13, 8,13,1),fpppp(13, 8,13,2),fpppp(13, 8,13,3)/
     x 7.8050425D-08,-1.1832780D-08, 9.7317940D-12 /
      data fpppp(13, 8,14,1),fpppp(13, 8,14,2),fpppp(13, 8,14,3)/
     x 9.1333252D-08, 9.5029341D-09, 8.9127307D-12 /
      data fpppp(13, 8,15,1),fpppp(13, 8,15,2),fpppp(13, 8,15,3)/
     x 1.8329332D-07,-2.5965059D-09,-2.0327988D-11 /
      data fpppp(13, 8,16,1),fpppp(13, 8,16,2),fpppp(13, 8,16,3)/
     x 9.1333252D-08, 4.8617261D-09, 6.8630129D-12 /
      data fpppp(13, 8,17,1),fpppp(13, 8,17,2),fpppp(13, 8,17,3)/
     x 7.8050425D-08, 6.7320517D-09, 1.7930665D-11 /
      data fpppp(13, 9, 1,1),fpppp(13, 9, 1,2),fpppp(13, 9, 1,3)/
     x-7.0294945D-09,-6.5189383D-09,-1.3369533D-11 /
      data fpppp(13, 9, 2,1),fpppp(13, 9, 2,2),fpppp(13, 9, 2,3)/
     x 1.0658949D-07, 8.4428584D-10,-5.3957953D-12 /
      data fpppp(13, 9, 3,1),fpppp(13, 9, 3,2),fpppp(13, 9, 3,3)/
     x 1.7533363D-07, 1.7097928D-08, 1.3942235D-11 /
      data fpppp(13, 9, 4,1),fpppp(13, 9, 4,2),fpppp(13, 9, 4,3)/
     x 1.0658949D-07, 2.2351077D-09,-6.4947577D-12 /
      data fpppp(13, 9, 5,1),fpppp(13, 9, 5,2),fpppp(13, 9, 5,3)/
     x-7.0294945D-09,-1.2082226D-08,-8.9736833D-12 /
      data fpppp(13, 9, 6,1),fpppp(13, 9, 6,2),fpppp(13, 9, 6,3)/
     x-5.2331162D-08,-1.2569580D-08, 1.1106797D-11 /
      data fpppp(13, 9, 7,1),fpppp(13, 9, 7,2),fpppp(13, 9, 7,3)/
     x-6.4081551D-09, 2.3993140D-08, 7.3207462D-12 /
      data fpppp(13, 9, 8,1),fpppp(13, 9, 8,2),fpppp(13, 9, 8,3)/
     x 6.0258396D-08, 2.9870348D-09,-2.4713988D-11 /
      data fpppp(13, 9, 9,1),fpppp(13, 9, 9,2),fpppp(13, 9, 9,3)/
     x 9.8159301D-08,-2.5993078D-08, 2.9384377D-11 /
      data fpppp(13, 9,10,1),fpppp(13, 9,10,2),fpppp(13, 9,10,3)/
     x 6.0258396D-08, 2.9870348D-09,-2.4713988D-11 /
      data fpppp(13, 9,11,1),fpppp(13, 9,11,2),fpppp(13, 9,11,3)/
     x-6.4081551D-09, 2.3993140D-08, 7.3207462D-12 /
      data fpppp(13, 9,12,1),fpppp(13, 9,12,2),fpppp(13, 9,12,3)/
     x-5.2331162D-08,-1.2569580D-08, 1.1106797D-11 /
      data fpppp(13, 9,13,1),fpppp(13, 9,13,2),fpppp(13, 9,13,3)/
     x-7.0294945D-09,-1.2082226D-08,-8.9736833D-12 /
      data fpppp(13, 9,14,1),fpppp(13, 9,14,2),fpppp(13, 9,14,3)/
     x 1.0658949D-07, 2.2351077D-09,-6.4947577D-12 /
      data fpppp(13, 9,15,1),fpppp(13, 9,15,2),fpppp(13, 9,15,3)/
     x 1.7533363D-07, 1.7097928D-08, 1.3942235D-11 /
      data fpppp(13, 9,16,1),fpppp(13, 9,16,2),fpppp(13, 9,16,3)/
     x 1.0658949D-07, 8.4428584D-10,-5.3957953D-12 /
      data fpppp(13, 9,17,1),fpppp(13, 9,17,2),fpppp(13, 9,17,3)/
     x-7.0294945D-09,-6.5189383D-09,-1.3369533D-11 /
      data fpppp(13,10, 1,1),fpppp(13,10, 1,2),fpppp(13,10, 1,3)/
     x 3.8109467D-09,-1.1129924D-08, 1.0541944D-11 /
      data fpppp(13,10, 2,1),fpppp(13,10, 2,2),fpppp(13,10, 2,3)/
     x 8.7755200D-08,-3.5906662D-09, 4.7312138D-12 /
      data fpppp(13,10, 3,1),fpppp(13,10, 3,2),fpppp(13,10, 3,3)/
     x 1.2849524D-07, 1.3819475D-08,-1.0479611D-11 /
      data fpppp(13,10, 4,1),fpppp(13,10, 4,2),fpppp(13,10, 4,3)/
     x 8.7755200D-08,-3.3184769D-09, 7.2098936D-12 /
      data fpppp(13,10, 5,1),fpppp(13,10, 5,2),fpppp(13,10, 5,3)/
     x 3.8109467D-09,-1.2218681D-08, 6.2722489D-13 /
      data fpppp(13,10, 6,1),fpppp(13,10, 6,2),fpppp(13,10, 6,3)/
     x-6.1272295D-08, 5.7058758D-09,-2.1438079D-12 /
      data fpppp(13,10, 7,1),fpppp(13,10, 7,2),fpppp(13,10, 7,3)/
     x 2.8523021D-09, 2.2467088D-08,-7.5594814D-12 /
      data fpppp(13,10, 8,1),fpppp(13,10, 8,2),fpppp(13,10, 8,3)/
     x 6.8624086D-08,-4.2555283D-09, 1.7996784D-11 /
      data fpppp(13,10, 9,1),fpppp(13,10, 9,2),fpppp(13,10, 9,3)/
     x 1.1385583D-07,-3.0534665D-08,-2.1368502D-11 /
      data fpppp(13,10,10,1),fpppp(13,10,10,2),fpppp(13,10,10,3)/
     x 6.8624086D-08,-4.2555283D-09, 1.7996784D-11 /
      data fpppp(13,10,11,1),fpppp(13,10,11,2),fpppp(13,10,11,3)/
     x 2.8523021D-09, 2.2467088D-08,-7.5594814D-12 /
      data fpppp(13,10,12,1),fpppp(13,10,12,2),fpppp(13,10,12,3)/
     x-6.1272295D-08, 5.7058758D-09,-2.1438079D-12 /
      data fpppp(13,10,13,1),fpppp(13,10,13,2),fpppp(13,10,13,3)/
     x 3.8109467D-09,-1.2218681D-08, 6.2722489D-13 /
      data fpppp(13,10,14,1),fpppp(13,10,14,2),fpppp(13,10,14,3)/
     x 8.7755200D-08,-3.3184769D-09, 7.2098936D-12 /
      data fpppp(13,10,15,1),fpppp(13,10,15,2),fpppp(13,10,15,3)/
     x 1.2849524D-07, 1.3819475D-08,-1.0479611D-11 /
      data fpppp(13,10,16,1),fpppp(13,10,16,2),fpppp(13,10,16,3)/
     x 8.7755200D-08,-3.5906662D-09, 4.7312138D-12 /
      data fpppp(13,10,17,1),fpppp(13,10,17,2),fpppp(13,10,17,3)/
     x 3.8109467D-09,-1.1129924D-08, 1.0541944D-11 /
      data fpppp(13,11, 1,1),fpppp(13,11, 1,2),fpppp(13,11, 1,3)/
     x-4.6870768D-08,-1.7385419D-08,-3.9694521D-12 /
      data fpppp(13,11, 2,1),fpppp(13,11, 2,2),fpppp(13,11, 2,3)/
     x 5.8342203D-08,-1.2884822D-08,-3.1866445D-12 /
      data fpppp(13,11, 3,1),fpppp(13,11, 3,2),fpppp(13,11, 3,3)/
     x 8.5864644D-08,-1.1978994D-09, 1.7777556D-12 /
      data fpppp(13,11, 4,1),fpppp(13,11, 4,2),fpppp(13,11, 4,3)/
     x 5.8342203D-08,-1.4663113D-08,-7.8934177D-12 /
      data fpppp(13,11, 5,1),fpppp(13,11, 5,2),fpppp(13,11, 5,3)/
     x-4.6870768D-08,-1.0272253D-08, 1.4857641D-11 /
      data fpppp(13,11, 6,1),fpppp(13,11, 6,2),fpppp(13,11, 6,3)/
     x-8.7271646D-08, 4.4615678D-08,-1.0554392D-11 /
      data fpppp(13,11, 7,1),fpppp(13,11, 7,2),fpppp(13,11, 7,3)/
     x-7.6542899D-09, 1.7217906D-08, 6.6156329D-12 /
      data fpppp(13,11, 8,1),fpppp(13,11, 8,2),fpppp(13,11, 8,3)/
     x 8.5530031D-08,-1.2695558D-08,-1.4044135D-11 /
      data fpppp(13,11, 9,1),fpppp(13,11, 9,2),fpppp(13,11, 9,3)/
     x 1.0117525D-07,-4.7503803D-08, 1.9475124D-11 /
      data fpppp(13,11,10,1),fpppp(13,11,10,2),fpppp(13,11,10,3)/
     x 8.5530031D-08,-1.2695558D-08,-1.4044135D-11 /
      data fpppp(13,11,11,1),fpppp(13,11,11,2),fpppp(13,11,11,3)/
     x-7.6542899D-09, 1.7217906D-08, 6.6156329D-12 /
      data fpppp(13,11,12,1),fpppp(13,11,12,2),fpppp(13,11,12,3)/
     x-8.7271646D-08, 4.4615678D-08,-1.0554392D-11 /
      data fpppp(13,11,13,1),fpppp(13,11,13,2),fpppp(13,11,13,3)/
     x-4.6870768D-08,-1.0272253D-08, 1.4857641D-11 /
      data fpppp(13,11,14,1),fpppp(13,11,14,2),fpppp(13,11,14,3)/
     x 5.8342203D-08,-1.4663113D-08,-7.8934177D-12 /
      data fpppp(13,11,15,1),fpppp(13,11,15,2),fpppp(13,11,15,3)/
     x 8.5864644D-08,-1.1978994D-09, 1.7777556D-12 /
      data fpppp(13,11,16,1),fpppp(13,11,16,2),fpppp(13,11,16,3)/
     x 5.8342203D-08,-1.2884822D-08,-3.1866445D-12 /
      data fpppp(13,11,17,1),fpppp(13,11,17,2),fpppp(13,11,17,3)/
     x-4.6870768D-08,-1.7385419D-08,-3.9694521D-12 /
      data fpppp(13,12, 1,1),fpppp(13,12, 1,2),fpppp(13,12, 1,3)/
     x-8.1436612D-08,-3.1779271D-08,-6.8521984D-12 /
      data fpppp(13,12, 2,1),fpppp(13,12, 2,2),fpppp(13,12, 2,3)/
     x-8.4700217D-09,-3.0122650D-08,-9.4184421D-13 /
      data fpppp(13,12, 3,1),fpppp(13,12, 3,2),fpppp(13,12, 3,3)/
     x 1.6357156D-08,-2.0980642D-08, 1.1385484D-11 /
      data fpppp(13,12, 4,1),fpppp(13,12, 4,2),fpppp(13,12, 4,3)/
     x-8.4700217D-09,-3.8037491D-08, 1.2534025D-12 /
      data fpppp(13,12, 5,1),fpppp(13,12, 5,2),fpppp(13,12, 5,3)/
     x-8.1436612D-08,-1.1990770D-10,-1.5633185D-11 /
      data fpppp(13,12, 6,1),fpppp(13,12, 6,2),fpppp(13,12, 6,3)/
     x-9.0182091D-08, 1.0076828D-07, 9.7733397D-12 /
      data fpppp(13,12, 7,1),fpppp(13,12, 7,2),fpppp(13,12, 7,3)/
     x-1.8607729D-08, 1.1413911D-08,-4.9755016D-12 /
      data fpppp(13,12, 8,1),fpppp(13,12, 8,2),fpppp(13,12, 8,3)/
     x 4.4258672D-08,-3.0913898D-08, 1.7057597D-11 /
      data fpppp(13,12, 9,1),fpppp(13,12, 9,2),fpppp(13,12, 9,3)/
     x 6.2022976D-08,-6.6560281D-08,-2.5970915D-11 /
      data fpppp(13,12,10,1),fpppp(13,12,10,2),fpppp(13,12,10,3)/
     x 4.4258672D-08,-3.0913898D-08, 1.7057597D-11 /
      data fpppp(13,12,11,1),fpppp(13,12,11,2),fpppp(13,12,11,3)/
     x-1.8607729D-08, 1.1413911D-08,-4.9755016D-12 /
      data fpppp(13,12,12,1),fpppp(13,12,12,2),fpppp(13,12,12,3)/
     x-9.0182091D-08, 1.0076828D-07, 9.7733397D-12 /
      data fpppp(13,12,13,1),fpppp(13,12,13,2),fpppp(13,12,13,3)/
     x-8.1436612D-08,-1.1990770D-10,-1.5633185D-11 /
      data fpppp(13,12,14,1),fpppp(13,12,14,2),fpppp(13,12,14,3)/
     x-8.4700217D-09,-3.8037491D-08, 1.2534025D-12 /
      data fpppp(13,12,15,1),fpppp(13,12,15,2),fpppp(13,12,15,3)/
     x 1.6357156D-08,-2.0980642D-08, 1.1385484D-11 /
      data fpppp(13,12,16,1),fpppp(13,12,16,2),fpppp(13,12,16,3)/
     x-8.4700217D-09,-3.0122650D-08,-9.4184421D-13 /
      data fpppp(13,12,17,1),fpppp(13,12,17,2),fpppp(13,12,17,3)/
     x-8.1436612D-08,-3.1779271D-08,-6.8521984D-12 /
      data fpppp(13,13, 1,1),fpppp(13,13, 1,2),fpppp(13,13, 1,3)/
     x-9.3498666D-08,-4.9449236D-08, 6.7116608D-12 /
      data fpppp(13,13, 2,1),fpppp(13,13, 2,2),fpppp(13,13, 2,3)/
     x-1.1739083D-07,-5.1753626D-08, 2.9538577D-12 /
      data fpppp(13,13, 3,1),fpppp(13,13, 3,2),fpppp(13,13, 3,3)/
     x-1.0256802D-07,-4.5640597D-08,-6.6524538D-12 /
      data fpppp(13,13, 4,1),fpppp(13,13, 4,2),fpppp(13,13, 4,3)/
     x-1.1739083D-07,-6.8988532D-08, 4.2110138D-12 /
      data fpppp(13,13, 5,1),fpppp(13,13, 5,2),fpppp(13,13, 5,3)/
     x-9.3498666D-08, 1.9490391D-08, 1.6830364D-12 /
      data fpppp(13,13, 6,1),fpppp(13,13, 6,2),fpppp(13,13, 6,3)/
     x-4.3812773D-08, 1.6527576D-07,-5.9019185D-12 /
      data fpppp(13,13, 7,1),fpppp(13,13, 7,2),fpppp(13,13, 7,3)/
     x-5.1723808D-08, 5.3658528D-09, 8.7302452D-12 /
      data fpppp(13,13, 8,1),fpppp(13,13, 8,2),fpppp(13,13, 8,3)/
     x-3.9258507D-08,-5.6609595D-08,-1.8598790D-11 /
      data fpppp(13,13, 9,1),fpppp(13,13, 9,2),fpppp(13,13, 9,3)/
     x-4.6372995D-08,-8.6299632D-08, 2.6614805D-11 /
      data fpppp(13,13,10,1),fpppp(13,13,10,2),fpppp(13,13,10,3)/
     x-3.9258507D-08,-5.6609595D-08,-1.8598790D-11 /
      data fpppp(13,13,11,1),fpppp(13,13,11,2),fpppp(13,13,11,3)/
     x-5.1723808D-08, 5.3658528D-09, 8.7302452D-12 /
      data fpppp(13,13,12,1),fpppp(13,13,12,2),fpppp(13,13,12,3)/
     x-4.3812773D-08, 1.6527576D-07,-5.9019185D-12 /
      data fpppp(13,13,13,1),fpppp(13,13,13,2),fpppp(13,13,13,3)/
     x-9.3498666D-08, 1.9490391D-08, 1.6830364D-12 /
      data fpppp(13,13,14,1),fpppp(13,13,14,2),fpppp(13,13,14,3)/
     x-1.1739083D-07,-6.8988532D-08, 4.2110138D-12 /
      data fpppp(13,13,15,1),fpppp(13,13,15,2),fpppp(13,13,15,3)/
     x-1.0256802D-07,-4.5640597D-08,-6.6524538D-12 /
      data fpppp(13,13,16,1),fpppp(13,13,16,2),fpppp(13,13,16,3)/
     x-1.1739083D-07,-5.1753626D-08, 2.9538577D-12 /
      data fpppp(13,13,17,1),fpppp(13,13,17,2),fpppp(13,13,17,3)/
     x-9.3498666D-08,-4.9449236D-08, 6.7116608D-12 /
      data fpppp(13,14, 1,1),fpppp(13,14, 1,2),fpppp(13,14, 1,3)/
     x-7.0769387D-08,-5.7484132D-08,-7.4529215D-12 /
      data fpppp(13,14, 2,1),fpppp(13,14, 2,2),fpppp(13,14, 2,3)/
     x-2.2939659D-07,-6.8082033D-08,-2.6233001D-12 /
      data fpppp(13,14, 3,1),fpppp(13,14, 3,2),fpppp(13,14, 3,3)/
     x-2.6676166D-07,-7.5814495D-08, 9.6816618D-12 /
      data fpppp(13,14, 4,1),fpppp(13,14, 4,2),fpppp(13,14, 4,3)/
     x-2.2939659D-07,-9.3575994D-08,-4.1770681D-12 /
      data fpppp(13,14, 5,1),fpppp(13,14, 5,2),fpppp(13,14, 5,3)/
     x-7.0769387D-08, 4.4491712D-08,-1.2378494D-12 /
      data fpppp(13,14, 6,1),fpppp(13,14, 6,2),fpppp(13,14, 6,3)/
     x 4.8842770D-08, 2.1612012D-07, 4.6950019D-13 /
      data fpppp(13,14, 7,1),fpppp(13,14, 7,2),fpppp(13,14, 7,3)/
     x-7.0464290D-08, 5.3584364D-09,-6.3472547D-12 /
      data fpppp(13,14, 8,1),fpppp(13,14, 8,2),fpppp(13,14, 8,3)/
     x-1.9613930D-07,-8.5423696D-08, 1.6309498D-11 /
      data fpppp(13,14, 9,1),fpppp(13,14, 9,2),fpppp(13,14, 9,3)/
     x-2.2331989D-07,-1.0237566D-07,-1.9974274D-11 /
      data fpppp(13,14,10,1),fpppp(13,14,10,2),fpppp(13,14,10,3)/
     x-1.9613930D-07,-8.5423696D-08, 1.6309498D-11 /
      data fpppp(13,14,11,1),fpppp(13,14,11,2),fpppp(13,14,11,3)/
     x-7.0464290D-08, 5.3584364D-09,-6.3472547D-12 /
      data fpppp(13,14,12,1),fpppp(13,14,12,2),fpppp(13,14,12,3)/
     x 4.8842770D-08, 2.1612012D-07, 4.6950019D-13 /
      data fpppp(13,14,13,1),fpppp(13,14,13,2),fpppp(13,14,13,3)/
     x-7.0769387D-08, 4.4491712D-08,-1.2378494D-12 /
      data fpppp(13,14,14,1),fpppp(13,14,14,2),fpppp(13,14,14,3)/
     x-2.2939659D-07,-9.3575994D-08,-4.1770681D-12 /
      data fpppp(13,14,15,1),fpppp(13,14,15,2),fpppp(13,14,15,3)/
     x-2.6676166D-07,-7.5814495D-08, 9.6816618D-12 /
      data fpppp(13,14,16,1),fpppp(13,14,16,2),fpppp(13,14,16,3)/
     x-2.2939659D-07,-6.8082033D-08,-2.6233001D-12 /
      data fpppp(13,14,17,1),fpppp(13,14,17,2),fpppp(13,14,17,3)/
     x-7.0769387D-08,-5.7484132D-08,-7.4529215D-12 /
      data fpppp(13,15, 1,1),fpppp(13,15, 1,2),fpppp(13,15, 1,3)/
     x 3.0912443D-08,-4.8205178D-08, 1.0926895D-11 /
      data fpppp(13,15, 2,1),fpppp(13,15, 2,2),fpppp(13,15, 2,3)/
     x-2.8172413D-07,-6.9785613D-08, 5.2189369D-12 /
      data fpppp(13,15, 3,1),fpppp(13,15, 3,2),fpppp(13,15, 3,3)/
     x-3.9103676D-07,-1.0101406D-07,-1.0619440D-11 /
      data fpppp(13,15, 4,1),fpppp(13,15, 4,2),fpppp(13,15, 4,3)/
     x-2.8172413D-07,-9.8474464D-08, 8.9986496D-12 /
      data fpppp(13,15, 5,1),fpppp(13,15, 5,2),fpppp(13,15, 5,3)/
     x 3.0912443D-08, 6.6550224D-08,-4.1919562D-12 /
      data fpppp(13,15, 6,1),fpppp(13,15, 6,2),fpppp(13,15, 6,3)/
     x 1.8733917D-07, 2.2721603D-07,-2.6362034D-12 /
      data fpppp(13,15, 7,1),fpppp(13,15, 7,2),fpppp(13,15, 7,3)/
     x-5.1455351D-08, 1.0788196D-08, 1.0759576D-11 /
      data fpppp(13,15, 8,1),fpppp(13,15, 8,2),fpppp(13,15, 8,3)/
     x-3.2826974D-07,-1.0102864D-07,-1.6382287D-11 /
      data fpppp(13,15, 9,1),fpppp(13,15, 9,2),fpppp(13,15, 9,3)/
     x-4.1378358D-07,-1.1387011D-07, 1.8153834D-11 /
      data fpppp(13,15,10,1),fpppp(13,15,10,2),fpppp(13,15,10,3)/
     x-3.2826974D-07,-1.0102864D-07,-1.6382287D-11 /
      data fpppp(13,15,11,1),fpppp(13,15,11,2),fpppp(13,15,11,3)/
     x-5.1455351D-08, 1.0788196D-08, 1.0759576D-11 /
      data fpppp(13,15,12,1),fpppp(13,15,12,2),fpppp(13,15,12,3)/
     x 1.8733917D-07, 2.2721603D-07,-2.6362034D-12 /
      data fpppp(13,15,13,1),fpppp(13,15,13,2),fpppp(13,15,13,3)/
     x 3.0912443D-08, 6.6550224D-08,-4.1919562D-12 /
      data fpppp(13,15,14,1),fpppp(13,15,14,2),fpppp(13,15,14,3)/
     x-2.8172413D-07,-9.8474464D-08, 8.9986496D-12 /
      data fpppp(13,15,15,1),fpppp(13,15,15,2),fpppp(13,15,15,3)/
     x-3.9103676D-07,-1.0101406D-07,-1.0619440D-11 /
      data fpppp(13,15,16,1),fpppp(13,15,16,2),fpppp(13,15,16,3)/
     x-2.8172413D-07,-6.9785613D-08, 5.2189369D-12 /
      data fpppp(13,15,17,1),fpppp(13,15,17,2),fpppp(13,15,17,3)/
     x 3.0912443D-08,-4.8205178D-08, 1.0926895D-11 /
      data fpppp(13,16, 1,1),fpppp(13,16, 1,2),fpppp(13,16, 1,3)/
     x 1.4135626D-07,-2.2754812D-08, 9.8679273D-13 /
      data fpppp(13,16, 2,1),fpppp(13,16, 2,2),fpppp(13,16, 2,3)/
     x-1.3994052D-07,-5.1670338D-08, 5.9798622D-13 /
      data fpppp(13,16, 3,1),fpppp(13,16, 3,2),fpppp(13,16, 3,3)/
     x-2.9150500D-07,-1.0340600D-07, 1.5291261D-13 /
      data fpppp(13,16, 4,1),fpppp(13,16, 4,2),fpppp(13,16, 4,3)/
     x-1.3994052D-07,-7.5271185D-08,-9.5226181D-14 /
      data fpppp(13,16, 5,1),fpppp(13,16, 5,2),fpppp(13,16, 5,3)/
     x 1.4135626D-07, 7.1648576D-08, 3.7596423D-12 /
      data fpppp(13,16, 6,1),fpppp(13,16, 6,2),fpppp(13,16, 6,3)/
     x 2.2575536D-07, 1.8241171D-07,-4.6628636D-12 /
      data fpppp(13,16, 7,1),fpppp(13,16, 7,2),fpppp(13,16, 7,3)/
     x-2.1396151D-08, 1.7739619D-08,-3.4923076D-12 /
      data fpppp(13,16, 8,1),fpppp(13,16, 8,2),fpppp(13,16, 8,3)/
     x-3.3302082D-07,-9.1588954D-08, 1.1162866D-11 /
      data fpppp(13,16, 9,1),fpppp(13,16, 9,2),fpppp(13,16, 9,3)/
     x-4.5842259D-07,-1.1040701D-07,-1.3612670D-11 /
      data fpppp(13,16,10,1),fpppp(13,16,10,2),fpppp(13,16,10,3)/
     x-3.3302082D-07,-9.1588954D-08, 1.1162866D-11 /
      data fpppp(13,16,11,1),fpppp(13,16,11,2),fpppp(13,16,11,3)/
     x-2.1396151D-08, 1.7739619D-08,-3.4923076D-12 /
      data fpppp(13,16,12,1),fpppp(13,16,12,2),fpppp(13,16,12,3)/
     x 2.2575536D-07, 1.8241171D-07,-4.6628636D-12 /
      data fpppp(13,16,13,1),fpppp(13,16,13,2),fpppp(13,16,13,3)/
     x 1.4135626D-07, 7.1648576D-08, 3.7596423D-12 /
      data fpppp(13,16,14,1),fpppp(13,16,14,2),fpppp(13,16,14,3)/
     x-1.3994052D-07,-7.5271185D-08,-9.5226181D-14 /
      data fpppp(13,16,15,1),fpppp(13,16,15,2),fpppp(13,16,15,3)/
     x-2.9150500D-07,-1.0340600D-07, 1.5291261D-13 /
      data fpppp(13,16,16,1),fpppp(13,16,16,2),fpppp(13,16,16,3)/
     x-1.3994052D-07,-5.1670338D-08, 5.9798622D-13 /
      data fpppp(13,16,17,1),fpppp(13,16,17,2),fpppp(13,16,17,3)/
     x 1.4135626D-07,-2.2754812D-08, 9.8679273D-13 /
      data fpppp(13,17, 1,1),fpppp(13,17, 1,2),fpppp(13,17, 1,3)/
     x 1.7899015D-07,-3.2111278D-11,-1.4737836D-11 /
      data fpppp(13,17, 2,1),fpppp(13,17, 2,2),fpppp(13,17, 2,3)/
     x 1.7495566D-07,-2.3442179D-08,-7.8833412D-12 /
      data fpppp(13,17, 3,1),fpppp(13,17, 3,2),fpppp(13,17, 3,3)/
     x 1.1743920D-07,-6.9213897D-08, 1.0961398D-11 /
      data fpppp(13,17, 4,1),fpppp(13,17, 4,2),fpppp(13,17, 4,3)/
     x 1.7495566D-07,-3.6719839D-08,-1.2159718D-11 /
      data fpppp(13,17, 5,1),fpppp(13,17, 5,2),fpppp(13,17, 5,3)/
     x 1.7899015D-07, 5.3078528D-08, 2.3676726D-12 /
      data fpppp(13,17, 6,1),fpppp(13,17, 6,2),fpppp(13,17, 6,3)/
     x 6.4859205D-08, 9.8936698D-08, 1.1972489D-11 /
      data fpppp(13,17, 7,1),fpppp(13,17, 7,2),fpppp(13,17, 7,3)/
     x 8.7519261D-09, 1.8219982D-08,-1.2743954D-11 /
      data fpppp(13,17, 8,1),fpppp(13,17, 8,2),fpppp(13,17, 8,3)/
     x-1.2941690D-07,-5.9591459D-08, 4.8604256D-12 /
      data fpppp(13,17, 9,1),fpppp(13,17, 9,2),fpppp(13,17, 9,3)/
     x-2.1506287D-07,-8.0846869D-08,-2.6795681D-13 /
      data fpppp(13,17,10,1),fpppp(13,17,10,2),fpppp(13,17,10,3)/
     x-1.2941690D-07,-5.9591459D-08, 4.8604256D-12 /
      data fpppp(13,17,11,1),fpppp(13,17,11,2),fpppp(13,17,11,3)/
     x 8.7519261D-09, 1.8219982D-08,-1.2743954D-11 /
      data fpppp(13,17,12,1),fpppp(13,17,12,2),fpppp(13,17,12,3)/
     x 6.4859205D-08, 9.8936698D-08, 1.1972489D-11 /
      data fpppp(13,17,13,1),fpppp(13,17,13,2),fpppp(13,17,13,3)/
     x 1.7899015D-07, 5.3078528D-08, 2.3676726D-12 /
      data fpppp(13,17,14,1),fpppp(13,17,14,2),fpppp(13,17,14,3)/
     x 1.7495566D-07,-3.6719839D-08,-1.2159718D-11 /
      data fpppp(13,17,15,1),fpppp(13,17,15,2),fpppp(13,17,15,3)/
     x 1.1743920D-07,-6.9213897D-08, 1.0961398D-11 /
      data fpppp(13,17,16,1),fpppp(13,17,16,2),fpppp(13,17,16,3)/
     x 1.7495566D-07,-2.3442179D-08,-7.8833412D-12 /
      data fpppp(13,17,17,1),fpppp(13,17,17,2),fpppp(13,17,17,3)/
     x 1.7899015D-07,-3.2111278D-11,-1.4737836D-11 /
      data fpppp(13,18, 1,1),fpppp(13,18, 1,2),fpppp(13,18, 1,3)/
     x 6.3172017D-08, 5.2314615D-09, 8.0416656D-12 /
      data fpppp(13,18, 2,1),fpppp(13,18, 2,2),fpppp(13,18, 2,3)/
     x 3.7712433D-07,-2.3523672D-09, 4.1144820D-12 /
      data fpppp(13,18, 3,1),fpppp(13,18, 3,2),fpppp(13,18, 3,3)/
     x 5.1559147D-07,-1.7862695D-08,-6.7920308D-12 /
      data fpppp(13,18, 4,1),fpppp(13,18, 4,2),fpppp(13,18, 4,3)/
     x 3.7712433D-07,-5.6302767D-09, 6.7291086D-12 /
      data fpppp(13,18, 5,1),fpppp(13,18, 5,2),fpppp(13,18, 5,3)/
     x 6.3172017D-08, 1.8343100D-08,-2.4168407D-12 /
      data fpppp(13,18, 6,1),fpppp(13,18, 6,2),fpppp(13,18, 6,3)/
     x-1.1787413D-07, 2.7956856D-08,-4.4760679D-12 /
      data fpppp(13,18, 7,1),fpppp(13,18, 7,2),fpppp(13,18, 7,3)/
     x-1.3289914D-08, 5.5710943D-09, 8.6505389D-12 /
      data fpppp(13,18, 8,1),fpppp(13,18, 8,2),fpppp(13,18, 8,3)/
     x 1.8150262D-07,-2.1184465D-08,-6.0852590D-12 /
      data fpppp(13,18, 9,1),fpppp(13,18, 9,2),fpppp(13,18, 9,3)/
     x 2.5897394D-07,-3.2796240D-08, 2.4248420D-12 /
      data fpppp(13,18,10,1),fpppp(13,18,10,2),fpppp(13,18,10,3)/
     x 1.8150262D-07,-2.1184465D-08,-6.0852590D-12 /
      data fpppp(13,18,11,1),fpppp(13,18,11,2),fpppp(13,18,11,3)/
     x-1.3289914D-08, 5.5710943D-09, 8.6505389D-12 /
      data fpppp(13,18,12,1),fpppp(13,18,12,2),fpppp(13,18,12,3)/
     x-1.1787413D-07, 2.7956856D-08,-4.4760679D-12 /
      data fpppp(13,18,13,1),fpppp(13,18,13,2),fpppp(13,18,13,3)/
     x 6.3172017D-08, 1.8343100D-08,-2.4168407D-12 /
      data fpppp(13,18,14,1),fpppp(13,18,14,2),fpppp(13,18,14,3)/
     x 3.7712433D-07,-5.6302767D-09, 6.7291086D-12 /
      data fpppp(13,18,15,1),fpppp(13,18,15,2),fpppp(13,18,15,3)/
     x 5.1559147D-07,-1.7862695D-08,-6.7920308D-12 /
      data fpppp(13,18,16,1),fpppp(13,18,16,2),fpppp(13,18,16,3)/
     x 3.7712433D-07,-2.3523672D-09, 4.1144820D-12 /
      data fpppp(13,18,17,1),fpppp(13,18,17,2),fpppp(13,18,17,3)/
     x 6.3172017D-08, 5.2314615D-09, 8.0416656D-12 /
      data fpppp(13,19, 1,1),fpppp(13,19, 1,2),fpppp(13,19, 1,3)/
     x-8.8026818D-09, 2.0940444D-22, 1.9819987D-11 /
      data fpppp(13,19, 2,1),fpppp(13,19, 2,2),fpppp(13,19, 2,3)/
     x 6.1150085D-07,-1.4560771D-22, 1.0261119D-11 /
      data fpppp(13,19, 3,1),fpppp(13,19, 3,2),fpppp(13,19, 3,3)/
     x 9.1682715D-07,-3.2835483D-23,-1.6384912D-11 /
      data fpppp(13,19, 4,1),fpppp(13,19, 4,2),fpppp(13,19, 4,3)/
     x 6.1150085D-07,-1.4085810D-23, 1.6774130D-11 /
      data fpppp(13,19, 5,1),fpppp(13,19, 5,2),fpppp(13,19, 5,3)/
     x-8.8026818D-09,-4.8742978D-23,-6.2320558D-12 /
      data fpppp(13,19, 6,1),fpppp(13,19, 6,2),fpppp(13,19, 6,3)/
     x-2.9436827D-07,-7.0117693D-23,-1.1472079D-11 /
      data fpppp(13,19, 7,1),fpppp(13,19, 7,2),fpppp(13,19, 7,3)/
     x-2.0420349D-08, 1.3517709D-23, 2.1288992D-11 /
      data fpppp(13,19, 8,1),fpppp(13,19, 8,2),fpppp(13,19, 8,3)/
     x 4.6176054D-07, 1.5810026D-23,-1.5704302D-11 /
      data fpppp(13,19, 9,1),fpppp(13,19, 9,2),fpppp(13,19, 9,3)/
     x 6.6710301D-07,-2.5554182D-24, 8.1610449D-12 /
      data fpppp(13,19,10,1),fpppp(13,19,10,2),fpppp(13,19,10,3)/
     x 4.6176054D-07,-4.9249307D-23,-1.5704302D-11 /
      data fpppp(13,19,11,1),fpppp(13,19,11,2),fpppp(13,19,11,3)/
     x-2.0420349D-08, 3.1755089D-23, 2.1288992D-11 /
      data fpppp(13,19,12,1),fpppp(13,19,12,2),fpppp(13,19,12,3)/
     x-2.9436827D-07, 2.3228449D-23,-1.1472079D-11 /
      data fpppp(13,19,13,1),fpppp(13,19,13,2),fpppp(13,19,13,3)/
     x-8.8026818D-09, 5.0298111D-23,-6.2320558D-12 /
      data fpppp(13,19,14,1),fpppp(13,19,14,2),fpppp(13,19,14,3)/
     x 6.1150085D-07,-3.7577153D-23, 1.6774130D-11 /
      data fpppp(13,19,15,1),fpppp(13,19,15,2),fpppp(13,19,15,3)/
     x 9.1682715D-07, 5.5237932D-23,-1.6384912D-11 /
      data fpppp(13,19,16,1),fpppp(13,19,16,2),fpppp(13,19,16,3)/
     x 6.1150085D-07,-5.3853929D-23, 1.0261119D-11 /
      data fpppp(13,19,17,1),fpppp(13,19,17,2),fpppp(13,19,17,3)/
     x-8.8026818D-09, 9.9539216D-23, 1.9819987D-11 /
 
      data fxyz( 1, 1, 1),fxyz( 1, 1, 2)/-4.6021876D-06,-1.9667056D-06/
      data fxyz( 1, 1, 3),fxyz( 1, 1, 4)/ 5.4316031D-06,-3.8399814D-06/
      data fxyz( 1, 1, 5),fxyz( 1, 1, 6)/ 2.8909157D-06,-7.7152993D-06/
      data fxyz( 1, 1, 7),fxyz( 1, 1, 8)/ 9.9094414D-06,-4.7822101D-06/
      data fxyz( 1, 1, 9),fxyz( 1, 1,10)/ 1.3304516D-06,-4.7822101D-06/
      data fxyz( 1, 1,11),fxyz( 1, 1,12)/ 9.9094414D-06,-7.7152993D-06/
      data fxyz( 1, 1,13),fxyz( 1, 1,14)/ 2.8909157D-06,-3.8399814D-06/
      data fxyz( 1, 1,15),fxyz( 1, 1,16)/ 5.4316031D-06,-1.9667056D-06/
      data fxyz( 1, 1,17)/               -4.6021876D-06/
      data fxyz( 1, 2, 1),fxyz( 1, 2, 2)/ 2.2302056D-06, 9.1079290D-07/
      data fxyz( 1, 2, 3),fxyz( 1, 2, 4)/-2.5818175D-06, 1.5317641D-06/
      data fxyz( 1, 2, 5),fxyz( 1, 2, 6)/-2.5367915D-07, 3.1753557D-07/
      data fxyz( 1, 2, 7),fxyz( 1, 2, 8)/-1.0946667D-06, 1.2884362D-06/
      data fxyz( 1, 2, 9),fxyz( 1, 2,10)/-8.9346724D-07, 1.2884362D-06/
      data fxyz( 1, 2,11),fxyz( 1, 2,12)/-1.0946667D-06, 3.1753557D-07/
      data fxyz( 1, 2,13),fxyz( 1, 2,14)/-2.5367915D-07, 1.5317641D-06/
      data fxyz( 1, 2,15),fxyz( 1, 2,16)/-2.5818175D-06, 9.1079290D-07/
      data fxyz( 1, 2,17)/                2.2302056D-06/
      data fxyz( 1, 3, 1),fxyz( 1, 3, 2)/ 1.9327803D-06, 5.8043684D-07/
      data fxyz( 1, 3, 3),fxyz( 1, 3, 4)/-3.0811382D-06, 1.3395974D-06/
      data fxyz( 1, 3, 5),fxyz( 1, 3, 6)/-1.1038620D-06, 3.6715296D-06/
      data fxyz( 1, 3, 7),fxyz( 1, 3, 8)/-2.9210469D-06, 2.6421700D-07/
      data fxyz( 1, 3, 9),fxyz( 1, 3,10)/ 7.0679467D-07, 2.6421700D-07/
      data fxyz( 1, 3,11),fxyz( 1, 3,12)/-2.9210469D-06, 3.6715296D-06/
      data fxyz( 1, 3,13),fxyz( 1, 3,14)/-1.1038620D-06, 1.3395974D-06/
      data fxyz( 1, 3,15),fxyz( 1, 3,16)/-3.0811382D-06, 5.8043684D-07/
      data fxyz( 1, 3,17)/                1.9327803D-06/
      data fxyz( 1, 4, 1),fxyz( 1, 4, 2)/ 2.6589720D-05, 1.1477572D-05/
      data fxyz( 1, 4, 3),fxyz( 1, 4, 4)/-2.9879808D-05, 2.0621123D-05/
      data fxyz( 1, 4, 5),fxyz( 1, 4, 6)/-9.9844869D-06, 2.3401466D-05/
      data fxyz( 1, 4, 7),fxyz( 1, 4, 8)/-3.6869475D-05, 2.4072027D-05/
      data fxyz( 1, 4, 9),fxyz( 1, 4,10)/-1.1077576D-05, 2.4072027D-05/
      data fxyz( 1, 4,11),fxyz( 1, 4,12)/-3.6869475D-05, 2.3401466D-05/
      data fxyz( 1, 4,13),fxyz( 1, 4,14)/-9.9844869D-06, 2.0621123D-05/
      data fxyz( 1, 4,15),fxyz( 1, 4,16)/-2.9879808D-05, 1.1477572D-05/
      data fxyz( 1, 4,17)/                2.6589720D-05/
      data fxyz( 1, 5, 1),fxyz( 1, 5, 2)/-4.4405354D-05,-1.8954990D-05/
      data fxyz( 1, 5, 3),fxyz( 1, 5, 4)/ 5.0404649D-05,-3.3918172D-05/
      data fxyz( 1, 5, 5),fxyz( 1, 5, 6)/ 1.5447377D-05,-3.6037758D-05/
      data fxyz( 1, 5, 7),fxyz( 1, 5, 8)/ 5.5700011D-05,-3.5185991D-05/
      data fxyz( 1, 5, 9),fxyz( 1, 5,10)/ 1.5090554D-05,-3.5185991D-05/
      data fxyz( 1, 5,11),fxyz( 1, 5,12)/ 5.5700011D-05,-3.6037758D-05/
      data fxyz( 1, 5,13),fxyz( 1, 5,14)/ 1.5447377D-05,-3.3918172D-05/
      data fxyz( 1, 5,15),fxyz( 1, 5,16)/ 5.0404649D-05,-1.8954990D-05/
      data fxyz( 1, 5,17)/               -4.4405354D-05/
      data fxyz( 1, 6, 1),fxyz( 1, 6, 2)/-3.8932740D-06,-1.6648551D-06/
      data fxyz( 1, 6, 3),fxyz( 1, 6, 4)/ 4.4680674D-06,-3.0647727D-06/
      data fxyz( 1, 6, 5),fxyz( 1, 6, 6)/ 1.7063967D-06,-4.0530556D-06/
      data fxyz( 1, 6, 7),fxyz( 1, 6, 8)/ 5.9725864D-06,-3.8854138D-06/
      data fxyz( 1, 6, 9),fxyz( 1, 6,10)/ 1.9471311D-06,-3.8854138D-06/
      data fxyz( 1, 6,11),fxyz( 1, 6,12)/ 5.9725864D-06,-4.0530556D-06/
      data fxyz( 1, 6,13),fxyz( 1, 6,14)/ 1.7063967D-06,-3.0647727D-06/
      data fxyz( 1, 6,15),fxyz( 1, 6,16)/ 4.4680674D-06,-1.6648551D-06/
      data fxyz( 1, 6,17)/               -3.8932740D-06/
      data fxyz( 1, 7, 1),fxyz( 1, 7, 2)/ 1.8124082D-05, 7.8211060D-06/
      data fxyz( 1, 7, 3),fxyz( 1, 7, 4)/-2.0301895D-05, 1.3945191D-05/
      data fxyz( 1, 7, 5),fxyz( 1, 7, 6)/-6.3722590D-06, 1.3756045D-05/
      data fxyz( 1, 7, 7),fxyz( 1, 7, 8)/-2.1416166D-05, 1.3848539D-05/
      data fxyz( 1, 7, 9),fxyz( 1, 7,10)/-6.2001247D-06, 1.3848539D-05/
      data fxyz( 1, 7,11),fxyz( 1, 7,12)/-2.1416166D-05, 1.3756045D-05/
      data fxyz( 1, 7,13),fxyz( 1, 7,14)/-6.3722590D-06, 1.3945191D-05/
      data fxyz( 1, 7,15),fxyz( 1, 7,16)/-2.0301895D-05, 7.8211060D-06/
      data fxyz( 1, 7,17)/                1.8124082D-05/
      data fxyz( 1, 8, 1),fxyz( 1, 8, 2)/-2.7680195D-07,-1.2205567D-07/
      data fxyz( 1, 8, 3),fxyz( 1, 8, 4)/ 3.0470831D-07,-2.2058964D-07/
      data fxyz( 1, 8, 5),fxyz( 1, 8, 6)/ 1.1733396D-07, 1.6813203D-07/
      data fxyz( 1, 8, 7),fxyz( 1, 8, 8)/-4.7403916D-07, 1.9082117D-07/
      data fxyz( 1, 8, 9),fxyz( 1, 8,10)/ 1.1555265D-07, 1.9082117D-07/
      data fxyz( 1, 8,11),fxyz( 1, 8,12)/-4.7403916D-07, 1.6813203D-07/
      data fxyz( 1, 8,13),fxyz( 1, 8,14)/ 1.1733396D-07,-2.2058964D-07/
      data fxyz( 1, 8,15),fxyz( 1, 8,16)/ 3.0470831D-07,-1.2205567D-07/
      data fxyz( 1, 8,17)/               -2.7680195D-07/
      data fxyz( 1, 9, 1),fxyz( 1, 9, 2)/ 6.1039402D-07, 2.6212079D-07/
      data fxyz( 1, 9, 3),fxyz( 1, 9, 4)/-6.7143465D-07, 4.4349765D-07/
      data fxyz( 1, 9, 5),fxyz( 1, 9, 6)/-1.1511341D-07, 2.7790908D-07/
      data fxyz( 1, 9, 7),fxyz( 1, 9, 8)/-5.6055080D-07, 4.2560336D-07/
      data fxyz( 1, 9, 9),fxyz( 1, 9,10)/-2.4102765D-07, 4.2560336D-07/
      data fxyz( 1, 9,11),fxyz( 1, 9,12)/-5.6055080D-07, 2.7790908D-07/
      data fxyz( 1, 9,13),fxyz( 1, 9,14)/-1.1511341D-07, 4.4349765D-07/
      data fxyz( 1, 9,15),fxyz( 1, 9,16)/-6.7143465D-07, 2.6212079D-07/
      data fxyz( 1, 9,17)/                6.1039402D-07/
      data fxyz( 1,10, 1),fxyz( 1,10, 2)/ 5.1805869D-08, 3.9363112D-09/
      data fxyz( 1,10, 3),fxyz( 1,10, 4)/-1.3760238D-07, 4.8700898D-08/
      data fxyz( 1,10, 5),fxyz( 1,10, 6)/-1.2725248D-07, 2.2140228D-07/
      data fxyz( 1,10, 7),fxyz( 1,10, 8)/ 3.3795975D-08,-1.2667421D-07/
      data fxyz( 1,10, 9),fxyz( 1,10,10)/ 4.5118210D-08,-1.2667421D-07/
      data fxyz( 1,10,11),fxyz( 1,10,12)/ 3.3795975D-08, 2.2140228D-07/
      data fxyz( 1,10,13),fxyz( 1,10,14)/-1.2725248D-07, 4.8700898D-08/
      data fxyz( 1,10,15),fxyz( 1,10,16)/-1.3760238D-07, 3.9363112D-09/
      data fxyz( 1,10,17)/                5.1805869D-08/
      data fxyz( 1,11, 1),fxyz( 1,11, 2)/-1.8562923D-09,-4.6541237D-08/
      data fxyz( 1,11, 3),fxyz( 1,11, 4)/ 3.6636259D-08,-3.2770478D-07/
      data fxyz( 1,11, 5),fxyz( 1,11, 6)/ 1.1227979D-06,-1.6512495D-06/
      data fxyz( 1,11, 7),fxyz( 1,11, 8)/ 1.0643571D-06,-3.3241379D-07/
      data fxyz( 1,11, 9),fxyz( 1,11,10)/ 1.6492925D-07,-3.3241379D-07/
      data fxyz( 1,11,11),fxyz( 1,11,12)/ 1.0643571D-06,-1.6512495D-06/
      data fxyz( 1,11,13),fxyz( 1,11,14)/ 1.1227979D-06,-3.2770478D-07/
      data fxyz( 1,11,15),fxyz( 1,11,16)/ 3.6636259D-08,-4.6541237D-08/
      data fxyz( 1,11,17)/               -1.8562923D-09/
      data fxyz( 1,12, 1),fxyz( 1,12, 2)/ 1.0689253D-07, 1.5790537D-07/
      data fxyz( 1,12, 3),fxyz( 1,12, 4)/-3.2164399D-07, 1.0557743D-06/
      data fxyz( 1,12, 5),fxyz( 1,12, 6)/-3.4845834D-06, 5.1596693D-06/
      data fxyz( 1,12, 7),fxyz( 1,12, 8)/-3.1142781D-06, 8.3739707D-07/
      data fxyz( 1,12, 9),fxyz( 1,12,10)/-4.3666981D-07, 8.3739707D-07/
      data fxyz( 1,12,11),fxyz( 1,12,12)/-3.1142781D-06, 5.1596693D-06/
      data fxyz( 1,12,13),fxyz( 1,12,14)/-3.4845834D-06, 1.0557743D-06/
      data fxyz( 1,12,15),fxyz( 1,12,16)/-3.2164399D-07, 1.5790537D-07/
      data fxyz( 1,12,17)/                1.0689253D-07/
      data fxyz( 1,13, 1),fxyz( 1,13, 2)/ 1.2588564D-07,-3.8083477D-07/
      data fxyz( 1,13, 3),fxyz( 1,13, 4)/ 1.1320432D-06,-4.4236731D-06/
      data fxyz( 1,13, 5),fxyz( 1,13, 6)/ 1.6297239D-05,-2.5559610D-05/
      data fxyz( 1,13, 7),fxyz( 1,13, 8)/ 1.6425798D-05,-4.8390744D-06/
      data fxyz( 1,13, 9),fxyz( 1,13,10)/ 2.3927912D-06,-4.8390744D-06/
      data fxyz( 1,13,11),fxyz( 1,13,12)/ 1.6425798D-05,-2.5559610D-05/
      data fxyz( 1,13,13),fxyz( 1,13,14)/ 1.6297239D-05,-4.4236731D-06/
      data fxyz( 1,13,15),fxyz( 1,13,16)/ 1.1320432D-06,-3.8083477D-07/
      data fxyz( 1,13,17)/                1.2588564D-07/
      data fxyz( 1,14, 1),fxyz( 1,14, 2)/ 4.3128141D-06, 4.1776064D-06/
      data fxyz( 1,14, 3),fxyz( 1,14, 4)/-5.3825868D-06, 1.8044669D-05/
      data fxyz( 1,14, 5),fxyz( 1,14, 6)/-5.1155437D-05, 6.9649238D-05/
      data fxyz( 1,14, 7),fxyz( 1,14, 8)/-4.1775407D-05, 1.2127704D-05/
      data fxyz( 1,14, 9),fxyz( 1,14,10)/-6.0877687D-06, 1.2127704D-05/
      data fxyz( 1,14,11),fxyz( 1,14,12)/-4.1775407D-05, 6.9649238D-05/
      data fxyz( 1,14,13),fxyz( 1,14,14)/-5.1155437D-05, 1.8044669D-05/
      data fxyz( 1,14,15),fxyz( 1,14,16)/-5.3825868D-06, 4.1776064D-06/
      data fxyz( 1,14,17)/                4.3128141D-06/
      data fxyz( 1,15, 1),fxyz( 1,15, 2)/-1.8393069D-06,-3.2218560D-06/
      data fxyz( 1,15, 3),fxyz( 1,15, 4)/ 5.5978391D-06,-2.1290321D-05/
      data fxyz( 1,15, 5),fxyz( 1,15, 6)/ 7.0434551D-05,-1.0301141D-04/
      data fxyz( 1,15, 7),fxyz( 1,15, 8)/ 6.2659634D-05,-1.7467500D-05/
      data fxyz( 1,15, 9),fxyz( 1,15,10)/ 8.7408453D-06,-1.7467500D-05/
      data fxyz( 1,15,11),fxyz( 1,15,12)/ 6.2659634D-05,-1.0301141D-04/
      data fxyz( 1,15,13),fxyz( 1,15,14)/ 7.0434551D-05,-2.1290321D-05/
      data fxyz( 1,15,15),fxyz( 1,15,16)/ 5.5978391D-06,-3.2218560D-06/
      data fxyz( 1,15,17)/               -1.8393069D-06/
      data fxyz( 1,16, 1),fxyz( 1,16, 2)/-1.5169046D-05,-8.2496526D-06/
      data fxyz( 1,16, 3),fxyz( 1,16, 4)/ 3.5375982D-06,-1.7126517D-06/
      data fxyz( 1,16, 5),fxyz( 1,16, 6)/-4.1317049D-05, 9.2362290D-05/
      data fxyz( 1,16, 7),fxyz( 1,16, 8)/-6.3468682D-05, 1.7175531D-05/
      data fxyz( 1,16, 9),fxyz( 1,16,10)/-8.5269743D-06, 1.7175531D-05/
      data fxyz( 1,16,11),fxyz( 1,16,12)/-6.3468682D-05, 9.2362290D-05/
      data fxyz( 1,16,13),fxyz( 1,16,14)/-4.1317049D-05,-1.7126517D-06/
      data fxyz( 1,16,15),fxyz( 1,16,16)/ 3.5375982D-06,-8.2496526D-06/
      data fxyz( 1,16,17)/               -1.5169046D-05/
      data fxyz( 1,17, 1),fxyz( 1,17, 2)/ 1.0304303D-05, 2.6566344D-06/
      data fxyz( 1,17, 3),fxyz( 1,17, 4)/-8.0507406D-06,-8.0491444D-06/
      data fxyz( 1,17, 5),fxyz( 1,17, 6)/ 5.3127418D-05,-7.1288707D-05/
      data fxyz( 1,17, 7),fxyz( 1,17, 8)/ 3.7906235D-05,-1.1145707D-05/
      data fxyz( 1,17, 9),fxyz( 1,17,10)/ 5.1662523D-06,-1.1145707D-05/
      data fxyz( 1,17,11),fxyz( 1,17,12)/ 3.7906235D-05,-7.1288707D-05/
      data fxyz( 1,17,13),fxyz( 1,17,14)/ 5.3127418D-05,-8.0491444D-06/
      data fxyz( 1,17,15),fxyz( 1,17,16)/-8.0507406D-06, 2.6566344D-06/
      data fxyz( 1,17,17)/                1.0304303D-05/
      data fxyz( 1,18, 1),fxyz( 1,18, 2)/ 6.9384088D-06, 9.6503647D-06/
      data fxyz( 1,18, 3),fxyz( 1,18, 4)/ 3.4186847D-06, 2.8489731D-05/
      data fxyz( 1,18, 5),fxyz( 1,18, 6)/-6.8419055D-05, 4.6394125D-05/
      data fxyz( 1,18, 7),fxyz( 1,18, 8)/-1.0278455D-05, 4.3691193D-06/
      data fxyz( 1,18, 9),fxyz( 1,18,10)/-1.3897197D-06, 4.3691193D-06/
      data fxyz( 1,18,11),fxyz( 1,18,12)/-1.0278455D-05, 4.6394125D-05/
      data fxyz( 1,18,13),fxyz( 1,18,14)/-6.8419055D-05, 2.8489731D-05/
      data fxyz( 1,18,15),fxyz( 1,18,16)/ 3.4186847D-06, 9.6503647D-06/
      data fxyz( 1,18,17)/                6.9384088D-06/
      data fxyz( 1,19, 1),fxyz( 1,19, 2)/ 1.1812298D-05, 1.7761968D-05/
      data fxyz( 1,19, 3),fxyz( 1,19, 4)/ 8.3001773D-06, 5.2778501D-05/
      data fxyz( 1,19, 5),fxyz( 1,19, 6)/-1.2825383D-04, 8.3695862D-05/
      data fxyz( 1,19, 7),fxyz( 1,19, 8)/-1.5731829D-05, 7.3593557D-06/
      data fxyz( 1,19, 9),fxyz( 1,19,10)/-2.1602063D-06, 7.3593557D-06/
      data fxyz( 1,19,11),fxyz( 1,19,12)/-1.5731829D-05, 8.3695862D-05/
      data fxyz( 1,19,13),fxyz( 1,19,14)/-1.2825383D-04, 5.2778501D-05/
      data fxyz( 1,19,15),fxyz( 1,19,16)/ 8.3001773D-06, 1.7761968D-05/
      data fxyz( 1,19,17)/                1.1812298D-05/
      data fxyz( 2, 1, 1),fxyz( 2, 1, 2)/-3.1613511D-06,-1.3269936D-06/
      data fxyz( 2, 1, 3),fxyz( 2, 1, 4)/ 3.7895694D-06,-2.5815870D-06/
      data fxyz( 2, 1, 5),fxyz( 2, 1, 6)/ 1.8570223D-06,-5.0669227D-06/
      data fxyz( 2, 1, 7),fxyz( 2, 1, 8)/ 6.4557719D-06,-3.1308658D-06/
      data fxyz( 2, 1, 9),fxyz( 2, 1,10)/ 9.3449416D-07,-3.1308658D-06/
      data fxyz( 2, 1,11),fxyz( 2, 1,12)/ 6.4557719D-06,-5.0669227D-06/
      data fxyz( 2, 1,13),fxyz( 2, 1,14)/ 1.8570223D-06,-2.5815870D-06/
      data fxyz( 2, 1,15),fxyz( 2, 1,16)/ 3.7895694D-06,-1.3269936D-06/
      data fxyz( 2, 1,17)/               -3.1613511D-06/
      data fxyz( 2, 2, 1),fxyz( 2, 2, 2)/ 1.4312543D-06, 5.9082602D-07/
      data fxyz( 2, 2, 3),fxyz( 2, 2, 4)/-1.6383717D-06, 9.9312359D-07/
      data fxyz( 2, 2, 5),fxyz( 2, 2, 6)/-1.7793596D-07, 2.1976609D-07/
      data fxyz( 2, 2, 7),fxyz( 2, 2, 8)/-7.5973475D-07, 8.5527351D-07/
      data fxyz( 2, 2, 9),fxyz( 2, 2,10)/-5.5556369D-07, 8.5527351D-07/
      data fxyz( 2, 2,11),fxyz( 2, 2,12)/-7.5973475D-07, 2.1976609D-07/
      data fxyz( 2, 2,13),fxyz( 2, 2,14)/-1.7793596D-07, 9.9312359D-07/
      data fxyz( 2, 2,15),fxyz( 2, 2,16)/-1.6383717D-06, 5.9082602D-07/
      data fxyz( 2, 2,17)/                1.4312543D-06/
      data fxyz( 2, 3, 1),fxyz( 2, 3, 2)/ 1.6187886D-06, 5.1448121D-07/
      data fxyz( 2, 3, 3),fxyz( 2, 3, 4)/-2.4511473D-06, 1.0978480D-06/
      data fxyz( 2, 3, 5),fxyz( 2, 3, 6)/-7.1467838D-07, 2.4819158D-06/
      data fxyz( 2, 3, 7),fxyz( 2, 3, 8)/-2.0937734D-06, 3.0740719D-07/
      data fxyz( 2, 3, 9),fxyz( 2, 3,10)/ 3.9093673D-07, 3.0740719D-07/
      data fxyz( 2, 3,11),fxyz( 2, 3,12)/-2.0937734D-06, 2.4819158D-06/
      data fxyz( 2, 3,13),fxyz( 2, 3,14)/-7.1467838D-07, 1.0978480D-06/
      data fxyz( 2, 3,15),fxyz( 2, 3,16)/-2.4511473D-06, 5.1448121D-07/
      data fxyz( 2, 3,17)/                1.6187886D-06/
      data fxyz( 2, 4, 1),fxyz( 2, 4, 2)/ 1.7224072D-05, 7.4177120D-06/
      data fxyz( 2, 4, 3),fxyz( 2, 4, 4)/-1.9417002D-05, 1.3347524D-05/
      data fxyz( 2, 4, 5),fxyz( 2, 4, 6)/-6.4951763D-06, 1.5329952D-05/
      data fxyz( 2, 4, 7),fxyz( 2, 4, 8)/-2.4012950D-05, 1.5628560D-05/
      data fxyz( 2, 4, 9),fxyz( 2, 4,10)/-7.1905168D-06, 1.5628560D-05/
      data fxyz( 2, 4,11),fxyz( 2, 4,12)/-2.4012950D-05, 1.5329952D-05/
      data fxyz( 2, 4,13),fxyz( 2, 4,14)/-6.4951763D-06, 1.3347524D-05/
      data fxyz( 2, 4,15),fxyz( 2, 4,16)/-1.9417002D-05, 7.4177120D-06/
      data fxyz( 2, 4,17)/                1.7224072D-05/
      data fxyz( 2, 5, 1),fxyz( 2, 5, 2)/-2.8943435D-05,-1.2330133D-05/
      data fxyz( 2, 5, 3),fxyz( 2, 5, 4)/ 3.2910694D-05,-2.2044817D-05/
      data fxyz( 2, 5, 5),fxyz( 2, 5, 6)/ 9.9153004D-06,-2.3401168D-05/
      data fxyz( 2, 5, 7),fxyz( 2, 5, 8)/ 3.6233067D-05,-2.2788637D-05/
      data fxyz( 2, 5, 9),fxyz( 2, 5,10)/ 9.6427005D-06,-2.2788637D-05/
      data fxyz( 2, 5,11),fxyz( 2, 5,12)/ 3.6233067D-05,-2.3401168D-05/
      data fxyz( 2, 5,13),fxyz( 2, 5,14)/ 9.9153004D-06,-2.2044817D-05/
      data fxyz( 2, 5,15),fxyz( 2, 5,16)/ 3.2910694D-05,-1.2330133D-05/
      data fxyz( 2, 5,17)/               -2.8943435D-05/
      data fxyz( 2, 6, 1),fxyz( 2, 6, 2)/-3.2462234D-06,-1.3915327D-06/
      data fxyz( 2, 6, 3),fxyz( 2, 6, 4)/ 3.7146918D-06,-2.5594521D-06/
      data fxyz( 2, 6, 5),fxyz( 2, 6, 6)/ 1.4254544D-06,-3.2834189D-06/
      data fxyz( 2, 6, 7),fxyz( 2, 6, 8)/ 4.8155873D-06,-3.1598026D-06/
      data fxyz( 2, 6, 9),fxyz( 2, 6,10)/ 1.6139190D-06,-3.1598026D-06/
      data fxyz( 2, 6,11),fxyz( 2, 6,12)/ 4.8155873D-06,-3.2834189D-06/
      data fxyz( 2, 6,13),fxyz( 2, 6,14)/ 1.4254544D-06,-2.5594521D-06/
      data fxyz( 2, 6,15),fxyz( 2, 6,16)/ 3.7146918D-06,-1.3915327D-06/
      data fxyz( 2, 6,17)/               -3.2462234D-06/
      data fxyz( 2, 7, 1),fxyz( 2, 7, 2)/ 1.2085466D-05, 5.2047337D-06/
      data fxyz( 2, 7, 3),fxyz( 2, 7, 4)/-1.3563359D-05, 9.2743103D-06/
      data fxyz( 2, 7, 5),fxyz( 2, 7, 6)/-4.1928407D-06, 9.2244289D-06/
      data fxyz( 2, 7, 7),fxyz( 2, 7, 8)/-1.4438336D-05, 9.3095004D-06/
      data fxyz( 2, 7, 9),fxyz( 2, 7,10)/-4.1125029D-06, 9.3095004D-06/
      data fxyz( 2, 7,11),fxyz( 2, 7,12)/-1.4438336D-05, 9.2244289D-06/
      data fxyz( 2, 7,13),fxyz( 2, 7,14)/-4.1928407D-06, 9.2743103D-06/
      data fxyz( 2, 7,15),fxyz( 2, 7,16)/-1.3563359D-05, 5.2047337D-06/
      data fxyz( 2, 7,17)/                1.2085466D-05/
      data fxyz( 2, 8, 1),fxyz( 2, 8, 2)/ 1.5499032D-07, 7.4298442D-08/
      data fxyz( 2, 8, 3),fxyz( 2, 8, 4)/-1.4769013D-07, 1.2485972D-07/
      data fxyz( 2, 8, 5),fxyz( 2, 8, 6)/-4.7254802D-08, 2.3883404D-07/
      data fxyz( 2, 8, 7),fxyz( 2, 8, 8)/-5.1679697D-07, 2.8318273D-07/
      data fxyz( 2, 8, 9),fxyz( 2, 8,10)/-9.5324288D-09, 2.8318273D-07/
      data fxyz( 2, 8,11),fxyz( 2, 8,12)/-5.1679697D-07, 2.3883404D-07/
      data fxyz( 2, 8,13),fxyz( 2, 8,14)/-4.7254802D-08, 1.2485972D-07/
      data fxyz( 2, 8,15),fxyz( 2, 8,16)/-1.4769013D-07, 7.4298442D-08/
      data fxyz( 2, 8,17)/                1.5499032D-07/
      data fxyz( 2, 9, 1),fxyz( 2, 9, 2)/ 2.7879243D-07, 1.2888458D-07/
      data fxyz( 2, 9, 3),fxyz( 2, 9, 4)/-2.8092490D-07, 2.1892137D-07/
      data fxyz( 2, 9, 5),fxyz( 2, 9, 6)/-8.1354715D-08, 1.4809072D-07/
      data fxyz( 2, 9, 7),fxyz( 2, 9, 8)/-3.2171894D-07, 2.6605399D-07/
      data fxyz( 2, 9, 9),fxyz( 2, 9,10)/-1.6405381D-07, 2.6605399D-07/
      data fxyz( 2, 9,11),fxyz( 2, 9,12)/-3.2171894D-07, 1.4809072D-07/
      data fxyz( 2, 9,13),fxyz( 2, 9,14)/-8.1354715D-08, 2.1892137D-07/
      data fxyz( 2, 9,15),fxyz( 2, 9,16)/-2.8092490D-07, 1.2888458D-07/
      data fxyz( 2, 9,17)/                2.7879243D-07/
      data fxyz( 2,10, 1),fxyz( 2,10, 2)/ 5.2069493D-08, 9.1565384D-09/
      data fxyz( 2,10, 3),fxyz( 2,10, 4)/-1.0661824D-07, 3.2623368D-08/
      data fxyz( 2,10, 5),fxyz( 2,10, 6)/-4.1797824D-08, 6.6952651D-08/
      data fxyz( 2,10, 7),fxyz( 2,10, 8)/ 8.5817954D-08,-1.0502020D-07/
      data fxyz( 2,10, 9),fxyz( 2,10,10)/ 3.3377481D-08,-1.0502020D-07/
      data fxyz( 2,10,11),fxyz( 2,10,12)/ 8.5817954D-08, 6.6952651D-08/
      data fxyz( 2,10,13),fxyz( 2,10,14)/-4.1797824D-08, 3.2623368D-08/
      data fxyz( 2,10,15),fxyz( 2,10,16)/-1.0661824D-07, 9.1565384D-09/
      data fxyz( 2,10,17)/                5.2069493D-08/
      data fxyz( 2,11, 1),fxyz( 2,11, 2)/ 4.1904784D-09,-2.9893576D-08/
      data fxyz( 2,11, 3),fxyz( 2,11, 4)/ 9.6336092D-10,-1.9547317D-07/
      data fxyz( 2,11, 5),fxyz( 2,11, 6)/ 6.6650886D-07,-9.5982136D-07/
      data fxyz( 2,11, 7),fxyz( 2,11, 8)/ 6.3268508D-07,-2.1044964D-07/
      data fxyz( 2,11, 9),fxyz( 2,11,10)/ 1.0454049D-07,-2.1044964D-07/
      data fxyz( 2,11,11),fxyz( 2,11,12)/ 6.3268508D-07,-9.5982136D-07/
      data fxyz( 2,11,13),fxyz( 2,11,14)/ 6.6650886D-07,-1.9547317D-07/
      data fxyz( 2,11,15),fxyz( 2,11,16)/ 9.6336092D-10,-2.9893576D-08/
      data fxyz( 2,11,17)/                4.1904784D-09/
      data fxyz( 2,12, 1),fxyz( 2,12, 2)/ 8.8105333D-08, 1.0276455D-07/
      data fxyz( 2,12, 3),fxyz( 2,12, 4)/-1.9411675D-07, 5.9939374D-07/
      data fxyz( 2,12, 5),fxyz( 2,12, 6)/-1.8984114D-06, 2.7515980D-06/
      data fxyz( 2,12, 7),fxyz( 2,12, 8)/-1.6286390D-06, 4.2702275D-07/
      data fxyz( 2,12, 9),fxyz( 2,12,10)/-2.2503993D-07, 4.2702275D-07/
      data fxyz( 2,12,11),fxyz( 2,12,12)/-1.6286390D-06, 2.7515980D-06/
      data fxyz( 2,12,13),fxyz( 2,12,14)/-1.8984114D-06, 5.9939374D-07/
      data fxyz( 2,12,15),fxyz( 2,12,16)/-1.9411675D-07, 1.0276455D-07/
      data fxyz( 2,12,17)/                8.8105333D-08/
      data fxyz( 2,13, 1),fxyz( 2,13, 2)/ 1.4352384D-07,-1.7365813D-07/
      data fxyz( 2,13, 3),fxyz( 2,13, 4)/ 6.1597227D-07,-2.4682406D-06/
      data fxyz( 2,13, 5),fxyz( 2,13, 6)/ 9.3218538D-06,-1.4790002D-05/
      data fxyz( 2,13, 7),fxyz( 2,13, 8)/ 9.5718450D-06,-2.8332873D-06/
      data fxyz( 2,13, 9),fxyz( 2,13,10)/ 1.3972598D-06,-2.8332873D-06/
      data fxyz( 2,13,11),fxyz( 2,13,12)/ 9.5718450D-06,-1.4790002D-05/
      data fxyz( 2,13,13),fxyz( 2,13,14)/ 9.3218538D-06,-2.4682406D-06/
      data fxyz( 2,13,15),fxyz( 2,13,16)/ 6.1597227D-07,-1.7365813D-07/
      data fxyz( 2,13,17)/                1.4352384D-07/
      data fxyz( 2,14, 1),fxyz( 2,14, 2)/ 2.9976118D-06, 2.6739011D-06/
      data fxyz( 2,14, 3),fxyz( 2,14, 4)/-3.1714810D-06, 1.0308987D-05/
      data fxyz( 2,14, 5),fxyz( 2,14, 6)/-2.7542732D-05, 3.6061987D-05/
      data fxyz( 2,14, 7),fxyz( 2,14, 8)/-2.1215933D-05, 6.1627134D-06/
      data fxyz( 2,14, 9),fxyz( 2,14,10)/-3.1060480D-06, 6.1627134D-06/
      data fxyz( 2,14,11),fxyz( 2,14,12)/-2.1215933D-05, 3.6061987D-05/
      data fxyz( 2,14,13),fxyz( 2,14,14)/-2.7542732D-05, 1.0308987D-05/
      data fxyz( 2,14,15),fxyz( 2,14,16)/-3.1714810D-06, 2.6739011D-06/
      data fxyz( 2,14,17)/                2.9976118D-06/
      data fxyz( 2,15, 1),fxyz( 2,15, 2)/-2.1273011D-06,-2.3545953D-06/
      data fxyz( 2,15, 3),fxyz( 2,15, 4)/ 3.1942599D-06,-1.1473408D-05/
      data fxyz( 2,15, 5),fxyz( 2,15, 6)/ 3.4347949D-05,-4.7499294D-05/
      data fxyz( 2,15, 7),fxyz( 2,15, 8)/ 2.8117296D-05,-7.7956229D-06/
      data fxyz( 2,15, 9),fxyz( 2,15,10)/ 3.8920973D-06,-7.7956229D-06/
      data fxyz( 2,15,11),fxyz( 2,15,12)/ 2.8117296D-05,-4.7499294D-05/
      data fxyz( 2,15,13),fxyz( 2,15,14)/ 3.4347949D-05,-1.1473408D-05/
      data fxyz( 2,15,15),fxyz( 2,15,16)/ 3.1942599D-06,-2.3545953D-06/
      data fxyz( 2,15,17)/               -2.1273011D-06/
      data fxyz( 2,16, 1),fxyz( 2,16, 2)/-9.0381194D-06,-5.2301505D-06/
      data fxyz( 2,16, 3),fxyz( 2,16, 4)/ 2.3276214D-06,-3.2389172D-06/
      data fxyz( 2,16, 5),fxyz( 2,16, 6)/-1.7003052D-05, 4.4517723D-05/
      data fxyz( 2,16, 7),fxyz( 2,16, 8)/-3.1546764D-05, 8.3514892D-06/
      data fxyz( 2,16, 9),fxyz( 2,16,10)/-4.1567062D-06, 8.3514892D-06/
      data fxyz( 2,16,11),fxyz( 2,16,12)/-3.1546764D-05, 4.4517723D-05/
      data fxyz( 2,16,13),fxyz( 2,16,14)/-1.7003052D-05,-3.2389172D-06/
      data fxyz( 2,16,15),fxyz( 2,16,16)/ 2.3276214D-06,-5.2301505D-06/
      data fxyz( 2,16,17)/               -9.0381194D-06/
      data fxyz( 2,17, 1),fxyz( 2,17, 2)/ 7.4459225D-06, 3.0043239D-06/
      data fxyz( 2,17, 3),fxyz( 2,17, 4)/-4.6473478D-06,-1.0637638D-06/
      data fxyz( 2,17, 5),fxyz( 2,17, 6)/ 2.3718273D-05,-3.7813923D-05/
      data fxyz( 2,17, 7),fxyz( 2,17, 8)/ 2.1911886D-05,-6.2195696D-06/
      data fxyz( 2,17, 9),fxyz( 2,17,10)/ 2.9035282D-06,-6.2195696D-06/
      data fxyz( 2,17,11),fxyz( 2,17,12)/ 2.1911886D-05,-3.7813923D-05/
      data fxyz( 2,17,13),fxyz( 2,17,14)/ 2.3718273D-05,-1.0637638D-06/
      data fxyz( 2,17,15),fxyz( 2,17,16)/-4.6473478D-06, 3.0043239D-06/
      data fxyz( 2,17,17)/                7.4459225D-06/
      data fxyz( 2,18, 1),fxyz( 2,18, 2)/ 3.1821135D-06, 4.5880159D-06/
      data fxyz( 2,18, 3),fxyz( 2,18, 4)/ 1.7796501D-06, 1.3721223D-05/
      data fxyz( 2,18, 5),fxyz( 2,18, 6)/-3.3350714D-05, 2.3139679D-05/
      data fxyz( 2,18, 7),fxyz( 2,18, 8)/-5.7093955D-06, 2.4202876D-06/
      data fxyz( 2,18, 9),fxyz( 2,18,10)/-6.9960935D-07, 2.4202876D-06/
      data fxyz( 2,18,11),fxyz( 2,18,12)/-5.7093955D-06, 2.3139679D-05/
      data fxyz( 2,18,13),fxyz( 2,18,14)/-3.3350714D-05, 1.3721223D-05/
      data fxyz( 2,18,15),fxyz( 2,18,16)/ 1.7796501D-06, 4.5880159D-06/
      data fxyz( 2,18,17)/                3.1821135D-06/
      data fxyz( 2,19, 1),fxyz( 2,19, 2)/ 4.8462620D-06, 8.0719315D-06/
      data fxyz( 2,19, 3),fxyz( 2,19, 4)/ 4.3775146D-06, 2.4903400D-05/
      data fxyz( 2,19, 5),fxyz( 2,19, 6)/-6.2479612D-05, 4.3154639D-05/
      data fxyz( 2,19, 7),fxyz( 2,19, 8)/-1.0164982D-05, 4.4284546D-06/
      data fxyz( 2,19, 9),fxyz( 2,19,10)/-1.2560692D-06, 4.4284546D-06/
      data fxyz( 2,19,11),fxyz( 2,19,12)/-1.0164982D-05, 4.3154639D-05/
      data fxyz( 2,19,13),fxyz( 2,19,14)/-6.2479612D-05, 2.4903400D-05/
      data fxyz( 2,19,15),fxyz( 2,19,16)/ 4.3775146D-06, 8.0719315D-06/
      data fxyz( 2,19,17)/                4.8462620D-06/
      data fxyz( 3, 1, 1),fxyz( 3, 1, 2)/-1.4391345D-06,-5.4596255D-07/
      data fxyz( 3, 1, 3),fxyz( 3, 1, 4)/ 1.8627349D-06,-1.0329071D-06/
      data fxyz( 3, 1, 5),fxyz( 3, 1, 6)/ 5.0864357D-07,-1.6624638D-06/
      data fxyz( 3, 1, 7),fxyz( 3, 1, 8)/ 2.0069097D-06,-1.0298059D-06/
      data fxyz( 3, 1, 9),fxyz( 3, 1,10)/ 4.7535456D-07,-1.0298059D-06/
      data fxyz( 3, 1,11),fxyz( 3, 1,12)/ 2.0069097D-06,-1.6624638D-06/
      data fxyz( 3, 1,13),fxyz( 3, 1,14)/ 5.0864357D-07,-1.0329071D-06/
      data fxyz( 3, 1,15),fxyz( 3, 1,16)/ 1.8627349D-06,-5.4596255D-07/
      data fxyz( 3, 1,17)/               -1.4391345D-06/
      data fxyz( 3, 2, 1),fxyz( 3, 2, 2)/ 3.7656142D-07, 1.7169232D-07/
      data fxyz( 3, 2, 3),fxyz( 3, 2, 4)/-3.8327519D-07, 2.8710172D-07/
      data fxyz( 3, 2, 5),fxyz( 3, 2, 6)/-8.5076184D-08, 1.1022810D-07/
      data fxyz( 3, 2, 7),fxyz( 3, 2, 8)/-3.6675019D-07, 3.0542181D-07/
      data fxyz( 3, 2, 9),fxyz( 3, 2,10)/-9.9340429D-08, 3.0542181D-07/
      data fxyz( 3, 2,11),fxyz( 3, 2,12)/-3.6675019D-07, 1.1022810D-07/
      data fxyz( 3, 2,13),fxyz( 3, 2,14)/-8.5076184D-08, 2.8710172D-07/
      data fxyz( 3, 2,15),fxyz( 3, 2,16)/-3.8327519D-07, 1.7169232D-07/
      data fxyz( 3, 2,17)/                3.7656142D-07/
      data fxyz( 3, 3, 1),fxyz( 3, 3, 2)/ 1.4878942D-06, 5.3564480D-07/
      data fxyz( 3, 3, 3),fxyz( 3, 3, 4)/-1.9688951D-06, 9.5958166D-07/
      data fxyz( 3, 3, 5),fxyz( 3, 3, 6)/-2.0785324D-07, 1.0052809D-06/
      data fxyz( 3, 3, 7),fxyz( 3, 3, 8)/-1.1804254D-06, 4.8169693D-07/
      data fxyz( 3, 3, 9),fxyz( 3, 3,10)/-7.7010428D-08, 4.8169693D-07/
      data fxyz( 3, 3,11),fxyz( 3, 3,12)/-1.1804254D-06, 1.0052809D-06/
      data fxyz( 3, 3,13),fxyz( 3, 3,14)/-2.0785324D-07, 9.5958166D-07/
      data fxyz( 3, 3,15),fxyz( 3, 3,16)/-1.9688951D-06, 5.3564480D-07/
      data fxyz( 3, 3,17)/                1.4878942D-06/
      data fxyz( 3, 4, 1),fxyz( 3, 4, 2)/ 5.0644978D-06, 2.1375556D-06/
      data fxyz( 3, 4, 3),fxyz( 3, 4, 4)/-5.8658806D-06, 3.8984125D-06/
      data fxyz( 3, 4, 5),fxyz( 3, 4, 6)/-1.9789297D-06, 4.9720705D-06/
      data fxyz( 3, 4, 7),fxyz( 3, 4, 8)/-7.4540471D-06, 4.7143061D-06/
      data fxyz( 3, 4, 9),fxyz( 3, 4,10)/-2.1442679D-06, 4.7143061D-06/
      data fxyz( 3, 4,11),fxyz( 3, 4,12)/-7.4540471D-06, 4.9720705D-06/
      data fxyz( 3, 4,13),fxyz( 3, 4,14)/-1.9789297D-06, 3.8984125D-06/
      data fxyz( 3, 4,15),fxyz( 3, 4,16)/-5.8658806D-06, 2.1375556D-06/
      data fxyz( 3, 4,17)/                5.0644978D-06/
      data fxyz( 3, 5, 1),fxyz( 3, 5, 2)/-9.0711097D-06,-3.7966767D-06/
      data fxyz( 3, 5, 3),fxyz( 3, 5, 4)/ 1.0469508D-05,-6.7354383D-06/
      data fxyz( 3, 5, 5),fxyz( 3, 5, 6)/ 2.6839368D-06,-7.0920457D-06/
      data fxyz( 3, 5, 7),fxyz( 3, 5, 8)/ 1.1166433D-05,-6.7521193D-06/
      data fxyz( 3, 5, 9),fxyz( 3, 5,10)/ 2.4991649D-06,-6.7521193D-06/
      data fxyz( 3, 5,11),fxyz( 3, 5,12)/ 1.1166433D-05,-7.0920457D-06/
      data fxyz( 3, 5,13),fxyz( 3, 5,14)/ 2.6839368D-06,-6.7354383D-06/
      data fxyz( 3, 5,15),fxyz( 3, 5,16)/ 1.0469508D-05,-3.7966767D-06/
      data fxyz( 3, 5,17)/               -9.0711097D-06/
      data fxyz( 3, 6, 1),fxyz( 3, 6, 2)/-2.7199983D-06,-1.1682561D-06/
      data fxyz( 3, 6, 3),fxyz( 3, 6, 4)/ 3.1058414D-06,-2.1483045D-06/
      data fxyz( 3, 6, 5),fxyz( 3, 6, 6)/ 1.2001952D-06,-2.6733463D-06/
      data fxyz( 3, 6, 7),fxyz( 3, 6, 8)/ 3.9097062D-06,-2.6073644D-06/
      data fxyz( 3, 6, 9),fxyz( 3, 6,10)/ 1.3690445D-06,-2.6073644D-06/
      data fxyz( 3, 6,11),fxyz( 3, 6,12)/ 3.9097062D-06,-2.6733463D-06/
      data fxyz( 3, 6,13),fxyz( 3, 6,14)/ 1.2001952D-06,-2.1483045D-06/
      data fxyz( 3, 6,15),fxyz( 3, 6,16)/ 3.1058414D-06,-1.1682561D-06/
      data fxyz( 3, 6,17)/               -2.7199983D-06/
      data fxyz( 3, 7, 1),fxyz( 3, 7, 2)/ 4.3528845D-06, 1.8491948D-06/
      data fxyz( 3, 7, 3),fxyz( 3, 7, 4)/-4.9485475D-06, 3.2828940D-06/
      data fxyz( 3, 7, 5),fxyz( 3, 7, 6)/-1.3819126D-06, 3.5016426D-06/
      data fxyz( 3, 7, 7),fxyz( 3, 7, 8)/-5.6708574D-06, 3.5798122D-06/
      data fxyz( 3, 7, 9),fxyz( 3, 7,10)/-1.4356603D-06, 3.5798122D-06/
      data fxyz( 3, 7,11),fxyz( 3, 7,12)/-5.6708574D-06, 3.5016426D-06/
      data fxyz( 3, 7,13),fxyz( 3, 7,14)/-1.3819126D-06, 3.2828940D-06/
      data fxyz( 3, 7,15),fxyz( 3, 7,16)/-4.9485475D-06, 1.8491948D-06/
      data fxyz( 3, 7,17)/                4.3528845D-06/
      data fxyz( 3, 8, 1),fxyz( 3, 8, 2)/ 8.9312205D-07, 4.0428704D-07/
      data fxyz( 3, 8, 3),fxyz( 3, 8, 4)/-9.3704025D-07, 7.0535545D-07/
      data fxyz( 3, 8, 5),fxyz( 3, 8, 6)/-3.1115158D-07, 4.5063464D-07/
      data fxyz( 3, 8, 7),fxyz( 3, 8, 8)/-7.6791999D-07, 5.2930437D-07/
      data fxyz( 3, 8, 9),fxyz( 3, 8,10)/-2.2522747D-07, 5.2930437D-07/
      data fxyz( 3, 8,11),fxyz( 3, 8,12)/-7.6791999D-07, 4.5063464D-07/
      data fxyz( 3, 8,13),fxyz( 3, 8,14)/-3.1115158D-07, 7.0535545D-07/
      data fxyz( 3, 8,15),fxyz( 3, 8,16)/-9.3704025D-07, 4.0428704D-07/
      data fxyz( 3, 8,17)/                8.9312205D-07/
      data fxyz( 3, 9, 1),fxyz( 3, 9, 2)/-1.6362404D-07,-4.8386665D-08/
      data fxyz( 3, 9, 3),fxyz( 3, 9, 4)/ 2.4065471D-07,-7.8617933D-08/
      data fxyz( 3, 9, 5),fxyz( 3, 9, 6)/-4.2698963D-08,-1.8344330D-08/
      data fxyz( 3, 9, 7),fxyz( 3, 9, 8)/-4.4704505D-09, 5.6074289D-08/
      data fxyz( 3, 9, 9),fxyz( 3, 9,10)/-6.9578482D-08, 5.6074289D-08/
      data fxyz( 3, 9,11),fxyz( 3, 9,12)/-4.4704505D-09,-1.8344330D-08/
      data fxyz( 3, 9,13),fxyz( 3, 9,14)/-4.2698963D-08,-7.8617933D-08/
      data fxyz( 3, 9,15),fxyz( 3, 9,16)/ 2.4065471D-07,-4.8386665D-08/
      data fxyz( 3, 9,17)/               -1.6362404D-07/
      data fxyz( 3,10, 1),fxyz( 3,10, 2)/ 6.2200651D-08, 1.7273226D-08/
      data fxyz( 3,10, 3),fxyz( 3,10, 4)/-8.0641440D-08, 6.8992399D-09/
      data fxyz( 3,10, 5),fxyz( 3,10, 6)/ 1.0369660D-07,-1.7954961D-07/
      data fxyz( 3,10, 7),fxyz( 3,10, 8)/ 1.8826974D-07,-9.3562285D-08/
      data fxyz( 3,10, 9),fxyz( 3,10,10)/ 2.7405072D-08,-9.3562285D-08/
      data fxyz( 3,10,11),fxyz( 3,10,12)/ 1.8826974D-07,-1.7954961D-07/
      data fxyz( 3,10,13),fxyz( 3,10,14)/ 1.0369660D-07, 6.8992399D-09/
      data fxyz( 3,10,15),fxyz( 3,10,16)/-8.0641440D-08, 1.7273226D-08/
      data fxyz( 3,10,17)/                6.2200651D-08/
      data fxyz( 3,11, 1),fxyz( 3,11, 2)/ 8.9744700D-09,-7.4151899D-09/
      data fxyz( 3,11, 3),fxyz( 3,11, 4)/-5.2438743D-08, 2.7563296D-09/
      data fxyz( 3,11, 5),fxyz( 3,11, 6)/-3.1711608D-08, 1.0424854D-07/
      data fxyz( 3,11, 7),fxyz( 3,11, 8)/-2.8629828D-08,-2.6389449D-08/
      data fxyz( 3,11, 9),fxyz( 3,11,10)/ 1.3586017D-08,-2.6389449D-08/
      data fxyz( 3,11,11),fxyz( 3,11,12)/-2.8629828D-08, 1.0424854D-07/
      data fxyz( 3,11,13),fxyz( 3,11,14)/-3.1711608D-08, 2.7563296D-09/
      data fxyz( 3,11,15),fxyz( 3,11,16)/-5.2438743D-08,-7.4151899D-09/
      data fxyz( 3,11,17)/                8.9744700D-09/
      data fxyz( 3,12, 1),fxyz( 3,12, 2)/ 7.9015357D-08, 2.9055508D-08/
      data fxyz( 3,12, 3),fxyz( 3,12, 4)/-8.4374750D-09,-8.9564488D-08/
      data fxyz( 3,12, 5),fxyz( 3,12, 6)/ 5.5349534D-07,-1.0031169D-06/
      data fxyz( 3,12, 7),fxyz( 3,12, 8)/ 6.9877065D-07,-2.1680496D-07/
      data fxyz( 3,12, 9),fxyz( 3,12,10)/ 1.0310813D-07,-2.1680496D-07/
      data fxyz( 3,12,11),fxyz( 3,12,12)/ 6.9877065D-07,-1.0031169D-06/
      data fxyz( 3,12,13),fxyz( 3,12,14)/ 5.5349534D-07,-8.9564488D-08/
      data fxyz( 3,12,15),fxyz( 3,12,16)/-8.4374750D-09, 2.9055508D-08/
      data fxyz( 3,12,17)/                7.9015357D-08/
      data fxyz( 3,13, 1),fxyz( 3,13, 2)/ 1.7970285D-07, 1.4516009D-07/
      data fxyz( 3,13, 3),fxyz( 3,13, 4)/-1.5562354D-07, 4.7543588D-07/
      data fxyz( 3,13, 5),fxyz( 3,13, 6)/-1.1414003D-06, 1.3052665D-06/
      data fxyz( 3,13, 7),fxyz( 3,13, 8)/-6.3139226D-07, 1.3695010D-07/
      data fxyz( 3,13, 9),fxyz( 3,13,10)/-7.9050324D-08, 1.3695010D-07/
      data fxyz( 3,13,11),fxyz( 3,13,12)/-6.3139226D-07, 1.3052665D-06/
      data fxyz( 3,13,13),fxyz( 3,13,14)/-1.1414003D-06, 4.7543588D-07/
      data fxyz( 3,13,15),fxyz( 3,13,16)/-1.5562354D-07, 1.4516009D-07/
      data fxyz( 3,13,17)/                1.7970285D-07/
      data fxyz( 3,14, 1),fxyz( 3,14, 2)/ 1.3747436D-06, 5.8586047D-07/
      data fxyz( 3,14, 3),fxyz( 3,14, 4)/ 1.0730900D-07,-1.4574031D-06/
      data fxyz( 3,14, 5),fxyz( 3,14, 6)/ 9.5477979D-06,-1.7575778D-05/
      data fxyz( 3,14, 7),fxyz( 3,14, 8)/ 1.1840574D-05,-3.4191500D-06/
      data fxyz( 3,14, 9),fxyz( 3,14,10)/ 1.6800643D-06,-3.4191500D-06/
      data fxyz( 3,14,11),fxyz( 3,14,12)/ 1.1840574D-05,-1.7575778D-05/
      data fxyz( 3,14,13),fxyz( 3,14,14)/ 9.5477979D-06,-1.4574031D-06/
      data fxyz( 3,14,15),fxyz( 3,14,16)/ 1.0730900D-07, 5.8586047D-07/
      data fxyz( 3,14,17)/                1.3747436D-06/
      data fxyz( 3,15, 1),fxyz( 3,15, 2)/-3.0823240D-06,-1.0844750D-06/
      data fxyz( 3,15, 3),fxyz( 3,15, 4)/-8.5430930D-07, 5.5627480D-06/
      data fxyz( 3,15, 5),fxyz( 3,15, 6)/-2.9671216D-05, 5.1958396D-05/
      data fxyz( 3,15, 7),fxyz( 3,15, 8)/-3.4156784D-05, 9.7343349D-06/
      data fxyz( 3,15, 9),fxyz( 3,15,10)/-4.8927785D-06, 9.7343349D-06/
      data fxyz( 3,15,11),fxyz( 3,15,12)/-3.4156784D-05, 5.1958396D-05/
      data fxyz( 3,15,13),fxyz( 3,15,14)/-2.9671216D-05, 5.5627480D-06/
      data fxyz( 3,15,15),fxyz( 3,15,16)/-8.5430930D-07,-1.0844750D-06/
      data fxyz( 3,15,17)/               -3.0823240D-06/
      data fxyz( 3,16, 1),fxyz( 3,16, 2)/-2.0039008D-06,-2.7174473D-06/
      data fxyz( 3,16, 3),fxyz( 3,16, 4)/ 2.0735185D-06,-1.2401309D-05/
      data fxyz( 3,16, 5),fxyz( 3,16, 6)/ 3.6731545D-05,-4.7407578D-05/
      data fxyz( 3,16, 7),fxyz( 3,16, 8)/ 2.7364949D-05,-8.1516321D-06/
      data fxyz( 3,16, 9),fxyz( 3,16,10)/ 4.0405538D-06,-8.1516321D-06/
      data fxyz( 3,16,11),fxyz( 3,16,12)/ 2.7364949D-05,-4.7407578D-05/
      data fxyz( 3,16,13),fxyz( 3,16,14)/ 3.6731545D-05,-1.2401309D-05/
      data fxyz( 3,16,15),fxyz( 3,16,16)/ 2.0735185D-06,-2.7174473D-06/
      data fxyz( 3,16,17)/               -2.0039008D-06/
      data fxyz( 3,17, 1),fxyz( 3,17, 2)/ 8.5555989D-06, 7.8774695D-06/
      data fxyz( 3,17, 3),fxyz( 3,17, 4)/-1.4334276D-06, 1.9470362D-05/
      data fxyz( 3,17, 5),fxyz( 3,17, 6)/-3.7815972D-05, 2.2516472D-05/
      data fxyz( 3,17, 7),fxyz( 3,17, 8)/-3.7866605D-06, 1.7199357D-06/
      data fxyz( 3,17, 9),fxyz( 3,17,10)/-8.4269693D-07, 1.7199357D-06/
      data fxyz( 3,17,11),fxyz( 3,17,12)/-3.7866605D-06, 2.2516472D-05/
      data fxyz( 3,17,13),fxyz( 3,17,14)/-3.7815972D-05, 1.9470362D-05/
      data fxyz( 3,17,15),fxyz( 3,17,16)/-1.4334276D-06, 7.8774695D-06/
      data fxyz( 3,17,17)/                8.5555989D-06/
      data fxyz( 3,18, 1),fxyz( 3,18, 2)/-5.4586984D-06,-5.5325434D-06/
      data fxyz( 3,18, 3),fxyz( 3,18, 4)/ 1.3511592D-07,-1.4292490D-05/
      data fxyz( 3,18, 5),fxyz( 3,18, 6)/ 2.9581088D-05,-1.7244365D-05/
      data fxyz( 3,18, 7),fxyz( 3,18, 8)/ 1.3072541D-06,-3.6189869D-07/
      data fxyz( 3,18, 9),fxyz( 3,18,10)/ 4.2571633D-07,-3.6189869D-07/
      data fxyz( 3,18,11),fxyz( 3,18,12)/ 1.3072541D-06,-1.7244365D-05/
      data fxyz( 3,18,13),fxyz( 3,18,14)/ 2.9581088D-05,-1.4292490D-05/
      data fxyz( 3,18,15),fxyz( 3,18,16)/ 1.3511592D-07,-5.5325434D-06/
      data fxyz( 3,18,17)/               -5.4586984D-06/
      data fxyz( 3,19, 1),fxyz( 3,19, 2)/-1.2451911D-05,-1.2084005D-05/
      data fxyz( 3,19, 3),fxyz( 3,19, 4)/ 2.5351955D-07,-2.9302622D-05/
      data fxyz( 3,19, 5),fxyz( 3,19, 6)/ 5.6422555D-05,-2.5666663D-05/
      data fxyz( 3,19, 7),fxyz( 3,19, 8)/-3.9546954D-06, 9.7152471D-07/
      data fxyz( 3,19, 9),fxyz( 3,19,10)/-6.3488699D-08, 9.7152471D-07/
      data fxyz( 3,19,11),fxyz( 3,19,12)/-3.9546954D-06,-2.5666663D-05/
      data fxyz( 3,19,13),fxyz( 3,19,14)/ 5.6422555D-05,-2.9302622D-05/
      data fxyz( 3,19,15),fxyz( 3,19,16)/ 2.5351955D-07,-1.2084005D-05/
      data fxyz( 3,19,17)/               -1.2451911D-05/
      data fxyz( 4, 1, 1),fxyz( 4, 1, 2)/-7.0174824D-07,-2.5954834D-07/
      data fxyz( 4, 1, 3),fxyz( 4, 1, 4)/ 9.3270339D-07,-5.0022632D-07/
      data fxyz( 4, 1, 5),fxyz( 4, 1, 6)/ 2.6096367D-07,-9.0429331D-07/
      data fxyz( 4, 1, 7),fxyz( 4, 1, 8)/ 1.0412219D-06,-5.0275047D-07/
      data fxyz( 4, 1, 9),fxyz( 4, 1,10)/ 2.3735270D-07,-5.0275047D-07/
      data fxyz( 4, 1,11),fxyz( 4, 1,12)/ 1.0412219D-06,-9.0429331D-07/
      data fxyz( 4, 1,13),fxyz( 4, 1,14)/ 2.6096367D-07,-5.0022632D-07/
      data fxyz( 4, 1,15),fxyz( 4, 1,16)/ 9.3270339D-07,-2.5954834D-07/
      data fxyz( 4, 1,17)/               -7.0174824D-07/
      data fxyz( 4, 2, 1),fxyz( 4, 2, 2)/ 2.1696422D-07, 9.9642509D-08/
      data fxyz( 4, 2, 3),fxyz( 4, 2, 4)/-2.1895626D-07, 1.6691467D-07/
      data fxyz( 4, 2, 5),fxyz( 4, 2, 6)/-5.2124426D-08, 4.1879905D-08/
      data fxyz( 4, 2, 7),fxyz( 4, 2, 8)/-1.7694963D-07, 1.6398172D-07/
      data fxyz( 4, 2, 9),fxyz( 4, 2,10)/-5.7236185D-08, 1.6398172D-07/
      data fxyz( 4, 2,11),fxyz( 4, 2,12)/-1.7694963D-07, 4.1879905D-08/
      data fxyz( 4, 2,13),fxyz( 4, 2,14)/-5.2124426D-08, 1.6691467D-07/
      data fxyz( 4, 2,15),fxyz( 4, 2,16)/-2.1895626D-07, 9.9642509D-08/
      data fxyz( 4, 2,17)/                2.1696422D-07/
      data fxyz( 4, 3, 1),fxyz( 4, 3, 2)/ 7.1615951D-07, 2.5189112D-07/
      data fxyz( 4, 3, 3),fxyz( 4, 3, 4)/-9.6955726D-07, 4.5912435D-07/
      data fxyz( 4, 3, 5),fxyz( 4, 3, 6)/-1.1277337D-07, 5.3321969D-07/
      data fxyz( 4, 3, 7),fxyz( 4, 3, 8)/-5.6833819D-07, 1.9713826D-07/
      data fxyz( 4, 3, 9),fxyz( 4, 3,10)/-1.2645343D-08, 1.9713826D-07/
      data fxyz( 4, 3,11),fxyz( 4, 3,12)/-5.6833819D-07, 5.3321969D-07/
      data fxyz( 4, 3,13),fxyz( 4, 3,14)/-1.1277337D-07, 4.5912435D-07/
      data fxyz( 4, 3,15),fxyz( 4, 3,16)/-9.6955726D-07, 2.5189112D-07/
      data fxyz( 4, 3,17)/                7.1615951D-07/
      data fxyz( 4, 4, 1),fxyz( 4, 4, 2)/ 2.6836649D-06, 1.1284376D-06/
      data fxyz( 4, 4, 3),fxyz( 4, 4, 4)/-3.1238635D-06, 2.0635936D-06/
      data fxyz( 4, 4, 5),fxyz( 4, 4, 6)/-1.0569593D-06, 2.6164765D-06/
      data fxyz( 4, 4, 7),fxyz( 4, 4, 8)/-3.8534672D-06, 2.4478096D-06/
      data fxyz( 4, 4, 9),fxyz( 4, 4,10)/-1.1551835D-06, 2.4478096D-06/
      data fxyz( 4, 4,11),fxyz( 4, 4,12)/-3.8534672D-06, 2.6164765D-06/
      data fxyz( 4, 4,13),fxyz( 4, 4,14)/-1.0569593D-06, 2.0635936D-06/
      data fxyz( 4, 4,15),fxyz( 4, 4,16)/-3.1238635D-06, 1.1284376D-06/
      data fxyz( 4, 4,17)/                2.6836649D-06/
      data fxyz( 4, 5, 1),fxyz( 4, 5, 2)/-4.6352037D-06,-1.9433188D-06/
      data fxyz( 4, 5, 3),fxyz( 4, 5, 4)/ 5.3436265D-06,-3.4521392D-06/
      data fxyz( 4, 5, 5),fxyz( 4, 5, 6)/ 1.4000781D-06,-3.6367826D-06/
      data fxyz( 4, 5, 7),fxyz( 4, 5, 8)/ 5.6987128D-06,-3.4526761D-06/
      data fxyz( 4, 5, 9),fxyz( 4, 5,10)/ 1.2905174D-06,-3.4526761D-06/
      data fxyz( 4, 5,11),fxyz( 4, 5,12)/ 5.6987128D-06,-3.6367826D-06/
      data fxyz( 4, 5,13),fxyz( 4, 5,14)/ 1.4000781D-06,-3.4521392D-06/
      data fxyz( 4, 5,15),fxyz( 4, 5,16)/ 5.3436265D-06,-1.9433188D-06/
      data fxyz( 4, 5,17)/               -4.6352037D-06/
      data fxyz( 4, 6, 1),fxyz( 4, 6, 2)/-1.7708838D-06,-7.6981926D-07/
      data fxyz( 4, 6, 3),fxyz( 4, 6, 4)/ 1.9911529D-06,-1.4075516D-06/
      data fxyz( 4, 6, 5),fxyz( 4, 6, 6)/ 7.8004536D-07,-1.5047996D-06/
      data fxyz( 4, 6, 7),fxyz( 4, 6, 8)/ 2.1249117D-06,-1.4488209D-06/
      data fxyz( 4, 6, 9),fxyz( 4, 6,10)/ 8.1498833D-07,-1.4488209D-06/
      data fxyz( 4, 6,11),fxyz( 4, 6,12)/ 2.1249117D-06,-1.5047996D-06/
      data fxyz( 4, 6,13),fxyz( 4, 6,14)/ 7.8004536D-07,-1.4075516D-06/
      data fxyz( 4, 6,15),fxyz( 4, 6,16)/ 1.9911529D-06,-7.6981926D-07/
      data fxyz( 4, 6,17)/               -1.7708838D-06/
      data fxyz( 4, 7, 1),fxyz( 4, 7, 2)/ 2.5491813D-06, 1.0807387D-06/
      data fxyz( 4, 7, 3),fxyz( 4, 7, 4)/-2.9007026D-06, 1.9133513D-06/
      data fxyz( 4, 7, 5),fxyz( 4, 7, 6)/-7.8126905D-07, 1.9479532D-06/
      data fxyz( 4, 7, 7),fxyz( 4, 7, 8)/-3.1671506D-06, 2.0173961D-06/
      data fxyz( 4, 7, 9),fxyz( 4, 7,10)/-8.2109067D-07, 2.0173961D-06/
      data fxyz( 4, 7,11),fxyz( 4, 7,12)/-3.1671506D-06, 1.9479532D-06/
      data fxyz( 4, 7,13),fxyz( 4, 7,14)/-7.8126905D-07, 1.9133513D-06/
      data fxyz( 4, 7,15),fxyz( 4, 7,16)/-2.9007026D-06, 1.0807387D-06/
      data fxyz( 4, 7,17)/                2.5491813D-06/
      data fxyz( 4, 8, 1),fxyz( 4, 8, 2)/ 5.5906567D-07, 2.6655492D-07/
      data fxyz( 4, 8, 3),fxyz( 4, 8, 4)/-5.4705950D-07, 4.6318892D-07/
      data fxyz( 4, 8, 5),fxyz( 4, 8, 6)/-2.2747031D-07, 1.6859016D-07/
      data fxyz( 4, 8, 7),fxyz( 4, 8, 8)/-2.8976477D-07, 2.3726574D-07/
      data fxyz( 4, 8, 9),fxyz( 4, 8,10)/-1.2378763D-07, 2.3726574D-07/
      data fxyz( 4, 8,11),fxyz( 4, 8,12)/-2.8976477D-07, 1.6859016D-07/
      data fxyz( 4, 8,13),fxyz( 4, 8,14)/-2.2747031D-07, 4.6318892D-07/
      data fxyz( 4, 8,15),fxyz( 4, 8,16)/-5.4705950D-07, 2.6655492D-07/
      data fxyz( 4, 8,17)/                5.5906567D-07/
      data fxyz( 4, 9, 1),fxyz( 4, 9, 2)/-2.1818846D-07,-7.1535268D-08/
      data fxyz( 4, 9, 3),fxyz( 4, 9, 4)/ 3.0348977D-07,-1.2078665D-07/
      data fxyz( 4, 9, 5),fxyz( 4, 9, 6)/-2.1182920D-08,-5.6620961D-08/
      data fxyz( 4, 9, 7),fxyz( 4, 9, 8)/ 3.8319821D-08, 2.2600728D-08/
      data fxyz( 4, 9, 9),fxyz( 4, 9,10)/-3.6358363D-08, 2.2600728D-08/
      data fxyz( 4, 9,11),fxyz( 4, 9,12)/ 3.8319821D-08,-5.6620961D-08/
      data fxyz( 4, 9,13),fxyz( 4, 9,14)/-2.1182920D-08,-1.2078665D-07/
      data fxyz( 4, 9,15),fxyz( 4, 9,16)/ 3.0348977D-07,-7.1535268D-08/
      data fxyz( 4, 9,17)/               -2.1818846D-07/
      data fxyz( 4,10, 1),fxyz( 4,10, 2)/ 3.7795442D-08, 1.5252302D-08/
      data fxyz( 4,10, 3),fxyz( 4,10, 4)/-3.7138960D-08, 1.4938203D-08/
      data fxyz( 4,10, 5),fxyz( 4,10, 6)/ 3.9051838D-08,-1.0386767D-07/
      data fxyz( 4,10, 7),fxyz( 4,10, 8)/ 1.1421720D-07,-4.6418037D-08/
      data fxyz( 4,10, 9),fxyz( 4,10,10)/ 1.2435388D-09,-4.6418037D-08/
      data fxyz( 4,10,11),fxyz( 4,10,12)/ 1.1421720D-07,-1.0386767D-07/
      data fxyz( 4,10,13),fxyz( 4,10,14)/ 3.9051838D-08, 1.4938203D-08/
      data fxyz( 4,10,15),fxyz( 4,10,16)/-3.7138960D-08, 1.5252302D-08/
      data fxyz( 4,10,17)/                3.7795442D-08/
      data fxyz( 4,11, 1),fxyz( 4,11, 2)/ 1.8178189D-08,-5.3443421D-09/
      data fxyz( 4,11, 3),fxyz( 4,11, 4)/-4.3788625D-08,-3.0006776D-08/
      data fxyz( 4,11, 5),fxyz( 4,11, 6)/ 1.1682792D-07,-1.3592775D-07/
      data fxyz( 4,11, 7),fxyz( 4,11, 8)/ 1.1380535D-07,-5.9665412D-08/
      data fxyz( 4,11, 9),fxyz( 4,11,10)/ 2.9611549D-08,-5.9665412D-08/
      data fxyz( 4,11,11),fxyz( 4,11,12)/ 1.1380535D-07,-1.3592775D-07/
      data fxyz( 4,11,13),fxyz( 4,11,14)/ 1.1682792D-07,-3.0006776D-08/
      data fxyz( 4,11,15),fxyz( 4,11,16)/-4.3788625D-08,-5.3443421D-09/
      data fxyz( 4,11,17)/                1.8178189D-08/
      data fxyz( 4,12, 1),fxyz( 4,12, 2)/ 3.5985096D-08, 2.0335215D-08/
      data fxyz( 4,12, 3),fxyz( 4,12, 4)/-2.6290347D-08, 3.5498974D-08/
      data fxyz( 4,12, 5),fxyz( 4,12, 6)/-2.4669940D-08,-4.4579289D-08/
      data fxyz( 4,12, 7),fxyz( 4,12, 8)/ 7.9983645D-08,-4.3545834D-08/
      data fxyz( 4,12, 9),fxyz( 4,12,10)/ 2.3442526D-08,-4.3545834D-08/
      data fxyz( 4,12,11),fxyz( 4,12,12)/ 7.9983645D-08,-4.4579289D-08/
      data fxyz( 4,12,13),fxyz( 4,12,14)/-2.4669940D-08, 3.5498974D-08/
      data fxyz( 4,12,15),fxyz( 4,12,16)/-2.6290347D-08, 2.0335215D-08/
      data fxyz( 4,12,17)/                3.5985096D-08/
      data fxyz( 4,13, 1),fxyz( 4,13, 2)/ 1.5098903D-07, 7.3232796D-08/
      data fxyz( 4,13, 3),fxyz( 4,13, 4)/-3.2882198D-08,-3.9741533D-08/
      data fxyz( 4,13, 5),fxyz( 4,13, 6)/ 6.0288635D-07,-1.2392764D-06/
      data fxyz( 4,13, 7),fxyz( 4,13, 8)/ 8.8786438D-07,-2.6838872D-07/
      data fxyz( 4,13, 9),fxyz( 4,13,10)/ 1.2736508D-07,-2.6838872D-07/
      data fxyz( 4,13,11),fxyz( 4,13,12)/ 8.8786438D-07,-1.2392764D-06/
      data fxyz( 4,13,13),fxyz( 4,13,14)/ 6.0288635D-07,-3.9741533D-08/
      data fxyz( 4,13,15),fxyz( 4,13,16)/-3.2882198D-08, 7.3232796D-08/
      data fxyz( 4,13,17)/                1.5098903D-07/
      data fxyz( 4,14, 1),fxyz( 4,14, 2)/ 8.2870595D-07, 5.4299357D-07/
      data fxyz( 4,14, 3),fxyz( 4,14, 4)/-3.5079600D-07, 8.8368455D-07/
      data fxyz( 4,14, 5),fxyz( 4,14, 6)/-5.3405798D-07,-1.0367453D-06/
      data fxyz( 4,14, 7),fxyz( 4,14, 8)/ 1.1574622D-06,-3.4195766D-07/
      data fxyz( 4,14, 9),fxyz( 4,14,10)/ 1.5080616D-07,-3.4195766D-07/
      data fxyz( 4,14,11),fxyz( 4,14,12)/ 1.1574622D-06,-1.0367453D-06/
      data fxyz( 4,14,13),fxyz( 4,14,14)/-5.3405798D-07, 8.8368455D-07/
      data fxyz( 4,14,15),fxyz( 4,14,16)/-3.5079600D-07, 5.4299357D-07/
      data fxyz( 4,14,17)/                8.2870595D-07/
      data fxyz( 4,15, 1),fxyz( 4,15, 2)/-1.7027463D-06,-1.2243633D-06/
      data fxyz( 4,15, 3),fxyz( 4,15, 4)/ 8.5458621D-07,-2.6684471D-06/
      data fxyz( 4,15, 5),fxyz( 4,15, 6)/ 4.0735890D-06,-2.3934166D-06/
      data fxyz( 4,15, 7),fxyz( 4,15, 8)/ 6.3023294D-07,-2.3898818D-07/
      data fxyz( 4,15, 9),fxyz( 4,15,10)/ 9.8793157D-08,-2.3898818D-07/
      data fxyz( 4,15,11),fxyz( 4,15,12)/ 6.3023294D-07,-2.3934166D-06/
      data fxyz( 4,15,13),fxyz( 4,15,14)/ 4.0735890D-06,-2.6684471D-06/
      data fxyz( 4,15,15),fxyz( 4,15,16)/ 8.5458621D-07,-1.2243633D-06/
      data fxyz( 4,15,17)/               -1.7027463D-06/
      data fxyz( 4,16, 1),fxyz( 4,16, 2)/ 1.8687959D-06, 1.5690521D-06/
      data fxyz( 4,16, 3),fxyz( 4,16, 4)/-1.5261427D-06, 5.1627410D-06/
      data fxyz( 4,16, 5),fxyz( 4,16, 6)/-1.2505960D-05, 1.4949689D-05/
      data fxyz( 4,16, 7),fxyz( 4,16, 8)/-8.1876209D-06, 2.2220252D-06/
      data fxyz( 4,16, 9),fxyz( 4,16,10)/-1.1566582D-06, 2.2220252D-06/
      data fxyz( 4,16,11),fxyz( 4,16,12)/-8.1876209D-06, 1.4949689D-05/
      data fxyz( 4,16,13),fxyz( 4,16,14)/-1.2505960D-05, 5.1627410D-06/
      data fxyz( 4,16,15),fxyz( 4,16,16)/-1.5261427D-06, 1.5690521D-06/
      data fxyz( 4,16,17)/                1.8687959D-06/
      data fxyz( 4,17, 1),fxyz( 4,17, 2)/-4.2229248D-06,-3.0884812D-06/
      data fxyz( 4,17, 3),fxyz( 4,17, 4)/ 2.4436467D-06,-7.4161208D-06/
      data fxyz( 4,17, 5),fxyz( 4,17, 6)/ 1.3087634D-05,-1.1147773D-05/
      data fxyz( 4,17, 7),fxyz( 4,17, 8)/ 4.4794821D-06,-8.8734774D-07/
      data fxyz( 4,17, 9),fxyz( 4,17,10)/ 6.0333131D-07,-8.8734774D-07/
      data fxyz( 4,17,11),fxyz( 4,17,12)/ 4.4794821D-06,-1.1147773D-05/
      data fxyz( 4,17,13),fxyz( 4,17,14)/ 1.3087634D-05,-7.4161208D-06/
      data fxyz( 4,17,15),fxyz( 4,17,16)/ 2.4436467D-06,-3.0884812D-06/
      data fxyz( 4,17,17)/               -4.2229248D-06/
      data fxyz( 4,18, 1),fxyz( 4,18, 2)/ 2.9962981D-06, 2.0506341D-06/
      data fxyz( 4,18, 3),fxyz( 4,18, 4)/-1.4901693D-06, 4.0520151D-06/
      data fxyz( 4,18, 5),fxyz( 4,18, 6)/-5.0092259D-06, 2.3251878D-06/
      data fxyz( 4,18, 7),fxyz( 4,18, 8)/-2.4266101D-07,-2.2734375D-07/
      data fxyz( 4,18, 9),fxyz( 4,18,10)/ 2.7788237D-08,-2.2734375D-07/
      data fxyz( 4,18,11),fxyz( 4,18,12)/-2.4266101D-07, 2.3251878D-06/
      data fxyz( 4,18,13),fxyz( 4,18,14)/-5.0092259D-06, 4.0520151D-06/
      data fxyz( 4,18,15),fxyz( 4,18,16)/-1.4901693D-06, 2.0506341D-06/
      data fxyz( 4,18,17)/                2.9962981D-06/
      data fxyz( 4,19, 1),fxyz( 4,19, 2)/ 6.4123943D-06, 4.3907070D-06/
      data fxyz( 4,19, 3),fxyz( 4,19, 4)/-3.1658124D-06, 8.6495802D-06/
      data fxyz( 4,19, 5),fxyz( 4,19, 6)/-1.0623099D-05, 4.4923135D-06/
      data fxyz( 4,19, 7),fxyz( 4,19, 8)/ 3.5519327D-09,-6.4430458D-07/
      data fxyz( 4,19, 9),fxyz( 4,19,10)/ 1.1954018D-07,-6.4430458D-07/
      data fxyz( 4,19,11),fxyz( 4,19,12)/ 3.5519327D-09, 4.4923135D-06/
      data fxyz( 4,19,13),fxyz( 4,19,14)/-1.0623099D-05, 8.6495802D-06/
      data fxyz( 4,19,15),fxyz( 4,19,16)/-3.1658124D-06, 4.3907070D-06/
      data fxyz( 4,19,17)/                6.4123943D-06/
      data fxyz( 5, 1, 1),fxyz( 5, 1, 2)/-3.0719115D-07,-9.6240196D-08/
      data fxyz( 5, 1, 3),fxyz( 5, 1, 4)/ 4.5733192D-07,-1.8827001D-07/
      data fxyz( 5, 1, 5),fxyz( 5, 1, 6)/ 6.0928099D-08,-3.7942981D-07/
      data fxyz( 5, 1, 7),fxyz( 5, 1, 8)/ 3.7607719D-07,-1.5344868D-07/
      data fxyz( 5, 1, 9),fxyz( 5, 1,10)/ 9.5616195D-08,-1.5344868D-07/
      data fxyz( 5, 1,11),fxyz( 5, 1,12)/ 3.7607719D-07,-3.7942981D-07/
      data fxyz( 5, 1,13),fxyz( 5, 1,14)/ 6.0928099D-08,-1.8827001D-07/
      data fxyz( 5, 1,15),fxyz( 5, 1,16)/ 4.5733192D-07,-9.6240196D-08/
      data fxyz( 5, 1,17)/               -3.0719115D-07/
      data fxyz( 5, 2, 1),fxyz( 5, 2, 2)/ 8.8312249D-08, 4.7509697D-08/
      data fxyz( 5, 2, 3),fxyz( 5, 2, 4)/-6.9673152D-08, 8.0475039D-08/
      data fxyz( 5, 2, 5),fxyz( 5, 2, 6)/-4.3549121D-08, 9.3965673D-09/
      data fxyz( 5, 2, 7),fxyz( 5, 2, 8)/-7.4972410D-08, 7.7242004D-08/
      data fxyz( 5, 2, 9),fxyz( 5, 2,10)/-2.2016784D-08, 7.7242004D-08/
      data fxyz( 5, 2,11),fxyz( 5, 2,12)/-7.4972410D-08, 9.3965673D-09/
      data fxyz( 5, 2,13),fxyz( 5, 2,14)/-4.3549121D-08, 8.0475039D-08/
      data fxyz( 5, 2,15),fxyz( 5, 2,16)/-6.9673152D-08, 4.7509697D-08/
      data fxyz( 5, 2,17)/                8.8312249D-08/
      data fxyz( 5, 3, 1),fxyz( 5, 3, 2)/ 3.6800895D-07, 1.2680892D-07/
      data fxyz( 5, 3, 3),fxyz( 5, 3, 4)/-5.0364882D-07, 2.2829540D-07/
      data fxyz( 5, 3, 5),fxyz( 5, 3, 6)/-3.7936989D-08, 2.1889378D-07/
      data fxyz( 5, 3, 7),fxyz( 5, 3, 8)/-2.0631743D-07, 6.4302516D-08/
      data fxyz( 5, 3, 9),fxyz( 5, 3,10)/-1.3911306D-08, 6.4302516D-08/
      data fxyz( 5, 3,11),fxyz( 5, 3,12)/-2.0631743D-07, 2.1889378D-07/
      data fxyz( 5, 3,13),fxyz( 5, 3,14)/-3.7936989D-08, 2.2829540D-07/
      data fxyz( 5, 3,15),fxyz( 5, 3,16)/-5.0364882D-07, 1.2680892D-07/
      data fxyz( 5, 3,17)/                3.6800895D-07/
      data fxyz( 5, 4, 1),fxyz( 5, 4, 2)/ 1.0530291D-06, 4.3168549D-07/
      data fxyz( 5, 4, 3),fxyz( 5, 4, 4)/-1.2632274D-06, 7.9935217D-07/
      data fxyz( 5, 4, 5),fxyz( 5, 4, 6)/-4.1763759D-07, 1.0560431D-06/
      data fxyz( 5, 4, 7),fxyz( 5, 4, 8)/-1.4566285D-06, 9.0406864D-07/
      data fxyz( 5, 4, 9),fxyz( 5, 4,10)/-4.4589043D-07, 9.0406864D-07/
      data fxyz( 5, 4,11),fxyz( 5, 4,12)/-1.4566285D-06, 1.0560431D-06/
      data fxyz( 5, 4,13),fxyz( 5, 4,14)/-4.1763759D-07, 7.9935217D-07/
      data fxyz( 5, 4,15),fxyz( 5, 4,16)/-1.2632274D-06, 4.3168549D-07/
      data fxyz( 5, 4,17)/                1.0530291D-06/
      data fxyz( 5, 5, 1),fxyz( 5, 5, 2)/-1.8778024D-06,-7.8815221D-07/
      data fxyz( 5, 5, 3),fxyz( 5, 5, 4)/ 2.1599273D-06,-1.3964957D-06/
      data fxyz( 5, 5, 5),fxyz( 5, 5, 6)/ 5.5557169D-07,-1.3776695D-06/
      data fxyz( 5, 5, 7),fxyz( 5, 5, 8)/ 2.1405263D-06,-1.2906207D-06/
      data fxyz( 5, 5, 9),fxyz( 5, 5,10)/ 4.7605812D-07,-1.2906207D-06/
      data fxyz( 5, 5,11),fxyz( 5, 5,12)/ 2.1405263D-06,-1.3776695D-06/
      data fxyz( 5, 5,13),fxyz( 5, 5,14)/ 5.5557169D-07,-1.3964957D-06/
      data fxyz( 5, 5,15),fxyz( 5, 5,16)/ 2.1599273D-06,-7.8815221D-07/
      data fxyz( 5, 5,17)/               -1.8778024D-06/
      data fxyz( 5, 6, 1),fxyz( 5, 6, 2)/-1.0391382D-06,-4.6125569D-07/
      data fxyz( 5, 6, 3),fxyz( 5, 6, 4)/ 1.1385891D-06,-8.3843403D-07/
      data fxyz( 5, 6, 5),fxyz( 5, 6, 6)/ 4.6957513D-07,-7.1464457D-07/
      data fxyz( 5, 6, 7),fxyz( 5, 6, 8)/ 9.3732743D-07,-6.6215332D-07/
      data fxyz( 5, 6, 9),fxyz( 5, 6,10)/ 4.1520655D-07,-6.6215332D-07/
      data fxyz( 5, 6,11),fxyz( 5, 6,12)/ 9.3732743D-07,-7.1464457D-07/
      data fxyz( 5, 6,13),fxyz( 5, 6,14)/ 4.6957513D-07,-8.3843403D-07/
      data fxyz( 5, 6,15),fxyz( 5, 6,16)/ 1.1385891D-06,-4.6125569D-07/
      data fxyz( 5, 6,17)/               -1.0391382D-06/
      data fxyz( 5, 7, 1),fxyz( 5, 7, 2)/ 1.3699661D-06, 5.8178704D-07/
      data fxyz( 5, 7, 3),fxyz( 5, 7, 4)/-1.5486230D-06, 1.0187754D-06/
      data fxyz( 5, 7, 5),fxyz( 5, 7, 6)/-3.7798743D-07, 8.4273503D-07/
      data fxyz( 5, 7, 7),fxyz( 5, 7, 8)/-1.3860776D-06, 8.9468296D-07/
      data fxyz( 5, 7, 9),fxyz( 5, 7,10)/-3.6280231D-07, 8.9468296D-07/
      data fxyz( 5, 7,11),fxyz( 5, 7,12)/-1.3860776D-06, 8.4273503D-07/
      data fxyz( 5, 7,13),fxyz( 5, 7,14)/-3.7798743D-07, 1.0187754D-06/
      data fxyz( 5, 7,15),fxyz( 5, 7,16)/-1.5486230D-06, 5.8178704D-07/
      data fxyz( 5, 7,17)/                1.3699661D-06/
      data fxyz( 5, 8, 1),fxyz( 5, 8, 2)/ 2.9540250D-07, 1.5469887D-07/
      data fxyz( 5, 8, 3),fxyz( 5, 8, 4)/-2.5091065D-07, 2.7065043D-07/
      data fxyz( 5, 8, 5),fxyz( 5, 8, 6)/-1.6840377D-07, 5.2876302D-08/
      data fxyz( 5, 8, 7),fxyz( 5, 8, 8)/-9.5940881D-08, 1.1822634D-07/
      data fxyz( 5, 8, 9),fxyz( 5, 8,10)/-8.4580946D-08, 1.1822634D-07/
      data fxyz( 5, 8,11),fxyz( 5, 8,12)/-9.5940881D-08, 5.2876302D-08/
      data fxyz( 5, 8,13),fxyz( 5, 8,14)/-1.6840377D-07, 2.7065043D-07/
      data fxyz( 5, 8,15),fxyz( 5, 8,16)/-2.5091065D-07, 1.5469887D-07/
      data fxyz( 5, 8,17)/                2.9540250D-07/
      data fxyz( 5, 9, 1),fxyz( 5, 9, 2)/-2.1556270D-07,-7.1799598D-08/
      data fxyz( 5, 9, 3),fxyz( 5, 9, 4)/ 2.9761220D-07,-1.2274645D-07/
      data fxyz( 5, 9, 5),fxyz( 5, 9, 6)/-1.1775281D-08,-7.6744108D-08/
      data fxyz( 5, 9, 7),fxyz( 5, 9, 8)/ 6.9918713D-08,-5.0774849D-09/
      data fxyz( 5, 9, 9),fxyz( 5, 9,10)/-1.3254117D-08,-5.0774849D-09/
      data fxyz( 5, 9,11),fxyz( 5, 9,12)/ 6.9918713D-08,-7.6744108D-08/
      data fxyz( 5, 9,13),fxyz( 5, 9,14)/-1.1775281D-08,-1.2274645D-07/
      data fxyz( 5, 9,15),fxyz( 5, 9,16)/ 2.9761220D-07,-7.1799598D-08/
      data fxyz( 5, 9,17)/               -2.1556270D-07/
      data fxyz( 5,10, 1),fxyz( 5,10, 2)/ 1.7431333D-08, 1.0143840D-08/
      data fxyz( 5,10, 3),fxyz( 5,10, 4)/-4.6466192D-09, 6.8233023D-09/
      data fxyz( 5,10, 5),fxyz( 5,10, 6)/ 3.0713484D-08,-9.2183659D-08/
      data fxyz( 5,10, 7),fxyz( 5,10, 8)/ 7.9000110D-08,-2.1852094D-08/
      data fxyz( 5,10, 9),fxyz( 5,10,10)/-9.0908903D-10,-2.1852094D-08/
      data fxyz( 5,10,11),fxyz( 5,10,12)/ 7.9000110D-08,-9.2183659D-08/
      data fxyz( 5,10,13),fxyz( 5,10,14)/ 3.0713484D-08, 6.8233023D-09/
      data fxyz( 5,10,15),fxyz( 5,10,16)/-4.6466192D-09, 1.0143840D-08/
      data fxyz( 5,10,17)/                1.7431333D-08/
      data fxyz( 5,11, 1),fxyz( 5,11, 2)/ 2.8957956D-08, 5.4955579D-09/
      data fxyz( 5,11, 3),fxyz( 5,11, 4)/-4.3539788D-08,-3.0698153D-09/
      data fxyz( 5,11, 5),fxyz( 5,11, 6)/ 6.3219449D-08,-8.7532678D-08/
      data fxyz( 5,11, 7),fxyz( 5,11, 8)/ 7.9575599D-08,-3.8416608D-08/
      data fxyz( 5,11, 9),fxyz( 5,11,10)/ 1.4560332D-08,-3.8416608D-08/
      data fxyz( 5,11,11),fxyz( 5,11,12)/ 7.9575599D-08,-8.7532678D-08/
      data fxyz( 5,11,13),fxyz( 5,11,14)/ 6.3219449D-08,-3.0698153D-09/
      data fxyz( 5,11,15),fxyz( 5,11,16)/-4.3539788D-08, 5.4955579D-09/
      data fxyz( 5,11,17)/                2.8957956D-08/
      data fxyz( 5,12, 1),fxyz( 5,12, 2)/ 3.9605028D-09,-5.2560810D-09/
      data fxyz( 5,12, 3),fxyz( 5,12, 4)/-7.8500733D-09,-3.3623136D-08/
      data fxyz( 5,12, 5),fxyz( 5,12, 6)/ 1.1742872D-07,-1.7886227D-07/
      data fxyz( 5,12, 7),fxyz( 5,12, 8)/ 1.3827071D-07,-5.7706729D-08/
      data fxyz( 5,12, 9),fxyz( 5,12,10)/ 3.2107638D-08,-5.7706729D-08/
      data fxyz( 5,12,11),fxyz( 5,12,12)/ 1.3827071D-07,-1.7886227D-07/
      data fxyz( 5,12,13),fxyz( 5,12,14)/ 1.1742872D-07,-3.3623136D-08/
      data fxyz( 5,12,15),fxyz( 5,12,16)/-7.8500733D-09,-5.2560810D-09/
      data fxyz( 5,12,17)/                3.9605028D-09/
      data fxyz( 5,13, 1),fxyz( 5,13, 2)/ 1.3001740D-07, 8.1671513D-08/
      data fxyz( 5,13, 3),fxyz( 5,13, 4)/-6.2013182D-08, 1.2798796D-07/
      data fxyz( 5,13, 5),fxyz( 5,13, 6)/-5.5248382D-08,-2.0210443D-07/
      data fxyz( 5,13, 7),fxyz( 5,13, 8)/ 2.1966644D-07,-7.2233895D-08/
      data fxyz( 5,13, 9),fxyz( 5,13,10)/ 3.3597202D-08,-7.2233895D-08/
      data fxyz( 5,13,11),fxyz( 5,13,12)/ 2.1966644D-07,-2.0210443D-07/
      data fxyz( 5,13,13),fxyz( 5,13,14)/-5.5248382D-08, 1.2798796D-07/
      data fxyz( 5,13,15),fxyz( 5,13,16)/-6.2013182D-08, 8.1671513D-08/
      data fxyz( 5,13,17)/                1.3001740D-07/
      data fxyz( 5,14, 1),fxyz( 5,14, 2)/ 3.2307860D-07, 1.8343850D-07/
      data fxyz( 5,14, 3),fxyz( 5,14, 4)/-7.4140298D-08, 8.1066341D-08/
      data fxyz( 5,14, 5),fxyz( 5,14, 6)/ 7.3256722D-07,-1.8500679D-06/
      data fxyz( 5,14, 7),fxyz( 5,14, 8)/ 1.3653006D-06,-3.9257722D-07/
      data fxyz( 5,14, 9),fxyz( 5,14,10)/ 1.8450008D-07,-3.9257722D-07/
      data fxyz( 5,14,11),fxyz( 5,14,12)/ 1.3653006D-06,-1.8500679D-06/
      data fxyz( 5,14,13),fxyz( 5,14,14)/ 7.3256722D-07, 8.1066341D-08/
      data fxyz( 5,14,15),fxyz( 5,14,16)/-7.4140298D-08, 1.8343850D-07/
      data fxyz( 5,14,17)/                3.2307860D-07/
      data fxyz( 5,15, 1),fxyz( 5,15, 2)/-5.2914437D-07,-2.9554099D-07/
      data fxyz( 5,15, 3),fxyz( 5,15, 4)/ 7.8382187D-09, 6.7002059D-08/
      data fxyz( 5,15, 5),fxyz( 5,15, 6)/-1.9793166D-06, 4.2654830D-06/
      data fxyz( 5,15, 7),fxyz( 5,15, 8)/-2.9018787D-06, 7.7814652D-07/
      data fxyz( 5,15, 9),fxyz( 5,15,10)/-4.0628688D-07, 7.7814652D-07/
      data fxyz( 5,15,11),fxyz( 5,15,12)/-2.9018787D-06, 4.2654830D-06/
      data fxyz( 5,15,13),fxyz( 5,15,14)/-1.9793166D-06, 6.7002059D-08/
      data fxyz( 5,15,15),fxyz( 5,15,16)/ 7.8382187D-09,-2.9554099D-07/
      data fxyz( 5,15,17)/               -5.2914437D-07/
      data fxyz( 5,16, 1),fxyz( 5,16, 2)/-3.0416731D-07,-1.9105287D-07/
      data fxyz( 5,16, 3),fxyz( 5,16, 4)/ 2.0520530D-07,-3.8953962D-07/
      data fxyz( 5,16, 5),fxyz( 5,16, 6)/ 4.8977967D-07,-2.5322080D-07/
      data fxyz( 5,16, 7),fxyz( 5,16, 8)/ 9.3895352D-08,-5.9642531D-08/
      data fxyz( 5,16, 9),fxyz( 5,16,10)/-8.3056860D-10,-5.9642531D-08/
      data fxyz( 5,16,11),fxyz( 5,16,12)/ 9.3895352D-08,-2.5322080D-07/
      data fxyz( 5,16,13),fxyz( 5,16,14)/ 4.8977967D-07,-3.8953962D-07/
      data fxyz( 5,16,15),fxyz( 5,16,16)/ 2.0520530D-07,-1.9105287D-07/
      data fxyz( 5,16,17)/               -3.0416731D-07/
      data fxyz( 5,17, 1),fxyz( 5,17, 2)/-8.8144592D-08,-4.1436104D-08/
      data fxyz( 5,17, 3),fxyz( 5,17, 4)/ 4.4701245D-08,-7.1624199D-09/
      data fxyz( 5,17, 5),fxyz( 5,17, 6)/-2.2523933D-07,-5.4930847D-08/
      data fxyz( 5,17, 7),fxyz( 5,17, 8)/ 1.9396689D-07, 2.5352443D-08/
      data fxyz( 5,17, 9),fxyz( 5,17,10)/ 9.7037556D-08, 2.5352443D-08/
      data fxyz( 5,17,11),fxyz( 5,17,12)/ 1.9396689D-07,-5.4930847D-08/
      data fxyz( 5,17,13),fxyz( 5,17,14)/-2.2523933D-07,-7.1624199D-09/
      data fxyz( 5,17,15),fxyz( 5,17,16)/ 4.4701245D-08,-4.1436104D-08/
      data fxyz( 5,17,17)/               -8.8144592D-08/
      data fxyz( 5,18, 1),fxyz( 5,18, 2)/ 3.4357932D-07, 9.3445258D-08/
      data fxyz( 5,18, 3),fxyz( 5,18, 4)/-2.6256478D-07,-2.4800890D-07/
      data fxyz( 5,18, 5),fxyz( 5,18, 6)/ 1.7093960D-06,-1.6001148D-06/
      data fxyz( 5,18, 7),fxyz( 5,18, 8)/ 5.5162187D-07,-3.1529254D-07/
      data fxyz( 5,18, 9),fxyz( 5,18,10)/ 1.0452563D-08,-3.1529254D-07/
      data fxyz( 5,18,11),fxyz( 5,18,12)/ 5.5162187D-07,-1.6001148D-06/
      data fxyz( 5,18,13),fxyz( 5,18,14)/ 1.7093960D-06,-2.4800890D-07/
      data fxyz( 5,18,15),fxyz( 5,18,16)/-2.6256478D-07, 9.3445258D-08/
      data fxyz( 5,18,17)/                3.4357932D-07/
      data fxyz( 5,19, 1),fxyz( 5,19, 2)/ 7.1367432D-07, 2.3253674D-07/
      data fxyz( 5,19, 3),fxyz( 5,19, 4)/-5.2789881D-07,-3.1079148D-07/
      data fxyz( 5,19, 5),fxyz( 5,19, 6)/ 2.8869872D-06,-2.6471634D-06/
      data fxyz( 5,19, 7),fxyz( 5,19, 8)/ 8.3568158D-07,-5.3432610D-07/
      data fxyz( 5,19, 9),fxyz( 5,19,10)/-2.3431540D-08,-5.3432610D-07/
      data fxyz( 5,19,11),fxyz( 5,19,12)/ 8.3568158D-07,-2.6471634D-06/
      data fxyz( 5,19,13),fxyz( 5,19,14)/ 2.8869872D-06,-3.1079148D-07/
      data fxyz( 5,19,15),fxyz( 5,19,16)/-5.2789881D-07, 2.3253674D-07/
      data fxyz( 5,19,17)/                7.1367432D-07/
      data fxyz( 6, 1, 1),fxyz( 6, 1, 2)/-1.2750210D-07,-2.5459730D-08/
      data fxyz( 6, 1, 3),fxyz( 6, 1, 4)/ 2.3121716D-07,-5.3326777D-08/
      data fxyz( 6, 1, 5),fxyz( 6, 1, 6)/-1.6033911D-08,-1.6757753D-07/
      data fxyz( 6, 1, 7),fxyz( 6, 1, 8)/ 1.2536815D-07,-2.0893232D-08/
      data fxyz( 6, 1, 9),fxyz( 6, 1,10)/ 2.9064941D-08,-2.0893232D-08/
      data fxyz( 6, 1,11),fxyz( 6, 1,12)/ 1.2536815D-07,-1.6757753D-07/
      data fxyz( 6, 1,13),fxyz( 6, 1,14)/-1.6033911D-08,-5.3326777D-08/
      data fxyz( 6, 1,15),fxyz( 6, 1,16)/ 2.3121716D-07,-2.5459730D-08/
      data fxyz( 6, 1,17)/               -1.2750210D-07/
      data fxyz( 6, 2, 1),fxyz( 6, 2, 2)/ 2.7922933D-08, 2.2543945D-08/
      data fxyz( 6, 2, 3),fxyz( 6, 2, 4)/-1.1039047D-09, 3.9189262D-08/
      data fxyz( 6, 2, 5),fxyz( 6, 2, 6)/-3.8658334D-08,-1.2244077D-08/
      data fxyz( 6, 2, 7),fxyz( 6, 2, 8)/-1.3431200D-08, 3.2776514D-08/
      data fxyz( 6, 2, 9),fxyz( 6, 2,10)/-1.1386206D-08, 3.2776514D-08/
      data fxyz( 6, 2,11),fxyz( 6, 2,12)/-1.3431200D-08,-1.2244077D-08/
      data fxyz( 6, 2,13),fxyz( 6, 2,14)/-3.8658334D-08, 3.9189262D-08/
      data fxyz( 6, 2,15),fxyz( 6, 2,16)/-1.1039047D-09, 2.2543945D-08/
      data fxyz( 6, 2,17)/                2.7922933D-08/
      data fxyz( 6, 3, 1),fxyz( 6, 3, 2)/ 1.3095592D-07, 4.1579355D-08/
      data fxyz( 6, 3, 3),fxyz( 6, 3, 4)/-1.9231848D-07, 7.9608137D-08/
      data fxyz( 6, 3, 5),fxyz( 6, 3, 6)/-2.1159211D-08, 7.8431007D-08/
      data fxyz( 6, 3, 7),fxyz( 6, 3, 8)/-2.1350115D-08,-7.7745612D-09/
      data fxyz( 6, 3, 9),fxyz( 6, 3,10)/-1.6853900D-08,-7.7745612D-09/
      data fxyz( 6, 3,11),fxyz( 6, 3,12)/-2.1350115D-08, 7.8431007D-08/
      data fxyz( 6, 3,13),fxyz( 6, 3,14)/-2.1159211D-08, 7.9608137D-08/
      data fxyz( 6, 3,15),fxyz( 6, 3,16)/-1.9231848D-07, 4.1579355D-08/
      data fxyz( 6, 3,17)/                1.3095592D-07/
      data fxyz( 6, 4, 1),fxyz( 6, 4, 2)/ 4.1736106D-07, 1.6200369D-07/
      data fxyz( 6, 4, 3),fxyz( 6, 4, 4)/-5.2740576D-07, 3.0236709D-07/
      data fxyz( 6, 4, 5),fxyz( 6, 4, 6)/-1.4409250D-07, 3.9541039D-07/
      data fxyz( 6, 4, 7),fxyz( 6, 4, 8)/-4.8735054D-07, 2.8144724D-07/
      data fxyz( 6, 4, 9),fxyz( 6, 4,10)/-1.4476368D-07, 2.8144724D-07/
      data fxyz( 6, 4,11),fxyz( 6, 4,12)/-4.8735054D-07, 3.9541039D-07/
      data fxyz( 6, 4,13),fxyz( 6, 4,14)/-1.4409250D-07, 3.0236709D-07/
      data fxyz( 6, 4,15),fxyz( 6, 4,16)/-5.2740576D-07, 1.6200369D-07/
      data fxyz( 6, 4,17)/                4.1736106D-07/
      data fxyz( 6, 5, 1),fxyz( 6, 5, 2)/-8.1834885D-07,-3.5642852D-07/
      data fxyz( 6, 5, 3),fxyz( 6, 5, 4)/ 9.0456001D-07,-6.3119013D-07/
      data fxyz( 6, 5, 5),fxyz( 6, 5, 6)/ 2.8069761D-07,-4.7797375D-07/
      data fxyz( 6, 5, 7),fxyz( 6, 5, 8)/ 7.0238233D-07,-4.4923056D-07/
      data fxyz( 6, 5, 9),fxyz( 6, 5,10)/ 2.0027538D-07,-4.4923056D-07/
      data fxyz( 6, 5,11),fxyz( 6, 5,12)/ 7.0238233D-07,-4.7797375D-07/
      data fxyz( 6, 5,13),fxyz( 6, 5,14)/ 2.8069761D-07,-6.3119013D-07/
      data fxyz( 6, 5,15),fxyz( 6, 5,16)/ 9.0456001D-07,-3.5642852D-07/
      data fxyz( 6, 5,17)/               -8.1834885D-07/
      data fxyz( 6, 6, 1),fxyz( 6, 6, 2)/-3.8702210D-07,-1.8318568D-07/
      data fxyz( 6, 6, 3),fxyz( 6, 6, 4)/ 3.9452719D-07,-3.3632749D-07/
      data fxyz( 6, 6, 5),fxyz( 6, 6, 6)/ 2.2554515D-07,-2.1960295D-07/
      data fxyz( 6, 6, 7),fxyz( 6, 6, 8)/ 2.2241020D-07,-1.8028273D-07/
      data fxyz( 6, 6, 9),fxyz( 6, 6,10)/ 1.5646481D-07,-1.8028273D-07/
      data fxyz( 6, 6,11),fxyz( 6, 6,12)/ 2.2241020D-07,-2.1960295D-07/
      data fxyz( 6, 6,13),fxyz( 6, 6,14)/ 2.2554515D-07,-3.3632749D-07/
      data fxyz( 6, 6,15),fxyz( 6, 6,16)/ 3.9452719D-07,-1.8318568D-07/
      data fxyz( 6, 6,17)/               -3.8702210D-07/
      data fxyz( 6, 7, 1),fxyz( 6, 7, 2)/ 7.7513754D-07, 3.3640895D-07/
      data fxyz( 6, 7, 3),fxyz( 6, 7, 4)/-8.5174858D-07, 5.8309515D-07/
      data fxyz( 6, 7, 5),fxyz( 6, 7, 6)/-2.1160726D-07, 3.1348690D-07/
      data fxyz( 6, 7, 7),fxyz( 6, 7, 8)/-5.1415622D-07, 3.5966934D-07/
      data fxyz( 6, 7, 9),fxyz( 6, 7,10)/-1.6811285D-07, 3.5966934D-07/
      data fxyz( 6, 7,11),fxyz( 6, 7,12)/-5.1415622D-07, 3.1348690D-07/
      data fxyz( 6, 7,13),fxyz( 6, 7,14)/-2.1160726D-07, 5.8309515D-07/
      data fxyz( 6, 7,15),fxyz( 6, 7,16)/-8.5174858D-07, 3.3640895D-07/
      data fxyz( 6, 7,17)/                7.7513754D-07/
      data fxyz( 6, 8, 1),fxyz( 6, 8, 2)/ 3.9102728D-08, 4.2389712D-08/
      data fxyz( 6, 8, 3),fxyz( 6, 8, 4)/ 2.6803368D-08, 7.7273669D-08/
      data fxyz( 6, 8, 5),fxyz( 6, 8, 6)/-1.0043310D-07,-2.2550910D-08/
      data fxyz( 6, 8, 7),fxyz( 6, 8, 8)/ 2.3958783D-08, 3.3901590D-08/
      data fxyz( 6, 8, 9),fxyz( 6, 8,10)/-4.5289435D-08, 3.3901590D-08/
      data fxyz( 6, 8,11),fxyz( 6, 8,12)/ 2.3958783D-08,-2.2550910D-08/
      data fxyz( 6, 8,13),fxyz( 6, 8,14)/-1.0043310D-07, 7.7273669D-08/
      data fxyz( 6, 8,15),fxyz( 6, 8,16)/ 2.6803368D-08, 4.2389712D-08/
      data fxyz( 6, 8,17)/                3.9102728D-08/
      data fxyz( 6, 9, 1),fxyz( 6, 9, 2)/-1.6822180D-07,-5.4793945D-08/
      data fxyz( 6, 9, 3),fxyz( 6, 9, 4)/ 2.3704930D-07,-9.5561318D-08/
      data fxyz( 6, 9, 5),fxyz( 6, 9, 6)/-5.1523056D-09,-8.0087045D-08/
      data fxyz( 6, 9, 7),fxyz( 6, 9, 8)/ 7.4742482D-08,-2.0619354D-08/
      data fxyz( 6, 9, 9),fxyz( 6, 9,10)/ 9.5112219D-09,-2.0619354D-08/
      data fxyz( 6, 9,11),fxyz( 6, 9,12)/ 7.4742482D-08,-8.0087045D-08/
      data fxyz( 6, 9,13),fxyz( 6, 9,14)/-5.1523056D-09,-9.5561318D-08/
      data fxyz( 6, 9,15),fxyz( 6, 9,16)/ 2.3704930D-07,-5.4793945D-08/
      data fxyz( 6, 9,17)/               -1.6822180D-07/
      data fxyz( 6,10, 1),fxyz( 6,10, 2)/ 7.6954166D-09, 8.8418051D-09/
      data fxyz( 6,10, 3),fxyz( 6,10, 4)/ 1.2125672D-08, 7.9283645D-09/
      data fxyz( 6,10, 5),fxyz( 6,10, 6)/ 1.1349179D-08,-6.2057669D-08/
      data fxyz( 6,10, 7),fxyz( 6,10, 8)/ 3.5825286D-08, 5.2331147D-09/
      data fxyz( 6,10, 9),fxyz( 6,10,10)/-8.8344620D-09, 5.2331147D-09/
      data fxyz( 6,10,11),fxyz( 6,10,12)/ 3.5825286D-08,-6.2057669D-08/
      data fxyz( 6,10,13),fxyz( 6,10,14)/ 1.1349179D-08, 7.9283645D-09/
      data fxyz( 6,10,15),fxyz( 6,10,16)/ 1.2125672D-08, 8.8418051D-09/
      data fxyz( 6,10,17)/                7.6954166D-09/
      data fxyz( 6,11, 1),fxyz( 6,11, 2)/ 2.8197531D-08, 9.3893167D-09/
      data fxyz( 6,11, 3),fxyz( 6,11, 4)/-2.9762159D-08, 2.2877787D-09/
      data fxyz( 6,11, 5),fxyz( 6,11, 6)/ 5.6603683D-08,-1.0049570D-07/
      data fxyz( 6,11, 7),fxyz( 6,11, 8)/ 7.8604531D-08,-2.7572439D-08/
      data fxyz( 6,11, 9),fxyz( 6,11,10)/ 9.7228691D-09,-2.7572439D-08/
      data fxyz( 6,11,11),fxyz( 6,11,12)/ 7.8604531D-08,-1.0049570D-07/
      data fxyz( 6,11,13),fxyz( 6,11,14)/ 5.6603683D-08, 2.2877787D-09/
      data fxyz( 6,11,15),fxyz( 6,11,16)/-2.9762159D-08, 9.3893167D-09/
      data fxyz( 6,11,17)/                2.8197531D-08/
      data fxyz( 6,12, 1),fxyz( 6,12, 2)/-2.4420132D-09,-8.9520937D-09/
      data fxyz( 6,12, 3),fxyz( 6,12, 4)/-9.8496655D-09,-3.0391018D-08/
      data fxyz( 6,12, 5),fxyz( 6,12, 6)/ 8.3313683D-08,-1.0128192D-07/
      data fxyz( 6,12, 7),fxyz( 6,12, 8)/ 7.7937971D-08,-3.6815818D-08/
      data fxyz( 6,12, 9),fxyz( 6,12,10)/ 2.0750716D-08,-3.6815818D-08/
      data fxyz( 6,12,11),fxyz( 6,12,12)/ 7.7937971D-08,-1.0128192D-07/
      data fxyz( 6,12,13),fxyz( 6,12,14)/ 8.3313683D-08,-3.0391018D-08/
      data fxyz( 6,12,15),fxyz( 6,12,16)/-9.8496655D-09,-8.9520937D-09/
      data fxyz( 6,12,17)/               -2.4420132D-09/
      data fxyz( 6,13, 1),fxyz( 6,13, 2)/ 5.5221593D-08, 3.1562484D-08/
      data fxyz( 6,13, 3),fxyz( 6,13, 4)/-2.4996965D-08, 3.3594779D-08/
      data fxyz( 6,13, 5),fxyz( 6,13, 6)/ 4.7092416D-08,-1.9969572D-07/
      data fxyz( 6,13, 7),fxyz( 6,13, 8)/ 1.7875122D-07,-6.1877550D-08/
      data fxyz( 6,13, 9),fxyz( 6,13,10)/ 2.9605390D-08,-6.1877550D-08/
      data fxyz( 6,13,11),fxyz( 6,13,12)/ 1.7875122D-07,-1.9969572D-07/
      data fxyz( 6,13,13),fxyz( 6,13,14)/ 4.7092416D-08, 3.3594779D-08/
      data fxyz( 6,13,15),fxyz( 6,13,16)/-2.4996965D-08, 3.1562484D-08/
      data fxyz( 6,13,17)/                5.5221593D-08/
      data fxyz( 6,14, 1),fxyz( 6,14, 2)/ 1.5552108D-07, 1.0087358D-07/
      data fxyz( 6,14, 3),fxyz( 6,14, 4)/-6.8043319D-08, 1.6298265D-07/
      data fxyz( 6,14, 5),fxyz( 6,14, 6)/-9.2915221D-08,-2.1526278D-07/
      data fxyz( 6,14, 7),fxyz( 6,14, 8)/ 2.4020722D-07,-7.0595165D-08/
      data fxyz( 6,14, 9),fxyz( 6,14,10)/ 2.9561412D-08,-7.0595165D-08/
      data fxyz( 6,14,11),fxyz( 6,14,12)/ 2.4020722D-07,-2.1526278D-07/
      data fxyz( 6,14,13),fxyz( 6,14,14)/-9.2915221D-08, 1.6298265D-07/
      data fxyz( 6,14,15),fxyz( 6,14,16)/-6.8043319D-08, 1.0087358D-07/
      data fxyz( 6,14,17)/                1.5552108D-07/
      data fxyz( 6,15, 1),fxyz( 6,15, 2)/-2.1041773D-07,-1.3984734D-07/
      data fxyz( 6,15, 3),fxyz( 6,15, 4)/ 3.8525459D-08,-1.6041021D-07/
      data fxyz( 6,15, 5),fxyz( 6,15, 6)/-1.2816626D-07, 6.9200871D-07/
      data fxyz( 6,15, 7),fxyz( 6,15, 8)/-5.0187574D-07, 1.1059040D-07/
      data fxyz( 6,15, 9),fxyz( 6,15,10)/-6.6246396D-08, 1.1059040D-07/
      data fxyz( 6,15,11),fxyz( 6,15,12)/-5.0187574D-07, 6.9200871D-07/
      data fxyz( 6,15,13),fxyz( 6,15,14)/-1.2816626D-07,-1.6041021D-07/
      data fxyz( 6,15,15),fxyz( 6,15,16)/ 3.8525459D-08,-1.3984734D-07/
      data fxyz( 6,15,17)/               -2.1041773D-07/
      data fxyz( 6,16, 1),fxyz( 6,16, 2)/-1.9810498D-07,-8.4157531D-08/
      data fxyz( 6,16, 3),fxyz( 6,16, 4)/ 6.8043315D-08, 8.6357262D-08/
      data fxyz( 6,16, 5),fxyz( 6,16, 6)/-8.8016415D-07, 1.5332355D-06/
      data fxyz( 6,16, 7),fxyz( 6,16, 8)/-9.2654758D-07, 2.3418094D-07/
      data fxyz( 6,16, 9),fxyz( 6,16,10)/-1.3374812D-07, 2.3418094D-07/
      data fxyz( 6,16,11),fxyz( 6,16,12)/-9.2654758D-07, 1.5332355D-06/
      data fxyz( 6,16,13),fxyz( 6,16,14)/-8.8016415D-07, 8.6357262D-08/
      data fxyz( 6,16,15),fxyz( 6,16,16)/ 6.8043315D-08,-8.4157531D-08/
      data fxyz( 6,16,17)/               -1.9810498D-07/
      data fxyz( 6,17, 1),fxyz( 6,17, 2)/-2.7552510D-07,-2.8776602D-07/
      data fxyz( 6,17, 3),fxyz( 6,17, 4)/-4.0584880D-08,-7.0138097D-07/
      data fxyz( 6,17, 5),fxyz( 6,17, 6)/ 1.3789347D-06,-9.5893929D-07/
      data fxyz( 6,17, 7),fxyz( 6,17, 8)/ 3.7739603D-07,-1.5800553D-07/
      data fxyz( 6,17, 9),fxyz( 6,17,10)/ 9.5639221D-08,-1.5800553D-07/
      data fxyz( 6,17,11),fxyz( 6,17,12)/ 3.7739603D-07,-9.5893929D-07/
      data fxyz( 6,17,13),fxyz( 6,17,14)/ 1.3789347D-06,-7.0138097D-07/
      data fxyz( 6,17,15),fxyz( 6,17,16)/-4.0584880D-08,-2.8776602D-07/
      data fxyz( 6,17,17)/               -2.7552510D-07/
      data fxyz( 6,18, 1),fxyz( 6,18, 2)/ 4.2995059D-07, 3.0291899D-07/
      data fxyz( 6,18, 3),fxyz( 6,18, 4)/-1.0643748D-07, 4.7234312D-07/
      data fxyz( 6,18, 5),fxyz( 6,18, 6)/-2.4774590D-07,-2.5988723D-07/
      data fxyz( 6,18, 7),fxyz( 6,18, 8)/ 2.5516304D-07,-1.2402951D-07/
      data fxyz( 6,18, 9),fxyz( 6,18,10)/-5.7012216D-08,-1.2402951D-07/
      data fxyz( 6,18,11),fxyz( 6,18,12)/ 2.5516304D-07,-2.5988723D-07/
      data fxyz( 6,18,13),fxyz( 6,18,14)/-2.4774590D-07, 4.7234312D-07/
      data fxyz( 6,18,15),fxyz( 6,18,16)/-1.0643748D-07, 3.0291899D-07/
      data fxyz( 6,18,17)/                4.2995059D-07/
      data fxyz( 6,19, 1),fxyz( 6,19, 2)/ 9.1174176D-07, 6.6666301D-07/
      data fxyz( 6,19, 3),fxyz( 6,19, 4)/-1.8451167D-07, 1.0856494D-06/
      data fxyz( 6,19, 5),fxyz( 6,19, 6)/-7.6420379D-07,-4.7261428D-07/
      data fxyz( 6,19, 7),fxyz( 6,19, 8)/ 5.4040908D-07,-2.1181419D-07/
      data fxyz( 6,19, 9),fxyz( 6,19,10)/-1.0050972D-07,-2.1181419D-07/
      data fxyz( 6,19,11),fxyz( 6,19,12)/ 5.4040908D-07,-4.7261428D-07/
      data fxyz( 6,19,13),fxyz( 6,19,14)/-7.6420379D-07, 1.0856494D-06/
      data fxyz( 6,19,15),fxyz( 6,19,16)/-1.8451167D-07, 6.6666301D-07/
      data fxyz( 6,19,17)/                9.1174176D-07/
      data fxyz( 7, 1, 1),fxyz( 7, 1, 2)/ 9.9744236D-10, 1.7928727D-08/
      data fxyz( 7, 1, 3),fxyz( 7, 1, 4)/ 5.0917030D-08, 2.7705771D-08/
      data fxyz( 7, 1, 5),fxyz( 7, 1, 6)/-3.8110734D-08,-3.0079089D-08/
      data fxyz( 7, 1, 7),fxyz( 7, 1, 8)/-2.3217718D-08, 3.4364898D-08/
      data fxyz( 7, 1, 9),fxyz( 7, 1,10)/ 9.3862198D-09, 3.4364898D-08/
      data fxyz( 7, 1,11),fxyz( 7, 1,12)/-2.3217718D-08,-3.0079089D-08/
      data fxyz( 7, 1,13),fxyz( 7, 1,14)/-3.8110734D-08, 2.7705771D-08/
      data fxyz( 7, 1,15),fxyz( 7, 1,16)/ 5.0917030D-08, 1.7928727D-08/
      data fxyz( 7, 1,17)/                9.9744236D-10/
      data fxyz( 7, 2, 1),fxyz( 7, 2, 2)/-1.6858493D-08, 7.6726879D-10/
      data fxyz( 7, 2, 3),fxyz( 7, 2, 4)/ 4.1543663D-08, 1.2928424D-09/
      data fxyz( 7, 2, 5),fxyz( 7, 2, 6)/-1.8960787D-08,-1.8426748D-08/
      data fxyz( 7, 2, 7),fxyz( 7, 2, 8)/ 9.1120040D-09, 3.7534564D-09/
      data fxyz( 7, 2, 9),fxyz( 7, 2,10)/ 5.0023977D-09, 3.7534564D-09/
      data fxyz( 7, 2,11),fxyz( 7, 2,12)/ 9.1120040D-09,-1.8426748D-08/
      data fxyz( 7, 2,13),fxyz( 7, 2,14)/-1.8960787D-08, 1.2928424D-09/
      data fxyz( 7, 2,15),fxyz( 7, 2,16)/ 4.1543663D-08, 7.6726879D-10/
      data fxyz( 7, 2,17)/               -1.6858493D-08/
      data fxyz( 7, 3, 1),fxyz( 7, 3, 2)/-5.2943879D-08,-2.2815664D-08/
      data fxyz( 7, 3, 3),fxyz( 7, 3, 4)/ 5.4696592D-08,-3.3635292D-08/
      data fxyz( 7, 3, 5),fxyz( 7, 3, 6)/-9.6653649D-09,-6.3477827D-09/
      data fxyz( 7, 3, 7),fxyz( 7, 3, 8)/ 6.0246909D-08,-3.0742118D-08/
      data fxyz( 7, 3, 9),fxyz( 7, 3,10)/-1.6212566D-08,-3.0742118D-08/
      data fxyz( 7, 3,11),fxyz( 7, 3,12)/ 6.0246909D-08,-6.3477827D-09/
      data fxyz( 7, 3,13),fxyz( 7, 3,14)/-9.6653649D-09,-3.3635292D-08/
      data fxyz( 7, 3,15),fxyz( 7, 3,16)/ 5.4696592D-08,-2.2815664D-08/
      data fxyz( 7, 3,17)/               -5.2943879D-08/
      data fxyz( 7, 4, 1),fxyz( 7, 4, 2)/-2.5226185D-08,-2.3923437D-08/
      data fxyz( 7, 4, 3),fxyz( 7, 4, 4)/-1.0992512D-08,-3.8760207D-08/
      data fxyz( 7, 4, 5),fxyz( 7, 4, 6)/ 3.4120893D-08, 4.2379933D-09/
      data fxyz( 7, 4, 7),fxyz( 7, 4, 8)/ 4.5563673D-08,-5.1643226D-08/
      data fxyz( 7, 4, 9),fxyz( 7, 4,10)/ 2.1481466D-08,-5.1643226D-08/
      data fxyz( 7, 4,11),fxyz( 7, 4,12)/ 4.5563673D-08, 4.2379933D-09/
      data fxyz( 7, 4,13),fxyz( 7, 4,14)/ 3.4120893D-08,-3.8760207D-08/
      data fxyz( 7, 4,15),fxyz( 7, 4,16)/-1.0992512D-08,-2.3923437D-08/
      data fxyz( 7, 4,17)/               -2.5226185D-08/
      data fxyz( 7, 5, 1),fxyz( 7, 5, 2)/-1.1583283D-08,-2.3315753D-08/
      data fxyz( 7, 5, 3),fxyz( 7, 5, 4)/-3.7279008D-08,-4.3434516D-08/
      data fxyz( 7, 5, 5),fxyz( 7, 5, 6)/ 6.8891770D-08, 4.7805122D-08/
      data fxyz( 7, 5, 7),fxyz( 7, 5, 8)/-9.5817230D-08, 2.9307338D-08/
      data fxyz( 7, 5, 9),fxyz( 7, 5,10)/ 2.0420914D-08, 2.9307338D-08/
      data fxyz( 7, 5,11),fxyz( 7, 5,12)/-9.5817230D-08, 4.7805122D-08/
      data fxyz( 7, 5,13),fxyz( 7, 5,14)/ 6.8891770D-08,-4.3434516D-08/
      data fxyz( 7, 5,15),fxyz( 7, 5,16)/-3.7279008D-08,-2.3315753D-08/
      data fxyz( 7, 5,17)/               -1.1583283D-08/
      data fxyz( 7, 6, 1),fxyz( 7, 6, 2)/ 1.5994684D-07, 5.9963112D-08/
      data fxyz( 7, 6, 3),fxyz( 7, 6, 4)/-1.9973839D-07, 9.9572329D-08/
      data fxyz( 7, 6, 5),fxyz( 7, 6, 6)/ 1.5099690D-09, 5.3915664D-08/
      data fxyz( 7, 6, 7),fxyz( 7, 6, 8)/-1.1134239D-07, 6.9653047D-08/
      data fxyz( 7, 6, 9),fxyz( 7, 6,10)/-2.0277313D-08, 6.9653047D-08/
      data fxyz( 7, 6,11),fxyz( 7, 6,12)/-1.1134239D-07, 5.3915664D-08/
      data fxyz( 7, 6,13),fxyz( 7, 6,14)/ 1.5099690D-09, 9.9572329D-08/
      data fxyz( 7, 6,15),fxyz( 7, 6,16)/-1.9973839D-07, 5.9963112D-08/
      data fxyz( 7, 6,17)/                1.5994684D-07/
      data fxyz( 7, 7, 1),fxyz( 7, 7, 2)/ 1.2440439D-07, 6.3085736D-08/
      data fxyz( 7, 7, 3),fxyz( 7, 7, 4)/-1.1059336D-07, 1.0898909D-07/
      data fxyz( 7, 7, 5),fxyz( 7, 7, 6)/-5.9209023D-08,-5.2549105D-09/
      data fxyz( 7, 7, 7),fxyz( 7, 7, 8)/ 5.8945814D-09, 2.5553633D-08/
      data fxyz( 7, 7, 9),fxyz( 7, 7,10)/-3.3702818D-08, 2.5553633D-08/
      data fxyz( 7, 7,11),fxyz( 7, 7,12)/ 5.8945814D-09,-5.2549105D-09/
      data fxyz( 7, 7,13),fxyz( 7, 7,14)/-5.9209023D-08, 1.0898909D-07/
      data fxyz( 7, 7,15),fxyz( 7, 7,16)/-1.1059336D-07, 6.3085736D-08/
      data fxyz( 7, 7,17)/                1.2440439D-07/
      data fxyz( 7, 8, 1),fxyz( 7, 8, 2)/-1.1487715D-07,-3.5023903D-08/
      data fxyz( 7, 8, 3),fxyz( 7, 8, 4)/ 1.6807012D-07,-6.0178560D-08/
      data fxyz( 7, 8, 5),fxyz( 7, 8, 6)/-1.4258527D-08,-6.6365222D-08/
      data fxyz( 7, 8, 7),fxyz( 7, 8, 8)/ 8.1225812D-08,-3.0383372D-08/
      data fxyz( 7, 8, 9),fxyz( 7, 8,10)/ 7.6571804D-09,-3.0383372D-08/
      data fxyz( 7, 8,11),fxyz( 7, 8,12)/ 8.1225812D-08,-6.6365222D-08/
      data fxyz( 7, 8,13),fxyz( 7, 8,14)/-1.4258527D-08,-6.0178560D-08/
      data fxyz( 7, 8,15),fxyz( 7, 8,16)/ 1.6807012D-07,-3.5023903D-08/
      data fxyz( 7, 8,17)/               -1.1487715D-07/
      data fxyz( 7, 9, 1),fxyz( 7, 9, 2)/-5.8442517D-08,-1.4536567D-08/
      data fxyz( 7, 9, 3),fxyz( 7, 9, 4)/ 9.5707279D-08,-2.6231508D-08/
      data fxyz( 7, 9, 5),fxyz( 7, 9, 6)/-1.1662753D-08,-3.5389391D-08/
      data fxyz( 7, 9, 7),fxyz( 7, 9, 8)/ 1.9895151D-08, 1.1195061D-09/
      data fxyz( 7, 9, 9),fxyz( 7, 9,10)/ 6.8815527D-09, 1.1195061D-09/
      data fxyz( 7, 9,11),fxyz( 7, 9,12)/ 1.9895151D-08,-3.5389391D-08/
      data fxyz( 7, 9,13),fxyz( 7, 9,14)/-1.1662753D-08,-2.6231508D-08/
      data fxyz( 7, 9,15),fxyz( 7, 9,16)/ 9.5707279D-08,-1.4536567D-08/
      data fxyz( 7, 9,17)/               -5.8442517D-08/
      data fxyz( 7,10, 1),fxyz( 7,10, 2)/-4.3893240D-09, 4.0617202D-09/
      data fxyz( 7,10, 3),fxyz( 7,10, 4)/ 2.4782021D-08, 2.5599243D-09/
      data fxyz( 7,10, 5),fxyz( 7,10, 6)/ 1.6178595D-09,-3.7978020D-08/
      data fxyz( 7,10, 7),fxyz( 7,10, 8)/ 1.0630784D-08, 8.2443567D-09/
      data fxyz( 7,10, 9),fxyz( 7,10,10)/ 4.8178693D-09, 8.2443567D-09/
      data fxyz( 7,10,11),fxyz( 7,10,12)/ 1.0630784D-08,-3.7978020D-08/
      data fxyz( 7,10,13),fxyz( 7,10,14)/ 1.6178595D-09, 2.5599243D-09/
      data fxyz( 7,10,15),fxyz( 7,10,16)/ 2.4782021D-08, 4.0617202D-09/
      data fxyz( 7,10,17)/               -4.3893240D-09/
      data fxyz( 7,11, 1),fxyz( 7,11, 2)/ 1.6482403D-08, 9.3828122D-09/
      data fxyz( 7,11, 3),fxyz( 7,11, 4)/-6.2804392D-09, 8.0291197D-09/
      data fxyz( 7,11, 5),fxyz( 7,11, 6)/ 2.1897173D-08,-5.9235278D-08/
      data fxyz( 7,11, 7),fxyz( 7,11, 8)/ 2.9484832D-08, 2.3856590D-09/
      data fxyz( 7,11, 9),fxyz( 7,11,10)/ 9.3181150D-10, 2.3856590D-09/
      data fxyz( 7,11,11),fxyz( 7,11,12)/ 2.9484832D-08,-5.9235278D-08/
      data fxyz( 7,11,13),fxyz( 7,11,14)/ 2.1897173D-08, 8.0291197D-09/
      data fxyz( 7,11,15),fxyz( 7,11,16)/-6.2804392D-09, 9.3828122D-09/
      data fxyz( 7,11,17)/                1.6482403D-08/
      data fxyz( 7,12, 1),fxyz( 7,12, 2)/ 1.5255801D-08, 5.5126263D-09/
      data fxyz( 7,12, 3),fxyz( 7,12, 4)/-1.3622519D-08, 1.1423359D-10/
      data fxyz( 7,12, 5),fxyz( 7,12, 6)/ 3.6849372D-08,-6.8238929D-08/
      data fxyz( 7,12, 7),fxyz( 7,12, 8)/ 4.6777359D-08,-1.1141044D-08/
      data fxyz( 7,12, 9),fxyz( 7,12,10)/ 4.0008059D-09,-1.1141044D-08/
      data fxyz( 7,12,11),fxyz( 7,12,12)/ 4.6777359D-08,-6.8238929D-08/
      data fxyz( 7,12,13),fxyz( 7,12,14)/ 3.6849372D-08, 1.1423359D-10/
      data fxyz( 7,12,15),fxyz( 7,12,16)/-1.3622519D-08, 5.5126263D-09/
      data fxyz( 7,12,17)/                1.5255801D-08/
      data fxyz( 7,13, 1),fxyz( 7,13, 2)/-1.0292102D-08,-9.5789118D-09/
      data fxyz( 7,13, 3),fxyz( 7,13, 4)/ 1.7779815D-11,-2.1477784D-08/
      data fxyz( 7,13, 5),fxyz( 7,13, 6)/ 3.7303389D-08,-3.6290363D-08/
      data fxyz( 7,13, 7),fxyz( 7,13, 8)/ 3.3476923D-08,-1.8394100D-08/
      data fxyz( 7,13, 9),fxyz( 7,13,10)/ 8.7629454D-09,-1.8394100D-08/
      data fxyz( 7,13,11),fxyz( 7,13,12)/ 3.3476923D-08,-3.6290363D-08/
      data fxyz( 7,13,13),fxyz( 7,13,14)/ 3.7303389D-08,-2.1477784D-08/
      data fxyz( 7,13,15),fxyz( 7,13,16)/ 1.7779815D-11,-9.5789118D-09/
      data fxyz( 7,13,17)/               -1.0292102D-08/
      data fxyz( 7,14, 1),fxyz( 7,14, 2)/ 2.4000871D-09, 1.6672836D-09/
      data fxyz( 7,14, 3),fxyz( 7,14, 4)/-1.1325681D-08, 1.8591918D-08/
      data fxyz( 7,14, 5),fxyz( 7,14, 6)/-6.5298450D-08, 7.9360824D-08/
      data fxyz( 7,14, 7),fxyz( 7,14, 8)/-1.6212717D-08,-9.3889690D-09/
      data fxyz( 7,14, 9),fxyz( 7,14,10)/ 4.1241442D-11,-9.3889690D-09/
      data fxyz( 7,14,11),fxyz( 7,14,12)/-1.6212717D-08, 7.9360824D-08/
      data fxyz( 7,14,13),fxyz( 7,14,14)/-6.5298450D-08, 1.8591918D-08/
      data fxyz( 7,14,15),fxyz( 7,14,16)/-1.1325681D-08, 1.6672836D-09/
      data fxyz( 7,14,17)/                2.4000871D-09/
      data fxyz( 7,15, 1),fxyz( 7,15, 2)/-2.3087328D-08,-1.1676077D-08/
      data fxyz( 7,15, 3),fxyz( 7,15, 4)/-1.9935566D-08, 4.0652534D-08/
      data fxyz( 7,15, 5),fxyz( 7,15, 6)/-2.3240177D-07, 3.9445533D-07/
      data fxyz( 7,15, 7),fxyz( 7,15, 8)/-2.0758399D-07, 3.3312525D-08/
      data fxyz( 7,15, 9),fxyz( 7,15,10)/-2.8212260D-08, 3.3312525D-08/
      data fxyz( 7,15,11),fxyz( 7,15,12)/-2.0758399D-07, 3.9445533D-07/
      data fxyz( 7,15,13),fxyz( 7,15,14)/-2.3240177D-07, 4.0652534D-08/
      data fxyz( 7,15,15),fxyz( 7,15,16)/-1.9935566D-08,-1.1676077D-08/
      data fxyz( 7,15,17)/               -2.3087328D-08/
      data fxyz( 7,16, 1),fxyz( 7,16, 2)/-1.3936892D-07,-1.0129014D-07/
      data fxyz( 7,16, 3),fxyz( 7,16, 4)/ 3.4609084D-08,-1.7186327D-07/
      data fxyz( 7,16, 5),fxyz( 7,16, 6)/ 1.4292359D-07, 8.8925481D-08/
      data fxyz( 7,16, 7),fxyz( 7,16, 8)/-5.2152603D-08,-3.3005972D-08/
      data fxyz( 7,16, 9),fxyz( 7,16,10)/ 3.9742747D-09,-3.3005972D-08/
      data fxyz( 7,16,11),fxyz( 7,16,12)/-5.2152603D-08, 8.8925481D-08/
      data fxyz( 7,16,13),fxyz( 7,16,14)/ 1.4292359D-07,-1.7186327D-07/
      data fxyz( 7,16,15),fxyz( 7,16,16)/ 3.4609084D-08,-1.0129014D-07/
      data fxyz( 7,16,17)/               -1.3936892D-07/
      data fxyz( 7,17, 1),fxyz( 7,17, 2)/ 8.6878622D-08, 1.2240503D-08/
      data fxyz( 7,17, 3),fxyz( 7,17, 4)/-1.5398704D-07, 3.4839123D-10/
      data fxyz( 7,17, 5),fxyz( 7,17, 6)/ 1.3444707D-07,-3.7494577D-08/
      data fxyz( 7,17, 7),fxyz( 7,17, 8)/ 7.0315878D-08,-7.6579490D-08/
      data fxyz( 7,17, 9),fxyz( 7,17,10)/-3.0069524D-08,-7.6579490D-08/
      data fxyz( 7,17,11),fxyz( 7,17,12)/ 7.0315878D-08,-3.7494577D-08/
      data fxyz( 7,17,13),fxyz( 7,17,14)/ 1.3444707D-07, 3.4839123D-10/
      data fxyz( 7,17,15),fxyz( 7,17,16)/-1.5398704D-07, 1.2240503D-08/
      data fxyz( 7,17,17)/                8.6878622D-08/
      data fxyz( 7,18, 1),fxyz( 7,18, 2)/ 5.5429026D-08, 5.6847081D-08/
      data fxyz( 7,18, 3),fxyz( 7,18, 4)/ 5.7657516D-08, 6.0594620D-08/
      data fxyz( 7,18, 5),fxyz( 7,18, 6)/ 4.0438868D-08,-1.9247187D-07/
      data fxyz( 7,18, 7),fxyz( 7,18, 8)/ 7.3550652D-08, 6.2879409D-09/
      data fxyz( 7,18, 9),fxyz( 7,18,10)/-3.3833350D-08, 6.2879409D-09/
      data fxyz( 7,18,11),fxyz( 7,18,12)/ 7.3550652D-08,-1.9247187D-07/
      data fxyz( 7,18,13),fxyz( 7,18,14)/ 4.0438868D-08, 6.0594620D-08/
      data fxyz( 7,18,15),fxyz( 7,18,16)/ 5.7657516D-08, 5.6847081D-08/
      data fxyz( 7,18,17)/                5.5429026D-08/
      data fxyz( 7,19, 1),fxyz( 7,19, 2)/ 9.7607182D-08, 1.2114625D-07/
      data fxyz( 7,19, 3),fxyz( 7,19, 4)/ 1.5494759D-07, 1.5283097D-07/
      data fxyz( 7,19, 5),fxyz( 7,19, 6)/-2.9131709D-08,-3.3928995D-07/
      data fxyz( 7,19, 7),fxyz( 7,19, 8)/ 1.1085220D-07, 5.3029386D-08/
      data fxyz( 7,19, 9),fxyz( 7,19,10)/-4.6248597D-08, 5.3029386D-08/
      data fxyz( 7,19,11),fxyz( 7,19,12)/ 1.1085220D-07,-3.3928995D-07/
      data fxyz( 7,19,13),fxyz( 7,19,14)/-2.9131709D-08, 1.5283097D-07/
      data fxyz( 7,19,15),fxyz( 7,19,16)/ 1.5494759D-07, 1.2114625D-07/
      data fxyz( 7,19,17)/                9.7607182D-08/
      data fxyz( 8, 1, 1),fxyz( 8, 1, 2)/ 8.3483182D-09, 1.2319406D-08/
      data fxyz( 8, 1, 3),fxyz( 8, 1, 4)/ 1.7361576D-08, 1.8654959D-08/
      data fxyz( 8, 1, 5),fxyz( 8, 1, 6)/-1.6993895D-08,-1.6811264D-08/
      data fxyz( 8, 1, 7),fxyz( 8, 1, 8)/-1.3285414D-08, 1.3174987D-08/
      data fxyz( 8, 1, 9),fxyz( 8, 1,10)/ 1.4215602D-08, 1.3174987D-08/
      data fxyz( 8, 1,11),fxyz( 8, 1,12)/-1.3285414D-08,-1.6811264D-08/
      data fxyz( 8, 1,13),fxyz( 8, 1,14)/-1.6993895D-08, 1.8654959D-08/
      data fxyz( 8, 1,15),fxyz( 8, 1,16)/ 1.7361576D-08, 1.2319406D-08/
      data fxyz( 8, 1,17)/                8.3483182D-09/
      data fxyz( 8, 2, 1),fxyz( 8, 2, 2)/-7.7634044D-09, 4.9606773D-10/
      data fxyz( 8, 2, 3),fxyz( 8, 2, 4)/ 1.9964971D-08, 2.0086505D-10/
      data fxyz( 8, 2, 5),fxyz( 8, 2, 6)/-6.5825937D-09,-7.8004377D-09/
      data fxyz( 8, 2, 7),fxyz( 8, 2, 8)/-2.6877448D-09, 2.9575977D-09/
      data fxyz( 8, 2, 9),fxyz( 8, 2,10)/ 7.8104552D-09, 2.9575977D-09/
      data fxyz( 8, 2,11),fxyz( 8, 2,12)/-2.6877448D-09,-7.8004377D-09/
      data fxyz( 8, 2,13),fxyz( 8, 2,14)/-6.5825937D-09, 2.0086505D-10/
      data fxyz( 8, 2,15),fxyz( 8, 2,16)/ 1.9964971D-08, 4.9606773D-10/
      data fxyz( 8, 2,17)/               -7.7634044D-09/
      data fxyz( 8, 3, 1),fxyz( 8, 3, 2)/-3.1067784D-08,-1.3509317D-08/
      data fxyz( 8, 3, 3),fxyz( 8, 3, 4)/ 3.2578261D-08,-2.1186048D-08/
      data fxyz( 8, 3, 5),fxyz( 8, 3, 6)/-3.6085844D-10, 3.5474224D-09/
      data fxyz( 8, 3, 7),fxyz( 8, 3, 8)/ 9.8384543D-09,-7.0426699D-09/
      data fxyz( 8, 3, 9),fxyz( 8, 3,10)/-3.4503161D-09,-7.0426699D-09/
      data fxyz( 8, 3,11),fxyz( 8, 3,12)/ 9.8384543D-09, 3.5474224D-09/
      data fxyz( 8, 3,13),fxyz( 8, 3,14)/-3.6085844D-10,-2.1186048D-08/
      data fxyz( 8, 3,15),fxyz( 8, 3,16)/ 3.2578261D-08,-1.3509317D-08/
      data fxyz( 8, 3,17)/               -3.1067784D-08/
      data fxyz( 8, 4, 1),fxyz( 8, 4, 2)/-2.9197864D-08,-1.9877540D-08/
      data fxyz( 8, 4, 3),fxyz( 8, 4, 4)/ 1.0156919D-08,-3.2308095D-08/
      data fxyz( 8, 4, 5),fxyz( 8, 4, 6)/ 2.0524357D-08, 6.7156638D-09/
      data fxyz( 8, 4, 7),fxyz( 8, 4, 8)/ 1.5614798D-08,-1.7802862D-08/
      data fxyz( 8, 4, 9),fxyz( 8, 4,10)/ 2.2835981D-09,-1.7802862D-08/
      data fxyz( 8, 4,11),fxyz( 8, 4,12)/ 1.5614798D-08, 6.7156638D-09/
      data fxyz( 8, 4,13),fxyz( 8, 4,14)/ 2.0524357D-08,-3.2308095D-08/
      data fxyz( 8, 4,15),fxyz( 8, 4,16)/ 1.0156919D-08,-1.9877540D-08/
      data fxyz( 8, 4,17)/               -2.9197864D-08/
      data fxyz( 8, 5, 1),fxyz( 8, 5, 2)/ 3.7878114D-08, 6.9493607D-09/
      data fxyz( 8, 5, 3),fxyz( 8, 5, 4)/-6.8096483D-08, 1.1267490D-08/
      data fxyz( 8, 5, 5),fxyz( 8, 5, 6)/ 2.0605598D-08, 1.3679096D-08/
      data fxyz( 8, 5, 7),fxyz( 8, 5, 8)/-1.1436584D-08,-5.1856391D-10/
      data fxyz( 8, 5, 9),fxyz( 8, 5,10)/ 1.6220989D-09,-5.1856391D-10/
      data fxyz( 8, 5,11),fxyz( 8, 5,12)/-1.1436584D-08, 1.3679096D-08/
      data fxyz( 8, 5,13),fxyz( 8, 5,14)/ 2.0605598D-08, 1.1267490D-08/
      data fxyz( 8, 5,15),fxyz( 8, 5,16)/-6.8096483D-08, 6.9493607D-09/
      data fxyz( 8, 5,17)/                3.7878114D-08/
      data fxyz( 8, 6, 1),fxyz( 8, 6, 2)/ 8.6928296D-08, 3.4796448D-08/
      data fxyz( 8, 6, 3),fxyz( 8, 6, 4)/-1.0334904D-07, 5.9553212D-08/
      data fxyz( 8, 6, 5),fxyz( 8, 6, 6)/-1.2098758D-08, 2.3097117D-08/
      data fxyz( 8, 6, 7),fxyz( 8, 6, 8)/-3.6142561D-08, 2.7602642D-08/
      data fxyz( 8, 6, 9),fxyz( 8, 6,10)/-1.6548138D-08, 2.7602642D-08/
      data fxyz( 8, 6,11),fxyz( 8, 6,12)/-3.6142561D-08, 2.3097117D-08/
      data fxyz( 8, 6,13),fxyz( 8, 6,14)/-1.2098758D-08, 5.9553212D-08/
      data fxyz( 8, 6,15),fxyz( 8, 6,16)/-1.0334904D-07, 3.4796448D-08/
      data fxyz( 8, 6,17)/                8.6928296D-08/
      data fxyz( 8, 7, 1),fxyz( 8, 7, 2)/ 2.0015080D-09, 5.5635537D-09/
      data fxyz( 8, 7, 3),fxyz( 8, 7, 4)/ 1.1364643D-08, 9.3290797D-09/
      data fxyz( 8, 7, 5),fxyz( 8, 7, 6)/-1.3060596D-08,-1.5006144D-08/
      data fxyz( 8, 7, 7),fxyz( 8, 7, 8)/ 1.5220300D-08, 1.1270706D-09/
      data fxyz( 8, 7, 9),fxyz( 8, 7,10)/-5.9564767D-09, 1.1270706D-09/
      data fxyz( 8, 7,11),fxyz( 8, 7,12)/ 1.5220300D-08,-1.5006144D-08/
      data fxyz( 8, 7,13),fxyz( 8, 7,14)/-1.3060596D-08, 9.3290797D-09/
      data fxyz( 8, 7,15),fxyz( 8, 7,16)/ 1.1364643D-08, 5.5635537D-09/
      data fxyz( 8, 7,17)/                2.0015080D-09/
      data fxyz( 8, 8, 1),fxyz( 8, 8, 2)/-3.8249075D-08,-9.8692005D-09/
      data fxyz( 8, 8, 3),fxyz( 8, 8, 4)/ 6.1296555D-08,-1.7288271D-08/
      data fxyz( 8, 8, 5),fxyz( 8, 8, 6)/-8.5727934D-09,-2.1339906D-08/
      data fxyz( 8, 8, 7),fxyz( 8, 8, 8)/ 1.7481535D-08,-2.9986126D-09/
      data fxyz( 8, 8, 9),fxyz( 8, 8,10)/ 2.9030292D-09,-2.9986126D-09/
      data fxyz( 8, 8,11),fxyz( 8, 8,12)/ 1.7481535D-08,-2.1339906D-08/
      data fxyz( 8, 8,13),fxyz( 8, 8,14)/-8.5727934D-09,-1.7288271D-08/
      data fxyz( 8, 8,15),fxyz( 8, 8,16)/ 6.1296555D-08,-9.8692005D-09/
      data fxyz( 8, 8,17)/               -3.8249075D-08/
      data fxyz( 8, 9, 1),fxyz( 8, 9, 2)/-1.9395949D-08,-3.1327699D-09/
      data fxyz( 8, 9, 3),fxyz( 8, 9, 4)/ 3.7080265D-08,-6.5311958D-09/
      data fxyz( 8, 9, 5),fxyz( 8, 9, 6)/-5.8022454D-09,-1.5778269D-08/
      data fxyz( 8, 9, 7),fxyz( 8, 9, 8)/ 2.4840960D-09, 3.8056227D-09/
      data fxyz( 8, 9, 9),fxyz( 8, 9,10)/ 5.9973145D-09, 3.8056227D-09/
      data fxyz( 8, 9,11),fxyz( 8, 9,12)/ 2.4840960D-09,-1.5778269D-08/
      data fxyz( 8, 9,13),fxyz( 8, 9,14)/-5.8022454D-09,-6.5311958D-09/
      data fxyz( 8, 9,15),fxyz( 8, 9,16)/ 3.7080265D-08,-3.1327699D-09/
      data fxyz( 8, 9,17)/               -1.9395949D-08/
      data fxyz( 8,10, 1),fxyz( 8,10, 2)/-1.2233915D-09, 3.2813364D-09/
      data fxyz( 8,10, 3),fxyz( 8,10, 4)/ 1.3810666D-08, 3.2538898D-09/
      data fxyz( 8,10, 5),fxyz( 8,10, 6)/-1.1136052D-09,-1.9945009D-08/
      data fxyz( 8,10, 7),fxyz( 8,10, 8)/ 2.5464259D-09, 5.0121849D-09/
      data fxyz( 8,10, 9),fxyz( 8,10,10)/ 6.6769872D-09, 5.0121849D-09/
      data fxyz( 8,10,11),fxyz( 8,10,12)/ 2.5464259D-09,-1.9945009D-08/
      data fxyz( 8,10,13),fxyz( 8,10,14)/-1.1136052D-09, 3.2538898D-09/
      data fxyz( 8,10,15),fxyz( 8,10,16)/ 1.3810666D-08, 3.2813364D-09/
      data fxyz( 8,10,17)/               -1.2233915D-09/
      data fxyz( 8,11, 1),fxyz( 8,11, 2)/ 8.5053046D-09, 6.5052280D-09/
      data fxyz( 8,11, 3),fxyz( 8,11, 4)/ 1.1124026D-09, 7.5941981D-09/
      data fxyz( 8,11, 5),fxyz( 8,11, 6)/ 4.1494243D-09,-2.7286140D-08/
      data fxyz( 8,11, 7),fxyz( 8,11, 8)/ 6.9647154D-09, 6.5788450D-09/
      data fxyz( 8,11, 9),fxyz( 8,11,10)/ 3.0670076D-09, 6.5788450D-09/
      data fxyz( 8,11,11),fxyz( 8,11,12)/ 6.9647154D-09,-2.7286140D-08/
      data fxyz( 8,11,13),fxyz( 8,11,14)/ 4.1494243D-09, 7.5941981D-09/
      data fxyz( 8,11,15),fxyz( 8,11,16)/ 1.1124026D-09, 6.5052280D-09/
      data fxyz( 8,11,17)/                8.5053046D-09/
      data fxyz( 8,12, 1),fxyz( 8,12, 2)/ 9.4723035D-09, 5.8323495D-09/
      data fxyz( 8,12, 3),fxyz( 8,12, 4)/-2.5924751D-09, 5.7297471D-09/
      data fxyz( 8,12, 5),fxyz( 8,12, 6)/ 9.8827131D-09,-3.4919603D-08/
      data fxyz( 8,12, 7),fxyz( 8,12, 8)/ 1.8010630D-08, 1.6561893D-09/
      data fxyz( 8,12, 9),fxyz( 8,12,10)/ 1.8560216D-09, 1.6561893D-09/
      data fxyz( 8,12,11),fxyz( 8,12,12)/ 1.8010630D-08,-3.4919603D-08/
      data fxyz( 8,12,13),fxyz( 8,12,14)/ 9.8827131D-09, 5.7297471D-09/
      data fxyz( 8,12,15),fxyz( 8,12,16)/-2.5924751D-09, 5.8323495D-09/
      data fxyz( 8,12,17)/                9.4723035D-09/
      data fxyz( 8,13, 1),fxyz( 8,13, 2)/ 2.3588330D-09, 5.2743731D-10/
      data fxyz( 8,13, 3),fxyz( 8,13, 4)/-3.7246680D-09, 4.9571021D-10/
      data fxyz( 8,13, 5),fxyz( 8,13, 6)/ 2.4857414D-09,-8.8675642D-09/
      data fxyz( 8,13, 7),fxyz( 8,13, 8)/ 1.0237933D-08,-2.4734586D-09/
      data fxyz( 8,13, 9),fxyz( 8,13,10)/-3.7344310D-11,-2.4734586D-09/
      data fxyz( 8,13,11),fxyz( 8,13,12)/ 1.0237933D-08,-8.8675642D-09/
      data fxyz( 8,13,13),fxyz( 8,13,14)/ 2.4857414D-09, 4.9571021D-10/
      data fxyz( 8,13,15),fxyz( 8,13,16)/-3.7246680D-09, 5.2743731D-10/
      data fxyz( 8,13,17)/                2.3588330D-09/
      data fxyz( 8,14, 1),fxyz( 8,14, 2)/-1.3975469D-08,-1.0145631D-08/
      data fxyz( 8,14, 3),fxyz( 8,14, 4)/-2.3869710D-09,-8.3791904D-09/
      data fxyz( 8,14, 5),fxyz( 8,14, 6)/-2.1041232D-08, 5.6349551D-08/
      data fxyz( 8,14, 7),fxyz( 8,14, 8)/-1.7627817D-08,-7.5852234D-09/
      data fxyz( 8,14, 9),fxyz( 8,14,10)/-7.5079648D-10,-7.5852234D-09/
      data fxyz( 8,14,11),fxyz( 8,14,12)/-1.7627817D-08, 5.6349551D-08/
      data fxyz( 8,14,13),fxyz( 8,14,14)/-2.1041232D-08,-8.3791904D-09/
      data fxyz( 8,14,15),fxyz( 8,14,16)/-2.3869710D-09,-1.0145631D-08/
      data fxyz( 8,14,17)/               -1.3975469D-08/
      data fxyz( 8,15, 1),fxyz( 8,15, 2)/-3.2932812D-08,-2.4842954D-08/
      data fxyz( 8,15, 3),fxyz( 8,15, 4)/-5.4885657D-09,-2.5560034D-08/
      data fxyz( 8,15, 5),fxyz( 8,15, 6)/-3.0064493D-08, 1.2157924D-07/
      data fxyz( 8,15, 7),fxyz( 8,15, 8)/-4.6211378D-08,-1.3444588D-08/
      data fxyz( 8,15, 9),fxyz( 8,15,10)/-7.2284387D-09,-1.3444588D-08/
      data fxyz( 8,15,11),fxyz( 8,15,12)/-4.6211378D-08, 1.2157924D-07/
      data fxyz( 8,15,13),fxyz( 8,15,14)/-3.0064493D-08,-2.5560034D-08/
      data fxyz( 8,15,15),fxyz( 8,15,16)/-5.4885657D-09,-2.4842954D-08/
      data fxyz( 8,15,17)/               -3.2932812D-08/
      data fxyz( 8,16, 1),fxyz( 8,16, 2)/-3.5482233D-08,-3.4667928D-08/
      data fxyz( 8,16, 3),fxyz( 8,16, 4)/-2.3899339D-08,-4.7970742D-08/
      data fxyz( 8,16, 5),fxyz( 8,16, 6)/ 1.7729024D-08, 1.1436087D-07/
      data fxyz( 8,16, 7),fxyz( 8,16, 8)/-4.1817473D-08,-2.4353246D-08/
      data fxyz( 8,16, 9),fxyz( 8,16,10)/-1.4214652D-08,-2.4353246D-08/
      data fxyz( 8,16,11),fxyz( 8,16,12)/-4.1817473D-08, 1.1436087D-07/
      data fxyz( 8,16,13),fxyz( 8,16,14)/ 1.7729024D-08,-4.7970742D-08/
      data fxyz( 8,16,15),fxyz( 8,16,16)/-2.3899339D-08,-3.4667928D-08/
      data fxyz( 8,16,17)/               -3.5482233D-08/
      data fxyz( 8,17, 1),fxyz( 8,17, 2)/ 3.2994094D-08, 3.1184293D-09/
      data fxyz( 8,17, 3),fxyz( 8,17, 4)/-5.6497867D-08,-1.2021951D-08/
      data fxyz( 8,17, 5),fxyz( 8,17, 6)/ 9.3555617D-08,-6.1799640D-08/
      data fxyz( 8,17, 7),fxyz( 8,17, 8)/ 5.4567048D-08,-2.9979541D-08/
      data fxyz( 8,17, 9),fxyz( 8,17,10)/-3.4668592D-08,-2.9979541D-08/
      data fxyz( 8,17,11),fxyz( 8,17,12)/ 5.4567048D-08,-6.1799640D-08/
      data fxyz( 8,17,13),fxyz( 8,17,14)/ 9.3555617D-08,-1.2021951D-08/
      data fxyz( 8,17,15),fxyz( 8,17,16)/-5.6497867D-08, 3.1184293D-09/
      data fxyz( 8,17,17)/                3.2994094D-08/
      data fxyz( 8,18, 1),fxyz( 8,18, 2)/ 3.1962517D-08, 3.5580534D-08/
      data fxyz( 8,18, 3),fxyz( 8,18, 4)/ 3.3972437D-08, 5.0655739D-08/
      data fxyz( 8,18, 5),fxyz( 8,18, 6)/-2.8338302D-08,-6.5667050D-08/
      data fxyz( 8,18, 7),fxyz( 8,18, 8)/ 1.0548331D-08, 1.7118975D-08/
      data fxyz( 8,18, 9),fxyz( 8,18,10)/-9.5289782D-11, 1.7118975D-08/
      data fxyz( 8,18,11),fxyz( 8,18,12)/ 1.0548331D-08,-6.5667050D-08/
      data fxyz( 8,18,13),fxyz( 8,18,14)/-2.8338302D-08, 5.0655739D-08/
      data fxyz( 8,18,15),fxyz( 8,18,16)/ 3.3972437D-08, 3.5580534D-08/
      data fxyz( 8,18,17)/                3.1962517D-08/
      data fxyz( 8,19, 1),fxyz( 8,19, 2)/ 5.0790342D-08, 6.9563854D-08/
      data fxyz( 8,19, 3),fxyz( 8,19, 4)/ 8.9280218D-08, 1.0569660D-07/
      data fxyz( 8,19, 5),fxyz( 8,19, 6)/-9.3740645D-08,-1.1876106D-07/
      data fxyz( 8,19, 7),fxyz( 8,19, 8)/ 6.6448254D-09, 4.9153260D-08/
      data fxyz( 8,19, 9),fxyz( 8,19,10)/ 1.8755943D-08, 4.9153260D-08/
      data fxyz( 8,19,11),fxyz( 8,19,12)/ 6.6448254D-09,-1.1876106D-07/
      data fxyz( 8,19,13),fxyz( 8,19,14)/-9.3740645D-08, 1.0569660D-07/
      data fxyz( 8,19,15),fxyz( 8,19,16)/ 8.9280218D-08, 6.9563854D-08/
      data fxyz( 8,19,17)/                5.0790342D-08/
      data fxyz( 9, 1, 1),fxyz( 9, 1, 2)/ 2.1285089D-09, 2.6684611D-09/
      data fxyz( 9, 1, 3),fxyz( 9, 1, 4)/ 3.3050797D-09, 3.6033660D-09/
      data fxyz( 9, 1, 5),fxyz( 9, 1, 6)/-1.6111106D-09,-4.4613192D-09/
      data fxyz( 9, 1, 7),fxyz( 9, 1, 8)/-4.3663572D-09, 2.0214705D-09/
      data fxyz( 9, 1, 9),fxyz( 9, 1,10)/ 6.4786387D-09, 2.0214705D-09/
      data fxyz( 9, 1,11),fxyz( 9, 1,12)/-4.3663572D-09,-4.4613192D-09/
      data fxyz( 9, 1,13),fxyz( 9, 1,14)/-1.6111106D-09, 3.6033660D-09/
      data fxyz( 9, 1,15),fxyz( 9, 1,16)/ 3.3050797D-09, 2.6684611D-09/
      data fxyz( 9, 1,17)/                2.1285089D-09/
      data fxyz( 9, 2, 1),fxyz( 9, 2, 2)/-5.0644544D-10, 5.0248001D-10/
      data fxyz( 9, 2, 3),fxyz( 9, 2, 4)/ 2.8925274D-09, 4.4864795D-10/
      data fxyz( 9, 2, 5),fxyz( 9, 2, 6)/-2.9111721D-10,-1.6334667D-09/
      data fxyz( 9, 2, 7),fxyz( 9, 2, 8)/-2.5443818D-09, 8.0829981D-10/
      data fxyz( 9, 2, 9),fxyz( 9, 2,10)/ 3.5225364D-09, 8.0829981D-10/
      data fxyz( 9, 2,11),fxyz( 9, 2,12)/-2.5443818D-09,-1.6334667D-09/
      data fxyz( 9, 2,13),fxyz( 9, 2,14)/-2.9111721D-10, 4.4864795D-10/
      data fxyz( 9, 2,15),fxyz( 9, 2,16)/ 2.8925274D-09, 5.0248001D-10/
      data fxyz( 9, 2,17)/               -5.0644544D-10/
      data fxyz( 9, 3, 1),fxyz( 9, 3, 2)/-5.0507182D-09,-2.3576390D-09/
      data fxyz( 9, 3, 3),fxyz( 9, 3, 4)/ 4.9293864D-09,-3.8623997D-09/
      data fxyz( 9, 3, 5),fxyz( 9, 3, 6)/ 9.6832468D-10, 1.7743467D-09/
      data fxyz( 9, 3, 7),fxyz( 9, 3, 8)/-1.4704486D-09,-4.9836799D-10/
      data fxyz( 9, 3, 9),fxyz( 9, 3,10)/ 9.9691004D-10,-4.9836799D-10/
      data fxyz( 9, 3,11),fxyz( 9, 3,12)/-1.4704486D-09, 1.7743467D-09/
      data fxyz( 9, 3,13),fxyz( 9, 3,14)/ 9.6832468D-10,-3.8623997D-09/
      data fxyz( 9, 3,15),fxyz( 9, 3,16)/ 4.9293864D-09,-2.3576390D-09/
      data fxyz( 9, 3,17)/               -5.0507182D-09/
      data fxyz( 9, 4, 1),fxyz( 9, 4, 2)/-2.9123765D-09,-2.7882754D-09/
      data fxyz( 9, 4, 3),fxyz( 9, 4, 4)/-1.6066940D-09,-4.1262937D-09/
      data fxyz( 9, 4, 5),fxyz( 9, 4, 6)/ 2.4396967D-09, 3.1522969D-09/
      data fxyz( 9, 4, 7),fxyz( 9, 4, 8)/ 2.2216324D-09,-1.4777958D-09/
      data fxyz( 9, 4, 9),fxyz( 9, 4,10)/-3.0353820D-09,-1.4777958D-09/
      data fxyz( 9, 4,11),fxyz( 9, 4,12)/ 2.2216324D-09, 3.1522969D-09/
      data fxyz( 9, 4,13),fxyz( 9, 4,14)/ 2.4396967D-09,-4.1262937D-09/
      data fxyz( 9, 4,15),fxyz( 9, 4,16)/-1.6066940D-09,-2.7882754D-09/
      data fxyz( 9, 4,17)/               -2.9123765D-09/
      data fxyz( 9, 5, 1),fxyz( 9, 5, 2)/ 8.5315475D-09, 2.0496802D-09/
      data fxyz( 9, 5, 3),fxyz( 9, 5, 4)/-1.4510774D-08, 4.2038255D-09/
      data fxyz( 9, 5, 5),fxyz( 9, 5, 6)/-8.5033599D-11, 4.6018886D-09/
      data fxyz( 9, 5, 7),fxyz( 9, 5, 8)/ 4.2457585D-10, 6.4971913D-10/
      data fxyz( 9, 5, 9),fxyz( 9, 5,10)/-4.7201529D-09, 6.4971913D-10/
      data fxyz( 9, 5,11),fxyz( 9, 5,12)/ 4.2457585D-10, 4.6018886D-09/
      data fxyz( 9, 5,13),fxyz( 9, 5,14)/-8.5033599D-11, 4.2038255D-09/
      data fxyz( 9, 5,15),fxyz( 9, 5,16)/-1.4510774D-08, 2.0496802D-09/
      data fxyz( 9, 5,17)/                8.5315475D-09/
      data fxyz( 9, 6, 1),fxyz( 9, 6, 2)/ 4.3834293D-09, 1.4128301D-09/
      data fxyz( 9, 6, 3),fxyz( 9, 6, 4)/-6.1748953D-09, 2.3973207D-09/
      data fxyz( 9, 6, 5),fxyz( 9, 6, 6)/ 4.4546696D-10,-2.5549051D-09/
      data fxyz( 9, 6, 7),fxyz( 9, 6, 8)/ 5.7001524D-09,-2.1326627D-09/
      data fxyz( 9, 6, 9),fxyz( 9, 6,10)/-1.3717673D-09,-2.1326627D-09/
      data fxyz( 9, 6,11),fxyz( 9, 6,12)/ 5.7001524D-09,-2.5549051D-09/
      data fxyz( 9, 6,13),fxyz( 9, 6,14)/ 4.4546696D-10, 2.3973207D-09/
      data fxyz( 9, 6,15),fxyz( 9, 6,16)/-6.1748953D-09, 1.4128301D-09/
      data fxyz( 9, 6,17)/                4.3834293D-09/
      data fxyz( 9, 7, 1),fxyz( 9, 7, 2)/ 1.7227940D-10, 9.9127312D-10/
      data fxyz( 9, 7, 3),fxyz( 9, 7, 4)/ 2.4886703D-09, 1.6116554D-09/
      data fxyz( 9, 7, 5),fxyz( 9, 7, 6)/-2.3092496D-09,-2.3431548D-09/
      data fxyz( 9, 7, 7),fxyz( 9, 7, 8)/ 1.3224758D-09, 7.8941546D-10/
      data fxyz( 9, 7, 9),fxyz( 9, 7,10)/-5.2755788D-10, 7.8941546D-10/
      data fxyz( 9, 7,11),fxyz( 9, 7,12)/ 1.3224758D-09,-2.3431548D-09/
      data fxyz( 9, 7,13),fxyz( 9, 7,14)/-2.3092496D-09, 1.6116554D-09/
      data fxyz( 9, 7,15),fxyz( 9, 7,16)/ 2.4886703D-09, 9.9127312D-10/
      data fxyz( 9, 7,17)/                1.7227940D-10/
      data fxyz( 9, 8, 1),fxyz( 9, 8, 2)/-2.3543944D-09, 1.6153972D-10/
      data fxyz( 9, 8, 3),fxyz( 9, 8, 4)/ 6.1655733D-09,-3.8741310D-11/
      data fxyz( 9, 8, 5),fxyz( 9, 8, 6)/-1.5532702D-09,-2.6441064D-09/
      data fxyz( 9, 8, 7),fxyz( 9, 8, 8)/-1.0292125D-09, 1.5153201D-09/
      data fxyz( 9, 8, 9),fxyz( 9, 8,10)/ 1.3010673D-09, 1.5153201D-09/
      data fxyz( 9, 8,11),fxyz( 9, 8,12)/-1.0292125D-09,-2.6441064D-09/
      data fxyz( 9, 8,13),fxyz( 9, 8,14)/-1.5532702D-09,-3.8741310D-11/
      data fxyz( 9, 8,15),fxyz( 9, 8,16)/ 6.1655733D-09, 1.6153972D-10/
      data fxyz( 9, 8,17)/               -2.3543944D-09/
      data fxyz( 9, 9, 1),fxyz( 9, 9, 2)/-1.7128263D-09, 4.0128462D-10/
      data fxyz( 9, 9, 3),fxyz( 9, 9, 4)/ 5.4124284D-09, 2.8395722D-10/
      data fxyz( 9, 9, 5),fxyz( 9, 9, 6)/-1.2435167D-09,-3.1290989D-09/
      data fxyz( 9, 9, 7),fxyz( 9, 9, 8)/-1.2493520D-09, 1.7206442D-09/
      data fxyz( 9, 9, 9),fxyz( 9, 9,10)/ 1.8027495D-09, 1.7206442D-09/
      data fxyz( 9, 9,11),fxyz( 9, 9,12)/-1.2493520D-09,-3.1290989D-09/
      data fxyz( 9, 9,13),fxyz( 9, 9,14)/-1.2435167D-09, 2.8395722D-10/
      data fxyz( 9, 9,15),fxyz( 9, 9,16)/ 5.4124284D-09, 4.0128462D-10/
      data fxyz( 9, 9,17)/               -1.7128263D-09/
      data fxyz( 9,10, 1),fxyz( 9,10, 2)/ 2.8991794D-10, 1.2300604D-09/
      data fxyz( 9,10, 3),fxyz( 9,10, 4)/ 3.1993600D-09, 1.5666094D-09/
      data fxyz( 9,10, 5),fxyz( 9,10, 6)/-1.0562783D-09,-4.2666079D-09/
      data fxyz( 9,10, 7),fxyz( 9,10, 8)/-8.2345957D-10, 1.8896790D-09/
      data fxyz( 9,10, 9),fxyz( 9,10,10)/ 2.2368463D-09, 1.8896790D-09/
      data fxyz( 9,10,11),fxyz( 9,10,12)/-8.2345957D-10,-4.2666079D-09/
      data fxyz( 9,10,13),fxyz( 9,10,14)/-1.0562783D-09, 1.5666094D-09/
      data fxyz( 9,10,15),fxyz( 9,10,16)/ 3.1993600D-09, 1.2300604D-09/
      data fxyz( 9,10,17)/                2.8991794D-10/
      data fxyz( 9,11, 1),fxyz( 9,11, 2)/ 1.6889025D-09, 1.8696753D-09/
      data fxyz( 9,11, 3),fxyz( 9,11, 4)/ 1.8575617D-09, 2.5205502D-09/
      data fxyz( 9,11, 5),fxyz( 9,11, 6)/-9.1459719D-10,-6.0799465D-09/
      data fxyz( 9,11, 7),fxyz( 9,11, 8)/ 6.6886695D-10, 1.5737848D-09/
      data fxyz( 9,11, 9),fxyz( 9,11,10)/ 2.7136010D-09, 1.5737848D-09/
      data fxyz( 9,11,11),fxyz( 9,11,12)/ 6.6886695D-10,-6.0799465D-09/
      data fxyz( 9,11,13),fxyz( 9,11,14)/-9.1459719D-10, 2.5205502D-09/
      data fxyz( 9,11,15),fxyz( 9,11,16)/ 1.8575617D-09, 1.8696753D-09/
      data fxyz( 9,11,17)/                1.6889025D-09/
      data fxyz( 9,12, 1),fxyz( 9,12, 2)/ 1.6655954D-09, 1.7355286D-09/
      data fxyz( 9,12, 3),fxyz( 9,12, 4)/ 1.4250323D-09, 2.4460395D-09/
      data fxyz( 9,12, 5),fxyz( 9,12, 6)/-1.1764480D-09,-5.6875592D-09/
      data fxyz( 9,12, 7),fxyz( 9,12, 8)/ 7.1125502D-10, 2.3624452D-09/
      data fxyz( 9,12, 9),fxyz( 9,12,10)/ 1.3819213D-09, 2.3624452D-09/
      data fxyz( 9,12,11),fxyz( 9,12,12)/ 7.1125502D-10,-5.6875592D-09/
      data fxyz( 9,12,13),fxyz( 9,12,14)/-1.1764480D-09, 2.4460395D-09/
      data fxyz( 9,12,15),fxyz( 9,12,16)/ 1.4250323D-09, 1.7355286D-09/
      data fxyz( 9,12,17)/                1.6655954D-09/
      data fxyz( 9,13, 1),fxyz( 9,13, 2)/-6.6006128D-10,-6.1242399D-11/
      data fxyz( 9,13, 3),fxyz( 9,13, 4)/ 1.1513850D-09, 2.1568252D-10/
      data fxyz( 9,13, 5),fxyz( 9,13, 6)/-1.7677609D-09,-1.9971989D-10/
      data fxyz( 9,13, 7),fxyz( 9,13, 8)/ 5.3802555D-11, 9.6408669D-10/
      data fxyz( 9,13, 9),fxyz( 9,13,10)/ 3.6258726D-10, 9.6408669D-10/
      data fxyz( 9,13,11),fxyz( 9,13,12)/ 5.3802555D-11,-1.9971989D-10/
      data fxyz( 9,13,13),fxyz( 9,13,14)/-1.7677609D-09, 2.1568252D-10/
      data fxyz( 9,13,15),fxyz( 9,13,16)/ 1.1513850D-09,-6.1242399D-11/
      data fxyz( 9,13,17)/               -6.6006128D-10/
      data fxyz( 9,14, 1),fxyz( 9,14, 2)/-6.0506465D-09,-4.5819821D-09/
      data fxyz( 9,14, 3),fxyz( 9,14, 4)/-4.9306450D-10,-5.5750331D-09/
      data fxyz( 9,14, 5),fxyz( 9,14, 6)/-2.0784427D-09, 1.6097137D-08/
      data fxyz( 9,14, 7),fxyz( 9,14, 8)/-5.4558843D-09,-1.9685196D-09/
      data fxyz( 9,14, 9),fxyz( 9,14,10)/-1.7109588D-09,-1.9685196D-09/
      data fxyz( 9,14,11),fxyz( 9,14,12)/-5.4558843D-09, 1.6097137D-08/
      data fxyz( 9,14,13),fxyz( 9,14,14)/-2.0784427D-09,-5.5750331D-09/
      data fxyz( 9,14,15),fxyz( 9,14,16)/-4.9306450D-10,-4.5819821D-09/
      data fxyz( 9,14,17)/               -6.0506465D-09/
      data fxyz( 9,15, 1),fxyz( 9,15, 2)/-8.8660023D-09,-8.6122716D-09/
      data fxyz( 9,15, 3),fxyz( 9,15, 4)/-5.6857848D-09,-1.2113944D-08/
      data fxyz( 9,15, 5),fxyz( 9,15, 6)/ 5.1406889D-09, 2.4359756D-08/
      data fxyz( 9,15, 7),fxyz( 9,15, 8)/-4.7485599D-09,-8.1912042D-09/
      data fxyz( 9,15, 9),fxyz( 9,15,10)/-3.7912997D-09,-8.1912042D-09/
      data fxyz( 9,15,11),fxyz( 9,15,12)/-4.7485599D-09, 2.4359756D-08/
      data fxyz( 9,15,13),fxyz( 9,15,14)/ 5.1406889D-09,-1.2113944D-08/
      data fxyz( 9,15,15),fxyz( 9,15,16)/-5.6857848D-09,-8.6122716D-09/
      data fxyz( 9,15,17)/               -8.8660023D-09/
      data fxyz( 9,16, 1),fxyz( 9,16, 2)/ 8.4693479D-10,-4.6219456D-09/
      data fxyz( 9,16, 3),fxyz( 9,16, 4)/-1.4708119D-08,-8.6337672D-09/
      data fxyz( 9,16, 5),fxyz( 9,16, 6)/ 1.6894221D-08, 5.5452136D-09/
      data fxyz( 9,16, 7),fxyz( 9,16, 8)/ 8.8869733D-09,-1.1456293D-08/
      data fxyz( 9,16, 9),fxyz( 9,16,10)/-8.4332134D-09,-1.1456293D-08/
      data fxyz( 9,16,11),fxyz( 9,16,12)/ 8.8869733D-09, 5.5452136D-09/
      data fxyz( 9,16,13),fxyz( 9,16,14)/ 1.6894221D-08,-8.6337672D-09/
      data fxyz( 9,16,15),fxyz( 9,16,16)/-1.4708119D-08,-4.6219456D-09/
      data fxyz( 9,16,17)/                8.4693479D-10/
      data fxyz( 9,17, 1),fxyz( 9,17, 2)/ 1.0839557D-08, 5.6345249D-09/
      data fxyz( 9,17, 3),fxyz( 9,17, 4)/-8.8141666D-09, 9.0899510D-09/
      data fxyz( 9,17, 5),fxyz( 9,17, 6)/-2.9821479D-09,-4.2875197D-10/
      data fxyz( 9,17, 7),fxyz( 9,17, 8)/ 5.6461901D-09,-9.1359688D-10/
      data fxyz( 9,17, 9),fxyz( 9,17,10)/-1.1433218D-08,-9.1359688D-10/
      data fxyz( 9,17,11),fxyz( 9,17,12)/ 5.6461901D-09,-4.2875197D-10/
      data fxyz( 9,17,13),fxyz( 9,17,14)/-2.9821479D-09, 9.0899510D-09/
      data fxyz( 9,17,15),fxyz( 9,17,16)/-8.8141666D-09, 5.6345249D-09/
      data fxyz( 9,17,17)/                1.0839557D-08/
      data fxyz( 9,18, 1),fxyz( 9,18, 2)/ 1.0150710D-09, 4.4703854D-09/
      data fxyz( 9,18, 3),fxyz( 9,18, 4)/ 1.1963216D-08, 5.3247392D-09/
      data fxyz( 9,18, 5),fxyz( 9,18, 6)/-2.4023443D-09,-1.4811285D-08/
      data fxyz( 9,18, 7),fxyz( 9,18, 8)/-2.7472126D-09, 5.6538584D-09/
      data fxyz( 9,18, 9),fxyz( 9,18,10)/ 6.1436644D-09, 5.6538584D-09/
      data fxyz( 9,18,11),fxyz( 9,18,12)/-2.7472126D-09,-1.4811285D-08/
      data fxyz( 9,18,13),fxyz( 9,18,14)/-2.4023443D-09, 5.3247392D-09/
      data fxyz( 9,18,15),fxyz( 9,18,16)/ 1.1963216D-08, 4.4703854D-09/
      data fxyz( 9,18,17)/                1.0150710D-09/
      data fxyz( 9,19, 1),fxyz( 9,19, 2)/-3.1473839D-09, 6.5692773D-09/
      data fxyz( 9,19, 3),fxyz( 9,19, 4)/ 2.8488190D-08, 7.6992216D-09/
      data fxyz( 9,19, 5),fxyz( 9,19, 6)/-7.6671614D-09,-2.6791370D-08/
      data fxyz( 9,19, 7),fxyz( 9,19, 8)/-9.6684383D-09, 1.3357097D-08/
      data fxyz( 9,19, 9),fxyz( 9,19,10)/ 1.7841436D-08, 1.3357097D-08/
      data fxyz( 9,19,11),fxyz( 9,19,12)/-9.6684383D-09,-2.6791370D-08/
      data fxyz( 9,19,13),fxyz( 9,19,14)/-7.6671614D-09, 7.6992216D-09/
      data fxyz( 9,19,15),fxyz( 9,19,16)/ 2.8488190D-08, 6.5692773D-09/
      data fxyz( 9,19,17)/               -3.1473839D-09/
      data fxyz(10, 1, 1),fxyz(10, 1, 2)/ 2.3248383D-10, 5.1742565D-10/
      data fxyz(10, 1, 3),fxyz(10, 1, 4)/ 1.0571456D-09, 7.0514216D-10/
      data fxyz(10, 1, 5),fxyz(10, 1, 6)/-5.1838220D-10,-1.0650657D-09/
      data fxyz(10, 1, 7),fxyz(10, 1, 8)/-7.2661047D-10, 5.2601235D-10/
      data fxyz(10, 1, 9),fxyz(10, 1,10)/ 1.1319482D-09, 5.2601235D-10/
      data fxyz(10, 1,11),fxyz(10, 1,12)/-7.2661047D-10,-1.0650657D-09/
      data fxyz(10, 1,13),fxyz(10, 1,14)/-5.1838220D-10, 7.0514216D-10/
      data fxyz(10, 1,15),fxyz(10, 1,16)/ 1.0571456D-09, 5.1742565D-10/
      data fxyz(10, 1,17)/                2.3248383D-10/
      data fxyz(10, 2, 1),fxyz(10, 2, 2)/-1.8274873D-10, 1.1051222D-10/
      data fxyz(10, 2, 3),fxyz(10, 2, 4)/ 7.7768718D-10, 1.3616310D-10/
      data fxyz(10, 2, 5),fxyz(10, 2, 6)/-2.8535224D-10,-3.5782130D-10/
      data fxyz(10, 2, 7),fxyz(10, 2, 8)/-3.7261553D-10, 2.2195368D-10/
      data fxyz(10, 2, 9),fxyz(10, 2,10)/ 5.4193259D-10, 2.2195368D-10/
      data fxyz(10, 2,11),fxyz(10, 2,12)/-3.7261553D-10,-3.5782130D-10/
      data fxyz(10, 2,13),fxyz(10, 2,14)/-2.8535224D-10, 1.3616310D-10/
      data fxyz(10, 2,15),fxyz(10, 2,16)/ 7.7768718D-10, 1.1051222D-10/
      data fxyz(10, 2,17)/               -1.8274873D-10/
      data fxyz(10, 3, 1),fxyz(10, 3, 2)/-7.6753200D-10,-3.7462122D-10/
      data fxyz(10, 3, 3),fxyz(10, 3, 4)/ 6.7644338D-10,-5.7603040D-10/
      data fxyz(10, 3, 5),fxyz(10, 3, 6)/ 3.8104715D-11, 4.2026579D-10/
      data fxyz(10, 3, 7),fxyz(10, 3, 8)/-9.1686166D-11,-1.6059031D-10/
      data fxyz(10, 3, 9),fxyz(10, 3,10)/ 2.9861166D-11,-1.6059031D-10/
      data fxyz(10, 3,11),fxyz(10, 3,12)/-9.1686166D-11, 4.2026579D-10/
      data fxyz(10, 3,13),fxyz(10, 3,14)/ 3.8104715D-11,-5.7603040D-10/
      data fxyz(10, 3,15),fxyz(10, 3,16)/ 6.7644338D-10,-3.7462122D-10/
      data fxyz(10, 3,17)/               -7.6753200D-10/
      data fxyz(10, 4, 1),fxyz(10, 4, 2)/-7.5888780D-10,-5.8598465D-10/
      data fxyz(10, 4, 3),fxyz(10, 4, 4)/-4.8551471D-11,-7.8697339D-10/
      data fxyz(10, 4, 5),fxyz(10, 4, 6)/ 4.5067155D-11, 9.5040335D-10/
      data fxyz(10, 4, 7),fxyz(10, 4, 8)/ 4.4497269D-10,-2.6843570D-10/
      data fxyz(10, 4, 9),fxyz(10, 4,10)/-7.5501486D-10,-2.6843570D-10/
      data fxyz(10, 4,11),fxyz(10, 4,12)/ 4.4497269D-10, 9.5040335D-10/
      data fxyz(10, 4,13),fxyz(10, 4,14)/ 4.5067155D-11,-7.8697339D-10/
      data fxyz(10, 4,15),fxyz(10, 4,16)/-4.8551471D-11,-5.8598465D-10/
      data fxyz(10, 4,17)/               -7.5888780D-10/
      data fxyz(10, 5, 1),fxyz(10, 5, 2)/ 1.0351206D-10,-4.9627814D-10/
      data fxyz(10, 5, 3),fxyz(10, 5, 4)/-1.5668574D-09,-9.8967500D-10/
      data fxyz(10, 5, 5),fxyz(10, 5, 6)/ 2.0770995D-09,-5.5701944D-10/
      data fxyz(10, 5, 7),fxyz(10, 5, 8)/ 8.9925645D-10,-5.3398443D-10/
      data fxyz(10, 5, 9),fxyz(10, 5,10)/-3.0672962D-10,-5.3398443D-10/
      data fxyz(10, 5,11),fxyz(10, 5,12)/ 8.9925645D-10,-5.5701944D-10/
      data fxyz(10, 5,13),fxyz(10, 5,14)/ 2.0770995D-09,-9.8967500D-10/
      data fxyz(10, 5,15),fxyz(10, 5,16)/-1.5668574D-09,-4.9627814D-10/
      data fxyz(10, 5,17)/                1.0351206D-10/
      data fxyz(10, 6, 1),fxyz(10, 6, 2)/ 3.0750753D-09, 1.3574517D-09/
      data fxyz(10, 6, 3),fxyz(10, 6, 4)/-3.4725561D-09, 2.5907807D-09/
      data fxyz(10, 6, 5),fxyz(10, 6, 6)/-1.8582406D-09, 1.5698947D-09/
      data fxyz(10, 6, 7),fxyz(10, 6, 8)/-6.5626071D-10, 3.1603585D-10/
      data fxyz(10, 6, 9),fxyz(10, 6,10)/-2.4630883D-10, 3.1603585D-10/
      data fxyz(10, 6,11),fxyz(10, 6,12)/-6.5626071D-10, 1.5698947D-09/
      data fxyz(10, 6,13),fxyz(10, 6,14)/-1.8582406D-09, 2.5907807D-09/
      data fxyz(10, 6,15),fxyz(10, 6,16)/-3.4725561D-09, 1.3574517D-09/
      data fxyz(10, 6,17)/                3.0750753D-09/
      data fxyz(10, 7, 1),fxyz(10, 7, 2)/-3.9046923D-10,-1.9398634D-10/
      data fxyz(10, 7, 3),fxyz(10, 7, 4)/ 5.2611243D-10,-5.8644441D-10/
      data fxyz(10, 7, 5),fxyz(10, 7, 6)/ 1.1793630D-09,-1.4511430D-09/
      data fxyz(10, 7, 7),fxyz(10, 7, 8)/ 5.6070715D-10,-1.4861039D-10/
      data fxyz(10, 7, 9),fxyz(10, 7,10)/ 3.0073308D-10,-1.4861039D-10/
      data fxyz(10, 7,11),fxyz(10, 7,12)/ 5.6070715D-10,-1.4511430D-09/
      data fxyz(10, 7,13),fxyz(10, 7,14)/ 1.1793630D-09,-5.8644441D-10/
      data fxyz(10, 7,15),fxyz(10, 7,16)/ 5.2611243D-10,-1.9398634D-10/
      data fxyz(10, 7,17)/               -3.9046923D-10/
      data fxyz(10, 8, 1),fxyz(10, 8, 2)/-9.2000212D-11, 3.2105958D-10/
      data fxyz(10, 8, 3),fxyz(10, 8, 4)/ 1.1140088D-09, 5.7734503D-10/
      data fxyz(10, 8, 5),fxyz(10, 8, 6)/-1.1171420D-09,-1.5155980D-10/
      data fxyz(10, 8, 7),fxyz(10, 8, 8)/-4.5854353D-10, 6.9865318D-10/
      data fxyz(10, 8, 9),fxyz(10, 8,10)/-1.6880035D-10, 6.9865318D-10/
      data fxyz(10, 8,11),fxyz(10, 8,12)/-4.5854353D-10,-1.5155980D-10/
      data fxyz(10, 8,13),fxyz(10, 8,14)/-1.1171420D-09, 5.7734503D-10/
      data fxyz(10, 8,15),fxyz(10, 8,16)/ 1.1140088D-09, 3.2105958D-10/
      data fxyz(10, 8,17)/               -9.2000212D-11/
      data fxyz(10, 9, 1),fxyz(10, 9, 2)/-4.2230670D-10, 8.8933550D-11/
      data fxyz(10, 9, 3),fxyz(10, 9, 4)/ 1.3050396D-09, 5.4115409D-11/
      data fxyz(10, 9, 5),fxyz(10, 9, 6)/-2.8303414D-10,-8.2973283D-10/
      data fxyz(10, 9, 7),fxyz(10, 9, 8)/-1.2904621D-10, 3.4378957D-10/
      data fxyz(10, 9, 9),fxyz(10, 9,10)/ 3.7697378D-10, 3.4378957D-10/
      data fxyz(10, 9,11),fxyz(10, 9,12)/-1.2904621D-10,-8.2973283D-10/
      data fxyz(10, 9,13),fxyz(10, 9,14)/-2.8303414D-10, 5.4115409D-11/
      data fxyz(10, 9,15),fxyz(10, 9,16)/ 1.3050396D-09, 8.8933550D-11/
      data fxyz(10, 9,17)/               -4.2230670D-10/
      data fxyz(10,10, 1),fxyz(10,10, 2)/-2.4964941D-10, 1.1572592D-10/
      data fxyz(10,10, 3),fxyz(10,10, 4)/ 1.0071109D-09, 5.7462144D-11/
      data fxyz(10,10, 5),fxyz(10,10, 6)/-1.6594294D-11,-1.1471118D-09/
      data fxyz(10,10, 7),fxyz(10,10, 8)/ 8.2559303D-11, 2.9643448D-10/
      data fxyz(10,10, 9),fxyz(10,10,10)/ 4.3767884D-10, 2.9643448D-10/
      data fxyz(10,10,11),fxyz(10,10,12)/ 8.2559303D-11,-1.1471118D-09/
      data fxyz(10,10,13),fxyz(10,10,14)/-1.6594294D-11, 5.7462144D-11/
      data fxyz(10,10,15),fxyz(10,10,16)/ 1.0071109D-09, 1.1572592D-10/
      data fxyz(10,10,17)/               -2.4964941D-10/
      data fxyz(10,11, 1),fxyz(10,11, 2)/ 1.0538009D-10, 2.5903914D-10/
      data fxyz(10,11, 3),fxyz(10,11, 4)/ 5.8426593D-10, 3.0900564D-10/
      data fxyz(10,11, 5),fxyz(10,11, 6)/-9.4485902D-11,-1.2545863D-09/
      data fxyz(10,11, 7),fxyz(10,11, 8)/ 2.2212003D-10, 3.6167643D-10/
      data fxyz(10,11, 9),fxyz(10,11,10)/ 3.3660192D-10, 3.6167643D-10/
      data fxyz(10,11,11),fxyz(10,11,12)/ 2.2212003D-10,-1.2545863D-09/
      data fxyz(10,11,13),fxyz(10,11,14)/-9.4485902D-11, 3.0900564D-10/
      data fxyz(10,11,15),fxyz(10,11,16)/ 5.8426593D-10, 2.5903914D-10/
      data fxyz(10,11,17)/                1.0538009D-10/
      data fxyz(10,12, 1),fxyz(10,12, 2)/ 3.7333487D-10, 3.3670075D-10/
      data fxyz(10,12, 3),fxyz(10,12, 4)/ 1.4827293D-10, 4.9112309D-10/
      data fxyz(10,12, 5),fxyz(10,12, 6)/-2.4435447D-10,-1.0678016D-09/
      data fxyz(10,12, 7),fxyz(10,12, 8)/ 3.8951770D-10, 1.8418740D-10/
      data fxyz(10,12, 9),fxyz(10,12,10)/ 3.7211991D-10, 1.8418740D-10/
      data fxyz(10,12,11),fxyz(10,12,12)/ 3.8951770D-10,-1.0678016D-09/
      data fxyz(10,12,13),fxyz(10,12,14)/-2.4435447D-10, 4.9112309D-10/
      data fxyz(10,12,15),fxyz(10,12,16)/ 1.4827293D-10, 3.3670075D-10/
      data fxyz(10,12,17)/                3.7333487D-10/
      data fxyz(10,13, 1),fxyz(10,13, 2)/-1.5273159D-10,-5.8555579D-11/
      data fxyz(10,13, 3),fxyz(10,13, 4)/ 1.1811758D-10, 6.0507057D-12/
      data fxyz(10,13, 5),fxyz(10,13, 6)/-4.1115673D-10, 2.2608553D-10/
      data fxyz(10,13, 7),fxyz(10,13, 8)/ 9.9269376D-11,-2.9289139D-11/
      data fxyz(10,13, 9),fxyz(10,13,10)/ 1.1073065D-10,-2.9289139D-11/
      data fxyz(10,13,11),fxyz(10,13,12)/ 9.9269376D-11, 2.2608553D-10/
      data fxyz(10,13,13),fxyz(10,13,14)/-4.1115673D-10, 6.0507057D-12/
      data fxyz(10,13,15),fxyz(10,13,16)/ 1.1811758D-10,-5.8555579D-11/
      data fxyz(10,13,17)/               -1.5273159D-10/
      data fxyz(10,14, 1),fxyz(10,14, 2)/-1.1282307D-09,-8.6357251D-10/
      data fxyz(10,14, 3),fxyz(10,14, 4)/-7.6540200D-11,-1.1178174D-09/
      data fxyz(10,14, 5),fxyz(10,14, 6)/-1.1125110D-10, 2.4132187D-09/
      data fxyz(10,14, 7),fxyz(10,14, 8)/-4.1291519D-10,-5.7969455D-10/
      data fxyz(10,14, 9),fxyz(10,14,10)/-3.4891496D-10,-5.7969455D-10/
      data fxyz(10,14,11),fxyz(10,14,12)/-4.1291519D-10, 2.4132187D-09/
      data fxyz(10,14,13),fxyz(10,14,14)/-1.1125110D-10,-1.1178174D-09/
      data fxyz(10,14,15),fxyz(10,14,16)/-7.6540200D-11,-8.6357251D-10/
      data fxyz(10,14,17)/               -1.1282307D-09/
      data fxyz(10,15, 1),fxyz(10,15, 2)/-1.1205018D-09,-1.2701246D-09/
      data fxyz(10,15, 3),fxyz(10,15, 4)/-1.3404707D-09,-1.6882853D-09/
      data fxyz(10,15, 5),fxyz(10,15, 6)/ 5.5214099D-10, 4.2692776D-09/
      data fxyz(10,15, 7),fxyz(10,15, 8)/-6.8845345D-10,-1.2857114D-09/
      data fxyz(10,15, 9),fxyz(10,15,10)/-1.0471597D-09,-1.2857114D-09/
      data fxyz(10,15,11),fxyz(10,15,12)/-6.8845345D-10, 4.2692776D-09/
      data fxyz(10,15,13),fxyz(10,15,14)/ 5.5214099D-10,-1.6882853D-09/
      data fxyz(10,15,15),fxyz(10,15,16)/-1.3404707D-09,-1.2701246D-09/
      data fxyz(10,15,17)/               -1.1205018D-09/
      data fxyz(10,16, 1),fxyz(10,16, 2)/-2.3451164D-10,-9.6933185D-10/
      data fxyz(10,16, 3),fxyz(10,16, 4)/-2.4757926D-09,-1.2815114D-09/
      data fxyz(10,16, 5),fxyz(10,16, 6)/ 1.0142066D-09, 4.2957488D-09/
      data fxyz(10,16, 7),fxyz(10,16, 8)/-4.6111796D-10,-1.4560470D-09/
      data fxyz(10,16, 9),fxyz(10,16,10)/-1.7987954D-09,-1.4560470D-09/
      data fxyz(10,16,11),fxyz(10,16,12)/-4.6111796D-10, 4.2957488D-09/
      data fxyz(10,16,13),fxyz(10,16,14)/ 1.0142066D-09,-1.2815114D-09/
      data fxyz(10,16,15),fxyz(10,16,16)/-2.4757926D-09,-9.6933185D-10/
      data fxyz(10,16,17)/               -2.3451164D-10/
      data fxyz(10,17, 1),fxyz(10,17, 2)/ 1.0313223D-09, 1.8521380D-10/
      data fxyz(10,17, 3),fxyz(10,17, 4)/-1.5107921D-09,-2.3215695D-10/
      data fxyz(10,17, 5),fxyz(10,17, 6)/ 2.7008053D-09,-1.8098384D-09/
      data fxyz(10,17, 7),fxyz(10,17, 8)/ 1.5946530D-09,-7.2440855D-10/
      data fxyz(10,17, 9),fxyz(10,17,10)/-1.6168785D-09,-7.2440855D-10/
      data fxyz(10,17,11),fxyz(10,17,12)/ 1.5946530D-09,-1.8098384D-09/
      data fxyz(10,17,13),fxyz(10,17,14)/ 2.7008053D-09,-2.3215695D-10/
      data fxyz(10,17,15),fxyz(10,17,16)/-1.5107921D-09, 1.8521380D-10/
      data fxyz(10,17,17)/                1.0313223D-09/
      data fxyz(10,18, 1),fxyz(10,18, 2)/ 1.0368472D-09, 1.4455713D-09/
      data fxyz(10,18, 3),fxyz(10,18, 4)/ 1.9800927D-09, 2.0743234D-09/
      data fxyz(10,18, 5),fxyz(10,18, 6)/-1.4781610D-09,-2.6741928D-09/
      data fxyz(10,18, 7),fxyz(10,18, 8)/-3.1277970D-10, 9.7287828D-10/
      data fxyz(10,18, 9),fxyz(10,18,10)/ 9.6056308D-10, 9.7287828D-10/
      data fxyz(10,18,11),fxyz(10,18,12)/-3.1277970D-10,-2.6741928D-09/
      data fxyz(10,18,13),fxyz(10,18,14)/-1.4781610D-09, 2.0743234D-09/
      data fxyz(10,18,15),fxyz(10,18,16)/ 1.9800927D-09, 1.4455713D-09/
      data fxyz(10,18,17)/                1.0368472D-09/
      data fxyz(10,19, 1),fxyz(10,19, 2)/ 1.4024605D-09, 2.6756968D-09/
      data fxyz(10,19, 3),fxyz(10,19, 4)/ 4.7492963D-09, 4.0216249D-09/
      data fxyz(10,19, 5),fxyz(10,19, 6)/-3.9812516D-09,-5.0360423D-09/
      data fxyz(10,19, 7),fxyz(10,19, 8)/-1.0878685D-09, 2.3942656D-09/
      data fxyz(10,19, 9),fxyz(10,19,10)/ 2.8535690D-09, 2.3942656D-09/
      data fxyz(10,19,11),fxyz(10,19,12)/-1.0878685D-09,-5.0360423D-09/
      data fxyz(10,19,13),fxyz(10,19,14)/-3.9812516D-09, 4.0216249D-09/
      data fxyz(10,19,15),fxyz(10,19,16)/ 4.7492963D-09, 2.6756968D-09/
      data fxyz(10,19,17)/                1.4024605D-09/
      data fxyz(11, 1, 1),fxyz(11, 1, 2)/-3.8777772D-11,-3.7763509D-11/
      data fxyz(11, 1, 3),fxyz(11, 1, 4)/-2.9479507D-11,-4.6639592D-11/
      data fxyz(11, 1, 5),fxyz(11, 1, 6)/-3.2734416D-12, 7.3588117D-11/
      data fxyz(11, 1, 7),fxyz(11, 1, 8)/ 7.3396201D-11,-3.6011526D-11/
      data fxyz(11, 1, 9),fxyz(11, 1,10)/-9.4119358D-11,-3.6011526D-11/
      data fxyz(11, 1,11),fxyz(11, 1,12)/ 7.3396201D-11, 7.3588117D-11/
      data fxyz(11, 1,13),fxyz(11, 1,14)/-3.2734416D-12,-4.6639592D-11/
      data fxyz(11, 1,15),fxyz(11, 1,16)/-2.9479507D-11,-3.7763509D-11/
      data fxyz(11, 1,17)/               -3.8777772D-11/
      data fxyz(11, 2, 1),fxyz(11, 2, 2)/-1.6335258D-11,-1.9702360D-11/
      data fxyz(11, 2, 3),fxyz(11, 2, 4)/-1.8620701D-11,-3.3109707D-11/
      data fxyz(11, 2, 5),fxyz(11, 2, 6)/ 3.7294128D-11,-6.8217687D-12/
      data fxyz(11, 2, 7),fxyz(11, 2, 8)/ 5.7760969D-11,-2.7959855D-11/
      data fxyz(11, 2, 9),fxyz(11, 2,10)/-3.7941389D-11,-2.7959855D-11/
      data fxyz(11, 2,11),fxyz(11, 2,12)/ 5.7760969D-11,-6.8217687D-12/
      data fxyz(11, 2,13),fxyz(11, 2,14)/ 3.7294128D-11,-3.3109707D-11/
      data fxyz(11, 2,15),fxyz(11, 2,16)/-1.8620701D-11,-1.9702360D-11/
      data fxyz(11, 2,17)/               -1.6335258D-11/
      data fxyz(11, 3, 1),fxyz(11, 3, 2)/ 8.0340906D-11, 5.3447300D-11/
      data fxyz(11, 3, 3),fxyz(11, 3, 4)/-4.2657243D-11, 1.0347649D-10/
      data fxyz(11, 3, 5),fxyz(11, 3, 6)/-1.1977587D-10, 2.9142406D-11/
      data fxyz(11, 3, 7),fxyz(11, 3, 8)/ 4.4881410D-12, 3.1279740D-11/
      data fxyz(11, 3, 9),fxyz(11, 3,10)/-4.6226379D-11, 3.1279740D-11/
      data fxyz(11, 3,11),fxyz(11, 3,12)/ 4.4881410D-12, 2.9142406D-11/
      data fxyz(11, 3,13),fxyz(11, 3,14)/-1.1977587D-10, 1.0347649D-10/
      data fxyz(11, 3,15),fxyz(11, 3,16)/-4.2657243D-11, 5.3447300D-11/
      data fxyz(11, 3,17)/                8.0340906D-11/
      data fxyz(11, 4, 1),fxyz(11, 4, 2)/-8.2800706D-11,-6.6212831D-11/
      data fxyz(11, 4, 3),fxyz(11, 4, 4)/ 5.5439933D-11,-1.9063441D-10/
      data fxyz(11, 4, 5),fxyz(11, 4, 6)/ 4.1488562D-10,-3.4220263D-10/
      data fxyz(11, 4, 7),fxyz(11, 4, 8)/ 8.2946897D-11,-8.8638399D-11/
      data fxyz(11, 4, 9),fxyz(11, 4,10)/ 1.7110898D-10,-8.8638399D-11/
      data fxyz(11, 4,11),fxyz(11, 4,12)/ 8.2946897D-11,-3.4220263D-10/
      data fxyz(11, 4,13),fxyz(11, 4,14)/ 4.1488562D-10,-1.9063441D-10/
      data fxyz(11, 4,15),fxyz(11, 4,16)/ 5.5439933D-11,-6.6212831D-11/
      data fxyz(11, 4,17)/               -8.2800706D-11/
      data fxyz(11, 5, 1),fxyz(11, 5, 2)/ 6.1455023D-10, 4.5517467D-10/
      data fxyz(11, 5, 3),fxyz(11, 5, 4)/-2.7670468D-10, 9.9517924D-10/
      data fxyz(11, 5, 5),fxyz(11, 5, 6)/-1.5454680D-09, 9.7190687D-10/
      data fxyz(11, 5, 7),fxyz(11, 5, 8)/-3.5886049D-10, 1.2810636D-10/
      data fxyz(11, 5, 9),fxyz(11, 5,10)/-1.5022438D-11, 1.2810636D-10/
      data fxyz(11, 5,11),fxyz(11, 5,12)/-3.5886049D-10, 9.7190687D-10/
      data fxyz(11, 5,13),fxyz(11, 5,14)/-1.5454680D-09, 9.9517924D-10/
      data fxyz(11, 5,15),fxyz(11, 5,16)/-2.7670468D-10, 4.5517467D-10/
      data fxyz(11, 5,17)/                6.1455023D-10/
      data fxyz(11, 6, 1),fxyz(11, 6, 2)/-1.2517410D-09,-7.9116277D-10/
      data fxyz(11, 6, 3),fxyz(11, 6, 4)/ 8.8024666D-10,-1.6862530D-09/
      data fxyz(11, 6, 5),fxyz(11, 6, 6)/ 2.3286199D-09,-1.4861603D-09/
      data fxyz(11, 6, 7),fxyz(11, 6, 8)/ 4.3182269D-10,-1.1772198D-10/
      data fxyz(11, 6, 9),fxyz(11, 6,10)/ 2.9956942D-11,-1.1772198D-10/
      data fxyz(11, 6,11),fxyz(11, 6,12)/ 4.3182269D-10,-1.4861603D-09/
      data fxyz(11, 6,13),fxyz(11, 6,14)/ 2.3286199D-09,-1.6862530D-09/
      data fxyz(11, 6,15),fxyz(11, 6,16)/ 8.8024666D-10,-7.9116277D-10/
      data fxyz(11, 6,17)/               -1.2517410D-09/
      data fxyz(11, 7, 1),fxyz(11, 7, 2)/ 8.5885993D-10, 5.3421204D-10/
      data fxyz(11, 7, 3),fxyz(11, 7, 4)/-6.3377937D-10, 1.1499316D-09/
      data fxyz(11, 7, 5),fxyz(11, 7, 6)/-1.6040181D-09, 1.1582953D-09/
      data fxyz(11, 7, 7),fxyz(11, 7, 8)/-5.1377576D-10, 2.9153745D-10/
      data fxyz(11, 7, 9),fxyz(11, 7,10)/-2.2754164D-10, 2.9153745D-10/
      data fxyz(11, 7,11),fxyz(11, 7,12)/-5.1377576D-10, 1.1582953D-09/
      data fxyz(11, 7,13),fxyz(11, 7,14)/-1.6040181D-09, 1.1499316D-09/
      data fxyz(11, 7,15),fxyz(11, 7,16)/-6.3377937D-10, 5.3421204D-10/
      data fxyz(11, 7,17)/                8.5885993D-10/
      data fxyz(11, 8, 1),fxyz(11, 8, 2)/-3.1653767D-10,-2.2277795D-10/
      data fxyz(11, 8, 3),fxyz(11, 8, 4)/ 1.5330690D-10,-4.5874623D-10/
      data fxyz(11, 8, 5),fxyz(11, 8, 6)/ 6.2733544D-10,-3.6162835D-10/
      data fxyz(11, 8, 7),fxyz(11, 8, 8)/ 2.2162927D-10,-2.1157087D-10/
      data fxyz(11, 8, 9),fxyz(11, 8,10)/ 1.7332650D-10,-2.1157087D-10/
      data fxyz(11, 8,11),fxyz(11, 8,12)/ 2.2162927D-10,-3.6162835D-10/
      data fxyz(11, 8,13),fxyz(11, 8,14)/ 6.2733544D-10,-4.5874623D-10/
      data fxyz(11, 8,15),fxyz(11, 8,16)/ 1.5330690D-10,-2.2277795D-10/
      data fxyz(11, 8,17)/               -3.1653767D-10/
      data fxyz(11, 9, 1),fxyz(11, 9, 2)/ 7.9520831D-12,-8.5528647D-12/
      data fxyz(11, 9, 3),fxyz(11, 9, 4)/-4.7823991D-11,-7.4134932D-12/
      data fxyz(11, 9, 5),fxyz(11, 9, 6)/ 3.3945972D-12, 2.8582917D-11/
      data fxyz(11, 9, 7),fxyz(11, 9, 8)/ 6.8862741D-11,-8.3785805D-11/
      data fxyz(11, 9, 9),fxyz(11, 9,10)/ 2.8731972D-11,-8.3785805D-11/
      data fxyz(11, 9,11),fxyz(11, 9,12)/ 6.8862741D-11, 2.8582917D-11/
      data fxyz(11, 9,13),fxyz(11, 9,14)/ 3.3945972D-12,-7.4134932D-12/
      data fxyz(11, 9,15),fxyz(11, 9,16)/-4.7823991D-11,-8.5528647D-12/
      data fxyz(11, 9,17)/                7.9520831D-12/
      data fxyz(11,10, 1),fxyz(11,10, 2)/ 6.6909347D-11, 1.7741164D-11/
      data fxyz(11,10, 3),fxyz(11,10, 4)/-1.1154878D-10, 3.9587447D-11/
      data fxyz(11,10, 5),fxyz(11,10, 6)/-2.0475784D-11, 7.2770691D-11/
      data fxyz(11,10, 7),fxyz(11,10, 8)/ 1.7014182D-11,-5.7110930D-11/
      data fxyz(11,10, 9),fxyz(11,10,10)/ 1.1618619D-11,-5.7110930D-11/
      data fxyz(11,10,11),fxyz(11,10,12)/ 1.7014182D-11, 7.2770691D-11/
      data fxyz(11,10,13),fxyz(11,10,14)/-2.0475784D-11, 3.9587447D-11/
      data fxyz(11,10,15),fxyz(11,10,16)/-1.1154878D-10, 1.7741164D-11/
      data fxyz(11,10,17)/                6.6909347D-11/
      data fxyz(11,11, 1),fxyz(11,11, 2)/ 7.6557716D-11, 3.2461579D-11/
      data fxyz(11,11, 3),fxyz(11,11, 4)/-9.8804395D-11, 7.5024062D-11/
      data fxyz(11,11, 5),fxyz(11,11, 6)/-9.3692215D-11, 1.3805395D-10/
      data fxyz(11,11, 7),fxyz(11,11, 8)/-6.0913007D-11, 3.5251630D-11/
      data fxyz(11,11, 9),fxyz(11,11,10)/-8.1550697D-11, 3.5251630D-11/
      data fxyz(11,11,11),fxyz(11,11,12)/-6.0913007D-11, 1.3805395D-10/
      data fxyz(11,11,13),fxyz(11,11,14)/-9.3692215D-11, 7.5024062D-11/
      data fxyz(11,11,15),fxyz(11,11,16)/-9.8804395D-11, 3.2461579D-11/
      data fxyz(11,11,17)/                7.6557716D-11/
      data fxyz(11,12, 1),fxyz(11,12, 2)/-5.7114545D-11,-2.9891928D-11/
      data fxyz(11,12, 3),fxyz(11,12, 4)/ 3.2537996D-11,-2.8257653D-11/
      data fxyz(11,12, 5),fxyz(11,12, 6)/-6.3651644D-11, 1.6361502D-10/
      data fxyz(11,12, 7),fxyz(11,12, 8)/-8.2932364D-11, 3.3709134D-11/
      data fxyz(11,12, 9),fxyz(11,12,10)/-7.7230604D-11, 3.3709134D-11/
      data fxyz(11,12,11),fxyz(11,12,12)/-8.2932364D-11, 1.6361502D-10/
      data fxyz(11,12,13),fxyz(11,12,14)/-6.3651644D-11,-2.8257653D-11/
      data fxyz(11,12,15),fxyz(11,12,16)/ 3.2537996D-11,-2.9891928D-11/
      data fxyz(11,12,17)/               -5.7114545D-11/
      data fxyz(11,13, 1),fxyz(11,13, 2)/-7.6031740D-11,-4.1313485D-11/
      data fxyz(11,13, 3),fxyz(11,13, 4)/ 5.7190459D-11,-6.7555508D-11/
      data fxyz(11,13, 5),fxyz(11,13, 6)/ 2.8936352D-11, 7.8755963D-11/
      data fxyz(11,13, 7),fxyz(11,13, 8)/-9.5751294D-11, 5.6151705D-11/
      data fxyz(11,13, 9),fxyz(11,13,10)/-6.2638566D-11, 5.6151705D-11/
      data fxyz(11,13,11),fxyz(11,13,12)/-9.5751294D-11, 7.8755963D-11/
      data fxyz(11,13,13),fxyz(11,13,14)/ 2.8936352D-11,-6.7555508D-11/
      data fxyz(11,13,15),fxyz(11,13,16)/ 5.7190459D-11,-4.1313485D-11/
      data fxyz(11,13,17)/               -7.6031740D-11/
      data fxyz(11,14, 1),fxyz(11,14, 2)/ 1.0142911D-10, 6.3993576D-11/
      data fxyz(11,14, 3),fxyz(11,14, 4)/-3.2151818D-11, 7.7187300D-11/
      data fxyz(11,14, 5),fxyz(11,14, 6)/ 4.8654213D-11,-1.9970045D-10/
      data fxyz(11,14, 7),fxyz(11,14, 8)/ 7.8262550D-11,-1.3648284D-11/
      data fxyz(11,14, 9),fxyz(11,14,10)/ 5.2840123D-11,-1.3648284D-11/
      data fxyz(11,14,11),fxyz(11,14,12)/ 7.8262550D-11,-1.9970045D-10/
      data fxyz(11,14,13),fxyz(11,14,14)/ 4.8654213D-11, 7.7187300D-11/
      data fxyz(11,14,15),fxyz(11,14,16)/-3.2151818D-11, 6.3993576D-11/
      data fxyz(11,14,17)/                1.0142911D-10/
      data fxyz(11,15, 1),fxyz(11,15, 2)/ 5.6769327D-11, 6.7648979D-11/
      data fxyz(11,15, 3),fxyz(11,15, 4)/ 9.5914539D-11, 6.3329420D-11/
      data fxyz(11,15, 5),fxyz(11,15, 6)/ 7.4047562D-11,-4.2425031D-10/
      data fxyz(11,15, 7),fxyz(11,15, 8)/ 1.7042245D-10, 3.1507255D-11/
      data fxyz(11,15, 9),fxyz(11,15,10)/ 7.3252782D-11, 3.1507255D-11/
      data fxyz(11,15,11),fxyz(11,15,12)/ 1.7042245D-10,-4.2425031D-10/
      data fxyz(11,15,13),fxyz(11,15,14)/ 7.4047562D-11, 6.3329420D-11/
      data fxyz(11,15,15),fxyz(11,15,16)/ 9.5914539D-11, 6.7648979D-11/
      data fxyz(11,15,17)/                5.6769327D-11/
      data fxyz(11,16, 1),fxyz(11,16, 2)/ 1.0117120D-10, 1.1898822D-10/
      data fxyz(11,16, 3),fxyz(11,16, 4)/ 1.5428318D-10, 1.2840533D-10/
      data fxyz(11,16, 5),fxyz(11,16, 6)/ 6.3502770D-11,-6.4012125D-10/
      data fxyz(11,16, 7),fxyz(11,16, 8)/ 2.2459901D-10, 7.8356704D-11/
      data fxyz(11,16, 9),fxyz(11,16,10)/ 1.3780121D-10, 7.8356704D-11/
      data fxyz(11,16,11),fxyz(11,16,12)/ 2.2459901D-10,-6.4012125D-10/
      data fxyz(11,16,13),fxyz(11,16,14)/ 6.3502770D-11, 1.2840533D-10/
      data fxyz(11,16,15),fxyz(11,16,16)/ 1.5428318D-10, 1.1898822D-10/
      data fxyz(11,16,17)/                1.0117120D-10/
      data fxyz(11,17, 1),fxyz(11,17, 2)/-5.6785579D-13, 6.6167577D-11/
      data fxyz(11,17, 3),fxyz(11,17, 4)/ 1.3545044D-10, 1.9581730D-10/
      data fxyz(11,17, 5),fxyz(11,17, 6)/-5.1916674D-10, 3.0403919D-10/
      data fxyz(11,17, 7),fxyz(11,17, 8)/-2.3283071D-10, 1.2470949D-10/
      data fxyz(11,17, 9),fxyz(11,17,10)/ 1.4102078D-10, 1.2470949D-10/
      data fxyz(11,17,11),fxyz(11,17,12)/-2.3283071D-10, 3.0403919D-10/
      data fxyz(11,17,13),fxyz(11,17,14)/-5.1916674D-10, 1.9581730D-10/
      data fxyz(11,17,15),fxyz(11,17,16)/ 1.3545044D-10, 6.6167577D-11/
      data fxyz(11,17,17)/               -5.6785579D-13/
      data fxyz(11,18, 1),fxyz(11,18, 2)/-1.8044949D-10,-1.8109320D-10/
      data fxyz(11,18, 3),fxyz(11,18, 4)/-1.1861136D-10,-2.7706896D-10/
      data fxyz(11,18, 5),fxyz(11,18, 6)/ 2.0345355D-10, 2.3642248D-10/
      data fxyz(11,18, 7),fxyz(11,18, 8)/-3.3513756D-11,-5.9565317D-11/
      data fxyz(11,18, 9),fxyz(11,18,10)/-3.6840574D-11,-5.9565317D-11/
      data fxyz(11,18,11),fxyz(11,18,12)/-3.3513756D-11, 2.3642248D-10/
      data fxyz(11,18,13),fxyz(11,18,14)/ 2.0345355D-10,-2.7706896D-10/
      data fxyz(11,18,15),fxyz(11,18,16)/-1.1861136D-10,-1.8109320D-10/
      data fxyz(11,18,17)/               -1.8044949D-10/
      data fxyz(11,19, 1),fxyz(11,19, 2)/-3.3800468D-10,-3.7279966D-10/
      data fxyz(11,19, 3),fxyz(11,19, 4)/-3.0546486D-10,-5.9558430D-10/
      data fxyz(11,19, 5),fxyz(11,19, 6)/ 5.5313389D-10, 4.5788495D-10/
      data fxyz(11,19, 7),fxyz(11,19, 8)/-2.1838710D-11,-1.7794653D-10/
      data fxyz(11,19, 9),fxyz(11,19,10)/-1.6296452D-10,-1.7794653D-10/
      data fxyz(11,19,11),fxyz(11,19,12)/-2.1838710D-11, 4.5788495D-10/
      data fxyz(11,19,13),fxyz(11,19,14)/ 5.5313389D-10,-5.9558430D-10/
      data fxyz(11,19,15),fxyz(11,19,16)/-3.0546486D-10,-3.7279966D-10/
      data fxyz(11,19,17)/               -3.3800468D-10/
      data fxyz(12, 1, 1),fxyz(12, 1, 2)/ 1.9583826D-11, 3.9692703D-11/
      data fxyz(12, 1, 3),fxyz(12, 1, 4)/ 7.5053600D-11, 5.7032427D-11/
      data fxyz(12, 1, 5),fxyz(12, 1, 6)/-4.9775072D-11,-7.1600620D-11/
      data fxyz(12, 1, 7),fxyz(12, 1, 8)/-4.7227211D-11, 4.1424442D-11/
      data fxyz(12, 1, 9),fxyz(12, 1,10)/ 6.8128422D-11, 4.1424442D-11/
      data fxyz(12, 1,11),fxyz(12, 1,12)/-4.7227211D-11,-7.1600620D-11/
      data fxyz(12, 1,13),fxyz(12, 1,14)/-4.9775072D-11, 5.7032427D-11/
      data fxyz(12, 1,15),fxyz(12, 1,16)/ 7.5053600D-11, 3.9692703D-11/
      data fxyz(12, 1,17)/                1.9583826D-11/
      data fxyz(12, 2, 1),fxyz(12, 2, 2)/-1.1243928D-11, 1.0343029D-11/
      data fxyz(12, 2, 3),fxyz(12, 2, 4)/ 5.6956164D-11, 1.5977677D-11/
      data fxyz(12, 2, 5),fxyz(12, 2, 6)/-3.3782519D-11,-2.1357090D-11/
      data fxyz(12, 2, 7),fxyz(12, 2, 8)/-2.1089827D-11, 1.6866434D-11/
      data fxyz(12, 2, 9),fxyz(12, 2,10)/ 3.0753595D-11, 1.6866434D-11/
      data fxyz(12, 2,11),fxyz(12, 2,12)/-2.1089827D-11,-2.1357090D-11/
      data fxyz(12, 2,13),fxyz(12, 2,14)/-3.3782519D-11, 1.5977677D-11/
      data fxyz(12, 2,15),fxyz(12, 2,16)/ 5.6956164D-11, 1.0343029D-11/
      data fxyz(12, 2,17)/               -1.1243928D-11/
      data fxyz(12, 3, 1),fxyz(12, 3, 2)/-7.2458096D-11,-3.5406193D-11/
      data fxyz(12, 3, 3),fxyz(12, 3, 4)/ 6.6229669D-11,-5.8178322D-11/
      data fxyz(12, 3, 5),fxyz(12, 3, 6)/ 1.8630422D-11, 1.1028546D-11/
      data fxyz(12, 3, 7),fxyz(12, 3, 8)/ 9.3317379D-12,-1.4327614D-11/
      data fxyz(12, 3, 9),fxyz(12, 3,10)/-2.9945623D-12,-1.4327614D-11/
      data fxyz(12, 3,11),fxyz(12, 3,12)/ 9.3317379D-12, 1.1028546D-11/
      data fxyz(12, 3,13),fxyz(12, 3,14)/ 1.8630422D-11,-5.8178322D-11/
      data fxyz(12, 3,15),fxyz(12, 3,16)/ 6.6229669D-11,-3.5406193D-11/
      data fxyz(12, 3,17)/               -7.2458096D-11/
      data fxyz(12, 4, 1),fxyz(12, 4, 2)/-2.7319813D-11,-2.3756995D-11/
      data fxyz(12, 4, 3),fxyz(12, 4, 4)/-2.0295116D-11,-1.6479949D-11/
      data fxyz(12, 4, 5),fxyz(12, 4, 6)/-5.6427996D-11, 1.0591681D-10/
      data fxyz(12, 4, 7),fxyz(12, 4, 8)/ 2.4758668D-11,-2.2295523D-11/
      data fxyz(12, 4, 9),fxyz(12, 4,10)/-4.9436062D-11,-2.2295523D-11/
      data fxyz(12, 4,11),fxyz(12, 4,12)/ 2.4758668D-11, 1.0591681D-10/
      data fxyz(12, 4,13),fxyz(12, 4,14)/-5.6427996D-11,-1.6479949D-11/
      data fxyz(12, 4,15),fxyz(12, 4,16)/-2.0295116D-11,-2.3756995D-11/
      data fxyz(12, 4,17)/               -2.7319813D-11/
      data fxyz(12, 5, 1),fxyz(12, 5, 2)/-9.9126836D-11,-1.0844634D-10/
      data fxyz(12, 5, 3),fxyz(12, 5, 4)/-4.9795098D-11,-2.2904149D-10/
      data fxyz(12, 5, 5),fxyz(12, 5, 6)/ 3.8325375D-10,-1.8160149D-10/
      data fxyz(12, 5, 7),fxyz(12, 5, 8)/ 9.8036101D-11,-4.8509767D-11/
      data fxyz(12, 5, 9),fxyz(12, 5,10)/-1.4578297D-11,-4.8509767D-11/
      data fxyz(12, 5,11),fxyz(12, 5,12)/ 9.8036101D-11,-1.8160149D-10/
      data fxyz(12, 5,13),fxyz(12, 5,14)/ 3.8325375D-10,-2.2904149D-10/
      data fxyz(12, 5,15),fxyz(12, 5,16)/-4.9795098D-11,-1.0844634D-10/
      data fxyz(12, 5,17)/               -9.9126836D-11/
      data fxyz(12, 6, 1),fxyz(12, 6, 2)/ 3.7958642D-10, 2.0663202D-10/
      data fxyz(12, 6, 3),fxyz(12, 6, 4)/-3.4303684D-10, 4.2579493D-10/
      data fxyz(12, 6, 5),fxyz(12, 6, 6)/-4.9706521D-10, 3.5251705D-10/
      data fxyz(12, 6, 7),fxyz(12, 6, 8)/-1.2645692D-10, 4.5127768D-11/
      data fxyz(12, 6, 9),fxyz(12, 6,10)/-2.0271237D-11, 4.5127768D-11/
      data fxyz(12, 6,11),fxyz(12, 6,12)/-1.2645692D-10, 3.5251705D-10/
      data fxyz(12, 6,13),fxyz(12, 6,14)/-4.9706521D-10, 4.2579493D-10/
      data fxyz(12, 6,15),fxyz(12, 6,16)/-3.4303684D-10, 2.0663202D-10/
      data fxyz(12, 6,17)/                3.7958642D-10/
      data fxyz(12, 7, 1),fxyz(12, 7, 2)/-9.9948795D-11,-7.3363361D-11/
      data fxyz(12, 7, 3),fxyz(12, 7, 4)/ 5.9690069D-11,-1.7989449D-10/
      data fxyz(12, 7, 5),fxyz(12, 7, 6)/ 3.2617571D-10,-2.4234081D-10/
      data fxyz(12, 7, 7),fxyz(12, 7, 8)/ 5.0464047D-11,-1.3205213D-11/
      data fxyz(12, 7, 9),fxyz(12, 7,10)/ 4.0156246D-11,-1.3205213D-11/
      data fxyz(12, 7,11),fxyz(12, 7,12)/ 5.0464047D-11,-2.4234081D-10/
      data fxyz(12, 7,13),fxyz(12, 7,14)/ 3.2617571D-10,-1.7989449D-10/
      data fxyz(12, 7,15),fxyz(12, 7,16)/ 5.9690069D-11,-7.3363361D-11/
      data fxyz(12, 7,17)/               -9.9948795D-11/
      data fxyz(12, 8, 1),fxyz(12, 8, 2)/ 3.3637807D-11, 4.6083005D-11/
      data fxyz(12, 8, 3),fxyz(12, 8, 4)/ 4.7529324D-11, 8.7471722D-11/
      data fxyz(12, 8, 5),fxyz(12, 8, 6)/-1.3191706D-10, 1.7281693D-11/
      data fxyz(12, 8, 7),fxyz(12, 8, 8)/-3.7218855D-11, 4.5846212D-11/
      data fxyz(12, 8, 9),fxyz(12, 8,10)/-3.5586320D-12, 4.5846212D-11/
      data fxyz(12, 8,11),fxyz(12, 8,12)/-3.7218855D-11, 1.7281693D-11/
      data fxyz(12, 8,13),fxyz(12, 8,14)/-1.3191706D-10, 8.7471722D-11/
      data fxyz(12, 8,15),fxyz(12, 8,16)/ 4.7529324D-11, 4.6083005D-11/
      data fxyz(12, 8,17)/                3.3637807D-11/
      data fxyz(12, 9, 1),fxyz(12, 9, 2)/-4.8867967D-11,-3.5498805D-12/
      data fxyz(12, 9, 3),fxyz(12, 9, 4)/ 1.0973009D-10,-1.4856532D-11/
      data fxyz(12, 9, 5),fxyz(12, 9, 6)/-3.6413606D-12,-7.3450061D-11/
      data fxyz(12, 9, 7),fxyz(12, 9, 8)/ 6.2865866D-12, 1.9361909D-11/
      data fxyz(12, 9, 9),fxyz(12, 9,10)/ 2.0984385D-11, 1.9361909D-11/
      data fxyz(12, 9,11),fxyz(12, 9,12)/ 6.2865866D-12,-7.3450061D-11/
      data fxyz(12, 9,13),fxyz(12, 9,14)/-3.6413606D-12,-1.4856532D-11/
      data fxyz(12, 9,15),fxyz(12, 9,16)/ 1.0973009D-10,-3.5498805D-12/
      data fxyz(12, 9,17)/               -4.8867967D-11/
      data fxyz(12,10, 1),fxyz(12,10, 2)/-2.3319947D-11, 7.2105555D-12/
      data fxyz(12,10, 3),fxyz(12,10, 4)/ 7.9251051D-11, 6.0065705D-12/
      data fxyz(12,10, 5),fxyz(12,10, 6)/-1.8504007D-11,-6.1415962D-11/
      data fxyz(12,10, 7),fxyz(12,10, 8)/-8.4634298D-12, 4.0710917D-11/
      data fxyz(12,10, 9),fxyz(12,10,10)/ 3.8801067D-12, 4.0710917D-11/
      data fxyz(12,10,11),fxyz(12,10,12)/-8.4634298D-12,-6.1415962D-11/
      data fxyz(12,10,13),fxyz(12,10,14)/-1.8504007D-11, 6.0065705D-12/
      data fxyz(12,10,15),fxyz(12,10,16)/ 7.9251051D-11, 7.2105555D-12/
      data fxyz(12,10,17)/               -2.3319947D-11/
      data fxyz(12,11, 1),fxyz(12,11, 2)/-4.6526188D-12, 1.1809554D-11/
      data fxyz(12,11, 3),fxyz(12,11, 4)/ 5.0659504D-11, 1.1152232D-11/
      data fxyz(12,11, 5),fxyz(12,11, 6)/-2.0233331D-12,-8.6607501D-11/
      data fxyz(12,11, 7),fxyz(12,11, 8)/ 2.3048123D-11, 1.0839838D-11/
      data fxyz(12,11, 9),fxyz(12,11,10)/ 3.6412225D-11, 1.0839838D-11/
      data fxyz(12,11,11),fxyz(12,11,12)/ 2.3048123D-11,-8.6607501D-11/
      data fxyz(12,11,13),fxyz(12,11,14)/-2.0233331D-12, 1.1152232D-11/
      data fxyz(12,11,15),fxyz(12,11,16)/ 5.0659504D-11, 1.1809554D-11/
      data fxyz(12,11,17)/               -4.6526188D-12/
      data fxyz(12,12, 1),fxyz(12,12, 2)/ 2.0268280D-11, 2.0893053D-11/
      data fxyz(12,12, 3),fxyz(12,12, 4)/ 1.6101359D-11, 3.0267301D-11/
      data fxyz(12,12, 5),fxyz(12,12, 6)/-1.7228710D-11,-7.1282111D-11/
      data fxyz(12,12, 7),fxyz(12,12, 8)/ 2.4220166D-11, 1.5261650D-11/
      data fxyz(12,12, 9),fxyz(12,12,10)/ 2.2984422D-11, 1.5261650D-11/
      data fxyz(12,12,11),fxyz(12,12,12)/ 2.4220166D-11,-7.1282111D-11/
      data fxyz(12,12,13),fxyz(12,12,14)/-1.7228710D-11, 3.0267301D-11/
      data fxyz(12,12,15),fxyz(12,12,16)/ 1.6101359D-11, 2.0893053D-11/
      data fxyz(12,12,17)/                2.0268280D-11/
      data fxyz(12,13, 1),fxyz(12,13, 2)/-1.0365051D-12, 1.7237899D-12/
      data fxyz(12,13, 3),fxyz(12,13, 4)/ 2.8097877D-12, 9.7558259D-12/
      data fxyz(12,13, 5),fxyz(12,13, 6)/-3.3164649D-11, 5.5377880D-12/
      data fxyz(12,13, 7),fxyz(12,13, 8)/ 2.2100561D-11,-1.6815550D-11/
      data fxyz(12,13, 9),fxyz(12,13,10)/ 2.3700934D-11,-1.6815550D-11/
      data fxyz(12,13,11),fxyz(12,13,12)/ 2.2100561D-11, 5.5377880D-12/
      data fxyz(12,13,13),fxyz(12,13,14)/-3.3164649D-11, 9.7558259D-12/
      data fxyz(12,13,15),fxyz(12,13,16)/ 2.8097877D-12, 1.7237899D-12/
      data fxyz(12,13,17)/               -1.0365051D-12/
      data fxyz(12,14, 1),fxyz(12,14, 2)/-7.3672026D-11,-5.6841970D-11/
      data fxyz(12,14, 3),fxyz(12,14, 4)/-6.4861398D-12,-7.3470518D-11/
      data fxyz(12,14, 5),fxyz(12,14, 6)/-7.1578360D-12, 1.5260184D-10/
      data fxyz(12,14, 7),fxyz(12,14, 8)/-1.7251945D-11,-3.6392288D-11/
      data fxyz(12,14, 9),fxyz(12,14,10)/-3.2943794D-11,-3.6392288D-11/
      data fxyz(12,14,11),fxyz(12,14,12)/-1.7251945D-11, 1.5260184D-10/
      data fxyz(12,14,13),fxyz(12,14,14)/-7.1578360D-12,-7.3470518D-11/
      data fxyz(12,14,15),fxyz(12,14,16)/-6.4861398D-12,-5.6841970D-11/
      data fxyz(12,14,17)/               -7.3672026D-11/
      data fxyz(12,15, 1),fxyz(12,15, 2)/-7.6122165D-11,-8.6251431D-11/
      data fxyz(12,15, 3),fxyz(12,15, 4)/-9.1649363D-11,-1.1360696D-10/
      data fxyz(12,15, 5),fxyz(12,15, 6)/ 3.3299970D-11, 2.9459870D-10/
      data fxyz(12,15, 7),fxyz(12,15, 8)/-4.7409567D-11,-8.0592373D-11/
      data fxyz(12,15, 9),fxyz(12,15,10)/-8.5489432D-11,-8.0592373D-11/
      data fxyz(12,15,11),fxyz(12,15,12)/-4.7409567D-11, 2.9459870D-10/
      data fxyz(12,15,13),fxyz(12,15,14)/ 3.3299970D-11,-1.1360696D-10/
      data fxyz(12,15,15),fxyz(12,15,16)/-9.1649363D-11,-8.6251431D-11/
      data fxyz(12,15,17)/               -7.6122165D-11/
      data fxyz(12,16, 1),fxyz(12,16, 2)/-2.0433380D-11,-6.9794339D-11/
      data fxyz(12,16, 3),fxyz(12,16, 4)/-1.6829021D-10,-9.4813883D-11/
      data fxyz(12,16, 5),fxyz(12,16, 6)/ 7.9644796D-11, 2.8737719D-10/
      data fxyz(12,16, 7),fxyz(12,16, 8)/-2.2703683D-11,-1.0581933D-10/
      data fxyz(12,16, 9),fxyz(12,16,10)/-1.2324988D-10,-1.0581933D-10/
      data fxyz(12,16,11),fxyz(12,16,12)/-2.2703683D-11, 2.8737719D-10/
      data fxyz(12,16,13),fxyz(12,16,14)/ 7.9644796D-11,-9.4813883D-11/
      data fxyz(12,16,15),fxyz(12,16,16)/-1.6829021D-10,-6.9794339D-11/
      data fxyz(12,16,17)/               -2.0433380D-11/
      data fxyz(12,17, 1),fxyz(12,17, 2)/ 6.9280236D-11, 1.3102020D-11/
      data fxyz(12,17, 3),fxyz(12,17, 4)/-1.0054196D-10,-1.3055763D-11/
      data fxyz(12,17, 5),fxyz(12,17, 6)/ 1.7391137D-10,-1.0694714D-10/
      data fxyz(12,17, 7),fxyz(12,17, 8)/ 9.4173490D-11,-4.3718963D-11/
      data fxyz(12,17, 9),fxyz(12,17,10)/-1.1254366D-10,-4.3718963D-11/
      data fxyz(12,17,11),fxyz(12,17,12)/ 9.4173490D-11,-1.0694714D-10/
      data fxyz(12,17,13),fxyz(12,17,14)/ 1.7391137D-10,-1.3055763D-11/
      data fxyz(12,17,15),fxyz(12,17,16)/-1.0054196D-10, 1.3102020D-11/
      data fxyz(12,17,17)/                6.9280236D-11/
      data fxyz(12,18, 1),fxyz(12,18, 2)/ 7.2393756D-11, 9.9015956D-11/
      data fxyz(12,18, 3),fxyz(12,18, 4)/ 1.3298244D-10, 1.4124393D-10/
      data fxyz(12,18, 5),fxyz(12,18, 6)/-9.6518123D-11,-1.8522195D-10/
      data fxyz(12,18, 7),fxyz(12,18, 8)/-2.2554674D-11, 6.3780751D-11/
      data fxyz(12,18, 9),fxyz(12,18,10)/ 7.2595704D-11, 6.3780751D-11/
      data fxyz(12,18,11),fxyz(12,18,12)/-2.2554674D-11,-1.8522195D-10/
      data fxyz(12,18,13),fxyz(12,18,14)/-9.6518123D-11, 1.4124393D-10/
      data fxyz(12,18,15),fxyz(12,18,16)/ 1.3298244D-10, 9.9015956D-11/
      data fxyz(12,18,17)/                7.2393756D-11/
      data fxyz(12,19, 1),fxyz(12,19, 2)/ 1.0025016D-10, 1.8406773D-10/
      data fxyz(12,19, 3),fxyz(12,19, 4)/ 3.1914223D-10, 2.7481745D-10/
      data fxyz(12,19, 5),fxyz(12,19, 6)/-2.6274874D-10,-3.5379663D-10/
      data fxyz(12,19, 7),fxyz(12,19, 8)/-7.2538456D-11, 1.5830922D-10/
      data fxyz(12,19, 9),fxyz(12,19,10)/ 2.0789703D-10, 1.5830922D-10/
      data fxyz(12,19,11),fxyz(12,19,12)/-7.2538456D-11,-3.5379663D-10/
      data fxyz(12,19,13),fxyz(12,19,14)/-2.6274874D-10, 2.7481745D-10/
      data fxyz(12,19,15),fxyz(12,19,16)/ 3.1914223D-10, 1.8406773D-10/
      data fxyz(12,19,17)/                1.0025016D-10/
      data fxyz(13, 1, 1),fxyz(13, 1, 2)/-1.4058779D-11,-7.6713190D-11/
      data fxyz(13, 1, 3),fxyz(13, 1, 4)/-2.0607254D-10,-1.0196461D-10/
      data fxyz(13, 1, 5),fxyz(13, 1, 6)/ 8.6946889D-11, 1.8261720D-10/
      data fxyz(13, 1, 7),fxyz(13, 1, 8)/ 1.1030461D-10,-7.7517138D-11/
      data fxyz(13, 1, 9),fxyz(13, 1,10)/-1.9890995D-10,-7.7517138D-11/
      data fxyz(13, 1,11),fxyz(13, 1,12)/ 1.1030461D-10, 1.8261720D-10/
      data fxyz(13, 1,13),fxyz(13, 1,14)/ 8.6946889D-11,-1.0196461D-10/
      data fxyz(13, 1,15),fxyz(13, 1,16)/-2.0607254D-10,-7.6713190D-11/
      data fxyz(13, 1,17)/               -1.4058779D-11/
      data fxyz(13, 2, 1),fxyz(13, 2, 2)/ 5.5702678D-11,-3.5079920D-12/
      data fxyz(13, 2, 3),fxyz(13, 2, 4)/-1.5022440D-10, 9.3292727D-12/
      data fxyz(13, 2, 5),fxyz(13, 2, 6)/ 4.3536194D-12, 9.1227743D-11/
      data fxyz(13, 2, 7),fxyz(13, 2, 8)/ 4.7849897D-11,-2.4254361D-11/
      data fxyz(13, 2, 9),fxyz(13, 2,10)/-1.0464840D-10,-2.4254361D-11/
      data fxyz(13, 2,11),fxyz(13, 2,12)/ 4.7849897D-11, 9.1227743D-11/
      data fxyz(13, 2,13),fxyz(13, 2,14)/ 4.3536194D-12, 9.3292727D-12/
      data fxyz(13, 2,15),fxyz(13, 2,16)/-1.5022440D-10,-3.5079920D-12/
      data fxyz(13, 2,17)/                5.5702678D-11/
      data fxyz(13, 3, 1),fxyz(13, 3, 2)/ 6.6237482D-11, 2.1358425D-11/
      data fxyz(13, 3, 3),fxyz(13, 3, 4)/-7.4847147D-11, 8.5900799D-12/
      data fxyz(13, 3, 5),fxyz(13, 3, 6)/ 1.1731086D-10,-1.5327810D-10/
      data fxyz(13, 3, 7),fxyz(13, 3, 8)/ 5.0174600D-11, 4.5692258D-12/
      data fxyz(13, 3, 9),fxyz(13, 3,10)/ 1.7985750D-11, 4.5692258D-12/
      data fxyz(13, 3,11),fxyz(13, 3,12)/ 5.0174600D-11,-1.5327810D-10/
      data fxyz(13, 3,13),fxyz(13, 3,14)/ 1.1731086D-10, 8.5900799D-12/
      data fxyz(13, 3,15),fxyz(13, 3,16)/-7.4847147D-11, 2.1358425D-11/
      data fxyz(13, 3,17)/                6.6237482D-11/
      data fxyz(13, 4, 1),fxyz(13, 4, 2)/ 2.8406557D-10, 2.1541058D-10/
      data fxyz(13, 4, 3),fxyz(13, 4, 4)/-6.7821788D-11, 3.9996664D-10/
      data fxyz(13, 4, 5),fxyz(13, 4, 6)/-4.5415869D-10, 1.3812339D-10/
      data fxyz(13, 4, 7),fxyz(13, 4, 8)/-1.7422866D-10, 1.1892998D-10/
      data fxyz(13, 4, 9),fxyz(13, 4,10)/ 4.1315812D-11, 1.1892998D-10/
      data fxyz(13, 4,11),fxyz(13, 4,12)/-1.7422866D-10, 1.3812339D-10/
      data fxyz(13, 4,13),fxyz(13, 4,14)/-4.5415869D-10, 3.9996664D-10/
      data fxyz(13, 4,15),fxyz(13, 4,16)/-6.7821788D-11, 2.1541058D-10/
      data fxyz(13, 4,17)/                2.8406557D-10/
      data fxyz(13, 5, 1),fxyz(13, 5, 2)/-7.1937948D-10,-3.9686543D-10/
      data fxyz(13, 5, 3),fxyz(13, 5, 4)/ 6.8146747D-10,-8.8556561D-10/
      data fxyz(13, 5, 5),fxyz(13, 5, 6)/ 1.2354213D-09,-9.2567482D-10/
      data fxyz(13, 5, 7),fxyz(13, 5, 8)/ 1.5286131D-10,-5.0858295D-12/
      data fxyz(13, 5, 9),fxyz(13, 5,10)/ 9.3169915D-11,-5.0858295D-12/
      data fxyz(13, 5,11),fxyz(13, 5,12)/ 1.5286131D-10,-9.2567482D-10/
      data fxyz(13, 5,13),fxyz(13, 5,14)/ 1.2354213D-09,-8.8556561D-10/
      data fxyz(13, 5,15),fxyz(13, 5,16)/ 6.8146747D-10,-3.9686543D-10/
      data fxyz(13, 5,17)/               -7.1937948D-10/
      data fxyz(13, 6, 1),fxyz(13, 6, 2)/ 6.3608354D-10, 5.4655610D-10/
      data fxyz(13, 6, 3),fxyz(13, 6, 4)/-1.2793039D-10, 1.2449398D-09/
      data fxyz(13, 6, 5),fxyz(13, 6, 6)/-2.1574511D-09, 1.3109991D-09/
      data fxyz(13, 6, 7),fxyz(13, 6, 8)/-3.5859581D-10, 7.0061370D-11/
      data fxyz(13, 6, 9),fxyz(13, 6,10)/ 2.4421034D-11, 7.0061370D-11/
      data fxyz(13, 6,11),fxyz(13, 6,12)/-3.5859581D-10, 1.3109991D-09/
      data fxyz(13, 6,13),fxyz(13, 6,14)/-2.1574511D-09, 1.2449398D-09/
      data fxyz(13, 6,15),fxyz(13, 6,16)/-1.2793039D-10, 5.4655610D-10/
      data fxyz(13, 6,17)/                6.3608354D-10/
      data fxyz(13, 7, 1),fxyz(13, 7, 2)/-7.2634649D-10,-4.9363316D-10/
      data fxyz(13, 7, 3),fxyz(13, 7, 4)/ 4.1851142D-10,-1.0473534D-09/
      data fxyz(13, 7, 5),fxyz(13, 7, 6)/ 1.4885345D-09,-8.6900295D-10/
      data fxyz(13, 7, 7),fxyz(13, 7, 8)/ 2.9435217D-10,-1.9646240D-10/
      data fxyz(13, 7, 9),fxyz(13, 7,10)/ 1.4906609D-10,-1.9646240D-10/
      data fxyz(13, 7,11),fxyz(13, 7,12)/ 2.9435217D-10,-8.6900295D-10/
      data fxyz(13, 7,13),fxyz(13, 7,14)/ 1.4885345D-09,-1.0473534D-09/
      data fxyz(13, 7,15),fxyz(13, 7,16)/ 4.1851142D-10,-4.9363316D-10/
      data fxyz(13, 7,17)/               -7.2634649D-10/
      data fxyz(13, 8, 1),fxyz(13, 8, 2)/ 3.4760950D-10, 1.5058823D-10/
      data fxyz(13, 8, 3),fxyz(13, 8, 4)/-4.2544746D-10, 3.2506732D-10/
      data fxyz(13, 8, 5),fxyz(13, 8, 6)/-3.5030686D-10, 3.6911051D-10/
      data fxyz(13, 8, 7),fxyz(13, 8, 8)/-8.0262765D-11, 2.6920042D-12/
      data fxyz(13, 8, 9),fxyz(13, 8,10)/-7.8073103D-11, 2.6920042D-12/
      data fxyz(13, 8,11),fxyz(13, 8,12)/-8.0262765D-11, 3.6911051D-10/
      data fxyz(13, 8,13),fxyz(13, 8,14)/-3.5030686D-10, 3.2506732D-10/
      data fxyz(13, 8,15),fxyz(13, 8,16)/-4.2544746D-10, 1.5058823D-10/
      data fxyz(13, 8,17)/                3.4760950D-10/
      data fxyz(13, 9, 1),fxyz(13, 9, 2)/ 4.4975059D-11,-3.3725330D-11/
      data fxyz(13, 9, 3),fxyz(13, 9, 4)/-2.0923939D-10,-4.5905599D-11/
      data fxyz(13, 9, 5),fxyz(13, 9, 6)/ 9.3696133D-11, 1.2656986D-10/
      data fxyz(13, 9, 7),fxyz(13, 9, 8)/ 8.1889369D-12,-2.1035305D-11/
      data fxyz(13, 9, 9),fxyz(13, 9,10)/-1.1581870D-10,-2.1035305D-11/
      data fxyz(13, 9,11),fxyz(13, 9,12)/ 8.1889369D-12, 1.2656986D-10/
      data fxyz(13, 9,13),fxyz(13, 9,14)/ 9.3696133D-11,-4.5905599D-11/
      data fxyz(13, 9,15),fxyz(13, 9,16)/-2.0923939D-10,-3.3725330D-11/
      data fxyz(13, 9,17)/                4.4975059D-11/
      data fxyz(13,10, 1),fxyz(13,10, 2)/-9.1094565D-12,-4.0737619D-11/
      data fxyz(13,10, 3),fxyz(13,10, 4)/-1.1596814D-10,-3.8590414D-11/
      data fxyz(13,10, 5),fxyz(13,10, 6)/-1.7698278D-11, 2.3512360D-10/
      data fxyz(13,10, 7),fxyz(13,10, 8)/-6.1410549D-11, 2.1499843D-11/
      data fxyz(13,10, 9),fxyz(13,10,10)/-1.6152241D-10, 2.1499843D-11/
      data fxyz(13,10,11),fxyz(13,10,12)/-6.1410549D-11, 2.3512360D-10/
      data fxyz(13,10,13),fxyz(13,10,14)/-1.7698278D-11,-3.8590414D-11/
      data fxyz(13,10,15),fxyz(13,10,16)/-1.1596814D-10,-4.0737619D-11/
      data fxyz(13,10,17)/               -9.1094565D-12/
      data fxyz(13,11, 1),fxyz(13,11, 2)/-1.0720784D-10,-9.4876403D-11/
      data fxyz(13,11, 3),fxyz(13,11, 4)/-3.1223406D-11,-1.4719586D-10/
      data fxyz(13,11, 5),fxyz(13,11, 6)/ 1.0206999D-10, 1.7099652D-10/
      data fxyz(13,11, 7),fxyz(13,11, 8)/ 1.4065490D-11,-1.3681204D-10/
      data fxyz(13,11, 9),fxyz(13,11,10)/ 1.6255307D-11,-1.3681204D-10/
      data fxyz(13,11,11),fxyz(13,11,12)/ 1.4065490D-11, 1.7099652D-10/
      data fxyz(13,11,13),fxyz(13,11,14)/ 1.0206999D-10,-1.4719586D-10/
      data fxyz(13,11,15),fxyz(13,11,16)/-3.1223406D-11,-9.4876403D-11/
      data fxyz(13,11,17)/               -1.0720784D-10/
      data fxyz(13,12, 1),fxyz(13,12, 2)/-5.0360511D-11,-5.6377145D-11/
      data fxyz(13,12, 3),fxyz(13,12, 4)/-4.5060324D-11,-9.4410598D-11/
      data fxyz(13,12, 5),fxyz(13,12, 6)/ 1.0177330D-10, 1.1545813D-10/
      data fxyz(13,12, 7),fxyz(13,12, 8)/-2.8140227D-11,-6.0950305D-11/
      data fxyz(13,12, 9),fxyz(13,12,10)/-2.8739195D-11,-6.0950305D-11/
      data fxyz(13,12,11),fxyz(13,12,12)/-2.8140227D-11, 1.1545813D-10/
      data fxyz(13,12,13),fxyz(13,12,14)/ 1.0177330D-10,-9.4410598D-11/
      data fxyz(13,12,15),fxyz(13,12,16)/-4.5060324D-11,-5.6377145D-11/
      data fxyz(13,12,17)/               -5.0360511D-11/
      data fxyz(13,13, 1),fxyz(13,13, 2)/ 1.1208304D-10, 5.6796180D-11/
      data fxyz(13,13, 3),fxyz(13,13, 4)/-8.1168003D-11, 7.0238434D-11/
      data fxyz(13,13, 5),fxyz(13,13, 6)/ 5.8314026D-11,-1.3153631D-10/
      data fxyz(13,13, 7),fxyz(13,13, 8)/ 8.3851679D-11,-6.8028161D-11/
      data fxyz(13,13, 9),fxyz(13,13,10)/ 5.7729040D-11,-6.8028161D-11/
      data fxyz(13,13,11),fxyz(13,13,12)/ 8.3851679D-11,-1.3153631D-10/
      data fxyz(13,13,13),fxyz(13,13,14)/ 5.8314026D-11, 7.0238434D-11/
      data fxyz(13,13,15),fxyz(13,13,16)/-8.1168003D-11, 5.6796180D-11/
      data fxyz(13,13,17)/                1.1208304D-10/
      data fxyz(13,14, 1),fxyz(13,14, 2)/ 1.8013249D-10, 1.4734649D-10/
      data fxyz(13,14, 3),fxyz(13,14, 4)/ 3.8895725D-11, 1.9527162D-10/
      data fxyz(13,14, 5),fxyz(13,14, 6)/-1.1568057D-11,-4.0909968D-10/
      data fxyz(13,14, 7),fxyz(13,14, 8)/ 5.5171989D-11, 1.4595872D-10/
      data fxyz(13,14, 9),fxyz(13,14,10)/ 1.7622609D-11, 1.4595872D-10/
      data fxyz(13,14,11),fxyz(13,14,12)/ 5.5171989D-11,-4.0909968D-10/
      data fxyz(13,14,13),fxyz(13,14,14)/-1.1568057D-11, 1.9527162D-10/
      data fxyz(13,14,15),fxyz(13,14,16)/ 3.8895725D-11, 1.4734649D-10/
      data fxyz(13,14,17)/                1.8013249D-10/
      data fxyz(13,15, 1),fxyz(13,15, 2)/ 2.0621803D-10, 2.3130751D-10/
      data fxyz(13,15, 3),fxyz(13,15, 4)/ 2.2404490D-10, 3.3001460D-10/
      data fxyz(13,15, 5),fxyz(13,15, 6)/-1.8861033D-10,-6.1697224D-10/
      data fxyz(13,15, 7),fxyz(13,15, 8)/ 2.1690906D-11, 2.7674284D-10/
      data fxyz(13,15, 9),fxyz(13,15,10)/ 1.4667471D-10, 2.7674284D-10/
      data fxyz(13,15,11),fxyz(13,15,12)/ 2.1690906D-11,-6.1697224D-10/
      data fxyz(13,15,13),fxyz(13,15,14)/-1.8861033D-10, 3.3001460D-10/
      data fxyz(13,15,15),fxyz(13,15,16)/ 2.2404490D-10, 2.3130751D-10/
      data fxyz(13,15,17)/                2.0621803D-10/
      data fxyz(13,16, 1),fxyz(13,16, 2)/-3.4719879D-11, 1.1655485D-10/
      data fxyz(13,16, 3),fxyz(13,16, 4)/ 4.3338249D-10, 1.7077493D-10/
      data fxyz(13,16, 5),fxyz(13,16, 6)/-2.5160021D-10,-4.7702534D-10/
      data fxyz(13,16, 7),fxyz(13,16, 8)/-5.0635784D-11, 2.4974739D-10/
      data fxyz(13,16, 9),fxyz(13,16,10)/ 2.9313221D-10, 2.4974739D-10/
      data fxyz(13,16,11),fxyz(13,16,12)/-5.0635784D-11,-4.7702534D-10/
      data fxyz(13,16,13),fxyz(13,16,14)/-2.5160021D-10, 1.7077493D-10/
      data fxyz(13,16,15),fxyz(13,16,16)/ 4.3338249D-10, 1.1655485D-10/
      data fxyz(13,16,17)/               -3.4719879D-11/
      data fxyz(13,17, 1),fxyz(13,17, 2)/-2.3099844D-10,-9.0753913D-11/
      data fxyz(13,17, 3),fxyz(13,17, 4)/ 2.3746759D-10,-9.2230313D-11/
      data fxyz(13,17, 5),fxyz(13,17, 6)/-2.2509284D-10, 2.0483216D-10/
      data fxyz(13,17, 7),fxyz(13,17, 8)/-2.0741137D-10, 7.7736333D-11/
      data fxyz(13,17, 9),fxyz(13,17,10)/ 2.4661840D-10, 7.7736333D-11/
      data fxyz(13,17,11),fxyz(13,17,12)/-2.0741137D-10, 2.0483216D-10/
      data fxyz(13,17,13),fxyz(13,17,14)/-2.2509284D-10,-9.2230313D-11/
      data fxyz(13,17,15),fxyz(13,17,16)/ 2.3746759D-10,-9.0753913D-11/
      data fxyz(13,17,17)/               -2.3099844D-10/
      data fxyz(13,18, 1),fxyz(13,18, 2)/-8.8834009D-11,-1.8184003D-10/
      data fxyz(13,18, 3),fxyz(13,18, 4)/-3.5370696D-10,-2.4956072D-10/
      data fxyz(13,18, 5),fxyz(13,18, 6)/ 1.8204873D-10, 4.0740688D-10/
      data fxyz(13,18, 7),fxyz(13,18, 8)/ 9.2526180D-11,-1.7612282D-10/
      data fxyz(13,18, 9),fxyz(13,18,10)/-1.7017632D-10,-1.7612282D-10/
      data fxyz(13,18,11),fxyz(13,18,12)/ 9.2526180D-11, 4.0740688D-10/
      data fxyz(13,18,13),fxyz(13,18,14)/ 1.8204873D-10,-2.4956072D-10/
      data fxyz(13,18,15),fxyz(13,18,16)/-3.5370696D-10,-1.8184003D-10/
      data fxyz(13,18,17)/               -8.8834009D-11/
      data fxyz(13,19, 1),fxyz(13,19, 2)/-4.3367575D-11,-3.0613262D-10/
      data fxyz(13,19, 3),fxyz(13,19, 4)/-8.3195019D-10,-4.3708393D-10/
      data fxyz(13,19, 5),fxyz(13,19, 6)/ 4.8043767D-10, 7.4691954D-10/
      data fxyz(13,19, 7),fxyz(13,19, 8)/ 2.6197426D-10,-4.0659680D-10/
      data fxyz(13,19, 9),fxyz(13,19,10)/-4.8117650D-10,-4.0659680D-10/
      data fxyz(13,19,11),fxyz(13,19,12)/ 2.6197426D-10, 7.4691954D-10/
      data fxyz(13,19,13),fxyz(13,19,14)/ 4.8043767D-10,-4.3708393D-10/
      data fxyz(13,19,15),fxyz(13,19,16)/-8.3195019D-10,-3.0613262D-10/
      data fxyz(13,19,17)/               -4.3367575D-11/
 
      data x( 1), x( 2) /  4.00000000D+00 ,  4.20000000D+00 /
      data x( 3), x( 4) /  4.40000000D+00 ,  4.60000000D+00 /
      data x( 5), x( 6) /  4.80000000D+00 ,  5.00000000D+00 /
      data x( 7), x( 8) /  5.50000000D+00 ,  6.00000000D+00 /
      data x( 9), x(10) /  7.00000000D+00 ,  8.00000000D+00 /
      data x(11), x(12) /  1.00000000D+01 ,  1.20000000D+01 /
      data x(13) /         1.50000000D+01 /
 
      data y( 1), y( 2) /  0.00000000D+00 ,  1.00000000D+01 /
      data y( 3), y( 4) /  2.00000000D+01 ,  3.00000000D+01 /
      data y( 5), y( 6) /  4.00000000D+01 ,  5.00000000D+01 /
      data y( 7), y( 8) /  6.00000000D+01 ,  7.00000000D+01 /
      data y( 9), y(10) /  8.00000000D+01 ,  9.00000000D+01 /
      data y(11), y(12) /  1.00000000D+02 ,  1.10000000D+02 /
      data y(13), y(14) /  1.20000000D+02 ,  1.30000000D+02 /
      data y(15), y(16) /  1.40000000D+02 ,  1.50000000D+02 /
      data y(17), y(18) /  1.60000000D+02 ,  1.70000000D+02 /
      data y(19) /         1.80000000D+02 /
 
      data z( 1), z( 2) / -6.00000000D+01 , -3.00000000D+01 /
      data z( 3), z( 4) /  0.00000000D+00 ,  3.00000000D+01 /
      data z( 5), z( 6) /  6.00000000D+01 ,  9.00000000D+01 /
      data z( 7), z( 8) /  1.20000000D+02 ,  1.50000000D+02 /
      data z( 9), z(10) /  1.80000000D+02 ,  2.10000000D+02 /
      data z(11), z(12) /  2.40000000D+02 ,  2.70000000D+02 /
      data z(13), z(14) /  3.00000000D+02 ,  3.30000000D+02 /
      data z(15), z(16) /  3.60000000D+02 ,  3.90000000D+02 /
      data z(17) /         4.20000000D+02 /
 
      data delx( 1), delx( 2) /  2.00000000D-01 ,  2.00000000D-01 /
      data delx( 3), delx( 4) /  2.00000000D-01 ,  2.00000000D-01 /
      data delx( 5), delx( 6) /  2.00000000D-01 ,  5.00000000D-01 /
      data delx( 7), delx( 8) /  5.00000000D-01 ,  1.00000000D+00 /
      data delx( 9), delx(10) /  1.00000000D+00 ,  2.00000000D+00 /
      data delx(11), delx(12) /  2.00000000D+00 ,  3.00000000D+00 /
      data dely( 1), dely( 2) /  1.00000000D+01 ,  1.00000000D+01 /
      data dely( 3), dely( 4) /  1.00000000D+01 ,  1.00000000D+01 /
      data dely( 5), dely( 6) /  1.00000000D+01 ,  1.00000000D+01 /
      data dely( 7), dely( 8) /  1.00000000D+01 ,  1.00000000D+01 /
      data dely( 9), dely(10) /  1.00000000D+01 ,  1.00000000D+01 /
      data dely(11), dely(12) /  1.00000000D+01 ,  1.00000000D+01 /
      data dely(13), dely(14) /  1.00000000D+01 ,  1.00000000D+01 /
      data dely(15), dely(16) /  1.00000000D+01 ,  1.00000000D+01 /
      data dely(17), dely(18) /  1.00000000D+01 ,  1.00000000D+01 /
      data delz( 1), delz( 2) /  3.00000000D+01 ,  3.00000000D+01 /
      data delz( 3), delz( 4) /  3.00000000D+01 ,  3.00000000D+01 /
      data delz( 5), delz( 6) /  3.00000000D+01 ,  3.00000000D+01 /
      data delz( 7), delz( 8) /  3.00000000D+01 ,  3.00000000D+01 /
      data delz( 9), delz(10) /  3.00000000D+01 ,  3.00000000D+01 /
      data delz(11), delz(12) /  3.00000000D+01 ,  3.00000000D+01 /
      data delz(13), delz(14) /  3.00000000D+01 ,  3.00000000D+01 /
      data delz(15), delz(16) /  3.00000000D+01 ,  3.00000000D+01 /
      data nptx,npty,nptz /  13 , 19 , 17 /


      data jprint / 0 /
C
      IF(XI .LE. X(1)) THEN
        IX=1
      ELSE IF( XI .GE. X(nptx)) THEN
        IX=nptx-1
      ELSE
        call hunt(x,nptx,xi,ix)
      ENDIF
 15   xix=x(ix)
      xixp1=x(ix+1)
      delxi = delx(ix)
      if(jprint .ne. 0)
     x  write(6,'(2x,a,3f10.5)') 'xix, xixp1, delxi', xix,xixp1,delxi
C
      IF(yi .LE. y(1)) THEN
        iy=1
      ELSE IF( yi .GE. y(npty)) THEN
        iy=npty-1
      ELSE
        call hunt(y,npty,yi,iy)
      ENDIF
 25   yiy=y(iy)
      yiyp1=y(iy+1)
      delyi = dely(iy)
      if(jprint .ne. 0)
     x  write(6,'(2x,a,3f10.5)') 'yiy, yiyp1, delyi', yiy,yiyp1,delyi
C
      IF(zi .LE. z(1)) THEN
        iz=1
      ELSE IF( zi .GE. z(nptz)) THEN
        iz=nptz-1
      ELSE
        call hunt(z,nptz,zi,iz)
      ENDIF
 35   ziz=z(iz)
      zizp1=z(iz+1)
      delzi = delz(iz)
      if(jprint .ne. 0)
     x  write(6,'(2x,a,3f10.5)') 'ziz, zizp1, delzi', ziz,zizp1,delzi

   40 CONTINUE
      C(1,1,1) = FXYZ(IX+1,IY+1,IZ+1)
      C(1,1,2) = FXYZ(IX,  IY+1,IZ+1)
      C(1,2,1) = FXYZ(IX+1,IY,  IZ+1)
      C(1,2,2) = FXYZ(IX,  IY,  IZ+1)
      C(1,3,1) = FPPPP(IX+1,IY+1,IZ+1,2)
      C(1,3,2) = FPPPP(IX,  IY+1,IZ+1,2)
      C(1,4,1) = FPPPP(IX+1,IY,  IZ+1,2)
      C(1,4,2) = FPPPP(IX,  IY,  IZ+1,2)
      C(1,1,3) = FPPPP(IX+1,IY+1,IZ+1,3)
      C(1,1,4) = FPPPP(IX,  IY+1,IZ+1,3)
      C(1,2,3) = FPPPP(IX+1,IY,  IZ+1,3)
      C(1,2,4) = FPPPP(IX,  IY,  IZ+1,3)
      C(1,3,3) = FPP(IX+1,IY+1,IZ+1,3)
      C(1,3,4) = FPP(IX,  IY+1,IZ+1,3)
      C(1,4,3) = FPP(IX+1,IY,  IZ+1,3)
      C(1,4,4) = FPP(IX,  IY,  IZ+1,3)
C
      C(2,1,1) = FXYZ(IX+1,IY+1,IZ)
      C(2,1,2) = FXYZ(IX,  IY+1,IZ)
      C(2,2,1) = FXYZ(IX+1,IY,  IZ)
      C(2,2,2) = FXYZ(IX,  IY,  IZ)
      C(2,3,1) = FPPPP(IX+1,IY+1,IZ, 2)
      C(2,3,2) = FPPPP(IX,  IY+1,IZ, 2)
      C(2,4,1) = FPPPP(IX+1,IY,  IZ, 2)
      C(2,4,2) = FPPPP(IX,  IY,  IZ, 2)
      C(2,1,3) = FPPPP(IX+1,IY+1,IZ, 3)
      C(2,1,4) = FPPPP(IX,  IY+1,IZ, 3)
      C(2,2,3) = FPPPP(IX+1,IY,  IZ, 3)
      C(2,2,4) = FPPPP(IX,  IY,  IZ, 3)
      C(2,3,3) = FPP(IX+1,IY+1,IZ, 3)
      C(2,3,4) = FPP(IX,  IY+1,IZ, 3)
      C(2,4,3) = FPP(IX+1,IY,  IZ, 3)
      C(2,4,4) = FPP(IX,  IY,  IZ, 3)
C
      C(3,1,1) = FPPPP(IX+1,IY+1,IZ+1,1)
      C(3,1,2) = FPPPP(IX  ,IY+1,IZ+1,1)
      C(3,2,1) = FPPPP(IX+1,IY  ,IZ+1,1)
      C(3,2,2) = FPPPP(IX,  IY,  IZ+1,1)
      C(3,3,1) = FPP(IX+1,IY+1,IZ+1,1)
      C(3,3,2) = FPP(IX,  IY+1,IZ+1,1)
      C(3,4,1) = FPP(IX+1,IY,  IZ+1,1)
      C(3,4,2) = FPP(IX,  IY,  IZ+1,1)
      C(3,1,3) = FPP(IX+1,IY+1,IZ+1,2)
      C(3,1,4) = FPP(IX,  IY+1,IZ+1,2)
      C(3,2,3) = FPP(IX+1,IY,  IZ+1,2)
      C(3,2,4) = FPP(IX,  IY,  IZ+1,2)
      C(3,3,3) = F(IX+1,IY+1,IZ+1)
      C(3,3,4) = F(IX,  IY+1,IZ+1)
      C(3,4,3) = F(IX+1,IY,  IZ+1)
      C(3,4,4) = F(IX,  IY,  IZ+1)
C
      C(4,1,1) = FPPPP(IX+1,IY+1,IZ,1)
      C(4,1,2) = FPPPP(IX  ,IY+1,IZ,1)
      C(4,2,1) = FPPPP(IX+1,IY  ,IZ,1)
      C(4,2,2) = FPPPP(IX,  IY,  IZ,1)
      C(4,3,1) = FPP(IX+1,IY+1,IZ,1)
      C(4,3,2) = FPP(IX,  IY+1,IZ,1)
      C(4,4,1) = FPP(IX+1,IY,  IZ,1)
      C(4,4,2) = FPP(IX,  IY,  IZ,1)
      C(4,1,3) = FPP(IX+1,IY+1,IZ,2)
      C(4,1,4) = FPP(IX,  IY+1,IZ,2)
      C(4,2,3) = FPP(IX+1,IY,  IZ,2)
      C(4,2,4) = FPP(IX,  IY,  IZ,2)
      C(4,3,3) = F(IX+1,IY+1,IZ)
      C(4,3,4) = F(IX,  IY+1,IZ)
      C(4,4,3) = F(IX+1,IY,  IZ)
      C(4,4,4) = F(IX,  IY,  IZ)

c      if(jprint .ne. 0) then
c       write(6,'(2x,a)') 'c(i,j,1) :'
c       call mwrita(c(1,1,1),4,4,6)
c       write(6,'(2x,a)') 'c(i,j,2) :'
c       call mwrita(c(1,1,2),4,4,6)
c       write(6,'(2x,a)') 'c(i,j,3) :'
c       call mwrita(c(1,1,3),4,4,6)
c       write(6,'(2x,a)') 'c(i,j,4) :'
c       call mwrita(c(1,1,4),4,4,6)
c      endif
C
      PX(1)=((XI-XIX)**3/(6.0d0*DELXI))-(XI-XIX)*DELXI/6.0d0
      PX(2)=(XI-XIXP1)*DELXI/6.0d0-((XI-XIXP1)**3/(6.0d0*DELXI))
      PX(3)=(XI-XIX)/DELXI
      PX(4)=(XIXP1-XI)/DELXI
c      if(jprint .ne. 0 ) write(6,'(2x,a,4f10.5)') ' px : ',px
C
      PY(1)=((YI-YIY)**3/(6.0d0*DELYI))-(YI-YIY)*DELYI/6.0d0
      PY(2)=(YI-YIYP1)*DELYI/6.0d0-((YI-YIYP1)**3/(6.0d0*DELYI))
      PY(3)=(YI-YIY)/DELYI
      PY(4)=(YIYP1-YI)/DELYI
c      if(jprint .ne. 0 ) write(6,'(2x,a,4f10.5)') ' py : ',py
C
      PZ(1)=((ZI-ZIZ)**3/(6.0d0*DELZI))-(ZI-ZIZ)*DELZI/6.0d0
      PZ(2)=(ZI-ZIZP1)*DELZI/6.0d0-((ZI-ZIZP1)**3/(6.0d0*DELZI))
      PZ(3)=(ZI-ZIZ)/DELZI
      PZ(4)=(ZIZP1-ZI)/DELZI
c      if(jprint .ne. 0 ) write(6,'(2x,a,4f10.5)') ' pz : ',pz
C
      DPX(1)=((XI-XIX)**2/(2.0d0*DELXI))-(DELXI/6.0d0)
      DPX(2)=(DELXI/6.0d0)-((XI-XIXP1)**2/(2.0d0*DELXI))
      DPX(3)=1.0d0/DELXI
      DPX(4)=-1.0d0/DELXI
C
      DPY(1)=((YI-YIY)**2/(2.0d0*DELYI))-(DELYI/6.0d0)
      DPY(2)=(DELYI/6.0d0)-((YI-YIYP1)**2/(2.0d0*DELYI))
      DPY(3)=1.0d0/DELYI
      DPY(4)=-1.0d0/DELYI
C
      DPZ(1)=((ZI-ZIZ)**2/(2.0d0*DELZI))-(DELZI/6.0d0)
      DPZ(2)=(DELZI/6.0d0)-((ZI-ZIZP1)**2/(2.0d0*DELZI))
      DPZ(3)=1.0d0/DELZI
      DPZ(4)=-1.0d0/DELZI
C
      CALL SEVAL(C,PX,PY,PZ,FI)
      CALL SEVAL(C,DPX,PY,PZ,DFX)
      CALL SEVAL(C,PX,DPY,PZ,DFY)
      CALL SEVAL(C,PX,PY,DPZ,DFZ)
C
      RETURN
      END  
