
      real*8 function nco_h(r, rpar, ipar)
c
c     sample main program for calling h+nco potential
c
c     coordinates:
c                          H
c                           \
c                        N---C---O
c
c     Input coordinates:
c           r     = R(C-H)             4.0 <   r   < 15.0 au
c           theta = H-C-N Angle     -180.0 < theta < +180. degrees
c
c
c     Fixed coordinates:    R(CN) = 2.37 au
c                           R(CO) = 2.24 au
c                           N-C-N = 180 degrees
c
c     Ouput energy in au relative to H+NCN
c


      implicit double precision (a-h,o-z)

      parameter (nfrag=2, natommx=100, ndim = 3)

      dimension r(nfrag,natommx,ndim)
      dimension rch(ndim),rnc(ndim),rnh(ndim)

      include 'data.fi'

      pi2 = asin(1.0d0)
      pi = 2.0d0*pi2

c
c     for nco + h -- just need to calculate r and theta 
c

      rch2 = 0.0d0
      rnc2 = 0.0d0
      rnh2 = 0.0d0
 
      do 1100 idim = 1 , ndim
 
         rch(idim) = r(1,1,idim) - r(2,1,idim)
         rnc(idim) = r(1,2,idim) - r(1,1,idim)
         rnh(idim) = r(2,1,idim) - r(1,2,idim)
         rch2 = rch2 + rch(idim)**2
         rnc2 = rnc2 + rnc(idim)**2
         rnh2 = rnh2 + rnh(idim)**2
 
1100  continue

      rch0 = sqrt(rch2)
      rnc0 = sqrt(rnc2)
      rnh0 = sqrt(rnh2)
 
      cthe = (rch2 + rnc2 - rnh2)/(2.0d0*rch0*rnc0)
      if (abs(cthe).gt.1.0d0) then
         write (6,*) 'error in cthe',cthe
         if (cthe.gt.1.0d0) then
            the = 0.0d0
         else
            the = pi
         endif
      else
         the = acos(cthe)
      endif

      theta = 180.0d0*the/pi
      if (rch0.lt.4.0) rch0=4.0
      if (rch0.gt.15.) rch0=15.
      call hPnco_atz_dci(rch0,theta,nco_h)

      return
      end


      SUBROUTINE hPnco_atz_dci(XI,YI,FI)
      IMPLICIT REAL*8 (A-H,O-Z)
      dimension fpp(17,54,2),f(17,54),fpppp(17,54)
      dimension delx(16),dely(53),x(17),y(54)
      dimension c(4,4),px(4),py(4)
 
      data f( 1, 1),f( 1, 2) / -1.68335313D+02 , -1.68343222D+02 /
      data f( 1, 3),f( 1, 4) / -1.68347107D+02 , -1.68328930D+02 /
      data f( 1, 5),f( 1, 6) / -1.68296679D+02 , -1.68264884D+02 /
      data f( 1, 7),f( 1, 8) / -1.68244459D+02 , -1.68239089D+02 /
      data f( 1, 9),f( 1,10) / -1.68243277D+02 , -1.68252256D+02 /
      data f( 1,11),f( 1,12) / -1.68264868D+02 , -1.68281809D+02 /
      data f( 1,13),f( 1,14) / -1.68304693D+02 , -1.68335227D+02 /
      data f( 1,15),f( 1,16) / -1.68372853D+02 , -1.68409759D+02 /
      data f( 1,17),f( 1,18) / -1.68429631D+02 , -1.68415027D+02 /
      data f( 1,19),f( 1,20) / -1.68415027D+02 , -1.68429631D+02 /
      data f( 1,21),f( 1,22) / -1.68409759D+02 , -1.68372853D+02 /
      data f( 1,23),f( 1,24) / -1.68335227D+02 , -1.68304693D+02 /
      data f( 1,25),f( 1,26) / -1.68281809D+02 , -1.68264868D+02 /
      data f( 1,27),f( 1,28) / -1.68252256D+02 , -1.68243277D+02 /
      data f( 1,29),f( 1,30) / -1.68239089D+02 , -1.68244459D+02 /
      data f( 1,31),f( 1,32) / -1.68264884D+02 , -1.68296679D+02 /
      data f( 1,33),f( 1,34) / -1.68328930D+02 , -1.68347107D+02 /
      data f( 1,35),f( 1,36) / -1.68343222D+02 , -1.68335313D+02 /
      data f( 1,37),f( 1,38) / -1.68343222D+02 , -1.68347107D+02 /
      data f( 1,39),f( 1,40) / -1.68328930D+02 , -1.68296679D+02 /
      data f( 1,41),f( 1,42) / -1.68264884D+02 , -1.68244459D+02 /
      data f( 1,43),f( 1,44) / -1.68239089D+02 , -1.68243277D+02 /
      data f( 1,45),f( 1,46) / -1.68252256D+02 , -1.68264868D+02 /
      data f( 1,47),f( 1,48) / -1.68281809D+02 , -1.68304693D+02 /
      data f( 1,49),f( 1,50) / -1.68335227D+02 , -1.68372853D+02 /
      data f( 1,51),f( 1,52) / -1.68409759D+02 , -1.68429631D+02 /
      data f( 1,53),f( 1,54) / -1.68415027D+02 , -1.68398319D+02 /
      data f( 2, 1),f( 2, 2) / -1.68327836D+02 , -1.68330233D+02 /
      data f( 2, 3),f( 2, 4) / -1.68327177D+02 , -1.68309433D+02 /
      data f( 2, 5),f( 2, 6) / -1.68283225D+02 , -1.68259745D+02 /
      data f( 2, 7),f( 2, 8) / -1.68246367D+02 , -1.68243048D+02 /
      data f( 2, 9),f( 2,10) / -1.68245913D+02 , -1.68252500D+02 /
      data f( 2,11),f( 2,12) / -1.68262312D+02 , -1.68276080D+02 /
      data f( 2,13),f( 2,14) / -1.68295282D+02 , -1.68321575D+02 /
      data f( 2,15),f( 2,16) / -1.68355098D+02 , -1.68390772D+02 /
      data f( 2,17),f( 2,18) / -1.68416050D+02 , -1.68422111D+02 /
      data f( 2,19),f( 2,20) / -1.68422111D+02 , -1.68416050D+02 /
      data f( 2,21),f( 2,22) / -1.68390772D+02 , -1.68355098D+02 /
      data f( 2,23),f( 2,24) / -1.68321575D+02 , -1.68295282D+02 /
      data f( 2,25),f( 2,26) / -1.68276080D+02 , -1.68262312D+02 /
      data f( 2,27),f( 2,28) / -1.68252500D+02 , -1.68245913D+02 /
      data f( 2,29),f( 2,30) / -1.68243048D+02 , -1.68246367D+02 /
      data f( 2,31),f( 2,32) / -1.68259745D+02 , -1.68283225D+02 /
      data f( 2,33),f( 2,34) / -1.68309433D+02 , -1.68327177D+02 /
      data f( 2,35),f( 2,36) / -1.68330233D+02 , -1.68327836D+02 /
      data f( 2,37),f( 2,38) / -1.68330233D+02 , -1.68327177D+02 /
      data f( 2,39),f( 2,40) / -1.68309433D+02 , -1.68283225D+02 /
      data f( 2,41),f( 2,42) / -1.68259745D+02 , -1.68246367D+02 /
      data f( 2,43),f( 2,44) / -1.68243048D+02 , -1.68245913D+02 /
      data f( 2,45),f( 2,46) / -1.68252500D+02 , -1.68262312D+02 /
      data f( 2,47),f( 2,48) / -1.68276080D+02 , -1.68295282D+02 /
      data f( 2,49),f( 2,50) / -1.68321575D+02 , -1.68355098D+02 /
      data f( 2,51),f( 2,52) / -1.68390772D+02 , -1.68416050D+02 /
      data f( 2,53),f( 2,54) / -1.68422111D+02 , -1.68418222D+02 /
      data f( 3, 1),f( 3, 2) / -1.68307394D+02 , -1.68308287D+02 /
      data f( 3, 3),f( 3, 4) / -1.68304834D+02 , -1.68291326D+02 /
      data f( 3, 5),f( 3, 6) / -1.68272516D+02 , -1.68256715D+02 /
      data f( 3, 7),f( 3, 8) / -1.68248168D+02 , -1.68246030D+02 /
      data f( 3, 9),f( 3,10) / -1.68248023D+02 , -1.68252847D+02 /
      data f( 3,11),f( 3,12) / -1.68260365D+02 , -1.68271303D+02 /
      data f( 3,13),f( 3,14) / -1.68286976D+02 , -1.68308899D+02 /
      data f( 3,15),f( 3,16) / -1.68337600D+02 , -1.68369852D+02 /
      data f( 3,17),f( 3,18) / -1.68396722D+02 , -1.68410737D+02 /
      data f( 3,19),f( 3,20) / -1.68410737D+02 , -1.68396722D+02 /
      data f( 3,21),f( 3,22) / -1.68369852D+02 , -1.68337600D+02 /
      data f( 3,23),f( 3,24) / -1.68308899D+02 , -1.68286976D+02 /
      data f( 3,25),f( 3,26) / -1.68271303D+02 , -1.68260365D+02 /
      data f( 3,27),f( 3,28) / -1.68252847D+02 , -1.68248023D+02 /
      data f( 3,29),f( 3,30) / -1.68246030D+02 , -1.68248168D+02 /
      data f( 3,31),f( 3,32) / -1.68256715D+02 , -1.68272516D+02 /
      data f( 3,33),f( 3,34) / -1.68291326D+02 , -1.68304834D+02 /
      data f( 3,35),f( 3,36) / -1.68308287D+02 , -1.68307394D+02 /
      data f( 3,37),f( 3,38) / -1.68308287D+02 , -1.68304834D+02 /
      data f( 3,39),f( 3,40) / -1.68291326D+02 , -1.68272516D+02 /
      data f( 3,41),f( 3,42) / -1.68256715D+02 , -1.68248168D+02 /
      data f( 3,43),f( 3,44) / -1.68246030D+02 , -1.68248023D+02 /
      data f( 3,45),f( 3,46) / -1.68252847D+02 , -1.68260365D+02 /
      data f( 3,47),f( 3,48) / -1.68271303D+02 , -1.68286976D+02 /
      data f( 3,49),f( 3,50) / -1.68308899D+02 , -1.68337600D+02 /
      data f( 3,51),f( 3,52) / -1.68369852D+02 , -1.68396722D+02 /
      data f( 3,53),f( 3,54) / -1.68410737D+02 , -1.68412689D+02 /
      data f( 4, 1),f( 4, 2) / -1.68281598D+02 , -1.68283402D+02 /
      data f( 4, 3),f( 4, 4) / -1.68283548D+02 , -1.68276364D+02 /
      data f( 4, 5),f( 4, 6) / -1.68264928D+02 , -1.68255112D+02 /
      data f( 4, 7),f( 4, 8) / -1.68249677D+02 , -1.68248253D+02 /
      data f( 4, 9),f( 4,10) / -1.68249650D+02 , -1.68253180D+02 /
      data f( 4,11),f( 4,12) / -1.68258878D+02 , -1.68267408D+02 /
      data f( 4,13),f( 4,14) / -1.68279882D+02 , -1.68297582D+02 /
      data f( 4,15),f( 4,16) / -1.68321162D+02 , -1.68348695D+02 /
      data f( 4,17),f( 4,18) / -1.68373797D+02 , -1.68389017D+02 /
      data f( 4,19),f( 4,20) / -1.68389017D+02 , -1.68373797D+02 /
      data f( 4,21),f( 4,22) / -1.68348695D+02 , -1.68321162D+02 /
      data f( 4,23),f( 4,24) / -1.68297582D+02 , -1.68279882D+02 /
      data f( 4,25),f( 4,26) / -1.68267408D+02 , -1.68258878D+02 /
      data f( 4,27),f( 4,28) / -1.68253180D+02 , -1.68249650D+02 /
      data f( 4,29),f( 4,30) / -1.68248253D+02 , -1.68249677D+02 /
      data f( 4,31),f( 4,32) / -1.68255112D+02 , -1.68264928D+02 /
      data f( 4,33),f( 4,34) / -1.68276364D+02 , -1.68283548D+02 /
      data f( 4,35),f( 4,36) / -1.68283402D+02 , -1.68281598D+02 /
      data f( 4,37),f( 4,38) / -1.68283402D+02 , -1.68283548D+02 /
      data f( 4,39),f( 4,40) / -1.68276364D+02 , -1.68264928D+02 /
      data f( 4,41),f( 4,42) / -1.68255112D+02 , -1.68249677D+02 /
      data f( 4,43),f( 4,44) / -1.68248253D+02 , -1.68249650D+02 /
      data f( 4,45),f( 4,46) / -1.68253180D+02 , -1.68258878D+02 /
      data f( 4,47),f( 4,48) / -1.68267408D+02 , -1.68279882D+02 /
      data f( 4,49),f( 4,50) / -1.68297582D+02 , -1.68321162D+02 /
      data f( 4,51),f( 4,52) / -1.68348695D+02 , -1.68373797D+02 /
      data f( 4,53),f( 4,54) / -1.68389017D+02 , -1.68393160D+02 /
      data f( 5, 1),f( 5, 2) / -1.68254435D+02 , -1.68259544D+02 /
      data f( 5, 3),f( 5, 4) / -1.68266078D+02 , -1.68265603D+02 /
      data f( 5, 5),f( 5, 6) / -1.68260103D+02 , -1.68254347D+02 /
      data f( 5, 7),f( 5, 8) / -1.68250868D+02 , -1.68249892D+02 /
      data f( 5, 9),f( 5,10) / -1.68250872D+02 , -1.68253453D+02 /
      data f( 5,11),f( 5,12) / -1.68257738D+02 , -1.68264290D+02 /
      data f( 5,13),f( 5,14) / -1.68274003D+02 , -1.68287857D+02 /
      data f( 5,15),f( 5,16) / -1.68306388D+02 , -1.68328505D+02 /
      data f( 5,17),f( 5,18) / -1.68349878D+02 , -1.68364404D+02 /
      data f( 5,19),f( 5,20) / -1.68364404D+02 , -1.68349878D+02 /
      data f( 5,21),f( 5,22) / -1.68328505D+02 , -1.68306388D+02 /
      data f( 5,23),f( 5,24) / -1.68287857D+02 , -1.68274003D+02 /
      data f( 5,25),f( 5,26) / -1.68264290D+02 , -1.68257738D+02 /
      data f( 5,27),f( 5,28) / -1.68253453D+02 , -1.68250872D+02 /
      data f( 5,29),f( 5,30) / -1.68249892D+02 , -1.68250868D+02 /
      data f( 5,31),f( 5,32) / -1.68254347D+02 , -1.68260103D+02 /
      data f( 5,33),f( 5,34) / -1.68265603D+02 , -1.68266078D+02 /
      data f( 5,35),f( 5,36) / -1.68259544D+02 , -1.68254435D+02 /
      data f( 5,37),f( 5,38) / -1.68259544D+02 , -1.68266078D+02 /
      data f( 5,39),f( 5,40) / -1.68265603D+02 , -1.68260103D+02 /
      data f( 5,41),f( 5,42) / -1.68254347D+02 , -1.68250868D+02 /
      data f( 5,43),f( 5,44) / -1.68249892D+02 , -1.68250872D+02 /
      data f( 5,45),f( 5,46) / -1.68253453D+02 , -1.68257738D+02 /
      data f( 5,47),f( 5,48) / -1.68264290D+02 , -1.68274003D+02 /
      data f( 5,49),f( 5,50) / -1.68287857D+02 , -1.68306388D+02 /
      data f( 5,51),f( 5,52) / -1.68328505D+02 , -1.68349878D+02 /
      data f( 5,53),f( 5,54) / -1.68364404D+02 , -1.68369142D+02 /
      data f( 6, 1),f( 6, 2) / -1.68209637D+02 , -1.68240295D+02 /
      data f( 6, 3),f( 6, 4) / -1.68254623D+02 , -1.68259017D+02 /
      data f( 6, 5),f( 6, 6) / -1.68257283D+02 , -1.68254031D+02 /
      data f( 6, 7),f( 6, 8) / -1.68251775D+02 , -1.68251087D+02 /
      data f( 6, 9),f( 6,10) / -1.68251773D+02 , -1.68253657D+02 /
      data f( 6,11),f( 6,12) / -1.68256859D+02 , -1.68261832D+02 /
      data f( 6,13),f( 6,14) / -1.68269258D+02 , -1.68279799D+02 /
      data f( 6,15),f( 6,16) / -1.68293695D+02 , -1.68310178D+02 /
      data f( 6,17),f( 6,18) / -1.68326630D+02 , -1.68338664D+02 /
      data f( 6,19),f( 6,20) / -1.68338664D+02 , -1.68326630D+02 /
      data f( 6,21),f( 6,22) / -1.68310178D+02 , -1.68293695D+02 /
      data f( 6,23),f( 6,24) / -1.68279799D+02 , -1.68269258D+02 /
      data f( 6,25),f( 6,26) / -1.68261832D+02 , -1.68256859D+02 /
      data f( 6,27),f( 6,28) / -1.68253657D+02 , -1.68251773D+02 /
      data f( 6,29),f( 6,30) / -1.68251087D+02 , -1.68251775D+02 /
      data f( 6,31),f( 6,32) / -1.68254031D+02 , -1.68257283D+02 /
      data f( 6,33),f( 6,34) / -1.68259017D+02 , -1.68254623D+02 /
      data f( 6,35),f( 6,36) / -1.68240295D+02 , -1.68209637D+02 /
      data f( 6,37),f( 6,38) / -1.68240295D+02 , -1.68254623D+02 /
      data f( 6,39),f( 6,40) / -1.68259017D+02 , -1.68257283D+02 /
      data f( 6,41),f( 6,42) / -1.68254031D+02 , -1.68251775D+02 /
      data f( 6,43),f( 6,44) / -1.68251087D+02 , -1.68251773D+02 /
      data f( 6,45),f( 6,46) / -1.68253657D+02 , -1.68256859D+02 /
      data f( 6,47),f( 6,48) / -1.68261832D+02 , -1.68269258D+02 /
      data f( 6,49),f( 6,50) / -1.68279799D+02 , -1.68293695D+02 /
      data f( 6,51),f( 6,52) / -1.68310178D+02 , -1.68326630D+02 /
      data f( 6,53),f( 6,54) / -1.68338664D+02 , -1.68342866D+02 /
      data f( 7, 1),f( 7, 2) / -1.68220990D+02 , -1.68234581D+02 /
      data f( 7, 3),f( 7, 4) / -1.68249527D+02 , -1.68255566D+02 /
      data f( 7, 5),f( 7, 6) / -1.68255730D+02 , -1.68253936D+02 /
      data f( 7, 7),f( 7, 8) / -1.68252446D+02 , -1.68251947D+02 /
      data f( 7, 9),f( 7,10) / -1.68252424D+02 , -1.68253797D+02 /
      data f( 7,11),f( 7,12) / -1.68256178D+02 , -1.68259918D+02 /
      data f( 7,13),f( 7,14) / -1.68265513D+02 , -1.68273344D+02 /
      data f( 7,15),f( 7,16) / -1.68283289D+02 , -1.68294431D+02 /
      data f( 7,17),f( 7,18) / -1.68305199D+02 , -1.68313477D+02 /
      data f( 7,19),f( 7,20) / -1.68313477D+02 , -1.68305199D+02 /
      data f( 7,21),f( 7,22) / -1.68294431D+02 , -1.68283289D+02 /
      data f( 7,23),f( 7,24) / -1.68273344D+02 , -1.68265513D+02 /
      data f( 7,25),f( 7,26) / -1.68259918D+02 , -1.68256178D+02 /
      data f( 7,27),f( 7,28) / -1.68253797D+02 , -1.68252424D+02 /
      data f( 7,29),f( 7,30) / -1.68251947D+02 , -1.68252446D+02 /
      data f( 7,31),f( 7,32) / -1.68253936D+02 , -1.68255730D+02 /
      data f( 7,33),f( 7,34) / -1.68255566D+02 , -1.68249527D+02 /
      data f( 7,35),f( 7,36) / -1.68234581D+02 , -1.68220990D+02 /
      data f( 7,37),f( 7,38) / -1.68234581D+02 , -1.68249527D+02 /
      data f( 7,39),f( 7,40) / -1.68255566D+02 , -1.68255730D+02 /
      data f( 7,41),f( 7,42) / -1.68253936D+02 , -1.68252446D+02 /
      data f( 7,43),f( 7,44) / -1.68251947D+02 , -1.68252424D+02 /
      data f( 7,45),f( 7,46) / -1.68253797D+02 , -1.68256178D+02 /
      data f( 7,47),f( 7,48) / -1.68259918D+02 , -1.68265513D+02 /
      data f( 7,49),f( 7,50) / -1.68273344D+02 , -1.68283289D+02 /
      data f( 7,51),f( 7,52) / -1.68294431D+02 , -1.68305199D+02 /
      data f( 7,53),f( 7,54) / -1.68313477D+02 , -1.68315608D+02 /
      data f( 8, 1),f( 8, 2) / -1.68236285D+02 , -1.68240934D+02 /
      data f( 8, 3),f( 8, 4) / -1.68248792D+02 , -1.68253412D+02 /
      data f( 8, 5),f( 8, 6) / -1.68254496D+02 , -1.68253962D+02 /
      data f( 8, 7),f( 8, 8) / -1.68253266D+02 , -1.68252983D+02 /
      data f( 8, 9),f( 8,10) / -1.68253206D+02 , -1.68253932D+02 /
      data f( 8,11),f( 8,12) / -1.68255234D+02 , -1.68257307D+02 /
      data f( 8,13),f( 8,14) / -1.68260388D+02 , -1.68264501D+02 /
      data f( 8,15),f( 8,16) / -1.68269030D+02 , -1.68272365D+02 /
      data f( 8,17),f( 8,18) / -1.68272232D+02 , -1.68267869D+02 /
      data f( 8,19),f( 8,20) / -1.68267869D+02 , -1.68272232D+02 /
      data f( 8,21),f( 8,22) / -1.68272365D+02 , -1.68269030D+02 /
      data f( 8,23),f( 8,24) / -1.68264501D+02 , -1.68260388D+02 /
      data f( 8,25),f( 8,26) / -1.68257307D+02 , -1.68255234D+02 /
      data f( 8,27),f( 8,28) / -1.68253932D+02 , -1.68253206D+02 /
      data f( 8,29),f( 8,30) / -1.68252983D+02 , -1.68253266D+02 /
      data f( 8,31),f( 8,32) / -1.68253962D+02 , -1.68254496D+02 /
      data f( 8,33),f( 8,34) / -1.68253412D+02 , -1.68248792D+02 /
      data f( 8,35),f( 8,36) / -1.68240934D+02 , -1.68236285D+02 /
      data f( 8,37),f( 8,38) / -1.68240934D+02 , -1.68248792D+02 /
      data f( 8,39),f( 8,40) / -1.68253412D+02 , -1.68254496D+02 /
      data f( 8,41),f( 8,42) / -1.68253962D+02 , -1.68253266D+02 /
      data f( 8,43),f( 8,44) / -1.68252983D+02 , -1.68253206D+02 /
      data f( 8,45),f( 8,46) / -1.68253932D+02 , -1.68255234D+02 /
      data f( 8,47),f( 8,48) / -1.68257307D+02 , -1.68260388D+02 /
      data f( 8,49),f( 8,50) / -1.68264501D+02 , -1.68269030D+02 /
      data f( 8,51),f( 8,52) / -1.68272365D+02 , -1.68272232D+02 /
      data f( 8,53),f( 8,54) / -1.68267869D+02 , -1.68226673D+02 /
      data f( 9, 1),f( 9, 2) / -1.68244861D+02 , -1.68246878D+02 /
      data f( 9, 3),f( 9, 4) / -1.68250722D+02 , -1.68253364D+02 /
      data f( 9, 5),f( 9, 6) / -1.68254180D+02 , -1.68254003D+02 /
      data f( 9, 7),f( 9, 8) / -1.68253644D+02 , -1.68253471D+02 /
      data f( 9, 9),f( 9,10) / -1.68253569D+02 , -1.68253949D+02 /
      data f( 9,11),f( 9,12) / -1.68254654D+02 , -1.68255783D+02 /
      data f( 9,13),f( 9,14) / -1.68257442D+02 , -1.68259535D+02 /
      data f( 9,15),f( 9,16) / -1.68261414D+02 , -1.68261557D+02 /
      data f( 9,17),f( 9,18) / -1.68257699D+02 , -1.68248014D+02 /
      data f( 9,19),f( 9,20) / -1.68248014D+02 , -1.68257699D+02 /
      data f( 9,21),f( 9,22) / -1.68261557D+02 , -1.68261414D+02 /
      data f( 9,23),f( 9,24) / -1.68259535D+02 , -1.68257442D+02 /
      data f( 9,25),f( 9,26) / -1.68255783D+02 , -1.68254654D+02 /
      data f( 9,27),f( 9,28) / -1.68253949D+02 , -1.68253569D+02 /
      data f( 9,29),f( 9,30) / -1.68253471D+02 , -1.68253644D+02 /
      data f( 9,31),f( 9,32) / -1.68254003D+02 , -1.68254180D+02 /
      data f( 9,33),f( 9,34) / -1.68253364D+02 , -1.68250722D+02 /
      data f( 9,35),f( 9,36) / -1.68246878D+02 , -1.68244861D+02 /
      data f( 9,37),f( 9,38) / -1.68246878D+02 , -1.68250722D+02 /
      data f( 9,39),f( 9,40) / -1.68253364D+02 , -1.68254180D+02 /
      data f( 9,41),f( 9,42) / -1.68254003D+02 , -1.68253644D+02 /
      data f( 9,43),f( 9,44) / -1.68253471D+02 , -1.68253569D+02 /
      data f( 9,45),f( 9,46) / -1.68253949D+02 , -1.68254654D+02 /
      data f( 9,47),f( 9,48) / -1.68255783D+02 , -1.68257442D+02 /
      data f( 9,49),f( 9,50) / -1.68259535D+02 , -1.68261414D+02 /
      data f( 9,51),f( 9,52) / -1.68261557D+02 , -1.68257699D+02 /
      data f( 9,53),f( 9,54) / -1.68248014D+02 , -1.68238618D+02 /
      data f(10, 1),f(10, 2) / -1.68250243D+02 , -1.68250997D+02 /
      data f(10, 3),f(10, 4) / -1.68252532D+02 , -1.68253672D+02 /
      data f(10, 5),f(10, 6) / -1.68254056D+02 , -1.68253980D+02 /
      data f(10, 7),f(10, 8) / -1.68253802D+02 , -1.68253703D+02 /
      data f(10, 9),f(10,10) / -1.68253733D+02 , -1.68253899D+02 /
      data f(10,11),f(10,12) / -1.68254224D+02 , -1.68254750D+02 /
      data f(10,13),f(10,14) / -1.68255508D+02 , -1.68256408D+02 /
      data f(10,15),f(10,16) / -1.68257029D+02 , -1.68256496D+02 /
      data f(10,17),f(10,18) / -1.68253846D+02 , -1.68249440D+02 /
      data f(10,19),f(10,20) / -1.68249440D+02 , -1.68253846D+02 /
      data f(10,21),f(10,22) / -1.68256496D+02 , -1.68257029D+02 /
      data f(10,23),f(10,24) / -1.68256408D+02 , -1.68255508D+02 /
      data f(10,25),f(10,26) / -1.68254750D+02 , -1.68254224D+02 /
      data f(10,27),f(10,28) / -1.68253899D+02 , -1.68253733D+02 /
      data f(10,29),f(10,30) / -1.68253703D+02 , -1.68253802D+02 /
      data f(10,31),f(10,32) / -1.68253980D+02 , -1.68254056D+02 /
      data f(10,33),f(10,34) / -1.68253672D+02 , -1.68252532D+02 /
      data f(10,35),f(10,36) / -1.68250997D+02 , -1.68250243D+02 /
      data f(10,37),f(10,38) / -1.68250997D+02 , -1.68252532D+02 /
      data f(10,39),f(10,40) / -1.68253672D+02 , -1.68254056D+02 /
      data f(10,41),f(10,42) / -1.68253980D+02 , -1.68253802D+02 /
      data f(10,43),f(10,44) / -1.68253703D+02 , -1.68253733D+02 /
      data f(10,45),f(10,46) / -1.68253899D+02 , -1.68254224D+02 /
      data f(10,47),f(10,48) / -1.68254750D+02 , -1.68255508D+02 /
      data f(10,49),f(10,50) / -1.68256408D+02 , -1.68257029D+02 /
      data f(10,51),f(10,52) / -1.68256496D+02 , -1.68253846D+02 /
      data f(10,53),f(10,54) / -1.68249440D+02 , -1.68246965D+02 /
      data f(11, 1),f(11, 2) / -1.68252554D+02 , -1.68252815D+02 /
      data f(11, 3),f(11, 4) / -1.68253393D+02 , -1.68253830D+02 /
      data f(11, 5),f(11, 6) / -1.68253966D+02 , -1.68253909D+02 /
      data f(11, 7),f(11, 8) / -1.68253811D+02 , -1.68253752D+02 /
      data f(11, 9),f(11,10) / -1.68253757D+02 , -1.68253829D+02 /
      data f(11,11),f(11,12) / -1.68253979D+02 , -1.68254225D+02 /
      data f(11,13),f(11,14) / -1.68254575D+02 , -1.68254976D+02 /
      data f(11,15),f(11,16) / -1.68255210D+02 , -1.68254869D+02 /
      data f(11,17),f(11,18) / -1.68253607D+02 , -1.68251806D+02 /
      data f(11,19),f(11,20) / -1.68251806D+02 , -1.68253607D+02 /
      data f(11,21),f(11,22) / -1.68254869D+02 , -1.68255210D+02 /
      data f(11,23),f(11,24) / -1.68254976D+02 , -1.68254575D+02 /
      data f(11,25),f(11,26) / -1.68254225D+02 , -1.68253979D+02 /
      data f(11,27),f(11,28) / -1.68253829D+02 , -1.68253757D+02 /
      data f(11,29),f(11,30) / -1.68253752D+02 , -1.68253811D+02 /
      data f(11,31),f(11,32) / -1.68253909D+02 , -1.68253966D+02 /
      data f(11,33),f(11,34) / -1.68253830D+02 , -1.68253393D+02 /
      data f(11,35),f(11,36) / -1.68252815D+02 , -1.68252554D+02 /
      data f(11,37),f(11,38) / -1.68252815D+02 , -1.68253393D+02 /
      data f(11,39),f(11,40) / -1.68253830D+02 , -1.68253966D+02 /
      data f(11,41),f(11,42) / -1.68253909D+02 , -1.68253811D+02 /
      data f(11,43),f(11,44) / -1.68253752D+02 , -1.68253757D+02 /
      data f(11,45),f(11,46) / -1.68253829D+02 , -1.68253979D+02 /
      data f(11,47),f(11,48) / -1.68254225D+02 , -1.68254575D+02 /
      data f(11,49),f(11,50) / -1.68254976D+02 , -1.68255210D+02 /
      data f(11,51),f(11,52) / -1.68254869D+02 , -1.68253607D+02 /
      data f(11,53),f(11,54) / -1.68251806D+02 , -1.68250937D+02 /
      data f(12, 1),f(12, 2) / -1.68253731D+02 , -1.68253728D+02 /
      data f(12, 3),f(12, 4) / -1.68253781D+02 , -1.68253812D+02 /
      data f(12, 5),f(12, 6) / -1.68253802D+02 , -1.68253767D+02 /
      data f(12, 7),f(12, 8) / -1.68253731D+02 , -1.68253707D+02 /
      data f(12, 9),f(12,10) / -1.68253701D+02 , -1.68253712D+02 /
      data f(12,11),f(12,12) / -1.68253745D+02 , -1.68253803D+02 /
      data f(12,13),f(12,14) / -1.68253886D+02 , -1.68253984D+02 /
      data f(12,15),f(12,16) / -1.68254055D+02 , -1.68254023D+02 /
      data f(12,17),f(12,18) / -1.68253834D+02 , -1.68253568D+02 /
      data f(12,19),f(12,20) / -1.68253568D+02 , -1.68253834D+02 /
      data f(12,21),f(12,22) / -1.68254023D+02 , -1.68254055D+02 /
      data f(12,23),f(12,24) / -1.68253984D+02 , -1.68253886D+02 /
      data f(12,25),f(12,26) / -1.68253803D+02 , -1.68253745D+02 /
      data f(12,27),f(12,28) / -1.68253712D+02 , -1.68253701D+02 /
      data f(12,29),f(12,30) / -1.68253707D+02 , -1.68253731D+02 /
      data f(12,31),f(12,32) / -1.68253767D+02 , -1.68253802D+02 /
      data f(12,33),f(12,34) / -1.68253812D+02 , -1.68253781D+02 /
      data f(12,35),f(12,36) / -1.68253728D+02 , -1.68253731D+02 /
      data f(12,37),f(12,38) / -1.68253728D+02 , -1.68253781D+02 /
      data f(12,39),f(12,40) / -1.68253812D+02 , -1.68253802D+02 /
      data f(12,41),f(12,42) / -1.68253767D+02 , -1.68253731D+02 /
      data f(12,43),f(12,44) / -1.68253707D+02 , -1.68253701D+02 /
      data f(12,45),f(12,46) / -1.68253712D+02 , -1.68253745D+02 /
      data f(12,47),f(12,48) / -1.68253803D+02 , -1.68253886D+02 /
      data f(12,49),f(12,50) / -1.68253984D+02 , -1.68254055D+02 /
      data f(12,51),f(12,52) / -1.68254023D+02 , -1.68253834D+02 /
      data f(12,53),f(12,54) / -1.68253568D+02 , -1.68253471D+02 /
      data f(13, 1),f(13, 2) / -1.68253752D+02 , -1.68253732D+02 /
      data f(13, 3),f(13, 4) / -1.68253727D+02 , -1.68253717D+02 /
      data f(13, 5),f(13, 6) / -1.68253699D+02 , -1.68253680D+02 /
      data f(13, 7),f(13, 8) / -1.68253663D+02 , -1.68253651D+02 /
      data f(13, 9),f(13,10) / -1.68253647D+02 , -1.68253649D+02 /
      data f(13,11),f(13,12) / -1.68253657D+02 , -1.68253673D+02 /
      data f(13,13),f(13,14) / -1.68253699D+02 , -1.68253733D+02 /
      data f(13,15),f(13,16) / -1.68253769D+02 , -1.68253793D+02 /
      data f(13,17),f(13,18) / -1.68253789D+02 , -1.68253766D+02 /
      data f(13,19),f(13,20) / -1.68253766D+02 , -1.68253789D+02 /
      data f(13,21),f(13,22) / -1.68253793D+02 , -1.68253769D+02 /
      data f(13,23),f(13,24) / -1.68253733D+02 , -1.68253699D+02 /
      data f(13,25),f(13,26) / -1.68253673D+02 , -1.68253657D+02 /
      data f(13,27),f(13,28) / -1.68253649D+02 , -1.68253647D+02 /
      data f(13,29),f(13,30) / -1.68253651D+02 , -1.68253663D+02 /
      data f(13,31),f(13,32) / -1.68253680D+02 , -1.68253699D+02 /
      data f(13,33),f(13,34) / -1.68253717D+02 , -1.68253727D+02 /
      data f(13,35),f(13,36) / -1.68253732D+02 , -1.68253752D+02 /
      data f(13,37),f(13,38) / -1.68253732D+02 , -1.68253727D+02 /
      data f(13,39),f(13,40) / -1.68253717D+02 , -1.68253699D+02 /
      data f(13,41),f(13,42) / -1.68253680D+02 , -1.68253663D+02 /
      data f(13,43),f(13,44) / -1.68253651D+02 , -1.68253647D+02 /
      data f(13,45),f(13,46) / -1.68253649D+02 , -1.68253657D+02 /
      data f(13,47),f(13,48) / -1.68253673D+02 , -1.68253699D+02 /
      data f(13,49),f(13,50) / -1.68253733D+02 , -1.68253769D+02 /
      data f(13,51),f(13,52) / -1.68253793D+02 , -1.68253789D+02 /
      data f(13,53),f(13,54) / -1.68253766D+02 , -1.68253782D+02 /
      data f(14, 1),f(14, 2) / -1.68253699D+02 , -1.68253677D+02 /
      data f(14, 3),f(14, 4) / -1.68253668D+02 , -1.68253656D+02 /
      data f(14, 5),f(14, 6) / -1.68253644D+02 , -1.68253633D+02 /
      data f(14, 7),f(14, 8) / -1.68253625D+02 , -1.68253620D+02 /
      data f(14, 9),f(14,10) / -1.68253618D+02 , -1.68253618D+02 /
      data f(14,11),f(14,12) / -1.68253622D+02 , -1.68253628D+02 /
      data f(14,13),f(14,14) / -1.68253638D+02 , -1.68253651D+02 /
      data f(14,15),f(14,16) / -1.68253669D+02 , -1.68253688D+02 /
      data f(14,17),f(14,18) / -1.68253703D+02 , -1.68253709D+02 /
      data f(14,19),f(14,20) / -1.68253709D+02 , -1.68253703D+02 /
      data f(14,21),f(14,22) / -1.68253688D+02 , -1.68253669D+02 /
      data f(14,23),f(14,24) / -1.68253651D+02 , -1.68253638D+02 /
      data f(14,25),f(14,26) / -1.68253628D+02 , -1.68253622D+02 /
      data f(14,27),f(14,28) / -1.68253618D+02 , -1.68253618D+02 /
      data f(14,29),f(14,30) / -1.68253620D+02 , -1.68253625D+02 /
      data f(14,31),f(14,32) / -1.68253633D+02 , -1.68253644D+02 /
      data f(14,33),f(14,34) / -1.68253656D+02 , -1.68253668D+02 /
      data f(14,35),f(14,36) / -1.68253677D+02 , -1.68253699D+02 /
      data f(14,37),f(14,38) / -1.68253677D+02 , -1.68253668D+02 /
      data f(14,39),f(14,40) / -1.68253656D+02 , -1.68253644D+02 /
      data f(14,41),f(14,42) / -1.68253633D+02 , -1.68253625D+02 /
      data f(14,43),f(14,44) / -1.68253620D+02 , -1.68253618D+02 /
      data f(14,45),f(14,46) / -1.68253618D+02 , -1.68253622D+02 /
      data f(14,47),f(14,48) / -1.68253628D+02 , -1.68253638D+02 /
      data f(14,49),f(14,50) / -1.68253651D+02 , -1.68253669D+02 /
      data f(14,51),f(14,52) / -1.68253688D+02 , -1.68253703D+02 /
      data f(14,53),f(14,54) / -1.68253709D+02 , -1.68253728D+02 /
      data f(15, 1),f(15, 2) / -1.68253637D+02 , -1.68253617D+02 /
      data f(15, 3),f(15, 4) / -1.68253612D+02 , -1.68253606D+02 /
      data f(15, 5),f(15, 6) / -1.68253602D+02 , -1.68253599D+02 /
      data f(15, 7),f(15, 8) / -1.68253597D+02 , -1.68253596D+02 /
      data f(15, 9),f(15,10) / -1.68253596D+02 , -1.68253596D+02 /
      data f(15,11),f(15,12) / -1.68253596D+02 , -1.68253597D+02 /
      data f(15,13),f(15,14) / -1.68253600D+02 , -1.68253604D+02 /
      data f(15,15),f(15,16) / -1.68253611D+02 , -1.68253619D+02 /
      data f(15,17),f(15,18) / -1.68253628D+02 , -1.68253635D+02 /
      data f(15,19),f(15,20) / -1.68253635D+02 , -1.68253628D+02 /
      data f(15,21),f(15,22) / -1.68253619D+02 , -1.68253611D+02 /
      data f(15,23),f(15,24) / -1.68253604D+02 , -1.68253600D+02 /
      data f(15,25),f(15,26) / -1.68253597D+02 , -1.68253596D+02 /
      data f(15,27),f(15,28) / -1.68253596D+02 , -1.68253596D+02 /
      data f(15,29),f(15,30) / -1.68253596D+02 , -1.68253597D+02 /
      data f(15,31),f(15,32) / -1.68253599D+02 , -1.68253602D+02 /
      data f(15,33),f(15,34) / -1.68253606D+02 , -1.68253612D+02 /
      data f(15,35),f(15,36) / -1.68253617D+02 , -1.68253637D+02 /
      data f(15,37),f(15,38) / -1.68253617D+02 , -1.68253612D+02 /
      data f(15,39),f(15,40) / -1.68253606D+02 , -1.68253602D+02 /
      data f(15,41),f(15,42) / -1.68253599D+02 , -1.68253597D+02 /
      data f(15,43),f(15,44) / -1.68253596D+02 , -1.68253596D+02 /
      data f(15,45),f(15,46) / -1.68253596D+02 , -1.68253596D+02 /
      data f(15,47),f(15,48) / -1.68253597D+02 , -1.68253600D+02 /
      data f(15,49),f(15,50) / -1.68253604D+02 , -1.68253611D+02 /
      data f(15,51),f(15,52) / -1.68253619D+02 , -1.68253628D+02 /
      data f(15,53),f(15,54) / -1.68253635D+02 , -1.68253657D+02 /
      data f(16, 1),f(16, 2) / -1.68253609D+02 , -1.68253590D+02 /
      data f(16, 3),f(16, 4) / -1.68253589D+02 , -1.68253589D+02 /
      data f(16, 5),f(16, 6) / -1.68253588D+02 , -1.68253587D+02 /
      data f(16, 7),f(16, 8) / -1.68253587D+02 , -1.68253587D+02 /
      data f(16, 9),f(16,10) / -1.68253587D+02 , -1.68253587D+02 /
      data f(16,11),f(16,12) / -1.68253587D+02 , -1.68253587D+02 /
      data f(16,13),f(16,14) / -1.68253588D+02 , -1.68253588D+02 /
      data f(16,15),f(16,16) / -1.68253590D+02 , -1.68253592D+02 /
      data f(16,17),f(16,18) / -1.68253593D+02 , -1.68253595D+02 /
      data f(16,19),f(16,20) / -1.68253595D+02 , -1.68253593D+02 /
      data f(16,21),f(16,22) / -1.68253592D+02 , -1.68253590D+02 /
      data f(16,23),f(16,24) / -1.68253588D+02 , -1.68253588D+02 /
      data f(16,25),f(16,26) / -1.68253587D+02 , -1.68253587D+02 /
      data f(16,27),f(16,28) / -1.68253587D+02 , -1.68253587D+02 /
      data f(16,29),f(16,30) / -1.68253587D+02 , -1.68253587D+02 /
      data f(16,31),f(16,32) / -1.68253587D+02 , -1.68253588D+02 /
      data f(16,33),f(16,34) / -1.68253589D+02 , -1.68253589D+02 /
      data f(16,35),f(16,36) / -1.68253590D+02 , -1.68253609D+02 /
      data f(16,37),f(16,38) / -1.68253590D+02 , -1.68253589D+02 /
      data f(16,39),f(16,40) / -1.68253589D+02 , -1.68253588D+02 /
      data f(16,41),f(16,42) / -1.68253587D+02 , -1.68253587D+02 /
      data f(16,43),f(16,44) / -1.68253587D+02 , -1.68253587D+02 /
      data f(16,45),f(16,46) / -1.68253587D+02 , -1.68253587D+02 /
      data f(16,47),f(16,48) / -1.68253587D+02 , -1.68253588D+02 /
      data f(16,49),f(16,50) / -1.68253588D+02 , -1.68253590D+02 /
      data f(16,51),f(16,52) / -1.68253592D+02 , -1.68253593D+02 /
      data f(16,53),f(16,54) / -1.68253595D+02 , -1.68253615D+02 /
      data f(17, 1),f(17, 2) / -1.68253604D+02 , -1.68253584D+02 /
      data f(17, 3),f(17, 4) / -1.68253584D+02 , -1.68253584D+02 /
      data f(17, 5),f(17, 6) / -1.68253584D+02 , -1.68253584D+02 /
      data f(17, 7),f(17, 8) / -1.68253584D+02 , -1.68253584D+02 /
      data f(17, 9),f(17,10) / -1.68253584D+02 , -1.68253584D+02 /
      data f(17,11),f(17,12) / -1.68253584D+02 , -1.68253584D+02 /
      data f(17,13),f(17,14) / -1.68253584D+02 , -1.68253584D+02 /
      data f(17,15),f(17,16) / -1.68253584D+02 , -1.68253584D+02 /
      data f(17,17),f(17,18) / -1.68253585D+02 , -1.68253585D+02 /
      data f(17,19),f(17,20) / -1.68253585D+02 , -1.68253585D+02 /
      data f(17,21),f(17,22) / -1.68253584D+02 , -1.68253584D+02 /
      data f(17,23),f(17,24) / -1.68253584D+02 , -1.68253584D+02 /
      data f(17,25),f(17,26) / -1.68253584D+02 , -1.68253584D+02 /
      data f(17,27),f(17,28) / -1.68253584D+02 , -1.68253584D+02 /
      data f(17,29),f(17,30) / -1.68253584D+02 , -1.68253584D+02 /
      data f(17,31),f(17,32) / -1.68253584D+02 , -1.68253584D+02 /
      data f(17,33),f(17,34) / -1.68253584D+02 , -1.68253584D+02 /
      data f(17,35),f(17,36) / -1.68253584D+02 , -1.68253604D+02 /
      data f(17,37),f(17,38) / -1.68253584D+02 , -1.68253584D+02 /
      data f(17,39),f(17,40) / -1.68253584D+02 , -1.68253584D+02 /
      data f(17,41),f(17,42) / -1.68253584D+02 , -1.68253584D+02 /
      data f(17,43),f(17,44) / -1.68253584D+02 , -1.68253584D+02 /
      data f(17,45),f(17,46) / -1.68253584D+02 , -1.68253584D+02 /
      data f(17,47),f(17,48) / -1.68253584D+02 , -1.68253584D+02 /
      data f(17,49),f(17,50) / -1.68253584D+02 , -1.68253584D+02 /
      data f(17,51),f(17,52) / -1.68253584D+02 , -1.68253585D+02 /
      data f(17,53),f(17,54) / -1.68253585D+02 , -1.68253605D+02 /
 
      data fpp( 1, 1,1),fpp( 1, 1,2)/ 5.25760057D-01,-1.30104846D-04/
      data fpp( 1, 2,1),fpp( 1, 2,2)/ 3.73107766D-01, 2.02766930D-05/
      data fpp( 1, 3,1),fpp( 1, 3,2)/ 1.46436113D-01, 2.90528075D-04/
      data fpp( 1, 4,1),fpp( 1, 4,2)/ 8.62131593D-03, 1.41235009D-04/
      data fpp( 1, 5,1),fpp( 1, 5,2)/-5.98673458D-02,-1.09681102D-05/
      data fpp( 1, 6,1),fpp( 1, 6,2)/-6.97655086D-02,-1.24752568D-04/
      data fpp( 1, 7,1),fpp( 1, 7,2)/-1.87412303D-03,-1.72143617D-04/
      data fpp( 1, 8,1),fpp( 1, 8,2)/ 2.98024399D-02,-9.00869646D-05/
      data fpp( 1, 9,1),fpp( 1, 9,2)/ 1.42934188D-02,-4.08865249D-05/
      data fpp( 1,10,1),fpp( 1,10,2)/-5.36633399D-03,-3.38749359D-05/
      data fpp( 1,11,1),fpp( 1,11,2)/-1.89060755D-02,-4.16417316D-05/
      data fpp( 1,12,1),fpp( 1,12,2)/-2.55764482D-02,-5.92141377D-05/
      data fpp( 1,13,1),fpp( 1,13,2)/-2.50488120D-02,-7.81057177D-05/
      data fpp( 1,14,1),fpp( 1,14,2)/-1.48552924D-02,-8.73689915D-05/
      data fpp( 1,15,1),fpp( 1,15,2)/ 1.35596768D-02, 2.04368363D-06/
      data fpp( 1,16,1),fpp( 1,16,2)/ 9.02549644D-02, 1.22388257D-04/
      data fpp( 1,17,1),fpp( 1,17,2)/ 1.98102674D-01, 5.30485289D-04/
      data fpp( 1,18,1),fpp( 1,18,2)/ 6.65193009D-01,-1.75835411D-04/
      data fpp( 1,19,1),fpp( 1,19,2)/ 6.65193009D-01,-1.75835411D-04/
      data fpp( 1,20,1),fpp( 1,20,2)/ 1.98102674D-01, 5.30485288D-04/
      data fpp( 1,21,1),fpp( 1,21,2)/ 9.02549644D-02, 1.22388257D-04/
      data fpp( 1,22,1),fpp( 1,22,2)/ 1.35596768D-02, 2.04368230D-06/
      data fpp( 1,23,1),fpp( 1,23,2)/-1.48552924D-02,-8.73689865D-05/
      data fpp( 1,24,1),fpp( 1,24,2)/-2.50488120D-02,-7.81057363D-05/
      data fpp( 1,25,1),fpp( 1,25,2)/-2.55764482D-02,-5.92140684D-05/
      data fpp( 1,26,1),fpp( 1,26,2)/-1.89060755D-02,-4.16419901D-05/
      data fpp( 1,27,1),fpp( 1,27,2)/-5.36633399D-03,-3.38739713D-05/
      data fpp( 1,28,1),fpp( 1,28,2)/ 1.42934188D-02,-4.08901247D-05/
      data fpp( 1,29,1),fpp( 1,29,2)/ 2.98024399D-02,-9.00735300D-05/
      data fpp( 1,30,1),fpp( 1,30,2)/-1.87412303D-03,-1.72193755D-04/
      data fpp( 1,31,1),fpp( 1,31,2)/-6.97655086D-02,-1.24565448D-04/
      data fpp( 1,32,1),fpp( 1,32,2)/-5.98673458D-02,-1.16664517D-05/
      data fpp( 1,33,1),fpp( 1,33,2)/ 8.62131593D-03, 1.43841255D-04/
      data fpp( 1,34,1),fpp( 1,34,2)/ 1.46436113D-01, 2.80801431D-04/
      data fpp( 1,35,1),fpp( 1,35,2)/ 3.73107766D-01, 5.65770196D-05/
      data fpp( 1,36,1),fpp( 1,36,2)/ 5.25760057D-01,-2.65579510D-04/
      data fpp( 1,37,1),fpp( 1,37,2)/ 3.73107766D-01, 5.65770197D-05/
      data fpp( 1,38,1),fpp( 1,38,2)/ 1.46436113D-01, 2.80801431D-04/
      data fpp( 1,39,1),fpp( 1,39,2)/ 8.62131593D-03, 1.43841257D-04/
      data fpp( 1,40,1),fpp( 1,40,2)/-5.98673458D-02,-1.16664574D-05/
      data fpp( 1,41,1),fpp( 1,41,2)/-6.97655086D-02,-1.24565427D-04/
      data fpp( 1,42,1),fpp( 1,42,2)/-1.87412303D-03,-1.72193835D-04/
      data fpp( 1,43,1),fpp( 1,43,2)/ 2.98024399D-02,-9.00732328D-05/
      data fpp( 1,44,1),fpp( 1,44,2)/ 1.42934188D-02,-4.08912336D-05/
      data fpp( 1,45,1),fpp( 1,45,2)/-5.36633399D-03,-3.38698329D-05/
      data fpp( 1,46,1),fpp( 1,46,2)/-1.89060755D-02,-4.16574348D-05/
      data fpp( 1,47,1),fpp( 1,47,2)/-2.55764482D-02,-5.91564281D-05/
      data fpp( 1,48,1),fpp( 1,48,2)/-2.50488120D-02,-7.83208530D-05/
      data fpp( 1,49,1),fpp( 1,49,2)/-1.48552924D-02,-8.65661600D-05/
      data fpp( 1,50,1),fpp( 1,50,2)/ 1.35596768D-02,-9.52506838D-07/
      data fpp( 1,51,1),fpp( 1,51,2)/ 9.02549644D-02, 1.33570187D-04/
      data fpp( 1,52,1),fpp( 1,52,2)/ 1.98102674D-01, 4.88753757D-04/
      data fpp( 1,53,1),fpp( 1,53,2)/ 6.65193009D-01,-2.00912164D-05/
      data fpp( 1,54,1),fpp( 1,54,2)/ 9.22486745D-01,-2.82070892D-04/
      data fpp( 2, 1,1),fpp( 2, 1,2)/ 3.01439885D-01,-3.19929066D-05/
      data fpp( 2, 2,1),fpp( 2, 2,2)/ 2.26601968D-01, 4.29598131D-05/
      data fpp( 2, 3,1),fpp( 2, 3,2)/ 6.16527734D-02, 1.87405654D-04/
      data fpp( 2, 4,1),fpp( 2, 4,2)/-3.37676318D-02, 8.86255708D-05/
      data fpp( 2, 5,1),fpp( 2, 5,2)/-6.73153085D-02,-3.40379373D-05/
      data fpp( 2, 6,1),fpp( 2, 6,2)/-5.28464828D-02,-1.16135821D-04/
      data fpp( 2, 7,1),fpp( 2, 7,2)/ 2.34324608D-03,-1.07514777D-04/
      data fpp( 2, 8,1),fpp( 2, 8,2)/ 2.44801202D-02,-5.74050712D-05/
      data fpp( 2, 9,1),fpp( 2, 9,2)/ 1.30981624D-02,-3.38989384D-05/
      data fpp( 2,10,1),fpp( 2,10,2)/-2.66983200D-03,-3.03131753D-05/
      data fpp( 2,11,1),fpp( 2,11,2)/-1.52803489D-02,-3.83243604D-05/
      data fpp( 2,12,1),fpp( 2,12,2)/-2.37296037D-02,-5.37493831D-05/
      data fpp( 2,13,1),fpp( 2,13,2)/-2.74548759D-02,-7.27001073D-05/
      data fpp( 2,14,1),fpp( 2,14,2)/-2.41119151D-02,-8.09941878D-05/
      data fpp( 2,15,1),fpp( 2,15,2)/-6.05435359D-03,-3.70631414D-05/
      data fpp( 2,16,1),fpp( 2,16,2)/ 4.91850712D-02, 1.00216753D-04/
      data fpp( 2,17,1),fpp( 2,17,2)/ 1.42279652D-01, 2.59938128D-04/
      data fpp( 2,18,1),fpp( 2,18,2)/ 4.59566482D-01, 1.29727340D-05/
      data fpp( 2,19,1),fpp( 2,19,2)/ 4.59566482D-01, 1.29727340D-05/
      data fpp( 2,20,1),fpp( 2,20,2)/ 1.42279652D-01, 2.59938128D-04/
      data fpp( 2,21,1),fpp( 2,21,2)/ 4.91850712D-02, 1.00216753D-04/
      data fpp( 2,22,1),fpp( 2,22,2)/-6.05435359D-03,-3.70631421D-05/
      data fpp( 2,23,1),fpp( 2,23,2)/-2.41119151D-02,-8.09941852D-05/
      data fpp( 2,24,1),fpp( 2,24,2)/-2.74548759D-02,-7.27001170D-05/
      data fpp( 2,25,1),fpp( 2,25,2)/-2.37296037D-02,-5.37493468D-05/
      data fpp( 2,26,1),fpp( 2,26,2)/-1.52803489D-02,-3.83244957D-05/
      data fpp( 2,27,1),fpp( 2,27,2)/-2.66983200D-03,-3.03126704D-05/
      data fpp( 2,28,1),fpp( 2,28,2)/ 1.30981624D-02,-3.39008227D-05/
      data fpp( 2,29,1),fpp( 2,29,2)/ 2.44801202D-02,-5.73980387D-05/
      data fpp( 2,30,1),fpp( 2,30,2)/ 2.34324608D-03,-1.07541023D-04/
      data fpp( 2,31,1),fpp( 2,31,2)/-5.28464828D-02,-1.16037871D-04/
      data fpp( 2,32,1),fpp( 2,32,2)/-6.73153085D-02,-3.44034931D-05/
      data fpp( 2,33,1),fpp( 2,33,2)/-3.37676318D-02, 8.99898435D-05/
      data fpp( 2,34,1),fpp( 2,34,2)/ 6.16527734D-02, 1.82314119D-04/
      data fpp( 2,35,1),fpp( 2,35,2)/ 2.26601968D-01, 6.19616803D-05/
      data fpp( 2,36,1),fpp( 2,36,2)/ 3.01439885D-01,-1.02908840D-04/
      data fpp( 2,37,1),fpp( 2,37,2)/ 2.26601968D-01, 6.19616803D-05/
      data fpp( 2,38,1),fpp( 2,38,2)/ 6.16527734D-02, 1.82314119D-04/
      data fpp( 2,39,1),fpp( 2,39,2)/-3.37676318D-02, 8.99898442D-05/
      data fpp( 2,40,1),fpp( 2,40,2)/-6.73153085D-02,-3.44034958D-05/
      data fpp( 2,41,1),fpp( 2,41,2)/-5.28464828D-02,-1.16037861D-04/
      data fpp( 2,42,1),fpp( 2,42,2)/ 2.34324608D-03,-1.07541060D-04/
      data fpp( 2,43,1),fpp( 2,43,2)/ 2.44801202D-02,-5.73978999D-05/
      data fpp( 2,44,1),fpp( 2,44,2)/ 1.30981624D-02,-3.39013407D-05/
      data fpp( 2,45,1),fpp( 2,45,2)/-2.66983200D-03,-3.03107373D-05/
      data fpp( 2,46,1),fpp( 2,46,2)/-1.52803489D-02,-3.83317101D-05/
      data fpp( 2,47,1),fpp( 2,47,2)/-2.37296037D-02,-5.37224224D-05/
      data fpp( 2,48,1),fpp( 2,48,2)/-2.74548759D-02,-7.28006002D-05/
      data fpp( 2,49,1),fpp( 2,49,2)/-2.41119151D-02,-8.06191767D-05/
      data fpp( 2,50,1),fpp( 2,50,2)/-6.05435359D-03,-3.84626930D-05/
      data fpp( 2,51,1),fpp( 2,51,2)/ 4.91850712D-02, 1.05439949D-04/
      data fpp( 2,52,1),fpp( 2,52,2)/ 1.42279652D-01, 2.40444898D-04/
      data fpp( 2,53,1),fpp( 2,53,2)/ 4.59566482D-01, 8.57224576D-05/
      data fpp( 2,54,1),fpp( 2,54,2)/ 6.34681510D-01, 1.37792712D-05/
      data fpp( 3, 1,1),fpp( 3, 1,2)/ 2.13230402D-01,-9.77243870D-06/
      data fpp( 3, 2,1),fpp( 3, 2,2)/ 6.41393630D-02, 3.57438774D-05/
      data fpp( 3, 3,1),fpp( 3, 3,2)/-3.10672068D-02, 1.27538929D-04/
      data fpp( 3, 4,1),fpp( 3, 4,2)/-8.20807886D-02, 5.73584061D-05/
      data fpp( 3, 5,1),fpp( 3, 5,2)/-8.25914204D-02,-3.88045535D-05/
      data fpp( 3, 6,1),fpp( 3, 6,2)/-3.52735601D-02,-8.26801921D-05/
      data fpp( 3, 7,1),fpp( 3, 7,2)/ 8.43113870D-03,-6.57206781D-05/
      data fpp( 3, 8,1),fpp( 3, 8,2)/ 1.87370792D-02,-3.89530956D-05/
      data fpp( 3, 9,1),fpp( 3, 9,2)/ 1.23339316D-02,-2.63449395D-05/
      data fpp( 3,10,1),fpp( 3,10,2)/ 7.90662002D-04,-2.55211464D-05/
      data fpp( 3,11,1),fpp( 3,11,2)/-1.13075287D-02,-3.32164748D-05/
      data fpp( 3,12,1),fpp( 3,12,2)/-2.22601371D-02,-4.68129543D-05/
      data fpp( 3,13,1),fpp( 3,13,2)/-3.09266843D-02,-6.36197082D-05/
      data fpp( 3,14,1),fpp( 3,14,2)/-3.48720470D-02,-7.37262131D-05/
      data fpp( 3,15,1),fpp( 3,15,2)/-2.77122624D-02,-4.81434394D-05/
      data fpp( 3,16,1),fpp( 3,16,2)/ 2.89475071D-03, 5.32279709D-05/
      data fpp( 3,17,1),fpp( 3,17,2)/ 9.47687166D-02, 1.58169556D-04/
      data fpp( 3,18,1),fpp( 3,18,2)/ 2.65286063D-01, 8.53458055D-05/
      data fpp( 3,19,1),fpp( 3,19,2)/ 2.65286063D-01, 8.53458055D-05/
      data fpp( 3,20,1),fpp( 3,20,2)/ 9.47687166D-02, 1.58169556D-04/
      data fpp( 3,21,1),fpp( 3,21,2)/ 2.89475071D-03, 5.32279710D-05/
      data fpp( 3,22,1),fpp( 3,22,2)/-2.77122624D-02,-4.81434398D-05/
      data fpp( 3,23,1),fpp( 3,23,2)/-3.48720470D-02,-7.37262116D-05/
      data fpp( 3,24,1),fpp( 3,24,2)/-3.09266843D-02,-6.36197137D-05/
      data fpp( 3,25,1),fpp( 3,25,2)/-2.22601371D-02,-4.68129337D-05/
      data fpp( 3,26,1),fpp( 3,26,2)/-1.13075287D-02,-3.32165517D-05/
      data fpp( 3,27,1),fpp( 3,27,2)/ 7.90662002D-04,-2.55208596D-05/
      data fpp( 3,28,1),fpp( 3,28,2)/ 1.23339316D-02,-2.63460098D-05/
      data fpp( 3,29,1),fpp( 3,29,2)/ 1.87370792D-02,-3.89491012D-05/
      data fpp( 3,30,1),fpp( 3,30,2)/ 8.43113870D-03,-6.57355855D-05/
      data fpp( 3,31,1),fpp( 3,31,2)/-3.52735601D-02,-8.26245566D-05/
      data fpp( 3,32,1),fpp( 3,32,2)/-8.25914204D-02,-3.90121879D-05/
      data fpp( 3,33,1),fpp( 3,33,2)/-8.20807886D-02, 5.81333081D-05/
      data fpp( 3,34,1),fpp( 3,34,2)/-3.10672068D-02, 1.24646956D-04/
      data fpp( 3,35,1),fpp( 3,35,2)/ 6.41393630D-02, 4.65368699D-05/
      data fpp( 3,36,1),fpp( 3,36,2)/ 2.13230402D-01,-5.00524349D-05/
      data fpp( 3,37,1),fpp( 3,37,2)/ 6.41393630D-02, 4.65368699D-05/
      data fpp( 3,38,1),fpp( 3,38,2)/-3.10672068D-02, 1.24646955D-04/
      data fpp( 3,39,1),fpp( 3,39,2)/-8.20807886D-02, 5.81333084D-05/
      data fpp( 3,40,1),fpp( 3,40,2)/-8.25914204D-02,-3.90121889D-05/
      data fpp( 3,41,1),fpp( 3,41,2)/-3.52735601D-02,-8.26245527D-05/
      data fpp( 3,42,1),fpp( 3,42,2)/ 8.43113870D-03,-6.57356004D-05/
      data fpp( 3,43,1),fpp( 3,43,2)/ 1.87370792D-02,-3.89490457D-05/
      data fpp( 3,44,1),fpp( 3,44,2)/ 1.23339316D-02,-2.63462167D-05/
      data fpp( 3,45,1),fpp( 3,45,2)/ 7.90662002D-04,-2.55200876D-05/
      data fpp( 3,46,1),fpp( 3,46,2)/-1.13075287D-02,-3.32194329D-05/
      data fpp( 3,47,1),fpp( 3,47,2)/-2.22601371D-02,-4.68021807D-05/
      data fpp( 3,48,1),fpp( 3,48,2)/-3.09266843D-02,-6.36598443D-05/
      data fpp( 3,49,1),fpp( 3,49,2)/-3.48720470D-02,-7.35764422D-05/
      data fpp( 3,50,1),fpp( 3,50,2)/-2.77122624D-02,-4.87023870D-05/
      data fpp( 3,51,1),fpp( 3,51,2)/ 2.89475071D-03, 5.53139903D-05/
      data fpp( 3,52,1),fpp( 3,52,2)/ 9.47687166D-02, 1.50384426D-04/
      data fpp( 3,53,1),fpp( 3,53,2)/ 2.65286063D-01, 1.14400307D-04/
      data fpp( 3,54,1),fpp( 3,54,2)/ 3.54127214D-01, 1.15860347D-04/
      data fpp( 4, 1,1),fpp( 4, 1,2)/-3.51366493D-01,-3.69060970D-05/
      data fpp( 4, 2,1),fpp( 4, 2,2)/-4.24744196D-02, 1.00781941D-05/
      data fpp( 4, 3,1),fpp( 4, 3,2)/-9.60089460D-02, 9.60253207D-05/
      data fpp( 4, 4,1),fpp( 4, 4,2)/-1.09659214D-01, 4.56025232D-05/
      data fpp( 4, 5,1),fpp( 4, 5,2)/-7.04690100D-02,-2.32794134D-05/
      data fpp( 4, 6,1),fpp( 4, 6,2)/-1.99892769D-02,-4.96548695D-05/
      data fpp( 4, 7,1),fpp( 4, 7,2)/ 7.97219911D-03,-4.09971086D-05/
      data fpp( 4, 8,1),fpp( 4, 8,2)/ 1.44665631D-02,-2.70346960D-05/
      data fpp( 4, 9,1),fpp( 4, 9,2)/ 1.00611113D-02,-2.00881074D-05/
      data fpp( 4,10,1),fpp( 4,10,2)/ 1.57718400D-03,-2.06168742D-05/
      data fpp( 4,11,1),fpp( 4,11,2)/-8.54953607D-03,-2.75423956D-05/
      data fpp( 4,12,1),fpp( 4,12,2)/-1.94698478D-02,-3.90735432D-05/
      data fpp( 4,13,1),fpp( 4,13,2)/-3.06683870D-02,-5.28814316D-05/
      data fpp( 4,14,1),fpp( 4,14,2)/-4.03698969D-02,-6.29127303D-05/
      data fpp( 4,15,1),fpp( 4,15,2)/-4.22165967D-02,-4.82676473D-05/
      data fpp( 4,16,1),fpp( 4,16,2)/-2.51240741D-02, 1.88333195D-05/
      data fpp( 4,17,1),fpp( 4,17,2)/ 1.81654814D-02, 1.18716369D-04/
      data fpp( 4,18,1),fpp( 4,18,2)/ 3.12942663D-02, 9.93052039D-05/
      data fpp( 4,19,1),fpp( 4,19,2)/ 3.12942663D-02, 9.93052039D-05/
      data fpp( 4,20,1),fpp( 4,20,2)/ 1.81654814D-02, 1.18716369D-04/
      data fpp( 4,21,1),fpp( 4,21,2)/-2.51240741D-02, 1.88333196D-05/
      data fpp( 4,22,1),fpp( 4,22,2)/-4.22165967D-02,-4.82676476D-05/
      data fpp( 4,23,1),fpp( 4,23,2)/-4.03698969D-02,-6.29127293D-05/
      data fpp( 4,24,1),fpp( 4,24,2)/-3.06683870D-02,-5.28814352D-05/
      data fpp( 4,25,1),fpp( 4,25,2)/-1.94698478D-02,-3.90735301D-05/
      data fpp( 4,26,1),fpp( 4,26,2)/-8.54953607D-03,-2.75424446D-05/
      data fpp( 4,27,1),fpp( 4,27,2)/ 1.57718400D-03,-2.06166914D-05/
      data fpp( 4,28,1),fpp( 4,28,2)/ 1.00611113D-02,-2.00887897D-05/
      data fpp( 4,29,1),fpp( 4,29,2)/ 1.44665631D-02,-2.70321499D-05/
      data fpp( 4,30,1),fpp( 4,30,2)/ 7.97219911D-03,-4.10066108D-05/
      data fpp( 4,31,1),fpp( 4,31,2)/-1.99892769D-02,-4.96194070D-05/
      data fpp( 4,32,1),fpp( 4,32,2)/-7.04690100D-02,-2.34117611D-05/
      data fpp( 4,33,1),fpp( 4,33,2)/-1.09659214D-01, 4.60964514D-05/
      data fpp( 4,34,1),fpp( 4,34,2)/-9.60089460D-02, 9.41819554D-05/
      data fpp( 4,35,1),fpp( 4,35,2)/-4.24744196D-02, 1.69577270D-05/
      data fpp( 4,36,1),fpp( 4,36,2)/-3.51366493D-01,-6.25808635D-05/
      data fpp( 4,37,1),fpp( 4,37,2)/-4.24744196D-02, 1.69577270D-05/
      data fpp( 4,38,1),fpp( 4,38,2)/-9.60089460D-02, 9.41819554D-05/
      data fpp( 4,39,1),fpp( 4,39,2)/-1.09659214D-01, 4.60964515D-05/
      data fpp( 4,40,1),fpp( 4,40,2)/-7.04690100D-02,-2.34117613D-05/
      data fpp( 4,41,1),fpp( 4,41,2)/-1.99892769D-02,-4.96194062D-05/
      data fpp( 4,42,1),fpp( 4,42,2)/ 7.97219911D-03,-4.10066140D-05/
      data fpp( 4,43,1),fpp( 4,43,2)/ 1.44665631D-02,-2.70321380D-05/
      data fpp( 4,44,1),fpp( 4,44,2)/ 1.00611113D-02,-2.00888342D-05/
      data fpp( 4,45,1),fpp( 4,45,2)/ 1.57718400D-03,-2.06165254D-05/
      data fpp( 4,46,1),fpp( 4,46,2)/-8.54953607D-03,-2.75430643D-05/
      data fpp( 4,47,1),fpp( 4,47,2)/-1.94698478D-02,-3.90712175D-05/
      data fpp( 4,48,1),fpp( 4,48,2)/-3.06683870D-02,-5.28900657D-05/
      data fpp( 4,49,1),fpp( 4,49,2)/-4.03698969D-02,-6.28805198D-05/
      data fpp( 4,50,1),fpp( 4,50,2)/-4.22165967D-02,-4.83878552D-05/
      data fpp( 4,51,1),fpp( 4,51,2)/-2.51240741D-02, 1.92819406D-05/
      data fpp( 4,52,1),fpp( 4,52,2)/ 1.81654814D-02, 1.17042093D-04/
      data fpp( 4,53,1),fpp( 4,53,2)/ 3.12942663D-02, 1.05553688D-04/
      data fpp( 4,54,1),fpp( 4,54,2)/ 4.81946329D-02, 1.25279156D-04/
      data fpp( 5, 1,1),fpp( 5, 1,2)/ 1.39752557D+00,-9.45989643D-05/
      data fpp( 5, 2,1),fpp( 5, 2,2)/-4.83366847D-02,-2.21520714D-05/
      data fpp( 5, 3,1),fpp( 5, 3,2)/-1.57222009D-01, 9.77912500D-05/
      data fpp( 5, 4,1),fpp( 5, 4,2)/-1.09327356D-01, 5.14970713D-05/
      data fpp( 5, 5,1),fpp( 5, 5,2)/-4.98775396D-02,-2.26753506D-06/
      data fpp( 5, 6,1),fpp( 5, 6,2)/-1.05743322D-02,-2.70909310D-05/
      data fpp( 5, 7,1),fpp( 5, 7,2)/ 7.20006486D-03,-2.60007409D-05/
      data fpp( 5, 8,1),fpp( 5, 8,2)/ 1.09816686D-02,-1.90501055D-05/
      data fpp( 5, 9,1),fpp( 5, 9,2)/ 8.02162321D-03,-1.51888371D-05/
      data fpp( 5,10,1),fpp( 5,10,2)/ 1.81060200D-03,-1.62305461D-05/
      data fpp( 5,11,1),fpp( 5,11,2)/-6.43932696D-03,-2.21049785D-05/
      data fpp( 5,12,1),fpp( 5,12,2)/-1.65004716D-02,-3.14055398D-05/
      data fpp( 5,13,1),fpp( 5,13,2)/-2.85747678D-02,-4.19568621D-05/
      data fpp( 5,14,1),fpp( 5,14,2)/-4.23283656D-02,-4.91610116D-05/
      data fpp( 5,15,1),fpp( 5,15,2)/-5.29613508D-02,-4.20730916D-05/
      data fpp( 5,16,1),fpp( 5,16,2)/-4.75084545D-02, 2.34137792D-06/
      data fpp( 5,17,1),fpp( 5,17,2)/-1.81806420D-02, 7.73055799D-05/
      data fpp( 5,18,1),fpp( 5,18,2)/ 4.33668720D-02, 9.92803025D-05/
      data fpp( 5,19,1),fpp( 5,19,2)/ 4.33668720D-02, 9.92803025D-05/
      data fpp( 5,20,1),fpp( 5,20,2)/-1.81806420D-02, 7.73055799D-05/
      data fpp( 5,21,1),fpp( 5,21,2)/-4.75084545D-02, 2.34137807D-06/
      data fpp( 5,22,1),fpp( 5,22,2)/-5.29613508D-02,-4.20730921D-05/
      data fpp( 5,23,1),fpp( 5,23,2)/-4.23283656D-02,-4.91610095D-05/
      data fpp( 5,24,1),fpp( 5,24,2)/-2.85747678D-02,-4.19568697D-05/
      data fpp( 5,25,1),fpp( 5,25,2)/-1.65004716D-02,-3.14055117D-05/
      data fpp( 5,26,1),fpp( 5,26,2)/-6.43932696D-03,-2.21050834D-05/
      data fpp( 5,27,1),fpp( 5,27,2)/ 1.81060200D-03,-1.62301546D-05/
      data fpp( 5,28,1),fpp( 5,28,2)/ 8.02162321D-03,-1.51902983D-05/
      data fpp( 5,29,1),fpp( 5,29,2)/ 1.09816686D-02,-1.90446524D-05/
      data fpp( 5,30,1),fpp( 5,30,2)/ 7.20006486D-03,-2.60210921D-05/
      data fpp( 5,31,1),fpp( 5,31,2)/-1.05743322D-02,-2.70149790D-05/
      data fpp( 5,32,1),fpp( 5,32,2)/-4.98775396D-02,-2.55099181D-06/
      data fpp( 5,33,1),fpp( 5,33,2)/-1.09327356D-01, 5.25549463D-05/
      data fpp( 5,34,1),fpp( 5,34,2)/-1.57222009D-01, 9.38432068D-05/
      data fpp( 5,35,1),fpp( 5,35,2)/-4.83366847D-02,-7.41777336D-06/
      data fpp( 5,36,1),fpp( 5,36,2)/ 1.39752557D+00,-1.49588113D-04/
      data fpp( 5,37,1),fpp( 5,37,2)/-4.83366847D-02,-7.41777337D-06/
      data fpp( 5,38,1),fpp( 5,38,2)/-1.57222009D-01, 9.38432068D-05/
      data fpp( 5,39,1),fpp( 5,39,2)/-1.09327356D-01, 5.25549462D-05/
      data fpp( 5,40,1),fpp( 5,40,2)/-4.98775396D-02,-2.55099165D-06/
      data fpp( 5,41,1),fpp( 5,41,2)/-1.05743322D-02,-2.70149796D-05/
      data fpp( 5,42,1),fpp( 5,42,2)/ 7.20006486D-03,-2.60210900D-05/
      data fpp( 5,43,1),fpp( 5,43,2)/ 1.09816686D-02,-1.90446605D-05/
      data fpp( 5,44,1),fpp( 5,44,2)/ 8.02162321D-03,-1.51902680D-05/
      data fpp( 5,45,1),fpp( 5,45,2)/ 1.81060200D-03,-1.62302677D-05/
      data fpp( 5,46,1),fpp( 5,46,2)/-6.43932696D-03,-2.21046614D-05/
      data fpp( 5,47,1),fpp( 5,47,2)/-1.65004716D-02,-3.14070866D-05/
      data fpp( 5,48,1),fpp( 5,48,2)/-2.85747678D-02,-4.19509921D-05/
      data fpp( 5,49,1),fpp( 5,49,2)/-4.23283656D-02,-4.91829451D-05/
      data fpp( 5,50,1),fpp( 5,50,2)/-5.29613508D-02,-4.19912274D-05/
      data fpp( 5,51,1),fpp( 5,51,2)/-4.75084545D-02, 2.03585477D-06/
      data fpp( 5,52,1),fpp( 5,52,2)/-1.81806420D-02, 7.84458083D-05/
      data fpp( 5,53,1),fpp( 5,53,2)/ 4.33668720D-02, 9.50249119D-05/
      data fpp( 5,54,1),fpp( 5,54,2)/ 1.26549254D-01, 1.28698544D-04/
      data fpp( 6, 1,1),fpp( 6, 1,2)/-2.59368079D+00, 2.26081194D-04/
      data fpp( 6, 2,1),fpp( 6, 2,2)/-4.55438841D-01, 1.65739612D-04/
      data fpp( 6, 3,1),fpp( 6, 3,2)/-1.77338018D-01, 9.08323571D-05/
      data fpp( 6, 4,1),fpp( 6, 4,2)/-7.94013625D-02, 6.69049592D-05/
      data fpp( 6, 5,1),fpp( 6, 5,2)/-3.08608317D-02, 9.28180600D-06/
      data fpp( 6, 6,1),fpp( 6, 6,2)/-5.12339427D-03,-1.30301832D-05/
      data fpp( 6, 7,1),fpp( 6, 7,2)/ 5.90254146D-03,-1.68670731D-05/
      data fpp( 6, 8,1),fpp( 6, 8,2)/ 8.28176257D-03,-1.35455245D-05/
      data fpp( 6, 9,1),fpp( 6, 9,2)/ 6.18239585D-03,-1.14448288D-05/
      data fpp( 6,10,1),fpp( 6,10,2)/ 1.60540798D-03,-1.25671602D-05/
      data fpp( 6,11,1),fpp( 6,11,2)/-4.90315608D-03,-1.73125306D-05/
      data fpp( 6,12,1),fpp( 6,12,2)/-1.35432658D-02,-2.45027176D-05/
      data fpp( 6,13,1),fpp( 6,13,2)/-2.51025417D-02,-3.18265990D-05/
      data fpp( 6,14,1),fpp( 6,14,2)/-4.04866408D-02,-3.50848865D-05/
      data fpp( 6,15,1),fpp( 6,15,2)/-5.80280000D-02,-2.91098549D-05/
      data fpp( 6,16,1),fpp( 6,16,2)/-6.43971081D-02,-3.76769396D-06/
      data fpp( 6,17,1),fpp( 6,17,2)/-4.62279135D-02, 4.60886307D-05/
      data fpp( 6,18,1),fpp( 6,18,2)/-3.57867541D-02, 8.44931711D-05/
      data fpp( 6,19,1),fpp( 6,19,2)/-3.57867541D-02, 8.44931713D-05/
      data fpp( 6,20,1),fpp( 6,20,2)/-4.62279135D-02, 4.60886297D-05/
      data fpp( 6,21,1),fpp( 6,21,2)/-6.43971081D-02,-3.76769022D-06/
      data fpp( 6,22,1),fpp( 6,22,2)/-5.80280000D-02,-2.91098688D-05/
      data fpp( 6,23,1),fpp( 6,23,2)/-4.04866408D-02,-3.50848345D-05/
      data fpp( 6,24,1),fpp( 6,24,2)/-2.51025417D-02,-3.18267933D-05/
      data fpp( 6,25,1),fpp( 6,25,2)/-1.35432658D-02,-2.45019924D-05/
      data fpp( 6,26,1),fpp( 6,26,2)/-4.90315608D-03,-1.73152373D-05/
      data fpp( 6,27,1),fpp( 6,27,2)/ 1.60540798D-03,-1.25570586D-05/
      data fpp( 6,28,1),fpp( 6,28,2)/ 6.18239585D-03,-1.14825285D-05/
      data fpp( 6,29,1),fpp( 6,29,2)/ 8.28176257D-03,-1.34048276D-05/
      data fpp( 6,30,1),fpp( 6,30,2)/ 5.90254146D-03,-1.73921610D-05/
      data fpp( 6,31,1),fpp( 6,31,2)/-5.12339427D-03,-1.10705283D-05/
      data fpp( 6,32,1),fpp( 6,32,2)/-3.08608317D-02, 1.96827415D-06/
      data fpp( 6,33,1),fpp( 6,33,2)/-7.94013625D-02, 9.41994317D-05/
      data fpp( 6,34,1),fpp( 6,34,2)/-1.77338018D-01,-1.10320008D-05/
      data fpp( 6,35,1),fpp( 6,35,2)/-4.55438841D-01, 5.45902572D-04/
      data fpp( 6,36,1),fpp( 6,36,2)/-2.59368079D+00,-1.19270629D-03/
      data fpp( 6,37,1),fpp( 6,37,2)/-4.55438841D-01, 5.45902572D-04/
      data fpp( 6,38,1),fpp( 6,38,2)/-1.77338018D-01,-1.10320008D-05/
      data fpp( 6,39,1),fpp( 6,39,2)/-7.94013625D-02, 9.41994316D-05/
      data fpp( 6,40,1),fpp( 6,40,2)/-3.08608317D-02, 1.96827442D-06/
      data fpp( 6,41,1),fpp( 6,41,2)/-5.12339427D-03,-1.10705293D-05/
      data fpp( 6,42,1),fpp( 6,42,2)/ 5.90254146D-03,-1.73921573D-05/
      data fpp( 6,43,1),fpp( 6,43,2)/ 8.28176257D-03,-1.34048415D-05/
      data fpp( 6,44,1),fpp( 6,44,2)/ 6.18239585D-03,-1.14824767D-05/
      data fpp( 6,45,1),fpp( 6,45,2)/ 1.60540798D-03,-1.25572518D-05/
      data fpp( 6,46,1),fpp( 6,46,2)/-4.90315608D-03,-1.73145161D-05/
      data fpp( 6,47,1),fpp( 6,47,2)/-1.35432658D-02,-2.45046838D-05/
      data fpp( 6,48,1),fpp( 6,48,2)/-2.51025417D-02,-3.18167488D-05/
      data fpp( 6,49,1),fpp( 6,49,2)/-4.04866408D-02,-3.51223212D-05/
      data fpp( 6,50,1),fpp( 6,50,2)/-5.80280000D-02,-2.89699664D-05/
      data fpp( 6,51,1),fpp( 6,51,2)/-6.43971081D-02,-4.28981313D-06/
      data fpp( 6,52,1),fpp( 6,52,2)/-4.62279135D-02, 4.80372189D-05/
      data fpp( 6,53,1),fpp( 6,53,2)/-3.57867541D-02, 7.72209375D-05/
      data fpp( 6,54,1),fpp( 6,54,2)/-2.15691649D-01, 1.13017031D-04/
      data fpp( 7, 1,1),fpp( 7, 1,2)/ 5.54667583D-01,-1.10758684D-04/
      data fpp( 7, 2,1),fpp( 7, 2,2)/-1.60142949D-01,-2.42816321D-05/
      data fpp( 7, 3,1),fpp( 7, 3,2)/-8.72909190D-02, 1.26675212D-04/
      data fpp( 7, 4,1),fpp( 7, 4,2)/-4.32271942D-02, 5.19527825D-05/
      data fpp( 7, 5,1),fpp( 7, 5,2)/-1.68491336D-02, 1.79836575D-05/
      data fpp( 7, 6,1),fpp( 7, 6,2)/-1.94709069D-03,-6.35341245D-06/
      data fpp( 7, 7,1),fpp( 7, 7,2)/ 4.64976931D-03,-1.08220077D-05/
      data fpp( 7, 8,1),fpp( 7, 8,2)/ 6.08128114D-03,-9.80055681D-06/
      data fpp( 7, 9,1),fpp( 7, 9,2)/ 4.64379340D-03,-8.58376508D-06/
      data fpp( 7,10,1),fpp( 7,10,2)/ 1.32276607D-03,-9.63038288D-06/
      data fpp( 7,11,1),fpp( 7,11,2)/-3.67804869D-03,-1.33087034D-05/
      data fpp( 7,12,1),fpp( 7,12,2)/-1.07914651D-02,-1.86988035D-05/
      data fpp( 7,13,1),fpp( 7,13,2)/-2.09700652D-02,-2.32140825D-05/
      data fpp( 7,14,1),fpp( 7,14,2)/-3.61150711D-02,-2.26168665D-05/
      data fpp( 7,15,1),fpp( 7,15,2)/-5.81716490D-02,-1.31644515D-05/
      data fpp( 7,16,1),fpp( 7,16,2)/-8.17831132D-02, 3.49067237D-06/
      data fpp( 7,17,1),fpp( 7,17,2)/-6.93827040D-02, 2.16357620D-05/
      data fpp( 7,18,1),fpp( 7,18,2)/ 1.69501446D-02, 5.93782797D-05/
      data fpp( 7,19,1),fpp( 7,19,2)/ 1.69501446D-02, 5.93782798D-05/
      data fpp( 7,20,1),fpp( 7,20,2)/-6.93827040D-02, 2.16357617D-05/
      data fpp( 7,21,1),fpp( 7,21,2)/-8.17831132D-02, 3.49067324D-06/
      data fpp( 7,22,1),fpp( 7,22,2)/-5.81716490D-02,-1.31644547D-05/
      data fpp( 7,23,1),fpp( 7,23,2)/-3.61150711D-02,-2.26168544D-05/
      data fpp( 7,24,1),fpp( 7,24,2)/-2.09700652D-02,-2.32141275D-05/
      data fpp( 7,25,1),fpp( 7,25,2)/-1.07914651D-02,-1.86986354D-05/
      data fpp( 7,26,1),fpp( 7,26,2)/-3.67804869D-03,-1.33093309D-05/
      data fpp( 7,27,1),fpp( 7,27,2)/ 1.32276607D-03,-9.62804100D-06/
      data fpp( 7,28,1),fpp( 7,28,2)/ 4.64379340D-03,-8.59250509D-06/
      data fpp( 7,29,1),fpp( 7,29,2)/ 6.08128114D-03,-9.76793864D-06/
      data fpp( 7,30,1),fpp( 7,30,2)/ 4.64976931D-03,-1.09437404D-05/
      data fpp( 7,31,1),fpp( 7,31,2)/-1.94709069D-03,-5.89909992D-06/
      data fpp( 7,32,1),fpp( 7,32,2)/-1.68491336D-02, 1.62881400D-05/
      data fpp( 7,33,1),fpp( 7,33,2)/-4.32271942D-02, 5.82805398D-05/
      data fpp( 7,34,1),fpp( 7,34,2)/-8.72909190D-02, 1.03059701D-04/
      data fpp( 7,35,1),fpp( 7,35,2)/-1.60142949D-01, 6.38526569D-05/
      data fpp( 7,36,1),fpp( 7,36,2)/ 5.54667583D-01,-4.39680328D-04/
      data fpp( 7,37,1),fpp( 7,37,2)/-1.60142949D-01, 6.38526569D-05/
      data fpp( 7,38,1),fpp( 7,38,2)/-8.72909190D-02, 1.03059701D-04/
      data fpp( 7,39,1),fpp( 7,39,2)/-4.32271942D-02, 5.82805398D-05/
      data fpp( 7,40,1),fpp( 7,40,2)/-1.68491336D-02, 1.62881399D-05/
      data fpp( 7,41,1),fpp( 7,41,2)/-1.94709069D-03,-5.89909947D-06/
      data fpp( 7,42,1),fpp( 7,42,2)/ 4.64976931D-03,-1.09437420D-05/
      data fpp( 7,43,1),fpp( 7,43,2)/ 6.08128114D-03,-9.76793240D-06/
      data fpp( 7,44,1),fpp( 7,44,2)/ 4.64379340D-03,-8.59252836D-06/
      data fpp( 7,45,1),fpp( 7,45,2)/ 1.32276607D-03,-9.62795416D-06/
      data fpp( 7,46,1),fpp( 7,46,2)/-3.67804869D-03,-1.33096550D-05/
      data fpp( 7,47,1),fpp( 7,47,2)/-1.07914651D-02,-1.86974259D-05/
      data fpp( 7,48,1),fpp( 7,48,2)/-2.09700652D-02,-2.32186415D-05/
      data fpp( 7,49,1),fpp( 7,49,2)/-3.61150711D-02,-2.26000080D-05/
      data fpp( 7,50,1),fpp( 7,50,2)/-5.81716490D-02,-1.32273266D-05/
      data fpp( 7,51,1),fpp( 7,51,2)/-8.17831132D-02, 3.72531435D-06/
      data fpp( 7,52,1),fpp( 7,52,2)/-6.93827040D-02, 2.07600692D-05/
      data fpp( 7,53,1),fpp( 7,53,2)/ 1.69501446D-02, 6.26464088D-05/
      data fpp( 7,54,1),fpp( 7,54,2)/ 8.83397343D-01, 9.74322956D-05/
      data fpp( 8, 1,1),fpp( 8, 1,2)/-8.93023545D-02,-9.42498552D-05/
      data fpp( 8, 2,1),fpp( 8, 2,2)/ 4.13682688D-02,-3.66742897D-05/
      data fpp( 8, 3,1),fpp( 8, 3,2)/-4.09948397D-03, 4.84190139D-05/
      data fpp( 8, 4,1),fpp( 8, 4,2)/-8.72398607D-03, 3.72002340D-05/
      data fpp( 8, 5,1),fpp( 8, 5,2)/-4.17343325D-03, 1.49940501D-05/
      data fpp( 8, 6,1),fpp( 8, 6,2)/ 2.61719218D-04,-9.04343874D-08/
      data fpp( 8, 7,1),fpp( 8, 7,2)/ 2.64067135D-03,-4.90031254D-06/
      data fpp( 8, 8,1),fpp( 8, 8,2)/ 3.22027529D-03,-5.13631544D-06/
      data fpp( 8, 9,1),fpp( 8, 9,2)/ 2.46617188D-03,-4.87842569D-06/
      data fpp( 8,10,1),fpp( 8,10,2)/ 6.92747796D-04,-5.51798180D-06/
      data fpp( 8,11,1),fpp( 8,11,2)/-2.17427588D-03,-7.59764712D-06/
      data fpp( 8,12,1),fpp( 8,12,2)/-6.54022183D-03,-1.03874297D-05/
      data fpp( 8,13,1),fpp( 8,13,2)/-1.32672834D-02,-1.13326340D-05/
      data fpp( 8,14,1),fpp( 8,14,2)/-2.39389662D-02,-6.22003433D-06/
      data fpp( 8,15,1),fpp( 8,15,2)/-4.21448030D-02, 1.12707713D-05/
      data fpp( 8,16,1),fpp( 8,16,2)/-7.59871062D-02, 3.28249490D-05/
      data fpp( 8,17,1),fpp( 8,17,2)/-1.39792931D-01, 6.54614325D-05/
      data fpp( 8,18,1),fpp( 8,18,2)/-2.11723307D-01,-4.09006791D-05/
      data fpp( 8,19,1),fpp( 8,19,2)/-2.11723307D-01,-4.09006791D-05/
      data fpp( 8,20,1),fpp( 8,20,2)/-1.39792931D-01, 6.54614325D-05/
      data fpp( 8,21,1),fpp( 8,21,2)/-7.59871062D-02, 3.28249491D-05/
      data fpp( 8,22,1),fpp( 8,22,2)/-4.21448030D-02, 1.12707710D-05/
      data fpp( 8,23,1),fpp( 8,23,2)/-2.39389662D-02,-6.22003319D-06/
      data fpp( 8,24,1),fpp( 8,24,2)/-1.32672834D-02,-1.13326382D-05/
      data fpp( 8,25,1),fpp( 8,25,2)/-6.54022183D-03,-1.03874139D-05/
      data fpp( 8,26,1),fpp( 8,26,2)/-2.17427588D-03,-7.59770633D-06/
      data fpp( 8,27,1),fpp( 8,27,2)/ 6.92747796D-04,-5.51776083D-06/
      data fpp( 8,28,1),fpp( 8,28,2)/ 2.46617188D-03,-4.87925034D-06/
      data fpp( 8,29,1),fpp( 8,29,2)/ 3.22027529D-03,-5.13323781D-06/
      data fpp( 8,30,1),fpp( 8,30,2)/ 2.64067135D-03,-4.91179844D-06/
      data fpp( 8,31,1),fpp( 8,31,2)/ 2.61719218D-04,-4.75684403D-08/
      data fpp( 8,32,1),fpp( 8,32,2)/-4.17343325D-03, 1.48340722D-05/
      data fpp( 8,33,1),fpp( 8,33,2)/-8.72398607D-03, 3.77972796D-05/
      data fpp( 8,34,1),fpp( 8,34,2)/-4.09948397D-03, 4.61908093D-05/
      data fpp( 8,35,1),fpp( 8,35,2)/ 4.13682688D-02,-2.83585169D-05/
      data fpp( 8,36,1),fpp( 8,36,2)/-8.93023545D-02,-1.25284742D-04/
      data fpp( 8,37,1),fpp( 8,37,2)/ 4.13682688D-02,-2.83585166D-05/
      data fpp( 8,38,1),fpp( 8,38,2)/-4.09948397D-03, 4.61908082D-05/
      data fpp( 8,39,1),fpp( 8,39,2)/-8.72398607D-03, 3.77972839D-05/
      data fpp( 8,40,1),fpp( 8,40,2)/-4.17343325D-03, 1.48340562D-05/
      data fpp( 8,41,1),fpp( 8,41,2)/ 2.61719218D-04,-4.75087220D-08/
      data fpp( 8,42,1),fpp( 8,42,2)/ 2.64067135D-03,-4.91202132D-06/
      data fpp( 8,43,1),fpp( 8,43,2)/ 3.22027529D-03,-5.13240602D-06/
      data fpp( 8,44,1),fpp( 8,44,2)/ 2.46617188D-03,-4.88235462D-06/
      data fpp( 8,45,1),fpp( 8,45,2)/ 6.92747796D-04,-5.50617552D-06/
      data fpp( 8,46,1),fpp( 8,46,2)/-2.17427588D-03,-7.64094330D-06/
      data fpp( 8,47,1),fpp( 8,47,2)/-6.54022183D-03,-1.02260513D-05/
      data fpp( 8,48,1),fpp( 8,48,2)/-1.32672834D-02,-1.19348516D-05/
      data fpp( 8,49,1),fpp( 8,49,2)/-2.39389662D-02,-3.97254236D-06/
      data fpp( 8,50,1),fpp( 8,50,2)/-4.21448030D-02, 2.88302102D-06/
      data fpp( 8,51,1),fpp( 8,51,2)/-7.59871062D-02, 6.41284583D-05/
      data fpp( 8,52,1),fpp( 8,52,2)/-1.39792931D-01,-5.13648542D-05/
      data fpp( 8,53,1),fpp( 8,53,2)/-2.11723307D-01, 3.95100958D-04/
      data fpp( 8,54,1),fpp( 8,54,2)/-1.25158120D+00, 6.81007021D-04/
      data fpp( 9, 1,1),fpp( 9, 1,2)/ 5.45343351D-02,-4.77148769D-05/
      data fpp( 9, 2,1),fpp( 9, 2,2)/ 9.98862421D-03,-1.99432463D-05/
      data fpp( 9, 3,1),fpp( 9, 3,2)/ 3.73635488D-03, 1.78858620D-05/
      data fpp( 9, 4,1),fpp( 9, 4,2)/-7.99361488D-04, 2.05137982D-05/
      data fpp( 9, 5,1),fpp( 9, 5,2)/-8.82133360D-04, 9.56494518D-06/
      data fpp( 9, 6,1),fpp( 9, 6,2)/ 3.71463821D-04, 9.02421092D-07/
      data fpp( 9, 7,1),fpp( 9, 7,2)/ 1.36629531D-03,-2.32062954D-06/
      data fpp( 9, 8,1),fpp( 9, 8,2)/ 1.63261771D-03,-2.77990293D-06/
      data fpp( 9, 9,1),fpp( 9, 9,2)/ 1.24526907D-03,-2.77175875D-06/
      data fpp( 9,10,1),fpp( 9,10,2)/ 3.08742746D-04,-3.11906206D-06/
      data fpp( 9,11,1),fpp( 9,11,2)/-1.29359778D-03,-4.18599299D-06/
      data fpp( 9,12,1),fpp( 9,12,2)/-3.82889759D-03,-5.63096598D-06/
      data fpp( 9,13,1),fpp( 9,13,2)/-7.68455115D-03,-5.06014309D-06/
      data fpp( 9,14,1),fpp( 9,14,2)/-1.35090639D-02,-1.74461662D-07/
      data fpp( 9,15,1),fpp( 9,15,2)/-2.23691391D-02, 1.85859897D-05/
      data fpp( 9,16,1),fpp( 9,16,2)/-3.64659618D-02, 3.00505027D-05/
      data fpp( 9,17,1),fpp( 9,17,2)/-6.27355713D-02, 1.01217999D-04/
      data fpp( 9,18,1),fpp( 9,18,2)/-1.35749418D-01,-8.52904999D-05/
      data fpp( 9,19,1),fpp( 9,19,2)/-1.35749418D-01,-8.52904999D-05/
      data fpp( 9,20,1),fpp( 9,20,2)/-6.27355713D-02, 1.01217999D-04/
      data fpp( 9,21,1),fpp( 9,21,2)/-3.64659618D-02, 3.00505028D-05/
      data fpp( 9,22,1),fpp( 9,22,2)/-2.23691391D-02, 1.85859897D-05/
      data fpp( 9,23,1),fpp( 9,23,2)/-1.35090639D-02,-1.74461541D-07/
      data fpp( 9,24,1),fpp( 9,24,2)/-7.68455115D-03,-5.06014353D-06/
      data fpp( 9,25,1),fpp( 9,25,2)/-3.82889759D-03,-5.63096431D-06/
      data fpp( 9,26,1),fpp( 9,26,2)/-1.29359778D-03,-4.18599922D-06/
      data fpp( 9,27,1),fpp( 9,27,2)/ 3.08742746D-04,-3.11903883D-06/
      data fpp( 9,28,1),fpp( 9,28,2)/ 1.24526907D-03,-2.77184548D-06/
      data fpp( 9,29,1),fpp( 9,29,2)/ 1.63261771D-03,-2.77957927D-06/
      data fpp( 9,30,1),fpp( 9,30,2)/ 1.36629531D-03,-2.32183745D-06/
      data fpp( 9,31,1),fpp( 9,31,2)/ 3.71463821D-04, 9.06929058D-07/
      data fpp( 9,32,1),fpp( 9,32,2)/-8.82133360D-04, 9.54812122D-06/
      data fpp( 9,33,1),fpp( 9,33,2)/-7.99361488D-04, 2.05765861D-05/
      data fpp( 9,34,1),fpp( 9,34,2)/ 3.73635488D-03, 1.76515345D-05/
      data fpp( 9,35,1),fpp( 9,35,2)/ 9.98862421D-03,-1.90687241D-05/
      data fpp( 9,36,1),fpp( 9,36,2)/ 5.45343351D-02,-5.09786379D-05/
      data fpp( 9,37,1),fpp( 9,37,2)/ 9.98862421D-03,-1.90687241D-05/
      data fpp( 9,38,1),fpp( 9,38,2)/ 3.73635488D-03, 1.76515343D-05/
      data fpp( 9,39,1),fpp( 9,39,2)/-7.99361488D-04, 2.05765868D-05/
      data fpp( 9,40,1),fpp( 9,40,2)/-8.82133360D-04, 9.54811843D-06/
      data fpp( 9,41,1),fpp( 9,41,2)/ 3.71463821D-04, 9.06939458D-07/
      data fpp( 9,42,1),fpp( 9,42,2)/ 1.36629531D-03,-2.32187626D-06/
      data fpp( 9,43,1),fpp( 9,43,2)/ 1.63261771D-03,-2.77943440D-06/
      data fpp( 9,44,1),fpp( 9,44,2)/ 1.24526907D-03,-2.77238613D-06/
      data fpp( 9,45,1),fpp( 9,45,2)/ 3.08742746D-04,-3.11702109D-06/
      data fpp( 9,46,1),fpp( 9,46,2)/-1.29359778D-03,-4.19352952D-06/
      data fpp( 9,47,1),fpp( 9,47,2)/-3.82889759D-03,-5.60286083D-06/
      data fpp( 9,48,1),fpp( 9,48,2)/-7.68455115D-03,-5.16502718D-06/
      data fpp( 9,49,1),fpp( 9,49,2)/-1.35090639D-02, 2.16969532D-07/
      data fpp( 9,50,1),fpp( 9,50,2)/-2.23691391D-02, 1.71251490D-05/
      data fpp( 9,51,1),fpp( 9,51,2)/-3.64659618D-02, 3.55024343D-05/
      data fpp( 9,52,1),fpp( 9,52,2)/-6.27355713D-02, 8.08711138D-05/
      data fpp( 9,53,1),fpp( 9,53,2)/-1.35749418D-01,-9.35488967D-06/
      data fpp( 9,54,1),fpp( 9,54,2)/ 3.39893723D-01,-6.08395552D-05/
      data fpp(10, 1,1),fpp(10, 1,2)/ 3.21707722D-03,-1.93192347D-05/
      data fpp(10, 2,1),fpp(10, 2,2)/ 1.04181378D-02,-8.35353059D-06/
      data fpp(10, 3,1),fpp(10, 3,2)/ 4.28810961D-03, 5.82535708D-06/
      data fpp(10, 4,1),fpp(10, 4,2)/ 9.84690215D-04, 8.75810228D-06/
      data fpp(10, 5,1),fpp(10, 5,2)/ 2.06266997D-05, 4.53823379D-06/
      data fpp(10, 6,1),fpp(10, 6,2)/ 2.00554872D-04, 6.58962563D-07/
      data fpp(10, 7,1),fpp(10, 7,2)/ 5.19199823D-04,-1.01208404D-06/
      data fpp(10, 8,1),fpp(10, 8,2)/ 6.31556010D-04,-1.35662641D-06/
      data fpp(10, 9,1),fpp(10, 9,2)/ 4.87293850D-04,-1.32541034D-06/
      data fpp(10,10,1),fpp(10,10,2)/ 5.57278825D-05,-1.54973222D-06/
      data fpp(10,11,1),fpp(10,11,2)/-6.89027300D-04,-1.97966078D-06/
      data fpp(10,12,1),fpp(10,12,2)/-1.87699122D-03,-2.52562466D-06/
      data fpp(10,13,1),fpp(10,13,2)/-3.67618912D-03,-1.93384058D-06/
      data fpp(10,14,1),fpp(10,14,2)/-6.14579689D-03, 1.79498699D-06/
      data fpp(10,15,1),fpp(10,15,2)/-8.97545673D-03, 1.15058926D-05/
      data fpp(10,16,1),fpp(10,16,2)/-1.07304525D-02, 2.13494425D-05/
      data fpp(10,17,1),fpp(10,17,2)/-5.84039853D-03, 3.02003374D-05/
      data fpp(10,18,1),fpp(10,18,2)/ 2.81767490D-02,-3.68207922D-05/
      data fpp(10,19,1),fpp(10,19,2)/ 2.81767490D-02,-3.68207922D-05/
      data fpp(10,20,1),fpp(10,20,2)/-5.84039853D-03, 3.02003374D-05/
      data fpp(10,21,1),fpp(10,21,2)/-1.07304525D-02, 2.13494425D-05/
      data fpp(10,22,1),fpp(10,22,2)/-8.97545673D-03, 1.15058926D-05/
      data fpp(10,23,1),fpp(10,23,2)/-6.14579689D-03, 1.79498695D-06/
      data fpp(10,24,1),fpp(10,24,2)/-3.67618912D-03,-1.93384044D-06/
      data fpp(10,25,1),fpp(10,25,2)/-1.87699122D-03,-2.52562518D-06/
      data fpp(10,26,1),fpp(10,26,2)/-6.89027300D-04,-1.97965883D-06/
      data fpp(10,27,1),fpp(10,27,2)/ 5.57278825D-05,-1.54973952D-06/
      data fpp(10,28,1),fpp(10,28,2)/ 4.87293850D-04,-1.32538310D-06/
      data fpp(10,29,1),fpp(10,29,2)/ 6.31556010D-04,-1.35672809D-06/
      data fpp(10,30,1),fpp(10,30,2)/ 5.19199823D-04,-1.01170455D-06/
      data fpp(10,31,1),fpp(10,31,2)/ 2.00554872D-04, 6.57546297D-07/
      data fpp(10,32,1),fpp(10,32,2)/ 2.06266997D-05, 4.54351936D-06/
      data fpp(10,33,1),fpp(10,33,2)/ 9.84690215D-04, 8.73837625D-06/
      data fpp(10,34,1),fpp(10,34,2)/ 4.28810961D-03, 5.89897562D-06/
      data fpp(10,35,1),fpp(10,35,2)/ 1.04181378D-02,-8.62827875D-06/
      data fpp(10,36,1),fpp(10,36,2)/ 3.21707722D-03,-1.82938606D-05/
      data fpp(10,37,1),fpp(10,37,2)/ 1.04181378D-02,-8.62827874D-06/
      data fpp(10,38,1),fpp(10,38,2)/ 4.28810961D-03, 5.89897559D-06/
      data fpp(10,39,1),fpp(10,39,2)/ 9.84690215D-04, 8.73837640D-06/
      data fpp(10,40,1),fpp(10,40,2)/ 2.06266997D-05, 4.54351881D-06/
      data fpp(10,41,1),fpp(10,41,2)/ 2.00554872D-04, 6.57548356D-07/
      data fpp(10,42,1),fpp(10,42,2)/ 5.19199823D-04,-1.01171224D-06/
      data fpp(10,43,1),fpp(10,43,2)/ 6.31556010D-04,-1.35669939D-06/
      data fpp(10,44,1),fpp(10,44,2)/ 4.87293850D-04,-1.32549019D-06/
      data fpp(10,45,1),fpp(10,45,2)/ 5.57278825D-05,-1.54933984D-06/
      data fpp(10,46,1),fpp(10,46,2)/-6.89027300D-04,-1.98115043D-06/
      data fpp(10,47,1),fpp(10,47,2)/-1.87699122D-03,-2.52005843D-06/
      data fpp(10,48,1),fpp(10,48,2)/-3.67618912D-03,-1.95461584D-06/
      data fpp(10,49,1),fpp(10,49,2)/-6.14579689D-03, 1.87252179D-06/
      data fpp(10,50,1),fpp(10,50,2)/-8.97545673D-03, 1.12165287D-05/
      data fpp(10,51,1),fpp(10,51,2)/-1.07304525D-02, 2.24293634D-05/
      data fpp(10,52,1),fpp(10,52,2)/-5.84039853D-03, 2.61700175D-05/
      data fpp(10,53,1),fpp(10,53,2)/ 2.81767490D-02,-2.17794336D-05/
      data fpp(10,54,1),fpp(10,54,2)/-6.43202385D-02,-5.49602832D-05/
      data fpp(11, 1,1),fpp(11, 1,2)/ 6.30855601D-03,-7.67479461D-06/
      data fpp(11, 2,1),fpp(11, 2,2)/ 3.55082450D-03,-3.36941079D-06/
      data fpp(11, 3,1),fpp(11, 3,2)/ 1.88960670D-03, 2.10243775D-06/
      data fpp(11, 4,1),fpp(11, 4,2)/ 4.99000629D-04, 3.49165978D-06/
      data fpp(11, 5,1),fpp(11, 5,2)/-1.15734367D-05, 1.94292314D-06/
      data fpp(11, 6,1),fpp(11, 6,2)/-7.28330594D-06, 2.68647647D-07/
      data fpp(11, 7,1),fpp(11, 7,2)/ 1.23305405D-04,-4.91513730D-07/
      data fpp(11, 8,1),fpp(11, 8,2)/ 1.92358250D-04,-6.72592726D-07/
      data fpp(11, 9,1),fpp(11, 9,2)/ 1.41555536D-04,-6.34115369D-07/
      data fpp(11,10,1),fpp(11,10,2)/-3.72542741D-05,-7.86945795D-07/
      data fpp(11,11,1),fpp(11,11,2)/-3.61493022D-04,-9.52101452D-07/
      data fpp(11,12,1),fpp(11,12,2)/-8.76737550D-04,-1.14064840D-06/
      data fpp(11,13,1),fpp(11,13,2)/-1.63469235D-03,-7.67304956D-07/
      data fpp(11,14,1),fpp(11,14,2)/-2.57814852D-03, 1.23386822D-06/
      data fpp(11,15,1),fpp(11,15,2)/-3.32743394D-03, 5.80383207D-06/
      data fpp(11,16,1),fpp(11,16,2)/-2.98502819D-03, 1.00508035D-05/
      data fpp(11,17,1),fpp(11,17,2)/-6.31634618D-04, 9.24095394D-06/
      data fpp(11,18,1),fpp(11,18,2)/ 4.87221650D-04,-1.46626192D-05/
      data fpp(11,19,1),fpp(11,19,2)/ 4.87221650D-04,-1.46626192D-05/
      data fpp(11,20,1),fpp(11,20,2)/-6.31634618D-04, 9.24095394D-06/
      data fpp(11,21,1),fpp(11,21,2)/-2.98502819D-03, 1.00508035D-05/
      data fpp(11,22,1),fpp(11,22,2)/-3.32743394D-03, 5.80383209D-06/
      data fpp(11,23,1),fpp(11,23,2)/-2.57814852D-03, 1.23386816D-06/
      data fpp(11,24,1),fpp(11,24,2)/-1.63469235D-03,-7.67304713D-07/
      data fpp(11,25,1),fpp(11,25,2)/-8.76737550D-04,-1.14064930D-06/
      data fpp(11,26,1),fpp(11,26,2)/-3.61493022D-04,-9.52098077D-07/
      data fpp(11,27,1),fpp(11,27,2)/-3.72542741D-05,-7.86958393D-07/
      data fpp(11,28,1),fpp(11,28,2)/ 1.41555536D-04,-6.34068351D-07/
      data fpp(11,29,1),fpp(11,29,2)/ 1.92358250D-04,-6.72768209D-07/
      data fpp(11,30,1),fpp(11,30,2)/ 1.23305405D-04,-4.90858816D-07/
      data fpp(11,31,1),fpp(11,31,2)/-7.28330594D-06, 2.66203473D-07/
      data fpp(11,32,1),fpp(11,32,2)/-1.15734367D-05, 1.95204493D-06/
      data fpp(11,33,1),fpp(11,33,2)/ 4.99000629D-04, 3.45761682D-06/
      data fpp(11,34,1),fpp(11,34,2)/ 1.88960670D-03, 2.22948778D-06/
      data fpp(11,35,1),fpp(11,35,2)/ 3.55082450D-03,-3.84356794D-06/
      data fpp(11,36,1),fpp(11,36,2)/ 6.30855601D-03,-5.90521603D-06/
      data fpp(11,37,1),fpp(11,37,2)/ 3.55082450D-03,-3.84356793D-06/
      data fpp(11,38,1),fpp(11,38,2)/ 1.88960670D-03, 2.22948777D-06/
      data fpp(11,39,1),fpp(11,39,2)/ 4.99000629D-04, 3.45761687D-06/
      data fpp(11,40,1),fpp(11,40,2)/-1.15734367D-05, 1.95204476D-06/
      data fpp(11,41,1),fpp(11,41,2)/-7.28330594D-06, 2.66204100D-07/
      data fpp(11,42,1),fpp(11,42,2)/ 1.23305405D-04,-4.90861162D-07/
      data fpp(11,43,1),fpp(11,43,2)/ 1.92358250D-04,-6.72759452D-07/
      data fpp(11,44,1),fpp(11,44,2)/ 1.41555536D-04,-6.34101033D-07/
      data fpp(11,45,1),fpp(11,45,2)/-3.72542741D-05,-7.86836420D-07/
      data fpp(11,46,1),fpp(11,46,2)/-3.61493022D-04,-9.52553287D-07/
      data fpp(11,47,1),fpp(11,47,2)/-8.76737550D-04,-1.13895043D-06/
      data fpp(11,48,1),fpp(11,48,2)/-1.63469235D-03,-7.73644976D-07/
      data fpp(11,49,1),fpp(11,49,2)/-2.57814852D-03, 1.25753033D-06/
      data fpp(11,50,1),fpp(11,50,2)/-3.32743394D-03, 5.71552364D-06/
      data fpp(11,51,1),fpp(11,51,2)/-2.98502819D-03, 1.03803751D-05/
      data fpp(11,52,1),fpp(11,52,2)/-6.31634618D-04, 8.01097593D-06/
      data fpp(11,53,1),fpp(11,53,2)/ 4.87221650D-04,-1.00722788D-05/
      data fpp(11,54,1),fpp(11,54,2)/ 2.23992313D-02,-2.36658606D-05/
      data fpp(12, 1,1),fpp(12, 1,2)/ 1.36393346D-04,-1.32600558D-06/
      data fpp(12, 2,1),fpp(12, 2,2)/ 4.81257599D-04,-6.04988841D-07/
      data fpp(12, 3,1),fpp(12, 3,2)/ 1.97725107D-04, 3.67960938D-07/
      data fpp(12, 4,1),fpp(12, 4,2)/ 3.25300507D-06, 4.59145087D-07/
      data fpp(12, 5,1),fpp(12, 5,2)/-7.81930393D-05, 2.67458712D-07/
      data fpp(12, 6,1),fpp(12, 6,2)/-7.24275177D-05,-3.49799377D-08/
      data fpp(12, 7,1),fpp(12, 7,2)/-3.91161272D-05,-1.15538958D-07/
      data fpp(12, 8,1),fpp(12, 8,2)/-2.46527544D-05,-1.86864231D-07/
      data fpp(12, 9,1),fpp(12, 9,2)/-3.29135319D-05,-1.63004119D-07/
      data fpp(12,10,1),fpp(12,10,2)/-6.37011187D-05,-2.35119291D-07/
      data fpp(12,11,1),fpp(12,11,2)/-1.16607284D-04,-2.40518720D-07/
      data fpp(12,12,1),fpp(12,12,2)/-1.99291741D-04,-2.66805830D-07/
      data fpp(12,13,1),fpp(12,13,2)/-3.17428383D-04,-1.98257962D-07/
      data fpp(12,14,1),fpp(12,14,2)/-4.31856007D-04, 1.83837683D-07/
      data fpp(12,15,1),fpp(12,15,2)/-4.30969827D-04, 1.05290722D-06/
      data fpp(12,16,1),fpp(12,16,2)/-1.40889178D-04, 1.78453341D-06/
      data fpp(12,17,1),fpp(12,17,2)/ 5.83903121D-04, 1.24695912D-06/
      data fpp(12,18,1),fpp(12,18,2)/ 2.27116055D-03,-2.15236989D-06/
      data fpp(12,19,1),fpp(12,19,2)/ 2.27116055D-03,-2.15236989D-06/
      data fpp(12,20,1),fpp(12,20,2)/ 5.83903121D-04, 1.24695912D-06/
      data fpp(12,21,1),fpp(12,21,2)/-1.40889178D-04, 1.78453341D-06/
      data fpp(12,22,1),fpp(12,22,2)/-4.30969827D-04, 1.05290725D-06/
      data fpp(12,23,1),fpp(12,23,2)/-4.31856007D-04, 1.83837611D-07/
      data fpp(12,24,1),fpp(12,24,2)/-3.17428383D-04,-1.98257690D-07/
      data fpp(12,25,1),fpp(12,25,2)/-1.99291741D-04,-2.66806847D-07/
      data fpp(12,26,1),fpp(12,26,2)/-1.16607284D-04,-2.40514922D-07/
      data fpp(12,27,1),fpp(12,27,2)/-6.37011187D-05,-2.35133467D-07/
      data fpp(12,28,1),fpp(12,28,2)/-3.29135319D-05,-1.62951209D-07/
      data fpp(12,29,1),fpp(12,29,2)/-2.46527544D-05,-1.87061700D-07/
      data fpp(12,30,1),fpp(12,30,2)/-3.91161272D-05,-1.14801992D-07/
      data fpp(12,31,1),fpp(12,31,2)/-7.24275177D-05,-3.77303311D-08/
      data fpp(12,32,1),fpp(12,32,2)/-7.81930393D-05, 2.77723321D-07/
      data fpp(12,33,1),fpp(12,33,2)/ 3.25300507D-06, 4.20837049D-07/
      data fpp(12,34,1),fpp(12,34,2)/ 1.97725107D-04, 5.10928487D-07/
      data fpp(12,35,1),fpp(12,35,2)/ 4.81257599D-04,-1.13855100D-06/
      data fpp(12,36,1),fpp(12,36,2)/ 1.36393346D-04, 6.65275499D-07/
      data fpp(12,37,1),fpp(12,37,2)/ 4.81257599D-04,-1.13855100D-06/
      data fpp(12,38,1),fpp(12,38,2)/ 1.97725107D-04, 5.10928486D-07/
      data fpp(12,39,1),fpp(12,39,2)/ 3.25300507D-06, 4.20837053D-07/
      data fpp(12,40,1),fpp(12,40,2)/-7.81930393D-05, 2.77723309D-07/
      data fpp(12,41,1),fpp(12,41,2)/-7.24275177D-05,-3.77302845D-08/
      data fpp(12,42,1),fpp(12,42,2)/-3.91161272D-05,-1.14802170D-07/
      data fpp(12,43,1),fpp(12,43,2)/-2.46527544D-05,-1.87061037D-07/
      data fpp(12,44,1),fpp(12,44,2)/-3.29135319D-05,-1.62953684D-07/
      data fpp(12,45,1),fpp(12,45,2)/-6.37011187D-05,-2.35124228D-07/
      data fpp(12,46,1),fpp(12,46,2)/-1.16607284D-04,-2.40549404D-07/
      data fpp(12,47,1),fpp(12,47,2)/-1.99291741D-04,-2.66678159D-07/
      data fpp(12,48,1),fpp(12,48,2)/-3.17428383D-04,-1.98737962D-07/
      data fpp(12,49,1),fpp(12,49,2)/-4.31856007D-04, 1.85630009D-07/
      data fpp(12,50,1),fpp(12,50,2)/-4.30969827D-04, 1.04621793D-06/
      data fpp(12,51,1),fpp(12,51,2)/-1.40889178D-04, 1.80949829D-06/
      data fpp(12,52,1),fpp(12,52,2)/ 5.83903121D-04, 1.15378892D-06/
      data fpp(12,53,1),fpp(12,53,2)/ 2.27116055D-03,-1.80465398D-06/
      data fpp(12,54,1),fpp(12,54,2)/-2.57937473D-03,-4.10517301D-06/
      data fpp(13, 1,1),fpp(13, 1,2)/ 8.36706006D-05,-3.41274668D-07/
      data fpp(13, 2,1),fpp(13, 2,2)/-2.54548917D-05,-1.60450665D-07/
      data fpp(13, 3,1),fpp(13, 3,2)/-3.39071254D-05, 1.13077323D-07/
      data fpp(13, 4,1),fpp(13, 4,2)/-4.58126490D-05, 6.21413735D-08/
      data fpp(13, 5,1),fpp(13, 5,2)/-4.40544059D-05, 2.83571794D-08/
      data fpp(13, 6,1),fpp(13, 6,2)/-3.72066229D-05,-3.15700924D-08/
      data fpp(13, 7,1),fpp(13, 7,2)/-3.28408962D-05,-6.40768076D-08/
      data fpp(13, 8,1),fpp(13, 8,2)/-2.71472322D-05,-6.61226727D-08/
      data fpp(13, 9,1),fpp(13, 9,2)/-2.61014077D-05,-6.14325043D-08/
      data fpp(13,10,1),fpp(13,10,2)/-3.01412507D-05,-7.21473067D-08/
      data fpp(13,11,1),fpp(13,11,2)/-4.56778418D-05,-5.79782680D-08/
      data fpp(13,12,1),fpp(13,12,2)/-7.38954838D-05,-1.15939625D-07/
      data fpp(13,13,1),fpp(13,13,2)/-1.05194114D-04,-8.42632339D-08/
      data fpp(13,14,1),fpp(13,14,2)/-1.38027454D-04,-4.50074394D-08/
      data fpp(13,15,1),fpp(13,15,2)/-1.60886757D-04, 1.26292985D-07/
      data fpp(13,16,1),fpp(13,16,2)/-1.42015098D-04, 3.01835494D-07/
      data fpp(13,17,1),fpp(13,17,2)/-7.43778638D-05, 2.80365033D-07/
      data fpp(13,18,1),fpp(13,18,2)/-1.89663834D-04,-2.11295629D-07/
      data fpp(13,19,1),fpp(13,19,2)/-1.89663834D-04,-2.11295629D-07/
      data fpp(13,20,1),fpp(13,20,2)/-7.43778638D-05, 2.80365034D-07/
      data fpp(13,21,1),fpp(13,21,2)/-1.42015098D-04, 3.01835491D-07/
      data fpp(13,22,1),fpp(13,22,2)/-1.60886757D-04, 1.26292997D-07/
      data fpp(13,23,1),fpp(13,23,2)/-1.38027454D-04,-4.50074804D-08/
      data fpp(13,24,1),fpp(13,24,2)/-1.05194114D-04,-8.42630747D-08/
      data fpp(13,25,1),fpp(13,25,2)/-7.38954838D-05,-1.15940217D-07/
      data fpp(13,26,1),fpp(13,26,2)/-4.56778418D-05,-5.79760583D-08/
      data fpp(13,27,1),fpp(13,27,2)/-3.01412507D-05,-7.21555554D-08/
      data fpp(13,28,1),fpp(13,28,2)/-2.61014077D-05,-6.14017169D-08/
      data fpp(13,29,1),fpp(13,29,2)/-2.71472322D-05,-6.62375812D-08/
      data fpp(13,30,1),fpp(13,30,2)/-3.28408962D-05,-6.36479620D-08/
      data fpp(13,31,1),fpp(13,31,2)/-3.72066229D-05,-3.31705679D-08/
      data fpp(13,32,1),fpp(13,32,2)/-4.40544059D-05, 3.43302355D-08/
      data fpp(13,33,1),fpp(13,33,2)/-4.58126490D-05, 3.98496281D-08/
      data fpp(13,34,1),fpp(13,34,2)/-3.39071254D-05, 1.96271255D-07/
      data fpp(13,35,1),fpp(13,35,2)/-2.54548917D-05,-4.70934644D-07/
      data fpp(13,36,1),fpp(13,36,2)/ 8.36706006D-05, 8.17467324D-07/
      data fpp(13,37,1),fpp(13,37,2)/-2.54548917D-05,-4.70934645D-07/
      data fpp(13,38,1),fpp(13,38,2)/-3.39071254D-05, 1.96271255D-07/
      data fpp(13,39,1),fpp(13,39,2)/-4.58126490D-05, 3.98496257D-08/
      data fpp(13,40,1),fpp(13,40,2)/-4.40544059D-05, 3.43302449D-08/
      data fpp(13,41,1),fpp(13,41,2)/-3.72066229D-05,-3.31706001D-08/
      data fpp(13,42,1),fpp(13,42,2)/-3.28408962D-05,-6.36478453D-08/
      data fpp(13,43,1),fpp(13,43,2)/-2.71472322D-05,-6.62380173D-08/
      data fpp(13,44,1),fpp(13,44,2)/-2.61014077D-05,-6.14000889D-08/
      data fpp(13,45,1),fpp(13,45,2)/-3.01412507D-05,-7.21616305D-08/
      data fpp(13,46,1),fpp(13,46,2)/-4.56778418D-05,-5.79533888D-08/
      data fpp(13,47,1),fpp(13,47,2)/-7.38954838D-05,-1.16024819D-07/
      data fpp(13,48,1),fpp(13,48,2)/-1.05194114D-04,-8.39473363D-08/
      data fpp(13,49,1),fpp(13,49,2)/-1.38027454D-04,-4.61858352D-08/
      data fpp(13,50,1),fpp(13,50,2)/-1.60886757D-04, 1.30690680D-07/
      data fpp(13,51,1),fpp(13,51,2)/-1.42015098D-04, 2.85423118D-07/
      data fpp(13,52,1),fpp(13,52,2)/-7.43778638D-05, 3.41616852D-07/
      data fpp(13,53,1),fpp(13,53,2)/-1.89663834D-04,-4.39890530D-07/
      data fpp(13,54,1),fpp(13,54,2)/ 1.25266758D-03,-9.82054735D-07/
      data fpp(14, 1,1),fpp(14, 1,2)/-3.36757488D-05,-2.93178660D-07/
      data fpp(14, 2,1),fpp(14, 2,2)/-1.88380322D-05,-1.52642680D-07/
      data fpp(14, 3,1),fpp(14, 3,2)/-2.42966056D-05, 8.17493769D-08/
      data fpp(14, 4,1),fpp(14, 4,2)/-2.70024091D-05,-1.23548260D-08/
      data fpp(14, 5,1),fpp(14, 5,2)/-2.63893374D-05,-1.43300754D-08/
      data fpp(14, 6,1),fpp(14, 6,2)/-2.23459908D-05,-2.63248723D-08/
      data fpp(14, 7,1),fpp(14, 7,2)/-1.73202879D-05,-3.03704313D-08/
      data fpp(14, 8,1),fpp(14, 8,2)/-1.43583173D-05,-3.21934027D-08/
      data fpp(14, 9,1),fpp(14, 9,2)/-1.26808370D-05,-2.08559589D-08/
      data fpp(14,10,1),fpp(14,10,2)/-1.31338781D-05,-2.83827573D-08/
      data fpp(14,11,1),fpp(14,11,2)/-1.44813488D-05,-2.76130155D-08/
      data fpp(14,12,1),fpp(14,12,2)/-1.63263234D-05,-4.71651820D-08/
      data fpp(14,13,1),fpp(14,13,2)/-2.31951589D-05,-1.77262586D-08/
      data fpp(14,14,1),fpp(14,14,2)/-3.42341748D-05,-6.79297838D-08/
      data fpp(14,15,1),fpp(14,15,2)/-4.26831462D-05, 1.44539108D-09/
      data fpp(14,16,1),fpp(14,16,2)/-4.52504312D-05, 2.61482141D-08/
      data fpp(14,17,1),fpp(14,17,2)/-3.43916655D-05, 1.15961751D-07/
      data fpp(14,18,1),fpp(14,18,2)/ 1.74947908D-05, 3.20047815D-08/
      data fpp(14,19,1),fpp(14,19,2)/ 1.74947908D-05, 3.20047809D-08/
      data fpp(14,20,1),fpp(14,20,2)/-3.43916655D-05, 1.15961752D-07/
      data fpp(14,21,1),fpp(14,21,2)/-4.52504312D-05, 2.61482106D-08/
      data fpp(14,22,1),fpp(14,22,2)/-4.26831462D-05, 1.44540328D-09/
      data fpp(14,23,1),fpp(14,23,2)/-3.42341748D-05,-6.79298270D-08/
      data fpp(14,24,1),fpp(14,24,2)/-2.31951589D-05,-1.77260920D-08/
      data fpp(14,25,1),fpp(14,25,2)/-1.63263234D-05,-4.71658034D-08/
      data fpp(14,26,1),fpp(14,26,2)/-1.44813488D-05,-2.76106952D-08/
      data fpp(14,27,1),fpp(14,27,2)/-1.31338781D-05,-2.83914167D-08/
      data fpp(14,28,1),fpp(14,28,2)/-1.26808370D-05,-2.08236371D-08/
      data fpp(14,29,1),fpp(14,29,2)/-1.43583173D-05,-3.23140365D-08/
      data fpp(14,30,1),fpp(14,30,2)/-1.73202879D-05,-2.99202177D-08/
      data fpp(14,31,1),fpp(14,31,2)/-2.23459908D-05,-2.80050928D-08/
      data fpp(14,32,1),fpp(14,32,2)/-2.63893374D-05,-8.05940807D-09/
      data fpp(14,33,1),fpp(14,33,2)/-2.70024091D-05,-3.57572717D-08/
      data fpp(14,34,1),fpp(14,34,2)/-2.42966056D-05, 1.69088497D-07/
      data fpp(14,35,1),fpp(14,35,2)/-1.88380322D-05,-4.78596712D-07/
      data fpp(14,36,1),fpp(14,36,2)/-3.36757488D-05, 9.23298357D-07/
      data fpp(14,37,1),fpp(14,37,2)/-1.88380322D-05,-4.78596713D-07/
      data fpp(14,38,1),fpp(14,38,2)/-2.42966056D-05, 1.69088497D-07/
      data fpp(14,39,1),fpp(14,39,2)/-2.70024091D-05,-3.57572735D-08/
      data fpp(14,40,1),fpp(14,40,2)/-2.63893374D-05,-8.05940082D-09/
      data fpp(14,41,1),fpp(14,41,2)/-2.23459908D-05,-2.80051190D-08/
      data fpp(14,42,1),fpp(14,42,2)/-1.73202879D-05,-2.99201221D-08/
      data fpp(14,43,1),fpp(14,43,2)/-1.43583173D-05,-3.23143944D-08/
      data fpp(14,44,1),fpp(14,44,2)/-1.26808370D-05,-2.08223003D-08/
      data fpp(14,45,1),fpp(14,45,2)/-1.31338781D-05,-2.83964039D-08/
      data fpp(14,46,1),fpp(14,46,2)/-1.44813488D-05,-2.75920866D-08/
      data fpp(14,47,1),fpp(14,47,2)/-1.63263234D-05,-4.72352505D-08/
      data fpp(14,48,1),fpp(14,48,2)/-2.31951589D-05,-1.74669139D-08/
      data fpp(14,49,1),fpp(14,49,2)/-3.42341748D-05,-6.88970949D-08/
      data fpp(14,50,1),fpp(14,50,2)/-4.26831462D-05, 5.05529892D-09/
      data fpp(14,51,1),fpp(14,51,2)/-4.52504312D-05, 1.26759001D-08/
      data fpp(14,52,1),fpp(14,52,2)/-3.43916655D-05, 1.66241103D-07/
      data fpp(14,53,1),fpp(14,53,2)/ 1.74947908D-05,-1.55640316D-07/
      data fpp(14,54,1),fpp(14,54,2)/-2.40095591D-04,-3.41679843D-07/
      data fpp(15, 1,1),fpp(15, 1,2)/-4.85805381D-06,-3.20298795D-07/
      data fpp(15, 2,1),fpp(15, 2,2)/-7.85845738D-06,-1.76402412D-07/
      data fpp(15, 3,1),fpp(15, 3,2)/-6.30662020D-06, 5.99084399D-08/
      data fpp(15, 4,1),fpp(15, 4,2)/-4.83644804D-06,-2.72313474D-08/
      data fpp(15, 5,1),fpp(15, 5,2)/-3.50478483D-06,-1.09830518D-08/
      data fpp(15, 6,1),fpp(15, 6,2)/-2.70871625D-06,-1.28364455D-08/
      data fpp(15, 7,1),fpp(15, 7,2)/-2.26868828D-06,-9.67116004D-09/
      data fpp(15, 8,1),fpp(15, 8,2)/-1.85143201D-06,-2.47891172D-09/
      data fpp(15, 9,1),fpp(15, 9,2)/-1.85678492D-06,-4.41319469D-09/
      data fpp(15,10,1),fpp(15,10,2)/-1.92774039D-06,-3.86830796D-09/
      data fpp(15,11,1),fpp(15,11,2)/-2.41703239D-06,-4.11357218D-09/
      data fpp(15,12,1),fpp(15,12,2)/-3.32328783D-06,-2.76774057D-08/
      data fpp(15,13,1),fpp(15,13,2)/-3.36746594D-06,-5.17680526D-09/
      data fpp(15,14,1),fpp(15,14,2)/-2.88374826D-06,-2.36153745D-08/
      data fpp(15,15,1),fpp(15,15,2)/-3.45718293D-06,-2.03617020D-08/
      data fpp(15,16,1),fpp(15,16,2)/-4.59115760D-06,-8.93782227D-09/
      data fpp(15,17,1),fpp(15,17,2)/-7.23607167D-06, 2.01129865D-08/
      data fpp(15,18,1),fpp(15,18,2)/-1.70524551D-05, 4.84858771D-08/
      data fpp(15,19,1),fpp(15,19,2)/-1.70524551D-05, 4.84858768D-08/
      data fpp(15,20,1),fpp(15,20,2)/-7.23607167D-06, 2.01129872D-08/
      data fpp(15,21,1),fpp(15,21,2)/-4.59115760D-06,-8.93782537D-09/
      data fpp(15,22,1),fpp(15,22,2)/-3.45718293D-06,-2.03616902D-08/
      data fpp(15,23,1),fpp(15,23,2)/-2.88374826D-06,-2.36154166D-08/
      data fpp(15,24,1),fpp(15,24,2)/-3.36746594D-06,-5.17664142D-09/
      data fpp(15,25,1),fpp(15,25,2)/-3.32328783D-06,-2.76780163D-08/
      data fpp(15,26,1),fpp(15,26,2)/-2.41703239D-06,-4.11129200D-09/
      data fpp(15,27,1),fpp(15,27,2)/-1.92774039D-06,-3.87681953D-09/
      data fpp(15,28,1),fpp(15,28,2)/-1.85678492D-06,-4.38142497D-09/
      data fpp(15,29,1),fpp(15,29,2)/-1.85143201D-06,-2.59748459D-09/
      data fpp(15,30,1),fpp(15,30,2)/-2.26868828D-06,-9.22863947D-09/
      data fpp(15,31,1),fpp(15,31,2)/-2.70871625D-06,-1.44879579D-08/
      data fpp(15,32,1),fpp(15,32,2)/-3.50478483D-06,-4.81952462D-09/
      data fpp(15,33,1),fpp(15,33,2)/-4.83644804D-06,-5.02339414D-08/
      data fpp(15,34,1),fpp(15,34,2)/-6.30662020D-06, 1.45755292D-07/
      data fpp(15,35,1),fpp(15,35,2)/-7.85845738D-06,-4.96787226D-07/
      data fpp(15,36,1),fpp(15,36,2)/-4.85805381D-06, 8.75393614D-07/
      data fpp(15,37,1),fpp(15,37,2)/-7.85845738D-06,-4.96787226D-07/
      data fpp(15,38,1),fpp(15,38,2)/-6.30662020D-06, 1.45755293D-07/
      data fpp(15,39,1),fpp(15,39,2)/-4.83644804D-06,-5.02339433D-08/
      data fpp(15,40,1),fpp(15,40,2)/-3.50478483D-06,-4.81951612D-09/
      data fpp(15,41,1),fpp(15,41,2)/-2.70871625D-06,-1.44879888D-08/
      data fpp(15,42,1),fpp(15,42,2)/-2.26868828D-06,-9.22852734D-09/
      data fpp(15,43,1),fpp(15,43,2)/-1.85143201D-06,-2.59790268D-09/
      data fpp(15,44,1),fpp(15,44,2)/-1.85678492D-06,-4.37986329D-09/
      data fpp(15,45,1),fpp(15,45,2)/-1.92774039D-06,-3.88264816D-09/
      data fpp(15,46,1),fpp(15,46,2)/-2.41703239D-06,-4.08954394D-09/
      data fpp(15,47,1),fpp(15,47,2)/-3.32328783D-06,-2.77591812D-08/
      data fpp(15,48,1),fpp(15,48,2)/-3.36746594D-06,-4.87373053D-09/
      data fpp(15,49,1),fpp(15,49,2)/-2.88374826D-06,-2.47458983D-08/
      data fpp(15,50,1),fpp(15,50,2)/-3.45718293D-06,-1.61426733D-08/
      data fpp(15,51,1),fpp(15,51,2)/-4.59115760D-06,-2.46834067D-08/
      data fpp(15,52,1),fpp(15,52,2)/-7.23607167D-06, 7.88763016D-08/
      data fpp(15,53,1),fpp(15,53,2)/-1.70524551D-05,-1.70821801D-07/
      data fpp(15,54,1),fpp(15,54,2)/ 3.95029838D-05,-3.19589099D-07/
      data fpp(16, 1,1),fpp(16, 1,2)/-4.38932138D-06,-3.63203965D-07/
      data fpp(16, 2,1),fpp(16, 2,2)/-3.51312058D-06,-2.00592069D-07/
      data fpp(16, 3,1),fpp(16, 3,2)/-3.48019551D-06, 5.55722399D-08/
      data fpp(16, 4,1),fpp(16, 4,2)/-3.24356711D-06,-1.56968918D-08/
      data fpp(16, 5,1),fpp(16, 5,2)/-2.85782560D-06, 1.21532763D-09/
      data fpp(16, 6,1),fpp(16, 6,2)/-2.37361861D-06,-1.16441856D-09/
      data fpp(16, 7,1),fpp(16, 7,2)/-1.92418038D-06,-2.55764938D-09/
      data fpp(16, 8,1),fpp(16, 8,2)/-1.65634844D-06,-6.04984524D-10/
      data fpp(16, 9,1),fpp(16, 9,2)/-1.52349224D-06,-1.02241385D-09/
      data fpp(16,10,1),fpp(16,10,2)/-1.55161325D-06,-1.30535724D-09/
      data fpp(16,11,1),fpp(16,11,2)/-1.68899281D-06, 2.43842163D-10/
      data fpp(16,12,1),fpp(16,12,2)/-1.93815826D-06,-5.67001247D-09/
      data fpp(16,13,1),fpp(16,13,2)/-2.54500757D-06,-1.56379673D-09/
      data fpp(16,14,1),fpp(16,14,2)/-3.43138928D-06,-6.07480003D-09/
      data fpp(16,15,1),fpp(16,15,2)/-4.32062602D-06,-4.13700704D-09/
      data fpp(16,16,1),fpp(16,16,2)/-4.96252053D-06,-1.37717948D-09/
      data fpp(16,17,1),fpp(16,17,2)/-4.88531741D-06, 3.64572369D-09/
      data fpp(16,18,1),fpp(16,18,2)/-2.62167664D-06, 1.07942852D-08/
      data fpp(16,19,1),fpp(16,19,2)/-2.62167664D-06, 1.07942846D-08/
      data fpp(16,20,1),fpp(16,20,2)/-4.88531741D-06, 3.64572472D-09/
      data fpp(16,21,1),fpp(16,21,2)/-4.96252053D-06,-1.37718301D-09/
      data fpp(16,22,1),fpp(16,22,2)/-4.32062602D-06,-4.13699465D-09/
      data fpp(16,23,1),fpp(16,23,2)/-3.43138928D-06,-6.07484242D-09/
      data fpp(16,24,1),fpp(16,24,2)/-2.54500757D-06,-1.56363210D-09/
      data fpp(16,25,1),fpp(16,25,2)/-1.93815826D-06,-5.67062497D-09/
      data fpp(16,26,1),fpp(16,26,2)/-1.68899281D-06, 2.46131494D-10/
      data fpp(16,27,1),fpp(16,27,2)/-1.55161325D-06,-1.31390163D-09/
      data fpp(16,28,1),fpp(16,28,2)/-1.52349224D-06,-9.90521569D-10/
      data fpp(16,29,1),fpp(16,29,2)/-1.65634844D-06,-7.24015080D-10/
      data fpp(16,30,1),fpp(16,30,2)/-1.92418038D-06,-2.11341890D-09/
      data fpp(16,31,1),fpp(16,31,2)/-2.37361861D-06,-2.82231006D-09/
      data fpp(16,32,1),fpp(16,32,2)/-2.85782560D-06, 7.40266303D-09/
      data fpp(16,33,1),fpp(16,33,2)/-3.24356711D-06,-3.87883410D-08/
      data fpp(16,34,1),fpp(16,34,2)/-3.48019551D-06, 1.41750707D-07/
      data fpp(16,35,1),fpp(16,35,2)/-3.51312058D-06,-5.22214487D-07/
      data fpp(16,36,1),fpp(16,36,2)/-4.38932138D-06, 8.37107244D-07/
      data fpp(16,37,1),fpp(16,37,2)/-3.51312058D-06,-5.22214487D-07/
      data fpp(16,38,1),fpp(16,38,2)/-3.48019551D-06, 1.41750708D-07/
      data fpp(16,39,1),fpp(16,39,2)/-3.24356711D-06,-3.87883431D-08/
      data fpp(16,40,1),fpp(16,40,2)/-2.85782560D-06, 7.40267134D-09/
      data fpp(16,41,1),fpp(16,41,2)/-2.37361861D-06,-2.82233970D-09/
      data fpp(16,42,1),fpp(16,42,2)/-1.92418038D-06,-2.11331278D-09/
      data fpp(16,43,1),fpp(16,43,2)/-1.65634844D-06,-7.24411279D-10/
      data fpp(16,44,1),fpp(16,44,2)/-1.52349224D-06,-9.89043325D-10/
      data fpp(16,45,1),fpp(16,45,2)/-1.55161325D-06,-1.31941871D-09/
      data fpp(16,46,1),fpp(16,46,2)/-1.68899281D-06, 2.66716988D-10/
      data fpp(16,47,1),fpp(16,47,2)/-1.93815826D-06,-5.74745236D-09/
      data fpp(16,48,1),fpp(16,48,2)/-2.54500757D-06,-1.27691277D-09/
      data fpp(16,49,1),fpp(16,49,2)/-3.43138928D-06,-7.14489683D-09/
      data fpp(16,50,1),fpp(16,50,2)/-4.32062602D-06,-1.43494692D-10/
      data fpp(16,51,1),fpp(16,51,2)/-4.96252053D-06,-1.62811242D-08/
      data fpp(16,52,1),fpp(16,52,2)/-4.88531741D-06, 5.92679949D-08/
      data fpp(16,53,1),fpp(16,53,2)/-2.62167664D-06,-1.96790857D-07/
      data fpp(16,54,1),fpp(16,54,2)/-1.49795520D-05,-3.58104571D-07/
      data fpp(17, 1,1),fpp(17, 1,2)/ 6.81666070D-06,-3.91800187D-07/
      data fpp(17, 2,1),fpp(17, 2,2)/ 6.68506032D-06,-2.16399627D-07/
      data fpp(17, 3,1),fpp(17, 3,2)/ 7.12059777D-06, 5.73986932D-08/
      data fpp(17, 4,1),fpp(17, 4,2)/ 7.12928357D-06,-1.31951451D-08/
      data fpp(17, 5,1),fpp(17, 5,2)/ 6.43191280D-06, 1.38188486D-09/
      data fpp(17, 6,1),fpp(17, 6,2)/ 5.28480930D-06, 1.66760593D-09/
      data fpp(17, 7,1),fpp(17, 7,2)/ 4.07059019D-06,-2.05230461D-09/
      data fpp(17, 8,1),fpp(17, 8,2)/ 3.19517423D-06, 5.41614767D-10/
      data fpp(17, 9,1),fpp(17, 9,2)/ 2.90924615D-06,-1.14155005D-10/
      data fpp(17,10,1),fpp(17,10,2)/ 3.08180664D-06,-8.49927650D-11/
      data fpp(17,11,1),fpp(17,11,2)/ 3.75899643D-06, 4.54125524D-10/
      data fpp(17,12,1),fpp(17,12,2)/ 4.78807913D-06,-1.73151087D-09/
      data fpp(17,13,1),fpp(17,13,2)/ 5.87650380D-06, 4.71915834D-10/
      data fpp(17,14,1),fpp(17,14,2)/ 7.25469467D-06,-1.56151806D-10/
      data fpp(17,15,1),fpp(17,15,2)/ 8.79631302D-06, 1.52685930D-10/
      data fpp(17,16,1),fpp(17,16,2)/ 9.37876029D-06,-4.54598480D-10/
      data fpp(17,17,1),fpp(17,17,2)/ 8.39065871D-06, 1.66570299D-09/
      data fpp(17,18,1),fpp(17,18,2)/ 5.27683833D-06,-2.08212358D-10/
      data fpp(17,19,1),fpp(17,19,2)/ 5.27683833D-06,-2.08212977D-10/
      data fpp(17,20,1),fpp(17,20,2)/ 8.39065871D-06, 1.66570392D-09/
      data fpp(17,21,1),fpp(17,21,2)/ 9.37876029D-06,-4.54602186D-10/
      data fpp(17,22,1),fpp(17,22,2)/ 8.79631302D-06, 1.52699398D-10/
      data fpp(17,23,1),fpp(17,23,2)/ 7.25469467D-06,-1.56196854D-10/
      data fpp(17,24,1),fpp(17,24,2)/ 5.87650380D-06, 4.72089686D-10/
      data fpp(17,25,1),fpp(17,25,2)/ 4.78807913D-06,-1.73215940D-09/
      data fpp(17,26,1),fpp(17,26,2)/ 3.75899643D-06, 4.56548145D-10/
      data fpp(17,27,1),fpp(17,27,2)/ 3.08180664D-06,-9.40347929D-11/
      data fpp(17,28,1),fpp(17,28,2)/ 2.90924615D-06,-8.04061765D-11/
      data fpp(17,29,1),fpp(17,29,2)/ 3.19517423D-06, 4.15656233D-10/
      data fpp(17,30,1),fpp(17,30,2)/ 4.07059019D-06,-1.58221957D-09/
      data fpp(17,31,1),fpp(17,31,2)/ 5.28480930D-06,-8.67769438D-11/
      data fpp(17,32,1),fpp(17,32,2)/ 6.43191280D-06, 7.92933041D-09/
      data fpp(17,33,1),fpp(17,33,2)/ 7.12928357D-06,-3.76305420D-08/
      data fpp(17,34,1),fpp(17,34,2)/ 7.12059777D-06, 1.48592839D-07/
      data fpp(17,35,1),fpp(17,35,2)/ 6.68506032D-06,-5.56740811D-07/
      data fpp(17,36,1),fpp(17,36,2)/ 6.81666070D-06, 8.78370406D-07/
      data fpp(17,37,1),fpp(17,37,2)/ 6.68506032D-06,-5.56740811D-07/
      data fpp(17,38,1),fpp(17,38,2)/ 7.12059777D-06, 1.48592839D-07/
      data fpp(17,39,1),fpp(17,39,2)/ 7.12928357D-06,-3.76305436D-08/
      data fpp(17,40,1),fpp(17,40,2)/ 6.43191280D-06, 7.92933858D-09/
      data fpp(17,41,1),fpp(17,41,2)/ 5.28480930D-06,-8.68077894D-11/
      data fpp(17,42,1),fpp(17,42,2)/ 4.07059019D-06,-1.58210904D-09/
      data fpp(17,43,1),fpp(17,43,2)/ 3.19517423D-06, 4.15243109D-10/
      data fpp(17,44,1),fpp(17,44,2)/ 2.90924615D-06,-7.88642809D-11/
      data fpp(17,45,1),fpp(17,45,2)/ 3.08180664D-06,-9.97901528D-11/
      data fpp(17,46,1),fpp(17,46,2)/ 3.75899643D-06, 4.78024163D-10/
      data fpp(17,47,1),fpp(17,47,2)/ 4.78807913D-06,-1.81230818D-09/
      data fpp(17,48,1),fpp(17,48,2)/ 5.87650380D-06, 7.71207086D-10/
      data fpp(17,49,1),fpp(17,49,2)/ 7.25469467D-06,-1.27252098D-09/
      data fpp(17,50,1),fpp(17,50,2)/ 8.79631302D-06, 4.31888001D-09/
      data fpp(17,51,1),fpp(17,51,2)/ 9.37876029D-06,-1.60029987D-08/
      data fpp(17,52,1),fpp(17,52,2)/ 8.39065871D-06, 5.96931149D-08/
      data fpp(17,53,1),fpp(17,53,2)/ 5.27683833D-06,-2.16769461D-07/
      data fpp(17,54,1),fpp(17,54,2)/ 9.75277601D-06,-3.92615269D-07/
 
      data fpppp( 1, 1),fpppp( 1, 2)/-2.29450550D-03,-8.89094190D-04/
      data fpppp( 1, 3),fpppp( 1, 4)/ 1.40972057D-03, 5.81623252D-04/
      data fpppp( 1, 5),fpppp( 1, 6)/ 4.23354568D-04, 1.24038841D-03/
      data fpppp( 1, 7),fpppp( 1, 8)/-7.17535309D-04,-5.43136530D-04/
      data fpppp( 1, 9),fpppp( 1,10)/ 5.89463883D-05, 5.83070735D-05/
      data fpppp( 1,11),fpppp( 1,12)/ 7.50259934D-05, 5.37510879D-05/
      data fpppp( 1,13),fpppp( 1,14)/ 1.41850180D-04,-4.11987986D-05/
      data fpppp( 1,15),fpppp( 1,16)/ 1.11623199D-03,-1.52691007D-03/
      data fpppp( 1,17),fpppp( 1,18)/ 6.86055358D-03,-4.36074671D-03/
      data fpppp( 1,19),fpppp( 1,20)/-4.36074671D-03, 6.86055358D-03/
      data fpppp( 1,21),fpppp( 1,22)/-1.52691006D-03, 1.11623197D-03/
      data fpppp( 1,23),fpppp( 1,24)/-4.11987207D-05, 1.41849889D-04/
      data fpppp( 1,25),fpppp( 1,26)/ 5.37521743D-05, 7.50219388D-05/
      data fpppp( 1,27),fpppp( 1,28)/ 5.83222049D-05, 5.88899170D-05/
      data fpppp( 1,29),fpppp( 1,30)/-5.42925776D-04,-7.18321855D-04/
      data fpppp( 1,31),fpppp( 1,32)/ 1.24332384D-03, 4.12399405D-04/
      data fpppp( 1,33),fpppp( 1,34)/ 6.22508474D-04, 1.25713484D-03/
      data fpppp( 1,35),fpppp( 1,36)/-3.19636513D-04,-4.41975048D-03/
      data fpppp( 1,37),fpppp( 1,38)/-3.19636512D-04, 1.25713484D-03/
      data fpppp( 1,39),fpppp( 1,40)/ 6.22508488D-04, 4.12399353D-04/
      data fpppp( 1,41),fpppp( 1,42)/ 1.24332403D-03,-7.18322590D-04/
      data fpppp( 1,43),fpppp( 1,44)/-5.42923030D-04, 5.88796700D-05/
      data fpppp( 1,45),fpppp( 1,46)/ 5.83604473D-05, 7.48792166D-05/
      data fpppp( 1,47),fpppp( 1,48)/ 5.42848211D-05, 1.39862024D-04/
      data fpppp( 1,49),fpppp( 1,50)/-3.37799067D-05, 1.08854458D-03/
      data fpppp( 1,51),fpppp( 1,52)/-1.42357931D-03, 6.47491798D-03/
      data fpppp( 1,53),fpppp( 1,54)/-2.92153506D-03,-7.37657371D-03/
      data fpppp( 2, 1),fpppp( 2, 2)/-2.42971670D-03,-1.03670623D-03/
      data fpppp( 2, 3),fpppp( 2, 4)/ 1.16986500D-03, 5.28973570D-04/
      data fpppp( 2, 5),fpppp( 2, 6)/ 4.26604433D-04, 6.45598832D-04/
      data fpppp( 2, 7),fpppp( 2, 8)/-5.65745563D-04,-3.65787867D-04/
      data fpppp( 2, 9),fpppp( 2,10)/ 1.77671110D-05, 3.15572276D-05/
      data fpppp( 2,11),fpppp( 2,12)/ 4.54526276D-05, 3.63079928D-05/
      data fpppp( 2,13),fpppp( 2,14)/ 9.27543518D-05, 1.67685812D-05/
      data fpppp( 2,15),fpppp( 2,16)/ 7.23047370D-04,-6.78046264D-04/
      data fpppp( 2,17),fpppp( 2,18)/ 4.26044707D-03,-2.91220711D-03/
      data fpppp( 2,19),fpppp( 2,20)/-2.91220711D-03, 4.26044707D-03/
      data fpppp( 2,21),fpppp( 2,22)/-6.78046266D-04, 7.23047378D-04/
      data fpppp( 2,23),fpppp( 2,24)/ 1.67685514D-05, 9.27544630D-05/
      data fpppp( 2,25),fpppp( 2,26)/ 3.63075778D-05, 4.54541761D-05/
      data fpppp( 2,27),fpppp( 2,28)/ 3.15514485D-05, 1.77886787D-05/
      data fpppp( 2,29),fpppp( 2,30)/-3.65868358D-04,-5.65445165D-04/
      data fpppp( 2,31),fpppp( 2,32)/ 6.44477730D-04, 4.30788443D-04/
      data fpppp( 2,33),fpppp( 2,34)/ 5.13358634D-04, 1.22814074D-03/
      data fpppp( 2,35),fpppp( 2,36)/-1.25419424D-03,-1.61804040D-03/
      data fpppp( 2,37),fpppp( 2,38)/-1.25419424D-03, 1.22814074D-03/
      data fpppp( 2,39),fpppp( 2,40)/ 5.13358643D-04, 4.30788406D-04/
      data fpppp( 2,41),fpppp( 2,42)/ 6.44477866D-04,-5.65445670D-04/
      data fpppp( 2,43),fpppp( 2,44)/-3.65866470D-04, 1.77816334D-05/
      data fpppp( 2,45),fpppp( 2,46)/ 3.15777418D-05, 4.53560481D-05/
      data fpppp( 2,47),fpppp( 2,48)/ 3.66737965D-05, 9.13877165D-05/
      data fpppp( 2,49),fpppp( 2,50)/ 2.18693188D-05, 7.04011055D-04/
      data fpppp( 2,51),fpppp( 2,52)/-6.07001742D-04, 3.99530529D-03/
      data fpppp( 2,53),fpppp( 2,54)/-1.92268453D-03,-4.83487525D-03/
      data fpppp( 3, 1),fpppp( 3, 2)/ 6.29651489D-04, 5.51060723D-04/
      data fpppp( 3, 3),fpppp( 3, 4)/ 3.99173773D-04, 5.03823467D-04/
      data fpppp( 3, 5),fpppp( 3, 6)/ 6.15709355D-04,-9.69513581D-05/
      data fpppp( 3, 7),fpppp( 3, 8)/-4.44693617D-04,-1.28199673D-04/
      data fpppp( 3, 9),fpppp( 3,10)/-4.50529773D-05, 4.26414104D-09/
      data fpppp( 3,11),fpppp( 3,12)/ 1.17406501D-05, 2.17680778D-05/
      data fpppp( 3,13),fpppp( 3,14)/ 3.83507120D-05, 1.08100140D-04/
      data fpppp( 3,15),fpppp( 3,16)/ 1.95557566D-04, 5.16503311D-04/
      data fpppp( 3,17),fpppp( 3,18)/ 1.41444635D-03,-1.45568589D-03/
      data fpppp( 3,19),fpppp( 3,20)/-1.45568589D-03, 1.41444635D-03/
      data fpppp( 3,21),fpppp( 3,22)/ 5.16503327D-04, 1.95557505D-04/
      data fpppp( 3,23),fpppp( 3,24)/ 1.08100368D-04, 3.83498614D-05/
      data fpppp( 3,25),fpppp( 3,26)/ 2.17712522D-05, 1.17288032D-05/
      data fpppp( 3,27),fpppp( 3,28)/ 4.84777136D-08,-4.52179845D-05/
      data fpppp( 3,29),fpppp( 3,30)/-1.27583858D-04,-4.46991870D-04/
      data fpppp( 3,31),fpppp( 3,32)/-8.83741607D-05, 5.83698818D-04/
      data fpppp( 3,33),fpppp( 3,34)/ 6.23288415D-04,-4.66754836D-05/
      data fpppp( 3,35),fpppp( 3,36)/ 2.21499280D-03,-5.58022757D-03/
      data fpppp( 3,37),fpppp( 3,38)/ 2.21499280D-03,-4.66754848D-05/
      data fpppp( 3,39),fpppp( 3,40)/ 6.23288420D-04, 5.83698800D-04/
      data fpppp( 3,41),fpppp( 3,42)/-8.83740925D-05,-4.46992124D-04/
      data fpppp( 3,43),fpppp( 3,44)/-1.27582909D-04,-4.52215272D-05/
      data fpppp( 3,45),fpppp( 3,46)/ 6.16994085D-08, 1.16794591D-05/
      data fpppp( 3,47),fpppp( 3,48)/ 2.19554067D-05, 3.76625875D-05/
      data fpppp( 3,49),fpppp( 3,50)/ 1.10665309D-04, 1.85985014D-04/
      data fpppp( 3,51),fpppp( 3,52)/ 5.52228351D-04, 1.28111875D-03/
      data fpppp( 3,53),fpppp( 3,54)/-9.58100505D-04,-2.34928843D-03/
      data fpppp( 4, 1),fpppp( 4, 2)/-7.49200819D-03,-3.93499880D-03/
      data fpppp( 4, 3),fpppp( 4, 4)/ 1.48640737D-03, 3.82424838D-04/
      data fpppp( 4, 5),fpppp( 4, 6)/ 1.54321581D-04,-3.22339408D-04/
      data fpppp( 4, 7),fpppp( 4, 8)/-2.16059370D-04,-1.01449836D-04/
      data fpppp( 4, 9),fpppp( 4,10)/-3.21302272D-05,-1.47377882D-05/
      data fpppp( 4,11),fpppp( 4,12)/-7.48618616D-06,-2.93296771D-06/
      data fpppp( 4,13),fpppp( 4,14)/ 2.52441285D-06, 8.26570728D-05/
      data fpppp( 4,15),fpppp( 4,16)/ 1.38135899D-04, 5.01152680D-04/
      data fpppp( 4,17),fpppp( 4,18)/-5.70924651D-04,-2.71003046D-05/
      data fpppp( 4,19),fpppp( 4,20)/-2.71003084D-05,-5.70924636D-04/
      data fpppp( 4,21),fpppp( 4,22)/ 5.01152623D-04, 1.38136111D-04/
      data fpppp( 4,23),fpppp( 4,24)/ 8.26562793D-05, 2.52737457D-06/
      data fpppp( 4,25),fpppp( 4,26)/-2.94402116D-06,-7.44493420D-06/
      data fpppp( 4,27),fpppp( 4,28)/-1.48917428D-05,-3.15556608D-05/
      data fpppp( 4,29),fpppp( 4,30)/-1.03594147D-04,-2.08056692D-04/
      data fpppp( 4,31),fpppp( 4,32)/-3.52205810D-04, 2.65784510D-04/
      data fpppp( 4,33),fpppp( 4,34)/-3.35604790D-05, 3.03888571D-03/
      data fpppp( 4,35),fpppp( 4,36)/-9.72892683D-03, 1.41312256D-02/
      data fpppp( 4,37),fpppp( 4,38)/-9.72892683D-03, 3.03888571D-03/
      data fpppp( 4,39),fpppp( 4,40)/-3.35604775D-05, 2.65784505D-04/
      data fpppp( 4,41),fpppp( 4,42)/-3.52205789D-04,-2.08056771D-04/
      data fpppp( 4,43),fpppp( 4,44)/-1.03593854D-04,-3.15567538D-05/
      data fpppp( 4,45),fpppp( 4,46)/-1.48876636D-05,-7.46015797D-06/
      data fpppp( 4,47),fpppp( 4,48)/-2.88720528D-06, 2.31533463D-06/
      data fpppp( 4,49),fpppp( 4,50)/ 8.34476228D-05, 1.35182777D-04/
      data fpppp( 4,51),fpppp( 4,52)/ 5.12174617D-04,-6.12059278D-04/
      data fpppp( 4,53),fpppp( 4,54)/ 1.26416267D-04, 3.32689114D-04/
      data fpppp( 5, 1),fpppp( 5, 2)/ 2.47544999D-02, 1.42042471D-02/
      data fpppp( 5, 3),fpppp( 5, 4)/-1.35287258D-03, 6.14041827D-04/
      data fpppp( 5, 5),fpppp( 5, 6)/-4.09984933D-04,-1.82898634D-04/
      data fpppp( 5, 7),fpppp( 5, 8)/-1.50149152D-04,-5.60723568D-05/
      data fpppp( 5, 9),fpppp( 5,10)/-3.00603679D-05,-1.87447211D-05/
      data fpppp( 5,11),fpppp( 5,12)/-1.72952131D-05,-2.07473664D-05/
      data fpppp( 5,13),fpppp( 5,14)/-2.05044181D-05, 2.00694735D-06/
      data fpppp( 5,15),fpppp( 5,16)/ 1.99713380D-04, 1.64292429D-04/
      data fpppp( 5,17),fpppp( 5,18)/ 5.75611875D-04,-5.33557843D-04/
      data fpppp( 5,19),fpppp( 5,20)/-5.33557827D-04, 5.75611814D-04/
      data fpppp( 5,21),fpppp( 5,22)/ 1.64292657D-04, 1.99712526D-04/
      data fpppp( 5,23),fpppp( 5,24)/ 2.01013558D-06,-2.05163169D-05/
      data fpppp( 5,25),fpppp( 5,26)/-2.07029594D-05,-1.74609423D-05/
      data fpppp( 5,27),fpppp( 5,28)/-1.81262109D-05,-3.23686795D-05/
      data fpppp( 5,29),fpppp( 5,30)/-4.74576207D-05,-1.82299785D-04/
      data fpppp( 5,31),fpppp( 5,32)/-6.29108382D-05,-8.57785481D-04/
      data fpppp( 5,33),fpppp( 5,34)/ 2.28525622D-03,-7.58992962D-03/
      data fpppp( 5,35),fpppp( 5,36)/ 3.74812609D-02,-6.21164981D-02/
      data fpppp( 5,37),fpppp( 5,38)/ 3.74812609D-02,-7.58992962D-03/
      data fpppp( 5,39),fpppp( 5,40)/ 2.28525623D-03,-8.57785508D-04/
      data fpppp( 5,41),fpppp( 5,42)/-6.29107378D-05,-1.82300160D-04/
      data fpppp( 5,43),fpppp( 5,44)/-4.74562210D-05,-3.23739031D-05/
      data fpppp( 5,45),fpppp( 5,46)/-1.81067160D-05,-1.75336982D-05/
      data fpppp( 5,47),fpppp( 5,48)/-2.04314309D-05,-2.15296748D-05/
      data fpppp( 5,49),fpppp( 5,50)/ 5.79203908D-06, 1.85598270D-04/
      data fpppp( 5,51),fpppp( 5,52)/ 2.16967777D-04, 3.79025591D-04/
      data fpppp( 5,53),fpppp( 5,54)/ 2.00111946D-04, 1.18618717D-04/
      data fpppp( 6, 1),fpppp( 6, 2)/-3.47700377D-02,-1.98636973D-02/
      data fpppp( 6, 3),fpppp( 6, 4)/ 2.61635960D-03,-1.41159116D-03/
      data fpppp( 6, 5),fpppp( 6, 6)/ 6.62375550D-05,-2.21544661D-04/
      data fpppp( 6, 7),fpppp( 6, 8)/-6.27490141D-05,-4.62621605D-05/
      data fpppp( 6, 9),fpppp( 6,10)/-2.09176133D-05,-1.87246554D-05/
      data fpppp( 6,11),fpppp( 6,12)/-2.00783372D-05,-2.88547366D-05/
      data fpppp( 6,13),fpppp( 6,14)/-3.96526855D-05,-4.20239129D-05/
      data fpppp( 6,15),fpppp( 6,16)/ 7.83127296D-05, 3.99108066D-04/
      data fpppp( 6,17),fpppp( 6,18)/-2.02446836D-04,-5.30028352D-05/
      data fpppp( 6,19),fpppp( 6,20)/-5.30028573D-05,-2.02446747D-04/
      data fpppp( 6,21),fpppp( 6,22)/ 3.99107734D-04, 7.83139656D-05/
      data fpppp( 6,23),fpppp( 6,24)/-4.20285258D-05,-3.96354699D-05/
      data fpppp( 6,25),fpppp( 6,26)/-2.89189863D-05,-1.98385539D-05/
      data fpppp( 6,27),fpppp( 6,28)/-1.96195388D-05,-1.75778628D-05/
      data fpppp( 6,29),fpppp( 6,30)/-5.87262787D-05,-1.62322920D-05/
      data fpppp( 6,31),fpppp( 6,32)/-3.95147431D-04, 7.14131915D-04/
      data fpppp( 6,33),fpppp( 6,34)/-3.82956583D-03, 1.16403639D-02/
      data fpppp( 6,35),fpppp( 6,36)/-5.35417399D-02, 9.09181284D-02/
      data fpppp( 6,37),fpppp( 6,38)/-5.35417399D-02, 1.16403639D-02/
      data fpppp( 6,39),fpppp( 6,40)/-3.82956585D-03, 7.14131987D-04/
      data fpppp( 6,41),fpppp( 6,42)/-3.95147700D-04,-1.62312874D-05/
      data fpppp( 6,43),fpppp( 6,44)/-5.87300277D-05,-1.75638713D-05/
      data fpppp( 6,45),fpppp( 6,46)/-1.96717560D-05,-1.96436768D-05/
      data fpppp( 6,47),fpppp( 6,48)/-2.96462777D-05,-3.69211816D-05/
      data fpppp( 6,49),fpppp( 6,50)/-5.21583877D-05, 1.16119125D-04/
      data fpppp( 6,51),fpppp( 6,52)/ 2.58016960D-04, 3.24111193D-04/
      data fpppp( 6,53),fpppp( 6,54)/-2.01814384D-03,-3.67229909D-03/
      data fpppp( 7, 1),fpppp( 7, 2)/ 1.56976457D-02, 8.56360292D-03/
      data fpppp( 7, 3),fpppp( 7, 4)/-2.69230359D-03, 4.78313117D-04/
      data fpppp( 7, 5),fpppp( 7, 6)/-2.82088726D-04,-3.85192735D-05/
      data fpppp( 7, 7),fpppp( 7, 8)/-6.21451565D-05,-2.28209904D-05/
      data fpppp( 7, 9),fpppp( 7,10)/-1.87108566D-05,-1.53479577D-05/
      data fpppp( 7,11),fpppp( 7,12)/-2.06845588D-05,-2.86699048D-05/
      data fpppp( 7,13),fpppp( 7,14)/-4.85468483D-05,-7.51270445D-05/
      data fpppp( 7,15),fpppp( 7,16)/-6.56392947D-05, 2.44391042D-04/
      data fpppp( 7,17),fpppp( 7,18)/ 1.24878753D-03,-8.03594808D-04/
      data fpppp( 7,19),fpppp( 7,20)/-8.03594800D-04, 1.24878750D-03/
      data fpppp( 7,21),fpppp( 7,22)/ 2.44391168D-04,-6.56397651D-05/
      data fpppp( 7,23),fpppp( 7,24)/-7.51252891D-05,-4.85533999D-05/
      data fpppp( 7,25),fpppp( 7,26)/-2.86454538D-05,-2.07758110D-05/
      data fpppp( 7,27),fpppp( 7,28)/-1.50073998D-05,-1.99818362D-05/
      data fpppp( 7,29),fpppp( 7,30)/-1.80776305D-05,-7.98476170D-05/
      data fpppp( 7,31),fpppp( 7,32)/ 2.75472083D-05,-5.28652192D-04/
      data fpppp( 7,33),fpppp( 7,34)/ 1.39850050D-03,-6.12648967D-03/
      data fpppp( 7,35),fpppp( 7,36)/ 2.13801598D-02,-3.21343959D-02/
      data fpppp( 7,37),fpppp( 7,38)/ 2.13801598D-02,-6.12648969D-03/
      data fpppp( 7,39),fpppp( 7,40)/ 1.39850059D-03,-5.28652529D-04/
      data fpppp( 7,41),fpppp( 7,42)/ 2.75484630D-05,-7.98522996D-05/
      data fpppp( 7,43),fpppp( 7,44)/-1.80601544D-05,-2.00470575D-05/
      data fpppp( 7,45),fpppp( 7,46)/-1.47639902D-05,-2.16842278D-05/
      data fpppp( 7,47),fpppp( 7,48)/-2.52551961D-05,-6.12060140D-05/
      data fpppp( 7,49),fpppp( 7,50)/-2.79050906D-05,-2.41867945D-04/
      data fpppp( 7,51),fpppp( 7,52)/ 9.02083689D-04,-1.20575441D-03/
      data fpppp( 7,53),fpppp( 7,54)/ 8.35688030D-03, 1.45850942D-02/
      data fpppp( 8, 1),fpppp( 8, 2)/-3.82584619D-03,-1.97209144D-03/
      data fpppp( 8, 3),fpppp( 8, 4)/ 1.14590939D-03,-1.60951090D-04/
      data fpppp( 8, 5),fpppp( 8, 6)/ 4.83982626D-05,-3.95659811D-05/
      data fpppp( 8, 7),fpppp( 8, 8)/-1.35063585D-05,-1.43694761D-05/
      data fpppp( 8, 9),fpppp( 8,10)/-9.03817777D-06,-1.06370541D-05/
      data fpppp( 8,11),fpppp( 8,12)/-1.40295813D-05,-2.31799568D-05/
      data fpppp( 8,13),fpppp( 8,14)/-3.49175284D-05,-7.38272057D-05/
      data fpppp( 8,15),fpppp( 8,16)/-1.21822882D-04,-3.77069260D-04/
      data fpppp( 8,17),fpppp( 8,18)/-1.67711379D-04, 5.60441739D-04/
      data fpppp( 8,19),fpppp( 8,20)/ 5.60441738D-04,-1.67711372D-04/
      data fpppp( 8,21),fpppp( 8,22)/-3.77069286D-04,-1.21822783D-04/
      data fpppp( 8,23),fpppp( 8,24)/-7.38275757D-05,-3.49161474D-05/
      data fpppp( 8,25),fpppp( 8,26)/-2.31851110D-05,-1.40103456D-05/
      data fpppp( 8,27),fpppp( 8,28)/-1.07088427D-05,-8.77025891D-06/
      data fpppp( 8,29),fpppp( 8,30)/-1.53693627D-05,-9.77473057D-06/
      data fpppp( 8,31),fpppp( 8,32)/-5.34926063D-05, 1.00373135D-04/
      data fpppp( 8,33),fpppp( 8,34)/-3.54923955D-04, 1.86982598D-03/
      data fpppp( 8,35),fpppp( 8,36)/-4.67378493D-03, 6.25701116D-03/
      data fpppp( 8,37),fpppp( 8,38)/-4.67378493D-03, 1.86982601D-03/
      data fpppp( 8,39),fpppp( 8,40)/-3.54924064D-04, 1.00373541D-04/
      data fpppp( 8,41),fpppp( 8,42)/-5.34941214D-05,-9.76907592D-06/
      data fpppp( 8,43),fpppp( 8,44)/-1.53904662D-05,-8.69149980D-06/
      data fpppp( 8,45),fpppp( 8,46)/-1.10027757D-05,-1.29133726D-05/
      data fpppp( 8,47),fpppp( 8,48)/-2.72790699D-05,-1.96372847D-05/
      data fpppp( 8,49),fpppp( 8,50)/-1.30849067D-04, 9.09843213D-05/
      data fpppp( 8,51),fpppp( 8,52)/-1.17127621D-03, 2.79630922D-03/
      data fpppp( 8,53),fpppp( 8,54)/-1.05014337D-02,-1.88662257D-02/
      data fpppp( 9, 1),fpppp( 9, 2)/ 7.31719693D-04, 4.16901633D-04/
      data fpppp( 9, 3),fpppp( 9, 4)/-1.01719732D-04, 9.29704709D-05/
      data fpppp( 9, 5),fpppp( 9, 6)/-2.98548226D-06,-8.46398706D-07/
      data fpppp( 9, 7),fpppp( 9, 8)/-9.15486470D-06,-6.24468726D-06/
      data fpppp( 9, 9),fpppp( 9,10)/-5.08664923D-06,-6.35937656D-06/
      data fpppp( 9,11),fpppp( 9,12)/-9.42469646D-06,-1.19193951D-05/
      data fpppp( 9,13),fpppp( 9,14)/-2.21189482D-05,-1.77363641D-05/
      data fpppp( 9,15),fpppp( 9,16)/-8.90693422D-05, 5.98088856D-05/
      data fpppp( 9,17),fpppp( 9,18)/-8.80533407D-04, 6.57670524D-04/
      data fpppp( 9,19),fpppp( 9,20)/ 6.57670524D-04,-8.80533409D-04/
      data fpppp( 9,21),fpppp( 9,22)/ 5.98088925D-05,-8.90693680D-05/
      data fpppp( 9,23),fpppp( 9,24)/-1.77362677D-05,-2.21193083D-05/
      data fpppp( 9,25),fpppp( 9,26)/-1.19180514D-05,-9.42971144D-06/
      data fpppp( 9,27),fpppp( 9,28)/-6.34066038D-06,-5.15649895D-06/
      data fpppp( 9,29),fpppp( 9,30)/-5.98400460D-06,-1.01277457D-05/
      data fpppp( 9,31),fpppp( 9,32)/ 2.78444260D-06,-1.65359665D-05/
      data fpppp( 9,33),fpppp( 9,34)/ 1.43541566D-04,-2.90453629D-04/
      data fpppp( 9,35),fpppp( 9,36)/ 1.12126613D-03,-1.89700439D-03/
      data fpppp( 9,37),fpppp( 9,38)/ 1.12126613D-03,-2.90453643D-04/
      data fpppp( 9,39),fpppp( 9,40)/ 1.43541619D-04,-1.65361631D-05/
      data fpppp( 9,41),fpppp( 9,42)/ 2.78517635D-06,-1.01304841D-05/
      data fpppp( 9,43),fpppp( 9,44)/-5.97378461D-06,-5.19464041D-06/
      data fpppp( 9,45),fpppp( 9,46)/-6.19831451D-06,-9.96095343D-06/
      data fpppp( 9,47),fpppp( 9,48)/-9.93542929D-06,-2.95185546D-05/
      data fpppp( 9,49),fpppp( 9,50)/ 9.87809551D-06,-1.92127574D-04/
      data fpppp( 9,51),fpppp( 9,52)/ 4.44427355D-04,-2.31594905D-03/
      data fpppp( 9,53),fpppp( 9,54)/ 6.01471463D-03, 1.11765097D-02/
      data fpppp(10, 1),fpppp(10, 2)/-2.88067883D-04,-1.46950851D-04/
      data fpppp(10, 3),fpppp(10, 4)/ 7.60059580D-05, 1.25235485D-05/
      data fpppp(10, 5),fpppp(10, 6)/ 1.42612004D-05,-9.28848835D-07/
      data fpppp(10, 7),fpppp(10, 8)/-2.22279826D-06,-2.55728393D-06/
      data fpppp(10, 9),fpppp(10,10)/-2.94516690D-06,-2.90027686D-06/
      data fpppp(10,11),fpppp(10,12)/-4.24507860D-06,-6.71193264D-06/
      data fpppp(10,13),fpppp(10,14)/-5.58123043D-06,-1.11877372D-05/
      data fpppp(10,15),fpppp(10,16)/ 2.87290547D-05,-3.92486375D-05/
      data fpppp(10,17),fpppp(10,18)/ 5.26968479D-04,-3.20999666D-04/
      data fpppp(10,19),fpppp(10,20)/-3.20999667D-04, 5.26968480D-04/
      data fpppp(10,21),fpppp(10,22)/-3.92486392D-05, 2.87290613D-05/
      data fpppp(10,23),fpppp(10,24)/-1.11877617D-05,-5.58113908D-06/
      data fpppp(10,25),fpppp(10,26)/-6.71227357D-06,-4.24380627D-06/
      data fpppp(10,27),fpppp(10,28)/-2.90502529D-06,-2.92744551D-06/
      data fpppp(10,29),fpppp(10,30)/-2.62342100D-06,-1.97597132D-06/
      data fpppp(10,31),fpppp(10,32)/-1.85001954D-06, 1.76990562D-05/
      data fpppp(10,33),fpppp(10,34)/-3.06704108D-07, 1.23889113D-04/
      data fpppp(10,35),fpppp(10,36)/-3.25653217D-04, 3.78858427D-04/
      data fpppp(10,37),fpppp(10,38)/-3.25653218D-04, 1.23889116D-04/
      data fpppp(10,39),fpppp(10,40)/-3.06714870D-07, 1.76990964D-05/
      data fpppp(10,41),fpppp(10,42)/-1.85016956D-06,-1.97541140D-06/
      data fpppp(10,43),fpppp(10,44)/-2.62551066D-06,-2.91964684D-06/
      data fpppp(10,45),fpppp(10,46)/-2.93413035D-06,-4.13518472D-06/
      data fpppp(10,47),fpppp(10,48)/-7.11765470D-06,-4.06823611D-06/
      data fpppp(10,49),fpppp(10,50)/-1.68339924D-05, 4.98010814D-05/
      data fpppp(10,51),fpppp(10,52)/-1.17890489D-04, 8.20463858D-04/
      data fpppp(10,53),fpppp(10,54)/-1.41633933D-03,-2.74595465D-03/
      data fpppp(11, 1),fpppp(11, 2)/ 1.85229909D-05, 1.23674694D-05/
      data fpppp(11, 3),fpppp(11, 4)/-2.20204556D-06, 1.26774168D-05/
      data fpppp(11, 5),fpppp(11, 6)/ 4.29429856D-06, 1.03724078D-06/
      data fpppp(11, 7),fpppp(11, 8)/-8.65346888D-07,-1.26800526D-06/
      data fpppp(11, 9),fpppp(11,10)/-1.25396560D-06,-1.39655811D-06/
      data fpppp(11,11),fpppp(11,12)/-1.88553825D-06,-2.52163573D-06/
      data fpppp(11,13),fpppp(11,14)/-2.59053525D-06, 1.75369497D-06/
      data fpppp(11,15),fpppp(11,16)/ 7.22600002D-06, 3.48437749D-05/
      data fpppp(11,17),fpppp(11,18)/-2.59418300D-05,-5.14869327D-06/
      data fpppp(11,19),fpppp(11,20)/-5.14869325D-06,-2.59418300D-05/
      data fpppp(11,21),fpppp(11,22)/ 3.48437752D-05, 7.22599880D-06/
      data fpppp(11,23),fpppp(11,24)/ 1.75369952D-06,-2.59055224D-06/
      data fpppp(11,25),fpppp(11,26)/-2.52157230D-06,-1.88577493D-06/
      data fpppp(11,27),fpppp(11,28)/-1.39567482D-06,-1.25726207D-06/
      data fpppp(11,29),fpppp(11,30)/-1.25570266D-06,-9.11260837D-07/
      data fpppp(11,31),fpppp(11,32)/ 1.20859401D-06, 3.65479965D-06/
      data fpppp(11,33),fpppp(11,34)/ 1.50640592D-05,-1.11091163D-05/
      data fpppp(11,35),fpppp(11,36)/ 4.56091100D-05,-1.05536501D-04/
      data fpppp(11,37),fpppp(11,38)/ 4.56091101D-05,-1.11091169D-05/
      data fpppp(11,39),fpppp(11,40)/ 1.50640615D-05, 3.65479103D-06/
      data fpppp(11,41),fpppp(11,42)/ 1.20862619D-06,-9.11380945D-07/
      data fpppp(11,43),fpppp(11,44)/-1.25525442D-06,-1.25893490D-06/
      data fpppp(11,45),fpppp(11,46)/-1.38943173D-06,-1.90907443D-06/
      data fpppp(11,47),fpppp(11,48)/-2.43461739D-06,-2.91507239D-06/
      data fpppp(11,49),fpppp(11,50)/ 2.96482520D-06, 2.70601621D-06/
      data fpppp(11,51),fpppp(11,52)/ 5.17125799D-05,-8.88970661D-05/
      data fpppp(11,53),fpppp(11,54)/ 2.29803446D-04, 4.17272485D-04/
      data fpppp(12, 1),fpppp(12, 2)/-1.31755781D-05,-6.84988882D-06/
      data fpppp(12, 3),fpppp(12, 4)/ 2.87132870D-06, 7.08197378D-07/
      data fpppp(12, 5),fpppp(12, 6)/ 1.07744526D-06, 2.14715540D-07/
      data fpppp(12, 7),fpppp(12, 8)/-2.83555283D-07,-2.11375449D-07/
      data fpppp(12, 9),fpppp(12,10)/-2.34391947D-07,-2.02665315D-07/
      data fpppp(12,11),fpppp(12,12)/-2.82061490D-07,-4.55786246D-07/
      data fpppp(12,13),fpppp(12,14)/-2.19245849D-08, 7.66025650D-07/
      data fpppp(12,15),fpppp(12,16)/ 3.87665026D-06, 1.07904141D-06/
      data fpppp(12,17),fpppp(12,18)/ 1.78898831D-05,-1.48906661D-05/
      data fpppp(12,19),fpppp(12,20)/-1.48906661D-05, 1.78898831D-05/
      data fpppp(12,21),fpppp(12,22)/ 1.07904133D-06, 3.87665056D-06/
      data fpppp(12,23),fpppp(12,24)/ 7.66024509D-07,-2.19203209D-08/
      data fpppp(12,25),fpppp(12,26)/-4.55802155D-07,-2.82002134D-07/
      data fpppp(12,27),fpppp(12,28)/-2.02886852D-07,-2.33565164D-07/
      data fpppp(12,29),fpppp(12,30)/-2.14461036D-07,-2.72039711D-07/
      data fpppp(12,31),fpppp(12,32)/ 1.71738825D-07, 1.23783653D-06/
      data fpppp(12,33),fpppp(12,34)/ 1.09608995D-07, 5.10529096D-06/
      data fpppp(12,35),fpppp(12,36)/-1.51871495D-05, 1.79395023D-05/
      data fpppp(12,37),fpppp(12,38)/-1.51871495D-05, 5.10529111D-06/
      data fpppp(12,39),fpppp(12,40)/ 1.09608431D-07, 1.23783863D-06/
      data fpppp(12,41),fpppp(12,42)/ 1.71730986D-07,-2.72010453D-07/
      data fpppp(12,43),fpppp(12,44)/-2.14570219D-07,-2.33157695D-07/
      data fpppp(12,45),fpppp(12,46)/-2.04407556D-07,-2.76326793D-07/
      data fpppp(12,47),fpppp(12,48)/-4.76982808D-07, 5.71269515D-08/
      data fpppp(12,49),fpppp(12,50)/ 4.71016072D-07, 4.97763705D-06/
      data fpppp(12,51),fpppp(12,52)/-3.02989618D-06, 3.32246466D-05/
      data fpppp(12,53),fpppp(12,54)/-7.21207828D-05,-1.37009077D-04/
      data fpppp(13, 1),fpppp(13, 2)/ 1.99497276D-06, 1.11278320D-06/
      data fpppp(13, 3),fpppp(13, 4)/-4.05710038D-07, 3.02859562D-07/
      data fpppp(13, 5),fpppp(13, 6)/ 1.40977982D-08,-5.38783647D-08/
      data fpppp(13, 7),fpppp(13, 8)/ 5.24922889D-08,-7.64145598D-08/
      data fpppp(13, 9),fpppp(13,10)/-2.57044331D-08,-1.25907749D-07/
      data fpppp(13,11),fpppp(13,12)/-1.60469461D-07, 6.92253598D-09/
      data fpppp(13,13),fpppp(13,14)/-5.20800043D-08, 1.09314926D-07/
      data fpppp(13,15),fpppp(13,16)/ 2.13262571D-07, 1.54149247D-06/
      data fpppp(13,17),fpppp(13,18)/-3.45329793D-06, 1.29630702D-06/
      data fpppp(13,19),fpppp(13,20)/ 1.29630702D-06,-3.45329794D-06/
      data fpppp(13,21),fpppp(13,22)/ 1.54149249D-06, 2.13262507D-07/
      data fpppp(13,23),fpppp(13,24)/ 1.09315172D-07,-5.20809279D-08/
      data fpppp(13,25),fpppp(13,26)/ 6.92597488D-09,-1.60482290D-07/
      data fpppp(13,27),fpppp(13,28)/-1.25859858D-07,-2.58831619D-08/
      data fpppp(13,29),fpppp(13,30)/-7.57475354D-08, 5.00029202D-08/
      data fpppp(13,31),fpppp(13,32)/-4.45879051D-08,-2.05746688D-08/
      data fpppp(13,33),fpppp(13,34)/ 4.32258967D-07,-8.88635195D-07/
      data fpppp(13,35),fpppp(13,36)/ 2.91508443D-06,-4.73130699D-06/
      data fpppp(13,37),fpppp(13,38)/ 2.91508444D-06,-8.88635237D-07/
      data fpppp(13,39),fpppp(13,40)/ 4.32259126D-07,-2.05752563D-08/
      data fpppp(13,41),fpppp(13,42)/-4.45857176D-08, 4.99947566D-08/
      data fpppp(13,43),fpppp(13,44)/-7.57170752D-08,-2.59968377D-08/
      data fpppp(13,45),fpppp(13,46)/-1.25435608D-07,-1.62065612D-07/
      data fpppp(13,47),fpppp(13,48)/ 1.28350099D-08,-7.41337442D-08/
      data fpppp(13,49),fpppp(13,50)/ 1.91617404D-07,-9.38936170D-08/
      data fpppp(13,51),fpppp(13,52)/ 2.68781474D-06,-7.73143084D-06/
      data fpppp(13,53),fpppp(13,54)/ 1.72625164D-05, 3.21384085D-05/
      data fpppp(14, 1),fpppp(14, 2)/-4.24122392D-07,-2.21625120D-07/
      data fpppp(14, 3),fpppp(14, 4)/ 9.28454649D-08, 1.54094574D-08/
      data fpppp(14, 5),fpppp(14, 6)/ 4.46492169D-08, 1.18101678D-08/
      data fpppp(14, 7),fpppp(14, 8)/-3.29485142D-08,-3.84004287D-09/
      data fpppp(14, 9),fpppp(14,10)/-2.87607348D-08,-8.94829510D-09/
      data fpppp(14,11),fpppp(14,12)/ 1.08881350D-08,-6.44544695D-08/
      data fpppp(14,13),fpppp(14,14)/-5.45019168D-08, 3.22513124D-08/
      data fpppp(14,15),fpppp(14,16)/ 8.08993309D-08,-2.94744884D-09/
      data fpppp(14,17),fpppp(14,18)/ 7.36453496D-07,-4.81205109D-07/
      data fpppp(14,19),fpppp(14,20)/-4.81205108D-07, 7.36453497D-07/
      data fpppp(14,21),fpppp(14,22)/-2.94745187D-09, 8.08993418D-08/
      data fpppp(14,23),fpppp(14,24)/ 3.22512712D-08,-5.45017607D-08/
      data fpppp(14,25),fpppp(14,26)/-6.44550475D-08, 1.08902928D-08/
      data fpppp(14,27),fpppp(14,28)/-8.95635345D-09,-2.87306642D-08/
      data fpppp(14,29),fpppp(14,30)/-3.95226865D-09,-3.25296839D-08/
      data fpppp(14,31),fpppp(14,32)/ 1.02470668D-08, 5.04827907D-08/
      data fpppp(14,33),fpppp(14,34)/-6.36173620D-09, 1.74096667D-07/
      data fpppp(14,35),fpppp(14,36)/-5.24858735D-07, 7.07560867D-07/
      data fpppp(14,37),fpppp(14,38)/-5.24858737D-07, 1.74096675D-07/
      data fpppp(14,39),fpppp(14,40)/-6.36176544D-09, 5.04828992D-08/
      data fpppp(14,41),fpppp(14,42)/ 1.02466645D-08,-3.25281847D-08/
      data fpppp(14,43),fpppp(14,44)/-3.95786066D-09,-2.87097958D-08/
      data fpppp(14,45),fpppp(14,46)/-9.03423923D-09, 1.11809667D-08/
      data fpppp(14,47),fpppp(14,48)/-6.55398577D-08,-5.04531945D-08/
      data fpppp(14,49),fpppp(14,50)/ 1.71418141D-08, 1.37288606D-07/
      data fpppp(14,51),fpppp(14,52)/-2.13395048D-07, 1.52185462D-06/
      data fpppp(14,53),fpppp(14,54)/-3.41236202D-06,-6.44101685D-06/
      data fpppp(15, 1),fpppp(15, 2)/ 8.99125665D-08, 4.94202051D-08/
      data fpppp(15, 3),fpppp(15, 4)/-1.44589419D-08, 3.51566341D-09/
      data fpppp(15, 5),fpppp(15, 6)/-7.91424979D-09,-3.99434113D-09/
      data fpppp(15, 7),fpppp(15, 8)/ 2.52917604D-09,-7.48866497D-09/
      data fpppp(15, 9),fpppp(15,10)/ 2.06893127D-09,-4.72321393D-09/
      data fpppp(15,11),fpppp(15,12)/-8.27626741D-09, 1.28104751D-08/
      data fpppp(15,13),fpppp(15,14)/ 8.75900664D-09,-1.61727530D-08/
      data fpppp(15,15),fpppp(15,16)/-7.49713609D-09, 1.25288992D-08/
      data fpppp(15,17),fpppp(15,18)/-1.33274823D-07, 9.02822290D-08/
      data fpppp(15,19),fpppp(15,20)/ 9.02822288D-08,-1.33274823D-07/
      data fpppp(15,21),fpppp(15,22)/ 1.25288996D-08,-7.49713819D-09/
      data fpppp(15,23),fpppp(15,24)/-1.61727444D-08, 8.75897404D-09/
      data fpppp(15,25),fpppp(15,26)/ 1.28105959D-08,-8.27671775D-09/
      data fpppp(15,27),fpppp(15,28)/-4.72153130D-09, 2.06265251D-09/
      data fpppp(15,29),fpppp(15,30)/-7.46523244D-09, 2.44172594D-09/
      data fpppp(15,31),fpppp(15,32)/-3.66797052D-09,-9.13228166D-09/
      data fpppp(15,33),fpppp(15,34)/ 8.06142006D-09,-3.14239360D-08/
      data fpppp(15,35),fpppp(15,36)/ 1.12734425D-07,-1.46379320D-07/
      data fpppp(15,37),fpppp(15,38)/ 1.12734426D-07,-3.14239378D-08/
      data fpppp(15,39),fpppp(15,40)/ 8.06142632D-09,-9.13230533D-09/
      data fpppp(15,41),fpppp(15,42)/-3.66788264D-09, 2.44139848D-09/
      data fpppp(15,43),fpppp(15,44)/-7.46401158D-09, 2.05809606D-09/
      data fpppp(15,45),fpppp(15,46)/-4.70452477D-09,-8.34018673D-09/
      data fpppp(15,47),fpppp(15,48)/ 1.30474656D-08, 7.87496318D-09/
      data fpppp(15,49),fpppp(15,50)/-1.28735704D-08,-1.98098237D-08/
      data fpppp(15,51),fpppp(15,52)/ 5.84804667D-08,-3.04768408D-07/
      data fpppp(15,53),fpppp(15,54)/ 7.30305000D-07, 1.36585776D-06/
      data fpppp(16, 1),fpppp(16, 2)/-1.84436049D-08,-9.35064301D-09/
      data fpppp(16, 3),fpppp(16, 4)/ 5.24963357D-09, 5.74308757D-10/
      data fpppp(16, 5),fpppp(16, 6)/ 1.39991742D-09,-2.66050215D-10/
      data fpppp(16, 7),fpppp(16, 8)/-2.42184155D-09,-9.42961052D-10/
      data fpppp(16, 9),fpppp(16,10)/-1.90485804D-09,-1.09623907D-09/
      data fpppp(16,11),fpppp(16,12)/-2.65699039D-10,-4.54811838D-09/
      data fpppp(16,13),fpppp(16,14)/-3.00285855D-09,-2.12391489D-10/
      data fpppp(16,15),fpppp(16,16)/ 3.68112271D-09, 3.28433551D-10/
      data fpppp(16,17),fpppp(16,18)/ 3.81510015D-08,-2.17461810D-08/
      data fpppp(16,19),fpppp(16,20)/-2.17461810D-08, 3.81510015D-08/
      data fpppp(16,21),fpppp(16,22)/ 3.28433414D-10, 3.68112325D-09/
      data fpppp(16,23),fpppp(16,24)/-2.12393577D-10,-3.00285071D-09/
      data fpppp(16,25),fpppp(16,26)/-4.54814757D-09,-2.65590269D-10/
      data fpppp(16,27),fpppp(16,28)/-1.09664529D-09,-1.90334217D-09/
      data fpppp(16,29),fpppp(16,30)/-9.48618354D-10,-2.40072841D-09/
      data fpppp(16,31),fpppp(16,32)/-3.44845858D-10, 1.69398675D-09/
      data fpppp(16,33),fpppp(16,34)/-5.23172749D-10, 9.34549010D-09/
      data fpppp(16,35),fpppp(16,36)/-2.46365878D-08, 3.86043177D-08/
      data fpppp(16,37),fpppp(16,38)/-2.46365879D-08, 9.34549047D-09/
      data fpppp(16,39),fpppp(16,40)/-5.23174109D-10, 1.69399190D-09/
      data fpppp(16,41),fpppp(16,42)/-3.44865021D-10,-2.40065691D-09/
      data fpppp(16,43),fpppp(16,44)/-9.48885084D-10,-1.90234667D-09/
      data fpppp(16,45),fpppp(16,46)/-1.10036073D-09,-2.51724020D-10/
      data fpppp(16,47),fpppp(16,48)/-4.59989696D-09,-2.80971911D-09/
      data fpppp(16,49),fpppp(16,50)/-9.33170569D-10, 6.37109971D-09/
      data fpppp(16,51),fpppp(16,52)/-9.71069536D-09, 7.56175405D-08/
      data fpppp(16,53),fpppp(16,54)/-1.61573208D-07,-3.06615675D-07/
      data fpppp(17, 1),fpppp(17, 2)/ 1.53709703D-08, 6.15198335D-09/
      data fpppp(17, 3),fpppp(17, 4)/-5.95063351D-09,-7.96054908D-09/
      data fpppp(17, 5),fpppp(17, 6)/-4.57056391D-09,-7.41159543D-10/
      data fpppp(17, 7),fpppp(17, 8)/ 3.50826583D-09, 7.03628730D-09/
      data fpppp(17, 9),fpppp(17,10)/ 3.71585676D-09, 5.60960056D-09/
      data fpppp(17,11),fpppp(17,12)/ 4.12349964D-09,-9.90023147D-10/
      data fpppp(17,13),fpppp(17,14)/ 3.39711099D-09, 4.78755034D-09/
      data fpppp(17,15),fpppp(17,16)/-1.27416627D-08,-1.13711645D-08/
      data fpppp(17,17),fpppp(17,18)/-3.60066109D-08, 2.78544792D-08/
      data fpppp(17,19),fpppp(17,20)/ 2.78544793D-08,-3.60066111D-08/
      data fpppp(17,21),fpppp(17,22)/-1.13711643D-08,-1.27416631D-08/
      data fpppp(17,23),fpppp(17,24)/ 4.78755135D-09, 3.39710736D-09/
      data fpppp(17,25),fpppp(17,26)/-9.90010129D-10, 4.12345011D-09/
      data fpppp(17,27),fpppp(17,28)/ 5.60978461D-09, 3.71516978D-09/
      data fpppp(17,29),fpppp(17,30)/ 7.03885151D-09, 3.49869497D-09/
      data fpppp(17,31),fpppp(17,32)/-7.05442121D-10,-4.70386350D-09/
      data fpppp(17,33),fpppp(17,34)/-7.46306766D-09,-7.80726121D-09/
      data fpppp(17,35),fpppp(17,36)/ 1.30810121D-08,-1.04885174D-08/
      data fpppp(17,37),fpppp(17,38)/ 1.30810121D-08,-7.80726120D-09/
      data fpppp(17,39),fpppp(17,40)/-7.46306687D-09,-4.70386571D-09/
      data fpppp(17,41),fpppp(17,42)/-7.05434328D-10, 3.49866611D-09/
      data fpppp(17,43),fpppp(17,44)/ 7.03895971D-09, 3.71476670D-09/
      data fpppp(17,45),fpppp(17,46)/ 5.61128825D-09, 4.11783825D-09/
      data fpppp(17,47),fpppp(17,48)/-9.69066003D-10, 3.31894489D-09/
      data fpppp(17,49),fpppp(17,50)/ 5.07925768D-09,-1.38303263D-08/
      data fpppp(17,51),fpppp(17,52)/-7.30821781D-09,-5.11697333D-08/
      data fpppp(17,53),fpppp(17,54)/ 8.44440227D-08, 1.68779128D-07/
 
      data x( 1), x( 2) /  4.00000000D+00 ,  4.20000000D+00 /
      data x( 3), x( 4) /  4.40000000D+00 ,  4.60000000D+00 /
      data x( 5), x( 6) /  4.80000000D+00 ,  5.00000000D+00 /
      data x( 7), x( 8) /  5.20000000D+00 ,  5.60000000D+00 /
      data x( 9), x(10) /  6.00000000D+00 ,  6.50000000D+00 /
      data x(11), x(12) /  7.00000000D+00 ,  8.00000000D+00 /
      data x(13), x(14) /  9.00000000D+00 ,  1.00000000D+01 /
      data x(15), x(16) /  1.20000000D+01 ,  1.50000000D+01 /
      data x(17) /         2.00000000D+01 /
 
      data y( 1), y( 2) / -1.80000000D+02 , -1.70000000D+02 /
      data y( 3), y( 4) / -1.60000000D+02 , -1.50000000D+02 /
      data y( 5), y( 6) / -1.40000000D+02 , -1.30000000D+02 /
      data y( 7), y( 8) / -1.20000000D+02 , -1.10000000D+02 /
      data y( 9), y(10) / -1.00000000D+02 , -9.00000000D+01 /
      data y(11), y(12) / -8.00000000D+01 , -7.00000000D+01 /
      data y(13), y(14) / -6.00000000D+01 , -5.00000000D+01 /
      data y(15), y(16) / -4.00000000D+01 , -3.00000000D+01 /
      data y(17), y(18) / -2.00000000D+01 , -1.00000000D+01 /
      data y(19), y(20) /  1.00000000D+01 ,  2.00000000D+01 /
      data y(21), y(22) /  3.00000000D+01 ,  4.00000000D+01 /
      data y(23), y(24) /  5.00000000D+01 ,  6.00000000D+01 /
      data y(25), y(26) /  7.00000000D+01 ,  8.00000000D+01 /
      data y(27), y(28) /  9.00000000D+01 ,  1.00000000D+02 /
      data y(29), y(30) /  1.10000000D+02 ,  1.20000000D+02 /
      data y(31), y(32) /  1.30000000D+02 ,  1.40000000D+02 /
      data y(33), y(34) /  1.50000000D+02 ,  1.60000000D+02 /
      data y(35), y(36) /  1.70000000D+02 ,  1.80000000D+02 /
      data y(37), y(38) /  1.90000000D+02 ,  2.00000000D+02 /
      data y(39), y(40) /  2.10000000D+02 ,  2.20000000D+02 /
      data y(41), y(42) /  2.30000000D+02 ,  2.40000000D+02 /
      data y(43), y(44) /  2.50000000D+02 ,  2.60000000D+02 /
      data y(45), y(46) /  2.70000000D+02 ,  2.80000000D+02 /
      data y(47), y(48) /  2.90000000D+02 ,  3.00000000D+02 /
      data y(49), y(50) /  3.10000000D+02 ,  3.20000000D+02 /
      data y(51), y(52) /  3.30000000D+02 ,  3.40000000D+02 /
      data y(53), y(54) /  3.50000000D+02 ,  3.60000000D+02 /
 
      data delx( 1), delx( 2) /  2.00000000D-01 ,  2.00000000D-01 /
      data delx( 3), delx( 4) /  2.00000000D-01 ,  2.00000000D-01 /
      data delx( 5), delx( 6) /  2.00000000D-01 ,  2.00000000D-01 /
      data delx( 7), delx( 8) /  4.00000000D-01 ,  4.00000000D-01 /
      data delx( 9), delx(10) /  5.00000000D-01 ,  5.00000000D-01 /
      data delx(11), delx(12) /  1.00000000D+00 ,  1.00000000D+00 /
      data delx(13), delx(14) /  1.00000000D+00 ,  2.00000000D+00 /
      data delx(15), delx(16) /  3.00000000D+00 ,  5.00000000D+00 /
      data dely( 1), dely( 2) /  1.00000000D+01 ,  1.00000000D+01 /
      data dely( 3), dely( 4) /  1.00000000D+01 ,  1.00000000D+01 /
      data dely( 5), dely( 6) /  1.00000000D+01 ,  1.00000000D+01 /
      data dely( 7), dely( 8) /  1.00000000D+01 ,  1.00000000D+01 /
      data dely( 9), dely(10) /  1.00000000D+01 ,  1.00000000D+01 /
      data dely(11), dely(12) /  1.00000000D+01 ,  1.00000000D+01 /
      data dely(13), dely(14) /  1.00000000D+01 ,  1.00000000D+01 /
      data dely(15), dely(16) /  1.00000000D+01 ,  1.00000000D+01 /
      data dely(17), dely(18) /  1.00000000D+01 ,  2.00000000D+01 /
      data dely(19), dely(20) /  1.00000000D+01 ,  1.00000000D+01 /
      data dely(21), dely(22) /  1.00000000D+01 ,  1.00000000D+01 /
      data dely(23), dely(24) /  1.00000000D+01 ,  1.00000000D+01 /
      data dely(25), dely(26) /  1.00000000D+01 ,  1.00000000D+01 /
      data dely(27), dely(28) /  1.00000000D+01 ,  1.00000000D+01 /
      data dely(29), dely(30) /  1.00000000D+01 ,  1.00000000D+01 /
      data dely(31), dely(32) /  1.00000000D+01 ,  1.00000000D+01 /
      data dely(33), dely(34) /  1.00000000D+01 ,  1.00000000D+01 /
      data dely(35), dely(36) /  1.00000000D+01 ,  1.00000000D+01 /
      data dely(37), dely(38) /  1.00000000D+01 ,  1.00000000D+01 /
      data dely(39), dely(40) /  1.00000000D+01 ,  1.00000000D+01 /
      data dely(41), dely(42) /  1.00000000D+01 ,  1.00000000D+01 /
      data dely(43), dely(44) /  1.00000000D+01 ,  1.00000000D+01 /
      data dely(45), dely(46) /  1.00000000D+01 ,  1.00000000D+01 /
      data dely(47), dely(48) /  1.00000000D+01 ,  1.00000000D+01 /
      data dely(49), dely(50) /  1.00000000D+01 ,  1.00000000D+01 /
      data dely(51), dely(52) /  1.00000000D+01 ,  1.00000000D+01 /
      data dely(53) /            1.00000000D+01 /
      data nptx,npty /  17 , 54 /
      data iprint / 0 /

      IF(XI .LE. X(1)) THEN
        IX=1
      ELSE IF( XI .GE. X(nptx)) THEN
        IX=nptx-1
      ELSE
        call hunt(x,nptx,xi,ix)
      ENDIF
 15   xix=x(ix)
      xixp1=x(ix+1)
      delxi = delx(ix)
      if(iprint .gt. 2) then
        write(6,'(a,i3,a,2f10.5,a,1f10.5)') ' ix=',ix,
     x       '  xix,xixp1=',xix,xixp1,'  delxi=',delxi
      endif
C
      IF(yi .LE. y(1)) THEN
        iy=1
      ELSE IF( yi .GE. y(npty)) THEN
        iy=npty-1
      ELSE
        call hunt(y,npty,yi,iy)
      ENDIF
 25   yiy=y(iy)
      yiyp1=y(iy+1)
      delyi = dely(iy)
      if(iprint .gt. 2) then
        write(6,'(a,i3,a,2f10.5,a,1f10.5)') ' iy=',iy,
     x       '  yiy,yiyp1=',yiy,yiyp1,'  delyi=',delyi
      endif
C
   30 C(1,1)=FPPPP(IX+1,IY+1)
      C(1,2)=FPPPP(IX+1,IY  )
      C(2,1)=FPPPP(IX  ,IY+1)
      C(2,2)=FPPPP(IX,  IY  )
      C(1,3)=FPP(IX+1,IY+1,1)
      C(1,4)=FPP(IX+1,IY  ,1)
      C(2,3)=FPP(IX,  IY+1,1)
      C(2,4)=FPP(IX,  IY,  1)
      C(3,1)=FPP(IX+1,IY+1,2)
      C(3,2)=FPP(IX+1,IY  ,2)
      C(4,1)=FPP(IX,  IY+1,2)
      C(4,2)=FPP(IX,  IY,  2)
      C(3,3)=F(IX+1,IY+1)
      C(3,4)=F(IX+1,IY  )
      C(4,3)=F(IX,  IY+1)
      C(4,4)=F(IX,  IY  )
      PX(1)=((XI-XIX)**3/(6.0*DELXi))-(XI-XIX)*DELXi/6.0
      PX(2)=(XI-XIXP1)*DELXi/6.0-((XI-XIXP1)**3/(6.0*DELXi))
      PX(3)=(XI-XIX)/DELXi
      PX(4)=(XIXP1-XI)/DELXi
      PY(1)=((YI-YIY)**3/(6.0*DELYi))-(YI-YIY)*DELYi/6.0
      PY(2)=(YI-YIYP1)*DELYi/6.0-((YI-YIYP1)**3/(6.0*DELYi))
      PY(3)=(YI-YIY)/DELYi
      PY(4)=(YIYP1-YI)/DELYi

      fi=0.0d 00
      do l=1,4
        sum=0.0d 00
        do i=1,4
          sum=sum + c(i,l) * px(i)
        enddo
        fi = fi + sum * py(l)
      enddo
      fi = fi + 168.2535841d0
      RETURN
      END  
